(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[  40337904,     737246]
NotebookOptionsPosition[  40116378,     732859]
NotebookOutlinePosition[  40284146,     736130]
CellTagsIndexPosition[  40283572,     736111]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["7. Working with CreateClones", "Subtitle",
 CellTags->{
  "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
   "Solar Array Example", "Cellular Array Example", "PR7."}],

Cell[TextData[{
 ButtonBox["7.1 Introduction",
  BaseStyle->"Hyperlink",
  ButtonData:>"7.1"],
 "\n",
 ButtonBox["7.2 Lenticular Array Example",
  BaseStyle->"Hyperlink",
  ButtonData:>"7.2"],
 "\n",
 ButtonBox["7.3 Solar Array Example",
  BaseStyle->"Hyperlink",
  ButtonData:>"7.3"],
 "\n",
 ButtonBox["7.4 Cellular Array Example",
  BaseStyle->"Hyperlink",
  ButtonData:>"7.4"]
}], "Outline2",
 CellTags->"PR7."],

Cell[CellGroupData[{

Cell["7.1 Introduction", "Section",
 CellTags->{"7.1", "7.1 Introduction", "PR7.1", "PR7."}],

Cell[TextData[{
 "This chapter discusses and demonstrates the use of ",
 StyleBox["CreateClones", "Input"],
 ", a powerful mechanism for modelling multiple copies of an optical element \
in a system. The ",
 StyleBox["CreateClones", "Input"],
 " option is limited to ",
 StyleBox["TurboTrace", "Input"],
 " calculations and does not exist in ",
 StyleBox["PropagateSystem", "Input"],
 ". Next we examine the usage message for ",
 StyleBox["CreateClones", "Input"],
 "."
}], "Text",
 CellTags->{"Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],

Cell[CellGroupData[{

Cell["?CreateClones", "Input",
 CellTags->{"Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."},
 CellLabel->"In[251]:="],

Cell[BoxData[
 StyleBox["\<\"CreateClones -> {{coordinates, rotationmatrix, \
componentnumber, scale}, ...} specifies the placement of one or more phantom \
optical components to be used during the ray trace. These component aliases \
exhibit the raytrace behavior of the original component members but do not \
consume additional computer memory. This permits the efficient nonsequential \
ray tracing of large arrays of optical elements. \\n\\nIn the specification \
of CreateClones, the coordinates parameter gives the two or three-dimensional \
location of the cloned object, rotationmatrix provides the cloned optic \
orientation, componentnumber denotes which component in the optical system \
list will be cloned, and scale indicates the relative size of the new clone. \
In addition to taking a single numeric value, the scale parameter can also \
take a list of three numbers to specify three separate coordinate scales. If \
no twisting about the rotation axis is required, the unit-direction vector \
(the first rotationmatrix element) can be used on its own and the remaining \
rotationmatrix elements will be internally calculated. During the \
specification of CreateClones, rotationmatrix, componentnumber, and scale are \
all optional parameters that can be selectively omitted or mixed-in, however, \
componentnumber must also be present before a scale can be specified. When \
not present, rotationmatrix, componentnumber, and scale will assume the \
respective values of: {{1,0,0},{0,1,0},{0,0,1}}, 1, and 1. \\n\\nCreateClones \
permits a wide variety of input data formats. For very large systems of \
specified elements, CreateClones also permits the use of packed arrays. In \
such a case, each set of parameters in the element listing is presented as a \
flattened list of real numbers. CreateClones also permits the specification \
of multiple sets of optical arrays. This is accomplished with an additional \
nesting of the data: {{{coordinates, rotationmatrix, componentnumber, scale}, \
...},...}. Here, the rays are nonsequentially traced within each array, but \
are sequentially traced between the array data sets. \\n\\nAlthough \
CreateClones only operates within the TurboTrace engine, CreateClones may \
also be specified for AnalyzeSystem/DrawSystem. In such an event, \
TracingEngine->TurboTrace is automatically used instead of PropagateSystem. \
See also: ShowClones, CloneSortLength, CloneSortMethod, ComponentNumber, \
TranslationVector, and RotationMatrix.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614727719092474*^9},
 CellTags->{
  "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
   "PR7.", "PR7.1"}]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 7 topics"]], "Text",
 CellTags->"PR7."]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Lenticular Array Example", "Section",
 CellTags->{"7.2", "Lenticular Array Example", "PR7.2", "PR7."}],

Cell["\<\
In this present example, we will model an array of lenslets in which each \
copy is identical in the size and shape to the other copies. This restriction \
is not necessary, however, and it is in fact possible to assign a scale the \
size of each copy uniquely. \
\>", "Text",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],

Cell["\<\
positions = Flatten[Table[{0.,y,z},{y,-5,5,1},{z,-5,5,1}],1]//N;\
\>", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[252]:="],

Cell["\<\
ListPlot[Map[Rest,positions],PlotRange->All, AspectRatio->1];\
\>", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[253]:="],

Cell[CellGroupData[{

Cell["\<\
lenslet = Resonate[{
\tMove[PinHole[{1,1},.75, GraphicDesign->Sketch],.07],
\tMove[PinHole[{1,1},.75, SurfaceRendering->Fill],.3],
\tPlanoConvexLens[2,.75,.3, SurfaceRendering->Empty, EdgeRendering->Empty, \
CrossRendering->Trace]}]\
\>", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[254]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Resonate", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"PinHole", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}], ",", "0.75`", ",", 
           RowBox[{"{", 
            RowBox[{"GraphicDesign", "\[Rule]", "Sketch"}], "}"}]}], "]"}], 
         ",", "0.07`"}], "]"}], ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"PinHole", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}], ",", "0.75`", ",", 
           RowBox[{"{", 
            RowBox[{"SurfaceRendering", "\[Rule]", "Fill"}], "}"}]}], "]"}], 
         ",", "0.3`"}], "]"}], ",", 
       RowBox[{"PlanoConvexLens", "[", 
        RowBox[{"2", ",", "0.75`", ",", "0.3`", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"SurfaceRendering", "\[Rule]", "Empty"}], ",", 
           RowBox[{"EdgeRendering", "\[Rule]", "Empty"}], ",", 
           RowBox[{"CrossRendering", "\[Rule]", "Trace"}]}], "}"}]}], "]"}]}],
       "}"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5634046673295183`*^9, 3.5661011583817167`*^9, 
  3.614727719550465*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"Out[254]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ByteCount[ShowSystem[lenslet,OutputType->StandardGraphics]]", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[255]:="],

Cell[BoxData["49552"], "Output",
 CellChangeTimes->{3.56340466737845*^9, 3.566101158481587*^9, 
  3.614727719592971*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"Out[255]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[lenslet, PlotType->FrontView, CreateClones -> positions, \
ShowLabels->False];\
\>", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[256]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, -5.}, {-5.479166666666667, -5.}, {-5.458333333333333, \
-5.}, {-5.4375, -5.}, {-5.416666666666667, -5.}, {-5.395833333333333, -5.}, \
{-5.375, -5.}, {-5.375, -5.}, {-5.395833333333333, -5.}, {-5.416666666666667, \
-5.}, {-5.4375, -5.}, {-5.458333333333333, -5.}, {-5.479166666666667, -5.}, \
{-5.5, -5.}, {-5.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, -5.}, {-4.604166666666667, -5.}, {-4.583333333333333, \
-5.}, {-4.5625, -5.}, {-4.541666666666667, -5.}, {-4.520833333333333, -5.}, \
{-4.5, -5.}, {-4.5, -5.}, {-4.520833333333333, -5.}, {-4.541666666666667, \
-5.}, {-4.5625, -5.}, {-4.583333333333333, -5.}, {-4.604166666666667, -5.}, \
{-4.625, -5.}, {-4.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -5.5}, {-5., -5.479166666666667}, {-5., \
-5.458333333333333}, {-5., -5.4375}, {-5., -5.416666666666667}, {-5., \
-5.395833333333333}, {-5., -5.375}, {-5., -5.375}, {-5., -5.395833333333333}, \
{-5., -5.416666666666667}, {-5., -5.4375}, {-5., -5.458333333333333}, {-5., \
-5.479166666666667}, {-5., -5.5}, {-5., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -4.625}, {-5., -4.604166666666667}, {-5., \
-4.583333333333333}, {-5., -4.5625}, {-5., -4.541666666666667}, {-5., \
-4.520833333333333}, {-5., -4.5}, {-5., -4.5}, {-5., -4.520833333333333}, \
{-5., -4.541666666666667}, {-5., -4.5625}, {-5., -4.583333333333333}, {-5., \
-4.604166666666667}, {-5., -4.625}, {-5., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, -5.}, {-5.25, -5.}, {-5.125, -5.}, {-5., -5.}, \
{-4.875, -5.}, {-4.75, -5.}, {-4.625, -5.}, {-4.625, -5.}, {-4.75, -5.}, \
{-4.875, -5.}, {-5., -5.}, {-5.125, -5.}, {-5.25, -5.}, {-5.375, -5.}, \
{-5.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -5.375}, {-5., -5.25}, {-5., -5.125}, {-5., -5.}, {-5., \
-4.875}, {-5., -4.75}, {-5., -4.625}, {-5., -4.625}, {-5., -4.75}, {-5., \
-4.875}, {-5., -5.}, {-5., -5.125}, {-5., -5.25}, {-5., -5.375}, {-5., \
-5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgDJED3NNXLBDtFTpws7eMd+4c4QMZd6Rt
izZD5R2EDxhxGk2u+CAEp2HiMHUwfTBzYObC7FEv6vyUlCyCKn9ABK7/3Lez
Oe38onDzZyg/OdTrIwq352tGePyrItEDN6D2QMwVhdsDk4fZg6IfaA/M/LNQ
GiYOU6cB1QczB9X9onD/ocgD3QXTD3M3zB6U8DuA8DfMHvTwBwD9OJFH
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCB2D06lUggOCHgoHwAVR1ImjqRdDUi6KpFyPI
R7VXDM1emHoRNPUiaOpF0dRj0ujq0M1BtwfdHejuJNaf6OGCHm6o9mKGO3q8
wGgAayNf+g==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, -5.265165042944956}, \
{-4.6752404735808355`, -5.1875}, {-4.595057255667003, -5.404942744332997}, \
{-4.734834957055044, -5.265165042944956}}], 
      PolygonBox[{{-4.562655006646477, -5.230251642536255}, \
{-4.595057255667003, -5.404942744332997}, {-4.6752404735808355`, -5.1875}, \
{-4.562655006646477, -5.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, -5.1875}, {-4.637777815141599, \
-5.097057141913445}, {-4.562655006646477, -5.230251642536255}, \
{-4.6752404735808355`, -5.1875}}], 
      PolygonBox[{{-4.562500018967059, -5.084292589556062}, \
{-4.562655006646477, -5.230251642536255}, {-4.637777815141599, \
-5.097057141913445}, {-4.562500018967059, -5.084292589556062}}], 
      PolygonBox[{{-4.637777815141599, -5.097057141913445}, {-4.625, -5.}, \
{-4.562500018967059, -5.084292589556062}, {-4.637777815141599, \
-5.097057141913445}}], 
      PolygonBox[{{-4.5625, -5.}, {-4.562500018967059, -5.084292589556062}, \
{-4.625, -5.}, {-4.5625, -5.}}], 
      PolygonBox[{{-4.625, -5.}, {-4.637777815141599, -4.902942858086555}, \
{-4.5625, -5.}, {-4.625, -5.}}], 
      PolygonBox[{{-4.562500018967059, -4.915707410443939}, {-4.5625, -5.}, \
{-4.637777815141599, -4.902942858086555}, {-4.562500018967059, \
-4.915707410443939}}], 
      PolygonBox[{{-4.637777815141599, -4.902942858086555}, \
{-4.6752404735808355`, -4.8125}, {-4.562500018967059, -4.915707410443939}, \
{-4.637777815141599, -4.902942858086555}}], 
      PolygonBox[{{-4.562655006646477, -4.769748357463745}, \
{-4.562500018967059, -4.915707410443939}, {-4.6752404735808355`, -4.8125}, \
{-4.562655006646477, -4.769748357463745}}], 
      PolygonBox[{{-4.6752404735808355`, -4.8125}, {-4.734834957055044, \
-4.734834957055044}, {-4.562655006646477, -4.769748357463745}, \
{-4.6752404735808355`, -4.8125}}], 
      PolygonBox[{{-4.595057255667003, -4.595057255667003}, \
{-4.562655006646477, -4.769748357463745}, {-4.734834957055044, \
-4.734834957055044}, {-4.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{-4.734834957055044, -4.734834957055044}, {-4.8125, \
-4.6752404735808355`}, {-4.595057255667003, -4.595057255667003}, \
{-4.734834957055044, -4.734834957055044}}], 
      PolygonBox[{{-4.769748357463745, -4.562655006646477}, \
{-4.595057255667003, -4.595057255667003}, {-4.8125, -4.6752404735808355`}, \
{-4.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{-4.8125, -4.6752404735808355`}, {-4.902942858086555, \
-4.637777815141599}, {-4.769748357463745, -4.562655006646477}, {-4.8125, \
-4.6752404735808355`}}], 
      PolygonBox[{{-4.9157074104439396`, -4.562500018967059}, \
{-4.769748357463745, -4.562655006646477}, {-4.902942858086555, \
-4.637777815141599}, {-4.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-4.902942858086555, -4.637777815141599}, {-5., -4.625}, \
{-4.9157074104439396`, -4.562500018967059}, {-4.902942858086555, \
-4.637777815141599}}], 
      PolygonBox[{{-4.999894472779513, -4.5625}, {-4.9157074104439396`, \
-4.562500018967059}, {-5., -4.625}, {-4.999894472779513, -4.5625}}], 
      PolygonBox[{{-5., -4.625}, {-5.097057141913445, -4.637777815141599}, \
{-4.999894472779513, -4.5625}, {-5., -4.625}}], 
      PolygonBox[{{-5.084292589556057, -4.562500018967059}, \
{-4.999894472779513, -4.5625}, {-5.097057141913445, -4.637777815141599}, \
{-5.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-5.097057141913445, -4.637777815141599}, {-5.1875, \
-4.6752404735808355`}, {-5.084292589556057, -4.562500018967059}, \
{-5.097057141913445, -4.637777815141599}}], 
      PolygonBox[{{-5.230251642536255, -4.562655006646477}, \
{-5.084292589556057, -4.562500018967059}, {-5.1875, -4.6752404735808355`}, \
{-5.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-5.1875, -4.6752404735808355`}, {-5.265165042944956, \
-4.734834957055044}, {-5.230251642536255, -4.562655006646477}, {-5.1875, \
-4.6752404735808355`}}], 
      PolygonBox[{{-5.404942744332997, -4.595057255667003}, \
{-5.230251642536255, -4.562655006646477}, {-5.265165042944956, \
-4.734834957055044}, {-5.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{-5.265165042944956, -4.734834957055044}, \
{-5.3247595264191645`, -4.8125}, {-5.404942744332997, -4.595057255667003}, \
{-5.265165042944956, -4.734834957055044}}], 
      PolygonBox[{{-5.437344993353523, -4.769748357463745}, \
{-5.404942744332997, -4.595057255667003}, {-5.3247595264191645`, -4.8125}, \
{-5.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{-5.3247595264191645`, -4.8125}, {-5.362222184858401, \
-4.902942858086554}, {-5.437344993353523, -4.769748357463745}, \
{-5.3247595264191645`, -4.8125}}], 
      PolygonBox[{{-5.437499981032941, -4.915707410443938}, \
{-5.437344993353523, -4.769748357463745}, {-5.362222184858401, \
-4.902942858086554}, {-5.437499981032941, -4.915707410443938}}], 
      PolygonBox[{{-5.362222184858401, -4.902942858086554}, {-5.375, -5.}, \
{-5.437499981032941, -4.915707410443938}, {-5.362222184858401, \
-4.902942858086554}}], 
      PolygonBox[{{-5.4375, -4.999876821937004}, {-5.437499981032941, \
-4.915707410443938}, {-5.375, -5.}, {-5.4375, -4.999876821937004}}], 
      PolygonBox[{{-5.375, -5.}, {-5.362222184858401, -5.097057141913445}, \
{-5.4375, -4.999876821937004}, {-5.375, -5.}}], 
      PolygonBox[{{-5.437499981032941, -5.084292589556055}, {-5.4375, \
-4.999876821937004}, {-5.362222184858401, -5.097057141913445}, \
{-5.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-5.362222184858401, -5.097057141913445}, \
{-5.3247595264191645`, -5.1875}, {-5.437499981032941, -5.084292589556055}, \
{-5.362222184858401, -5.097057141913445}}], 
      PolygonBox[{{-5.437344993353523, -5.230251642536254}, \
{-5.437499981032941, -5.084292589556055}, {-5.3247595264191645`, -5.1875}, \
{-5.437344993353523, -5.230251642536254}}], 
      PolygonBox[{{-5.3247595264191645`, -5.1875}, {-5.265165042944956, \
-5.265165042944956}, {-5.437344993353523, -5.230251642536254}, \
{-5.3247595264191645`, -5.1875}}], 
      PolygonBox[{{-5.404942744332997, -5.404942744332997}, \
{-5.437344993353523, -5.230251642536254}, {-5.265165042944956, \
-5.265165042944956}, {-5.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, -5.265165042944956}, {-5.1875, \
-5.3247595264191645`}, {-5.404942744332997, -5.404942744332997}, \
{-5.265165042944956, -5.265165042944956}}], 
      PolygonBox[{{-5.230251642536255, -5.437344993353523}, \
{-5.404942744332997, -5.404942744332997}, {-5.1875, -5.3247595264191645`}, \
{-5.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{-5.1875, -5.3247595264191645`}, {-5.097057141913446, \
-5.362222184858401}, {-5.230251642536255, -5.437344993353523}, {-5.1875, \
-5.3247595264191645`}}], 
      PolygonBox[{{-5.084292589556064, -5.437499981032941}, \
{-5.230251642536255, -5.437344993353523}, {-5.097057141913446, \
-5.362222184858401}, {-5.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-5.097057141913446, -5.362222184858401}, {-5., -5.375}, \
{-5.084292589556064, -5.437499981032941}, {-5.097057141913446, \
-5.362222184858401}}], 
      PolygonBox[{{-4.999865158168957, -5.4375}, {-5.084292589556064, \
-5.437499981032941}, {-5., -5.375}, {-4.999865158168957, -5.4375}}], 
      PolygonBox[{{-5., -5.375}, {-4.902942858086555, -5.362222184858401}, \
{-4.999865158168957, -5.4375}, {-5., -5.375}}], 
      PolygonBox[{{-4.915707410443947, -5.437499981032941}, \
{-4.999865158168957, -5.4375}, {-4.902942858086555, -5.362222184858401}, \
{-4.915707410443947, -5.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, -5.362222184858401}, {-4.8125, \
-5.3247595264191645`}, {-4.915707410443947, -5.437499981032941}, \
{-4.902942858086555, -5.362222184858401}}], 
      PolygonBox[{{-4.769748357463746, -5.437344993353523}, \
{-4.915707410443947, -5.437499981032941}, {-4.8125, -5.3247595264191645`}, \
{-4.769748357463746, -5.437344993353523}}], 
      PolygonBox[{{-4.8125, -5.3247595264191645`}, {-4.734834957055044, \
-5.265165042944956}, {-4.769748357463746, -5.437344993353523}, {-4.8125, \
-5.3247595264191645`}}], 
      PolygonBox[{{-4.595057255667003, -5.404942744332997}, \
{-4.769748357463746, -5.437344993353523}, {-4.734834957055044, \
-5.265165042944956}, {-4.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, -5.265165042944956}, \
{-4.734834957055044, -5.265165042944956}, {-4.595057255667003, \
-5.404942744332997}, {-4.734834957055044, -5.265165042944956}}], 
      PolygonBox[{{-4.595057255667003, -5.404942744332997}, \
{-4.595057255667003, -5.404942744332997}, {-4.734834957055044, \
-5.265165042944956}, {-4.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-4.595057255667003, -5.404942744332997}, \
{-4.562655006646477, -5.230251642536255}, {-4.5, -5.5}, {-4.595057255667003, \
-5.404942744332997}}], 
      PolygonBox[{{-4.5, -5.357662782649368}, {-4.5, -5.5}, \
{-4.562655006646477, -5.230251642536255}, {-4.5, -5.357662782649368}}], 
      PolygonBox[{{-4.562655006646477, -5.230251642536255}, \
{-4.562500018967059, -5.084292589556062}, {-4.5, -5.357662782649368}, \
{-4.562655006646477, -5.230251642536255}}], 
      PolygonBox[{{-4.5, -5.20590900530174}, {-4.5, -5.357662782649368}, \
{-4.562500018967059, -5.084292589556062}, {-4.5, -5.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, -5.084292589556062}, {-4.5625, -5.}, \
{-4.5, -5.20590900530174}, {-4.562500018967059, -5.084292589556062}}], 
      PolygonBox[{{-4.5, -5.}, {-4.5, -5.20590900530174}, {-4.5625, -5.}, \
{-4.5, -5.}}], 
      PolygonBox[{{-4.5625, -5.}, {-4.562500018967059, -4.915707410443939}, \
{-4.5, -5.}, {-4.5625, -5.}}], 
      PolygonBox[{{-4.5, -4.79409099469826}, {-4.5, -5.}, \
{-4.562500018967059, -4.915707410443939}, {-4.5, -4.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, -4.915707410443939}, \
{-4.562655006646477, -4.769748357463745}, {-4.5, -4.79409099469826}, \
{-4.562500018967059, -4.915707410443939}}], 
      PolygonBox[{{-4.5, -4.642337217350632}, {-4.5, -4.79409099469826}, \
{-4.562655006646477, -4.769748357463745}, {-4.5, -4.642337217350632}}], 
      PolygonBox[{{-4.562655006646477, -4.769748357463745}, \
{-4.595057255667003, -4.595057255667003}, {-4.5, -4.642337217350632}, \
{-4.562655006646477, -4.769748357463745}}], 
      PolygonBox[{{-4.508553435038814, -4.508553435038814}, {-4.5, \
-4.642337217350632}, {-4.595057255667003, -4.595057255667003}, \
{-4.508553435038814, -4.508553435038814}}], 
      PolygonBox[{{-4.595057255667003, -4.595057255667003}, \
{-4.769748357463745, -4.562655006646477}, {-4.508553435038814, \
-4.508553435038814}, {-4.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{-4.642337217350632, -4.5}, {-4.508553435038814, \
-4.508553435038814}, {-4.769748357463745, -4.562655006646477}, \
{-4.642337217350632, -4.5}}], 
      PolygonBox[{{-4.769748357463745, -4.562655006646477}, \
{-4.9157074104439396`, -4.562500018967059}, {-4.642337217350632, -4.5}, \
{-4.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{-4.794090994626744, -4.5}, {-4.642337217350632, -4.5}, \
{-4.9157074104439396`, -4.562500018967059}, {-4.794090994626744, -4.5}}], 
      PolygonBox[{{-4.9157074104439396`, -4.562500018967059}, \
{-4.999894472779513, -4.5625}, {-4.794090994626744, -4.5}, \
{-4.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-4.92205804197311, -4.5}, {-4.794090994626744, -4.5}, \
{-4.999894472779513, -4.5625}, {-4.92205804197311, -4.5}}], 
      PolygonBox[{{-4.999894472779513, -4.5625}, {-5.084292589556057, \
-4.562500018967059}, {-4.92205804197311, -4.5}, {-4.999894472779513, \
-4.5625}}], 
      PolygonBox[{{-5.205909005304446, -4.5}, {-4.92205804197311, -4.5}, \
{-5.084292589556057, -4.562500018967059}, {-5.205909005304446, -4.5}}], 
      PolygonBox[{{-5.084292589556057, -4.562500018967059}, \
{-5.230251642536255, -4.562655006646477}, {-5.205909005304446, -4.5}, \
{-5.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-5.357662782649366, -4.5}, {-5.205909005304446, -4.5}, \
{-5.230251642536255, -4.562655006646477}, {-5.357662782649366, -4.5}}], 
      PolygonBox[{{-5.230251642536255, -4.562655006646477}, \
{-5.404942744332997, -4.595057255667003}, {-5.357662782649366, -4.5}, \
{-5.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-4.5, -4.5}, {-5.357662782649366, -4.5}, \
{-5.404942744332997, -4.595057255667003}, {-4.5, -4.5}}], 
      PolygonBox[{{-5.404942744332997, -4.595057255667003}, \
{-5.437344993353523, -4.769748357463745}, {-4.5, -4.5}, {-5.404942744332997, \
-4.595057255667003}}], 
      PolygonBox[{{-5.5, -4.642337217350631}, {-4.5, -4.5}, \
{-5.437344993353523, -4.769748357463745}, {-5.5, -4.642337217350631}}], 
      PolygonBox[{{-5.437344993353523, -4.769748357463745}, \
{-5.437499981032941, -4.915707410443938}, {-5.5, -4.642337217350631}, \
{-5.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{-5.5, -4.794090994717101}, {-5.5, -4.642337217350631}, \
{-5.437499981032941, -4.915707410443938}, {-5.5, -4.794090994717101}}], 
      PolygonBox[{{-5.437499981032941, -4.915707410443938}, {-5.4375, \
-4.999876821937004}, {-5.5, -4.794090994717101}, {-5.437499981032941, \
-4.915707410443938}}], 
      PolygonBox[{{-5.5, -4.9193213332412995`}, {-5.5, -4.794090994717101}, \
{-5.4375, -4.999876821937004}, {-5.5, -4.9193213332412995`}}], 
      PolygonBox[{{-5.4375, -4.999876821937004}, {-5.437499981032941, \
-5.084292589556055}, {-5.5, -4.9193213332412995`}, {-5.4375, \
-4.999876821937004}}], 
      PolygonBox[{{-5.5, -5.205909005145278}, {-5.5, -4.9193213332412995`}, \
{-5.437499981032941, -5.084292589556055}, {-5.5, -5.205909005145278}}], 
      PolygonBox[{{-5.437499981032941, -5.084292589556055}, \
{-5.437344993353523, -5.230251642536254}, {-5.5, -5.205909005145278}, \
{-5.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-5.5, -5.357662782649365}, {-5.5, -5.205909005145278}, \
{-5.437344993353523, -5.230251642536254}, {-5.5, -5.357662782649365}}], 
      PolygonBox[{{-5.437344993353523, -5.230251642536254}, \
{-5.404942744332997, -5.404942744332997}, {-5.5, -5.357662782649365}, \
{-5.437344993353523, -5.230251642536254}}], 
      PolygonBox[{{-5.5, -4.5}, {-5.5, -5.357662782649365}, \
{-5.404942744332997, -5.404942744332997}, {-5.5, -4.5}}], 
      PolygonBox[{{-5.404942744332997, -5.404942744332997}, \
{-5.230251642536255, -5.437344993353523}, {-5.5, -4.5}, {-5.404942744332997, \
-5.404942744332997}}], 
      PolygonBox[{{-5.5, -5.5}, {-5.5, -4.5}, {-5.230251642536255, \
-5.437344993353523}, {-5.5, -5.5}}], 
      PolygonBox[{{-5.230251642536255, -5.437344993353523}, \
{-5.084292589556064, -5.437499981032941}, {-5.5, -5.5}, {-5.230251642536255, \
-5.437344993353523}}], 
      PolygonBox[{{-5.205909005566828, -5.5}, {-5.5, -5.5}, \
{-5.084292589556064, -5.437499981032941}, {-5.205909005566828, -5.5}}], 
      PolygonBox[{{-5.084292589556064, -5.437499981032941}, \
{-4.999865158168957, -5.4375}, {-5.205909005566828, -5.5}, \
{-5.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-4.917676129598938, -5.5}, {-5.205909005566828, -5.5}, \
{-4.999865158168957, -5.4375}, {-4.917676129598938, -5.5}}], 
      PolygonBox[{{-4.999865158168957, -5.4375}, {-4.915707410443947, \
-5.437499981032941}, {-4.917676129598938, -5.5}, {-4.999865158168957, \
-5.4375}}], 
      PolygonBox[{{-4.794090994639602, -5.5}, {-4.917676129598938, -5.5}, \
{-4.915707410443947, -5.437499981032941}, {-4.794090994639602, -5.5}}], 
      PolygonBox[{{-4.915707410443947, -5.437499981032941}, \
{-4.769748357463746, -5.437344993353523}, {-4.794090994639602, -5.5}, \
{-4.915707410443947, -5.437499981032941}}], 
      PolygonBox[{{-4.6423372173506285`, -5.5}, {-4.794090994639602, -5.5}, \
{-4.769748357463746, -5.437344993353523}, {-4.6423372173506285`, -5.5}}], 
      PolygonBox[{{-4.769748357463746, -5.437344993353523}, \
{-4.595057255667003, -5.404942744332997}, {-4.6423372173506285`, -5.5}, \
{-4.769748357463746, -5.437344993353523}}], 
      PolygonBox[{{-4.5, -5.5}, {-4.6423372173506285`, -5.5}, \
{-4.595057255667003, -5.404942744332997}, {-4.5, -5.5}}], 
      PolygonBox[{{-4.595057255667003, -5.404942744332997}, \
{-4.595057255667003, -5.404942744332997}, {-4.5, -5.5}, {-4.595057255667003, \
-5.404942744332997}}], 
      PolygonBox[{{-4.5, -5.5}, {-4.5, -5.5}, {-4.595057255667003, \
-5.404942744332997}, {-4.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, -4.}, {-5.479166666666667, -4.}, {-5.458333333333333, \
-4.}, {-5.4375, -4.}, {-5.416666666666667, -4.}, {-5.395833333333333, -4.}, \
{-5.375, -4.}, {-5.375, -4.}, {-5.395833333333333, -4.}, {-5.416666666666667, \
-4.}, {-5.4375, -4.}, {-5.458333333333333, -4.}, {-5.479166666666667, -4.}, \
{-5.5, -4.}, {-5.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, -4.}, {-4.604166666666667, -4.}, {-4.583333333333333, \
-4.}, {-4.5625, -4.}, {-4.541666666666667, -4.}, {-4.520833333333333, -4.}, \
{-4.5, -4.}, {-4.5, -4.}, {-4.520833333333333, -4.}, {-4.541666666666667, \
-4.}, {-4.5625, -4.}, {-4.583333333333333, -4.}, {-4.604166666666667, -4.}, \
{-4.625, -4.}, {-4.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -4.5}, {-5., -4.479166666666667}, {-5., \
-4.458333333333333}, {-5., -4.4375}, {-5., -4.416666666666667}, {-5., \
-4.395833333333333}, {-5., -4.375}, {-5., -4.375}, {-5., -4.395833333333333}, \
{-5., -4.416666666666667}, {-5., -4.4375}, {-5., -4.458333333333333}, {-5., \
-4.479166666666667}, {-5., -4.5}, {-5., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -3.625}, {-5., -3.6041666666666665`}, {-5., \
-3.5833333333333335`}, {-5., -3.5625}, {-5., -3.5416666666666665`}, {-5., \
-3.5208333333333335`}, {-5., -3.5}, {-5., -3.5}, {-5., -3.5208333333333335`}, \
{-5., -3.5416666666666665`}, {-5., -3.5625}, {-5., -3.5833333333333335`}, \
{-5., -3.6041666666666665`}, {-5., -3.625}, {-5., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, -4.}, {-5.25, -4.}, {-5.125, -4.}, {-5., -4.}, \
{-4.875, -4.}, {-4.75, -4.}, {-4.625, -4.}, {-4.625, -4.}, {-4.75, -4.}, \
{-4.875, -4.}, {-5., -4.}, {-5.125, -4.}, {-5.25, -4.}, {-5.375, -4.}, \
{-5.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -4.375}, {-5., -4.25}, {-5., -4.125}, {-5., -4.}, {-5., \
-3.875}, {-5., -3.75}, {-5., -3.625}, {-5., -3.625}, {-5., -3.75}, {-5., \
-3.875}, {-5., -4.}, {-5., -4.125}, {-5., -4.25}, {-5., -4.375}, {-5., \
-4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgDIED3NNXLBDtFTqwUfqtlJUl/4GMO9K2
RZuh8g18B4w4jSZXfBA6kCqUovbxAS9E3EH4wIUd5lVP0ngP3Owt4507R/iA
mF6go7YUVJ5BBErzHlAv6vyUlCyCKn9ABK7/3LezOe38onDzZyg/OdTrIwq3
/2tGePyrIlG4+yDionD3w+Qh9gig6j8gADf/LJgWhNsPUSd4QAPqPog5gqju
bxCE+w9FHuh/mH5Y+JyDmo8SfgcQ4asBdR96+AMAFfaOmQ==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByA0z4HVq0AAwQ8FA2E4H0KLoKkXQVMviqZe
jCAfoo8XzoeYy4emXgBNXgBNvyCaeiEMPqr7hNDcD1MvgqZeGE29EJp6wjSq
+4TQ3A9TJ4Amzwfnh6GEDyJ+APGgX3U=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, -4.265165042944956}, \
{-4.6752404735808355`, -4.1875}, {-4.595057255667003, -4.404942744332997}, \
{-4.734834957055044, -4.265165042944956}}], 
      PolygonBox[{{-4.562655006646477, -4.230251642536255}, \
{-4.595057255667003, -4.404942744332997}, {-4.6752404735808355`, -4.1875}, \
{-4.562655006646477, -4.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, -4.1875}, {-4.637777815141599, \
-4.097057141913445}, {-4.562655006646477, -4.230251642536255}, \
{-4.6752404735808355`, -4.1875}}], 
      PolygonBox[{{-4.562500018967059, -4.084292589556062}, \
{-4.562655006646477, -4.230251642536255}, {-4.637777815141599, \
-4.097057141913445}, {-4.562500018967059, -4.084292589556062}}], 
      PolygonBox[{{-4.637777815141599, -4.097057141913445}, {-4.625, -4.}, \
{-4.562500018967059, -4.084292589556062}, {-4.637777815141599, \
-4.097057141913445}}], 
      PolygonBox[{{-4.5625, -4.}, {-4.562500018967059, -4.084292589556062}, \
{-4.625, -4.}, {-4.5625, -4.}}], 
      PolygonBox[{{-4.625, -4.}, {-4.637777815141599, -3.9029428580865546`}, \
{-4.5625, -4.}, {-4.625, -4.}}], 
      PolygonBox[{{-4.562500018967059, -3.915707410443938}, {-4.5625, -4.}, \
{-4.637777815141599, -3.9029428580865546`}, {-4.562500018967059, \
-3.915707410443938}}], 
      PolygonBox[{{-4.637777815141599, -3.9029428580865546`}, \
{-4.6752404735808355`, -3.8125}, {-4.562500018967059, -3.915707410443938}, \
{-4.637777815141599, -3.9029428580865546`}}], 
      PolygonBox[{{-4.562655006646477, -3.769748357463745}, \
{-4.562500018967059, -3.915707410443938}, {-4.6752404735808355`, -3.8125}, \
{-4.562655006646477, -3.769748357463745}}], 
      PolygonBox[{{-4.6752404735808355`, -3.8125}, {-4.734834957055044, \
-3.7348349570550448`}, {-4.562655006646477, -3.769748357463745}, \
{-4.6752404735808355`, -3.8125}}], 
      PolygonBox[{{-4.595057255667003, -3.595057255667003}, \
{-4.562655006646477, -3.769748357463745}, {-4.734834957055044, \
-3.7348349570550448`}, {-4.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{-4.734834957055044, -3.7348349570550448`}, {-4.8125, \
-3.6752404735808355`}, {-4.595057255667003, -3.595057255667003}, \
{-4.734834957055044, -3.7348349570550448`}}], 
      PolygonBox[{{-4.769748357463745, -3.5626550066464766`}, \
{-4.595057255667003, -3.595057255667003}, {-4.8125, -3.6752404735808355`}, \
{-4.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{-4.8125, -3.6752404735808355`}, {-4.902942858086555, \
-3.6377778151415994`}, {-4.769748357463745, -3.5626550066464766`}, {-4.8125, \
-3.6752404735808355`}}], 
      PolygonBox[{{-4.9157074104439396`, -3.562500018967059}, \
{-4.769748357463745, -3.5626550066464766`}, {-4.902942858086555, \
-3.6377778151415994`}, {-4.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-4.902942858086555, -3.6377778151415994`}, {-5., -3.625}, \
{-4.9157074104439396`, -3.562500018967059}, {-4.902942858086555, \
-3.6377778151415994`}}], 
      PolygonBox[{{-4.999894472779513, -3.5625}, {-4.9157074104439396`, \
-3.562500018967059}, {-5., -3.625}, {-4.999894472779513, -3.5625}}], 
      PolygonBox[{{-5., -3.625}, {-5.097057141913445, -3.6377778151415994`}, \
{-4.999894472779513, -3.5625}, {-5., -3.625}}], 
      PolygonBox[{{-5.084292589556057, -3.562500018967059}, \
{-4.999894472779513, -3.5625}, {-5.097057141913445, -3.6377778151415994`}, \
{-5.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-5.097057141913445, -3.6377778151415994`}, {-5.1875, \
-3.6752404735808355`}, {-5.084292589556057, -3.562500018967059}, \
{-5.097057141913445, -3.6377778151415994`}}], 
      PolygonBox[{{-5.230251642536255, -3.5626550066464766`}, \
{-5.084292589556057, -3.562500018967059}, {-5.1875, -3.6752404735808355`}, \
{-5.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-5.1875, -3.6752404735808355`}, {-5.265165042944956, \
-3.7348349570550448`}, {-5.230251642536255, -3.5626550066464766`}, {-5.1875, \
-3.6752404735808355`}}], 
      PolygonBox[{{-5.404942744332997, -3.595057255667003}, \
{-5.230251642536255, -3.5626550066464766`}, {-5.265165042944956, \
-3.7348349570550448`}, {-5.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-5.265165042944956, -3.7348349570550448`}, \
{-5.3247595264191645`, -3.8125}, {-5.404942744332997, -3.595057255667003}, \
{-5.265165042944956, -3.7348349570550448`}}], 
      PolygonBox[{{-5.437344993353523, -3.7697483574637447`}, \
{-5.404942744332997, -3.595057255667003}, {-5.3247595264191645`, -3.8125}, \
{-5.437344993353523, -3.7697483574637447`}}], 
      PolygonBox[{{-5.3247595264191645`, -3.8125}, {-5.362222184858401, \
-3.9029428580865546`}, {-5.437344993353523, -3.7697483574637447`}, \
{-5.3247595264191645`, -3.8125}}], 
      PolygonBox[{{-5.437499981032941, -3.9157074104439378`}, \
{-5.437344993353523, -3.7697483574637447`}, {-5.362222184858401, \
-3.9029428580865546`}, {-5.437499981032941, -3.9157074104439378`}}], 
      PolygonBox[{{-5.362222184858401, -3.9029428580865546`}, {-5.375, -4.}, \
{-5.437499981032941, -3.9157074104439378`}, {-5.362222184858401, \
-3.9029428580865546`}}], 
      PolygonBox[{{-5.4375, -3.9998768219370047`}, {-5.437499981032941, \
-3.9157074104439378`}, {-5.375, -4.}, {-5.4375, -3.9998768219370047`}}], 
      PolygonBox[{{-5.375, -4.}, {-5.362222184858401, -4.097057141913445}, \
{-5.4375, -3.9998768219370047`}, {-5.375, -4.}}], 
      PolygonBox[{{-5.437499981032941, -4.084292589556055}, {-5.4375, \
-3.9998768219370047`}, {-5.362222184858401, -4.097057141913445}, \
{-5.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-5.362222184858401, -4.097057141913445}, \
{-5.3247595264191645`, -4.1875}, {-5.437499981032941, -4.084292589556055}, \
{-5.362222184858401, -4.097057141913445}}], 
      PolygonBox[{{-5.437344993353523, -4.230251642536254}, \
{-5.437499981032941, -4.084292589556055}, {-5.3247595264191645`, -4.1875}, \
{-5.437344993353523, -4.230251642536254}}], 
      PolygonBox[{{-5.3247595264191645`, -4.1875}, {-5.265165042944956, \
-4.265165042944956}, {-5.437344993353523, -4.230251642536254}, \
{-5.3247595264191645`, -4.1875}}], 
      PolygonBox[{{-5.404942744332997, -4.404942744332997}, \
{-5.437344993353523, -4.230251642536254}, {-5.265165042944956, \
-4.265165042944956}, {-5.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, -4.265165042944956}, {-5.1875, \
-4.3247595264191645`}, {-5.404942744332997, -4.404942744332997}, \
{-5.265165042944956, -4.265165042944956}}], 
      PolygonBox[{{-5.230251642536255, -4.437344993353523}, \
{-5.404942744332997, -4.404942744332997}, {-5.1875, -4.3247595264191645`}, \
{-5.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{-5.1875, -4.3247595264191645`}, {-5.097057141913446, \
-4.362222184858401}, {-5.230251642536255, -4.437344993353523}, {-5.1875, \
-4.3247595264191645`}}], 
      PolygonBox[{{-5.084292589556064, -4.437499981032941}, \
{-5.230251642536255, -4.437344993353523}, {-5.097057141913446, \
-4.362222184858401}, {-5.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-5.097057141913446, -4.362222184858401}, {-5., -4.375}, \
{-5.084292589556064, -4.437499981032941}, {-5.097057141913446, \
-4.362222184858401}}], 
      PolygonBox[{{-4.999865158168957, -4.4375}, {-5.084292589556064, \
-4.437499981032941}, {-5., -4.375}, {-4.999865158168957, -4.4375}}], 
      PolygonBox[{{-5., -4.375}, {-4.902942858086555, -4.362222184858401}, \
{-4.999865158168957, -4.4375}, {-5., -4.375}}], 
      PolygonBox[{{-4.915707410443947, -4.437499981032941}, \
{-4.999865158168957, -4.4375}, {-4.902942858086555, -4.362222184858401}, \
{-4.915707410443947, -4.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, -4.362222184858401}, {-4.8125, \
-4.3247595264191645`}, {-4.915707410443947, -4.437499981032941}, \
{-4.902942858086555, -4.362222184858401}}], 
      PolygonBox[{{-4.769748357463746, -4.437344993353523}, \
{-4.915707410443947, -4.437499981032941}, {-4.8125, -4.3247595264191645`}, \
{-4.769748357463746, -4.437344993353523}}], 
      PolygonBox[{{-4.8125, -4.3247595264191645`}, {-4.734834957055044, \
-4.265165042944956}, {-4.769748357463746, -4.437344993353523}, {-4.8125, \
-4.3247595264191645`}}], 
      PolygonBox[{{-4.595057255667003, -4.404942744332997}, \
{-4.769748357463746, -4.437344993353523}, {-4.734834957055044, \
-4.265165042944956}, {-4.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, -4.265165042944956}, \
{-4.734834957055044, -4.265165042944956}, {-4.595057255667003, \
-4.404942744332997}, {-4.734834957055044, -4.265165042944956}}], 
      PolygonBox[{{-4.595057255667003, -4.404942744332997}, \
{-4.595057255667003, -4.404942744332997}, {-4.734834957055044, \
-4.265165042944956}, {-4.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-4.595057255667003, -4.404942744332997}, \
{-4.562655006646477, -4.230251642536255}, {-4.5, -4.5}, {-4.595057255667003, \
-4.404942744332997}}], 
      PolygonBox[{{-4.5, -4.357662782649368}, {-4.5, -4.5}, \
{-4.562655006646477, -4.230251642536255}, {-4.5, -4.357662782649368}}], 
      PolygonBox[{{-4.562655006646477, -4.230251642536255}, \
{-4.562500018967059, -4.084292589556062}, {-4.5, -4.357662782649368}, \
{-4.562655006646477, -4.230251642536255}}], 
      PolygonBox[{{-4.5, -4.20590900530174}, {-4.5, -4.357662782649368}, \
{-4.562500018967059, -4.084292589556062}, {-4.5, -4.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, -4.084292589556062}, {-4.5625, -4.}, \
{-4.5, -4.20590900530174}, {-4.562500018967059, -4.084292589556062}}], 
      PolygonBox[{{-4.5, -4.}, {-4.5, -4.20590900530174}, {-4.5625, -4.}, \
{-4.5, -4.}}], 
      PolygonBox[{{-4.5625, -4.}, {-4.562500018967059, -3.915707410443938}, \
{-4.5, -4.}, {-4.5625, -4.}}], 
      PolygonBox[{{-4.5, -3.79409099469826}, {-4.5, -4.}, \
{-4.562500018967059, -3.915707410443938}, {-4.5, -3.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, -3.915707410443938}, \
{-4.562655006646477, -3.769748357463745}, {-4.5, -3.79409099469826}, \
{-4.562500018967059, -3.915707410443938}}], 
      PolygonBox[{{-4.5, -3.6423372173506325`}, {-4.5, -3.79409099469826}, \
{-4.562655006646477, -3.769748357463745}, {-4.5, -3.6423372173506325`}}], 
      PolygonBox[{{-4.562655006646477, -3.769748357463745}, \
{-4.595057255667003, -3.595057255667003}, {-4.5, -3.6423372173506325`}, \
{-4.562655006646477, -3.769748357463745}}], 
      PolygonBox[{{-4.508553435038814, -3.508553435038814}, {-4.5, \
-3.6423372173506325`}, {-4.595057255667003, -3.595057255667003}, \
{-4.508553435038814, -3.508553435038814}}], 
      PolygonBox[{{-4.595057255667003, -3.595057255667003}, \
{-4.769748357463745, -3.5626550066464766`}, {-4.508553435038814, \
-3.508553435038814}, {-4.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{-4.642337217350632, -3.5}, {-4.508553435038814, \
-3.508553435038814}, {-4.769748357463745, -3.5626550066464766`}, \
{-4.642337217350632, -3.5}}], 
      PolygonBox[{{-4.769748357463745, -3.5626550066464766`}, \
{-4.9157074104439396`, -3.562500018967059}, {-4.642337217350632, -3.5}, \
{-4.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{-4.794090994626744, -3.5}, {-4.642337217350632, -3.5}, \
{-4.9157074104439396`, -3.562500018967059}, {-4.794090994626744, -3.5}}], 
      PolygonBox[{{-4.9157074104439396`, -3.562500018967059}, \
{-4.999894472779513, -3.5625}, {-4.794090994626744, -3.5}, \
{-4.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-4.92205804197311, -3.5}, {-4.794090994626744, -3.5}, \
{-4.999894472779513, -3.5625}, {-4.92205804197311, -3.5}}], 
      PolygonBox[{{-4.999894472779513, -3.5625}, {-5.084292589556057, \
-3.562500018967059}, {-4.92205804197311, -3.5}, {-4.999894472779513, \
-3.5625}}], 
      PolygonBox[{{-5.205909005304446, -3.5}, {-4.92205804197311, -3.5}, \
{-5.084292589556057, -3.562500018967059}, {-5.205909005304446, -3.5}}], 
      PolygonBox[{{-5.084292589556057, -3.562500018967059}, \
{-5.230251642536255, -3.5626550066464766`}, {-5.205909005304446, -3.5}, \
{-5.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-5.357662782649366, -3.5}, {-5.205909005304446, -3.5}, \
{-5.230251642536255, -3.5626550066464766`}, {-5.357662782649366, -3.5}}], 
      PolygonBox[{{-5.230251642536255, -3.5626550066464766`}, \
{-5.404942744332997, -3.595057255667003}, {-5.357662782649366, -3.5}, \
{-5.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-4.5, -3.5}, {-5.357662782649366, -3.5}, \
{-5.404942744332997, -3.595057255667003}, {-4.5, -3.5}}], 
      PolygonBox[{{-5.404942744332997, -3.595057255667003}, \
{-5.437344993353523, -3.7697483574637447`}, {-4.5, -3.5}, \
{-5.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-5.5, -3.642337217350631}, {-4.5, -3.5}, \
{-5.437344993353523, -3.7697483574637447`}, {-5.5, -3.642337217350631}}], 
      PolygonBox[{{-5.437344993353523, -3.7697483574637447`}, \
{-5.437499981032941, -3.9157074104439378`}, {-5.5, -3.642337217350631}, \
{-5.437344993353523, -3.7697483574637447`}}], 
      PolygonBox[{{-5.5, -3.794090994717101}, {-5.5, -3.642337217350631}, \
{-5.437499981032941, -3.9157074104439378`}, {-5.5, -3.794090994717101}}], 
      PolygonBox[{{-5.437499981032941, -3.9157074104439378`}, {-5.4375, \
-3.9998768219370047`}, {-5.5, -3.794090994717101}, {-5.437499981032941, \
-3.9157074104439378`}}], 
      PolygonBox[{{-5.5, -3.9193213332413}, {-5.5, -3.794090994717101}, \
{-5.4375, -3.9998768219370047`}, {-5.5, -3.9193213332413}}], 
      PolygonBox[{{-5.4375, -3.9998768219370047`}, {-5.437499981032941, \
-4.084292589556055}, {-5.5, -3.9193213332413}, {-5.4375, \
-3.9998768219370047`}}], 
      PolygonBox[{{-5.5, -4.205909005145278}, {-5.5, -3.9193213332413}, \
{-5.437499981032941, -4.084292589556055}, {-5.5, -4.205909005145278}}], 
      PolygonBox[{{-5.437499981032941, -4.084292589556055}, \
{-5.437344993353523, -4.230251642536254}, {-5.5, -4.205909005145278}, \
{-5.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-5.5, -4.357662782649365}, {-5.5, -4.205909005145278}, \
{-5.437344993353523, -4.230251642536254}, {-5.5, -4.357662782649365}}], 
      PolygonBox[{{-5.437344993353523, -4.230251642536254}, \
{-5.404942744332997, -4.404942744332997}, {-5.5, -4.357662782649365}, \
{-5.437344993353523, -4.230251642536254}}], 
      PolygonBox[{{-5.5, -3.5}, {-5.5, -4.357662782649365}, \
{-5.404942744332997, -4.404942744332997}, {-5.5, -3.5}}], 
      PolygonBox[{{-5.404942744332997, -4.404942744332997}, \
{-5.230251642536255, -4.437344993353523}, {-5.5, -3.5}, {-5.404942744332997, \
-4.404942744332997}}], 
      PolygonBox[{{-5.5, -4.5}, {-5.5, -3.5}, {-5.230251642536255, \
-4.437344993353523}, {-5.5, -4.5}}], 
      PolygonBox[{{-5.230251642536255, -4.437344993353523}, \
{-5.084292589556064, -4.437499981032941}, {-5.5, -4.5}, {-5.230251642536255, \
-4.437344993353523}}], 
      PolygonBox[{{-5.205909005566828, -4.5}, {-5.5, -4.5}, \
{-5.084292589556064, -4.437499981032941}, {-5.205909005566828, -4.5}}], 
      PolygonBox[{{-5.084292589556064, -4.437499981032941}, \
{-4.999865158168957, -4.4375}, {-5.205909005566828, -4.5}, \
{-5.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-4.917676129598938, -4.5}, {-5.205909005566828, -4.5}, \
{-4.999865158168957, -4.4375}, {-4.917676129598938, -4.5}}], 
      PolygonBox[{{-4.999865158168957, -4.4375}, {-4.915707410443947, \
-4.437499981032941}, {-4.917676129598938, -4.5}, {-4.999865158168957, \
-4.4375}}], 
      PolygonBox[{{-4.794090994639602, -4.5}, {-4.917676129598938, -4.5}, \
{-4.915707410443947, -4.437499981032941}, {-4.794090994639602, -4.5}}], 
      PolygonBox[{{-4.915707410443947, -4.437499981032941}, \
{-4.769748357463746, -4.437344993353523}, {-4.794090994639602, -4.5}, \
{-4.915707410443947, -4.437499981032941}}], 
      PolygonBox[{{-4.6423372173506285`, -4.5}, {-4.794090994639602, -4.5}, \
{-4.769748357463746, -4.437344993353523}, {-4.6423372173506285`, -4.5}}], 
      PolygonBox[{{-4.769748357463746, -4.437344993353523}, \
{-4.595057255667003, -4.404942744332997}, {-4.6423372173506285`, -4.5}, \
{-4.769748357463746, -4.437344993353523}}], 
      PolygonBox[{{-4.5, -4.5}, {-4.6423372173506285`, -4.5}, \
{-4.595057255667003, -4.404942744332997}, {-4.5, -4.5}}], 
      PolygonBox[{{-4.595057255667003, -4.404942744332997}, \
{-4.595057255667003, -4.404942744332997}, {-4.5, -4.5}, {-4.595057255667003, \
-4.404942744332997}}], 
      PolygonBox[{{-4.5, -4.5}, {-4.5, -4.5}, {-4.595057255667003, \
-4.404942744332997}, {-4.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, -3.}, {-5.479166666666667, -3.}, {-5.458333333333333, \
-3.}, {-5.4375, -3.}, {-5.416666666666667, -3.}, {-5.395833333333333, -3.}, \
{-5.375, -3.}, {-5.375, -3.}, {-5.395833333333333, -3.}, {-5.416666666666667, \
-3.}, {-5.4375, -3.}, {-5.458333333333333, -3.}, {-5.479166666666667, -3.}, \
{-5.5, -3.}, {-5.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, -3.}, {-4.604166666666667, -3.}, {-4.583333333333333, \
-3.}, {-4.5625, -3.}, {-4.541666666666667, -3.}, {-4.520833333333333, -3.}, \
{-4.5, -3.}, {-4.5, -3.}, {-4.520833333333333, -3.}, {-4.541666666666667, \
-3.}, {-4.5625, -3.}, {-4.583333333333333, -3.}, {-4.604166666666667, -3.}, \
{-4.625, -3.}, {-4.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -3.5}, {-5., -3.4791666666666665`}, {-5., \
-3.4583333333333335`}, {-5., -3.4375}, {-5., -3.4166666666666665`}, {-5., \
-3.3958333333333335`}, {-5., -3.375}, {-5., -3.375}, {-5., \
-3.3958333333333335`}, {-5., -3.4166666666666665`}, {-5., -3.4375}, {-5., \
-3.4583333333333335`}, {-5., -3.4791666666666665`}, {-5., -3.5}, {-5., \
-3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -2.625}, {-5., -2.6041666666666665`}, {-5., \
-2.5833333333333335`}, {-5., -2.5625}, {-5., -2.5416666666666665`}, {-5., \
-2.5208333333333335`}, {-5., -2.5}, {-5., -2.5}, {-5., -2.5208333333333335`}, \
{-5., -2.5416666666666665`}, {-5., -2.5625}, {-5., -2.5833333333333335`}, \
{-5., -2.6041666666666665`}, {-5., -2.625}, {-5., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, -3.}, {-5.25, -3.}, {-5.125, -3.}, {-5., -3.}, \
{-4.875, -3.}, {-4.75, -3.}, {-4.625, -3.}, {-4.625, -3.}, {-4.75, -3.}, \
{-4.875, -3.}, {-5., -3.}, {-5.125, -3.}, {-5.25, -3.}, {-5.375, -3.}, \
{-5.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -3.375}, {-5., -3.25}, {-5., -3.125}, {-5., -3.}, {-5., \
-2.875}, {-5., -2.75}, {-5., -2.625}, {-5., -2.625}, {-5., -2.75}, {-5., \
-2.875}, {-5., -3.}, {-5., -3.125}, {-5., -3.25}, {-5., -3.375}, {-5., \
-3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgDI4D3NNXLBDtFTqwUfqtlJUl+4GMO9K2
RZuh8g1sB4w4jSZXfBA6kCqUovbxAStE3EH4wIUd5lVP0lgP3Owt4507R/iA
mF6go7YUVJ5BBEqzHlAv6vyUlCyCKn9ABK7/3LezOe38onDzZyg/OdTrIwq3
/2tGePyrIlG4+yDionD3w+T9ngg9PXqMA00/J9z82W9n3+ST54Lbb+B+olV6
JtcBDaj7Xl1ct+/KUy4093PD/YciD/Q/TD8sfGDmo4YfJzx8/aHuQw9/AP91
jxw=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByA0y4HVq0AAwQ8FA2E4H0KLoKkXQVMviqZe
jCAfoo8VzoeYy4amngNNPSecD1a+igtNPQ8GH9V9PGjuh6kXQVMvjKZeCE09
Yf5qFPcJobkfpp4DTT0bnB+GEj6I+AEAP9Reqg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, -3.2651650429449552`}, \
{-4.6752404735808355`, -3.1875}, {-4.595057255667003, -3.404942744332997}, \
{-4.734834957055044, -3.2651650429449552`}}], 
      PolygonBox[{{-4.562655006646477, -3.2302516425362553`}, \
{-4.595057255667003, -3.404942744332997}, {-4.6752404735808355`, -3.1875}, \
{-4.562655006646477, -3.2302516425362553`}}], 
      PolygonBox[{{-4.6752404735808355`, -3.1875}, {-4.637777815141599, \
-3.0970571419134454`}, {-4.562655006646477, -3.2302516425362553`}, \
{-4.6752404735808355`, -3.1875}}], 
      PolygonBox[{{-4.562500018967059, -3.084292589556062}, \
{-4.562655006646477, -3.2302516425362553`}, {-4.637777815141599, \
-3.0970571419134454`}, {-4.562500018967059, -3.084292589556062}}], 
      PolygonBox[{{-4.637777815141599, -3.0970571419134454`}, {-4.625, -3.}, \
{-4.562500018967059, -3.084292589556062}, {-4.637777815141599, \
-3.0970571419134454`}}], 
      PolygonBox[{{-4.5625, -3.}, {-4.562500018967059, -3.084292589556062}, \
{-4.625, -3.}, {-4.5625, -3.}}], 
      PolygonBox[{{-4.625, -3.}, {-4.637777815141599, -2.9029428580865546`}, \
{-4.5625, -3.}, {-4.625, -3.}}], 
      PolygonBox[{{-4.562500018967059, -2.915707410443938}, {-4.5625, -3.}, \
{-4.637777815141599, -2.9029428580865546`}, {-4.562500018967059, \
-2.915707410443938}}], 
      PolygonBox[{{-4.637777815141599, -2.9029428580865546`}, \
{-4.6752404735808355`, -2.8125}, {-4.562500018967059, -2.915707410443938}, \
{-4.637777815141599, -2.9029428580865546`}}], 
      PolygonBox[{{-4.562655006646477, -2.769748357463745}, \
{-4.562500018967059, -2.915707410443938}, {-4.6752404735808355`, -2.8125}, \
{-4.562655006646477, -2.769748357463745}}], 
      PolygonBox[{{-4.6752404735808355`, -2.8125}, {-4.734834957055044, \
-2.7348349570550448`}, {-4.562655006646477, -2.769748357463745}, \
{-4.6752404735808355`, -2.8125}}], 
      PolygonBox[{{-4.595057255667003, -2.595057255667003}, \
{-4.562655006646477, -2.769748357463745}, {-4.734834957055044, \
-2.7348349570550448`}, {-4.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{-4.734834957055044, -2.7348349570550448`}, {-4.8125, \
-2.6752404735808355`}, {-4.595057255667003, -2.595057255667003}, \
{-4.734834957055044, -2.7348349570550448`}}], 
      PolygonBox[{{-4.769748357463745, -2.5626550066464766`}, \
{-4.595057255667003, -2.595057255667003}, {-4.8125, -2.6752404735808355`}, \
{-4.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{-4.8125, -2.6752404735808355`}, {-4.902942858086555, \
-2.6377778151415994`}, {-4.769748357463745, -2.5626550066464766`}, {-4.8125, \
-2.6752404735808355`}}], 
      PolygonBox[{{-4.9157074104439396`, -2.562500018967059}, \
{-4.769748357463745, -2.5626550066464766`}, {-4.902942858086555, \
-2.6377778151415994`}, {-4.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-4.902942858086555, -2.6377778151415994`}, {-5., -2.625}, \
{-4.9157074104439396`, -2.562500018967059}, {-4.902942858086555, \
-2.6377778151415994`}}], 
      PolygonBox[{{-4.999894472779513, -2.5625}, {-4.9157074104439396`, \
-2.562500018967059}, {-5., -2.625}, {-4.999894472779513, -2.5625}}], 
      PolygonBox[{{-5., -2.625}, {-5.097057141913445, -2.6377778151415994`}, \
{-4.999894472779513, -2.5625}, {-5., -2.625}}], 
      PolygonBox[{{-5.084292589556057, -2.562500018967059}, \
{-4.999894472779513, -2.5625}, {-5.097057141913445, -2.6377778151415994`}, \
{-5.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-5.097057141913445, -2.6377778151415994`}, {-5.1875, \
-2.6752404735808355`}, {-5.084292589556057, -2.562500018967059}, \
{-5.097057141913445, -2.6377778151415994`}}], 
      PolygonBox[{{-5.230251642536255, -2.5626550066464766`}, \
{-5.084292589556057, -2.562500018967059}, {-5.1875, -2.6752404735808355`}, \
{-5.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-5.1875, -2.6752404735808355`}, {-5.265165042944956, \
-2.7348349570550448`}, {-5.230251642536255, -2.5626550066464766`}, {-5.1875, \
-2.6752404735808355`}}], 
      PolygonBox[{{-5.404942744332997, -2.595057255667003}, \
{-5.230251642536255, -2.5626550066464766`}, {-5.265165042944956, \
-2.7348349570550448`}, {-5.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-5.265165042944956, -2.7348349570550448`}, \
{-5.3247595264191645`, -2.8125}, {-5.404942744332997, -2.595057255667003}, \
{-5.265165042944956, -2.7348349570550448`}}], 
      PolygonBox[{{-5.437344993353523, -2.7697483574637447`}, \
{-5.404942744332997, -2.595057255667003}, {-5.3247595264191645`, -2.8125}, \
{-5.437344993353523, -2.7697483574637447`}}], 
      PolygonBox[{{-5.3247595264191645`, -2.8125}, {-5.362222184858401, \
-2.9029428580865546`}, {-5.437344993353523, -2.7697483574637447`}, \
{-5.3247595264191645`, -2.8125}}], 
      PolygonBox[{{-5.437499981032941, -2.9157074104439378`}, \
{-5.437344993353523, -2.7697483574637447`}, {-5.362222184858401, \
-2.9029428580865546`}, {-5.437499981032941, -2.9157074104439378`}}], 
      PolygonBox[{{-5.362222184858401, -2.9029428580865546`}, {-5.375, -3.}, \
{-5.437499981032941, -2.9157074104439378`}, {-5.362222184858401, \
-2.9029428580865546`}}], 
      PolygonBox[{{-5.4375, -2.9998768219370047`}, {-5.437499981032941, \
-2.9157074104439378`}, {-5.375, -3.}, {-5.4375, -2.9998768219370047`}}], 
      PolygonBox[{{-5.375, -3.}, {-5.362222184858401, -3.097057141913445}, \
{-5.4375, -2.9998768219370047`}, {-5.375, -3.}}], 
      PolygonBox[{{-5.437499981032941, -3.084292589556055}, {-5.4375, \
-2.9998768219370047`}, {-5.362222184858401, -3.097057141913445}, \
{-5.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-5.362222184858401, -3.097057141913445}, \
{-5.3247595264191645`, -3.1875}, {-5.437499981032941, -3.084292589556055}, \
{-5.362222184858401, -3.097057141913445}}], 
      PolygonBox[{{-5.437344993353523, -3.230251642536255}, \
{-5.437499981032941, -3.084292589556055}, {-5.3247595264191645`, -3.1875}, \
{-5.437344993353523, -3.230251642536255}}], 
      PolygonBox[{{-5.3247595264191645`, -3.1875}, {-5.265165042944956, \
-3.2651650429449552`}, {-5.437344993353523, -3.230251642536255}, \
{-5.3247595264191645`, -3.1875}}], 
      PolygonBox[{{-5.404942744332997, -3.404942744332997}, \
{-5.437344993353523, -3.230251642536255}, {-5.265165042944956, \
-3.2651650429449552`}, {-5.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, -3.2651650429449552`}, {-5.1875, \
-3.3247595264191645`}, {-5.404942744332997, -3.404942744332997}, \
{-5.265165042944956, -3.2651650429449552`}}], 
      PolygonBox[{{-5.230251642536255, -3.4373449933535234`}, \
{-5.404942744332997, -3.404942744332997}, {-5.1875, -3.3247595264191645`}, \
{-5.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{-5.1875, -3.3247595264191645`}, {-5.097057141913446, \
-3.3622221848584006`}, {-5.230251642536255, -3.4373449933535234`}, {-5.1875, \
-3.3247595264191645`}}], 
      PolygonBox[{{-5.084292589556064, -3.437499981032941}, \
{-5.230251642536255, -3.4373449933535234`}, {-5.097057141913446, \
-3.3622221848584006`}, {-5.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-5.097057141913446, -3.3622221848584006`}, {-5., -3.375}, \
{-5.084292589556064, -3.437499981032941}, {-5.097057141913446, \
-3.3622221848584006`}}], 
      PolygonBox[{{-4.999865158168957, -3.4375}, {-5.084292589556064, \
-3.437499981032941}, {-5., -3.375}, {-4.999865158168957, -3.4375}}], 
      PolygonBox[{{-5., -3.375}, {-4.902942858086555, -3.3622221848584006`}, \
{-4.999865158168957, -3.4375}, {-5., -3.375}}], 
      PolygonBox[{{-4.915707410443947, -3.437499981032941}, \
{-4.999865158168957, -3.4375}, {-4.902942858086555, -3.3622221848584006`}, \
{-4.915707410443947, -3.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, -3.3622221848584006`}, {-4.8125, \
-3.3247595264191645`}, {-4.915707410443947, -3.437499981032941}, \
{-4.902942858086555, -3.3622221848584006`}}], 
      PolygonBox[{{-4.769748357463746, -3.4373449933535234`}, \
{-4.915707410443947, -3.437499981032941}, {-4.8125, -3.3247595264191645`}, \
{-4.769748357463746, -3.4373449933535234`}}], 
      PolygonBox[{{-4.8125, -3.3247595264191645`}, {-4.734834957055044, \
-3.2651650429449552`}, {-4.769748357463746, -3.4373449933535234`}, {-4.8125, \
-3.3247595264191645`}}], 
      PolygonBox[{{-4.595057255667003, -3.404942744332997}, \
{-4.769748357463746, -3.4373449933535234`}, {-4.734834957055044, \
-3.2651650429449552`}, {-4.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, -3.2651650429449552`}, \
{-4.734834957055044, -3.2651650429449552`}, {-4.595057255667003, \
-3.404942744332997}, {-4.734834957055044, -3.2651650429449552`}}], 
      PolygonBox[{{-4.595057255667003, -3.404942744332997}, \
{-4.595057255667003, -3.404942744332997}, {-4.734834957055044, \
-3.2651650429449552`}, {-4.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-4.595057255667003, -3.404942744332997}, \
{-4.562655006646477, -3.2302516425362553`}, {-4.5, -3.5}, \
{-4.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-4.5, -3.357662782649368}, {-4.5, -3.5}, \
{-4.562655006646477, -3.2302516425362553`}, {-4.5, -3.357662782649368}}], 
      PolygonBox[{{-4.562655006646477, -3.2302516425362553`}, \
{-4.562500018967059, -3.084292589556062}, {-4.5, -3.357662782649368}, \
{-4.562655006646477, -3.2302516425362553`}}], 
      PolygonBox[{{-4.5, -3.20590900530174}, {-4.5, -3.357662782649368}, \
{-4.562500018967059, -3.084292589556062}, {-4.5, -3.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, -3.084292589556062}, {-4.5625, -3.}, \
{-4.5, -3.20590900530174}, {-4.562500018967059, -3.084292589556062}}], 
      PolygonBox[{{-4.5, -3.}, {-4.5, -3.20590900530174}, {-4.5625, -3.}, \
{-4.5, -3.}}], 
      PolygonBox[{{-4.5625, -3.}, {-4.562500018967059, -2.915707410443938}, \
{-4.5, -3.}, {-4.5625, -3.}}], 
      PolygonBox[{{-4.5, -2.79409099469826}, {-4.5, -3.}, \
{-4.562500018967059, -2.915707410443938}, {-4.5, -2.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, -2.915707410443938}, \
{-4.562655006646477, -2.769748357463745}, {-4.5, -2.79409099469826}, \
{-4.562500018967059, -2.915707410443938}}], 
      PolygonBox[{{-4.5, -2.6423372173506325`}, {-4.5, -2.79409099469826}, \
{-4.562655006646477, -2.769748357463745}, {-4.5, -2.6423372173506325`}}], 
      PolygonBox[{{-4.562655006646477, -2.769748357463745}, \
{-4.595057255667003, -2.595057255667003}, {-4.5, -2.6423372173506325`}, \
{-4.562655006646477, -2.769748357463745}}], 
      PolygonBox[{{-4.508553435038814, -2.508553435038814}, {-4.5, \
-2.6423372173506325`}, {-4.595057255667003, -2.595057255667003}, \
{-4.508553435038814, -2.508553435038814}}], 
      PolygonBox[{{-4.595057255667003, -2.595057255667003}, \
{-4.769748357463745, -2.5626550066464766`}, {-4.508553435038814, \
-2.508553435038814}, {-4.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{-4.642337217350632, -2.5}, {-4.508553435038814, \
-2.508553435038814}, {-4.769748357463745, -2.5626550066464766`}, \
{-4.642337217350632, -2.5}}], 
      PolygonBox[{{-4.769748357463745, -2.5626550066464766`}, \
{-4.9157074104439396`, -2.562500018967059}, {-4.642337217350632, -2.5}, \
{-4.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{-4.794090994626744, -2.5}, {-4.642337217350632, -2.5}, \
{-4.9157074104439396`, -2.562500018967059}, {-4.794090994626744, -2.5}}], 
      PolygonBox[{{-4.9157074104439396`, -2.562500018967059}, \
{-4.999894472779513, -2.5625}, {-4.794090994626744, -2.5}, \
{-4.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-4.92205804197311, -2.5}, {-4.794090994626744, -2.5}, \
{-4.999894472779513, -2.5625}, {-4.92205804197311, -2.5}}], 
      PolygonBox[{{-4.999894472779513, -2.5625}, {-5.084292589556057, \
-2.562500018967059}, {-4.92205804197311, -2.5}, {-4.999894472779513, \
-2.5625}}], 
      PolygonBox[{{-5.205909005304446, -2.5}, {-4.92205804197311, -2.5}, \
{-5.084292589556057, -2.562500018967059}, {-5.205909005304446, -2.5}}], 
      PolygonBox[{{-5.084292589556057, -2.562500018967059}, \
{-5.230251642536255, -2.5626550066464766`}, {-5.205909005304446, -2.5}, \
{-5.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-5.357662782649366, -2.5}, {-5.205909005304446, -2.5}, \
{-5.230251642536255, -2.5626550066464766`}, {-5.357662782649366, -2.5}}], 
      PolygonBox[{{-5.230251642536255, -2.5626550066464766`}, \
{-5.404942744332997, -2.595057255667003}, {-5.357662782649366, -2.5}, \
{-5.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-4.5, -2.5}, {-5.357662782649366, -2.5}, \
{-5.404942744332997, -2.595057255667003}, {-4.5, -2.5}}], 
      PolygonBox[{{-5.404942744332997, -2.595057255667003}, \
{-5.437344993353523, -2.7697483574637447`}, {-4.5, -2.5}, \
{-5.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-5.5, -2.642337217350631}, {-4.5, -2.5}, \
{-5.437344993353523, -2.7697483574637447`}, {-5.5, -2.642337217350631}}], 
      PolygonBox[{{-5.437344993353523, -2.7697483574637447`}, \
{-5.437499981032941, -2.9157074104439378`}, {-5.5, -2.642337217350631}, \
{-5.437344993353523, -2.7697483574637447`}}], 
      PolygonBox[{{-5.5, -2.794090994717101}, {-5.5, -2.642337217350631}, \
{-5.437499981032941, -2.9157074104439378`}, {-5.5, -2.794090994717101}}], 
      PolygonBox[{{-5.437499981032941, -2.9157074104439378`}, {-5.4375, \
-2.9998768219370047`}, {-5.5, -2.794090994717101}, {-5.437499981032941, \
-2.9157074104439378`}}], 
      PolygonBox[{{-5.5, -2.9193213332413}, {-5.5, -2.794090994717101}, \
{-5.4375, -2.9998768219370047`}, {-5.5, -2.9193213332413}}], 
      PolygonBox[{{-5.4375, -2.9998768219370047`}, {-5.437499981032941, \
-3.084292589556055}, {-5.5, -2.9193213332413}, {-5.4375, \
-2.9998768219370047`}}], 
      PolygonBox[{{-5.5, -3.2059090051452785`}, {-5.5, -2.9193213332413}, \
{-5.437499981032941, -3.084292589556055}, {-5.5, -3.2059090051452785`}}], 
      PolygonBox[{{-5.437499981032941, -3.084292589556055}, \
{-5.437344993353523, -3.230251642536255}, {-5.5, -3.2059090051452785`}, \
{-5.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-5.5, -3.3576627826493652`}, {-5.5, -3.2059090051452785`}, \
{-5.437344993353523, -3.230251642536255}, {-5.5, -3.3576627826493652`}}], 
      PolygonBox[{{-5.437344993353523, -3.230251642536255}, \
{-5.404942744332997, -3.404942744332997}, {-5.5, -3.3576627826493652`}, \
{-5.437344993353523, -3.230251642536255}}], 
      PolygonBox[{{-5.5, -2.5}, {-5.5, -3.3576627826493652`}, \
{-5.404942744332997, -3.404942744332997}, {-5.5, -2.5}}], 
      PolygonBox[{{-5.404942744332997, -3.404942744332997}, \
{-5.230251642536255, -3.4373449933535234`}, {-5.5, -2.5}, \
{-5.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-5.5, -3.5}, {-5.5, -2.5}, {-5.230251642536255, \
-3.4373449933535234`}, {-5.5, -3.5}}], 
      PolygonBox[{{-5.230251642536255, -3.4373449933535234`}, \
{-5.084292589556064, -3.437499981032941}, {-5.5, -3.5}, {-5.230251642536255, \
-3.4373449933535234`}}], 
      PolygonBox[{{-5.205909005566828, -3.5}, {-5.5, -3.5}, \
{-5.084292589556064, -3.437499981032941}, {-5.205909005566828, -3.5}}], 
      PolygonBox[{{-5.084292589556064, -3.437499981032941}, \
{-4.999865158168957, -3.4375}, {-5.205909005566828, -3.5}, \
{-5.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-4.917676129598938, -3.5}, {-5.205909005566828, -3.5}, \
{-4.999865158168957, -3.4375}, {-4.917676129598938, -3.5}}], 
      PolygonBox[{{-4.999865158168957, -3.4375}, {-4.915707410443947, \
-3.437499981032941}, {-4.917676129598938, -3.5}, {-4.999865158168957, \
-3.4375}}], 
      PolygonBox[{{-4.794090994639602, -3.5}, {-4.917676129598938, -3.5}, \
{-4.915707410443947, -3.437499981032941}, {-4.794090994639602, -3.5}}], 
      PolygonBox[{{-4.915707410443947, -3.437499981032941}, \
{-4.769748357463746, -3.4373449933535234`}, {-4.794090994639602, -3.5}, \
{-4.915707410443947, -3.437499981032941}}], 
      PolygonBox[{{-4.6423372173506285`, -3.5}, {-4.794090994639602, -3.5}, \
{-4.769748357463746, -3.4373449933535234`}, {-4.6423372173506285`, -3.5}}], 
      PolygonBox[{{-4.769748357463746, -3.4373449933535234`}, \
{-4.595057255667003, -3.404942744332997}, {-4.6423372173506285`, -3.5}, \
{-4.769748357463746, -3.4373449933535234`}}], 
      PolygonBox[{{-4.5, -3.5}, {-4.6423372173506285`, -3.5}, \
{-4.595057255667003, -3.404942744332997}, {-4.5, -3.5}}], 
      PolygonBox[{{-4.595057255667003, -3.404942744332997}, \
{-4.595057255667003, -3.404942744332997}, {-4.5, -3.5}, {-4.595057255667003, \
-3.404942744332997}}], 
      PolygonBox[{{-4.5, -3.5}, {-4.5, -3.5}, {-4.595057255667003, \
-3.404942744332997}, {-4.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, -2.}, {-5.479166666666667, -2.}, {-5.458333333333333, \
-2.}, {-5.4375, -2.}, {-5.416666666666667, -2.}, {-5.395833333333333, -2.}, \
{-5.375, -2.}, {-5.375, -2.}, {-5.395833333333333, -2.}, {-5.416666666666667, \
-2.}, {-5.4375, -2.}, {-5.458333333333333, -2.}, {-5.479166666666667, -2.}, \
{-5.5, -2.}, {-5.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, -2.}, {-4.604166666666667, -2.}, {-4.583333333333333, \
-2.}, {-4.5625, -2.}, {-4.541666666666667, -2.}, {-4.520833333333333, -2.}, \
{-4.5, -2.}, {-4.5, -2.}, {-4.520833333333333, -2.}, {-4.541666666666667, \
-2.}, {-4.5625, -2.}, {-4.583333333333333, -2.}, {-4.604166666666667, -2.}, \
{-4.625, -2.}, {-4.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -2.5}, {-5., -2.4791666666666665`}, {-5., \
-2.4583333333333335`}, {-5., -2.4375}, {-5., -2.4166666666666665`}, {-5., \
-2.3958333333333335`}, {-5., -2.375}, {-5., -2.375}, {-5., \
-2.3958333333333335`}, {-5., -2.4166666666666665`}, {-5., -2.4375}, {-5., \
-2.4583333333333335`}, {-5., -2.4791666666666665`}, {-5., -2.5}, {-5., \
-2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -1.625}, {-5., -1.6041666666666667`}, {-5., \
-1.5833333333333333`}, {-5., -1.5625}, {-5., -1.5416666666666667`}, {-5., \
-1.5208333333333335`}, {-5., -1.5}, {-5., -1.5}, {-5., -1.5208333333333333`}, \
{-5., -1.5416666666666667`}, {-5., -1.5625}, {-5., -1.5833333333333333`}, \
{-5., -1.6041666666666665`}, {-5., -1.625}, {-5., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, -2.}, {-5.25, -2.}, {-5.125, -2.}, {-5., -2.}, \
{-4.875, -2.}, {-4.75, -2.}, {-4.625, -2.}, {-4.625, -2.}, {-4.75, -2.}, \
{-4.875, -2.}, {-5., -2.}, {-5.125, -2.}, {-5.25, -2.}, {-5.375, -2.}, \
{-5.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -2.375}, {-5., -2.25}, {-5., -2.125}, {-5., -2.}, {-5., \
-1.875}, {-5., -1.75}, {-5., -1.625}, {-5., -1.625}, {-5., -1.75}, {-5., \
-1.875}, {-5., -2.}, {-5., -2.125}, {-5., -2.25}, {-5., -2.375}, {-5., \
-2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgegrAPc01csEO0VOpBkfsu0pOjf/ow70rZF
m2Hyf/cbcRpNrvggdOCUygmfRwd/7wcLOwgfWFCY/+XE2V/7b/aW8c6dI3xA
J2ZRU5jJL4g8gwhU/6/96kWdn5KSRVDlD4jA9Z/7djannV8Ubv4M5SeHen1E
4fZ/zQiPf1UkCncfxP0weYYDMHm/J0JPjx5jOICiv4HxAMz82W9n3+STZzoA
s9/A/USr9EymAxpQ9726uG7fladQebj7mQ/A/IciD/Q/TD8sfGDmo4Qf0H5Y
+PpD3Yce/gDW052q
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByD0j/2rV4EAgh8KBsJwPoQWQVMvgqZeFE29
GEE+2JhVv+B8iDl/0dQzHECVZzyAqp/pAKp6Fgw+qvtYDqC6H6ZeBE29MJp6
ITT1hPmrUdwnhOZ+mHoGOD8Mxf8w/b/2o6r/sR8AmApqkA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, -2.2651650429449552`}, \
{-4.6752404735808355`, -2.1875}, {-4.595057255667003, -2.404942744332997}, \
{-4.734834957055044, -2.2651650429449552`}}], 
      PolygonBox[{{-4.562655006646477, -2.2302516425362553`}, \
{-4.595057255667003, -2.404942744332997}, {-4.6752404735808355`, -2.1875}, \
{-4.562655006646477, -2.2302516425362553`}}], 
      PolygonBox[{{-4.6752404735808355`, -2.1875}, {-4.637777815141599, \
-2.0970571419134454`}, {-4.562655006646477, -2.2302516425362553`}, \
{-4.6752404735808355`, -2.1875}}], 
      PolygonBox[{{-4.562500018967059, -2.084292589556062}, \
{-4.562655006646477, -2.2302516425362553`}, {-4.637777815141599, \
-2.0970571419134454`}, {-4.562500018967059, -2.084292589556062}}], 
      PolygonBox[{{-4.637777815141599, -2.0970571419134454`}, {-4.625, -2.}, \
{-4.562500018967059, -2.084292589556062}, {-4.637777815141599, \
-2.0970571419134454`}}], 
      PolygonBox[{{-4.5625, -2.}, {-4.562500018967059, -2.084292589556062}, \
{-4.625, -2.}, {-4.5625, -2.}}], 
      PolygonBox[{{-4.625, -2.}, {-4.637777815141599, -1.9029428580865548`}, \
{-4.5625, -2.}, {-4.625, -2.}}], 
      PolygonBox[{{-4.562500018967059, -1.9157074104439382`}, {-4.5625, -2.}, \
{-4.637777815141599, -1.9029428580865548`}, {-4.562500018967059, \
-1.9157074104439382`}}], 
      PolygonBox[{{-4.637777815141599, -1.9029428580865548`}, \
{-4.6752404735808355`, -1.8125}, {-4.562500018967059, -1.9157074104439382`}, \
{-4.637777815141599, -1.9029428580865548`}}], 
      PolygonBox[{{-4.562655006646477, -1.769748357463745}, \
{-4.562500018967059, -1.9157074104439382`}, {-4.6752404735808355`, -1.8125}, \
{-4.562655006646477, -1.769748357463745}}], 
      PolygonBox[{{-4.6752404735808355`, -1.8125}, {-4.734834957055044, \
-1.7348349570550448`}, {-4.562655006646477, -1.769748357463745}, \
{-4.6752404735808355`, -1.8125}}], 
      PolygonBox[{{-4.595057255667003, -1.5950572556670028`}, \
{-4.562655006646477, -1.769748357463745}, {-4.734834957055044, \
-1.7348349570550448`}, {-4.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{-4.734834957055044, -1.7348349570550448`}, {-4.8125, \
-1.6752404735808355`}, {-4.595057255667003, -1.5950572556670028`}, \
{-4.734834957055044, -1.7348349570550448`}}], 
      PolygonBox[{{-4.769748357463745, -1.5626550066464766`}, \
{-4.595057255667003, -1.5950572556670028`}, {-4.8125, -1.6752404735808355`}, \
{-4.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{-4.8125, -1.6752404735808355`}, {-4.902942858086555, \
-1.6377778151415994`}, {-4.769748357463745, -1.5626550066464766`}, {-4.8125, \
-1.6752404735808355`}}], 
      PolygonBox[{{-4.9157074104439396`, -1.5625000189670593`}, \
{-4.769748357463745, -1.5626550066464766`}, {-4.902942858086555, \
-1.6377778151415994`}, {-4.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-4.902942858086555, -1.6377778151415994`}, {-5., -1.625}, \
{-4.9157074104439396`, -1.5625000189670593`}, {-4.902942858086555, \
-1.6377778151415994`}}], 
      PolygonBox[{{-4.999894472779513, -1.5625}, {-4.9157074104439396`, \
-1.5625000189670593`}, {-5., -1.625}, {-4.999894472779513, -1.5625}}], 
      PolygonBox[{{-5., -1.625}, {-5.097057141913445, -1.6377778151415994`}, \
{-4.999894472779513, -1.5625}, {-5., -1.625}}], 
      PolygonBox[{{-5.084292589556057, -1.5625000189670593`}, \
{-4.999894472779513, -1.5625}, {-5.097057141913445, -1.6377778151415994`}, \
{-5.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-5.097057141913445, -1.6377778151415994`}, {-5.1875, \
-1.6752404735808355`}, {-5.084292589556057, -1.5625000189670593`}, \
{-5.097057141913445, -1.6377778151415994`}}], 
      PolygonBox[{{-5.230251642536255, -1.5626550066464766`}, \
{-5.084292589556057, -1.5625000189670593`}, {-5.1875, -1.6752404735808355`}, \
{-5.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-5.1875, -1.6752404735808355`}, {-5.265165042944956, \
-1.7348349570550448`}, {-5.230251642536255, -1.5626550066464766`}, {-5.1875, \
-1.6752404735808355`}}], 
      PolygonBox[{{-5.404942744332997, -1.5950572556670028`}, \
{-5.230251642536255, -1.5626550066464766`}, {-5.265165042944956, \
-1.7348349570550448`}, {-5.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-5.265165042944956, -1.7348349570550448`}, \
{-5.3247595264191645`, -1.8125}, {-5.404942744332997, -1.5950572556670028`}, \
{-5.265165042944956, -1.7348349570550448`}}], 
      PolygonBox[{{-5.437344993353523, -1.7697483574637447`}, \
{-5.404942744332997, -1.5950572556670028`}, {-5.3247595264191645`, -1.8125}, \
{-5.437344993353523, -1.7697483574637447`}}], 
      PolygonBox[{{-5.3247595264191645`, -1.8125}, {-5.362222184858401, \
-1.9029428580865546`}, {-5.437344993353523, -1.7697483574637447`}, \
{-5.3247595264191645`, -1.8125}}], 
      PolygonBox[{{-5.437499981032941, -1.9157074104439376`}, \
{-5.437344993353523, -1.7697483574637447`}, {-5.362222184858401, \
-1.9029428580865546`}, {-5.437499981032941, -1.9157074104439376`}}], 
      PolygonBox[{{-5.362222184858401, -1.9029428580865546`}, {-5.375, \
-1.9999999999999998`}, {-5.437499981032941, -1.9157074104439376`}, \
{-5.362222184858401, -1.9029428580865546`}}], 
      PolygonBox[{{-5.4375, -1.9998768219370047`}, {-5.437499981032941, \
-1.9157074104439376`}, {-5.375, -1.9999999999999998`}, {-5.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-5.375, -1.9999999999999998`}, {-5.362222184858401, \
-2.097057141913445}, {-5.4375, -1.9998768219370047`}, {-5.375, \
-1.9999999999999998`}}], 
      PolygonBox[{{-5.437499981032941, -2.084292589556055}, {-5.4375, \
-1.9998768219370047`}, {-5.362222184858401, -2.097057141913445}, \
{-5.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-5.362222184858401, -2.097057141913445}, \
{-5.3247595264191645`, -2.1875}, {-5.437499981032941, -2.084292589556055}, \
{-5.362222184858401, -2.097057141913445}}], 
      PolygonBox[{{-5.437344993353523, -2.230251642536255}, \
{-5.437499981032941, -2.084292589556055}, {-5.3247595264191645`, -2.1875}, \
{-5.437344993353523, -2.230251642536255}}], 
      PolygonBox[{{-5.3247595264191645`, -2.1875}, {-5.265165042944956, \
-2.2651650429449552`}, {-5.437344993353523, -2.230251642536255}, \
{-5.3247595264191645`, -2.1875}}], 
      PolygonBox[{{-5.404942744332997, -2.404942744332997}, \
{-5.437344993353523, -2.230251642536255}, {-5.265165042944956, \
-2.2651650429449552`}, {-5.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, -2.2651650429449552`}, {-5.1875, \
-2.3247595264191645`}, {-5.404942744332997, -2.404942744332997}, \
{-5.265165042944956, -2.2651650429449552`}}], 
      PolygonBox[{{-5.230251642536255, -2.4373449933535234`}, \
{-5.404942744332997, -2.404942744332997}, {-5.1875, -2.3247595264191645`}, \
{-5.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{-5.1875, -2.3247595264191645`}, {-5.097057141913446, \
-2.3622221848584006`}, {-5.230251642536255, -2.4373449933535234`}, {-5.1875, \
-2.3247595264191645`}}], 
      PolygonBox[{{-5.084292589556064, -2.437499981032941}, \
{-5.230251642536255, -2.4373449933535234`}, {-5.097057141913446, \
-2.3622221848584006`}, {-5.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-5.097057141913446, -2.3622221848584006`}, {-5., -2.375}, \
{-5.084292589556064, -2.437499981032941}, {-5.097057141913446, \
-2.3622221848584006`}}], 
      PolygonBox[{{-4.999865158168957, -2.4375}, {-5.084292589556064, \
-2.437499981032941}, {-5., -2.375}, {-4.999865158168957, -2.4375}}], 
      PolygonBox[{{-5., -2.375}, {-4.902942858086555, -2.3622221848584006`}, \
{-4.999865158168957, -2.4375}, {-5., -2.375}}], 
      PolygonBox[{{-4.915707410443947, -2.437499981032941}, \
{-4.999865158168957, -2.4375}, {-4.902942858086555, -2.3622221848584006`}, \
{-4.915707410443947, -2.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, -2.3622221848584006`}, {-4.8125, \
-2.3247595264191645`}, {-4.915707410443947, -2.437499981032941}, \
{-4.902942858086555, -2.3622221848584006`}}], 
      PolygonBox[{{-4.769748357463746, -2.4373449933535234`}, \
{-4.915707410443947, -2.437499981032941}, {-4.8125, -2.3247595264191645`}, \
{-4.769748357463746, -2.4373449933535234`}}], 
      PolygonBox[{{-4.8125, -2.3247595264191645`}, {-4.734834957055044, \
-2.2651650429449552`}, {-4.769748357463746, -2.4373449933535234`}, {-4.8125, \
-2.3247595264191645`}}], 
      PolygonBox[{{-4.595057255667003, -2.404942744332997}, \
{-4.769748357463746, -2.4373449933535234`}, {-4.734834957055044, \
-2.2651650429449552`}, {-4.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, -2.2651650429449552`}, \
{-4.734834957055044, -2.2651650429449552`}, {-4.595057255667003, \
-2.404942744332997}, {-4.734834957055044, -2.2651650429449552`}}], 
      PolygonBox[{{-4.595057255667003, -2.404942744332997}, \
{-4.595057255667003, -2.404942744332997}, {-4.734834957055044, \
-2.2651650429449552`}, {-4.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-4.595057255667003, -2.404942744332997}, \
{-4.562655006646477, -2.2302516425362553`}, {-4.5, -2.5}, \
{-4.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-4.5, -2.357662782649368}, {-4.5, -2.5}, \
{-4.562655006646477, -2.2302516425362553`}, {-4.5, -2.357662782649368}}], 
      PolygonBox[{{-4.562655006646477, -2.2302516425362553`}, \
{-4.562500018967059, -2.084292589556062}, {-4.5, -2.357662782649368}, \
{-4.562655006646477, -2.2302516425362553`}}], 
      PolygonBox[{{-4.5, -2.20590900530174}, {-4.5, -2.357662782649368}, \
{-4.562500018967059, -2.084292589556062}, {-4.5, -2.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, -2.084292589556062}, {-4.5625, -2.}, \
{-4.5, -2.20590900530174}, {-4.562500018967059, -2.084292589556062}}], 
      PolygonBox[{{-4.5, -2.}, {-4.5, -2.20590900530174}, {-4.5625, -2.}, \
{-4.5, -2.}}], 
      PolygonBox[{{-4.5625, -2.}, {-4.562500018967059, -1.9157074104439382`}, \
{-4.5, -2.}, {-4.5625, -2.}}], 
      PolygonBox[{{-4.5, -1.7940909946982602`}, {-4.5, -2.}, \
{-4.562500018967059, -1.9157074104439382`}, {-4.5, -1.7940909946982602`}}], 
      PolygonBox[{{-4.562500018967059, -1.9157074104439382`}, \
{-4.562655006646477, -1.769748357463745}, {-4.5, -1.7940909946982602`}, \
{-4.562500018967059, -1.9157074104439382`}}], 
      PolygonBox[{{-4.5, -1.6423372173506325`}, {-4.5, -1.7940909946982602`}, \
{-4.562655006646477, -1.769748357463745}, {-4.5, -1.6423372173506325`}}], 
      PolygonBox[{{-4.562655006646477, -1.769748357463745}, \
{-4.595057255667003, -1.5950572556670028`}, {-4.5, -1.6423372173506325`}, \
{-4.562655006646477, -1.769748357463745}}], 
      PolygonBox[{{-4.508553435038814, -1.508553435038814}, {-4.5, \
-1.6423372173506325`}, {-4.595057255667003, -1.5950572556670028`}, \
{-4.508553435038814, -1.508553435038814}}], 
      PolygonBox[{{-4.595057255667003, -1.5950572556670028`}, \
{-4.769748357463745, -1.5626550066464766`}, {-4.508553435038814, \
-1.508553435038814}, {-4.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{-4.642337217350632, -1.5}, {-4.508553435038814, \
-1.508553435038814}, {-4.769748357463745, -1.5626550066464766`}, \
{-4.642337217350632, -1.5}}], 
      PolygonBox[{{-4.769748357463745, -1.5626550066464766`}, \
{-4.9157074104439396`, -1.5625000189670593`}, {-4.642337217350632, -1.5}, \
{-4.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{-4.794090994626744, -1.5}, {-4.642337217350632, -1.5}, \
{-4.9157074104439396`, -1.5625000189670593`}, {-4.794090994626744, -1.5}}], 
      PolygonBox[{{-4.9157074104439396`, -1.5625000189670593`}, \
{-4.999894472779513, -1.5625}, {-4.794090994626744, -1.5}, \
{-4.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-4.92205804197311, -1.5}, {-4.794090994626744, -1.5}, \
{-4.999894472779513, -1.5625}, {-4.92205804197311, -1.5}}], 
      PolygonBox[{{-4.999894472779513, -1.5625}, {-5.084292589556057, \
-1.5625000189670593`}, {-4.92205804197311, -1.5}, {-4.999894472779513, \
-1.5625}}], 
      PolygonBox[{{-5.205909005304446, -1.5}, {-4.92205804197311, -1.5}, \
{-5.084292589556057, -1.5625000189670593`}, {-5.205909005304446, -1.5}}], 
      PolygonBox[{{-5.084292589556057, -1.5625000189670593`}, \
{-5.230251642536255, -1.5626550066464766`}, {-5.205909005304446, -1.5}, \
{-5.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-5.357662782649366, -1.5}, {-5.205909005304446, -1.5}, \
{-5.230251642536255, -1.5626550066464766`}, {-5.357662782649366, -1.5}}], 
      PolygonBox[{{-5.230251642536255, -1.5626550066464766`}, \
{-5.404942744332997, -1.5950572556670028`}, {-5.357662782649366, -1.5}, \
{-5.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-4.5, -1.5}, {-5.357662782649366, -1.5}, \
{-5.404942744332997, -1.5950572556670028`}, {-4.5, -1.5}}], 
      PolygonBox[{{-5.404942744332997, -1.5950572556670028`}, \
{-5.437344993353523, -1.7697483574637447`}, {-4.5, -1.5}, \
{-5.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-5.5, -1.642337217350631}, {-4.5, -1.5}, \
{-5.437344993353523, -1.7697483574637447`}, {-5.5, -1.642337217350631}}], 
      PolygonBox[{{-5.437344993353523, -1.7697483574637447`}, \
{-5.437499981032941, -1.9157074104439376`}, {-5.5, -1.642337217350631}, \
{-5.437344993353523, -1.7697483574637447`}}], 
      PolygonBox[{{-5.5, -1.794090994717101}, {-5.5, -1.642337217350631}, \
{-5.437499981032941, -1.9157074104439376`}, {-5.5, -1.794090994717101}}], 
      PolygonBox[{{-5.437499981032941, -1.9157074104439376`}, {-5.4375, \
-1.9998768219370047`}, {-5.5, -1.794090994717101}, {-5.437499981032941, \
-1.9157074104439376`}}], 
      PolygonBox[{{-5.5, -1.9193213332412997`}, {-5.5, -1.794090994717101}, \
{-5.4375, -1.9998768219370047`}, {-5.5, -1.9193213332412997`}}], 
      PolygonBox[{{-5.4375, -1.9998768219370047`}, {-5.437499981032941, \
-2.084292589556055}, {-5.5, -1.9193213332412997`}, {-5.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-5.5, -2.2059090051452785`}, {-5.5, -1.9193213332412997`}, \
{-5.437499981032941, -2.084292589556055}, {-5.5, -2.2059090051452785`}}], 
      PolygonBox[{{-5.437499981032941, -2.084292589556055}, \
{-5.437344993353523, -2.230251642536255}, {-5.5, -2.2059090051452785`}, \
{-5.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-5.5, -2.3576627826493652`}, {-5.5, -2.2059090051452785`}, \
{-5.437344993353523, -2.230251642536255}, {-5.5, -2.3576627826493652`}}], 
      PolygonBox[{{-5.437344993353523, -2.230251642536255}, \
{-5.404942744332997, -2.404942744332997}, {-5.5, -2.3576627826493652`}, \
{-5.437344993353523, -2.230251642536255}}], 
      PolygonBox[{{-5.5, -1.5}, {-5.5, -2.3576627826493652`}, \
{-5.404942744332997, -2.404942744332997}, {-5.5, -1.5}}], 
      PolygonBox[{{-5.404942744332997, -2.404942744332997}, \
{-5.230251642536255, -2.4373449933535234`}, {-5.5, -1.5}, \
{-5.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-5.5, -2.5}, {-5.5, -1.5}, {-5.230251642536255, \
-2.4373449933535234`}, {-5.5, -2.5}}], 
      PolygonBox[{{-5.230251642536255, -2.4373449933535234`}, \
{-5.084292589556064, -2.437499981032941}, {-5.5, -2.5}, {-5.230251642536255, \
-2.4373449933535234`}}], 
      PolygonBox[{{-5.205909005566828, -2.5}, {-5.5, -2.5}, \
{-5.084292589556064, -2.437499981032941}, {-5.205909005566828, -2.5}}], 
      PolygonBox[{{-5.084292589556064, -2.437499981032941}, \
{-4.999865158168957, -2.4375}, {-5.205909005566828, -2.5}, \
{-5.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-4.917676129598938, -2.5}, {-5.205909005566828, -2.5}, \
{-4.999865158168957, -2.4375}, {-4.917676129598938, -2.5}}], 
      PolygonBox[{{-4.999865158168957, -2.4375}, {-4.915707410443947, \
-2.437499981032941}, {-4.917676129598938, -2.5}, {-4.999865158168957, \
-2.4375}}], 
      PolygonBox[{{-4.794090994639602, -2.5}, {-4.917676129598938, -2.5}, \
{-4.915707410443947, -2.437499981032941}, {-4.794090994639602, -2.5}}], 
      PolygonBox[{{-4.915707410443947, -2.437499981032941}, \
{-4.769748357463746, -2.4373449933535234`}, {-4.794090994639602, -2.5}, \
{-4.915707410443947, -2.437499981032941}}], 
      PolygonBox[{{-4.6423372173506285`, -2.5}, {-4.794090994639602, -2.5}, \
{-4.769748357463746, -2.4373449933535234`}, {-4.6423372173506285`, -2.5}}], 
      PolygonBox[{{-4.769748357463746, -2.4373449933535234`}, \
{-4.595057255667003, -2.404942744332997}, {-4.6423372173506285`, -2.5}, \
{-4.769748357463746, -2.4373449933535234`}}], 
      PolygonBox[{{-4.5, -2.5}, {-4.6423372173506285`, -2.5}, \
{-4.595057255667003, -2.404942744332997}, {-4.5, -2.5}}], 
      PolygonBox[{{-4.595057255667003, -2.404942744332997}, \
{-4.595057255667003, -2.404942744332997}, {-4.5, -2.5}, {-4.595057255667003, \
-2.404942744332997}}], 
      PolygonBox[{{-4.5, -2.5}, {-4.5, -2.5}, {-4.595057255667003, \
-2.404942744332997}, {-4.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, -1.}, {-5.479166666666667, -1.}, {-5.458333333333333, \
-1.}, {-5.4375, -1.}, {-5.416666666666667, -1.}, {-5.395833333333333, -1.}, \
{-5.375, -1.}, {-5.375, -1.}, {-5.395833333333333, -1.}, {-5.416666666666667, \
-1.}, {-5.4375, -1.}, {-5.458333333333333, -1.}, {-5.479166666666667, -1.}, \
{-5.5, -1.}, {-5.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, -1.}, {-4.604166666666667, -1.}, {-4.583333333333333, \
-1.}, {-4.5625, -1.}, {-4.541666666666667, -1.}, {-4.520833333333333, -1.}, \
{-4.5, -1.}, {-4.5, -1.}, {-4.520833333333333, -1.}, {-4.541666666666667, \
-1.}, {-4.5625, -1.}, {-4.583333333333333, -1.}, {-4.604166666666667, -1.}, \
{-4.625, -1.}, {-4.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -1.5}, {-5., -1.4791666666666667`}, {-5., \
-1.4583333333333333`}, {-5., -1.4375}, {-5., -1.4166666666666667`}, {-5., \
-1.3958333333333335`}, {-5., -1.375}, {-5., -1.375}, {-5., \
-1.3958333333333333`}, {-5., -1.4166666666666667`}, {-5., -1.4375}, {-5., \
-1.4583333333333333`}, {-5., -1.4791666666666665`}, {-5., -1.5}, {-5., \
-1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -0.625}, {-5., -0.6041666666666667}, {-5., \
-0.5833333333333333}, {-5., -0.5625}, {-5., -0.5416666666666667}, {-5., \
-0.5208333333333334}, {-5., -0.5}, {-5., -0.5}, {-5., -0.5208333333333333}, \
{-5., -0.5416666666666667}, {-5., -0.5625}, {-5., -0.5833333333333333}, {-5., \
-0.6041666666666666}, {-5., -0.625}, {-5., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, -1.}, {-5.25, -1.}, {-5.125, -1.}, {-5., -1.}, \
{-4.875, -1.}, {-4.75, -1.}, {-4.625, -1.}, {-4.625, -1.}, {-4.75, -1.}, \
{-4.875, -1.}, {-5., -1.}, {-5.125, -1.}, {-5.25, -1.}, {-5.375, -1.}, \
{-5.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -1.375}, {-5., -1.25}, {-5., -1.125}, {-5., -1.}, {-5., \
-0.875}, {-5., -0.75}, {-5., -0.625}, {-5., -0.625}, {-5., -0.75}, {-5., \
-0.875}, {-5., -1.}, {-5., -1.125}, {-5., -1.25}, {-5., -1.375}, {-5., \
-1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgjA/7uaevWCDaK3TgaN6W7BdP3uzPuCNt
W7QZJv9qvxGn0eSKD0IHpnhOmHmk+fl+sLCD8AGHx/deTJz9dP/N3jLeuXOE
D0TscGFdm/EEIs8gAtX/ZL96UeenpGQRVPkDInD9576dzWnnFz0wGWr+DOUn
h3p9RA/8B4OX+79mhMe/KhI9cATqPoj7ReHuh8nPPaF6qrv3I1w/RP4z3Hyz
2+abZe2+wO1P6JvAbW70db8G1H1XFsfWrjz9Fc393+D+Q5EH+h+mHxY+MPNh
4ccItR8WvvOh7kMPfwAqLKxw
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByD0g/2rV4EAgh8KBsJwPoQWQVMvgqZeFE29
GEE+RN9TOB9s7KpXaOo/oMl/QtP/FU39Dww+qvt+oLn/B5r/fqD5/wda+MDU
E+aHobhP6MBqFPfD1H9Ak3+Fpv8pmvoH+wFDA3eW
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, -1.2651650429449552`}, \
{-4.6752404735808355`, -1.1875}, {-4.595057255667003, -1.4049427443329972`}, \
{-4.734834957055044, -1.2651650429449552`}}], 
      PolygonBox[{{-4.562655006646477, -1.230251642536255}, \
{-4.595057255667003, -1.4049427443329972`}, {-4.6752404735808355`, -1.1875}, \
{-4.562655006646477, -1.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, -1.1875}, {-4.637777815141599, \
-1.0970571419134454`}, {-4.562655006646477, -1.230251642536255}, \
{-4.6752404735808355`, -1.1875}}], 
      PolygonBox[{{-4.562500018967059, -1.0842925895560618`}, \
{-4.562655006646477, -1.230251642536255}, {-4.637777815141599, \
-1.0970571419134454`}, {-4.562500018967059, -1.0842925895560618`}}], 
      PolygonBox[{{-4.637777815141599, -1.0970571419134454`}, {-4.625, -1.}, \
{-4.562500018967059, -1.0842925895560618`}, {-4.637777815141599, \
-1.0970571419134454`}}], 
      PolygonBox[{{-4.5625, -1.}, {-4.562500018967059, -1.0842925895560618`}, \
{-4.625, -1.}, {-4.5625, -1.}}], 
      PolygonBox[{{-4.625, -1.}, {-4.637777815141599, -0.9029428580865547}, \
{-4.5625, -1.}, {-4.625, -1.}}], 
      PolygonBox[{{-4.562500018967059, -0.9157074104439382}, {-4.5625, -1.}, \
{-4.637777815141599, -0.9029428580865547}, {-4.562500018967059, \
-0.9157074104439382}}], 
      PolygonBox[{{-4.637777815141599, -0.9029428580865547}, \
{-4.6752404735808355`, -0.8125}, {-4.562500018967059, -0.9157074104439382}, \
{-4.637777815141599, -0.9029428580865547}}], 
      PolygonBox[{{-4.562655006646477, -0.7697483574637449}, \
{-4.562500018967059, -0.9157074104439382}, {-4.6752404735808355`, -0.8125}, \
{-4.562655006646477, -0.7697483574637449}}], 
      PolygonBox[{{-4.6752404735808355`, -0.8125}, {-4.734834957055044, \
-0.7348349570550448}, {-4.562655006646477, -0.7697483574637449}, \
{-4.6752404735808355`, -0.8125}}], 
      PolygonBox[{{-4.595057255667003, -0.5950572556670028}, \
{-4.562655006646477, -0.7697483574637449}, {-4.734834957055044, \
-0.7348349570550448}, {-4.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{-4.734834957055044, -0.7348349570550448}, {-4.8125, \
-0.6752404735808355}, {-4.595057255667003, -0.5950572556670028}, \
{-4.734834957055044, -0.7348349570550448}}], 
      PolygonBox[{{-4.769748357463745, -0.5626550066464766}, \
{-4.595057255667003, -0.5950572556670028}, {-4.8125, -0.6752404735808355}, \
{-4.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{-4.8125, -0.6752404735808355}, {-4.902942858086555, \
-0.6377778151415994}, {-4.769748357463745, -0.5626550066464766}, {-4.8125, \
-0.6752404735808355}}], 
      PolygonBox[{{-4.9157074104439396`, -0.5625000189670593}, \
{-4.769748357463745, -0.5626550066464766}, {-4.902942858086555, \
-0.6377778151415994}, {-4.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-4.902942858086555, -0.6377778151415994}, {-5., -0.625}, \
{-4.9157074104439396`, -0.5625000189670593}, {-4.902942858086555, \
-0.6377778151415994}}], 
      PolygonBox[{{-4.999894472779513, -0.5625}, {-4.9157074104439396`, \
-0.5625000189670593}, {-5., -0.625}, {-4.999894472779513, -0.5625}}], 
      PolygonBox[{{-5., -0.625}, {-5.097057141913445, -0.6377778151415994}, \
{-4.999894472779513, -0.5625}, {-5., -0.625}}], 
      PolygonBox[{{-5.084292589556057, -0.5625000189670593}, \
{-4.999894472779513, -0.5625}, {-5.097057141913445, -0.6377778151415994}, \
{-5.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-5.097057141913445, -0.6377778151415994}, {-5.1875, \
-0.6752404735808355}, {-5.084292589556057, -0.5625000189670593}, \
{-5.097057141913445, -0.6377778151415994}}], 
      PolygonBox[{{-5.230251642536255, -0.5626550066464766}, \
{-5.084292589556057, -0.5625000189670593}, {-5.1875, -0.6752404735808355}, \
{-5.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-5.1875, -0.6752404735808355}, {-5.265165042944956, \
-0.7348349570550446}, {-5.230251642536255, -0.5626550066464766}, {-5.1875, \
-0.6752404735808355}}], 
      PolygonBox[{{-5.404942744332997, -0.5950572556670028}, \
{-5.230251642536255, -0.5626550066464766}, {-5.265165042944956, \
-0.7348349570550446}, {-5.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{-5.265165042944956, -0.7348349570550446}, \
{-5.3247595264191645`, -0.8124999999999999}, {-5.404942744332997, \
-0.5950572556670028}, {-5.265165042944956, -0.7348349570550446}}], 
      PolygonBox[{{-5.437344993353523, -0.7697483574637446}, \
{-5.404942744332997, -0.5950572556670028}, {-5.3247595264191645`, \
-0.8124999999999999}, {-5.437344993353523, -0.7697483574637446}}], 
      PolygonBox[{{-5.3247595264191645`, -0.8124999999999999}, \
{-5.362222184858401, -0.9029428580865546}, {-5.437344993353523, \
-0.7697483574637446}, {-5.3247595264191645`, -0.8124999999999999}}], 
      PolygonBox[{{-5.437499981032941, -0.9157074104439377}, \
{-5.437344993353523, -0.7697483574637446}, {-5.362222184858401, \
-0.9029428580865546}, {-5.437499981032941, -0.9157074104439377}}], 
      PolygonBox[{{-5.362222184858401, -0.9029428580865546}, {-5.375, \
-0.9999999999999998}, {-5.437499981032941, -0.9157074104439377}, \
{-5.362222184858401, -0.9029428580865546}}], 
      PolygonBox[{{-5.4375, -0.9998768219370047}, {-5.437499981032941, \
-0.9157074104439377}, {-5.375, -0.9999999999999998}, {-5.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-5.375, -0.9999999999999998}, {-5.362222184858401, \
-1.0970571419134452`}, {-5.4375, -0.9998768219370047}, {-5.375, \
-0.9999999999999998}}], 
      PolygonBox[{{-5.437499981032941, -1.084292589556055}, {-5.4375, \
-0.9998768219370047}, {-5.362222184858401, -1.0970571419134452`}, \
{-5.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-5.362222184858401, -1.0970571419134452`}, \
{-5.3247595264191645`, -1.1874999999999998`}, {-5.437499981032941, \
-1.084292589556055}, {-5.362222184858401, -1.0970571419134452`}}], 
      PolygonBox[{{-5.437344993353523, -1.2302516425362549`}, \
{-5.437499981032941, -1.084292589556055}, {-5.3247595264191645`, \
-1.1874999999999998`}, {-5.437344993353523, -1.2302516425362549`}}], 
      PolygonBox[{{-5.3247595264191645`, -1.1874999999999998`}, \
{-5.265165042944956, -1.2651650429449552`}, {-5.437344993353523, \
-1.2302516425362549`}, {-5.3247595264191645`, -1.1874999999999998`}}], 
      PolygonBox[{{-5.404942744332997, -1.4049427443329972`}, \
{-5.437344993353523, -1.2302516425362549`}, {-5.265165042944956, \
-1.2651650429449552`}, {-5.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-5.265165042944956, -1.2651650429449552`}, {-5.1875, \
-1.3247595264191645`}, {-5.404942744332997, -1.4049427443329972`}, \
{-5.265165042944956, -1.2651650429449552`}}], 
      PolygonBox[{{-5.230251642536255, -1.4373449933535234`}, \
{-5.404942744332997, -1.4049427443329972`}, {-5.1875, -1.3247595264191645`}, \
{-5.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-5.1875, -1.3247595264191645`}, {-5.097057141913446, \
-1.3622221848584006`}, {-5.230251642536255, -1.4373449933535234`}, {-5.1875, \
-1.3247595264191645`}}], 
      PolygonBox[{{-5.084292589556064, -1.4374999810329407`}, \
{-5.230251642536255, -1.4373449933535234`}, {-5.097057141913446, \
-1.3622221848584006`}, {-5.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-5.097057141913446, -1.3622221848584006`}, {-5., -1.375}, \
{-5.084292589556064, -1.4374999810329407`}, {-5.097057141913446, \
-1.3622221848584006`}}], 
      PolygonBox[{{-4.999865158168957, -1.4375}, {-5.084292589556064, \
-1.4374999810329407`}, {-5., -1.375}, {-4.999865158168957, -1.4375}}], 
      PolygonBox[{{-5., -1.375}, {-4.902942858086555, -1.3622221848584006`}, \
{-4.999865158168957, -1.4375}, {-5., -1.375}}], 
      PolygonBox[{{-4.915707410443947, -1.4374999810329407`}, \
{-4.999865158168957, -1.4375}, {-4.902942858086555, -1.3622221848584006`}, \
{-4.915707410443947, -1.4374999810329407`}}], 
      PolygonBox[{{-4.902942858086555, -1.3622221848584006`}, {-4.8125, \
-1.3247595264191645`}, {-4.915707410443947, -1.4374999810329407`}, \
{-4.902942858086555, -1.3622221848584006`}}], 
      PolygonBox[{{-4.769748357463746, -1.4373449933535234`}, \
{-4.915707410443947, -1.4374999810329407`}, {-4.8125, -1.3247595264191645`}, \
{-4.769748357463746, -1.4373449933535234`}}], 
      PolygonBox[{{-4.8125, -1.3247595264191645`}, {-4.734834957055044, \
-1.2651650429449552`}, {-4.769748357463746, -1.4373449933535234`}, {-4.8125, \
-1.3247595264191645`}}], 
      PolygonBox[{{-4.595057255667003, -1.4049427443329972`}, \
{-4.769748357463746, -1.4373449933535234`}, {-4.734834957055044, \
-1.2651650429449552`}, {-4.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-4.734834957055044, -1.2651650429449552`}, \
{-4.734834957055044, -1.2651650429449552`}, {-4.595057255667003, \
-1.4049427443329972`}, {-4.734834957055044, -1.2651650429449552`}}], 
      PolygonBox[{{-4.595057255667003, -1.4049427443329972`}, \
{-4.595057255667003, -1.4049427443329972`}, {-4.734834957055044, \
-1.2651650429449552`}, {-4.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-4.595057255667003, -1.4049427443329972`}, \
{-4.562655006646477, -1.230251642536255}, {-4.5, -1.5}, {-4.595057255667003, \
-1.4049427443329972`}}], 
      PolygonBox[{{-4.5, -1.3576627826493677`}, {-4.5, -1.5}, \
{-4.562655006646477, -1.230251642536255}, {-4.5, -1.3576627826493677`}}], 
      PolygonBox[{{-4.562655006646477, -1.230251642536255}, \
{-4.562500018967059, -1.0842925895560618`}, {-4.5, -1.3576627826493677`}, \
{-4.562655006646477, -1.230251642536255}}], 
      PolygonBox[{{-4.5, -1.20590900530174}, {-4.5, -1.3576627826493677`}, \
{-4.562500018967059, -1.0842925895560618`}, {-4.5, -1.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, -1.0842925895560618`}, {-4.5625, -1.}, \
{-4.5, -1.20590900530174}, {-4.562500018967059, -1.0842925895560618`}}], 
      PolygonBox[{{-4.5, -1.}, {-4.5, -1.20590900530174}, {-4.5625, -1.}, \
{-4.5, -1.}}], 
      PolygonBox[{{-4.5625, -1.}, {-4.562500018967059, -0.9157074104439382}, \
{-4.5, -1.}, {-4.5625, -1.}}], 
      PolygonBox[{{-4.5, -0.79409099469826}, {-4.5, -1.}, \
{-4.562500018967059, -0.9157074104439382}, {-4.5, -0.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, -0.9157074104439382}, \
{-4.562655006646477, -0.7697483574637449}, {-4.5, -0.79409099469826}, \
{-4.562500018967059, -0.9157074104439382}}], 
      PolygonBox[{{-4.5, -0.6423372173506324}, {-4.5, -0.79409099469826}, \
{-4.562655006646477, -0.7697483574637449}, {-4.5, -0.6423372173506324}}], 
      PolygonBox[{{-4.562655006646477, -0.7697483574637449}, \
{-4.595057255667003, -0.5950572556670028}, {-4.5, -0.6423372173506324}, \
{-4.562655006646477, -0.7697483574637449}}], 
      PolygonBox[{{-4.508553435038814, -0.508553435038814}, {-4.5, \
-0.6423372173506324}, {-4.595057255667003, -0.5950572556670028}, \
{-4.508553435038814, -0.508553435038814}}], 
      PolygonBox[{{-4.595057255667003, -0.5950572556670028}, \
{-4.769748357463745, -0.5626550066464766}, {-4.508553435038814, \
-0.508553435038814}, {-4.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{-4.642337217350632, -0.5}, {-4.508553435038814, \
-0.508553435038814}, {-4.769748357463745, -0.5626550066464766}, \
{-4.642337217350632, -0.5}}], 
      PolygonBox[{{-4.769748357463745, -0.5626550066464766}, \
{-4.9157074104439396`, -0.5625000189670593}, {-4.642337217350632, -0.5}, \
{-4.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{-4.794090994626744, -0.5}, {-4.642337217350632, -0.5}, \
{-4.9157074104439396`, -0.5625000189670593}, {-4.794090994626744, -0.5}}], 
      PolygonBox[{{-4.9157074104439396`, -0.5625000189670593}, \
{-4.999894472779513, -0.5625}, {-4.794090994626744, -0.5}, \
{-4.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-4.92205804197311, -0.5}, {-4.794090994626744, -0.5}, \
{-4.999894472779513, -0.5625}, {-4.92205804197311, -0.5}}], 
      PolygonBox[{{-4.999894472779513, -0.5625}, {-5.084292589556057, \
-0.5625000189670593}, {-4.92205804197311, -0.5}, {-4.999894472779513, \
-0.5625}}], 
      PolygonBox[{{-5.205909005304446, -0.5}, {-4.92205804197311, -0.5}, \
{-5.084292589556057, -0.5625000189670593}, {-5.205909005304446, -0.5}}], 
      PolygonBox[{{-5.084292589556057, -0.5625000189670593}, \
{-5.230251642536255, -0.5626550066464766}, {-5.205909005304446, -0.5}, \
{-5.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-5.357662782649366, -0.5}, {-5.205909005304446, -0.5}, \
{-5.230251642536255, -0.5626550066464766}, {-5.357662782649366, -0.5}}], 
      PolygonBox[{{-5.230251642536255, -0.5626550066464766}, \
{-5.404942744332997, -0.5950572556670028}, {-5.357662782649366, -0.5}, \
{-5.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-4.5, -0.5}, {-5.357662782649366, -0.5}, \
{-5.404942744332997, -0.5950572556670028}, {-4.5, -0.5}}], 
      PolygonBox[{{-5.404942744332997, -0.5950572556670028}, \
{-5.437344993353523, -0.7697483574637446}, {-4.5, -0.5}, {-5.404942744332997, \
-0.5950572556670028}}], 
      PolygonBox[{{-5.5, -0.642337217350631}, {-4.5, -0.5}, \
{-5.437344993353523, -0.7697483574637446}, {-5.5, -0.642337217350631}}], 
      PolygonBox[{{-5.437344993353523, -0.7697483574637446}, \
{-5.437499981032941, -0.9157074104439377}, {-5.5, -0.642337217350631}, \
{-5.437344993353523, -0.7697483574637446}}], 
      PolygonBox[{{-5.5, -0.7940909947171011}, {-5.5, -0.642337217350631}, \
{-5.437499981032941, -0.9157074104439377}, {-5.5, -0.7940909947171011}}], 
      PolygonBox[{{-5.437499981032941, -0.9157074104439377}, {-5.4375, \
-0.9998768219370047}, {-5.5, -0.7940909947171011}, {-5.437499981032941, \
-0.9157074104439377}}], 
      PolygonBox[{{-5.5, -0.9193213332412997}, {-5.5, -0.7940909947171011}, \
{-5.4375, -0.9998768219370047}, {-5.5, -0.9193213332412997}}], 
      PolygonBox[{{-5.4375, -0.9998768219370047}, {-5.437499981032941, \
-1.084292589556055}, {-5.5, -0.9193213332412997}, {-5.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-5.5, -1.2059090051452785`}, {-5.5, -0.9193213332412997}, \
{-5.437499981032941, -1.084292589556055}, {-5.5, -1.2059090051452785`}}], 
      PolygonBox[{{-5.437499981032941, -1.084292589556055}, \
{-5.437344993353523, -1.2302516425362549`}, {-5.5, -1.2059090051452785`}, \
{-5.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-5.5, -1.3576627826493652`}, {-5.5, -1.2059090051452785`}, \
{-5.437344993353523, -1.2302516425362549`}, {-5.5, -1.3576627826493652`}}], 
      PolygonBox[{{-5.437344993353523, -1.2302516425362549`}, \
{-5.404942744332997, -1.4049427443329972`}, {-5.5, -1.3576627826493652`}, \
{-5.437344993353523, -1.2302516425362549`}}], 
      PolygonBox[{{-5.5, -0.5}, {-5.5, -1.3576627826493652`}, \
{-5.404942744332997, -1.4049427443329972`}, {-5.5, -0.5}}], 
      PolygonBox[{{-5.404942744332997, -1.4049427443329972`}, \
{-5.230251642536255, -1.4373449933535234`}, {-5.5, -0.5}, \
{-5.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-5.5, -1.5}, {-5.5, -0.5}, {-5.230251642536255, \
-1.4373449933535234`}, {-5.5, -1.5}}], 
      PolygonBox[{{-5.230251642536255, -1.4373449933535234`}, \
{-5.084292589556064, -1.4374999810329407`}, {-5.5, -1.5}, \
{-5.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-5.205909005566828, -1.5}, {-5.5, -1.5}, \
{-5.084292589556064, -1.4374999810329407`}, {-5.205909005566828, -1.5}}], 
      PolygonBox[{{-5.084292589556064, -1.4374999810329407`}, \
{-4.999865158168957, -1.4375}, {-5.205909005566828, -1.5}, \
{-5.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-4.917676129598938, -1.5}, {-5.205909005566828, -1.5}, \
{-4.999865158168957, -1.4375}, {-4.917676129598938, -1.5}}], 
      PolygonBox[{{-4.999865158168957, -1.4375}, {-4.915707410443947, \
-1.4374999810329407`}, {-4.917676129598938, -1.5}, {-4.999865158168957, \
-1.4375}}], 
      PolygonBox[{{-4.794090994639602, -1.5}, {-4.917676129598938, -1.5}, \
{-4.915707410443947, -1.4374999810329407`}, {-4.794090994639602, -1.5}}], 
      PolygonBox[{{-4.915707410443947, -1.4374999810329407`}, \
{-4.769748357463746, -1.4373449933535234`}, {-4.794090994639602, -1.5}, \
{-4.915707410443947, -1.4374999810329407`}}], 
      PolygonBox[{{-4.6423372173506285`, -1.5}, {-4.794090994639602, -1.5}, \
{-4.769748357463746, -1.4373449933535234`}, {-4.6423372173506285`, -1.5}}], 
      PolygonBox[{{-4.769748357463746, -1.4373449933535234`}, \
{-4.595057255667003, -1.4049427443329972`}, {-4.6423372173506285`, -1.5}, \
{-4.769748357463746, -1.4373449933535234`}}], 
      PolygonBox[{{-4.5, -1.5}, {-4.6423372173506285`, -1.5}, \
{-4.595057255667003, -1.4049427443329972`}, {-4.5, -1.5}}], 
      PolygonBox[{{-4.595057255667003, -1.4049427443329972`}, \
{-4.595057255667003, -1.4049427443329972`}, {-4.5, -1.5}, \
{-4.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-4.5, -1.5}, {-4.5, -1.5}, {-4.595057255667003, \
-1.4049427443329972`}, {-4.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, 0.}, {-5.479166666666667, 0.}, {-5.458333333333333, 
       0.}, {-5.4375, 0.}, {-5.416666666666667, 0.}, {-5.395833333333333, 
       0.}, {-5.375, 0.}, {-5.375, 0.}, {-5.395833333333333, 
       0.}, {-5.416666666666667, 0.}, {-5.4375, 0.}, {-5.458333333333333, 
       0.}, {-5.479166666666667, 0.}, {-5.5, 0.}, {-5.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, 0.}, {-4.604166666666667, 0.}, {-4.583333333333333, 
       0.}, {-4.5625, 0.}, {-4.541666666666667, 0.}, {-4.520833333333333, 
       0.}, {-4.5, 0.}, {-4.5, 0.}, {-4.520833333333333, 
       0.}, {-4.541666666666667, 0.}, {-4.5625, 0.}, {-4.583333333333333, 
       0.}, {-4.604166666666667, 0.}, {-4.625, 0.}, {-4.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -0.5}, {-5., -0.4791666666666667}, {-5., \
-0.4583333333333333}, {-5., -0.4375}, {-5., -0.4166666666666667}, {-5., \
-0.39583333333333337`}, {-5., -0.375}, {-5., -0.375}, {-5., \
-0.3958333333333333}, {-5., -0.4166666666666667}, {-5., -0.4375}, {-5., \
-0.4583333333333333}, {-5., -0.47916666666666663`}, {-5., -0.5}, {-5., \
-0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 0.375}, {-5., 0.3958333333333333}, {-5., 
       0.4166666666666667}, {-5., 0.4375}, {-5., 0.4583333333333333}, {-5., 
       0.47916666666666663`}, {-5., 0.5}, {-5., 0.5}, {-5., 
       0.4791666666666667}, {-5., 0.4583333333333333}, {-5., 0.4375}, {-5., 
       0.4166666666666667}, {-5., 0.39583333333333337`}, {-5., 0.375}, {-5., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, 0.}, {-5.25, 0.}, {-5.125, 0.}, {-5., 0.}, {-4.875, 
       0.}, {-4.75, 0.}, {-4.625, 0.}, {-4.625, 0.}, {-4.75, 0.}, {-4.875, 
       0.}, {-5., 0.}, {-5.125, 0.}, {-5.25, 0.}, {-5.375, 0.}, {-5.375, 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -0.375}, {-5., -0.25}, {-5., -0.125}, {-5., 0.}, {-5., 
       0.125}, {-5., 0.25}, {-5., 0.375}, {-5., 0.375}, {-5., 0.25}, {-5., 
       0.125}, {-5., 
       0.}, {-5., -0.125}, {-5., -0.25}, {-5., -0.375}, {-5., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgdgTO7pKxaI9goduNEZs2jPjR32GXekbYs2
Cx34DwbH7Y04jSZXfBA6cDPn/pmyHxfswZochA80WDrp3Tlxxf5mbxnv3DnC
B/z7y74u1bsOkWcQgZp/w169qPNTUrLIgQBk+QMicP3nvp3NaecXPXALav4M
5SeHen1ED7CAFZ6w/5oRHv+qSPTAA6j7IO4XPcDVNc/HsrLLBiZ/DiK/H6b/
D8T9+2HmX4eYvx9mfx3E/v0aUPf5Qdy3H839+2H+C0CWB/q/CaofFj5Q9++H
hR8bxP37YeH7Duo+WPhD3D9rDwA7orG/
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByD0A/vVq0AAwQ8FA2E4H0KLoKkXQVMviqZe
jCA/DKzvKhr/KJp6GBA7EAKR34/Kv7ofVf0DDD6a+/ajuX8/mv/2o/l/P1r4
QNUT5oehuA/GP4qmHgaEYP6zR+VftUdV/8AeAKdpY+A=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, -0.2651650429449553}, \
{-4.6752404735808355`, -0.1875}, {-4.595057255667003, -0.4049427443329971}, \
{-4.734834957055044, -0.2651650429449553}}], 
      PolygonBox[{{-4.562655006646477, -0.23025164253625516`}, \
{-4.595057255667003, -0.4049427443329971}, {-4.6752404735808355`, -0.1875}, \
{-4.562655006646477, -0.23025164253625516`}}], 
      PolygonBox[{{-4.6752404735808355`, -0.1875}, {-4.637777815141599, \
-0.0970571419134453}, {-4.562655006646477, -0.23025164253625516`}, \
{-4.6752404735808355`, -0.1875}}], 
      PolygonBox[{{-4.562500018967059, -0.08429258955606181}, \
{-4.562655006646477, -0.23025164253625516`}, {-4.637777815141599, \
-0.0970571419134453}, {-4.562500018967059, -0.08429258955606181}}], 
      PolygonBox[{{-4.637777815141599, -0.0970571419134453}, {-4.625, 
       0.}, {-4.562500018967059, -0.08429258955606181}, {-4.637777815141599, \
-0.0970571419134453}}], 
      PolygonBox[{{-4.5625, 
       0.}, {-4.562500018967059, -0.08429258955606181}, {-4.625, 
       0.}, {-4.5625, 0.}}], 
      PolygonBox[{{-4.625, 0.}, {-4.637777815141599, 
       0.09705714191344525}, {-4.5625, 0.}, {-4.625, 0.}}], 
      PolygonBox[{{-4.562500018967059, 0.08429258955606177}, {-4.5625, 
       0.}, {-4.637777815141599, 0.09705714191344525}, {-4.562500018967059, 
       0.08429258955606177}}], 
      PolygonBox[{{-4.637777815141599, 
       0.09705714191344525}, {-4.6752404735808355`, 
       0.18749999999999994`}, {-4.562500018967059, 
       0.08429258955606177}, {-4.637777815141599, 0.09705714191344525}}], 
      PolygonBox[{{-4.562655006646477, 
       0.23025164253625502`}, {-4.562500018967059, 
       0.08429258955606177}, {-4.6752404735808355`, 
       0.18749999999999994`}, {-4.562655006646477, 0.23025164253625502`}}], 
      PolygonBox[{{-4.6752404735808355`, 
       0.18749999999999994`}, {-4.734834957055044, 
       0.2651650429449553}, {-4.562655006646477, 
       0.23025164253625502`}, {-4.6752404735808355`, 0.18749999999999994`}}], 
      PolygonBox[{{-4.595057255667003, 
       0.40494274433299715`}, {-4.562655006646477, 
       0.23025164253625502`}, {-4.734834957055044, 
       0.2651650429449553}, {-4.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{-4.734834957055044, 0.2651650429449553}, {-4.8125, 
       0.3247595264191645}, {-4.595057255667003, 
       0.40494274433299715`}, {-4.734834957055044, 0.2651650429449553}}], 
      PolygonBox[{{-4.769748357463745, 
       0.4373449933535234}, {-4.595057255667003, 
       0.40494274433299715`}, {-4.8125, 
       0.3247595264191645}, {-4.769748357463745, 0.4373449933535234}}], 
      PolygonBox[{{-4.8125, 0.3247595264191645}, {-4.902942858086555, 
       0.3622221848584006}, {-4.769748357463745, 
       0.4373449933535234}, {-4.8125, 0.3247595264191645}}], 
      PolygonBox[{{-4.9157074104439396`, 
       0.4374999810329408}, {-4.769748357463745, 
       0.4373449933535234}, {-4.902942858086555, 
       0.3622221848584006}, {-4.9157074104439396`, 0.4374999810329408}}], 
      PolygonBox[{{-4.902942858086555, 0.3622221848584006}, {-5., 
       0.375}, {-4.9157074104439396`, 
       0.4374999810329408}, {-4.902942858086555, 0.3622221848584006}}], 
      PolygonBox[{{-4.999894472779513, 0.4375}, {-4.9157074104439396`, 
       0.4374999810329408}, {-5., 0.375}, {-4.999894472779513, 0.4375}}], 
      PolygonBox[{{-5., 0.375}, {-5.097057141913445, 
       0.36222218485840063`}, {-4.999894472779513, 0.4375}, {-5., 0.375}}], 
      PolygonBox[{{-5.084292589556057, 
       0.4374999810329408}, {-4.999894472779513, 0.4375}, {-5.097057141913445,
        0.36222218485840063`}, {-5.084292589556057, 0.4374999810329408}}], 
      PolygonBox[{{-5.097057141913445, 0.36222218485840063`}, {-5.1875, 
       0.3247595264191645}, {-5.084292589556057, 
       0.4374999810329408}, {-5.097057141913445, 0.36222218485840063`}}], 
      PolygonBox[{{-5.230251642536255, 
       0.4373449933535234}, {-5.084292589556057, 
       0.4374999810329408}, {-5.1875, 
       0.3247595264191645}, {-5.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{-5.1875, 0.3247595264191645}, {-5.265165042944956, 
       0.26516504294495535`}, {-5.230251642536255, 
       0.4373449933535234}, {-5.1875, 0.3247595264191645}}], 
      PolygonBox[{{-5.404942744332997, 
       0.40494274433299715`}, {-5.230251642536255, 
       0.4373449933535234}, {-5.265165042944956, 
       0.26516504294495535`}, {-5.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{-5.265165042944956, 
       0.26516504294495535`}, {-5.3247595264191645`, 
       0.1875000000000001}, {-5.404942744332997, 
       0.40494274433299715`}, {-5.265165042944956, 0.26516504294495535`}}], 
      PolygonBox[{{-5.437344993353523, 
       0.2302516425362554}, {-5.404942744332997, 
       0.40494274433299715`}, {-5.3247595264191645`, 
       0.1875000000000001}, {-5.437344993353523, 0.2302516425362554}}], 
      PolygonBox[{{-5.3247595264191645`, 
       0.1875000000000001}, {-5.362222184858401, 
       0.09705714191344539}, {-5.437344993353523, 
       0.2302516425362554}, {-5.3247595264191645`, 0.1875000000000001}}], 
      PolygonBox[{{-5.437499981032941, 
       0.08429258955606238}, {-5.437344993353523, 
       0.2302516425362554}, {-5.362222184858401, 
       0.09705714191344539}, {-5.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-5.362222184858401, 0.09705714191344539}, {-5.375, 
       2.1245770866179924`*^-16}, {-5.437499981032941, 
       0.08429258955606238}, {-5.362222184858401, 0.09705714191344539}}], 
      PolygonBox[{{-5.4375, 0.00012317806299537147`}, {-5.437499981032941, 
       0.08429258955606238}, {-5.375, 2.1245770866179924`*^-16}, {-5.4375, 
       0.00012317806299537147`}}], 
      PolygonBox[{{-5.375, 
       2.1245770866179924`*^-16}, {-5.362222184858401, -0.09705714191344514}, \
{-5.4375, 0.00012317806299537147`}, {-5.375, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{-5.437499981032941, -0.084292589556055}, {-5.4375, 
       0.00012317806299537147`}, {-5.362222184858401, -0.09705714191344514}, \
{-5.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-5.362222184858401, -0.09705714191344514}, \
{-5.3247595264191645`, -0.18749999999999978`}, {-5.437499981032941, \
-0.084292589556055}, {-5.362222184858401, -0.09705714191344514}}], 
      PolygonBox[{{-5.437344993353523, -0.23025164253625477`}, \
{-5.437499981032941, -0.084292589556055}, {-5.3247595264191645`, \
-0.18749999999999978`}, {-5.437344993353523, -0.23025164253625477`}}], 
      PolygonBox[{{-5.3247595264191645`, -0.18749999999999978`}, \
{-5.265165042944956, -0.2651650429449553}, {-5.437344993353523, \
-0.23025164253625477`}, {-5.3247595264191645`, -0.18749999999999978`}}], 
      PolygonBox[{{-5.404942744332997, -0.4049427443329971}, \
{-5.437344993353523, -0.23025164253625477`}, {-5.265165042944956, \
-0.2651650429449553}, {-5.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-5.265165042944956, -0.2651650429449553}, {-5.1875, \
-0.3247595264191644}, {-5.404942744332997, -0.4049427443329971}, \
{-5.265165042944956, -0.2651650429449553}}], 
      PolygonBox[{{-5.230251642536255, -0.4373449933535234}, \
{-5.404942744332997, -0.4049427443329971}, {-5.1875, -0.3247595264191644}, \
{-5.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{-5.1875, -0.3247595264191644}, {-5.097057141913446, \
-0.3622221848584005}, {-5.230251642536255, -0.4373449933535234}, {-5.1875, \
-0.3247595264191644}}], 
      PolygonBox[{{-5.084292589556064, -0.4374999810329408}, \
{-5.230251642536255, -0.4373449933535234}, {-5.097057141913446, \
-0.3622221848584005}, {-5.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-5.097057141913446, -0.3622221848584005}, {-5., -0.375}, \
{-5.084292589556064, -0.4374999810329408}, {-5.097057141913446, \
-0.3622221848584005}}], 
      PolygonBox[{{-4.999865158168957, -0.4375}, {-5.084292589556064, \
-0.4374999810329408}, {-5., -0.375}, {-4.999865158168957, -0.4375}}], 
      PolygonBox[{{-5., -0.375}, {-4.902942858086555, -0.36222218485840063`}, \
{-4.999865158168957, -0.4375}, {-5., -0.375}}], 
      PolygonBox[{{-4.915707410443947, -0.4374999810329408}, \
{-4.999865158168957, -0.4375}, {-4.902942858086555, -0.36222218485840063`}, \
{-4.915707410443947, -0.4374999810329408}}], 
      PolygonBox[{{-4.902942858086555, -0.36222218485840063`}, {-4.8125, \
-0.3247595264191646}, {-4.915707410443947, -0.4374999810329408}, \
{-4.902942858086555, -0.36222218485840063`}}], 
      PolygonBox[{{-4.769748357463746, -0.4373449933535234}, \
{-4.915707410443947, -0.4374999810329408}, {-4.8125, -0.3247595264191646}, \
{-4.769748357463746, -0.4373449933535234}}], 
      PolygonBox[{{-4.8125, -0.3247595264191646}, {-4.734834957055044, \
-0.26516504294495535`}, {-4.769748357463746, -0.4373449933535234}, {-4.8125, \
-0.3247595264191646}}], 
      PolygonBox[{{-4.595057255667003, -0.40494274433299715`}, \
{-4.769748357463746, -0.4373449933535234}, {-4.734834957055044, \
-0.26516504294495535`}, {-4.595057255667003, -0.40494274433299715`}}], 
      PolygonBox[{{-4.734834957055044, -0.26516504294495535`}, \
{-4.734834957055044, -0.2651650429449553}, {-4.595057255667003, \
-0.40494274433299715`}, {-4.734834957055044, -0.26516504294495535`}}], 
      PolygonBox[{{-4.595057255667003, -0.4049427443329971}, \
{-4.595057255667003, -0.40494274433299715`}, {-4.734834957055044, \
-0.2651650429449553}, {-4.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{-4.595057255667003, -0.4049427443329971}, \
{-4.562655006646477, -0.23025164253625516`}, {-4.5, -0.5}, \
{-4.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{-4.5, -0.3576627826493677}, {-4.5, -0.5}, \
{-4.562655006646477, -0.23025164253625516`}, {-4.5, -0.3576627826493677}}], 
      PolygonBox[{{-4.562655006646477, -0.23025164253625516`}, \
{-4.562500018967059, -0.08429258955606181}, {-4.5, -0.3576627826493677}, \
{-4.562655006646477, -0.23025164253625516`}}], 
      PolygonBox[{{-4.5, -0.20590900530173997`}, {-4.5, -0.3576627826493677}, \
{-4.562500018967059, -0.08429258955606181}, {-4.5, -0.20590900530173997`}}], 
      PolygonBox[{{-4.562500018967059, -0.08429258955606181}, {-4.5625, 
       0.}, {-4.5, -0.20590900530173997`}, {-4.562500018967059, \
-0.08429258955606181}}], 
      PolygonBox[{{-4.5, 0.}, {-4.5, -0.20590900530173997`}, {-4.5625, 
       0.}, {-4.5, 0.}}], 
      PolygonBox[{{-4.5625, 0.}, {-4.562500018967059, 
       0.08429258955606177}, {-4.5, 0.}, {-4.5625, 0.}}], 
      PolygonBox[{{-4.5, 0.20590900530173992`}, {-4.5, 
       0.}, {-4.562500018967059, 0.08429258955606177}, {-4.5, 
       0.20590900530173992`}}], 
      PolygonBox[{{-4.562500018967059, 
       0.08429258955606177}, {-4.562655006646477, 
       0.23025164253625502`}, {-4.5, 
       0.20590900530173992`}, {-4.562500018967059, 0.08429258955606177}}], 
      PolygonBox[{{-4.5, 0.35766278264936757`}, {-4.5, 
       0.20590900530173992`}, {-4.562655006646477, 
       0.23025164253625502`}, {-4.5, 0.35766278264936757`}}], 
      PolygonBox[{{-4.562655006646477, 
       0.23025164253625502`}, {-4.595057255667003, 
       0.40494274433299715`}, {-4.5, 
       0.35766278264936757`}, {-4.562655006646477, 0.23025164253625502`}}], 
      PolygonBox[{{-4.508553435038814, 0.491446564961186}, {-4.5, 
       0.35766278264936757`}, {-4.595057255667003, 
       0.40494274433299715`}, {-4.508553435038814, 0.491446564961186}}], 
      PolygonBox[{{-4.595057255667003, 
       0.40494274433299715`}, {-4.769748357463745, 
       0.4373449933535234}, {-4.508553435038814, 
       0.491446564961186}, {-4.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{-4.642337217350632, 0.5}, {-4.508553435038814, 
       0.491446564961186}, {-4.769748357463745, 
       0.4373449933535234}, {-4.642337217350632, 0.5}}], 
      PolygonBox[{{-4.769748357463745, 
       0.4373449933535234}, {-4.9157074104439396`, 
       0.4374999810329408}, {-4.642337217350632, 0.5}, {-4.769748357463745, 
       0.4373449933535234}}], 
      PolygonBox[{{-4.794090994626744, 0.5}, {-4.642337217350632, 
       0.5}, {-4.9157074104439396`, 0.4374999810329408}, {-4.794090994626744, 
       0.5}}], PolygonBox[{{-4.9157074104439396`, 
       0.4374999810329408}, {-4.999894472779513, 0.4375}, {-4.794090994626744,
        0.5}, {-4.9157074104439396`, 0.4374999810329408}}], 
      PolygonBox[{{-4.92205804197311, 0.5}, {-4.794090994626744, 
       0.5}, {-4.999894472779513, 0.4375}, {-4.92205804197311, 0.5}}], 
      PolygonBox[{{-4.999894472779513, 0.4375}, {-5.084292589556057, 
       0.4374999810329408}, {-4.92205804197311, 0.5}, {-4.999894472779513, 
       0.4375}}], 
      PolygonBox[{{-5.205909005304446, 0.5}, {-4.92205804197311, 
       0.5}, {-5.084292589556057, 0.4374999810329408}, {-5.205909005304446, 
       0.5}}], PolygonBox[{{-5.084292589556057, 
       0.4374999810329408}, {-5.230251642536255, 
       0.4373449933535234}, {-5.205909005304446, 0.5}, {-5.084292589556057, 
       0.4374999810329408}}], 
      PolygonBox[{{-5.357662782649366, 0.5}, {-5.205909005304446, 
       0.5}, {-5.230251642536255, 0.4373449933535234}, {-5.357662782649366, 
       0.5}}], PolygonBox[{{-5.230251642536255, 
       0.4373449933535234}, {-5.404942744332997, 
       0.40494274433299715`}, {-5.357662782649366, 0.5}, {-5.230251642536255, 
       0.4373449933535234}}], 
      PolygonBox[{{-4.5, 0.5}, {-5.357662782649366, 0.5}, {-5.404942744332997,
        0.40494274433299715`}, {-4.5, 0.5}}], 
      PolygonBox[{{-5.404942744332997, 
       0.40494274433299715`}, {-5.437344993353523, 0.2302516425362554}, {-4.5,
        0.5}, {-5.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{-5.5, 0.357662782649369}, {-4.5, 0.5}, {-5.437344993353523,
        0.2302516425362554}, {-5.5, 0.357662782649369}}], 
      PolygonBox[{{-5.437344993353523, 
       0.2302516425362554}, {-5.437499981032941, 0.08429258955606238}, {-5.5, 
       0.357662782649369}, {-5.437344993353523, 0.2302516425362554}}], 
      PolygonBox[{{-5.5, 0.20590900528289896`}, {-5.5, 
       0.357662782649369}, {-5.437499981032941, 0.08429258955606238}, {-5.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{-5.437499981032941, 0.08429258955606238}, {-5.4375, 
       0.00012317806299537147`}, {-5.5, 
       0.20590900528289896`}, {-5.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-5.5, 0.08067866675870025}, {-5.5, 
       0.20590900528289896`}, {-5.4375, 0.00012317806299537147`}, {-5.5, 
       0.08067866675870025}}], 
      PolygonBox[{{-5.4375, 
       0.00012317806299537147`}, {-5.437499981032941, -0.084292589556055}, \
{-5.5, 0.08067866675870025}, {-5.4375, 0.00012317806299537147`}}], 
      PolygonBox[{{-5.5, -0.20590900514527852`}, {-5.5, 
       0.08067866675870025}, {-5.437499981032941, -0.084292589556055}, {-5.5, \
-0.20590900514527852`}}], 
      PolygonBox[{{-5.437499981032941, -0.084292589556055}, \
{-5.437344993353523, -0.23025164253625477`}, {-5.5, -0.20590900514527852`}, \
{-5.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-5.5, -0.35766278264936535`}, {-5.5, \
-0.20590900514527852`}, {-5.437344993353523, -0.23025164253625477`}, {-5.5, \
-0.35766278264936535`}}], 
      PolygonBox[{{-5.437344993353523, -0.23025164253625477`}, \
{-5.404942744332997, -0.4049427443329971}, {-5.5, -0.35766278264936535`}, \
{-5.437344993353523, -0.23025164253625477`}}], 
      PolygonBox[{{-5.5, 
       0.5}, {-5.5, -0.35766278264936535`}, {-5.404942744332997, \
-0.4049427443329971}, {-5.5, 0.5}}], 
      PolygonBox[{{-5.404942744332997, -0.4049427443329971}, \
{-5.230251642536255, -0.4373449933535234}, {-5.5, 
       0.5}, {-5.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-5.5, -0.5}, {-5.5, 
       0.5}, {-5.230251642536255, -0.4373449933535234}, {-5.5, -0.5}}], 
      PolygonBox[{{-5.230251642536255, -0.4373449933535234}, \
{-5.084292589556064, -0.4374999810329408}, {-5.5, -0.5}, {-5.230251642536255, \
-0.4373449933535234}}], 
      PolygonBox[{{-5.205909005566828, -0.5}, {-5.5, -0.5}, \
{-5.084292589556064, -0.4374999810329408}, {-5.205909005566828, -0.5}}], 
      PolygonBox[{{-5.084292589556064, -0.4374999810329408}, \
{-4.999865158168957, -0.4375}, {-5.205909005566828, -0.5}, \
{-5.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-4.917676129598938, -0.5}, {-5.205909005566828, -0.5}, \
{-4.999865158168957, -0.4375}, {-4.917676129598938, -0.5}}], 
      PolygonBox[{{-4.999865158168957, -0.4375}, {-4.915707410443947, \
-0.4374999810329408}, {-4.917676129598938, -0.5}, {-4.999865158168957, \
-0.4375}}], 
      PolygonBox[{{-4.794090994639602, -0.5}, {-4.917676129598938, -0.5}, \
{-4.915707410443947, -0.4374999810329408}, {-4.794090994639602, -0.5}}], 
      PolygonBox[{{-4.915707410443947, -0.4374999810329408}, \
{-4.769748357463746, -0.4373449933535234}, {-4.794090994639602, -0.5}, \
{-4.915707410443947, -0.4374999810329408}}], 
      PolygonBox[{{-4.6423372173506285`, -0.5}, {-4.794090994639602, -0.5}, \
{-4.769748357463746, -0.4373449933535234}, {-4.6423372173506285`, -0.5}}], 
      PolygonBox[{{-4.769748357463746, -0.4373449933535234}, \
{-4.595057255667003, -0.40494274433299715`}, {-4.6423372173506285`, -0.5}, \
{-4.769748357463746, -0.4373449933535234}}], 
      PolygonBox[{{-4.5, -0.5}, {-4.6423372173506285`, -0.5}, \
{-4.595057255667003, -0.40494274433299715`}, {-4.5, -0.5}}], 
      PolygonBox[{{-4.595057255667003, -0.40494274433299715`}, \
{-4.595057255667003, -0.4049427443329971}, {-4.5, -0.5}, {-4.595057255667003, \
-0.40494274433299715`}}], 
      PolygonBox[{{-4.5, -0.5}, {-4.5, -0.5}, {-4.595057255667003, \
-0.4049427443329971}, {-4.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, 1.}, {-5.479166666666667, 1.}, {-5.458333333333333, 
       1.}, {-5.4375, 1.}, {-5.416666666666667, 1.}, {-5.395833333333333, 
       1.}, {-5.375, 1.}, {-5.375, 1.}, {-5.395833333333333, 
       1.}, {-5.416666666666667, 1.}, {-5.4375, 1.}, {-5.458333333333333, 
       1.}, {-5.479166666666667, 1.}, {-5.5, 1.}, {-5.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, 1.}, {-4.604166666666667, 1.}, {-4.583333333333333, 
       1.}, {-4.5625, 1.}, {-4.541666666666667, 1.}, {-4.520833333333333, 
       1.}, {-4.5, 1.}, {-4.5, 1.}, {-4.520833333333333, 
       1.}, {-4.541666666666667, 1.}, {-4.5625, 1.}, {-4.583333333333333, 
       1.}, {-4.604166666666667, 1.}, {-4.625, 1.}, {-4.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 0.5}, {-5., 0.5208333333333333}, {-5., 
       0.5416666666666667}, {-5., 0.5625}, {-5., 0.5833333333333333}, {-5., 
       0.6041666666666666}, {-5., 0.625}, {-5., 0.625}, {-5., 
       0.6041666666666667}, {-5., 0.5833333333333333}, {-5., 0.5625}, {-5., 
       0.5416666666666667}, {-5., 0.5208333333333334}, {-5., 0.5}, {-5., 
       0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 1.375}, {-5., 1.3958333333333333`}, {-5., 
       1.4166666666666667`}, {-5., 1.4375}, {-5., 1.4583333333333333`}, {-5., 
       1.4791666666666665`}, {-5., 1.5}, {-5., 1.5}, {-5., 
       1.4791666666666667`}, {-5., 1.4583333333333333`}, {-5., 1.4375}, {-5., 
       1.4166666666666667`}, {-5., 1.3958333333333335`}, {-5., 1.375}, {-5., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, 1.}, {-5.25, 1.}, {-5.125, 1.}, {-5., 1.}, {-4.875, 
       1.}, {-4.75, 1.}, {-4.625, 1.}, {-4.625, 1.}, {-4.75, 1.}, {-4.875, 
       1.}, {-5., 1.}, {-5.125, 1.}, {-5.25, 1.}, {-5.375, 1.}, {-5.375, 
       1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 0.625}, {-5., 0.75}, {-5., 0.875}, {-5., 1.}, {-5., 
       1.125}, {-5., 1.25}, {-5., 1.375}, {-5., 1.375}, {-5., 1.25}, {-5., 
       1.125}, {-5., 1.}, {-5., 0.875}, {-5., 0.75}, {-5., 0.625}, {-5., 
       0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgjA/23NNXLBDtFTow74Tqqe7ej/YZd6Rt
izbD5D/bG3EaTa74IHTA7Lb5Zlm7L/ZgYQfhAwl9E7jNjb7a3+wt4507R/jA
lcWxtStPf4XIM4hA9X+zVy/q/JSULIIqf0AErv/ct7M57fyicPNnKD851Osj
Crf/a0Z4/KsiUbj7IO6HyX+Ayx/L25L94skbuH5GsPwruPlTPCfMPNL8HG6/
4+N7LybOfmqvAXVf5A4X1rUZT9Dc/wTuvwhkeaD/7aH6YeEzGWo+LPz+/QeB
l/DwPQR1Hyz8wdL/39sDACACpeg=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByD0D/vVq0AAwQ8FA2E4H0KLoKkXQVMviqZe
jCA/DKzvK5wPMfcTmvoPaPKv0PQ/RVP/AIOP6r4HaO5/gOa/B2j+f4AWPjD1
hPmhKO4TOrAKxf0w9R/Q5D+h6f+Kpv6HPQD6z2mW
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, 
       0.7348349570550448}, {-4.6752404735808355`, 
       0.8125}, {-4.595057255667003, 0.5950572556670028}, {-4.734834957055044,
        0.7348349570550448}}], 
      PolygonBox[{{-4.562655006646477, 
       0.7697483574637448}, {-4.595057255667003, 
       0.5950572556670028}, {-4.6752404735808355`, 
       0.8125}, {-4.562655006646477, 0.7697483574637448}}], 
      PolygonBox[{{-4.6752404735808355`, 0.8125}, {-4.637777815141599, 
       0.9029428580865547}, {-4.562655006646477, 
       0.7697483574637448}, {-4.6752404735808355`, 0.8125}}], 
      PolygonBox[{{-4.562500018967059, 
       0.9157074104439382}, {-4.562655006646477, 
       0.7697483574637448}, {-4.637777815141599, 
       0.9029428580865547}, {-4.562500018967059, 0.9157074104439382}}], 
      PolygonBox[{{-4.637777815141599, 0.9029428580865547}, {-4.625, 
       1.}, {-4.562500018967059, 0.9157074104439382}, {-4.637777815141599, 
       0.9029428580865547}}], 
      PolygonBox[{{-4.5625, 1.}, {-4.562500018967059, 
       0.9157074104439382}, {-4.625, 1.}, {-4.5625, 1.}}], 
      PolygonBox[{{-4.625, 1.}, {-4.637777815141599, 
       1.0970571419134452`}, {-4.5625, 1.}, {-4.625, 1.}}], 
      PolygonBox[{{-4.562500018967059, 1.0842925895560618`}, {-4.5625, 
       1.}, {-4.637777815141599, 1.0970571419134452`}, {-4.562500018967059, 
       1.0842925895560618`}}], 
      PolygonBox[{{-4.637777815141599, 
       1.0970571419134452`}, {-4.6752404735808355`, 
       1.1875}, {-4.562500018967059, 
       1.0842925895560618`}, {-4.637777815141599, 1.0970571419134452`}}], 
      PolygonBox[{{-4.562655006646477, 
       1.230251642536255}, {-4.562500018967059, 
       1.0842925895560618`}, {-4.6752404735808355`, 
       1.1875}, {-4.562655006646477, 1.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, 1.1875}, {-4.734834957055044, 
       1.2651650429449552`}, {-4.562655006646477, 
       1.230251642536255}, {-4.6752404735808355`, 1.1875}}], 
      PolygonBox[{{-4.595057255667003, 
       1.4049427443329972`}, {-4.562655006646477, 
       1.230251642536255}, {-4.734834957055044, 
       1.2651650429449552`}, {-4.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{-4.734834957055044, 1.2651650429449552`}, {-4.8125, 
       1.3247595264191645`}, {-4.595057255667003, 
       1.4049427443329972`}, {-4.734834957055044, 1.2651650429449552`}}], 
      PolygonBox[{{-4.769748357463745, 
       1.4373449933535234`}, {-4.595057255667003, 
       1.4049427443329972`}, {-4.8125, 
       1.3247595264191645`}, {-4.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{-4.8125, 1.3247595264191645`}, {-4.902942858086555, 
       1.3622221848584006`}, {-4.769748357463745, 
       1.4373449933535234`}, {-4.8125, 1.3247595264191645`}}], 
      PolygonBox[{{-4.9157074104439396`, 
       1.4374999810329407`}, {-4.769748357463745, 
       1.4373449933535234`}, {-4.902942858086555, 
       1.3622221848584006`}, {-4.9157074104439396`, 1.4374999810329407`}}], 
      PolygonBox[{{-4.902942858086555, 1.3622221848584006`}, {-5., 
       1.375}, {-4.9157074104439396`, 
       1.4374999810329407`}, {-4.902942858086555, 1.3622221848584006`}}], 
      PolygonBox[{{-4.999894472779513, 1.4375}, {-4.9157074104439396`, 
       1.4374999810329407`}, {-5., 1.375}, {-4.999894472779513, 1.4375}}], 
      PolygonBox[{{-5., 1.375}, {-5.097057141913445, 
       1.3622221848584006`}, {-4.999894472779513, 1.4375}, {-5., 1.375}}], 
      PolygonBox[{{-5.084292589556057, 
       1.4374999810329407`}, {-4.999894472779513, 
       1.4375}, {-5.097057141913445, 
       1.3622221848584006`}, {-5.084292589556057, 1.4374999810329407`}}], 
      PolygonBox[{{-5.097057141913445, 1.3622221848584006`}, {-5.1875, 
       1.3247595264191645`}, {-5.084292589556057, 
       1.4374999810329407`}, {-5.097057141913445, 1.3622221848584006`}}], 
      PolygonBox[{{-5.230251642536255, 
       1.4373449933535234`}, {-5.084292589556057, 
       1.4374999810329407`}, {-5.1875, 
       1.3247595264191645`}, {-5.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{-5.1875, 1.3247595264191645`}, {-5.265165042944956, 
       1.2651650429449552`}, {-5.230251642536255, 
       1.4373449933535234`}, {-5.1875, 1.3247595264191645`}}], 
      PolygonBox[{{-5.404942744332997, 
       1.4049427443329972`}, {-5.230251642536255, 
       1.4373449933535234`}, {-5.265165042944956, 
       1.2651650429449552`}, {-5.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{-5.265165042944956, 
       1.2651650429449552`}, {-5.3247595264191645`, 
       1.1875}, {-5.404942744332997, 
       1.4049427443329972`}, {-5.265165042944956, 1.2651650429449552`}}], 
      PolygonBox[{{-5.437344993353523, 
       1.2302516425362553`}, {-5.404942744332997, 
       1.4049427443329972`}, {-5.3247595264191645`, 
       1.1875}, {-5.437344993353523, 1.2302516425362553`}}], 
      PolygonBox[{{-5.3247595264191645`, 1.1875}, {-5.362222184858401, 
       1.0970571419134454`}, {-5.437344993353523, 
       1.2302516425362553`}, {-5.3247595264191645`, 1.1875}}], 
      PolygonBox[{{-5.437499981032941, 
       1.0842925895560624`}, {-5.437344993353523, 
       1.2302516425362553`}, {-5.362222184858401, 
       1.0970571419134454`}, {-5.437499981032941, 1.0842925895560624`}}], 
      PolygonBox[{{-5.362222184858401, 1.0970571419134454`}, {-5.375, 
       1.0000000000000002`}, {-5.437499981032941, 
       1.0842925895560624`}, {-5.362222184858401, 1.0970571419134454`}}], 
      PolygonBox[{{-5.4375, 1.0001231780629953`}, {-5.437499981032941, 
       1.0842925895560624`}, {-5.375, 1.0000000000000002`}, {-5.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-5.375, 1.0000000000000002`}, {-5.362222184858401, 
       0.9029428580865548}, {-5.4375, 1.0001231780629953`}, {-5.375, 
       1.0000000000000002`}}], 
      PolygonBox[{{-5.437499981032941, 0.915707410443945}, {-5.4375, 
       1.0001231780629953`}, {-5.362222184858401, 
       0.9029428580865548}, {-5.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-5.362222184858401, 
       0.9029428580865548}, {-5.3247595264191645`, 
       0.8125000000000002}, {-5.437499981032941, 
       0.915707410443945}, {-5.362222184858401, 0.9029428580865548}}], 
      PolygonBox[{{-5.437344993353523, 
       0.7697483574637453}, {-5.437499981032941, 
       0.915707410443945}, {-5.3247595264191645`, 
       0.8125000000000002}, {-5.437344993353523, 0.7697483574637453}}], 
      PolygonBox[{{-5.3247595264191645`, 
       0.8125000000000002}, {-5.265165042944956, 
       0.7348349570550448}, {-5.437344993353523, 
       0.7697483574637453}, {-5.3247595264191645`, 0.8125000000000002}}], 
      PolygonBox[{{-5.404942744332997, 
       0.5950572556670028}, {-5.437344993353523, 
       0.7697483574637453}, {-5.265165042944956, 
       0.7348349570550448}, {-5.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-5.265165042944956, 0.7348349570550448}, {-5.1875, 
       0.6752404735808356}, {-5.404942744332997, 
       0.5950572556670028}, {-5.265165042944956, 0.7348349570550448}}], 
      PolygonBox[{{-5.230251642536255, 
       0.5626550066464766}, {-5.404942744332997, 
       0.5950572556670028}, {-5.1875, 
       0.6752404735808356}, {-5.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-5.1875, 0.6752404735808356}, {-5.097057141913446, 
       0.6377778151415995}, {-5.230251642536255, 
       0.5626550066464766}, {-5.1875, 0.6752404735808356}}], 
      PolygonBox[{{-5.084292589556064, 
       0.5625000189670593}, {-5.230251642536255, 
       0.5626550066464766}, {-5.097057141913446, 
       0.6377778151415995}, {-5.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-5.097057141913446, 0.6377778151415995}, {-5., 
       0.625}, {-5.084292589556064, 0.5625000189670593}, {-5.097057141913446, 
       0.6377778151415995}}], 
      PolygonBox[{{-4.999865158168957, 0.5625}, {-5.084292589556064, 
       0.5625000189670593}, {-5., 0.625}, {-4.999865158168957, 0.5625}}], 
      PolygonBox[{{-5., 0.625}, {-4.902942858086555, 
       0.6377778151415994}, {-4.999865158168957, 0.5625}, {-5., 0.625}}], 
      PolygonBox[{{-4.915707410443947, 
       0.5625000189670593}, {-4.999865158168957, 0.5625}, {-4.902942858086555,
        0.6377778151415994}, {-4.915707410443947, 0.5625000189670593}}], 
      PolygonBox[{{-4.902942858086555, 0.6377778151415994}, {-4.8125, 
       0.6752404735808354}, {-4.915707410443947, 
       0.5625000189670593}, {-4.902942858086555, 0.6377778151415994}}], 
      PolygonBox[{{-4.769748357463746, 
       0.5626550066464766}, {-4.915707410443947, 
       0.5625000189670593}, {-4.8125, 
       0.6752404735808354}, {-4.769748357463746, 0.5626550066464766}}], 
      PolygonBox[{{-4.8125, 0.6752404735808354}, {-4.734834957055044, 
       0.7348349570550446}, {-4.769748357463746, 
       0.5626550066464766}, {-4.8125, 0.6752404735808354}}], 
      PolygonBox[{{-4.595057255667003, 
       0.5950572556670028}, {-4.769748357463746, 
       0.5626550066464766}, {-4.734834957055044, 
       0.7348349570550446}, {-4.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-4.734834957055044, 
       0.7348349570550446}, {-4.734834957055044, 
       0.7348349570550448}, {-4.595057255667003, 
       0.5950572556670028}, {-4.734834957055044, 0.7348349570550446}}], 
      PolygonBox[{{-4.595057255667003, 
       0.5950572556670028}, {-4.595057255667003, 
       0.5950572556670028}, {-4.734834957055044, 
       0.7348349570550448}, {-4.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-4.595057255667003, 
       0.5950572556670028}, {-4.562655006646477, 0.7697483574637448}, {-4.5, 
       0.5}, {-4.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-4.5, 0.6423372173506323}, {-4.5, 
       0.5}, {-4.562655006646477, 0.7697483574637448}, {-4.5, 
       0.6423372173506323}}], 
      PolygonBox[{{-4.562655006646477, 
       0.7697483574637448}, {-4.562500018967059, 0.9157074104439382}, {-4.5, 
       0.6423372173506323}, {-4.562655006646477, 0.7697483574637448}}], 
      PolygonBox[{{-4.5, 0.79409099469826}, {-4.5, 
       0.6423372173506323}, {-4.562500018967059, 0.9157074104439382}, {-4.5, 
       0.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, 0.9157074104439382}, {-4.5625, 
       1.}, {-4.5, 0.79409099469826}, {-4.562500018967059, 
       0.9157074104439382}}], 
      PolygonBox[{{-4.5, 1.}, {-4.5, 0.79409099469826}, {-4.5625, 1.}, {-4.5, 
       1.}}], PolygonBox[{{-4.5625, 1.}, {-4.562500018967059, 
       1.0842925895560618`}, {-4.5, 1.}, {-4.5625, 1.}}], 
      PolygonBox[{{-4.5, 1.2059090053017398`}, {-4.5, 
       1.}, {-4.562500018967059, 1.0842925895560618`}, {-4.5, 
       1.2059090053017398`}}], 
      PolygonBox[{{-4.562500018967059, 
       1.0842925895560618`}, {-4.562655006646477, 1.230251642536255}, {-4.5, 
       1.2059090053017398`}, {-4.562500018967059, 1.0842925895560618`}}], 
      PolygonBox[{{-4.5, 1.3576627826493675`}, {-4.5, 
       1.2059090053017398`}, {-4.562655006646477, 1.230251642536255}, {-4.5, 
       1.3576627826493675`}}], 
      PolygonBox[{{-4.562655006646477, 
       1.230251642536255}, {-4.595057255667003, 1.4049427443329972`}, {-4.5, 
       1.3576627826493675`}, {-4.562655006646477, 1.230251642536255}}], 
      PolygonBox[{{-4.508553435038814, 1.491446564961186}, {-4.5, 
       1.3576627826493675`}, {-4.595057255667003, 
       1.4049427443329972`}, {-4.508553435038814, 1.491446564961186}}], 
      PolygonBox[{{-4.595057255667003, 
       1.4049427443329972`}, {-4.769748357463745, 
       1.4373449933535234`}, {-4.508553435038814, 
       1.491446564961186}, {-4.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{-4.642337217350632, 1.5}, {-4.508553435038814, 
       1.491446564961186}, {-4.769748357463745, 
       1.4373449933535234`}, {-4.642337217350632, 1.5}}], 
      PolygonBox[{{-4.769748357463745, 
       1.4373449933535234`}, {-4.9157074104439396`, 
       1.4374999810329407`}, {-4.642337217350632, 1.5}, {-4.769748357463745, 
       1.4373449933535234`}}], 
      PolygonBox[{{-4.794090994626744, 1.5}, {-4.642337217350632, 
       1.5}, {-4.9157074104439396`, 1.4374999810329407`}, {-4.794090994626744,
        1.5}}], 
      PolygonBox[{{-4.9157074104439396`, 
       1.4374999810329407`}, {-4.999894472779513, 
       1.4375}, {-4.794090994626744, 1.5}, {-4.9157074104439396`, 
       1.4374999810329407`}}], 
      PolygonBox[{{-4.92205804197311, 1.5}, {-4.794090994626744, 
       1.5}, {-4.999894472779513, 1.4375}, {-4.92205804197311, 1.5}}], 
      PolygonBox[{{-4.999894472779513, 1.4375}, {-5.084292589556057, 
       1.4374999810329407`}, {-4.92205804197311, 1.5}, {-4.999894472779513, 
       1.4375}}], 
      PolygonBox[{{-5.205909005304446, 1.5}, {-4.92205804197311, 
       1.5}, {-5.084292589556057, 1.4374999810329407`}, {-5.205909005304446, 
       1.5}}], PolygonBox[{{-5.084292589556057, 
       1.4374999810329407`}, {-5.230251642536255, 
       1.4373449933535234`}, {-5.205909005304446, 1.5}, {-5.084292589556057, 
       1.4374999810329407`}}], 
      PolygonBox[{{-5.357662782649366, 1.5}, {-5.205909005304446, 
       1.5}, {-5.230251642536255, 1.4373449933535234`}, {-5.357662782649366, 
       1.5}}], PolygonBox[{{-5.230251642536255, 
       1.4373449933535234`}, {-5.404942744332997, 
       1.4049427443329972`}, {-5.357662782649366, 1.5}, {-5.230251642536255, 
       1.4373449933535234`}}], 
      PolygonBox[{{-4.5, 1.5}, {-5.357662782649366, 1.5}, {-5.404942744332997,
        1.4049427443329972`}, {-4.5, 1.5}}], 
      PolygonBox[{{-5.404942744332997, 
       1.4049427443329972`}, {-5.437344993353523, 1.2302516425362553`}, {-4.5,
        1.5}, {-5.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{-5.5, 1.357662782649369}, {-4.5, 1.5}, {-5.437344993353523,
        1.2302516425362553`}, {-5.5, 1.357662782649369}}], 
      PolygonBox[{{-5.437344993353523, 
       1.2302516425362553`}, {-5.437499981032941, 1.0842925895560624`}, {-5.5,
        1.357662782649369}, {-5.437344993353523, 1.2302516425362553`}}], 
      PolygonBox[{{-5.5, 1.205909005282899}, {-5.5, 
       1.357662782649369}, {-5.437499981032941, 1.0842925895560624`}, {-5.5, 
       1.205909005282899}}], 
      PolygonBox[{{-5.437499981032941, 1.0842925895560624`}, {-5.4375, 
       1.0001231780629953`}, {-5.5, 1.205909005282899}, {-5.437499981032941, 
       1.0842925895560624`}}], 
      PolygonBox[{{-5.5, 1.0806786667587003`}, {-5.5, 
       1.205909005282899}, {-5.4375, 1.0001231780629953`}, {-5.5, 
       1.0806786667587003`}}], 
      PolygonBox[{{-5.4375, 1.0001231780629953`}, {-5.437499981032941, 
       0.915707410443945}, {-5.5, 1.0806786667587003`}, {-5.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-5.5, 0.7940909948547215}, {-5.5, 
       1.0806786667587003`}, {-5.437499981032941, 0.915707410443945}, {-5.5, 
       0.7940909948547215}}], 
      PolygonBox[{{-5.437499981032941, 
       0.915707410443945}, {-5.437344993353523, 0.7697483574637453}, {-5.5, 
       0.7940909948547215}, {-5.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-5.5, 0.6423372173506346}, {-5.5, 
       0.7940909948547215}, {-5.437344993353523, 0.7697483574637453}, {-5.5, 
       0.6423372173506346}}], 
      PolygonBox[{{-5.437344993353523, 
       0.7697483574637453}, {-5.404942744332997, 0.5950572556670028}, {-5.5, 
       0.6423372173506346}, {-5.437344993353523, 0.7697483574637453}}], 
      PolygonBox[{{-5.5, 1.5}, {-5.5, 
       0.6423372173506346}, {-5.404942744332997, 0.5950572556670028}, {-5.5, 
       1.5}}], PolygonBox[{{-5.404942744332997, 
       0.5950572556670028}, {-5.230251642536255, 0.5626550066464766}, {-5.5, 
       1.5}, {-5.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-5.5, 0.5}, {-5.5, 1.5}, {-5.230251642536255, 
       0.5626550066464766}, {-5.5, 0.5}}], 
      PolygonBox[{{-5.230251642536255, 
       0.5626550066464766}, {-5.084292589556064, 0.5625000189670593}, {-5.5, 
       0.5}, {-5.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-5.205909005566828, 0.5}, {-5.5, 0.5}, {-5.084292589556064,
        0.5625000189670593}, {-5.205909005566828, 0.5}}], 
      PolygonBox[{{-5.084292589556064, 
       0.5625000189670593}, {-4.999865158168957, 0.5625}, {-5.205909005566828,
        0.5}, {-5.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-4.917676129598938, 0.5}, {-5.205909005566828, 
       0.5}, {-4.999865158168957, 0.5625}, {-4.917676129598938, 0.5}}], 
      PolygonBox[{{-4.999865158168957, 0.5625}, {-4.915707410443947, 
       0.5625000189670593}, {-4.917676129598938, 0.5}, {-4.999865158168957, 
       0.5625}}], 
      PolygonBox[{{-4.794090994639602, 0.5}, {-4.917676129598938, 
       0.5}, {-4.915707410443947, 0.5625000189670593}, {-4.794090994639602, 
       0.5}}], PolygonBox[{{-4.915707410443947, 
       0.5625000189670593}, {-4.769748357463746, 
       0.5626550066464766}, {-4.794090994639602, 0.5}, {-4.915707410443947, 
       0.5625000189670593}}], 
      PolygonBox[{{-4.6423372173506285`, 0.5}, {-4.794090994639602, 
       0.5}, {-4.769748357463746, 0.5626550066464766}, {-4.6423372173506285`, 
       0.5}}], PolygonBox[{{-4.769748357463746, 
       0.5626550066464766}, {-4.595057255667003, 
       0.5950572556670028}, {-4.6423372173506285`, 0.5}, {-4.769748357463746, 
       0.5626550066464766}}], 
      PolygonBox[{{-4.5, 0.5}, {-4.6423372173506285`, 
       0.5}, {-4.595057255667003, 0.5950572556670028}, {-4.5, 0.5}}], 
      PolygonBox[{{-4.595057255667003, 
       0.5950572556670028}, {-4.595057255667003, 0.5950572556670028}, {-4.5, 
       0.5}, {-4.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-4.5, 0.5}, {-4.5, 0.5}, {-4.595057255667003, 
       0.5950572556670028}, {-4.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, 2.}, {-5.479166666666667, 2.}, {-5.458333333333333, 
       2.}, {-5.4375, 2.}, {-5.416666666666667, 2.}, {-5.395833333333333, 
       2.}, {-5.375, 2.}, {-5.375, 2.}, {-5.395833333333333, 
       2.}, {-5.416666666666667, 2.}, {-5.4375, 2.}, {-5.458333333333333, 
       2.}, {-5.479166666666667, 2.}, {-5.5, 2.}, {-5.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, 2.}, {-4.604166666666667, 2.}, {-4.583333333333333, 
       2.}, {-4.5625, 2.}, {-4.541666666666667, 2.}, {-4.520833333333333, 
       2.}, {-4.5, 2.}, {-4.5, 2.}, {-4.520833333333333, 
       2.}, {-4.541666666666667, 2.}, {-4.5625, 2.}, {-4.583333333333333, 
       2.}, {-4.604166666666667, 2.}, {-4.625, 2.}, {-4.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 1.5}, {-5., 1.5208333333333333`}, {-5., 
       1.5416666666666667`}, {-5., 1.5625}, {-5., 1.5833333333333333`}, {-5., 
       1.6041666666666665`}, {-5., 1.625}, {-5., 1.625}, {-5., 
       1.6041666666666667`}, {-5., 1.5833333333333333`}, {-5., 1.5625}, {-5., 
       1.5416666666666667`}, {-5., 1.5208333333333335`}, {-5., 1.5}, {-5., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 2.375}, {-5., 2.3958333333333335`}, {-5., 
       2.4166666666666665`}, {-5., 2.4375}, {-5., 2.4583333333333335`}, {-5., 
       2.4791666666666665`}, {-5., 2.5}, {-5., 2.5}, {-5., 
       2.4791666666666665`}, {-5., 2.4583333333333335`}, {-5., 2.4375}, {-5., 
       2.4166666666666665`}, {-5., 2.3958333333333335`}, {-5., 2.375}, {-5., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, 2.}, {-5.25, 2.}, {-5.125, 2.}, {-5., 2.}, {-4.875, 
       2.}, {-4.75, 2.}, {-4.625, 2.}, {-4.625, 2.}, {-4.75, 2.}, {-4.875, 
       2.}, {-5., 2.}, {-5.125, 2.}, {-5.25, 2.}, {-5.375, 2.}, {-5.375, 
       2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 1.625}, {-5., 1.75}, {-5., 1.875}, {-5., 2.}, {-5., 
       2.125}, {-5., 2.25}, {-5., 2.375}, {-5., 2.375}, {-5., 2.25}, {-5., 
       2.125}, {-5., 2.}, {-5., 1.875}, {-5., 1.75}, {-5., 1.625}, {-5., 
       1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgegLAfu6SsWiPYKHfB/IvT06DEGh4w70rZF
m6HyDYwORpxGkys+CB2Y/Xb2TT55JgeILuEDBu4nWqVnMjnc7C3jnTtH+MCr
i+v2XXkKlWcQgZrP7KBe1PkpKVkEVf6ACFz/uW9nc9r5ReHmz1B+cqjXRxRu
/9eM8PhXRaJw90HEReHuh8knm98yLSn6Z4+in+GvPcz8UyonfB4d/G0Ps39B
Yf6XE2d/2WtA3acTs6gpzOSXPar7f9nD/IciD/Q/TD8sfGDmw8LvPxj8sYeF
byLUfejhDwCrZZck
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByA0i8PqVSCA4IeCgTCcD6FF0NSLoKkXRVMv
RpAPMYcJzoeYw4imngHODwPL/7VH1f/LHlX9Dww+qvt+2KO6H6ZeBE29MJp6
ITT1hPmrUNwnBPXfXzT1MP8Jofkfpp/JAVU9iwMA6zxckA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, 
       1.7348349570550448`}, {-4.6752404735808355`, 
       1.8125}, {-4.595057255667003, 
       1.5950572556670028`}, {-4.734834957055044, 1.7348349570550448`}}], 
      PolygonBox[{{-4.562655006646477, 
       1.769748357463745}, {-4.595057255667003, 
       1.5950572556670028`}, {-4.6752404735808355`, 
       1.8125}, {-4.562655006646477, 1.769748357463745}}], 
      PolygonBox[{{-4.6752404735808355`, 1.8125}, {-4.637777815141599, 
       1.9029428580865546`}, {-4.562655006646477, 
       1.769748357463745}, {-4.6752404735808355`, 1.8125}}], 
      PolygonBox[{{-4.562500018967059, 
       1.9157074104439382`}, {-4.562655006646477, 
       1.769748357463745}, {-4.637777815141599, 
       1.9029428580865546`}, {-4.562500018967059, 1.9157074104439382`}}], 
      PolygonBox[{{-4.637777815141599, 1.9029428580865546`}, {-4.625, 
       2.}, {-4.562500018967059, 1.9157074104439382`}, {-4.637777815141599, 
       1.9029428580865546`}}], 
      PolygonBox[{{-4.5625, 2.}, {-4.562500018967059, 
       1.9157074104439382`}, {-4.625, 2.}, {-4.5625, 2.}}], 
      PolygonBox[{{-4.625, 2.}, {-4.637777815141599, 
       2.0970571419134454`}, {-4.5625, 2.}, {-4.625, 2.}}], 
      PolygonBox[{{-4.562500018967059, 2.084292589556062}, {-4.5625, 
       2.}, {-4.637777815141599, 2.0970571419134454`}, {-4.562500018967059, 
       2.084292589556062}}], 
      PolygonBox[{{-4.637777815141599, 
       2.0970571419134454`}, {-4.6752404735808355`, 
       2.1875}, {-4.562500018967059, 2.084292589556062}, {-4.637777815141599, 
       2.0970571419134454`}}], 
      PolygonBox[{{-4.562655006646477, 
       2.230251642536255}, {-4.562500018967059, 
       2.084292589556062}, {-4.6752404735808355`, 
       2.1875}, {-4.562655006646477, 2.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, 2.1875}, {-4.734834957055044, 
       2.2651650429449552`}, {-4.562655006646477, 
       2.230251642536255}, {-4.6752404735808355`, 2.1875}}], 
      PolygonBox[{{-4.595057255667003, 
       2.404942744332997}, {-4.562655006646477, 
       2.230251642536255}, {-4.734834957055044, 
       2.2651650429449552`}, {-4.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, 2.2651650429449552`}, {-4.8125, 
       2.3247595264191645`}, {-4.595057255667003, 
       2.404942744332997}, {-4.734834957055044, 2.2651650429449552`}}], 
      PolygonBox[{{-4.769748357463745, 
       2.4373449933535234`}, {-4.595057255667003, 
       2.404942744332997}, {-4.8125, 
       2.3247595264191645`}, {-4.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{-4.8125, 2.3247595264191645`}, {-4.902942858086555, 
       2.3622221848584006`}, {-4.769748357463745, 
       2.4373449933535234`}, {-4.8125, 2.3247595264191645`}}], 
      PolygonBox[{{-4.9157074104439396`, 
       2.437499981032941}, {-4.769748357463745, 
       2.4373449933535234`}, {-4.902942858086555, 
       2.3622221848584006`}, {-4.9157074104439396`, 2.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, 2.3622221848584006`}, {-5., 
       2.375}, {-4.9157074104439396`, 2.437499981032941}, {-4.902942858086555,
        2.3622221848584006`}}], 
      PolygonBox[{{-4.999894472779513, 2.4375}, {-4.9157074104439396`, 
       2.437499981032941}, {-5., 2.375}, {-4.999894472779513, 2.4375}}], 
      PolygonBox[{{-5., 2.375}, {-5.097057141913445, 
       2.3622221848584006`}, {-4.999894472779513, 2.4375}, {-5., 2.375}}], 
      PolygonBox[{{-5.084292589556057, 
       2.437499981032941}, {-4.999894472779513, 2.4375}, {-5.097057141913445, 
       2.3622221848584006`}, {-5.084292589556057, 2.437499981032941}}], 
      PolygonBox[{{-5.097057141913445, 2.3622221848584006`}, {-5.1875, 
       2.3247595264191645`}, {-5.084292589556057, 
       2.437499981032941}, {-5.097057141913445, 2.3622221848584006`}}], 
      PolygonBox[{{-5.230251642536255, 
       2.4373449933535234`}, {-5.084292589556057, 
       2.437499981032941}, {-5.1875, 
       2.3247595264191645`}, {-5.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{-5.1875, 2.3247595264191645`}, {-5.265165042944956, 
       2.2651650429449552`}, {-5.230251642536255, 
       2.4373449933535234`}, {-5.1875, 2.3247595264191645`}}], 
      PolygonBox[{{-5.404942744332997, 
       2.404942744332997}, {-5.230251642536255, 
       2.4373449933535234`}, {-5.265165042944956, 
       2.2651650429449552`}, {-5.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, 
       2.2651650429449552`}, {-5.3247595264191645`, 
       2.1875}, {-5.404942744332997, 2.404942744332997}, {-5.265165042944956, 
       2.2651650429449552`}}], 
      PolygonBox[{{-5.437344993353523, 
       2.2302516425362553`}, {-5.404942744332997, 
       2.404942744332997}, {-5.3247595264191645`, 
       2.1875}, {-5.437344993353523, 2.2302516425362553`}}], 
      PolygonBox[{{-5.3247595264191645`, 2.1875}, {-5.362222184858401, 
       2.0970571419134454`}, {-5.437344993353523, 
       2.2302516425362553`}, {-5.3247595264191645`, 2.1875}}], 
      PolygonBox[{{-5.437499981032941, 
       2.0842925895560622`}, {-5.437344993353523, 
       2.2302516425362553`}, {-5.362222184858401, 
       2.0970571419134454`}, {-5.437499981032941, 2.0842925895560622`}}], 
      PolygonBox[{{-5.362222184858401, 2.0970571419134454`}, {-5.375, 
       2.}, {-5.437499981032941, 2.0842925895560622`}, {-5.362222184858401, 
       2.0970571419134454`}}], 
      PolygonBox[{{-5.4375, 2.0001231780629953`}, {-5.437499981032941, 
       2.0842925895560622`}, {-5.375, 2.}, {-5.4375, 2.0001231780629953`}}], 
      PolygonBox[{{-5.375, 2.}, {-5.362222184858401, 
       1.9029428580865548`}, {-5.4375, 2.0001231780629953`}, {-5.375, 2.}}], 
      PolygonBox[{{-5.437499981032941, 1.915707410443945}, {-5.4375, 
       2.0001231780629953`}, {-5.362222184858401, 
       1.9029428580865548`}, {-5.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-5.362222184858401, 
       1.9029428580865548`}, {-5.3247595264191645`, 
       1.8125000000000002`}, {-5.437499981032941, 
       1.915707410443945}, {-5.362222184858401, 1.9029428580865548`}}], 
      PolygonBox[{{-5.437344993353523, 
       1.7697483574637451`}, {-5.437499981032941, 
       1.915707410443945}, {-5.3247595264191645`, 
       1.8125000000000002`}, {-5.437344993353523, 1.7697483574637451`}}], 
      PolygonBox[{{-5.3247595264191645`, 
       1.8125000000000002`}, {-5.265165042944956, 
       1.7348349570550448`}, {-5.437344993353523, 
       1.7697483574637451`}, {-5.3247595264191645`, 1.8125000000000002`}}], 
      PolygonBox[{{-5.404942744332997, 
       1.5950572556670028`}, {-5.437344993353523, 
       1.7697483574637451`}, {-5.265165042944956, 
       1.7348349570550448`}, {-5.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-5.265165042944956, 1.7348349570550448`}, {-5.1875, 
       1.6752404735808355`}, {-5.404942744332997, 
       1.5950572556670028`}, {-5.265165042944956, 1.7348349570550448`}}], 
      PolygonBox[{{-5.230251642536255, 
       1.5626550066464766`}, {-5.404942744332997, 
       1.5950572556670028`}, {-5.1875, 
       1.6752404735808355`}, {-5.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-5.1875, 1.6752404735808355`}, {-5.097057141913446, 
       1.6377778151415994`}, {-5.230251642536255, 
       1.5626550066464766`}, {-5.1875, 1.6752404735808355`}}], 
      PolygonBox[{{-5.084292589556064, 
       1.5625000189670593`}, {-5.230251642536255, 
       1.5626550066464766`}, {-5.097057141913446, 
       1.6377778151415994`}, {-5.084292589556064, 1.5625000189670593`}}], 
      PolygonBox[{{-5.097057141913446, 1.6377778151415994`}, {-5., 
       1.625}, {-5.084292589556064, 1.5625000189670593`}, {-5.097057141913446,
        1.6377778151415994`}}], 
      PolygonBox[{{-4.999865158168957, 1.5625}, {-5.084292589556064, 
       1.5625000189670593`}, {-5., 1.625}, {-4.999865158168957, 1.5625}}], 
      PolygonBox[{{-5., 1.625}, {-4.902942858086555, 
       1.6377778151415994`}, {-4.999865158168957, 1.5625}, {-5., 1.625}}], 
      PolygonBox[{{-4.915707410443947, 
       1.5625000189670593`}, {-4.999865158168957, 
       1.5625}, {-4.902942858086555, 
       1.6377778151415994`}, {-4.915707410443947, 1.5625000189670593`}}], 
      PolygonBox[{{-4.902942858086555, 1.6377778151415994`}, {-4.8125, 
       1.6752404735808355`}, {-4.915707410443947, 
       1.5625000189670593`}, {-4.902942858086555, 1.6377778151415994`}}], 
      PolygonBox[{{-4.769748357463746, 
       1.5626550066464766`}, {-4.915707410443947, 
       1.5625000189670593`}, {-4.8125, 
       1.6752404735808355`}, {-4.769748357463746, 1.5626550066464766`}}], 
      PolygonBox[{{-4.8125, 1.6752404735808355`}, {-4.734834957055044, 
       1.7348349570550448`}, {-4.769748357463746, 
       1.5626550066464766`}, {-4.8125, 1.6752404735808355`}}], 
      PolygonBox[{{-4.595057255667003, 
       1.5950572556670028`}, {-4.769748357463746, 
       1.5626550066464766`}, {-4.734834957055044, 
       1.7348349570550448`}, {-4.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-4.734834957055044, 
       1.7348349570550448`}, {-4.734834957055044, 
       1.7348349570550448`}, {-4.595057255667003, 
       1.5950572556670028`}, {-4.734834957055044, 1.7348349570550448`}}], 
      PolygonBox[{{-4.595057255667003, 
       1.5950572556670028`}, {-4.595057255667003, 
       1.5950572556670028`}, {-4.734834957055044, 
       1.7348349570550448`}, {-4.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-4.595057255667003, 
       1.5950572556670028`}, {-4.562655006646477, 1.769748357463745}, {-4.5, 
       1.5}, {-4.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-4.5, 1.6423372173506323`}, {-4.5, 
       1.5}, {-4.562655006646477, 1.769748357463745}, {-4.5, 
       1.6423372173506323`}}], 
      PolygonBox[{{-4.562655006646477, 
       1.769748357463745}, {-4.562500018967059, 1.9157074104439382`}, {-4.5, 
       1.6423372173506323`}, {-4.562655006646477, 1.769748357463745}}], 
      PolygonBox[{{-4.5, 1.79409099469826}, {-4.5, 
       1.6423372173506323`}, {-4.562500018967059, 1.9157074104439382`}, {-4.5,
        1.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, 1.9157074104439382`}, {-4.5625, 
       2.}, {-4.5, 1.79409099469826}, {-4.562500018967059, 
       1.9157074104439382`}}], 
      PolygonBox[{{-4.5, 2.}, {-4.5, 1.79409099469826}, {-4.5625, 2.}, {-4.5, 
       2.}}], PolygonBox[{{-4.5625, 2.}, {-4.562500018967059, 
       2.084292589556062}, {-4.5, 2.}, {-4.5625, 2.}}], 
      PolygonBox[{{-4.5, 2.20590900530174}, {-4.5, 2.}, {-4.562500018967059, 
       2.084292589556062}, {-4.5, 2.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, 
       2.084292589556062}, {-4.562655006646477, 2.230251642536255}, {-4.5, 
       2.20590900530174}, {-4.562500018967059, 2.084292589556062}}], 
      PolygonBox[{{-4.5, 2.3576627826493675`}, {-4.5, 
       2.20590900530174}, {-4.562655006646477, 2.230251642536255}, {-4.5, 
       2.3576627826493675`}}], 
      PolygonBox[{{-4.562655006646477, 
       2.230251642536255}, {-4.595057255667003, 2.404942744332997}, {-4.5, 
       2.3576627826493675`}, {-4.562655006646477, 2.230251642536255}}], 
      PolygonBox[{{-4.508553435038814, 2.491446564961186}, {-4.5, 
       2.3576627826493675`}, {-4.595057255667003, 
       2.404942744332997}, {-4.508553435038814, 2.491446564961186}}], 
      PolygonBox[{{-4.595057255667003, 
       2.404942744332997}, {-4.769748357463745, 
       2.4373449933535234`}, {-4.508553435038814, 
       2.491446564961186}, {-4.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{-4.642337217350632, 2.5}, {-4.508553435038814, 
       2.491446564961186}, {-4.769748357463745, 
       2.4373449933535234`}, {-4.642337217350632, 2.5}}], 
      PolygonBox[{{-4.769748357463745, 
       2.4373449933535234`}, {-4.9157074104439396`, 
       2.437499981032941}, {-4.642337217350632, 2.5}, {-4.769748357463745, 
       2.4373449933535234`}}], 
      PolygonBox[{{-4.794090994626744, 2.5}, {-4.642337217350632, 
       2.5}, {-4.9157074104439396`, 2.437499981032941}, {-4.794090994626744, 
       2.5}}], PolygonBox[{{-4.9157074104439396`, 
       2.437499981032941}, {-4.999894472779513, 2.4375}, {-4.794090994626744, 
       2.5}, {-4.9157074104439396`, 2.437499981032941}}], 
      PolygonBox[{{-4.92205804197311, 2.5}, {-4.794090994626744, 
       2.5}, {-4.999894472779513, 2.4375}, {-4.92205804197311, 2.5}}], 
      PolygonBox[{{-4.999894472779513, 2.4375}, {-5.084292589556057, 
       2.437499981032941}, {-4.92205804197311, 2.5}, {-4.999894472779513, 
       2.4375}}], 
      PolygonBox[{{-5.205909005304446, 2.5}, {-4.92205804197311, 
       2.5}, {-5.084292589556057, 2.437499981032941}, {-5.205909005304446, 
       2.5}}], PolygonBox[{{-5.084292589556057, 
       2.437499981032941}, {-5.230251642536255, 
       2.4373449933535234`}, {-5.205909005304446, 2.5}, {-5.084292589556057, 
       2.437499981032941}}], 
      PolygonBox[{{-5.357662782649366, 2.5}, {-5.205909005304446, 
       2.5}, {-5.230251642536255, 2.4373449933535234`}, {-5.357662782649366, 
       2.5}}], PolygonBox[{{-5.230251642536255, 
       2.4373449933535234`}, {-5.404942744332997, 
       2.404942744332997}, {-5.357662782649366, 2.5}, {-5.230251642536255, 
       2.4373449933535234`}}], 
      PolygonBox[{{-4.5, 2.5}, {-5.357662782649366, 2.5}, {-5.404942744332997,
        2.404942744332997}, {-4.5, 2.5}}], 
      PolygonBox[{{-5.404942744332997, 
       2.404942744332997}, {-5.437344993353523, 2.2302516425362553`}, {-4.5, 
       2.5}, {-5.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-5.5, 2.357662782649369}, {-4.5, 2.5}, {-5.437344993353523,
        2.2302516425362553`}, {-5.5, 2.357662782649369}}], 
      PolygonBox[{{-5.437344993353523, 
       2.2302516425362553`}, {-5.437499981032941, 2.0842925895560622`}, {-5.5,
        2.357662782649369}, {-5.437344993353523, 2.2302516425362553`}}], 
      PolygonBox[{{-5.5, 2.205909005282899}, {-5.5, 
       2.357662782649369}, {-5.437499981032941, 2.0842925895560622`}, {-5.5, 
       2.205909005282899}}], 
      PolygonBox[{{-5.437499981032941, 2.0842925895560622`}, {-5.4375, 
       2.0001231780629953`}, {-5.5, 2.205909005282899}, {-5.437499981032941, 
       2.0842925895560622`}}], 
      PolygonBox[{{-5.5, 2.0806786667587}, {-5.5, 
       2.205909005282899}, {-5.4375, 2.0001231780629953`}, {-5.5, 
       2.0806786667587}}], 
      PolygonBox[{{-5.4375, 2.0001231780629953`}, {-5.437499981032941, 
       1.915707410443945}, {-5.5, 2.0806786667587}, {-5.4375, 
       2.0001231780629953`}}], 
      PolygonBox[{{-5.5, 1.7940909948547215`}, {-5.5, 
       2.0806786667587}, {-5.437499981032941, 1.915707410443945}, {-5.5, 
       1.7940909948547215`}}], 
      PolygonBox[{{-5.437499981032941, 
       1.915707410443945}, {-5.437344993353523, 1.7697483574637451`}, {-5.5, 
       1.7940909948547215`}, {-5.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-5.5, 1.6423372173506348`}, {-5.5, 
       1.7940909948547215`}, {-5.437344993353523, 1.7697483574637451`}, {-5.5,
        1.6423372173506348`}}], 
      PolygonBox[{{-5.437344993353523, 
       1.7697483574637451`}, {-5.404942744332997, 1.5950572556670028`}, {-5.5,
        1.6423372173506348`}, {-5.437344993353523, 1.7697483574637451`}}], 
      PolygonBox[{{-5.5, 2.5}, {-5.5, 
       1.6423372173506348`}, {-5.404942744332997, 1.5950572556670028`}, {-5.5,
        2.5}}], 
      PolygonBox[{{-5.404942744332997, 
       1.5950572556670028`}, {-5.230251642536255, 1.5626550066464766`}, {-5.5,
        2.5}, {-5.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-5.5, 1.5}, {-5.5, 2.5}, {-5.230251642536255, 
       1.5626550066464766`}, {-5.5, 1.5}}], 
      PolygonBox[{{-5.230251642536255, 
       1.5626550066464766`}, {-5.084292589556064, 1.5625000189670593`}, {-5.5,
        1.5}, {-5.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-5.205909005566828, 1.5}, {-5.5, 1.5}, {-5.084292589556064,
        1.5625000189670593`}, {-5.205909005566828, 1.5}}], 
      PolygonBox[{{-5.084292589556064, 
       1.5625000189670593`}, {-4.999865158168957, 
       1.5625}, {-5.205909005566828, 1.5}, {-5.084292589556064, 
       1.5625000189670593`}}], 
      PolygonBox[{{-4.917676129598938, 1.5}, {-5.205909005566828, 
       1.5}, {-4.999865158168957, 1.5625}, {-4.917676129598938, 1.5}}], 
      PolygonBox[{{-4.999865158168957, 1.5625}, {-4.915707410443947, 
       1.5625000189670593`}, {-4.917676129598938, 1.5}, {-4.999865158168957, 
       1.5625}}], 
      PolygonBox[{{-4.794090994639602, 1.5}, {-4.917676129598938, 
       1.5}, {-4.915707410443947, 1.5625000189670593`}, {-4.794090994639602, 
       1.5}}], PolygonBox[{{-4.915707410443947, 
       1.5625000189670593`}, {-4.769748357463746, 
       1.5626550066464766`}, {-4.794090994639602, 1.5}, {-4.915707410443947, 
       1.5625000189670593`}}], 
      PolygonBox[{{-4.6423372173506285`, 1.5}, {-4.794090994639602, 
       1.5}, {-4.769748357463746, 1.5626550066464766`}, {-4.6423372173506285`,
        1.5}}], 
      PolygonBox[{{-4.769748357463746, 
       1.5626550066464766`}, {-4.595057255667003, 
       1.5950572556670028`}, {-4.6423372173506285`, 1.5}, {-4.769748357463746,
        1.5626550066464766`}}], 
      PolygonBox[{{-4.5, 1.5}, {-4.6423372173506285`, 
       1.5}, {-4.595057255667003, 1.5950572556670028`}, {-4.5, 1.5}}], 
      PolygonBox[{{-4.595057255667003, 
       1.5950572556670028`}, {-4.595057255667003, 1.5950572556670028`}, {-4.5,
        1.5}, {-4.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-4.5, 1.5}, {-4.5, 1.5}, {-4.595057255667003, 
       1.5950572556670028`}, {-4.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, 3.}, {-5.479166666666667, 3.}, {-5.458333333333333, 
       3.}, {-5.4375, 3.}, {-5.416666666666667, 3.}, {-5.395833333333333, 
       3.}, {-5.375, 3.}, {-5.375, 3.}, {-5.395833333333333, 
       3.}, {-5.416666666666667, 3.}, {-5.4375, 3.}, {-5.458333333333333, 
       3.}, {-5.479166666666667, 3.}, {-5.5, 3.}, {-5.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, 3.}, {-4.604166666666667, 3.}, {-4.583333333333333, 
       3.}, {-4.5625, 3.}, {-4.541666666666667, 3.}, {-4.520833333333333, 
       3.}, {-4.5, 3.}, {-4.5, 3.}, {-4.520833333333333, 
       3.}, {-4.541666666666667, 3.}, {-4.5625, 3.}, {-4.583333333333333, 
       3.}, {-4.604166666666667, 3.}, {-4.625, 3.}, {-4.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 2.5}, {-5., 2.5208333333333335`}, {-5., 
       2.5416666666666665`}, {-5., 2.5625}, {-5., 2.5833333333333335`}, {-5., 
       2.6041666666666665`}, {-5., 2.625}, {-5., 2.625}, {-5., 
       2.6041666666666665`}, {-5., 2.5833333333333335`}, {-5., 2.5625}, {-5., 
       2.5416666666666665`}, {-5., 2.5208333333333335`}, {-5., 2.5}, {-5., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 3.375}, {-5., 3.3958333333333335`}, {-5., 
       3.4166666666666665`}, {-5., 3.4375}, {-5., 3.4583333333333335`}, {-5., 
       3.4791666666666665`}, {-5., 3.5}, {-5., 3.5}, {-5., 
       3.4791666666666665`}, {-5., 3.4583333333333335`}, {-5., 3.4375}, {-5., 
       3.4166666666666665`}, {-5., 3.3958333333333335`}, {-5., 3.375}, {-5., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, 3.}, {-5.25, 3.}, {-5.125, 3.}, {-5., 3.}, {-4.875, 
       3.}, {-4.75, 3.}, {-4.625, 3.}, {-4.625, 3.}, {-4.75, 3.}, {-4.875, 
       3.}, {-5., 3.}, {-5.125, 3.}, {-5.25, 3.}, {-5.375, 3.}, {-5.375, 
       3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 2.625}, {-5., 2.75}, {-5., 2.875}, {-5., 3.}, {-5., 
       3.125}, {-5., 3.25}, {-5., 3.375}, {-5., 3.375}, {-5., 3.25}, {-5., 
       3.125}, {-5., 3.}, {-5., 2.875}, {-5., 2.75}, {-5., 2.625}, {-5., 
       2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgDA4H7ukrFoj2Ch3wfyL09OgxDoeMO9K2
RZuh8g2cDkacRpMrPggdmP129k0+eS4HsLiD8AED9xOt0jO5HG72lvHOnSN8
4NXFdfuuPIXKM4hAzed2UC/q/JSULIIqf0AErv/ct7M57fyicPNnKD851Osj
Crf/a0Z4/KsiUbj7IOKicPfD5DdJv5WysmRH088GNz9VKEXt4wNWuP0XdphX
PUljddCAuk9ML9BRW4oVzf2scP+hyAP9D9MPCx+Y+ajhxwYP341Q96GHPwB1
R4Ke
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByA0j8PqVSCA4IeCgTCcD6FF0NSLoKkXRVMv
RpAPMYcLzoeYw4mmngNNPRucHwZWz4qmngWDj+o+FjT3w9SLoKkXRlMvhKae
MD8UxX1CaO6HqedAU88J569CCR9E/AAAk+BQqg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, 
       2.7348349570550448`}, {-4.6752404735808355`, 
       2.8125}, {-4.595057255667003, 2.595057255667003}, {-4.734834957055044, 
       2.7348349570550448`}}], 
      PolygonBox[{{-4.562655006646477, 
       2.7697483574637447`}, {-4.595057255667003, 
       2.595057255667003}, {-4.6752404735808355`, 
       2.8125}, {-4.562655006646477, 2.7697483574637447`}}], 
      PolygonBox[{{-4.6752404735808355`, 2.8125}, {-4.637777815141599, 
       2.9029428580865546`}, {-4.562655006646477, 
       2.7697483574637447`}, {-4.6752404735808355`, 2.8125}}], 
      PolygonBox[{{-4.562500018967059, 
       2.915707410443938}, {-4.562655006646477, 
       2.7697483574637447`}, {-4.637777815141599, 
       2.9029428580865546`}, {-4.562500018967059, 2.915707410443938}}], 
      PolygonBox[{{-4.637777815141599, 2.9029428580865546`}, {-4.625, 
       3.}, {-4.562500018967059, 2.915707410443938}, {-4.637777815141599, 
       2.9029428580865546`}}], 
      PolygonBox[{{-4.5625, 3.}, {-4.562500018967059, 
       2.915707410443938}, {-4.625, 3.}, {-4.5625, 3.}}], 
      PolygonBox[{{-4.625, 3.}, {-4.637777815141599, 
       3.0970571419134454`}, {-4.5625, 3.}, {-4.625, 3.}}], 
      PolygonBox[{{-4.562500018967059, 3.084292589556062}, {-4.5625, 
       3.}, {-4.637777815141599, 3.0970571419134454`}, {-4.562500018967059, 
       3.084292589556062}}], 
      PolygonBox[{{-4.637777815141599, 
       3.0970571419134454`}, {-4.6752404735808355`, 
       3.1875}, {-4.562500018967059, 3.084292589556062}, {-4.637777815141599, 
       3.0970571419134454`}}], 
      PolygonBox[{{-4.562655006646477, 
       3.230251642536255}, {-4.562500018967059, 
       3.084292589556062}, {-4.6752404735808355`, 
       3.1875}, {-4.562655006646477, 3.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, 3.1875}, {-4.734834957055044, 
       3.2651650429449552`}, {-4.562655006646477, 
       3.230251642536255}, {-4.6752404735808355`, 3.1875}}], 
      PolygonBox[{{-4.595057255667003, 
       3.404942744332997}, {-4.562655006646477, 
       3.230251642536255}, {-4.734834957055044, 
       3.2651650429449552`}, {-4.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, 3.2651650429449552`}, {-4.8125, 
       3.3247595264191645`}, {-4.595057255667003, 
       3.404942744332997}, {-4.734834957055044, 3.2651650429449552`}}], 
      PolygonBox[{{-4.769748357463745, 
       3.4373449933535234`}, {-4.595057255667003, 
       3.404942744332997}, {-4.8125, 
       3.3247595264191645`}, {-4.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{-4.8125, 3.3247595264191645`}, {-4.902942858086555, 
       3.3622221848584006`}, {-4.769748357463745, 
       3.4373449933535234`}, {-4.8125, 3.3247595264191645`}}], 
      PolygonBox[{{-4.9157074104439396`, 
       3.437499981032941}, {-4.769748357463745, 
       3.4373449933535234`}, {-4.902942858086555, 
       3.3622221848584006`}, {-4.9157074104439396`, 3.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, 3.3622221848584006`}, {-5., 
       3.375}, {-4.9157074104439396`, 3.437499981032941}, {-4.902942858086555,
        3.3622221848584006`}}], 
      PolygonBox[{{-4.999894472779513, 3.4375}, {-4.9157074104439396`, 
       3.437499981032941}, {-5., 3.375}, {-4.999894472779513, 3.4375}}], 
      PolygonBox[{{-5., 3.375}, {-5.097057141913445, 
       3.3622221848584006`}, {-4.999894472779513, 3.4375}, {-5., 3.375}}], 
      PolygonBox[{{-5.084292589556057, 
       3.437499981032941}, {-4.999894472779513, 3.4375}, {-5.097057141913445, 
       3.3622221848584006`}, {-5.084292589556057, 3.437499981032941}}], 
      PolygonBox[{{-5.097057141913445, 3.3622221848584006`}, {-5.1875, 
       3.3247595264191645`}, {-5.084292589556057, 
       3.437499981032941}, {-5.097057141913445, 3.3622221848584006`}}], 
      PolygonBox[{{-5.230251642536255, 
       3.4373449933535234`}, {-5.084292589556057, 
       3.437499981032941}, {-5.1875, 
       3.3247595264191645`}, {-5.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{-5.1875, 3.3247595264191645`}, {-5.265165042944956, 
       3.2651650429449552`}, {-5.230251642536255, 
       3.4373449933535234`}, {-5.1875, 3.3247595264191645`}}], 
      PolygonBox[{{-5.404942744332997, 
       3.404942744332997}, {-5.230251642536255, 
       3.4373449933535234`}, {-5.265165042944956, 
       3.2651650429449552`}, {-5.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, 
       3.2651650429449552`}, {-5.3247595264191645`, 
       3.1875}, {-5.404942744332997, 3.404942744332997}, {-5.265165042944956, 
       3.2651650429449552`}}], 
      PolygonBox[{{-5.437344993353523, 
       3.2302516425362553`}, {-5.404942744332997, 
       3.404942744332997}, {-5.3247595264191645`, 
       3.1875}, {-5.437344993353523, 3.2302516425362553`}}], 
      PolygonBox[{{-5.3247595264191645`, 3.1875}, {-5.362222184858401, 
       3.0970571419134454`}, {-5.437344993353523, 
       3.2302516425362553`}, {-5.3247595264191645`, 3.1875}}], 
      PolygonBox[{{-5.437499981032941, 
       3.0842925895560622`}, {-5.437344993353523, 
       3.2302516425362553`}, {-5.362222184858401, 
       3.0970571419134454`}, {-5.437499981032941, 3.0842925895560622`}}], 
      PolygonBox[{{-5.362222184858401, 3.0970571419134454`}, {-5.375, 
       3.}, {-5.437499981032941, 3.0842925895560622`}, {-5.362222184858401, 
       3.0970571419134454`}}], 
      PolygonBox[{{-5.4375, 3.0001231780629953`}, {-5.437499981032941, 
       3.0842925895560622`}, {-5.375, 3.}, {-5.4375, 3.0001231780629953`}}], 
      PolygonBox[{{-5.375, 3.}, {-5.362222184858401, 
       2.902942858086555}, {-5.4375, 3.0001231780629953`}, {-5.375, 3.}}], 
      PolygonBox[{{-5.437499981032941, 2.915707410443945}, {-5.4375, 
       3.0001231780629953`}, {-5.362222184858401, 
       2.902942858086555}, {-5.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-5.362222184858401, 
       2.902942858086555}, {-5.3247595264191645`, 
       2.8125}, {-5.437499981032941, 2.915707410443945}, {-5.362222184858401, 
       2.902942858086555}}], 
      PolygonBox[{{-5.437344993353523, 
       2.769748357463745}, {-5.437499981032941, 
       2.915707410443945}, {-5.3247595264191645`, 
       2.8125}, {-5.437344993353523, 2.769748357463745}}], 
      PolygonBox[{{-5.3247595264191645`, 2.8125}, {-5.265165042944956, 
       2.7348349570550448`}, {-5.437344993353523, 
       2.769748357463745}, {-5.3247595264191645`, 2.8125}}], 
      PolygonBox[{{-5.404942744332997, 
       2.595057255667003}, {-5.437344993353523, 
       2.769748357463745}, {-5.265165042944956, 
       2.7348349570550448`}, {-5.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-5.265165042944956, 2.7348349570550448`}, {-5.1875, 
       2.6752404735808355`}, {-5.404942744332997, 
       2.595057255667003}, {-5.265165042944956, 2.7348349570550448`}}], 
      PolygonBox[{{-5.230251642536255, 
       2.5626550066464766`}, {-5.404942744332997, 
       2.595057255667003}, {-5.1875, 
       2.6752404735808355`}, {-5.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-5.1875, 2.6752404735808355`}, {-5.097057141913446, 
       2.6377778151415994`}, {-5.230251642536255, 
       2.5626550066464766`}, {-5.1875, 2.6752404735808355`}}], 
      PolygonBox[{{-5.084292589556064, 
       2.562500018967059}, {-5.230251642536255, 
       2.5626550066464766`}, {-5.097057141913446, 
       2.6377778151415994`}, {-5.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-5.097057141913446, 2.6377778151415994`}, {-5., 
       2.625}, {-5.084292589556064, 2.562500018967059}, {-5.097057141913446, 
       2.6377778151415994`}}], 
      PolygonBox[{{-4.999865158168957, 2.5625}, {-5.084292589556064, 
       2.562500018967059}, {-5., 2.625}, {-4.999865158168957, 2.5625}}], 
      PolygonBox[{{-5., 2.625}, {-4.902942858086555, 
       2.6377778151415994`}, {-4.999865158168957, 2.5625}, {-5., 2.625}}], 
      PolygonBox[{{-4.915707410443947, 
       2.562500018967059}, {-4.999865158168957, 2.5625}, {-4.902942858086555, 
       2.6377778151415994`}, {-4.915707410443947, 2.562500018967059}}], 
      PolygonBox[{{-4.902942858086555, 2.6377778151415994`}, {-4.8125, 
       2.6752404735808355`}, {-4.915707410443947, 
       2.562500018967059}, {-4.902942858086555, 2.6377778151415994`}}], 
      PolygonBox[{{-4.769748357463746, 
       2.5626550066464766`}, {-4.915707410443947, 
       2.562500018967059}, {-4.8125, 
       2.6752404735808355`}, {-4.769748357463746, 2.5626550066464766`}}], 
      PolygonBox[{{-4.8125, 2.6752404735808355`}, {-4.734834957055044, 
       2.7348349570550448`}, {-4.769748357463746, 
       2.5626550066464766`}, {-4.8125, 2.6752404735808355`}}], 
      PolygonBox[{{-4.595057255667003, 
       2.595057255667003}, {-4.769748357463746, 
       2.5626550066464766`}, {-4.734834957055044, 
       2.7348349570550448`}, {-4.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-4.734834957055044, 
       2.7348349570550448`}, {-4.734834957055044, 
       2.7348349570550448`}, {-4.595057255667003, 
       2.595057255667003}, {-4.734834957055044, 2.7348349570550448`}}], 
      PolygonBox[{{-4.595057255667003, 
       2.595057255667003}, {-4.595057255667003, 
       2.595057255667003}, {-4.734834957055044, 
       2.7348349570550448`}, {-4.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-4.595057255667003, 
       2.595057255667003}, {-4.562655006646477, 2.7697483574637447`}, {-4.5, 
       2.5}, {-4.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-4.5, 2.642337217350632}, {-4.5, 2.5}, {-4.562655006646477,
        2.7697483574637447`}, {-4.5, 2.642337217350632}}], 
      PolygonBox[{{-4.562655006646477, 
       2.7697483574637447`}, {-4.562500018967059, 2.915707410443938}, {-4.5, 
       2.642337217350632}, {-4.562655006646477, 2.7697483574637447`}}], 
      PolygonBox[{{-4.5, 2.79409099469826}, {-4.5, 
       2.642337217350632}, {-4.562500018967059, 2.915707410443938}, {-4.5, 
       2.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, 2.915707410443938}, {-4.5625, 
       3.}, {-4.5, 2.79409099469826}, {-4.562500018967059, 
       2.915707410443938}}], 
      PolygonBox[{{-4.5, 3.}, {-4.5, 2.79409099469826}, {-4.5625, 3.}, {-4.5, 
       3.}}], PolygonBox[{{-4.5625, 3.}, {-4.562500018967059, 
       3.084292589556062}, {-4.5, 3.}, {-4.5625, 3.}}], 
      PolygonBox[{{-4.5, 3.20590900530174}, {-4.5, 3.}, {-4.562500018967059, 
       3.084292589556062}, {-4.5, 3.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, 
       3.084292589556062}, {-4.562655006646477, 3.230251642536255}, {-4.5, 
       3.20590900530174}, {-4.562500018967059, 3.084292589556062}}], 
      PolygonBox[{{-4.5, 3.3576627826493675`}, {-4.5, 
       3.20590900530174}, {-4.562655006646477, 3.230251642536255}, {-4.5, 
       3.3576627826493675`}}], 
      PolygonBox[{{-4.562655006646477, 
       3.230251642536255}, {-4.595057255667003, 3.404942744332997}, {-4.5, 
       3.3576627826493675`}, {-4.562655006646477, 3.230251642536255}}], 
      PolygonBox[{{-4.508553435038814, 3.491446564961186}, {-4.5, 
       3.3576627826493675`}, {-4.595057255667003, 
       3.404942744332997}, {-4.508553435038814, 3.491446564961186}}], 
      PolygonBox[{{-4.595057255667003, 
       3.404942744332997}, {-4.769748357463745, 
       3.4373449933535234`}, {-4.508553435038814, 
       3.491446564961186}, {-4.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{-4.642337217350632, 3.5}, {-4.508553435038814, 
       3.491446564961186}, {-4.769748357463745, 
       3.4373449933535234`}, {-4.642337217350632, 3.5}}], 
      PolygonBox[{{-4.769748357463745, 
       3.4373449933535234`}, {-4.9157074104439396`, 
       3.437499981032941}, {-4.642337217350632, 3.5}, {-4.769748357463745, 
       3.4373449933535234`}}], 
      PolygonBox[{{-4.794090994626744, 3.5}, {-4.642337217350632, 
       3.5}, {-4.9157074104439396`, 3.437499981032941}, {-4.794090994626744, 
       3.5}}], PolygonBox[{{-4.9157074104439396`, 
       3.437499981032941}, {-4.999894472779513, 3.4375}, {-4.794090994626744, 
       3.5}, {-4.9157074104439396`, 3.437499981032941}}], 
      PolygonBox[{{-4.92205804197311, 3.5}, {-4.794090994626744, 
       3.5}, {-4.999894472779513, 3.4375}, {-4.92205804197311, 3.5}}], 
      PolygonBox[{{-4.999894472779513, 3.4375}, {-5.084292589556057, 
       3.437499981032941}, {-4.92205804197311, 3.5}, {-4.999894472779513, 
       3.4375}}], 
      PolygonBox[{{-5.205909005304446, 3.5}, {-4.92205804197311, 
       3.5}, {-5.084292589556057, 3.437499981032941}, {-5.205909005304446, 
       3.5}}], PolygonBox[{{-5.084292589556057, 
       3.437499981032941}, {-5.230251642536255, 
       3.4373449933535234`}, {-5.205909005304446, 3.5}, {-5.084292589556057, 
       3.437499981032941}}], 
      PolygonBox[{{-5.357662782649366, 3.5}, {-5.205909005304446, 
       3.5}, {-5.230251642536255, 3.4373449933535234`}, {-5.357662782649366, 
       3.5}}], PolygonBox[{{-5.230251642536255, 
       3.4373449933535234`}, {-5.404942744332997, 
       3.404942744332997}, {-5.357662782649366, 3.5}, {-5.230251642536255, 
       3.4373449933535234`}}], 
      PolygonBox[{{-4.5, 3.5}, {-5.357662782649366, 3.5}, {-5.404942744332997,
        3.404942744332997}, {-4.5, 3.5}}], 
      PolygonBox[{{-5.404942744332997, 
       3.404942744332997}, {-5.437344993353523, 3.2302516425362553`}, {-4.5, 
       3.5}, {-5.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-5.5, 3.357662782649369}, {-4.5, 3.5}, {-5.437344993353523,
        3.2302516425362553`}, {-5.5, 3.357662782649369}}], 
      PolygonBox[{{-5.437344993353523, 
       3.2302516425362553`}, {-5.437499981032941, 3.0842925895560622`}, {-5.5,
        3.357662782649369}, {-5.437344993353523, 3.2302516425362553`}}], 
      PolygonBox[{{-5.5, 3.205909005282899}, {-5.5, 
       3.357662782649369}, {-5.437499981032941, 3.0842925895560622`}, {-5.5, 
       3.205909005282899}}], 
      PolygonBox[{{-5.437499981032941, 3.0842925895560622`}, {-5.4375, 
       3.0001231780629953`}, {-5.5, 3.205909005282899}, {-5.437499981032941, 
       3.0842925895560622`}}], 
      PolygonBox[{{-5.5, 3.0806786667587}, {-5.5, 
       3.205909005282899}, {-5.4375, 3.0001231780629953`}, {-5.5, 
       3.0806786667587}}], 
      PolygonBox[{{-5.4375, 3.0001231780629953`}, {-5.437499981032941, 
       2.915707410443945}, {-5.5, 3.0806786667587}, {-5.4375, 
       3.0001231780629953`}}], 
      PolygonBox[{{-5.5, 2.7940909948547215`}, {-5.5, 
       3.0806786667587}, {-5.437499981032941, 2.915707410443945}, {-5.5, 
       2.7940909948547215`}}], 
      PolygonBox[{{-5.437499981032941, 
       2.915707410443945}, {-5.437344993353523, 2.769748357463745}, {-5.5, 
       2.7940909948547215`}, {-5.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-5.5, 2.6423372173506348`}, {-5.5, 
       2.7940909948547215`}, {-5.437344993353523, 2.769748357463745}, {-5.5, 
       2.6423372173506348`}}], 
      PolygonBox[{{-5.437344993353523, 
       2.769748357463745}, {-5.404942744332997, 2.595057255667003}, {-5.5, 
       2.6423372173506348`}, {-5.437344993353523, 2.769748357463745}}], 
      PolygonBox[{{-5.5, 3.5}, {-5.5, 
       2.6423372173506348`}, {-5.404942744332997, 2.595057255667003}, {-5.5, 
       3.5}}], PolygonBox[{{-5.404942744332997, 
       2.595057255667003}, {-5.230251642536255, 2.5626550066464766`}, {-5.5, 
       3.5}, {-5.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-5.5, 2.5}, {-5.5, 3.5}, {-5.230251642536255, 
       2.5626550066464766`}, {-5.5, 2.5}}], 
      PolygonBox[{{-5.230251642536255, 
       2.5626550066464766`}, {-5.084292589556064, 2.562500018967059}, {-5.5, 
       2.5}, {-5.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-5.205909005566828, 2.5}, {-5.5, 2.5}, {-5.084292589556064,
        2.562500018967059}, {-5.205909005566828, 2.5}}], 
      PolygonBox[{{-5.084292589556064, 
       2.562500018967059}, {-4.999865158168957, 2.5625}, {-5.205909005566828, 
       2.5}, {-5.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-4.917676129598938, 2.5}, {-5.205909005566828, 
       2.5}, {-4.999865158168957, 2.5625}, {-4.917676129598938, 2.5}}], 
      PolygonBox[{{-4.999865158168957, 2.5625}, {-4.915707410443947, 
       2.562500018967059}, {-4.917676129598938, 2.5}, {-4.999865158168957, 
       2.5625}}], 
      PolygonBox[{{-4.794090994639602, 2.5}, {-4.917676129598938, 
       2.5}, {-4.915707410443947, 2.562500018967059}, {-4.794090994639602, 
       2.5}}], PolygonBox[{{-4.915707410443947, 
       2.562500018967059}, {-4.769748357463746, 
       2.5626550066464766`}, {-4.794090994639602, 2.5}, {-4.915707410443947, 
       2.562500018967059}}], 
      PolygonBox[{{-4.6423372173506285`, 2.5}, {-4.794090994639602, 
       2.5}, {-4.769748357463746, 2.5626550066464766`}, {-4.6423372173506285`,
        2.5}}], 
      PolygonBox[{{-4.769748357463746, 
       2.5626550066464766`}, {-4.595057255667003, 
       2.595057255667003}, {-4.6423372173506285`, 2.5}, {-4.769748357463746, 
       2.5626550066464766`}}], 
      PolygonBox[{{-4.5, 2.5}, {-4.6423372173506285`, 
       2.5}, {-4.595057255667003, 2.595057255667003}, {-4.5, 2.5}}], 
      PolygonBox[{{-4.595057255667003, 
       2.595057255667003}, {-4.595057255667003, 2.595057255667003}, {-4.5, 
       2.5}, {-4.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-4.5, 2.5}, {-4.5, 2.5}, {-4.595057255667003, 
       2.595057255667003}, {-4.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, 4.}, {-5.479166666666667, 4.}, {-5.458333333333333, 
       4.}, {-5.4375, 4.}, {-5.416666666666667, 4.}, {-5.395833333333333, 
       4.}, {-5.375, 4.}, {-5.375, 4.}, {-5.395833333333333, 
       4.}, {-5.416666666666667, 4.}, {-5.4375, 4.}, {-5.458333333333333, 
       4.}, {-5.479166666666667, 4.}, {-5.5, 4.}, {-5.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, 4.}, {-4.604166666666667, 4.}, {-4.583333333333333, 
       4.}, {-4.5625, 4.}, {-4.541666666666667, 4.}, {-4.520833333333333, 
       4.}, {-4.5, 4.}, {-4.5, 4.}, {-4.520833333333333, 
       4.}, {-4.541666666666667, 4.}, {-4.5625, 4.}, {-4.583333333333333, 
       4.}, {-4.604166666666667, 4.}, {-4.625, 4.}, {-4.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 3.5}, {-5., 3.5208333333333335`}, {-5., 
       3.5416666666666665`}, {-5., 3.5625}, {-5., 3.5833333333333335`}, {-5., 
       3.6041666666666665`}, {-5., 3.625}, {-5., 3.625}, {-5., 
       3.6041666666666665`}, {-5., 3.5833333333333335`}, {-5., 3.5625}, {-5., 
       3.5416666666666665`}, {-5., 3.5208333333333335`}, {-5., 3.5}, {-5., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 4.375}, {-5., 4.395833333333333}, {-5., 
       4.416666666666667}, {-5., 4.4375}, {-5., 4.458333333333333}, {-5., 
       4.479166666666667}, {-5., 4.5}, {-5., 4.5}, {-5., 
       4.479166666666667}, {-5., 4.458333333333333}, {-5., 4.4375}, {-5., 
       4.416666666666667}, {-5., 4.395833333333333}, {-5., 4.375}, {-5., 
       4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, 4.}, {-5.25, 4.}, {-5.125, 4.}, {-5., 4.}, {-4.875, 
       4.}, {-4.75, 4.}, {-4.625, 4.}, {-4.625, 4.}, {-4.75, 4.}, {-4.875, 
       4.}, {-5., 4.}, {-5.125, 4.}, {-5.25, 4.}, {-5.375, 4.}, {-5.375, 
       4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 3.625}, {-5., 3.75}, {-5., 3.875}, {-5., 4.}, {-5., 
       4.125}, {-5., 4.25}, {-5., 4.375}, {-5., 4.375}, {-5., 4.25}, {-5., 
       4.125}, {-5., 4.}, {-5., 3.875}, {-5., 3.75}, {-5., 3.625}, {-5., 
       3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgDAEH7ukrFoj2Ch1QL+r8lJQs4JBxR9q2
aDNU/oCAgxGn0eSKD0IHzn07m9POL+gAFncQPjBD+cmhXh9Bh5u9Zbxz5wgf
+JoRHv+qCCrPIALR3yDoADFXBFX+gAhcP8RcUbj5EHFRuP0QfaIHNKDug5gr
Cnc/TH6T9FspK0t+VP0NfHDzU4VS1D4+4IXbf2GHedWTNF4HDaj7xPQCHbWl
eFHdz8AL9x+KPND/MP2w8IGZjxJ+QPth4bsR6j708AcAk0qCGw==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCB6C0w+pVIIDgh4KBMJwPoUXQ1IugqRdFUy9G
kA/RJwjnQ8wVQFMvgCbPB+eHgfXzoqnnweCjuo8Hzf0w9SJo6oXR1AuhqSfM
D0VxnxCa+2HqBdDkBdD0C6KpF3IAADibUXU=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, 
       3.7348349570550448`}, {-4.6752404735808355`, 
       3.8125}, {-4.595057255667003, 3.595057255667003}, {-4.734834957055044, 
       3.7348349570550448`}}], 
      PolygonBox[{{-4.562655006646477, 
       3.7697483574637447`}, {-4.595057255667003, 
       3.595057255667003}, {-4.6752404735808355`, 
       3.8125}, {-4.562655006646477, 3.7697483574637447`}}], 
      PolygonBox[{{-4.6752404735808355`, 3.8125}, {-4.637777815141599, 
       3.9029428580865546`}, {-4.562655006646477, 
       3.7697483574637447`}, {-4.6752404735808355`, 3.8125}}], 
      PolygonBox[{{-4.562500018967059, 
       3.915707410443938}, {-4.562655006646477, 
       3.7697483574637447`}, {-4.637777815141599, 
       3.9029428580865546`}, {-4.562500018967059, 3.915707410443938}}], 
      PolygonBox[{{-4.637777815141599, 3.9029428580865546`}, {-4.625, 
       4.}, {-4.562500018967059, 3.915707410443938}, {-4.637777815141599, 
       3.9029428580865546`}}], 
      PolygonBox[{{-4.5625, 4.}, {-4.562500018967059, 
       3.915707410443938}, {-4.625, 4.}, {-4.5625, 4.}}], 
      PolygonBox[{{-4.625, 4.}, {-4.637777815141599, 
       4.097057141913445}, {-4.5625, 4.}, {-4.625, 4.}}], 
      PolygonBox[{{-4.562500018967059, 4.084292589556061}, {-4.5625, 
       4.}, {-4.637777815141599, 4.097057141913445}, {-4.562500018967059, 
       4.084292589556061}}], 
      PolygonBox[{{-4.637777815141599, 
       4.097057141913445}, {-4.6752404735808355`, 
       4.1875}, {-4.562500018967059, 4.084292589556061}, {-4.637777815141599, 
       4.097057141913445}}], 
      PolygonBox[{{-4.562655006646477, 
       4.230251642536255}, {-4.562500018967059, 
       4.084292589556061}, {-4.6752404735808355`, 
       4.1875}, {-4.562655006646477, 4.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, 4.1875}, {-4.734834957055044, 
       4.265165042944956}, {-4.562655006646477, 
       4.230251642536255}, {-4.6752404735808355`, 4.1875}}], 
      PolygonBox[{{-4.595057255667003, 
       4.404942744332997}, {-4.562655006646477, 
       4.230251642536255}, {-4.734834957055044, 
       4.265165042944956}, {-4.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, 4.265165042944956}, {-4.8125, 
       4.3247595264191645`}, {-4.595057255667003, 
       4.404942744332997}, {-4.734834957055044, 4.265165042944956}}], 
      PolygonBox[{{-4.769748357463745, 
       4.437344993353523}, {-4.595057255667003, 4.404942744332997}, {-4.8125, 
       4.3247595264191645`}, {-4.769748357463745, 4.437344993353523}}], 
      PolygonBox[{{-4.8125, 4.3247595264191645`}, {-4.902942858086555, 
       4.362222184858401}, {-4.769748357463745, 4.437344993353523}, {-4.8125, 
       4.3247595264191645`}}], 
      PolygonBox[{{-4.9157074104439396`, 
       4.437499981032941}, {-4.769748357463745, 
       4.437344993353523}, {-4.902942858086555, 
       4.362222184858401}, {-4.9157074104439396`, 4.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, 4.362222184858401}, {-5., 
       4.375}, {-4.9157074104439396`, 4.437499981032941}, {-4.902942858086555,
        4.362222184858401}}], 
      PolygonBox[{{-4.999894472779513, 4.4375}, {-4.9157074104439396`, 
       4.437499981032941}, {-5., 4.375}, {-4.999894472779513, 4.4375}}], 
      PolygonBox[{{-5., 4.375}, {-5.097057141913445, 
       4.362222184858401}, {-4.999894472779513, 4.4375}, {-5., 4.375}}], 
      PolygonBox[{{-5.084292589556057, 
       4.437499981032941}, {-4.999894472779513, 4.4375}, {-5.097057141913445, 
       4.362222184858401}, {-5.084292589556057, 4.437499981032941}}], 
      PolygonBox[{{-5.097057141913445, 4.362222184858401}, {-5.1875, 
       4.3247595264191645`}, {-5.084292589556057, 
       4.437499981032941}, {-5.097057141913445, 4.362222184858401}}], 
      PolygonBox[{{-5.230251642536255, 
       4.437344993353523}, {-5.084292589556057, 4.437499981032941}, {-5.1875, 
       4.3247595264191645`}, {-5.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{-5.1875, 4.3247595264191645`}, {-5.265165042944956, 
       4.265165042944956}, {-5.230251642536255, 4.437344993353523}, {-5.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{-5.404942744332997, 
       4.404942744332997}, {-5.230251642536255, 
       4.437344993353523}, {-5.265165042944956, 
       4.265165042944956}, {-5.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, 
       4.265165042944956}, {-5.3247595264191645`, 
       4.1875}, {-5.404942744332997, 4.404942744332997}, {-5.265165042944956, 
       4.265165042944956}}], 
      PolygonBox[{{-5.437344993353523, 
       4.230251642536255}, {-5.404942744332997, 
       4.404942744332997}, {-5.3247595264191645`, 
       4.1875}, {-5.437344993353523, 4.230251642536255}}], 
      PolygonBox[{{-5.3247595264191645`, 4.1875}, {-5.362222184858401, 
       4.097057141913446}, {-5.437344993353523, 
       4.230251642536255}, {-5.3247595264191645`, 4.1875}}], 
      PolygonBox[{{-5.437499981032941, 
       4.084292589556062}, {-5.437344993353523, 
       4.230251642536255}, {-5.362222184858401, 
       4.097057141913446}, {-5.437499981032941, 4.084292589556062}}], 
      PolygonBox[{{-5.362222184858401, 4.097057141913446}, {-5.375, 
       4.}, {-5.437499981032941, 4.084292589556062}, {-5.362222184858401, 
       4.097057141913446}}], 
      PolygonBox[{{-5.4375, 4.000123178062996}, {-5.437499981032941, 
       4.084292589556062}, {-5.375, 4.}, {-5.4375, 4.000123178062996}}], 
      PolygonBox[{{-5.375, 4.}, {-5.362222184858401, 
       3.902942858086555}, {-5.4375, 4.000123178062996}, {-5.375, 4.}}], 
      PolygonBox[{{-5.437499981032941, 3.915707410443945}, {-5.4375, 
       4.000123178062996}, {-5.362222184858401, 
       3.902942858086555}, {-5.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-5.362222184858401, 
       3.902942858086555}, {-5.3247595264191645`, 
       3.8125}, {-5.437499981032941, 3.915707410443945}, {-5.362222184858401, 
       3.902942858086555}}], 
      PolygonBox[{{-5.437344993353523, 
       3.769748357463745}, {-5.437499981032941, 
       3.915707410443945}, {-5.3247595264191645`, 
       3.8125}, {-5.437344993353523, 3.769748357463745}}], 
      PolygonBox[{{-5.3247595264191645`, 3.8125}, {-5.265165042944956, 
       3.7348349570550448`}, {-5.437344993353523, 
       3.769748357463745}, {-5.3247595264191645`, 3.8125}}], 
      PolygonBox[{{-5.404942744332997, 
       3.595057255667003}, {-5.437344993353523, 
       3.769748357463745}, {-5.265165042944956, 
       3.7348349570550448`}, {-5.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-5.265165042944956, 3.7348349570550448`}, {-5.1875, 
       3.6752404735808355`}, {-5.404942744332997, 
       3.595057255667003}, {-5.265165042944956, 3.7348349570550448`}}], 
      PolygonBox[{{-5.230251642536255, 
       3.5626550066464766`}, {-5.404942744332997, 
       3.595057255667003}, {-5.1875, 
       3.6752404735808355`}, {-5.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-5.1875, 3.6752404735808355`}, {-5.097057141913446, 
       3.6377778151415994`}, {-5.230251642536255, 
       3.5626550066464766`}, {-5.1875, 3.6752404735808355`}}], 
      PolygonBox[{{-5.084292589556064, 
       3.562500018967059}, {-5.230251642536255, 
       3.5626550066464766`}, {-5.097057141913446, 
       3.6377778151415994`}, {-5.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-5.097057141913446, 3.6377778151415994`}, {-5., 
       3.625}, {-5.084292589556064, 3.562500018967059}, {-5.097057141913446, 
       3.6377778151415994`}}], 
      PolygonBox[{{-4.999865158168957, 3.5625}, {-5.084292589556064, 
       3.562500018967059}, {-5., 3.625}, {-4.999865158168957, 3.5625}}], 
      PolygonBox[{{-5., 3.625}, {-4.902942858086555, 
       3.6377778151415994`}, {-4.999865158168957, 3.5625}, {-5., 3.625}}], 
      PolygonBox[{{-4.915707410443947, 
       3.562500018967059}, {-4.999865158168957, 3.5625}, {-4.902942858086555, 
       3.6377778151415994`}, {-4.915707410443947, 3.562500018967059}}], 
      PolygonBox[{{-4.902942858086555, 3.6377778151415994`}, {-4.8125, 
       3.6752404735808355`}, {-4.915707410443947, 
       3.562500018967059}, {-4.902942858086555, 3.6377778151415994`}}], 
      PolygonBox[{{-4.769748357463746, 
       3.5626550066464766`}, {-4.915707410443947, 
       3.562500018967059}, {-4.8125, 
       3.6752404735808355`}, {-4.769748357463746, 3.5626550066464766`}}], 
      PolygonBox[{{-4.8125, 3.6752404735808355`}, {-4.734834957055044, 
       3.7348349570550448`}, {-4.769748357463746, 
       3.5626550066464766`}, {-4.8125, 3.6752404735808355`}}], 
      PolygonBox[{{-4.595057255667003, 
       3.595057255667003}, {-4.769748357463746, 
       3.5626550066464766`}, {-4.734834957055044, 
       3.7348349570550448`}, {-4.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-4.734834957055044, 
       3.7348349570550448`}, {-4.734834957055044, 
       3.7348349570550448`}, {-4.595057255667003, 
       3.595057255667003}, {-4.734834957055044, 3.7348349570550448`}}], 
      PolygonBox[{{-4.595057255667003, 
       3.595057255667003}, {-4.595057255667003, 
       3.595057255667003}, {-4.734834957055044, 
       3.7348349570550448`}, {-4.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-4.595057255667003, 
       3.595057255667003}, {-4.562655006646477, 3.7697483574637447`}, {-4.5, 
       3.5}, {-4.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-4.5, 3.642337217350632}, {-4.5, 3.5}, {-4.562655006646477,
        3.7697483574637447`}, {-4.5, 3.642337217350632}}], 
      PolygonBox[{{-4.562655006646477, 
       3.7697483574637447`}, {-4.562500018967059, 3.915707410443938}, {-4.5, 
       3.642337217350632}, {-4.562655006646477, 3.7697483574637447`}}], 
      PolygonBox[{{-4.5, 3.79409099469826}, {-4.5, 
       3.642337217350632}, {-4.562500018967059, 3.915707410443938}, {-4.5, 
       3.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, 3.915707410443938}, {-4.5625, 
       4.}, {-4.5, 3.79409099469826}, {-4.562500018967059, 
       3.915707410443938}}], 
      PolygonBox[{{-4.5, 4.}, {-4.5, 3.79409099469826}, {-4.5625, 4.}, {-4.5, 
       4.}}], PolygonBox[{{-4.5625, 4.}, {-4.562500018967059, 
       4.084292589556061}, {-4.5, 4.}, {-4.5625, 4.}}], 
      PolygonBox[{{-4.5, 4.20590900530174}, {-4.5, 4.}, {-4.562500018967059, 
       4.084292589556061}, {-4.5, 4.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, 
       4.084292589556061}, {-4.562655006646477, 4.230251642536255}, {-4.5, 
       4.20590900530174}, {-4.562500018967059, 4.084292589556061}}], 
      PolygonBox[{{-4.5, 4.357662782649368}, {-4.5, 
       4.20590900530174}, {-4.562655006646477, 4.230251642536255}, {-4.5, 
       4.357662782649368}}], 
      PolygonBox[{{-4.562655006646477, 
       4.230251642536255}, {-4.595057255667003, 4.404942744332997}, {-4.5, 
       4.357662782649368}, {-4.562655006646477, 4.230251642536255}}], 
      PolygonBox[{{-4.508553435038814, 4.491446564961186}, {-4.5, 
       4.357662782649368}, {-4.595057255667003, 
       4.404942744332997}, {-4.508553435038814, 4.491446564961186}}], 
      PolygonBox[{{-4.595057255667003, 
       4.404942744332997}, {-4.769748357463745, 
       4.437344993353523}, {-4.508553435038814, 
       4.491446564961186}, {-4.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{-4.642337217350632, 4.5}, {-4.508553435038814, 
       4.491446564961186}, {-4.769748357463745, 
       4.437344993353523}, {-4.642337217350632, 4.5}}], 
      PolygonBox[{{-4.769748357463745, 
       4.437344993353523}, {-4.9157074104439396`, 
       4.437499981032941}, {-4.642337217350632, 4.5}, {-4.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{-4.794090994626744, 4.5}, {-4.642337217350632, 
       4.5}, {-4.9157074104439396`, 4.437499981032941}, {-4.794090994626744, 
       4.5}}], PolygonBox[{{-4.9157074104439396`, 
       4.437499981032941}, {-4.999894472779513, 4.4375}, {-4.794090994626744, 
       4.5}, {-4.9157074104439396`, 4.437499981032941}}], 
      PolygonBox[{{-4.92205804197311, 4.5}, {-4.794090994626744, 
       4.5}, {-4.999894472779513, 4.4375}, {-4.92205804197311, 4.5}}], 
      PolygonBox[{{-4.999894472779513, 4.4375}, {-5.084292589556057, 
       4.437499981032941}, {-4.92205804197311, 4.5}, {-4.999894472779513, 
       4.4375}}], 
      PolygonBox[{{-5.205909005304446, 4.5}, {-4.92205804197311, 
       4.5}, {-5.084292589556057, 4.437499981032941}, {-5.205909005304446, 
       4.5}}], PolygonBox[{{-5.084292589556057, 
       4.437499981032941}, {-5.230251642536255, 
       4.437344993353523}, {-5.205909005304446, 4.5}, {-5.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-5.357662782649366, 4.5}, {-5.205909005304446, 
       4.5}, {-5.230251642536255, 4.437344993353523}, {-5.357662782649366, 
       4.5}}], PolygonBox[{{-5.230251642536255, 
       4.437344993353523}, {-5.404942744332997, 
       4.404942744332997}, {-5.357662782649366, 4.5}, {-5.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{-4.5, 4.5}, {-5.357662782649366, 4.5}, {-5.404942744332997,
        4.404942744332997}, {-4.5, 4.5}}], 
      PolygonBox[{{-5.404942744332997, 
       4.404942744332997}, {-5.437344993353523, 4.230251642536255}, {-4.5, 
       4.5}, {-5.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-5.5, 4.357662782649369}, {-4.5, 4.5}, {-5.437344993353523,
        4.230251642536255}, {-5.5, 4.357662782649369}}], 
      PolygonBox[{{-5.437344993353523, 
       4.230251642536255}, {-5.437499981032941, 4.084292589556062}, {-5.5, 
       4.357662782649369}, {-5.437344993353523, 4.230251642536255}}], 
      PolygonBox[{{-5.5, 4.205909005282899}, {-5.5, 
       4.357662782649369}, {-5.437499981032941, 4.084292589556062}, {-5.5, 
       4.205909005282899}}], 
      PolygonBox[{{-5.437499981032941, 4.084292589556062}, {-5.4375, 
       4.000123178062996}, {-5.5, 4.205909005282899}, {-5.437499981032941, 
       4.084292589556062}}], 
      PolygonBox[{{-5.5, 4.0806786667587005`}, {-5.5, 
       4.205909005282899}, {-5.4375, 4.000123178062996}, {-5.5, 
       4.0806786667587005`}}], 
      PolygonBox[{{-5.4375, 4.000123178062996}, {-5.437499981032941, 
       3.915707410443945}, {-5.5, 4.0806786667587005`}, {-5.4375, 
       4.000123178062996}}], 
      PolygonBox[{{-5.5, 3.7940909948547215`}, {-5.5, 
       4.0806786667587005`}, {-5.437499981032941, 3.915707410443945}, {-5.5, 
       3.7940909948547215`}}], 
      PolygonBox[{{-5.437499981032941, 
       3.915707410443945}, {-5.437344993353523, 3.769748357463745}, {-5.5, 
       3.7940909948547215`}, {-5.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-5.5, 3.6423372173506348`}, {-5.5, 
       3.7940909948547215`}, {-5.437344993353523, 3.769748357463745}, {-5.5, 
       3.6423372173506348`}}], 
      PolygonBox[{{-5.437344993353523, 
       3.769748357463745}, {-5.404942744332997, 3.595057255667003}, {-5.5, 
       3.6423372173506348`}, {-5.437344993353523, 3.769748357463745}}], 
      PolygonBox[{{-5.5, 4.5}, {-5.5, 
       3.6423372173506348`}, {-5.404942744332997, 3.595057255667003}, {-5.5, 
       4.5}}], PolygonBox[{{-5.404942744332997, 
       3.595057255667003}, {-5.230251642536255, 3.5626550066464766`}, {-5.5, 
       4.5}, {-5.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-5.5, 3.5}, {-5.5, 4.5}, {-5.230251642536255, 
       3.5626550066464766`}, {-5.5, 3.5}}], 
      PolygonBox[{{-5.230251642536255, 
       3.5626550066464766`}, {-5.084292589556064, 3.562500018967059}, {-5.5, 
       3.5}, {-5.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-5.205909005566828, 3.5}, {-5.5, 3.5}, {-5.084292589556064,
        3.562500018967059}, {-5.205909005566828, 3.5}}], 
      PolygonBox[{{-5.084292589556064, 
       3.562500018967059}, {-4.999865158168957, 3.5625}, {-5.205909005566828, 
       3.5}, {-5.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-4.917676129598938, 3.5}, {-5.205909005566828, 
       3.5}, {-4.999865158168957, 3.5625}, {-4.917676129598938, 3.5}}], 
      PolygonBox[{{-4.999865158168957, 3.5625}, {-4.915707410443947, 
       3.562500018967059}, {-4.917676129598938, 3.5}, {-4.999865158168957, 
       3.5625}}], 
      PolygonBox[{{-4.794090994639602, 3.5}, {-4.917676129598938, 
       3.5}, {-4.915707410443947, 3.562500018967059}, {-4.794090994639602, 
       3.5}}], PolygonBox[{{-4.915707410443947, 
       3.562500018967059}, {-4.769748357463746, 
       3.5626550066464766`}, {-4.794090994639602, 3.5}, {-4.915707410443947, 
       3.562500018967059}}], 
      PolygonBox[{{-4.6423372173506285`, 3.5}, {-4.794090994639602, 
       3.5}, {-4.769748357463746, 3.5626550066464766`}, {-4.6423372173506285`,
        3.5}}], 
      PolygonBox[{{-4.769748357463746, 
       3.5626550066464766`}, {-4.595057255667003, 
       3.595057255667003}, {-4.6423372173506285`, 3.5}, {-4.769748357463746, 
       3.5626550066464766`}}], 
      PolygonBox[{{-4.5, 3.5}, {-4.6423372173506285`, 
       3.5}, {-4.595057255667003, 3.595057255667003}, {-4.5, 3.5}}], 
      PolygonBox[{{-4.595057255667003, 
       3.595057255667003}, {-4.595057255667003, 3.595057255667003}, {-4.5, 
       3.5}, {-4.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-4.5, 3.5}, {-4.5, 3.5}, {-4.595057255667003, 
       3.595057255667003}, {-4.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.5, 5.}, {-5.479166666666667, 5.}, {-5.458333333333333, 
       5.}, {-5.4375, 5.}, {-5.416666666666667, 5.}, {-5.395833333333333, 
       5.}, {-5.375, 5.}, {-5.375, 5.}, {-5.395833333333333, 
       5.}, {-5.416666666666667, 5.}, {-5.4375, 5.}, {-5.458333333333333, 
       5.}, {-5.479166666666667, 5.}, {-5.5, 5.}, {-5.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.625, 5.}, {-4.604166666666667, 5.}, {-4.583333333333333, 
       5.}, {-4.5625, 5.}, {-4.541666666666667, 5.}, {-4.520833333333333, 
       5.}, {-4.5, 5.}, {-4.5, 5.}, {-4.520833333333333, 
       5.}, {-4.541666666666667, 5.}, {-4.5625, 5.}, {-4.583333333333333, 
       5.}, {-4.604166666666667, 5.}, {-4.625, 5.}, {-4.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 4.5}, {-5., 4.520833333333333}, {-5., 
       4.541666666666667}, {-5., 4.5625}, {-5., 4.583333333333333}, {-5., 
       4.604166666666667}, {-5., 4.625}, {-5., 4.625}, {-5., 
       4.604166666666667}, {-5., 4.583333333333333}, {-5., 4.5625}, {-5., 
       4.541666666666667}, {-5., 4.520833333333333}, {-5., 4.5}, {-5., 
       4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 5.375}, {-5., 5.395833333333333}, {-5., 
       5.416666666666667}, {-5., 5.4375}, {-5., 5.458333333333333}, {-5., 
       5.479166666666667}, {-5., 5.5}, {-5., 5.5}, {-5., 
       5.479166666666667}, {-5., 5.458333333333333}, {-5., 5.4375}, {-5., 
       5.416666666666667}, {-5., 5.395833333333333}, {-5., 5.375}, {-5., 
       5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.375, 5.}, {-5.25, 5.}, {-5.125, 5.}, {-5., 5.}, {-4.875, 
       5.}, {-4.75, 5.}, {-4.625, 5.}, {-4.625, 5.}, {-4.75, 5.}, {-4.875, 
       5.}, {-5., 5.}, {-5.125, 5.}, {-5.25, 5.}, {-5.375, 5.}, {-5.375, 
       5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., 4.625}, {-5., 4.75}, {-5., 4.875}, {-5., 5.}, {-5., 
       5.125}, {-5., 5.25}, {-5., 5.375}, {-5., 5.375}, {-5., 5.25}, {-5., 
       5.125}, {-5., 5.}, {-5., 4.875}, {-5., 4.75}, {-5., 4.625}, {-5., 
       4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNQgcgDBEH7ukrFoj2Ch1QL+r8lJQs4pBxR9q2
aDNU/oCIgxGn0eSKD0IHzn07m9POL+oAFncQPjBD+cmhXh9Rh5u9Zbxz5wgf
+JoRHv+qCCrPIALR3yDqADUXVf6ACFw/1Fy4+VBxuP1QfQc0oO6Dmgt3P0we
6g5U/Q7CcPONIf6A2w/1pwPU3APQcEBzvxDcfyjyQP/D9MPCB0qjhh/Qflj4
3oC6Dz38AcLdhMk=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCByC0mMPqVSCA4IeCgTCcD6FF0NSLoKkXRVMv
RpAP1QfnQ81FUy+Cpl4YTb0QmnpMPqr7hNDcD1MvgqZeGE29EJp6wnxU9wmh
uR+mXgRNvQiaelE09WIOAKTvUfo=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-4.734834957055044, 
       4.734834957055044}, {-4.6752404735808355`, 
       4.8125}, {-4.595057255667003, 4.595057255667003}, {-4.734834957055044, 
       4.734834957055044}}], 
      PolygonBox[{{-4.562655006646477, 
       4.769748357463745}, {-4.595057255667003, 
       4.595057255667003}, {-4.6752404735808355`, 
       4.8125}, {-4.562655006646477, 4.769748357463745}}], 
      PolygonBox[{{-4.6752404735808355`, 4.8125}, {-4.637777815141599, 
       4.902942858086555}, {-4.562655006646477, 
       4.769748357463745}, {-4.6752404735808355`, 4.8125}}], 
      PolygonBox[{{-4.562500018967059, 
       4.915707410443938}, {-4.562655006646477, 
       4.769748357463745}, {-4.637777815141599, 
       4.902942858086555}, {-4.562500018967059, 4.915707410443938}}], 
      PolygonBox[{{-4.637777815141599, 4.902942858086555}, {-4.625, 
       5.}, {-4.562500018967059, 4.915707410443938}, {-4.637777815141599, 
       4.902942858086555}}], 
      PolygonBox[{{-4.5625, 5.}, {-4.562500018967059, 
       4.915707410443938}, {-4.625, 5.}, {-4.5625, 5.}}], 
      PolygonBox[{{-4.625, 5.}, {-4.637777815141599, 
       5.097057141913445}, {-4.5625, 5.}, {-4.625, 5.}}], 
      PolygonBox[{{-4.562500018967059, 5.084292589556061}, {-4.5625, 
       5.}, {-4.637777815141599, 5.097057141913445}, {-4.562500018967059, 
       5.084292589556061}}], 
      PolygonBox[{{-4.637777815141599, 
       5.097057141913445}, {-4.6752404735808355`, 
       5.1875}, {-4.562500018967059, 5.084292589556061}, {-4.637777815141599, 
       5.097057141913445}}], 
      PolygonBox[{{-4.562655006646477, 
       5.230251642536255}, {-4.562500018967059, 
       5.084292589556061}, {-4.6752404735808355`, 
       5.1875}, {-4.562655006646477, 5.230251642536255}}], 
      PolygonBox[{{-4.6752404735808355`, 5.1875}, {-4.734834957055044, 
       5.265165042944956}, {-4.562655006646477, 
       5.230251642536255}, {-4.6752404735808355`, 5.1875}}], 
      PolygonBox[{{-4.595057255667003, 
       5.404942744332997}, {-4.562655006646477, 
       5.230251642536255}, {-4.734834957055044, 
       5.265165042944956}, {-4.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{-4.734834957055044, 5.265165042944956}, {-4.8125, 
       5.3247595264191645`}, {-4.595057255667003, 
       5.404942744332997}, {-4.734834957055044, 5.265165042944956}}], 
      PolygonBox[{{-4.769748357463745, 
       5.437344993353523}, {-4.595057255667003, 5.404942744332997}, {-4.8125, 
       5.3247595264191645`}, {-4.769748357463745, 5.437344993353523}}], 
      PolygonBox[{{-4.8125, 5.3247595264191645`}, {-4.902942858086555, 
       5.362222184858401}, {-4.769748357463745, 5.437344993353523}, {-4.8125, 
       5.3247595264191645`}}], 
      PolygonBox[{{-4.9157074104439396`, 
       5.437499981032941}, {-4.769748357463745, 
       5.437344993353523}, {-4.902942858086555, 
       5.362222184858401}, {-4.9157074104439396`, 5.437499981032941}}], 
      PolygonBox[{{-4.902942858086555, 5.362222184858401}, {-5., 
       5.375}, {-4.9157074104439396`, 5.437499981032941}, {-4.902942858086555,
        5.362222184858401}}], 
      PolygonBox[{{-4.999894472779513, 5.4375}, {-4.9157074104439396`, 
       5.437499981032941}, {-5., 5.375}, {-4.999894472779513, 5.4375}}], 
      PolygonBox[{{-5., 5.375}, {-5.097057141913445, 
       5.362222184858401}, {-4.999894472779513, 5.4375}, {-5., 5.375}}], 
      PolygonBox[{{-5.084292589556057, 
       5.437499981032941}, {-4.999894472779513, 5.4375}, {-5.097057141913445, 
       5.362222184858401}, {-5.084292589556057, 5.437499981032941}}], 
      PolygonBox[{{-5.097057141913445, 5.362222184858401}, {-5.1875, 
       5.3247595264191645`}, {-5.084292589556057, 
       5.437499981032941}, {-5.097057141913445, 5.362222184858401}}], 
      PolygonBox[{{-5.230251642536255, 
       5.437344993353523}, {-5.084292589556057, 5.437499981032941}, {-5.1875, 
       5.3247595264191645`}, {-5.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{-5.1875, 5.3247595264191645`}, {-5.265165042944956, 
       5.265165042944956}, {-5.230251642536255, 5.437344993353523}, {-5.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{-5.404942744332997, 
       5.404942744332997}, {-5.230251642536255, 
       5.437344993353523}, {-5.265165042944956, 
       5.265165042944956}, {-5.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-5.265165042944956, 
       5.265165042944956}, {-5.3247595264191645`, 
       5.1875}, {-5.404942744332997, 5.404942744332997}, {-5.265165042944956, 
       5.265165042944956}}], 
      PolygonBox[{{-5.437344993353523, 
       5.230251642536255}, {-5.404942744332997, 
       5.404942744332997}, {-5.3247595264191645`, 
       5.1875}, {-5.437344993353523, 5.230251642536255}}], 
      PolygonBox[{{-5.3247595264191645`, 5.1875}, {-5.362222184858401, 
       5.097057141913446}, {-5.437344993353523, 
       5.230251642536255}, {-5.3247595264191645`, 5.1875}}], 
      PolygonBox[{{-5.437499981032941, 
       5.084292589556062}, {-5.437344993353523, 
       5.230251642536255}, {-5.362222184858401, 
       5.097057141913446}, {-5.437499981032941, 5.084292589556062}}], 
      PolygonBox[{{-5.362222184858401, 5.097057141913446}, {-5.375, 
       5.}, {-5.437499981032941, 5.084292589556062}, {-5.362222184858401, 
       5.097057141913446}}], 
      PolygonBox[{{-5.4375, 5.000123178062996}, {-5.437499981032941, 
       5.084292589556062}, {-5.375, 5.}, {-5.4375, 5.000123178062996}}], 
      PolygonBox[{{-5.375, 5.}, {-5.362222184858401, 
       4.902942858086555}, {-5.4375, 5.000123178062996}, {-5.375, 5.}}], 
      PolygonBox[{{-5.437499981032941, 4.915707410443945}, {-5.4375, 
       5.000123178062996}, {-5.362222184858401, 
       4.902942858086555}, {-5.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-5.362222184858401, 
       4.902942858086555}, {-5.3247595264191645`, 
       4.8125}, {-5.437499981032941, 4.915707410443945}, {-5.362222184858401, 
       4.902942858086555}}], 
      PolygonBox[{{-5.437344993353523, 
       4.769748357463746}, {-5.437499981032941, 
       4.915707410443945}, {-5.3247595264191645`, 
       4.8125}, {-5.437344993353523, 4.769748357463746}}], 
      PolygonBox[{{-5.3247595264191645`, 4.8125}, {-5.265165042944956, 
       4.734834957055044}, {-5.437344993353523, 
       4.769748357463746}, {-5.3247595264191645`, 4.8125}}], 
      PolygonBox[{{-5.404942744332997, 
       4.595057255667003}, {-5.437344993353523, 
       4.769748357463746}, {-5.265165042944956, 
       4.734834957055044}, {-5.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-5.265165042944956, 4.734834957055044}, {-5.1875, 
       4.6752404735808355`}, {-5.404942744332997, 
       4.595057255667003}, {-5.265165042944956, 4.734834957055044}}], 
      PolygonBox[{{-5.230251642536255, 
       4.562655006646477}, {-5.404942744332997, 4.595057255667003}, {-5.1875, 
       4.6752404735808355`}, {-5.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-5.1875, 4.6752404735808355`}, {-5.097057141913446, 
       4.637777815141599}, {-5.230251642536255, 4.562655006646477}, {-5.1875, 
       4.6752404735808355`}}], 
      PolygonBox[{{-5.084292589556064, 
       4.562500018967059}, {-5.230251642536255, 
       4.562655006646477}, {-5.097057141913446, 
       4.637777815141599}, {-5.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-5.097057141913446, 4.637777815141599}, {-5., 
       4.625}, {-5.084292589556064, 4.562500018967059}, {-5.097057141913446, 
       4.637777815141599}}], 
      PolygonBox[{{-4.999865158168957, 4.5625}, {-5.084292589556064, 
       4.562500018967059}, {-5., 4.625}, {-4.999865158168957, 4.5625}}], 
      PolygonBox[{{-5., 4.625}, {-4.902942858086555, 
       4.637777815141599}, {-4.999865158168957, 4.5625}, {-5., 4.625}}], 
      PolygonBox[{{-4.915707410443947, 
       4.562500018967059}, {-4.999865158168957, 4.5625}, {-4.902942858086555, 
       4.637777815141599}, {-4.915707410443947, 4.562500018967059}}], 
      PolygonBox[{{-4.902942858086555, 4.637777815141599}, {-4.8125, 
       4.6752404735808355`}, {-4.915707410443947, 
       4.562500018967059}, {-4.902942858086555, 4.637777815141599}}], 
      PolygonBox[{{-4.769748357463746, 
       4.562655006646477}, {-4.915707410443947, 4.562500018967059}, {-4.8125, 
       4.6752404735808355`}, {-4.769748357463746, 4.562655006646477}}], 
      PolygonBox[{{-4.8125, 4.6752404735808355`}, {-4.734834957055044, 
       4.734834957055044}, {-4.769748357463746, 4.562655006646477}, {-4.8125, 
       4.6752404735808355`}}], 
      PolygonBox[{{-4.595057255667003, 
       4.595057255667003}, {-4.769748357463746, 
       4.562655006646477}, {-4.734834957055044, 
       4.734834957055044}, {-4.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-4.734834957055044, 
       4.734834957055044}, {-4.734834957055044, 
       4.734834957055044}, {-4.595057255667003, 
       4.595057255667003}, {-4.734834957055044, 4.734834957055044}}], 
      PolygonBox[{{-4.595057255667003, 
       4.595057255667003}, {-4.595057255667003, 
       4.595057255667003}, {-4.734834957055044, 
       4.734834957055044}, {-4.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-4.595057255667003, 
       4.595057255667003}, {-4.562655006646477, 4.769748357463745}, {-4.5, 
       4.5}, {-4.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-4.5, 4.642337217350632}, {-4.5, 4.5}, {-4.562655006646477,
        4.769748357463745}, {-4.5, 4.642337217350632}}], 
      PolygonBox[{{-4.562655006646477, 
       4.769748357463745}, {-4.562500018967059, 4.915707410443938}, {-4.5, 
       4.642337217350632}, {-4.562655006646477, 4.769748357463745}}], 
      PolygonBox[{{-4.5, 4.79409099469826}, {-4.5, 
       4.642337217350632}, {-4.562500018967059, 4.915707410443938}, {-4.5, 
       4.79409099469826}}], 
      PolygonBox[{{-4.562500018967059, 4.915707410443938}, {-4.5625, 
       5.}, {-4.5, 4.79409099469826}, {-4.562500018967059, 
       4.915707410443938}}], 
      PolygonBox[{{-4.5, 5.}, {-4.5, 4.79409099469826}, {-4.5625, 5.}, {-4.5, 
       5.}}], 
      PolygonBox[{{-4.5625, 5.}, {-4.562500018967059, 
       5.084292589556061}, {-4.5, 5.}, {-4.5625, 5.}}], 
      PolygonBox[{{-4.5, 5.20590900530174}, {-4.5, 5.}, {-4.562500018967059, 
       5.084292589556061}, {-4.5, 5.20590900530174}}], 
      PolygonBox[{{-4.562500018967059, 
       5.084292589556061}, {-4.562655006646477, 5.230251642536255}, {-4.5, 
       5.20590900530174}, {-4.562500018967059, 5.084292589556061}}], 
      PolygonBox[{{-4.5, 5.357662782649368}, {-4.5, 
       5.20590900530174}, {-4.562655006646477, 5.230251642536255}, {-4.5, 
       5.357662782649368}}], 
      PolygonBox[{{-4.562655006646477, 
       5.230251642536255}, {-4.595057255667003, 5.404942744332997}, {-4.5, 
       5.357662782649368}, {-4.562655006646477, 5.230251642536255}}], 
      PolygonBox[{{-4.508553435038814, 5.491446564961186}, {-4.5, 
       5.357662782649368}, {-4.595057255667003, 
       5.404942744332997}, {-4.508553435038814, 5.491446564961186}}], 
      PolygonBox[{{-4.595057255667003, 
       5.404942744332997}, {-4.769748357463745, 
       5.437344993353523}, {-4.508553435038814, 
       5.491446564961186}, {-4.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{-4.642337217350632, 5.5}, {-4.508553435038814, 
       5.491446564961186}, {-4.769748357463745, 
       5.437344993353523}, {-4.642337217350632, 5.5}}], 
      PolygonBox[{{-4.769748357463745, 
       5.437344993353523}, {-4.9157074104439396`, 
       5.437499981032941}, {-4.642337217350632, 5.5}, {-4.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{-4.794090994626744, 5.5}, {-4.642337217350632, 
       5.5}, {-4.9157074104439396`, 5.437499981032941}, {-4.794090994626744, 
       5.5}}], PolygonBox[{{-4.9157074104439396`, 
       5.437499981032941}, {-4.999894472779513, 5.4375}, {-4.794090994626744, 
       5.5}, {-4.9157074104439396`, 5.437499981032941}}], 
      PolygonBox[{{-4.92205804197311, 5.5}, {-4.794090994626744, 
       5.5}, {-4.999894472779513, 5.4375}, {-4.92205804197311, 5.5}}], 
      PolygonBox[{{-4.999894472779513, 5.4375}, {-5.084292589556057, 
       5.437499981032941}, {-4.92205804197311, 5.5}, {-4.999894472779513, 
       5.4375}}], 
      PolygonBox[{{-5.205909005304446, 5.5}, {-4.92205804197311, 
       5.5}, {-5.084292589556057, 5.437499981032941}, {-5.205909005304446, 
       5.5}}], PolygonBox[{{-5.084292589556057, 
       5.437499981032941}, {-5.230251642536255, 
       5.437344993353523}, {-5.205909005304446, 5.5}, {-5.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-5.357662782649366, 5.5}, {-5.205909005304446, 
       5.5}, {-5.230251642536255, 5.437344993353523}, {-5.357662782649366, 
       5.5}}], PolygonBox[{{-5.230251642536255, 
       5.437344993353523}, {-5.404942744332997, 
       5.404942744332997}, {-5.357662782649366, 5.5}, {-5.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{-4.5, 5.5}, {-5.357662782649366, 5.5}, {-5.404942744332997,
        5.404942744332997}, {-4.5, 5.5}}], 
      PolygonBox[{{-5.404942744332997, 
       5.404942744332997}, {-5.437344993353523, 5.230251642536255}, {-4.5, 
       5.5}, {-5.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-5.5, 5.357662782649369}, {-4.5, 5.5}, {-5.437344993353523,
        5.230251642536255}, {-5.5, 5.357662782649369}}], 
      PolygonBox[{{-5.437344993353523, 
       5.230251642536255}, {-5.437499981032941, 5.084292589556062}, {-5.5, 
       5.357662782649369}, {-5.437344993353523, 5.230251642536255}}], 
      PolygonBox[{{-5.5, 5.205909005282899}, {-5.5, 
       5.357662782649369}, {-5.437499981032941, 5.084292589556062}, {-5.5, 
       5.205909005282899}}], 
      PolygonBox[{{-5.437499981032941, 5.084292589556062}, {-5.4375, 
       5.000123178062996}, {-5.5, 5.205909005282899}, {-5.437499981032941, 
       5.084292589556062}}], 
      PolygonBox[{{-5.5, 5.0806786667587005`}, {-5.5, 
       5.205909005282899}, {-5.4375, 5.000123178062996}, {-5.5, 
       5.0806786667587005`}}], 
      PolygonBox[{{-5.4375, 5.000123178062996}, {-5.437499981032941, 
       4.915707410443945}, {-5.5, 5.0806786667587005`}, {-5.4375, 
       5.000123178062996}}], 
      PolygonBox[{{-5.5, 4.794090994854722}, {-5.5, 
       5.0806786667587005`}, {-5.437499981032941, 4.915707410443945}, {-5.5, 
       4.794090994854722}}], 
      PolygonBox[{{-5.437499981032941, 
       4.915707410443945}, {-5.437344993353523, 4.769748357463746}, {-5.5, 
       4.794090994854722}, {-5.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-5.5, 4.642337217350635}, {-5.5, 
       4.794090994854722}, {-5.437344993353523, 4.769748357463746}, {-5.5, 
       4.642337217350635}}], 
      PolygonBox[{{-5.437344993353523, 
       4.769748357463746}, {-5.404942744332997, 4.595057255667003}, {-5.5, 
       4.642337217350635}, {-5.437344993353523, 4.769748357463746}}], 
      PolygonBox[{{-5.5, 5.5}, {-5.5, 4.642337217350635}, {-5.404942744332997,
        4.595057255667003}, {-5.5, 5.5}}], 
      PolygonBox[{{-5.404942744332997, 
       4.595057255667003}, {-5.230251642536255, 4.562655006646477}, {-5.5, 
       5.5}, {-5.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-5.5, 4.5}, {-5.5, 5.5}, {-5.230251642536255, 
       4.562655006646477}, {-5.5, 4.5}}], 
      PolygonBox[{{-5.230251642536255, 
       4.562655006646477}, {-5.084292589556064, 4.562500018967059}, {-5.5, 
       4.5}, {-5.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-5.205909005566828, 4.5}, {-5.5, 4.5}, {-5.084292589556064,
        4.562500018967059}, {-5.205909005566828, 4.5}}], 
      PolygonBox[{{-5.084292589556064, 
       4.562500018967059}, {-4.999865158168957, 4.5625}, {-5.205909005566828, 
       4.5}, {-5.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-4.917676129598938, 4.5}, {-5.205909005566828, 
       4.5}, {-4.999865158168957, 4.5625}, {-4.917676129598938, 4.5}}], 
      PolygonBox[{{-4.999865158168957, 4.5625}, {-4.915707410443947, 
       4.562500018967059}, {-4.917676129598938, 4.5}, {-4.999865158168957, 
       4.5625}}], 
      PolygonBox[{{-4.794090994639602, 4.5}, {-4.917676129598938, 
       4.5}, {-4.915707410443947, 4.562500018967059}, {-4.794090994639602, 
       4.5}}], PolygonBox[{{-4.915707410443947, 
       4.562500018967059}, {-4.769748357463746, 
       4.562655006646477}, {-4.794090994639602, 4.5}, {-4.915707410443947, 
       4.562500018967059}}], 
      PolygonBox[{{-4.6423372173506285`, 4.5}, {-4.794090994639602, 
       4.5}, {-4.769748357463746, 4.562655006646477}, {-4.6423372173506285`, 
       4.5}}], PolygonBox[{{-4.769748357463746, 
       4.562655006646477}, {-4.595057255667003, 
       4.595057255667003}, {-4.6423372173506285`, 4.5}, {-4.769748357463746, 
       4.562655006646477}}], 
      PolygonBox[{{-4.5, 4.5}, {-4.6423372173506285`, 
       4.5}, {-4.595057255667003, 4.595057255667003}, {-4.5, 4.5}}], 
      PolygonBox[{{-4.595057255667003, 
       4.595057255667003}, {-4.595057255667003, 4.595057255667003}, {-4.5, 
       4.5}, {-4.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-4.5, 4.5}, {-4.5, 4.5}, {-4.595057255667003, 
       4.595057255667003}, {-4.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, -5.}, {-4.479166666666667, -5.}, {-4.458333333333333, \
-5.}, {-4.4375, -5.}, {-4.416666666666667, -5.}, {-4.395833333333333, -5.}, \
{-4.375, -5.}, {-4.375, -5.}, {-4.395833333333333, -5.}, {-4.416666666666667, \
-5.}, {-4.4375, -5.}, {-4.458333333333333, -5.}, {-4.479166666666667, -5.}, \
{-4.5, -5.}, {-4.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, -5.}, {-3.6041666666666665`, -5.}, \
{-3.5833333333333335`, -5.}, {-3.5625, -5.}, {-3.5416666666666665`, -5.}, \
{-3.5208333333333335`, -5.}, {-3.5, -5.}, {-3.5, -5.}, {-3.5208333333333335`, \
-5.}, {-3.5416666666666665`, -5.}, {-3.5625, -5.}, {-3.5833333333333335`, \
-5.}, {-3.6041666666666665`, -5.}, {-3.625, -5.}, {-3.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -5.5}, {-4., -5.479166666666667}, {-4., \
-5.458333333333333}, {-4., -5.4375}, {-4., -5.416666666666667}, {-4., \
-5.395833333333333}, {-4., -5.375}, {-4., -5.375}, {-4., -5.395833333333333}, \
{-4., -5.416666666666667}, {-4., -5.4375}, {-4., -5.458333333333333}, {-4., \
-5.479166666666667}, {-4., -5.5}, {-4., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -4.625}, {-4., -4.604166666666667}, {-4., \
-4.583333333333333}, {-4., -4.5625}, {-4., -4.541666666666667}, {-4., \
-4.520833333333333}, {-4., -4.5}, {-4., -4.5}, {-4., -4.520833333333333}, \
{-4., -4.541666666666667}, {-4., -4.5625}, {-4., -4.583333333333333}, {-4., \
-4.604166666666667}, {-4., -4.625}, {-4., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, -5.}, {-4.25, -5.}, {-4.125, -5.}, {-4., -5.}, \
{-3.875, -5.}, {-3.75, -5.}, {-3.625, -5.}, {-3.625, -5.}, {-3.75, -5.}, \
{-3.875, -5.}, {-4., -5.}, {-4.125, -5.}, {-4.25, -5.}, {-4.375, -5.}, \
{-4.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -5.375}, {-4., -5.25}, {-4., -5.125}, {-4., -5.}, {-4., \
-4.875}, {-4., -4.75}, {-4., -4.625}, {-4., -4.625}, {-4., -4.75}, {-4., \
-4.875}, {-4., -5.}, {-4., -5.125}, {-4., -5.25}, {-4., -5.375}, {-4., \
-5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByC0yAExvUBHbSneAzd7y3jnzhE+cGGHedWT
NKi8g/CBVKEUtY8PeA8YcRpNrvggBBFv4DuQcUfatmiz0IGN0m+lrCz5D3BP
X7FAtBcqzyAAVSd0QL2o81NSsgCq/AEBuP5z387mtPMLws2fofzkUK+PINz+
rxnh8a+KBA/cgLoPYq4g3P0weYg9Iqj6D4jAzT8LpkXh9kPUiR7QgLoPYo4o
mvtFD2yC+g8mzwj1P0w/LHzOQc1HCb8DiPDVgLoPPfwBdiyOGQ==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByC00IFQMOCF81evAgE+OB9CC6DJC6DpF0RT
T5iGmIPgQ8wRRlMngqZeBE29KJp6MQw+qvvE0NwPUy+AJs8H54ehhA9MPQ9B
Pqr7eNDcD1MvgqZeGE29EJp6oQMA/MhfdQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, -5.265165042944956}, \
{-3.6752404735808355`, -5.1875}, {-3.595057255667003, -5.404942744332997}, \
{-3.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{-3.5626550066464766`, -5.230251642536255}, \
{-3.595057255667003, -5.404942744332997}, {-3.6752404735808355`, -5.1875}, \
{-3.5626550066464766`, -5.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, -5.1875}, {-3.6377778151415994`, \
-5.097057141913445}, {-3.5626550066464766`, -5.230251642536255}, \
{-3.6752404735808355`, -5.1875}}], 
      PolygonBox[{{-3.562500018967059, -5.084292589556062}, \
{-3.5626550066464766`, -5.230251642536255}, {-3.6377778151415994`, \
-5.097057141913445}, {-3.562500018967059, -5.084292589556062}}], 
      PolygonBox[{{-3.6377778151415994`, -5.097057141913445}, {-3.625, -5.}, \
{-3.562500018967059, -5.084292589556062}, {-3.6377778151415994`, \
-5.097057141913445}}], 
      PolygonBox[{{-3.5625, -5.}, {-3.562500018967059, -5.084292589556062}, \
{-3.625, -5.}, {-3.5625, -5.}}], 
      PolygonBox[{{-3.625, -5.}, {-3.6377778151415994`, -4.902942858086555}, \
{-3.5625, -5.}, {-3.625, -5.}}], 
      PolygonBox[{{-3.562500018967059, -4.915707410443939}, {-3.5625, -5.}, \
{-3.6377778151415994`, -4.902942858086555}, {-3.562500018967059, \
-4.915707410443939}}], 
      PolygonBox[{{-3.6377778151415994`, -4.902942858086555}, \
{-3.6752404735808355`, -4.8125}, {-3.562500018967059, -4.915707410443939}, \
{-3.6377778151415994`, -4.902942858086555}}], 
      PolygonBox[{{-3.5626550066464766`, -4.769748357463745}, \
{-3.562500018967059, -4.915707410443939}, {-3.6752404735808355`, -4.8125}, \
{-3.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{-3.6752404735808355`, -4.8125}, {-3.7348349570550448`, \
-4.734834957055044}, {-3.5626550066464766`, -4.769748357463745}, \
{-3.6752404735808355`, -4.8125}}], 
      PolygonBox[{{-3.595057255667003, -4.595057255667003}, \
{-3.5626550066464766`, -4.769748357463745}, {-3.7348349570550448`, \
-4.734834957055044}, {-3.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{-3.7348349570550448`, -4.734834957055044}, {-3.8125, \
-4.6752404735808355`}, {-3.595057255667003, -4.595057255667003}, \
{-3.7348349570550448`, -4.734834957055044}}], 
      PolygonBox[{{-3.7697483574637447`, -4.562655006646477}, \
{-3.595057255667003, -4.595057255667003}, {-3.8125, -4.6752404735808355`}, \
{-3.7697483574637447`, -4.562655006646477}}], 
      PolygonBox[{{-3.8125, -4.6752404735808355`}, {-3.9029428580865546`, \
-4.637777815141599}, {-3.7697483574637447`, -4.562655006646477}, {-3.8125, \
-4.6752404735808355`}}], 
      PolygonBox[{{-3.9157074104439396`, -4.562500018967059}, \
{-3.7697483574637447`, -4.562655006646477}, {-3.9029428580865546`, \
-4.637777815141599}, {-3.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-3.9029428580865546`, -4.637777815141599}, {-4., -4.625}, \
{-3.9157074104439396`, -4.562500018967059}, {-3.9029428580865546`, \
-4.637777815141599}}], 
      PolygonBox[{{-3.9998944727795123`, -4.5625}, {-3.9157074104439396`, \
-4.562500018967059}, {-4., -4.625}, {-3.9998944727795123`, -4.5625}}], 
      PolygonBox[{{-4., -4.625}, {-4.097057141913445, -4.637777815141599}, \
{-3.9998944727795123`, -4.5625}, {-4., -4.625}}], 
      PolygonBox[{{-4.084292589556057, -4.562500018967059}, \
{-3.9998944727795123`, -4.5625}, {-4.097057141913445, -4.637777815141599}, \
{-4.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-4.097057141913445, -4.637777815141599}, {-4.1875, \
-4.6752404735808355`}, {-4.084292589556057, -4.562500018967059}, \
{-4.097057141913445, -4.637777815141599}}], 
      PolygonBox[{{-4.230251642536255, -4.562655006646477}, \
{-4.084292589556057, -4.562500018967059}, {-4.1875, -4.6752404735808355`}, \
{-4.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-4.1875, -4.6752404735808355`}, {-4.265165042944956, \
-4.734834957055044}, {-4.230251642536255, -4.562655006646477}, {-4.1875, \
-4.6752404735808355`}}], 
      PolygonBox[{{-4.404942744332997, -4.595057255667003}, \
{-4.230251642536255, -4.562655006646477}, {-4.265165042944956, \
-4.734834957055044}, {-4.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{-4.265165042944956, -4.734834957055044}, \
{-4.3247595264191645`, -4.8125}, {-4.404942744332997, -4.595057255667003}, \
{-4.265165042944956, -4.734834957055044}}], 
      PolygonBox[{{-4.437344993353523, -4.769748357463745}, \
{-4.404942744332997, -4.595057255667003}, {-4.3247595264191645`, -4.8125}, \
{-4.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{-4.3247595264191645`, -4.8125}, {-4.362222184858401, \
-4.902942858086554}, {-4.437344993353523, -4.769748357463745}, \
{-4.3247595264191645`, -4.8125}}], 
      PolygonBox[{{-4.437499981032941, -4.915707410443938}, \
{-4.437344993353523, -4.769748357463745}, {-4.362222184858401, \
-4.902942858086554}, {-4.437499981032941, -4.915707410443938}}], 
      PolygonBox[{{-4.362222184858401, -4.902942858086554}, {-4.375, -5.}, \
{-4.437499981032941, -4.915707410443938}, {-4.362222184858401, \
-4.902942858086554}}], 
      PolygonBox[{{-4.4375, -4.999876821937004}, {-4.437499981032941, \
-4.915707410443938}, {-4.375, -5.}, {-4.4375, -4.999876821937004}}], 
      PolygonBox[{{-4.375, -5.}, {-4.362222184858401, -5.097057141913445}, \
{-4.4375, -4.999876821937004}, {-4.375, -5.}}], 
      PolygonBox[{{-4.437499981032941, -5.084292589556055}, {-4.4375, \
-4.999876821937004}, {-4.362222184858401, -5.097057141913445}, \
{-4.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-4.362222184858401, -5.097057141913445}, \
{-4.3247595264191645`, -5.1875}, {-4.437499981032941, -5.084292589556055}, \
{-4.362222184858401, -5.097057141913445}}], 
      PolygonBox[{{-4.437344993353523, -5.230251642536254}, \
{-4.437499981032941, -5.084292589556055}, {-4.3247595264191645`, -5.1875}, \
{-4.437344993353523, -5.230251642536254}}], 
      PolygonBox[{{-4.3247595264191645`, -5.1875}, {-4.265165042944956, \
-5.265165042944956}, {-4.437344993353523, -5.230251642536254}, \
{-4.3247595264191645`, -5.1875}}], 
      PolygonBox[{{-4.404942744332997, -5.404942744332997}, \
{-4.437344993353523, -5.230251642536254}, {-4.265165042944956, \
-5.265165042944956}, {-4.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, -5.265165042944956}, {-4.1875, \
-5.3247595264191645`}, {-4.404942744332997, -5.404942744332997}, \
{-4.265165042944956, -5.265165042944956}}], 
      PolygonBox[{{-4.230251642536255, -5.437344993353523}, \
{-4.404942744332997, -5.404942744332997}, {-4.1875, -5.3247595264191645`}, \
{-4.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{-4.1875, -5.3247595264191645`}, {-4.097057141913446, \
-5.362222184858401}, {-4.230251642536255, -5.437344993353523}, {-4.1875, \
-5.3247595264191645`}}], 
      PolygonBox[{{-4.084292589556064, -5.437499981032941}, \
{-4.230251642536255, -5.437344993353523}, {-4.097057141913446, \
-5.362222184858401}, {-4.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-4.097057141913446, -5.362222184858401}, {-4., -5.375}, \
{-4.084292589556064, -5.437499981032941}, {-4.097057141913446, \
-5.362222184858401}}], 
      PolygonBox[{{-3.999865158168957, -5.4375}, {-4.084292589556064, \
-5.437499981032941}, {-4., -5.375}, {-3.999865158168957, -5.4375}}], 
      PolygonBox[{{-4., -5.375}, {-3.902942858086555, -5.362222184858401}, \
{-3.999865158168957, -5.4375}, {-4., -5.375}}], 
      PolygonBox[{{-3.9157074104439467`, -5.437499981032941}, \
{-3.999865158168957, -5.4375}, {-3.902942858086555, -5.362222184858401}, \
{-3.9157074104439467`, -5.437499981032941}}], 
      PolygonBox[{{-3.902942858086555, -5.362222184858401}, \
{-3.8125000000000004`, -5.3247595264191645`}, {-3.9157074104439467`, \
-5.437499981032941}, {-3.902942858086555, -5.362222184858401}}], 
      PolygonBox[{{-3.769748357463745, -5.437344993353523}, \
{-3.9157074104439467`, -5.437499981032941}, {-3.8125000000000004`, \
-5.3247595264191645`}, {-3.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{-3.8125000000000004`, -5.3247595264191645`}, \
{-3.7348349570550448`, -5.265165042944956}, {-3.769748357463745, \
-5.437344993353523}, {-3.8125000000000004`, -5.3247595264191645`}}], 
      PolygonBox[{{-3.595057255667003, -5.404942744332997}, \
{-3.769748357463745, -5.437344993353523}, {-3.7348349570550448`, \
-5.265165042944956}, {-3.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, -5.265165042944956}, \
{-3.7348349570550448`, -5.265165042944956}, {-3.595057255667003, \
-5.404942744332997}, {-3.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{-3.595057255667003, -5.404942744332997}, \
{-3.595057255667003, -5.404942744332997}, {-3.7348349570550448`, \
-5.265165042944956}, {-3.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-3.595057255667003, -5.404942744332997}, \
{-3.5626550066464766`, -5.230251642536255}, {-3.5, -5.5}, \
{-3.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-3.5, -5.357662782649368}, {-3.5, -5.5}, \
{-3.5626550066464766`, -5.230251642536255}, {-3.5, -5.357662782649368}}], 
      PolygonBox[{{-3.5626550066464766`, -5.230251642536255}, \
{-3.562500018967059, -5.084292589556062}, {-3.5, -5.357662782649368}, \
{-3.5626550066464766`, -5.230251642536255}}], 
      PolygonBox[{{-3.5, -5.20590900530174}, {-3.5, -5.357662782649368}, \
{-3.562500018967059, -5.084292589556062}, {-3.5, -5.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, -5.084292589556062}, {-3.5625, -5.}, \
{-3.5, -5.20590900530174}, {-3.562500018967059, -5.084292589556062}}], 
      PolygonBox[{{-3.5, -5.}, {-3.5, -5.20590900530174}, {-3.5625, -5.}, \
{-3.5, -5.}}], 
      PolygonBox[{{-3.5625, -5.}, {-3.562500018967059, -4.915707410443939}, \
{-3.5, -5.}, {-3.5625, -5.}}], 
      PolygonBox[{{-3.5, -4.79409099469826}, {-3.5, -5.}, \
{-3.562500018967059, -4.915707410443939}, {-3.5, -4.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, -4.915707410443939}, \
{-3.5626550066464766`, -4.769748357463745}, {-3.5, -4.79409099469826}, \
{-3.562500018967059, -4.915707410443939}}], 
      PolygonBox[{{-3.5, -4.642337217350632}, {-3.5, -4.79409099469826}, \
{-3.5626550066464766`, -4.769748357463745}, {-3.5, -4.642337217350632}}], 
      PolygonBox[{{-3.5626550066464766`, -4.769748357463745}, \
{-3.595057255667003, -4.595057255667003}, {-3.5, -4.642337217350632}, \
{-3.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{-3.508553435038814, -4.508553435038814}, {-3.5, \
-4.642337217350632}, {-3.595057255667003, -4.595057255667003}, \
{-3.508553435038814, -4.508553435038814}}], 
      PolygonBox[{{-3.595057255667003, -4.595057255667003}, \
{-3.7697483574637447`, -4.562655006646477}, {-3.508553435038814, \
-4.508553435038814}, {-3.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{-3.642337217350632, -4.5}, {-3.508553435038814, \
-4.508553435038814}, {-3.7697483574637447`, -4.562655006646477}, \
{-3.642337217350632, -4.5}}], 
      PolygonBox[{{-3.7697483574637447`, -4.562655006646477}, \
{-3.9157074104439396`, -4.562500018967059}, {-3.642337217350632, -4.5}, \
{-3.7697483574637447`, -4.562655006646477}}], 
      PolygonBox[{{-3.7940909946267443`, -4.5}, {-3.642337217350632, -4.5}, \
{-3.9157074104439396`, -4.562500018967059}, {-3.7940909946267443`, -4.5}}], 
      PolygonBox[{{-3.9157074104439396`, -4.562500018967059}, \
{-3.9998944727795123`, -4.5625}, {-3.7940909946267443`, -4.5}, \
{-3.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-3.92205804197311, -4.5}, {-3.7940909946267443`, -4.5}, \
{-3.9998944727795123`, -4.5625}, {-3.92205804197311, -4.5}}], 
      PolygonBox[{{-3.9998944727795123`, -4.5625}, {-4.084292589556057, \
-4.562500018967059}, {-3.92205804197311, -4.5}, {-3.9998944727795123`, \
-4.5625}}], 
      PolygonBox[{{-4.205909005304446, -4.5}, {-3.92205804197311, -4.5}, \
{-4.084292589556057, -4.562500018967059}, {-4.205909005304446, -4.5}}], 
      PolygonBox[{{-4.084292589556057, -4.562500018967059}, \
{-4.230251642536255, -4.562655006646477}, {-4.205909005304446, -4.5}, \
{-4.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-4.357662782649366, -4.5}, {-4.205909005304446, -4.5}, \
{-4.230251642536255, -4.562655006646477}, {-4.357662782649366, -4.5}}], 
      PolygonBox[{{-4.230251642536255, -4.562655006646477}, \
{-4.404942744332997, -4.595057255667003}, {-4.357662782649366, -4.5}, \
{-4.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-3.5, -4.5}, {-4.357662782649366, -4.5}, \
{-4.404942744332997, -4.595057255667003}, {-3.5, -4.5}}], 
      PolygonBox[{{-4.404942744332997, -4.595057255667003}, \
{-4.437344993353523, -4.769748357463745}, {-3.5, -4.5}, {-4.404942744332997, \
-4.595057255667003}}], 
      PolygonBox[{{-4.5, -4.642337217350631}, {-3.5, -4.5}, \
{-4.437344993353523, -4.769748357463745}, {-4.5, -4.642337217350631}}], 
      PolygonBox[{{-4.437344993353523, -4.769748357463745}, \
{-4.437499981032941, -4.915707410443938}, {-4.5, -4.642337217350631}, \
{-4.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{-4.5, -4.794090994717101}, {-4.5, -4.642337217350631}, \
{-4.437499981032941, -4.915707410443938}, {-4.5, -4.794090994717101}}], 
      PolygonBox[{{-4.437499981032941, -4.915707410443938}, {-4.4375, \
-4.999876821937004}, {-4.5, -4.794090994717101}, {-4.437499981032941, \
-4.915707410443938}}], 
      PolygonBox[{{-4.5, -4.9193213332412995`}, {-4.5, -4.794090994717101}, \
{-4.4375, -4.999876821937004}, {-4.5, -4.9193213332412995`}}], 
      PolygonBox[{{-4.4375, -4.999876821937004}, {-4.437499981032941, \
-5.084292589556055}, {-4.5, -4.9193213332412995`}, {-4.4375, \
-4.999876821937004}}], 
      PolygonBox[{{-4.5, -5.205909005145278}, {-4.5, -4.9193213332412995`}, \
{-4.437499981032941, -5.084292589556055}, {-4.5, -5.205909005145278}}], 
      PolygonBox[{{-4.437499981032941, -5.084292589556055}, \
{-4.437344993353523, -5.230251642536254}, {-4.5, -5.205909005145278}, \
{-4.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-4.5, -5.357662782649365}, {-4.5, -5.205909005145278}, \
{-4.437344993353523, -5.230251642536254}, {-4.5, -5.357662782649365}}], 
      PolygonBox[{{-4.437344993353523, -5.230251642536254}, \
{-4.404942744332997, -5.404942744332997}, {-4.5, -5.357662782649365}, \
{-4.437344993353523, -5.230251642536254}}], 
      PolygonBox[{{-4.5, -4.5}, {-4.5, -5.357662782649365}, \
{-4.404942744332997, -5.404942744332997}, {-4.5, -4.5}}], 
      PolygonBox[{{-4.404942744332997, -5.404942744332997}, \
{-4.230251642536255, -5.437344993353523}, {-4.5, -4.5}, {-4.404942744332997, \
-5.404942744332997}}], 
      PolygonBox[{{-4.5, -5.5}, {-4.5, -4.5}, {-4.230251642536255, \
-5.437344993353523}, {-4.5, -5.5}}], 
      PolygonBox[{{-4.230251642536255, -5.437344993353523}, \
{-4.084292589556064, -5.437499981032941}, {-4.5, -5.5}, {-4.230251642536255, \
-5.437344993353523}}], 
      PolygonBox[{{-4.205909005566828, -5.5}, {-4.5, -5.5}, \
{-4.084292589556064, -5.437499981032941}, {-4.205909005566828, -5.5}}], 
      PolygonBox[{{-4.084292589556064, -5.437499981032941}, \
{-3.999865158168957, -5.4375}, {-4.205909005566828, -5.5}, \
{-4.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-3.9176761295989384`, -5.5}, {-4.205909005566828, -5.5}, \
{-3.999865158168957, -5.4375}, {-3.9176761295989384`, -5.5}}], 
      PolygonBox[{{-3.999865158168957, -5.4375}, {-3.9157074104439467`, \
-5.437499981032941}, {-3.9176761295989384`, -5.5}, {-3.999865158168957, \
-5.4375}}], 
      PolygonBox[{{-3.7940909946396024`, -5.5}, {-3.9176761295989384`, -5.5}, \
{-3.9157074104439467`, -5.437499981032941}, {-3.7940909946396024`, -5.5}}], 
      PolygonBox[{{-3.9157074104439467`, -5.437499981032941}, \
{-3.769748357463745, -5.437344993353523}, {-3.7940909946396024`, -5.5}, \
{-3.9157074104439467`, -5.437499981032941}}], 
      PolygonBox[{{-3.642337217350629, -5.5}, {-3.7940909946396024`, -5.5}, \
{-3.769748357463745, -5.437344993353523}, {-3.642337217350629, -5.5}}], 
      PolygonBox[{{-3.769748357463745, -5.437344993353523}, \
{-3.595057255667003, -5.404942744332997}, {-3.642337217350629, -5.5}, \
{-3.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{-3.5, -5.5}, {-3.642337217350629, -5.5}, \
{-3.595057255667003, -5.404942744332997}, {-3.5, -5.5}}], 
      PolygonBox[{{-3.595057255667003, -5.404942744332997}, \
{-3.595057255667003, -5.404942744332997}, {-3.5, -5.5}, {-3.595057255667003, \
-5.404942744332997}}], 
      PolygonBox[{{-3.5, -5.5}, {-3.5, -5.5}, {-3.595057255667003, \
-5.404942744332997}, {-3.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, -4.}, {-4.479166666666667, -4.}, {-4.458333333333333, \
-4.}, {-4.4375, -4.}, {-4.416666666666667, -4.}, {-4.395833333333333, -4.}, \
{-4.375, -4.}, {-4.375, -4.}, {-4.395833333333333, -4.}, {-4.416666666666667, \
-4.}, {-4.4375, -4.}, {-4.458333333333333, -4.}, {-4.479166666666667, -4.}, \
{-4.5, -4.}, {-4.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, -4.}, {-3.6041666666666665`, -4.}, \
{-3.5833333333333335`, -4.}, {-3.5625, -4.}, {-3.5416666666666665`, -4.}, \
{-3.5208333333333335`, -4.}, {-3.5, -4.}, {-3.5, -4.}, {-3.5208333333333335`, \
-4.}, {-3.5416666666666665`, -4.}, {-3.5625, -4.}, {-3.5833333333333335`, \
-4.}, {-3.6041666666666665`, -4.}, {-3.625, -4.}, {-3.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -4.5}, {-4., -4.479166666666667}, {-4., \
-4.458333333333333}, {-4., -4.4375}, {-4., -4.416666666666667}, {-4., \
-4.395833333333333}, {-4., -4.375}, {-4., -4.375}, {-4., -4.395833333333333}, \
{-4., -4.416666666666667}, {-4., -4.4375}, {-4., -4.458333333333333}, {-4., \
-4.479166666666667}, {-4., -4.5}, {-4., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -3.625}, {-4., -3.6041666666666665`}, {-4., \
-3.5833333333333335`}, {-4., -3.5625}, {-4., -3.5416666666666665`}, {-4., \
-3.5208333333333335`}, {-4., -3.5}, {-4., -3.5}, {-4., -3.5208333333333335`}, \
{-4., -3.5416666666666665`}, {-4., -3.5625}, {-4., -3.5833333333333335`}, \
{-4., -3.6041666666666665`}, {-4., -3.625}, {-4., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, -4.}, {-4.25, -4.}, {-4.125, -4.}, {-4., -4.}, \
{-3.875, -4.}, {-3.75, -4.}, {-3.625, -4.}, {-3.625, -4.}, {-3.75, -4.}, \
{-3.875, -4.}, {-4., -4.}, {-4.125, -4.}, {-4.25, -4.}, {-4.375, -4.}, \
{-4.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -4.375}, {-4., -4.25}, {-4., -4.125}, {-4., -4.}, {-4., \
-3.875}, {-4., -3.75}, {-4., -3.625}, {-4., -3.625}, {-4., -3.75}, {-4., \
-3.875}, {-4., -4.}, {-4., -4.125}, {-4., -4.25}, {-4., -4.375}, {-4., \
-4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByC0wAExvUBHbSneAxul30pZWfIfuLDDvOpJ
GlS+ge9AqlCK2scHvHAaJg5TB9MHMwdmLswe9aLOT0nJAqjyBwTg+s99O5vT
zi8IN3+G8pNDvT6CcHu+ZoTHvyoShNsDEReE2wOTh9mDoh9oD8z8s1AaJg5T
pwHVBzMHxf1AezZB7YXJM0LdBdMPczfMHpTwO4DwN8we9PAHAI7bi2s=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8B2B0KBjwwvmrV4EA3wFUdQJo8gJo+gXR1AsR
5KPaK4RmL0y9AJq8AJp+QTT1mDS6OnRzsNuDcEcYmjuJ9Sd6uKCHG6q9mOEe
hhYvMBoAg1Re8A==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, -4.265165042944956}, \
{-3.6752404735808355`, -4.1875}, {-3.595057255667003, -4.404942744332997}, \
{-3.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{-3.5626550066464766`, -4.230251642536255}, \
{-3.595057255667003, -4.404942744332997}, {-3.6752404735808355`, -4.1875}, \
{-3.5626550066464766`, -4.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, -4.1875}, {-3.6377778151415994`, \
-4.097057141913445}, {-3.5626550066464766`, -4.230251642536255}, \
{-3.6752404735808355`, -4.1875}}], 
      PolygonBox[{{-3.562500018967059, -4.084292589556062}, \
{-3.5626550066464766`, -4.230251642536255}, {-3.6377778151415994`, \
-4.097057141913445}, {-3.562500018967059, -4.084292589556062}}], 
      PolygonBox[{{-3.6377778151415994`, -4.097057141913445}, {-3.625, -4.}, \
{-3.562500018967059, -4.084292589556062}, {-3.6377778151415994`, \
-4.097057141913445}}], 
      PolygonBox[{{-3.5625, -4.}, {-3.562500018967059, -4.084292589556062}, \
{-3.625, -4.}, {-3.5625, -4.}}], 
      PolygonBox[{{-3.625, -4.}, {-3.6377778151415994`, \
-3.9029428580865546`}, {-3.5625, -4.}, {-3.625, -4.}}], 
      PolygonBox[{{-3.562500018967059, -3.915707410443938}, {-3.5625, -4.}, \
{-3.6377778151415994`, -3.9029428580865546`}, {-3.562500018967059, \
-3.915707410443938}}], 
      PolygonBox[{{-3.6377778151415994`, -3.9029428580865546`}, \
{-3.6752404735808355`, -3.8125}, {-3.562500018967059, -3.915707410443938}, \
{-3.6377778151415994`, -3.9029428580865546`}}], 
      PolygonBox[{{-3.5626550066464766`, -3.769748357463745}, \
{-3.562500018967059, -3.915707410443938}, {-3.6752404735808355`, -3.8125}, \
{-3.5626550066464766`, -3.769748357463745}}], 
      PolygonBox[{{-3.6752404735808355`, -3.8125}, {-3.7348349570550448`, \
-3.7348349570550448`}, {-3.5626550066464766`, -3.769748357463745}, \
{-3.6752404735808355`, -3.8125}}], 
      PolygonBox[{{-3.595057255667003, -3.595057255667003}, \
{-3.5626550066464766`, -3.769748357463745}, {-3.7348349570550448`, \
-3.7348349570550448`}, {-3.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{-3.7348349570550448`, -3.7348349570550448`}, {-3.8125, \
-3.6752404735808355`}, {-3.595057255667003, -3.595057255667003}, \
{-3.7348349570550448`, -3.7348349570550448`}}], 
      PolygonBox[{{-3.7697483574637447`, -3.5626550066464766`}, \
{-3.595057255667003, -3.595057255667003}, {-3.8125, -3.6752404735808355`}, \
{-3.7697483574637447`, -3.5626550066464766`}}], 
      PolygonBox[{{-3.8125, -3.6752404735808355`}, {-3.9029428580865546`, \
-3.6377778151415994`}, {-3.7697483574637447`, -3.5626550066464766`}, \
{-3.8125, -3.6752404735808355`}}], 
      PolygonBox[{{-3.9157074104439396`, -3.562500018967059}, \
{-3.7697483574637447`, -3.5626550066464766`}, {-3.9029428580865546`, \
-3.6377778151415994`}, {-3.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-3.9029428580865546`, -3.6377778151415994`}, {-4., \
-3.625}, {-3.9157074104439396`, -3.562500018967059}, {-3.9029428580865546`, \
-3.6377778151415994`}}], 
      PolygonBox[{{-3.9998944727795123`, -3.5625}, {-3.9157074104439396`, \
-3.562500018967059}, {-4., -3.625}, {-3.9998944727795123`, -3.5625}}], 
      PolygonBox[{{-4., -3.625}, {-4.097057141913445, -3.6377778151415994`}, \
{-3.9998944727795123`, -3.5625}, {-4., -3.625}}], 
      PolygonBox[{{-4.084292589556057, -3.562500018967059}, \
{-3.9998944727795123`, -3.5625}, {-4.097057141913445, -3.6377778151415994`}, \
{-4.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-4.097057141913445, -3.6377778151415994`}, {-4.1875, \
-3.6752404735808355`}, {-4.084292589556057, -3.562500018967059}, \
{-4.097057141913445, -3.6377778151415994`}}], 
      PolygonBox[{{-4.230251642536255, -3.5626550066464766`}, \
{-4.084292589556057, -3.562500018967059}, {-4.1875, -3.6752404735808355`}, \
{-4.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-4.1875, -3.6752404735808355`}, {-4.265165042944956, \
-3.7348349570550448`}, {-4.230251642536255, -3.5626550066464766`}, {-4.1875, \
-3.6752404735808355`}}], 
      PolygonBox[{{-4.404942744332997, -3.595057255667003}, \
{-4.230251642536255, -3.5626550066464766`}, {-4.265165042944956, \
-3.7348349570550448`}, {-4.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-4.265165042944956, -3.7348349570550448`}, \
{-4.3247595264191645`, -3.8125}, {-4.404942744332997, -3.595057255667003}, \
{-4.265165042944956, -3.7348349570550448`}}], 
      PolygonBox[{{-4.437344993353523, -3.7697483574637447`}, \
{-4.404942744332997, -3.595057255667003}, {-4.3247595264191645`, -3.8125}, \
{-4.437344993353523, -3.7697483574637447`}}], 
      PolygonBox[{{-4.3247595264191645`, -3.8125}, {-4.362222184858401, \
-3.9029428580865546`}, {-4.437344993353523, -3.7697483574637447`}, \
{-4.3247595264191645`, -3.8125}}], 
      PolygonBox[{{-4.437499981032941, -3.9157074104439378`}, \
{-4.437344993353523, -3.7697483574637447`}, {-4.362222184858401, \
-3.9029428580865546`}, {-4.437499981032941, -3.9157074104439378`}}], 
      PolygonBox[{{-4.362222184858401, -3.9029428580865546`}, {-4.375, -4.}, \
{-4.437499981032941, -3.9157074104439378`}, {-4.362222184858401, \
-3.9029428580865546`}}], 
      PolygonBox[{{-4.4375, -3.9998768219370047`}, {-4.437499981032941, \
-3.9157074104439378`}, {-4.375, -4.}, {-4.4375, -3.9998768219370047`}}], 
      PolygonBox[{{-4.375, -4.}, {-4.362222184858401, -4.097057141913445}, \
{-4.4375, -3.9998768219370047`}, {-4.375, -4.}}], 
      PolygonBox[{{-4.437499981032941, -4.084292589556055}, {-4.4375, \
-3.9998768219370047`}, {-4.362222184858401, -4.097057141913445}, \
{-4.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-4.362222184858401, -4.097057141913445}, \
{-4.3247595264191645`, -4.1875}, {-4.437499981032941, -4.084292589556055}, \
{-4.362222184858401, -4.097057141913445}}], 
      PolygonBox[{{-4.437344993353523, -4.230251642536254}, \
{-4.437499981032941, -4.084292589556055}, {-4.3247595264191645`, -4.1875}, \
{-4.437344993353523, -4.230251642536254}}], 
      PolygonBox[{{-4.3247595264191645`, -4.1875}, {-4.265165042944956, \
-4.265165042944956}, {-4.437344993353523, -4.230251642536254}, \
{-4.3247595264191645`, -4.1875}}], 
      PolygonBox[{{-4.404942744332997, -4.404942744332997}, \
{-4.437344993353523, -4.230251642536254}, {-4.265165042944956, \
-4.265165042944956}, {-4.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, -4.265165042944956}, {-4.1875, \
-4.3247595264191645`}, {-4.404942744332997, -4.404942744332997}, \
{-4.265165042944956, -4.265165042944956}}], 
      PolygonBox[{{-4.230251642536255, -4.437344993353523}, \
{-4.404942744332997, -4.404942744332997}, {-4.1875, -4.3247595264191645`}, \
{-4.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{-4.1875, -4.3247595264191645`}, {-4.097057141913446, \
-4.362222184858401}, {-4.230251642536255, -4.437344993353523}, {-4.1875, \
-4.3247595264191645`}}], 
      PolygonBox[{{-4.084292589556064, -4.437499981032941}, \
{-4.230251642536255, -4.437344993353523}, {-4.097057141913446, \
-4.362222184858401}, {-4.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-4.097057141913446, -4.362222184858401}, {-4., -4.375}, \
{-4.084292589556064, -4.437499981032941}, {-4.097057141913446, \
-4.362222184858401}}], 
      PolygonBox[{{-3.999865158168957, -4.4375}, {-4.084292589556064, \
-4.437499981032941}, {-4., -4.375}, {-3.999865158168957, -4.4375}}], 
      PolygonBox[{{-4., -4.375}, {-3.902942858086555, -4.362222184858401}, \
{-3.999865158168957, -4.4375}, {-4., -4.375}}], 
      PolygonBox[{{-3.9157074104439467`, -4.437499981032941}, \
{-3.999865158168957, -4.4375}, {-3.902942858086555, -4.362222184858401}, \
{-3.9157074104439467`, -4.437499981032941}}], 
      PolygonBox[{{-3.902942858086555, -4.362222184858401}, \
{-3.8125000000000004`, -4.3247595264191645`}, {-3.9157074104439467`, \
-4.437499981032941}, {-3.902942858086555, -4.362222184858401}}], 
      PolygonBox[{{-3.769748357463745, -4.437344993353523}, \
{-3.9157074104439467`, -4.437499981032941}, {-3.8125000000000004`, \
-4.3247595264191645`}, {-3.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{-3.8125000000000004`, -4.3247595264191645`}, \
{-3.7348349570550448`, -4.265165042944956}, {-3.769748357463745, \
-4.437344993353523}, {-3.8125000000000004`, -4.3247595264191645`}}], 
      PolygonBox[{{-3.595057255667003, -4.404942744332997}, \
{-3.769748357463745, -4.437344993353523}, {-3.7348349570550448`, \
-4.265165042944956}, {-3.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, -4.265165042944956}, \
{-3.7348349570550448`, -4.265165042944956}, {-3.595057255667003, \
-4.404942744332997}, {-3.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{-3.595057255667003, -4.404942744332997}, \
{-3.595057255667003, -4.404942744332997}, {-3.7348349570550448`, \
-4.265165042944956}, {-3.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-3.595057255667003, -4.404942744332997}, \
{-3.5626550066464766`, -4.230251642536255}, {-3.5, -4.5}, \
{-3.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-3.5, -4.357662782649368}, {-3.5, -4.5}, \
{-3.5626550066464766`, -4.230251642536255}, {-3.5, -4.357662782649368}}], 
      PolygonBox[{{-3.5626550066464766`, -4.230251642536255}, \
{-3.562500018967059, -4.084292589556062}, {-3.5, -4.357662782649368}, \
{-3.5626550066464766`, -4.230251642536255}}], 
      PolygonBox[{{-3.5, -4.20590900530174}, {-3.5, -4.357662782649368}, \
{-3.562500018967059, -4.084292589556062}, {-3.5, -4.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, -4.084292589556062}, {-3.5625, -4.}, \
{-3.5, -4.20590900530174}, {-3.562500018967059, -4.084292589556062}}], 
      PolygonBox[{{-3.5, -4.}, {-3.5, -4.20590900530174}, {-3.5625, -4.}, \
{-3.5, -4.}}], 
      PolygonBox[{{-3.5625, -4.}, {-3.562500018967059, -3.915707410443938}, \
{-3.5, -4.}, {-3.5625, -4.}}], 
      PolygonBox[{{-3.5, -3.79409099469826}, {-3.5, -4.}, \
{-3.562500018967059, -3.915707410443938}, {-3.5, -3.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, -3.915707410443938}, \
{-3.5626550066464766`, -3.769748357463745}, {-3.5, -3.79409099469826}, \
{-3.562500018967059, -3.915707410443938}}], 
      PolygonBox[{{-3.5, -3.6423372173506325`}, {-3.5, -3.79409099469826}, \
{-3.5626550066464766`, -3.769748357463745}, {-3.5, -3.6423372173506325`}}], 
      PolygonBox[{{-3.5626550066464766`, -3.769748357463745}, \
{-3.595057255667003, -3.595057255667003}, {-3.5, -3.6423372173506325`}, \
{-3.5626550066464766`, -3.769748357463745}}], 
      PolygonBox[{{-3.508553435038814, -3.508553435038814}, {-3.5, \
-3.6423372173506325`}, {-3.595057255667003, -3.595057255667003}, \
{-3.508553435038814, -3.508553435038814}}], 
      PolygonBox[{{-3.595057255667003, -3.595057255667003}, \
{-3.7697483574637447`, -3.5626550066464766`}, {-3.508553435038814, \
-3.508553435038814}, {-3.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{-3.642337217350632, -3.5}, {-3.508553435038814, \
-3.508553435038814}, {-3.7697483574637447`, -3.5626550066464766`}, \
{-3.642337217350632, -3.5}}], 
      PolygonBox[{{-3.7697483574637447`, -3.5626550066464766`}, \
{-3.9157074104439396`, -3.562500018967059}, {-3.642337217350632, -3.5}, \
{-3.7697483574637447`, -3.5626550066464766`}}], 
      PolygonBox[{{-3.7940909946267443`, -3.5}, {-3.642337217350632, -3.5}, \
{-3.9157074104439396`, -3.562500018967059}, {-3.7940909946267443`, -3.5}}], 
      PolygonBox[{{-3.9157074104439396`, -3.562500018967059}, \
{-3.9998944727795123`, -3.5625}, {-3.7940909946267443`, -3.5}, \
{-3.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-3.92205804197311, -3.5}, {-3.7940909946267443`, -3.5}, \
{-3.9998944727795123`, -3.5625}, {-3.92205804197311, -3.5}}], 
      PolygonBox[{{-3.9998944727795123`, -3.5625}, {-4.084292589556057, \
-3.562500018967059}, {-3.92205804197311, -3.5}, {-3.9998944727795123`, \
-3.5625}}], 
      PolygonBox[{{-4.205909005304446, -3.5}, {-3.92205804197311, -3.5}, \
{-4.084292589556057, -3.562500018967059}, {-4.205909005304446, -3.5}}], 
      PolygonBox[{{-4.084292589556057, -3.562500018967059}, \
{-4.230251642536255, -3.5626550066464766`}, {-4.205909005304446, -3.5}, \
{-4.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-4.357662782649366, -3.5}, {-4.205909005304446, -3.5}, \
{-4.230251642536255, -3.5626550066464766`}, {-4.357662782649366, -3.5}}], 
      PolygonBox[{{-4.230251642536255, -3.5626550066464766`}, \
{-4.404942744332997, -3.595057255667003}, {-4.357662782649366, -3.5}, \
{-4.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-3.5, -3.5}, {-4.357662782649366, -3.5}, \
{-4.404942744332997, -3.595057255667003}, {-3.5, -3.5}}], 
      PolygonBox[{{-4.404942744332997, -3.595057255667003}, \
{-4.437344993353523, -3.7697483574637447`}, {-3.5, -3.5}, \
{-4.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-4.5, -3.642337217350631}, {-3.5, -3.5}, \
{-4.437344993353523, -3.7697483574637447`}, {-4.5, -3.642337217350631}}], 
      PolygonBox[{{-4.437344993353523, -3.7697483574637447`}, \
{-4.437499981032941, -3.9157074104439378`}, {-4.5, -3.642337217350631}, \
{-4.437344993353523, -3.7697483574637447`}}], 
      PolygonBox[{{-4.5, -3.794090994717101}, {-4.5, -3.642337217350631}, \
{-4.437499981032941, -3.9157074104439378`}, {-4.5, -3.794090994717101}}], 
      PolygonBox[{{-4.437499981032941, -3.9157074104439378`}, {-4.4375, \
-3.9998768219370047`}, {-4.5, -3.794090994717101}, {-4.437499981032941, \
-3.9157074104439378`}}], 
      PolygonBox[{{-4.5, -3.9193213332413}, {-4.5, -3.794090994717101}, \
{-4.4375, -3.9998768219370047`}, {-4.5, -3.9193213332413}}], 
      PolygonBox[{{-4.4375, -3.9998768219370047`}, {-4.437499981032941, \
-4.084292589556055}, {-4.5, -3.9193213332413}, {-4.4375, \
-3.9998768219370047`}}], 
      PolygonBox[{{-4.5, -4.205909005145278}, {-4.5, -3.9193213332413}, \
{-4.437499981032941, -4.084292589556055}, {-4.5, -4.205909005145278}}], 
      PolygonBox[{{-4.437499981032941, -4.084292589556055}, \
{-4.437344993353523, -4.230251642536254}, {-4.5, -4.205909005145278}, \
{-4.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-4.5, -4.357662782649365}, {-4.5, -4.205909005145278}, \
{-4.437344993353523, -4.230251642536254}, {-4.5, -4.357662782649365}}], 
      PolygonBox[{{-4.437344993353523, -4.230251642536254}, \
{-4.404942744332997, -4.404942744332997}, {-4.5, -4.357662782649365}, \
{-4.437344993353523, -4.230251642536254}}], 
      PolygonBox[{{-4.5, -3.5}, {-4.5, -4.357662782649365}, \
{-4.404942744332997, -4.404942744332997}, {-4.5, -3.5}}], 
      PolygonBox[{{-4.404942744332997, -4.404942744332997}, \
{-4.230251642536255, -4.437344993353523}, {-4.5, -3.5}, {-4.404942744332997, \
-4.404942744332997}}], 
      PolygonBox[{{-4.5, -4.5}, {-4.5, -3.5}, {-4.230251642536255, \
-4.437344993353523}, {-4.5, -4.5}}], 
      PolygonBox[{{-4.230251642536255, -4.437344993353523}, \
{-4.084292589556064, -4.437499981032941}, {-4.5, -4.5}, {-4.230251642536255, \
-4.437344993353523}}], 
      PolygonBox[{{-4.205909005566828, -4.5}, {-4.5, -4.5}, \
{-4.084292589556064, -4.437499981032941}, {-4.205909005566828, -4.5}}], 
      PolygonBox[{{-4.084292589556064, -4.437499981032941}, \
{-3.999865158168957, -4.4375}, {-4.205909005566828, -4.5}, \
{-4.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-3.9176761295989384`, -4.5}, {-4.205909005566828, -4.5}, \
{-3.999865158168957, -4.4375}, {-3.9176761295989384`, -4.5}}], 
      PolygonBox[{{-3.999865158168957, -4.4375}, {-3.9157074104439467`, \
-4.437499981032941}, {-3.9176761295989384`, -4.5}, {-3.999865158168957, \
-4.4375}}], 
      PolygonBox[{{-3.7940909946396024`, -4.5}, {-3.9176761295989384`, -4.5}, \
{-3.9157074104439467`, -4.437499981032941}, {-3.7940909946396024`, -4.5}}], 
      PolygonBox[{{-3.9157074104439467`, -4.437499981032941}, \
{-3.769748357463745, -4.437344993353523}, {-3.7940909946396024`, -4.5}, \
{-3.9157074104439467`, -4.437499981032941}}], 
      PolygonBox[{{-3.642337217350629, -4.5}, {-3.7940909946396024`, -4.5}, \
{-3.769748357463745, -4.437344993353523}, {-3.642337217350629, -4.5}}], 
      PolygonBox[{{-3.769748357463745, -4.437344993353523}, \
{-3.595057255667003, -4.404942744332997}, {-3.642337217350629, -4.5}, \
{-3.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{-3.5, -4.5}, {-3.642337217350629, -4.5}, \
{-3.595057255667003, -4.404942744332997}, {-3.5, -4.5}}], 
      PolygonBox[{{-3.595057255667003, -4.404942744332997}, \
{-3.595057255667003, -4.404942744332997}, {-3.5, -4.5}, {-3.595057255667003, \
-4.404942744332997}}], 
      PolygonBox[{{-3.5, -4.5}, {-3.5, -4.5}, {-3.595057255667003, \
-4.404942744332997}, {-3.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, -3.}, {-4.479166666666667, -3.}, {-4.458333333333333, \
-3.}, {-4.4375, -3.}, {-4.416666666666667, -3.}, {-4.395833333333333, -3.}, \
{-4.375, -3.}, {-4.375, -3.}, {-4.395833333333333, -3.}, {-4.416666666666667, \
-3.}, {-4.4375, -3.}, {-4.458333333333333, -3.}, {-4.479166666666667, -3.}, \
{-4.5, -3.}, {-4.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, -3.}, {-3.6041666666666665`, -3.}, \
{-3.5833333333333335`, -3.}, {-3.5625, -3.}, {-3.5416666666666665`, -3.}, \
{-3.5208333333333335`, -3.}, {-3.5, -3.}, {-3.5, -3.}, {-3.5208333333333335`, \
-3.}, {-3.5416666666666665`, -3.}, {-3.5625, -3.}, {-3.5833333333333335`, \
-3.}, {-3.6041666666666665`, -3.}, {-3.625, -3.}, {-3.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -3.5}, {-4., -3.4791666666666665`}, {-4., \
-3.4583333333333335`}, {-4., -3.4375}, {-4., -3.4166666666666665`}, {-4., \
-3.3958333333333335`}, {-4., -3.375}, {-4., -3.375}, {-4., \
-3.3958333333333335`}, {-4., -3.4166666666666665`}, {-4., -3.4375}, {-4., \
-3.4583333333333335`}, {-4., -3.4791666666666665`}, {-4., -3.5}, {-4., \
-3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -2.625}, {-4., -2.6041666666666665`}, {-4., \
-2.5833333333333335`}, {-4., -2.5625}, {-4., -2.5416666666666665`}, {-4., \
-2.5208333333333335`}, {-4., -2.5}, {-4., -2.5}, {-4., -2.5208333333333335`}, \
{-4., -2.5416666666666665`}, {-4., -2.5625}, {-4., -2.5833333333333335`}, \
{-4., -2.6041666666666665`}, {-4., -2.625}, {-4., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, -3.}, {-4.25, -3.}, {-4.125, -3.}, {-4., -3.}, \
{-3.875, -3.}, {-3.75, -3.}, {-3.625, -3.}, {-3.625, -3.}, {-3.75, -3.}, \
{-3.875, -3.}, {-4., -3.}, {-4.125, -3.}, {-4.25, -3.}, {-4.375, -3.}, \
{-4.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -3.375}, {-4., -3.25}, {-4., -3.125}, {-4., -3.}, {-4., \
-2.875}, {-4., -2.75}, {-4., -2.625}, {-4., -2.625}, {-4., -2.75}, {-4., \
-2.875}, {-4., -3.}, {-4., -3.125}, {-4., -3.25}, {-4., -3.375}, {-4., \
-3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByA0xwExvUBHbSneAxul30pZWbIfuLDDvOpJ
GlS+ge1AqlCK2scHvFCaFSrOB1XHCtXHDzUHKs8gAKVZD6gXdX5KShZAlT8g
ANd/7tvZnHZ+Qbj5M5SfHOr1EYTb/zUjPP5VkSDcfRBxQbj7YfJ+T4SeHj3G
gaafE27+7Lezb/LJc8HtN3A/0So9k+uABtR9ry6u23flKRea+7kPbIL6DybP
CPU/TD8sfGDmo4YfJzx8/aHuQw9/AHhpi+4=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByA0y4FQMOCF81evAgE+OB9CC6DJC6DpF0RT
L0SQD9HHCudDzGVDU8+Bpp4TzgcrX8WFpp4Hg4/qPh4098PUC6DJ88H5YSjh
w0M0vRrFfTxo7oep40BTzwbnh6GEDyK+ANF5XiU=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, -3.2651650429449552`}, \
{-3.6752404735808355`, -3.1875}, {-3.595057255667003, -3.404942744332997}, \
{-3.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{-3.5626550066464766`, -3.2302516425362553`}, \
{-3.595057255667003, -3.404942744332997}, {-3.6752404735808355`, -3.1875}, \
{-3.5626550066464766`, -3.2302516425362553`}}], 
      PolygonBox[{{-3.6752404735808355`, -3.1875}, {-3.6377778151415994`, \
-3.0970571419134454`}, {-3.5626550066464766`, -3.2302516425362553`}, \
{-3.6752404735808355`, -3.1875}}], 
      PolygonBox[{{-3.562500018967059, -3.084292589556062}, \
{-3.5626550066464766`, -3.2302516425362553`}, {-3.6377778151415994`, \
-3.0970571419134454`}, {-3.562500018967059, -3.084292589556062}}], 
      PolygonBox[{{-3.6377778151415994`, -3.0970571419134454`}, {-3.625, \
-3.}, {-3.562500018967059, -3.084292589556062}, {-3.6377778151415994`, \
-3.0970571419134454`}}], 
      PolygonBox[{{-3.5625, -3.}, {-3.562500018967059, -3.084292589556062}, \
{-3.625, -3.}, {-3.5625, -3.}}], 
      PolygonBox[{{-3.625, -3.}, {-3.6377778151415994`, \
-2.9029428580865546`}, {-3.5625, -3.}, {-3.625, -3.}}], 
      PolygonBox[{{-3.562500018967059, -2.915707410443938}, {-3.5625, -3.}, \
{-3.6377778151415994`, -2.9029428580865546`}, {-3.562500018967059, \
-2.915707410443938}}], 
      PolygonBox[{{-3.6377778151415994`, -2.9029428580865546`}, \
{-3.6752404735808355`, -2.8125}, {-3.562500018967059, -2.915707410443938}, \
{-3.6377778151415994`, -2.9029428580865546`}}], 
      PolygonBox[{{-3.5626550066464766`, -2.769748357463745}, \
{-3.562500018967059, -2.915707410443938}, {-3.6752404735808355`, -2.8125}, \
{-3.5626550066464766`, -2.769748357463745}}], 
      PolygonBox[{{-3.6752404735808355`, -2.8125}, {-3.7348349570550448`, \
-2.7348349570550448`}, {-3.5626550066464766`, -2.769748357463745}, \
{-3.6752404735808355`, -2.8125}}], 
      PolygonBox[{{-3.595057255667003, -2.595057255667003}, \
{-3.5626550066464766`, -2.769748357463745}, {-3.7348349570550448`, \
-2.7348349570550448`}, {-3.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{-3.7348349570550448`, -2.7348349570550448`}, {-3.8125, \
-2.6752404735808355`}, {-3.595057255667003, -2.595057255667003}, \
{-3.7348349570550448`, -2.7348349570550448`}}], 
      PolygonBox[{{-3.7697483574637447`, -2.5626550066464766`}, \
{-3.595057255667003, -2.595057255667003}, {-3.8125, -2.6752404735808355`}, \
{-3.7697483574637447`, -2.5626550066464766`}}], 
      PolygonBox[{{-3.8125, -2.6752404735808355`}, {-3.9029428580865546`, \
-2.6377778151415994`}, {-3.7697483574637447`, -2.5626550066464766`}, \
{-3.8125, -2.6752404735808355`}}], 
      PolygonBox[{{-3.9157074104439396`, -2.562500018967059}, \
{-3.7697483574637447`, -2.5626550066464766`}, {-3.9029428580865546`, \
-2.6377778151415994`}, {-3.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-3.9029428580865546`, -2.6377778151415994`}, {-4., \
-2.625}, {-3.9157074104439396`, -2.562500018967059}, {-3.9029428580865546`, \
-2.6377778151415994`}}], 
      PolygonBox[{{-3.9998944727795123`, -2.5625}, {-3.9157074104439396`, \
-2.562500018967059}, {-4., -2.625}, {-3.9998944727795123`, -2.5625}}], 
      PolygonBox[{{-4., -2.625}, {-4.097057141913445, -2.6377778151415994`}, \
{-3.9998944727795123`, -2.5625}, {-4., -2.625}}], 
      PolygonBox[{{-4.084292589556057, -2.562500018967059}, \
{-3.9998944727795123`, -2.5625}, {-4.097057141913445, -2.6377778151415994`}, \
{-4.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-4.097057141913445, -2.6377778151415994`}, {-4.1875, \
-2.6752404735808355`}, {-4.084292589556057, -2.562500018967059}, \
{-4.097057141913445, -2.6377778151415994`}}], 
      PolygonBox[{{-4.230251642536255, -2.5626550066464766`}, \
{-4.084292589556057, -2.562500018967059}, {-4.1875, -2.6752404735808355`}, \
{-4.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-4.1875, -2.6752404735808355`}, {-4.265165042944956, \
-2.7348349570550448`}, {-4.230251642536255, -2.5626550066464766`}, {-4.1875, \
-2.6752404735808355`}}], 
      PolygonBox[{{-4.404942744332997, -2.595057255667003}, \
{-4.230251642536255, -2.5626550066464766`}, {-4.265165042944956, \
-2.7348349570550448`}, {-4.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-4.265165042944956, -2.7348349570550448`}, \
{-4.3247595264191645`, -2.8125}, {-4.404942744332997, -2.595057255667003}, \
{-4.265165042944956, -2.7348349570550448`}}], 
      PolygonBox[{{-4.437344993353523, -2.7697483574637447`}, \
{-4.404942744332997, -2.595057255667003}, {-4.3247595264191645`, -2.8125}, \
{-4.437344993353523, -2.7697483574637447`}}], 
      PolygonBox[{{-4.3247595264191645`, -2.8125}, {-4.362222184858401, \
-2.9029428580865546`}, {-4.437344993353523, -2.7697483574637447`}, \
{-4.3247595264191645`, -2.8125}}], 
      PolygonBox[{{-4.437499981032941, -2.9157074104439378`}, \
{-4.437344993353523, -2.7697483574637447`}, {-4.362222184858401, \
-2.9029428580865546`}, {-4.437499981032941, -2.9157074104439378`}}], 
      PolygonBox[{{-4.362222184858401, -2.9029428580865546`}, {-4.375, -3.}, \
{-4.437499981032941, -2.9157074104439378`}, {-4.362222184858401, \
-2.9029428580865546`}}], 
      PolygonBox[{{-4.4375, -2.9998768219370047`}, {-4.437499981032941, \
-2.9157074104439378`}, {-4.375, -3.}, {-4.4375, -2.9998768219370047`}}], 
      PolygonBox[{{-4.375, -3.}, {-4.362222184858401, -3.097057141913445}, \
{-4.4375, -2.9998768219370047`}, {-4.375, -3.}}], 
      PolygonBox[{{-4.437499981032941, -3.084292589556055}, {-4.4375, \
-2.9998768219370047`}, {-4.362222184858401, -3.097057141913445}, \
{-4.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-4.362222184858401, -3.097057141913445}, \
{-4.3247595264191645`, -3.1875}, {-4.437499981032941, -3.084292589556055}, \
{-4.362222184858401, -3.097057141913445}}], 
      PolygonBox[{{-4.437344993353523, -3.230251642536255}, \
{-4.437499981032941, -3.084292589556055}, {-4.3247595264191645`, -3.1875}, \
{-4.437344993353523, -3.230251642536255}}], 
      PolygonBox[{{-4.3247595264191645`, -3.1875}, {-4.265165042944956, \
-3.2651650429449552`}, {-4.437344993353523, -3.230251642536255}, \
{-4.3247595264191645`, -3.1875}}], 
      PolygonBox[{{-4.404942744332997, -3.404942744332997}, \
{-4.437344993353523, -3.230251642536255}, {-4.265165042944956, \
-3.2651650429449552`}, {-4.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, -3.2651650429449552`}, {-4.1875, \
-3.3247595264191645`}, {-4.404942744332997, -3.404942744332997}, \
{-4.265165042944956, -3.2651650429449552`}}], 
      PolygonBox[{{-4.230251642536255, -3.4373449933535234`}, \
{-4.404942744332997, -3.404942744332997}, {-4.1875, -3.3247595264191645`}, \
{-4.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{-4.1875, -3.3247595264191645`}, {-4.097057141913446, \
-3.3622221848584006`}, {-4.230251642536255, -3.4373449933535234`}, {-4.1875, \
-3.3247595264191645`}}], 
      PolygonBox[{{-4.084292589556064, -3.437499981032941}, \
{-4.230251642536255, -3.4373449933535234`}, {-4.097057141913446, \
-3.3622221848584006`}, {-4.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-4.097057141913446, -3.3622221848584006`}, {-4., -3.375}, \
{-4.084292589556064, -3.437499981032941}, {-4.097057141913446, \
-3.3622221848584006`}}], 
      PolygonBox[{{-3.999865158168957, -3.4375}, {-4.084292589556064, \
-3.437499981032941}, {-4., -3.375}, {-3.999865158168957, -3.4375}}], 
      PolygonBox[{{-4., -3.375}, {-3.902942858086555, -3.3622221848584006`}, \
{-3.999865158168957, -3.4375}, {-4., -3.375}}], 
      PolygonBox[{{-3.9157074104439467`, -3.437499981032941}, \
{-3.999865158168957, -3.4375}, {-3.902942858086555, -3.3622221848584006`}, \
{-3.9157074104439467`, -3.437499981032941}}], 
      PolygonBox[{{-3.902942858086555, -3.3622221848584006`}, \
{-3.8125000000000004`, -3.3247595264191645`}, {-3.9157074104439467`, \
-3.437499981032941}, {-3.902942858086555, -3.3622221848584006`}}], 
      PolygonBox[{{-3.769748357463745, -3.4373449933535234`}, \
{-3.9157074104439467`, -3.437499981032941}, {-3.8125000000000004`, \
-3.3247595264191645`}, {-3.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{-3.8125000000000004`, -3.3247595264191645`}, \
{-3.7348349570550448`, -3.2651650429449552`}, {-3.769748357463745, \
-3.4373449933535234`}, {-3.8125000000000004`, -3.3247595264191645`}}], 
      PolygonBox[{{-3.595057255667003, -3.404942744332997}, \
{-3.769748357463745, -3.4373449933535234`}, {-3.7348349570550448`, \
-3.2651650429449552`}, {-3.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, -3.2651650429449552`}, \
{-3.7348349570550448`, -3.2651650429449552`}, {-3.595057255667003, \
-3.404942744332997}, {-3.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{-3.595057255667003, -3.404942744332997}, \
{-3.595057255667003, -3.404942744332997}, {-3.7348349570550448`, \
-3.2651650429449552`}, {-3.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-3.595057255667003, -3.404942744332997}, \
{-3.5626550066464766`, -3.2302516425362553`}, {-3.5, -3.5}, \
{-3.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-3.5, -3.357662782649368}, {-3.5, -3.5}, \
{-3.5626550066464766`, -3.2302516425362553`}, {-3.5, -3.357662782649368}}], 
      PolygonBox[{{-3.5626550066464766`, -3.2302516425362553`}, \
{-3.562500018967059, -3.084292589556062}, {-3.5, -3.357662782649368}, \
{-3.5626550066464766`, -3.2302516425362553`}}], 
      PolygonBox[{{-3.5, -3.20590900530174}, {-3.5, -3.357662782649368}, \
{-3.562500018967059, -3.084292589556062}, {-3.5, -3.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, -3.084292589556062}, {-3.5625, -3.}, \
{-3.5, -3.20590900530174}, {-3.562500018967059, -3.084292589556062}}], 
      PolygonBox[{{-3.5, -3.}, {-3.5, -3.20590900530174}, {-3.5625, -3.}, \
{-3.5, -3.}}], 
      PolygonBox[{{-3.5625, -3.}, {-3.562500018967059, -2.915707410443938}, \
{-3.5, -3.}, {-3.5625, -3.}}], 
      PolygonBox[{{-3.5, -2.79409099469826}, {-3.5, -3.}, \
{-3.562500018967059, -2.915707410443938}, {-3.5, -2.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, -2.915707410443938}, \
{-3.5626550066464766`, -2.769748357463745}, {-3.5, -2.79409099469826}, \
{-3.562500018967059, -2.915707410443938}}], 
      PolygonBox[{{-3.5, -2.6423372173506325`}, {-3.5, -2.79409099469826}, \
{-3.5626550066464766`, -2.769748357463745}, {-3.5, -2.6423372173506325`}}], 
      PolygonBox[{{-3.5626550066464766`, -2.769748357463745}, \
{-3.595057255667003, -2.595057255667003}, {-3.5, -2.6423372173506325`}, \
{-3.5626550066464766`, -2.769748357463745}}], 
      PolygonBox[{{-3.508553435038814, -2.508553435038814}, {-3.5, \
-2.6423372173506325`}, {-3.595057255667003, -2.595057255667003}, \
{-3.508553435038814, -2.508553435038814}}], 
      PolygonBox[{{-3.595057255667003, -2.595057255667003}, \
{-3.7697483574637447`, -2.5626550066464766`}, {-3.508553435038814, \
-2.508553435038814}, {-3.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{-3.642337217350632, -2.5}, {-3.508553435038814, \
-2.508553435038814}, {-3.7697483574637447`, -2.5626550066464766`}, \
{-3.642337217350632, -2.5}}], 
      PolygonBox[{{-3.7697483574637447`, -2.5626550066464766`}, \
{-3.9157074104439396`, -2.562500018967059}, {-3.642337217350632, -2.5}, \
{-3.7697483574637447`, -2.5626550066464766`}}], 
      PolygonBox[{{-3.7940909946267443`, -2.5}, {-3.642337217350632, -2.5}, \
{-3.9157074104439396`, -2.562500018967059}, {-3.7940909946267443`, -2.5}}], 
      PolygonBox[{{-3.9157074104439396`, -2.562500018967059}, \
{-3.9998944727795123`, -2.5625}, {-3.7940909946267443`, -2.5}, \
{-3.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-3.92205804197311, -2.5}, {-3.7940909946267443`, -2.5}, \
{-3.9998944727795123`, -2.5625}, {-3.92205804197311, -2.5}}], 
      PolygonBox[{{-3.9998944727795123`, -2.5625}, {-4.084292589556057, \
-2.562500018967059}, {-3.92205804197311, -2.5}, {-3.9998944727795123`, \
-2.5625}}], 
      PolygonBox[{{-4.205909005304446, -2.5}, {-3.92205804197311, -2.5}, \
{-4.084292589556057, -2.562500018967059}, {-4.205909005304446, -2.5}}], 
      PolygonBox[{{-4.084292589556057, -2.562500018967059}, \
{-4.230251642536255, -2.5626550066464766`}, {-4.205909005304446, -2.5}, \
{-4.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-4.357662782649366, -2.5}, {-4.205909005304446, -2.5}, \
{-4.230251642536255, -2.5626550066464766`}, {-4.357662782649366, -2.5}}], 
      PolygonBox[{{-4.230251642536255, -2.5626550066464766`}, \
{-4.404942744332997, -2.595057255667003}, {-4.357662782649366, -2.5}, \
{-4.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-3.5, -2.5}, {-4.357662782649366, -2.5}, \
{-4.404942744332997, -2.595057255667003}, {-3.5, -2.5}}], 
      PolygonBox[{{-4.404942744332997, -2.595057255667003}, \
{-4.437344993353523, -2.7697483574637447`}, {-3.5, -2.5}, \
{-4.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-4.5, -2.642337217350631}, {-3.5, -2.5}, \
{-4.437344993353523, -2.7697483574637447`}, {-4.5, -2.642337217350631}}], 
      PolygonBox[{{-4.437344993353523, -2.7697483574637447`}, \
{-4.437499981032941, -2.9157074104439378`}, {-4.5, -2.642337217350631}, \
{-4.437344993353523, -2.7697483574637447`}}], 
      PolygonBox[{{-4.5, -2.794090994717101}, {-4.5, -2.642337217350631}, \
{-4.437499981032941, -2.9157074104439378`}, {-4.5, -2.794090994717101}}], 
      PolygonBox[{{-4.437499981032941, -2.9157074104439378`}, {-4.4375, \
-2.9998768219370047`}, {-4.5, -2.794090994717101}, {-4.437499981032941, \
-2.9157074104439378`}}], 
      PolygonBox[{{-4.5, -2.9193213332413}, {-4.5, -2.794090994717101}, \
{-4.4375, -2.9998768219370047`}, {-4.5, -2.9193213332413}}], 
      PolygonBox[{{-4.4375, -2.9998768219370047`}, {-4.437499981032941, \
-3.084292589556055}, {-4.5, -2.9193213332413}, {-4.4375, \
-2.9998768219370047`}}], 
      PolygonBox[{{-4.5, -3.2059090051452785`}, {-4.5, -2.9193213332413}, \
{-4.437499981032941, -3.084292589556055}, {-4.5, -3.2059090051452785`}}], 
      PolygonBox[{{-4.437499981032941, -3.084292589556055}, \
{-4.437344993353523, -3.230251642536255}, {-4.5, -3.2059090051452785`}, \
{-4.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-4.5, -3.3576627826493652`}, {-4.5, -3.2059090051452785`}, \
{-4.437344993353523, -3.230251642536255}, {-4.5, -3.3576627826493652`}}], 
      PolygonBox[{{-4.437344993353523, -3.230251642536255}, \
{-4.404942744332997, -3.404942744332997}, {-4.5, -3.3576627826493652`}, \
{-4.437344993353523, -3.230251642536255}}], 
      PolygonBox[{{-4.5, -2.5}, {-4.5, -3.3576627826493652`}, \
{-4.404942744332997, -3.404942744332997}, {-4.5, -2.5}}], 
      PolygonBox[{{-4.404942744332997, -3.404942744332997}, \
{-4.230251642536255, -3.4373449933535234`}, {-4.5, -2.5}, \
{-4.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-4.5, -3.5}, {-4.5, -2.5}, {-4.230251642536255, \
-3.4373449933535234`}, {-4.5, -3.5}}], 
      PolygonBox[{{-4.230251642536255, -3.4373449933535234`}, \
{-4.084292589556064, -3.437499981032941}, {-4.5, -3.5}, {-4.230251642536255, \
-3.4373449933535234`}}], 
      PolygonBox[{{-4.205909005566828, -3.5}, {-4.5, -3.5}, \
{-4.084292589556064, -3.437499981032941}, {-4.205909005566828, -3.5}}], 
      PolygonBox[{{-4.084292589556064, -3.437499981032941}, \
{-3.999865158168957, -3.4375}, {-4.205909005566828, -3.5}, \
{-4.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-3.9176761295989384`, -3.5}, {-4.205909005566828, -3.5}, \
{-3.999865158168957, -3.4375}, {-3.9176761295989384`, -3.5}}], 
      PolygonBox[{{-3.999865158168957, -3.4375}, {-3.9157074104439467`, \
-3.437499981032941}, {-3.9176761295989384`, -3.5}, {-3.999865158168957, \
-3.4375}}], 
      PolygonBox[{{-3.7940909946396024`, -3.5}, {-3.9176761295989384`, -3.5}, \
{-3.9157074104439467`, -3.437499981032941}, {-3.7940909946396024`, -3.5}}], 
      PolygonBox[{{-3.9157074104439467`, -3.437499981032941}, \
{-3.769748357463745, -3.4373449933535234`}, {-3.7940909946396024`, -3.5}, \
{-3.9157074104439467`, -3.437499981032941}}], 
      PolygonBox[{{-3.642337217350629, -3.5}, {-3.7940909946396024`, -3.5}, \
{-3.769748357463745, -3.4373449933535234`}, {-3.642337217350629, -3.5}}], 
      PolygonBox[{{-3.769748357463745, -3.4373449933535234`}, \
{-3.595057255667003, -3.404942744332997}, {-3.642337217350629, -3.5}, \
{-3.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{-3.5, -3.5}, {-3.642337217350629, -3.5}, \
{-3.595057255667003, -3.404942744332997}, {-3.5, -3.5}}], 
      PolygonBox[{{-3.595057255667003, -3.404942744332997}, \
{-3.595057255667003, -3.404942744332997}, {-3.5, -3.5}, {-3.595057255667003, \
-3.404942744332997}}], 
      PolygonBox[{{-3.5, -3.5}, {-3.5, -3.5}, {-3.595057255667003, \
-3.404942744332997}, {-3.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, -2.}, {-4.479166666666667, -2.}, {-4.458333333333333, \
-2.}, {-4.4375, -2.}, {-4.416666666666667, -2.}, {-4.395833333333333, -2.}, \
{-4.375, -2.}, {-4.375, -2.}, {-4.395833333333333, -2.}, {-4.416666666666667, \
-2.}, {-4.4375, -2.}, {-4.458333333333333, -2.}, {-4.479166666666667, -2.}, \
{-4.5, -2.}, {-4.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, -2.}, {-3.6041666666666665`, -2.}, \
{-3.5833333333333335`, -2.}, {-3.5625, -2.}, {-3.5416666666666665`, -2.}, \
{-3.5208333333333335`, -2.}, {-3.5, -2.}, {-3.5, -2.}, {-3.5208333333333335`, \
-2.}, {-3.5416666666666665`, -2.}, {-3.5625, -2.}, {-3.5833333333333335`, \
-2.}, {-3.6041666666666665`, -2.}, {-3.625, -2.}, {-3.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -2.5}, {-4., -2.4791666666666665`}, {-4., \
-2.4583333333333335`}, {-4., -2.4375}, {-4., -2.4166666666666665`}, {-4., \
-2.3958333333333335`}, {-4., -2.375}, {-4., -2.375}, {-4., \
-2.3958333333333335`}, {-4., -2.4166666666666665`}, {-4., -2.4375}, {-4., \
-2.4583333333333335`}, {-4., -2.4791666666666665`}, {-4., -2.5}, {-4., \
-2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -1.625}, {-4., -1.6041666666666667`}, {-4., \
-1.5833333333333333`}, {-4., -1.5625}, {-4., -1.5416666666666667`}, {-4., \
-1.5208333333333335`}, {-4., -1.5}, {-4., -1.5}, {-4., -1.5208333333333333`}, \
{-4., -1.5416666666666667`}, {-4., -1.5625}, {-4., -1.5833333333333333`}, \
{-4., -1.6041666666666665`}, {-4., -1.625}, {-4., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, -2.}, {-4.25, -2.}, {-4.125, -2.}, {-4., -2.}, \
{-3.875, -2.}, {-3.75, -2.}, {-3.625, -2.}, {-3.625, -2.}, {-3.75, -2.}, \
{-3.875, -2.}, {-4., -2.}, {-4.125, -2.}, {-4.25, -2.}, {-4.375, -2.}, \
{-4.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -2.375}, {-4., -2.25}, {-4., -2.125}, {-4., -2.}, {-4., \
-1.875}, {-4., -1.75}, {-4., -1.625}, {-4., -1.625}, {-4., -1.75}, {-4., \
-1.875}, {-4., -2.}, {-4., -2.125}, {-4., -2.25}, {-4., -2.375}, {-4., \
-2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8B6CMA2J6gY7aUrwHksxvmZYU/dt/YYd51ZM0
mPzf/alCKWofH/AeOKVywufRwd/7wcINfAcWFOZ/OXH21/6N0m+lrCz5D+jE
LGoKM/kFkWcQgOr/tV+9qPNTUrIAqvwBAbj+c9/O5rTzC8LNn6H85FCvjyDc
/q8Z4fGvigTh7oPYD5NnOACT93si9PToMYYDKPobGA/AzJ/9dvZNPnmmAzD7
DdxPtErPZDqgAXXfq4vr9l15CpWHu5/5wCao/2DyjFD/w/TDwgdmPkr4Ae2H
ha8/1H3o4Q8AT8eafA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByD0j/2hYMAL569eBQJ8cD6EFkCTF0DTL4im
XoggH2zMql9wPsScv2jqGQ6gyjMeQNXPdABVPQsGH9V9LAdQ3Q9TL4Amzwfn
h6GED0w9D0H+ahT38aC5H6aeAc4PQ/E/TP+v/ajqf+wHACm+ags=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, -2.2651650429449552`}, \
{-3.6752404735808355`, -2.1875}, {-3.595057255667003, -2.404942744332997}, \
{-3.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{-3.5626550066464766`, -2.2302516425362553`}, \
{-3.595057255667003, -2.404942744332997}, {-3.6752404735808355`, -2.1875}, \
{-3.5626550066464766`, -2.2302516425362553`}}], 
      PolygonBox[{{-3.6752404735808355`, -2.1875}, {-3.6377778151415994`, \
-2.0970571419134454`}, {-3.5626550066464766`, -2.2302516425362553`}, \
{-3.6752404735808355`, -2.1875}}], 
      PolygonBox[{{-3.562500018967059, -2.084292589556062}, \
{-3.5626550066464766`, -2.2302516425362553`}, {-3.6377778151415994`, \
-2.0970571419134454`}, {-3.562500018967059, -2.084292589556062}}], 
      PolygonBox[{{-3.6377778151415994`, -2.0970571419134454`}, {-3.625, \
-2.}, {-3.562500018967059, -2.084292589556062}, {-3.6377778151415994`, \
-2.0970571419134454`}}], 
      PolygonBox[{{-3.5625, -2.}, {-3.562500018967059, -2.084292589556062}, \
{-3.625, -2.}, {-3.5625, -2.}}], 
      PolygonBox[{{-3.625, -2.}, {-3.6377778151415994`, \
-1.9029428580865548`}, {-3.5625, -2.}, {-3.625, -2.}}], 
      PolygonBox[{{-3.562500018967059, -1.9157074104439382`}, {-3.5625, -2.}, \
{-3.6377778151415994`, -1.9029428580865548`}, {-3.562500018967059, \
-1.9157074104439382`}}], 
      PolygonBox[{{-3.6377778151415994`, -1.9029428580865548`}, \
{-3.6752404735808355`, -1.8125}, {-3.562500018967059, -1.9157074104439382`}, \
{-3.6377778151415994`, -1.9029428580865548`}}], 
      PolygonBox[{{-3.5626550066464766`, -1.769748357463745}, \
{-3.562500018967059, -1.9157074104439382`}, {-3.6752404735808355`, -1.8125}, \
{-3.5626550066464766`, -1.769748357463745}}], 
      PolygonBox[{{-3.6752404735808355`, -1.8125}, {-3.7348349570550448`, \
-1.7348349570550448`}, {-3.5626550066464766`, -1.769748357463745}, \
{-3.6752404735808355`, -1.8125}}], 
      PolygonBox[{{-3.595057255667003, -1.5950572556670028`}, \
{-3.5626550066464766`, -1.769748357463745}, {-3.7348349570550448`, \
-1.7348349570550448`}, {-3.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{-3.7348349570550448`, -1.7348349570550448`}, {-3.8125, \
-1.6752404735808355`}, {-3.595057255667003, -1.5950572556670028`}, \
{-3.7348349570550448`, -1.7348349570550448`}}], 
      PolygonBox[{{-3.7697483574637447`, -1.5626550066464766`}, \
{-3.595057255667003, -1.5950572556670028`}, {-3.8125, -1.6752404735808355`}, \
{-3.7697483574637447`, -1.5626550066464766`}}], 
      PolygonBox[{{-3.8125, -1.6752404735808355`}, {-3.9029428580865546`, \
-1.6377778151415994`}, {-3.7697483574637447`, -1.5626550066464766`}, \
{-3.8125, -1.6752404735808355`}}], 
      PolygonBox[{{-3.9157074104439396`, -1.5625000189670593`}, \
{-3.7697483574637447`, -1.5626550066464766`}, {-3.9029428580865546`, \
-1.6377778151415994`}, {-3.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-3.9029428580865546`, -1.6377778151415994`}, {-4., \
-1.625}, {-3.9157074104439396`, -1.5625000189670593`}, {-3.9029428580865546`, \
-1.6377778151415994`}}], 
      PolygonBox[{{-3.9998944727795123`, -1.5625}, {-3.9157074104439396`, \
-1.5625000189670593`}, {-4., -1.625}, {-3.9998944727795123`, -1.5625}}], 
      PolygonBox[{{-4., -1.625}, {-4.097057141913445, -1.6377778151415994`}, \
{-3.9998944727795123`, -1.5625}, {-4., -1.625}}], 
      PolygonBox[{{-4.084292589556057, -1.5625000189670593`}, \
{-3.9998944727795123`, -1.5625}, {-4.097057141913445, -1.6377778151415994`}, \
{-4.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-4.097057141913445, -1.6377778151415994`}, {-4.1875, \
-1.6752404735808355`}, {-4.084292589556057, -1.5625000189670593`}, \
{-4.097057141913445, -1.6377778151415994`}}], 
      PolygonBox[{{-4.230251642536255, -1.5626550066464766`}, \
{-4.084292589556057, -1.5625000189670593`}, {-4.1875, -1.6752404735808355`}, \
{-4.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-4.1875, -1.6752404735808355`}, {-4.265165042944956, \
-1.7348349570550448`}, {-4.230251642536255, -1.5626550066464766`}, {-4.1875, \
-1.6752404735808355`}}], 
      PolygonBox[{{-4.404942744332997, -1.5950572556670028`}, \
{-4.230251642536255, -1.5626550066464766`}, {-4.265165042944956, \
-1.7348349570550448`}, {-4.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-4.265165042944956, -1.7348349570550448`}, \
{-4.3247595264191645`, -1.8125}, {-4.404942744332997, -1.5950572556670028`}, \
{-4.265165042944956, -1.7348349570550448`}}], 
      PolygonBox[{{-4.437344993353523, -1.7697483574637447`}, \
{-4.404942744332997, -1.5950572556670028`}, {-4.3247595264191645`, -1.8125}, \
{-4.437344993353523, -1.7697483574637447`}}], 
      PolygonBox[{{-4.3247595264191645`, -1.8125}, {-4.362222184858401, \
-1.9029428580865546`}, {-4.437344993353523, -1.7697483574637447`}, \
{-4.3247595264191645`, -1.8125}}], 
      PolygonBox[{{-4.437499981032941, -1.9157074104439376`}, \
{-4.437344993353523, -1.7697483574637447`}, {-4.362222184858401, \
-1.9029428580865546`}, {-4.437499981032941, -1.9157074104439376`}}], 
      PolygonBox[{{-4.362222184858401, -1.9029428580865546`}, {-4.375, \
-1.9999999999999998`}, {-4.437499981032941, -1.9157074104439376`}, \
{-4.362222184858401, -1.9029428580865546`}}], 
      PolygonBox[{{-4.4375, -1.9998768219370047`}, {-4.437499981032941, \
-1.9157074104439376`}, {-4.375, -1.9999999999999998`}, {-4.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-4.375, -1.9999999999999998`}, {-4.362222184858401, \
-2.097057141913445}, {-4.4375, -1.9998768219370047`}, {-4.375, \
-1.9999999999999998`}}], 
      PolygonBox[{{-4.437499981032941, -2.084292589556055}, {-4.4375, \
-1.9998768219370047`}, {-4.362222184858401, -2.097057141913445}, \
{-4.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-4.362222184858401, -2.097057141913445}, \
{-4.3247595264191645`, -2.1875}, {-4.437499981032941, -2.084292589556055}, \
{-4.362222184858401, -2.097057141913445}}], 
      PolygonBox[{{-4.437344993353523, -2.230251642536255}, \
{-4.437499981032941, -2.084292589556055}, {-4.3247595264191645`, -2.1875}, \
{-4.437344993353523, -2.230251642536255}}], 
      PolygonBox[{{-4.3247595264191645`, -2.1875}, {-4.265165042944956, \
-2.2651650429449552`}, {-4.437344993353523, -2.230251642536255}, \
{-4.3247595264191645`, -2.1875}}], 
      PolygonBox[{{-4.404942744332997, -2.404942744332997}, \
{-4.437344993353523, -2.230251642536255}, {-4.265165042944956, \
-2.2651650429449552`}, {-4.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, -2.2651650429449552`}, {-4.1875, \
-2.3247595264191645`}, {-4.404942744332997, -2.404942744332997}, \
{-4.265165042944956, -2.2651650429449552`}}], 
      PolygonBox[{{-4.230251642536255, -2.4373449933535234`}, \
{-4.404942744332997, -2.404942744332997}, {-4.1875, -2.3247595264191645`}, \
{-4.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{-4.1875, -2.3247595264191645`}, {-4.097057141913446, \
-2.3622221848584006`}, {-4.230251642536255, -2.4373449933535234`}, {-4.1875, \
-2.3247595264191645`}}], 
      PolygonBox[{{-4.084292589556064, -2.437499981032941}, \
{-4.230251642536255, -2.4373449933535234`}, {-4.097057141913446, \
-2.3622221848584006`}, {-4.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-4.097057141913446, -2.3622221848584006`}, {-4., -2.375}, \
{-4.084292589556064, -2.437499981032941}, {-4.097057141913446, \
-2.3622221848584006`}}], 
      PolygonBox[{{-3.999865158168957, -2.4375}, {-4.084292589556064, \
-2.437499981032941}, {-4., -2.375}, {-3.999865158168957, -2.4375}}], 
      PolygonBox[{{-4., -2.375}, {-3.902942858086555, -2.3622221848584006`}, \
{-3.999865158168957, -2.4375}, {-4., -2.375}}], 
      PolygonBox[{{-3.9157074104439467`, -2.437499981032941}, \
{-3.999865158168957, -2.4375}, {-3.902942858086555, -2.3622221848584006`}, \
{-3.9157074104439467`, -2.437499981032941}}], 
      PolygonBox[{{-3.902942858086555, -2.3622221848584006`}, \
{-3.8125000000000004`, -2.3247595264191645`}, {-3.9157074104439467`, \
-2.437499981032941}, {-3.902942858086555, -2.3622221848584006`}}], 
      PolygonBox[{{-3.769748357463745, -2.4373449933535234`}, \
{-3.9157074104439467`, -2.437499981032941}, {-3.8125000000000004`, \
-2.3247595264191645`}, {-3.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{-3.8125000000000004`, -2.3247595264191645`}, \
{-3.7348349570550448`, -2.2651650429449552`}, {-3.769748357463745, \
-2.4373449933535234`}, {-3.8125000000000004`, -2.3247595264191645`}}], 
      PolygonBox[{{-3.595057255667003, -2.404942744332997}, \
{-3.769748357463745, -2.4373449933535234`}, {-3.7348349570550448`, \
-2.2651650429449552`}, {-3.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, -2.2651650429449552`}, \
{-3.7348349570550448`, -2.2651650429449552`}, {-3.595057255667003, \
-2.404942744332997}, {-3.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{-3.595057255667003, -2.404942744332997}, \
{-3.595057255667003, -2.404942744332997}, {-3.7348349570550448`, \
-2.2651650429449552`}, {-3.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-3.595057255667003, -2.404942744332997}, \
{-3.5626550066464766`, -2.2302516425362553`}, {-3.5, -2.5}, \
{-3.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-3.5, -2.357662782649368}, {-3.5, -2.5}, \
{-3.5626550066464766`, -2.2302516425362553`}, {-3.5, -2.357662782649368}}], 
      PolygonBox[{{-3.5626550066464766`, -2.2302516425362553`}, \
{-3.562500018967059, -2.084292589556062}, {-3.5, -2.357662782649368}, \
{-3.5626550066464766`, -2.2302516425362553`}}], 
      PolygonBox[{{-3.5, -2.20590900530174}, {-3.5, -2.357662782649368}, \
{-3.562500018967059, -2.084292589556062}, {-3.5, -2.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, -2.084292589556062}, {-3.5625, -2.}, \
{-3.5, -2.20590900530174}, {-3.562500018967059, -2.084292589556062}}], 
      PolygonBox[{{-3.5, -2.}, {-3.5, -2.20590900530174}, {-3.5625, -2.}, \
{-3.5, -2.}}], 
      PolygonBox[{{-3.5625, -2.}, {-3.562500018967059, -1.9157074104439382`}, \
{-3.5, -2.}, {-3.5625, -2.}}], 
      PolygonBox[{{-3.5, -1.7940909946982602`}, {-3.5, -2.}, \
{-3.562500018967059, -1.9157074104439382`}, {-3.5, -1.7940909946982602`}}], 
      PolygonBox[{{-3.562500018967059, -1.9157074104439382`}, \
{-3.5626550066464766`, -1.769748357463745}, {-3.5, -1.7940909946982602`}, \
{-3.562500018967059, -1.9157074104439382`}}], 
      PolygonBox[{{-3.5, -1.6423372173506325`}, {-3.5, -1.7940909946982602`}, \
{-3.5626550066464766`, -1.769748357463745}, {-3.5, -1.6423372173506325`}}], 
      PolygonBox[{{-3.5626550066464766`, -1.769748357463745}, \
{-3.595057255667003, -1.5950572556670028`}, {-3.5, -1.6423372173506325`}, \
{-3.5626550066464766`, -1.769748357463745}}], 
      PolygonBox[{{-3.508553435038814, -1.508553435038814}, {-3.5, \
-1.6423372173506325`}, {-3.595057255667003, -1.5950572556670028`}, \
{-3.508553435038814, -1.508553435038814}}], 
      PolygonBox[{{-3.595057255667003, -1.5950572556670028`}, \
{-3.7697483574637447`, -1.5626550066464766`}, {-3.508553435038814, \
-1.508553435038814}, {-3.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{-3.642337217350632, -1.5}, {-3.508553435038814, \
-1.508553435038814}, {-3.7697483574637447`, -1.5626550066464766`}, \
{-3.642337217350632, -1.5}}], 
      PolygonBox[{{-3.7697483574637447`, -1.5626550066464766`}, \
{-3.9157074104439396`, -1.5625000189670593`}, {-3.642337217350632, -1.5}, \
{-3.7697483574637447`, -1.5626550066464766`}}], 
      PolygonBox[{{-3.7940909946267443`, -1.5}, {-3.642337217350632, -1.5}, \
{-3.9157074104439396`, -1.5625000189670593`}, {-3.7940909946267443`, -1.5}}], 
      PolygonBox[{{-3.9157074104439396`, -1.5625000189670593`}, \
{-3.9998944727795123`, -1.5625}, {-3.7940909946267443`, -1.5}, \
{-3.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-3.92205804197311, -1.5}, {-3.7940909946267443`, -1.5}, \
{-3.9998944727795123`, -1.5625}, {-3.92205804197311, -1.5}}], 
      PolygonBox[{{-3.9998944727795123`, -1.5625}, {-4.084292589556057, \
-1.5625000189670593`}, {-3.92205804197311, -1.5}, {-3.9998944727795123`, \
-1.5625}}], 
      PolygonBox[{{-4.205909005304446, -1.5}, {-3.92205804197311, -1.5}, \
{-4.084292589556057, -1.5625000189670593`}, {-4.205909005304446, -1.5}}], 
      PolygonBox[{{-4.084292589556057, -1.5625000189670593`}, \
{-4.230251642536255, -1.5626550066464766`}, {-4.205909005304446, -1.5}, \
{-4.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-4.357662782649366, -1.5}, {-4.205909005304446, -1.5}, \
{-4.230251642536255, -1.5626550066464766`}, {-4.357662782649366, -1.5}}], 
      PolygonBox[{{-4.230251642536255, -1.5626550066464766`}, \
{-4.404942744332997, -1.5950572556670028`}, {-4.357662782649366, -1.5}, \
{-4.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-3.5, -1.5}, {-4.357662782649366, -1.5}, \
{-4.404942744332997, -1.5950572556670028`}, {-3.5, -1.5}}], 
      PolygonBox[{{-4.404942744332997, -1.5950572556670028`}, \
{-4.437344993353523, -1.7697483574637447`}, {-3.5, -1.5}, \
{-4.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-4.5, -1.642337217350631}, {-3.5, -1.5}, \
{-4.437344993353523, -1.7697483574637447`}, {-4.5, -1.642337217350631}}], 
      PolygonBox[{{-4.437344993353523, -1.7697483574637447`}, \
{-4.437499981032941, -1.9157074104439376`}, {-4.5, -1.642337217350631}, \
{-4.437344993353523, -1.7697483574637447`}}], 
      PolygonBox[{{-4.5, -1.794090994717101}, {-4.5, -1.642337217350631}, \
{-4.437499981032941, -1.9157074104439376`}, {-4.5, -1.794090994717101}}], 
      PolygonBox[{{-4.437499981032941, -1.9157074104439376`}, {-4.4375, \
-1.9998768219370047`}, {-4.5, -1.794090994717101}, {-4.437499981032941, \
-1.9157074104439376`}}], 
      PolygonBox[{{-4.5, -1.9193213332412997`}, {-4.5, -1.794090994717101}, \
{-4.4375, -1.9998768219370047`}, {-4.5, -1.9193213332412997`}}], 
      PolygonBox[{{-4.4375, -1.9998768219370047`}, {-4.437499981032941, \
-2.084292589556055}, {-4.5, -1.9193213332412997`}, {-4.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-4.5, -2.2059090051452785`}, {-4.5, -1.9193213332412997`}, \
{-4.437499981032941, -2.084292589556055}, {-4.5, -2.2059090051452785`}}], 
      PolygonBox[{{-4.437499981032941, -2.084292589556055}, \
{-4.437344993353523, -2.230251642536255}, {-4.5, -2.2059090051452785`}, \
{-4.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-4.5, -2.3576627826493652`}, {-4.5, -2.2059090051452785`}, \
{-4.437344993353523, -2.230251642536255}, {-4.5, -2.3576627826493652`}}], 
      PolygonBox[{{-4.437344993353523, -2.230251642536255}, \
{-4.404942744332997, -2.404942744332997}, {-4.5, -2.3576627826493652`}, \
{-4.437344993353523, -2.230251642536255}}], 
      PolygonBox[{{-4.5, -1.5}, {-4.5, -2.3576627826493652`}, \
{-4.404942744332997, -2.404942744332997}, {-4.5, -1.5}}], 
      PolygonBox[{{-4.404942744332997, -2.404942744332997}, \
{-4.230251642536255, -2.4373449933535234`}, {-4.5, -1.5}, \
{-4.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-4.5, -2.5}, {-4.5, -1.5}, {-4.230251642536255, \
-2.4373449933535234`}, {-4.5, -2.5}}], 
      PolygonBox[{{-4.230251642536255, -2.4373449933535234`}, \
{-4.084292589556064, -2.437499981032941}, {-4.5, -2.5}, {-4.230251642536255, \
-2.4373449933535234`}}], 
      PolygonBox[{{-4.205909005566828, -2.5}, {-4.5, -2.5}, \
{-4.084292589556064, -2.437499981032941}, {-4.205909005566828, -2.5}}], 
      PolygonBox[{{-4.084292589556064, -2.437499981032941}, \
{-3.999865158168957, -2.4375}, {-4.205909005566828, -2.5}, \
{-4.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-3.9176761295989384`, -2.5}, {-4.205909005566828, -2.5}, \
{-3.999865158168957, -2.4375}, {-3.9176761295989384`, -2.5}}], 
      PolygonBox[{{-3.999865158168957, -2.4375}, {-3.9157074104439467`, \
-2.437499981032941}, {-3.9176761295989384`, -2.5}, {-3.999865158168957, \
-2.4375}}], 
      PolygonBox[{{-3.7940909946396024`, -2.5}, {-3.9176761295989384`, -2.5}, \
{-3.9157074104439467`, -2.437499981032941}, {-3.7940909946396024`, -2.5}}], 
      PolygonBox[{{-3.9157074104439467`, -2.437499981032941}, \
{-3.769748357463745, -2.4373449933535234`}, {-3.7940909946396024`, -2.5}, \
{-3.9157074104439467`, -2.437499981032941}}], 
      PolygonBox[{{-3.642337217350629, -2.5}, {-3.7940909946396024`, -2.5}, \
{-3.769748357463745, -2.4373449933535234`}, {-3.642337217350629, -2.5}}], 
      PolygonBox[{{-3.769748357463745, -2.4373449933535234`}, \
{-3.595057255667003, -2.404942744332997}, {-3.642337217350629, -2.5}, \
{-3.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{-3.5, -2.5}, {-3.642337217350629, -2.5}, \
{-3.595057255667003, -2.404942744332997}, {-3.5, -2.5}}], 
      PolygonBox[{{-3.595057255667003, -2.404942744332997}, \
{-3.595057255667003, -2.404942744332997}, {-3.5, -2.5}, {-3.595057255667003, \
-2.404942744332997}}], 
      PolygonBox[{{-3.5, -2.5}, {-3.5, -2.5}, {-3.595057255667003, \
-2.404942744332997}, {-3.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, -1.}, {-4.479166666666667, -1.}, {-4.458333333333333, \
-1.}, {-4.4375, -1.}, {-4.416666666666667, -1.}, {-4.395833333333333, -1.}, \
{-4.375, -1.}, {-4.375, -1.}, {-4.395833333333333, -1.}, {-4.416666666666667, \
-1.}, {-4.4375, -1.}, {-4.458333333333333, -1.}, {-4.479166666666667, -1.}, \
{-4.5, -1.}, {-4.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, -1.}, {-3.6041666666666665`, -1.}, \
{-3.5833333333333335`, -1.}, {-3.5625, -1.}, {-3.5416666666666665`, -1.}, \
{-3.5208333333333335`, -1.}, {-3.5, -1.}, {-3.5, -1.}, {-3.5208333333333335`, \
-1.}, {-3.5416666666666665`, -1.}, {-3.5625, -1.}, {-3.5833333333333335`, \
-1.}, {-3.6041666666666665`, -1.}, {-3.625, -1.}, {-3.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -1.5}, {-4., -1.4791666666666667`}, {-4., \
-1.4583333333333333`}, {-4., -1.4375}, {-4., -1.4166666666666667`}, {-4., \
-1.3958333333333335`}, {-4., -1.375}, {-4., -1.375}, {-4., \
-1.3958333333333333`}, {-4., -1.4166666666666667`}, {-4., -1.4375}, {-4., \
-1.4583333333333333`}, {-4., -1.4791666666666665`}, {-4., -1.5}, {-4., \
-1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -0.625}, {-4., -0.6041666666666667}, {-4., \
-0.5833333333333333}, {-4., -0.5625}, {-4., -0.5416666666666667}, {-4., \
-0.5208333333333334}, {-4., -0.5}, {-4., -0.5}, {-4., -0.5208333333333333}, \
{-4., -0.5416666666666667}, {-4., -0.5625}, {-4., -0.5833333333333333}, {-4., \
-0.6041666666666666}, {-4., -0.625}, {-4., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, -1.}, {-4.25, -1.}, {-4.125, -1.}, {-4., -1.}, \
{-3.875, -1.}, {-3.75, -1.}, {-3.625, -1.}, {-3.625, -1.}, {-3.75, -1.}, \
{-3.875, -1.}, {-4., -1.}, {-4.125, -1.}, {-4.25, -1.}, {-4.375, -1.}, \
{-4.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -1.375}, {-4., -1.25}, {-4., -1.125}, {-4., -1.}, {-4., \
-0.875}, {-4., -0.75}, {-4., -0.625}, {-4., -0.625}, {-4., -0.75}, {-4., \
-0.875}, {-4., -1.}, {-4., -1.125}, {-4., -1.25}, {-4., -1.375}, {-4., \
-1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByD0h/1ieoGO2lK8B47mbcl+8eTN/gs7zKue
pMHkX+1PFUpR+/iA98AUzwkzjzQ/3w8WbuA74PD43ouJs5/u3yj9VsrKkv9A
xA4X1rUZTyDyDAJQ/U/2qxd1fkpKFkCVPyAA13/u29mcdn7BA5Oh5s9QfnKo
10fwwH8weLn/a0Z4/KsiwQNHoO6D2C8Idz9Mfu4J1VPdvR/h+iHyn+Hmm902
3yxr9wVuf0LfBG5zo6/7NaDuu7I4tnbl6a9o7v+2fxPUfzB5Rqj/Yfph4QMz
HxZ+jFD7YeE7H+o+9PAHAKMRqUI=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByD0g/2hYMAL569eBQJ8cD6EFkCTF0DTL4im
XoggH6LvKZwPNnbVKzT1H9DkP6Hp/4qm/gcGH9V9P9Dc/wPNfz/Q/P9jfxhK
+MDU8xDkh6G4j+fAahT3w9R/QJN/hab/KZr6B/sB1Kh3EQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, -1.2651650429449552`}, \
{-3.6752404735808355`, -1.1875}, {-3.595057255667003, -1.4049427443329972`}, \
{-3.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{-3.5626550066464766`, -1.230251642536255}, \
{-3.595057255667003, -1.4049427443329972`}, {-3.6752404735808355`, -1.1875}, \
{-3.5626550066464766`, -1.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, -1.1875}, {-3.6377778151415994`, \
-1.0970571419134454`}, {-3.5626550066464766`, -1.230251642536255}, \
{-3.6752404735808355`, -1.1875}}], 
      PolygonBox[{{-3.562500018967059, -1.0842925895560618`}, \
{-3.5626550066464766`, -1.230251642536255}, {-3.6377778151415994`, \
-1.0970571419134454`}, {-3.562500018967059, -1.0842925895560618`}}], 
      PolygonBox[{{-3.6377778151415994`, -1.0970571419134454`}, {-3.625, \
-1.}, {-3.562500018967059, -1.0842925895560618`}, {-3.6377778151415994`, \
-1.0970571419134454`}}], 
      PolygonBox[{{-3.5625, -1.}, {-3.562500018967059, -1.0842925895560618`}, \
{-3.625, -1.}, {-3.5625, -1.}}], 
      PolygonBox[{{-3.625, -1.}, {-3.6377778151415994`, -0.9029428580865547}, \
{-3.5625, -1.}, {-3.625, -1.}}], 
      PolygonBox[{{-3.562500018967059, -0.9157074104439382}, {-3.5625, -1.}, \
{-3.6377778151415994`, -0.9029428580865547}, {-3.562500018967059, \
-0.9157074104439382}}], 
      PolygonBox[{{-3.6377778151415994`, -0.9029428580865547}, \
{-3.6752404735808355`, -0.8125}, {-3.562500018967059, -0.9157074104439382}, \
{-3.6377778151415994`, -0.9029428580865547}}], 
      PolygonBox[{{-3.5626550066464766`, -0.7697483574637449}, \
{-3.562500018967059, -0.9157074104439382}, {-3.6752404735808355`, -0.8125}, \
{-3.5626550066464766`, -0.7697483574637449}}], 
      PolygonBox[{{-3.6752404735808355`, -0.8125}, {-3.7348349570550448`, \
-0.7348349570550448}, {-3.5626550066464766`, -0.7697483574637449}, \
{-3.6752404735808355`, -0.8125}}], 
      PolygonBox[{{-3.595057255667003, -0.5950572556670028}, \
{-3.5626550066464766`, -0.7697483574637449}, {-3.7348349570550448`, \
-0.7348349570550448}, {-3.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{-3.7348349570550448`, -0.7348349570550448}, {-3.8125, \
-0.6752404735808355}, {-3.595057255667003, -0.5950572556670028}, \
{-3.7348349570550448`, -0.7348349570550448}}], 
      PolygonBox[{{-3.7697483574637447`, -0.5626550066464766}, \
{-3.595057255667003, -0.5950572556670028}, {-3.8125, -0.6752404735808355}, \
{-3.7697483574637447`, -0.5626550066464766}}], 
      PolygonBox[{{-3.8125, -0.6752404735808355}, {-3.9029428580865546`, \
-0.6377778151415994}, {-3.7697483574637447`, -0.5626550066464766}, {-3.8125, \
-0.6752404735808355}}], 
      PolygonBox[{{-3.9157074104439396`, -0.5625000189670593}, \
{-3.7697483574637447`, -0.5626550066464766}, {-3.9029428580865546`, \
-0.6377778151415994}, {-3.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-3.9029428580865546`, -0.6377778151415994}, {-4., -0.625}, \
{-3.9157074104439396`, -0.5625000189670593}, {-3.9029428580865546`, \
-0.6377778151415994}}], 
      PolygonBox[{{-3.9998944727795123`, -0.5625}, {-3.9157074104439396`, \
-0.5625000189670593}, {-4., -0.625}, {-3.9998944727795123`, -0.5625}}], 
      PolygonBox[{{-4., -0.625}, {-4.097057141913445, -0.6377778151415994}, \
{-3.9998944727795123`, -0.5625}, {-4., -0.625}}], 
      PolygonBox[{{-4.084292589556057, -0.5625000189670593}, \
{-3.9998944727795123`, -0.5625}, {-4.097057141913445, -0.6377778151415994}, \
{-4.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-4.097057141913445, -0.6377778151415994}, {-4.1875, \
-0.6752404735808355}, {-4.084292589556057, -0.5625000189670593}, \
{-4.097057141913445, -0.6377778151415994}}], 
      PolygonBox[{{-4.230251642536255, -0.5626550066464766}, \
{-4.084292589556057, -0.5625000189670593}, {-4.1875, -0.6752404735808355}, \
{-4.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-4.1875, -0.6752404735808355}, {-4.265165042944956, \
-0.7348349570550446}, {-4.230251642536255, -0.5626550066464766}, {-4.1875, \
-0.6752404735808355}}], 
      PolygonBox[{{-4.404942744332997, -0.5950572556670028}, \
{-4.230251642536255, -0.5626550066464766}, {-4.265165042944956, \
-0.7348349570550446}, {-4.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{-4.265165042944956, -0.7348349570550446}, \
{-4.3247595264191645`, -0.8124999999999999}, {-4.404942744332997, \
-0.5950572556670028}, {-4.265165042944956, -0.7348349570550446}}], 
      PolygonBox[{{-4.437344993353523, -0.7697483574637446}, \
{-4.404942744332997, -0.5950572556670028}, {-4.3247595264191645`, \
-0.8124999999999999}, {-4.437344993353523, -0.7697483574637446}}], 
      PolygonBox[{{-4.3247595264191645`, -0.8124999999999999}, \
{-4.362222184858401, -0.9029428580865546}, {-4.437344993353523, \
-0.7697483574637446}, {-4.3247595264191645`, -0.8124999999999999}}], 
      PolygonBox[{{-4.437499981032941, -0.9157074104439377}, \
{-4.437344993353523, -0.7697483574637446}, {-4.362222184858401, \
-0.9029428580865546}, {-4.437499981032941, -0.9157074104439377}}], 
      PolygonBox[{{-4.362222184858401, -0.9029428580865546}, {-4.375, \
-0.9999999999999998}, {-4.437499981032941, -0.9157074104439377}, \
{-4.362222184858401, -0.9029428580865546}}], 
      PolygonBox[{{-4.4375, -0.9998768219370047}, {-4.437499981032941, \
-0.9157074104439377}, {-4.375, -0.9999999999999998}, {-4.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-4.375, -0.9999999999999998}, {-4.362222184858401, \
-1.0970571419134452`}, {-4.4375, -0.9998768219370047}, {-4.375, \
-0.9999999999999998}}], 
      PolygonBox[{{-4.437499981032941, -1.084292589556055}, {-4.4375, \
-0.9998768219370047}, {-4.362222184858401, -1.0970571419134452`}, \
{-4.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-4.362222184858401, -1.0970571419134452`}, \
{-4.3247595264191645`, -1.1874999999999998`}, {-4.437499981032941, \
-1.084292589556055}, {-4.362222184858401, -1.0970571419134452`}}], 
      PolygonBox[{{-4.437344993353523, -1.2302516425362549`}, \
{-4.437499981032941, -1.084292589556055}, {-4.3247595264191645`, \
-1.1874999999999998`}, {-4.437344993353523, -1.2302516425362549`}}], 
      PolygonBox[{{-4.3247595264191645`, -1.1874999999999998`}, \
{-4.265165042944956, -1.2651650429449552`}, {-4.437344993353523, \
-1.2302516425362549`}, {-4.3247595264191645`, -1.1874999999999998`}}], 
      PolygonBox[{{-4.404942744332997, -1.4049427443329972`}, \
{-4.437344993353523, -1.2302516425362549`}, {-4.265165042944956, \
-1.2651650429449552`}, {-4.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-4.265165042944956, -1.2651650429449552`}, {-4.1875, \
-1.3247595264191645`}, {-4.404942744332997, -1.4049427443329972`}, \
{-4.265165042944956, -1.2651650429449552`}}], 
      PolygonBox[{{-4.230251642536255, -1.4373449933535234`}, \
{-4.404942744332997, -1.4049427443329972`}, {-4.1875, -1.3247595264191645`}, \
{-4.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-4.1875, -1.3247595264191645`}, {-4.097057141913446, \
-1.3622221848584006`}, {-4.230251642536255, -1.4373449933535234`}, {-4.1875, \
-1.3247595264191645`}}], 
      PolygonBox[{{-4.084292589556064, -1.4374999810329407`}, \
{-4.230251642536255, -1.4373449933535234`}, {-4.097057141913446, \
-1.3622221848584006`}, {-4.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-4.097057141913446, -1.3622221848584006`}, {-4., -1.375}, \
{-4.084292589556064, -1.4374999810329407`}, {-4.097057141913446, \
-1.3622221848584006`}}], 
      PolygonBox[{{-3.999865158168957, -1.4375}, {-4.084292589556064, \
-1.4374999810329407`}, {-4., -1.375}, {-3.999865158168957, -1.4375}}], 
      PolygonBox[{{-4., -1.375}, {-3.902942858086555, -1.3622221848584006`}, \
{-3.999865158168957, -1.4375}, {-4., -1.375}}], 
      PolygonBox[{{-3.9157074104439467`, -1.4374999810329407`}, \
{-3.999865158168957, -1.4375}, {-3.902942858086555, -1.3622221848584006`}, \
{-3.9157074104439467`, -1.4374999810329407`}}], 
      PolygonBox[{{-3.902942858086555, -1.3622221848584006`}, \
{-3.8125000000000004`, -1.3247595264191645`}, {-3.9157074104439467`, \
-1.4374999810329407`}, {-3.902942858086555, -1.3622221848584006`}}], 
      PolygonBox[{{-3.769748357463745, -1.4373449933535234`}, \
{-3.9157074104439467`, -1.4374999810329407`}, {-3.8125000000000004`, \
-1.3247595264191645`}, {-3.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{-3.8125000000000004`, -1.3247595264191645`}, \
{-3.7348349570550448`, -1.2651650429449552`}, {-3.769748357463745, \
-1.4373449933535234`}, {-3.8125000000000004`, -1.3247595264191645`}}], 
      PolygonBox[{{-3.595057255667003, -1.4049427443329972`}, \
{-3.769748357463745, -1.4373449933535234`}, {-3.7348349570550448`, \
-1.2651650429449552`}, {-3.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-3.7348349570550448`, -1.2651650429449552`}, \
{-3.7348349570550448`, -1.2651650429449552`}, {-3.595057255667003, \
-1.4049427443329972`}, {-3.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{-3.595057255667003, -1.4049427443329972`}, \
{-3.595057255667003, -1.4049427443329972`}, {-3.7348349570550448`, \
-1.2651650429449552`}, {-3.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-3.595057255667003, -1.4049427443329972`}, \
{-3.5626550066464766`, -1.230251642536255}, {-3.5, -1.5}, \
{-3.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-3.5, -1.3576627826493677`}, {-3.5, -1.5}, \
{-3.5626550066464766`, -1.230251642536255}, {-3.5, -1.3576627826493677`}}], 
      PolygonBox[{{-3.5626550066464766`, -1.230251642536255}, \
{-3.562500018967059, -1.0842925895560618`}, {-3.5, -1.3576627826493677`}, \
{-3.5626550066464766`, -1.230251642536255}}], 
      PolygonBox[{{-3.5, -1.20590900530174}, {-3.5, -1.3576627826493677`}, \
{-3.562500018967059, -1.0842925895560618`}, {-3.5, -1.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, -1.0842925895560618`}, {-3.5625, -1.}, \
{-3.5, -1.20590900530174}, {-3.562500018967059, -1.0842925895560618`}}], 
      PolygonBox[{{-3.5, -1.}, {-3.5, -1.20590900530174}, {-3.5625, -1.}, \
{-3.5, -1.}}], 
      PolygonBox[{{-3.5625, -1.}, {-3.562500018967059, -0.9157074104439382}, \
{-3.5, -1.}, {-3.5625, -1.}}], 
      PolygonBox[{{-3.5, -0.79409099469826}, {-3.5, -1.}, \
{-3.562500018967059, -0.9157074104439382}, {-3.5, -0.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, -0.9157074104439382}, \
{-3.5626550066464766`, -0.7697483574637449}, {-3.5, -0.79409099469826}, \
{-3.562500018967059, -0.9157074104439382}}], 
      PolygonBox[{{-3.5, -0.6423372173506324}, {-3.5, -0.79409099469826}, \
{-3.5626550066464766`, -0.7697483574637449}, {-3.5, -0.6423372173506324}}], 
      PolygonBox[{{-3.5626550066464766`, -0.7697483574637449}, \
{-3.595057255667003, -0.5950572556670028}, {-3.5, -0.6423372173506324}, \
{-3.5626550066464766`, -0.7697483574637449}}], 
      PolygonBox[{{-3.508553435038814, -0.508553435038814}, {-3.5, \
-0.6423372173506324}, {-3.595057255667003, -0.5950572556670028}, \
{-3.508553435038814, -0.508553435038814}}], 
      PolygonBox[{{-3.595057255667003, -0.5950572556670028}, \
{-3.7697483574637447`, -0.5626550066464766}, {-3.508553435038814, \
-0.508553435038814}, {-3.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{-3.642337217350632, -0.5}, {-3.508553435038814, \
-0.508553435038814}, {-3.7697483574637447`, -0.5626550066464766}, \
{-3.642337217350632, -0.5}}], 
      PolygonBox[{{-3.7697483574637447`, -0.5626550066464766}, \
{-3.9157074104439396`, -0.5625000189670593}, {-3.642337217350632, -0.5}, \
{-3.7697483574637447`, -0.5626550066464766}}], 
      PolygonBox[{{-3.7940909946267443`, -0.5}, {-3.642337217350632, -0.5}, \
{-3.9157074104439396`, -0.5625000189670593}, {-3.7940909946267443`, -0.5}}], 
      PolygonBox[{{-3.9157074104439396`, -0.5625000189670593}, \
{-3.9998944727795123`, -0.5625}, {-3.7940909946267443`, -0.5}, \
{-3.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-3.92205804197311, -0.5}, {-3.7940909946267443`, -0.5}, \
{-3.9998944727795123`, -0.5625}, {-3.92205804197311, -0.5}}], 
      PolygonBox[{{-3.9998944727795123`, -0.5625}, {-4.084292589556057, \
-0.5625000189670593}, {-3.92205804197311, -0.5}, {-3.9998944727795123`, \
-0.5625}}], 
      PolygonBox[{{-4.205909005304446, -0.5}, {-3.92205804197311, -0.5}, \
{-4.084292589556057, -0.5625000189670593}, {-4.205909005304446, -0.5}}], 
      PolygonBox[{{-4.084292589556057, -0.5625000189670593}, \
{-4.230251642536255, -0.5626550066464766}, {-4.205909005304446, -0.5}, \
{-4.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-4.357662782649366, -0.5}, {-4.205909005304446, -0.5}, \
{-4.230251642536255, -0.5626550066464766}, {-4.357662782649366, -0.5}}], 
      PolygonBox[{{-4.230251642536255, -0.5626550066464766}, \
{-4.404942744332997, -0.5950572556670028}, {-4.357662782649366, -0.5}, \
{-4.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-3.5, -0.5}, {-4.357662782649366, -0.5}, \
{-4.404942744332997, -0.5950572556670028}, {-3.5, -0.5}}], 
      PolygonBox[{{-4.404942744332997, -0.5950572556670028}, \
{-4.437344993353523, -0.7697483574637446}, {-3.5, -0.5}, {-4.404942744332997, \
-0.5950572556670028}}], 
      PolygonBox[{{-4.5, -0.642337217350631}, {-3.5, -0.5}, \
{-4.437344993353523, -0.7697483574637446}, {-4.5, -0.642337217350631}}], 
      PolygonBox[{{-4.437344993353523, -0.7697483574637446}, \
{-4.437499981032941, -0.9157074104439377}, {-4.5, -0.642337217350631}, \
{-4.437344993353523, -0.7697483574637446}}], 
      PolygonBox[{{-4.5, -0.7940909947171011}, {-4.5, -0.642337217350631}, \
{-4.437499981032941, -0.9157074104439377}, {-4.5, -0.7940909947171011}}], 
      PolygonBox[{{-4.437499981032941, -0.9157074104439377}, {-4.4375, \
-0.9998768219370047}, {-4.5, -0.7940909947171011}, {-4.437499981032941, \
-0.9157074104439377}}], 
      PolygonBox[{{-4.5, -0.9193213332412997}, {-4.5, -0.7940909947171011}, \
{-4.4375, -0.9998768219370047}, {-4.5, -0.9193213332412997}}], 
      PolygonBox[{{-4.4375, -0.9998768219370047}, {-4.437499981032941, \
-1.084292589556055}, {-4.5, -0.9193213332412997}, {-4.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-4.5, -1.2059090051452785`}, {-4.5, -0.9193213332412997}, \
{-4.437499981032941, -1.084292589556055}, {-4.5, -1.2059090051452785`}}], 
      PolygonBox[{{-4.437499981032941, -1.084292589556055}, \
{-4.437344993353523, -1.2302516425362549`}, {-4.5, -1.2059090051452785`}, \
{-4.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-4.5, -1.3576627826493652`}, {-4.5, -1.2059090051452785`}, \
{-4.437344993353523, -1.2302516425362549`}, {-4.5, -1.3576627826493652`}}], 
      PolygonBox[{{-4.437344993353523, -1.2302516425362549`}, \
{-4.404942744332997, -1.4049427443329972`}, {-4.5, -1.3576627826493652`}, \
{-4.437344993353523, -1.2302516425362549`}}], 
      PolygonBox[{{-4.5, -0.5}, {-4.5, -1.3576627826493652`}, \
{-4.404942744332997, -1.4049427443329972`}, {-4.5, -0.5}}], 
      PolygonBox[{{-4.404942744332997, -1.4049427443329972`}, \
{-4.230251642536255, -1.4373449933535234`}, {-4.5, -0.5}, \
{-4.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-4.5, -1.5}, {-4.5, -0.5}, {-4.230251642536255, \
-1.4373449933535234`}, {-4.5, -1.5}}], 
      PolygonBox[{{-4.230251642536255, -1.4373449933535234`}, \
{-4.084292589556064, -1.4374999810329407`}, {-4.5, -1.5}, \
{-4.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-4.205909005566828, -1.5}, {-4.5, -1.5}, \
{-4.084292589556064, -1.4374999810329407`}, {-4.205909005566828, -1.5}}], 
      PolygonBox[{{-4.084292589556064, -1.4374999810329407`}, \
{-3.999865158168957, -1.4375}, {-4.205909005566828, -1.5}, \
{-4.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-3.9176761295989384`, -1.5}, {-4.205909005566828, -1.5}, \
{-3.999865158168957, -1.4375}, {-3.9176761295989384`, -1.5}}], 
      PolygonBox[{{-3.999865158168957, -1.4375}, {-3.9157074104439467`, \
-1.4374999810329407`}, {-3.9176761295989384`, -1.5}, {-3.999865158168957, \
-1.4375}}], 
      PolygonBox[{{-3.7940909946396024`, -1.5}, {-3.9176761295989384`, -1.5}, \
{-3.9157074104439467`, -1.4374999810329407`}, {-3.7940909946396024`, -1.5}}], 
      PolygonBox[{{-3.9157074104439467`, -1.4374999810329407`}, \
{-3.769748357463745, -1.4373449933535234`}, {-3.7940909946396024`, -1.5}, \
{-3.9157074104439467`, -1.4374999810329407`}}], 
      PolygonBox[{{-3.642337217350629, -1.5}, {-3.7940909946396024`, -1.5}, \
{-3.769748357463745, -1.4373449933535234`}, {-3.642337217350629, -1.5}}], 
      PolygonBox[{{-3.769748357463745, -1.4373449933535234`}, \
{-3.595057255667003, -1.4049427443329972`}, {-3.642337217350629, -1.5}, \
{-3.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{-3.5, -1.5}, {-3.642337217350629, -1.5}, \
{-3.595057255667003, -1.4049427443329972`}, {-3.5, -1.5}}], 
      PolygonBox[{{-3.595057255667003, -1.4049427443329972`}, \
{-3.595057255667003, -1.4049427443329972`}, {-3.5, -1.5}, \
{-3.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-3.5, -1.5}, {-3.5, -1.5}, {-3.595057255667003, \
-1.4049427443329972`}, {-3.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, 0.}, {-4.479166666666667, 0.}, {-4.458333333333333, 
       0.}, {-4.4375, 0.}, {-4.416666666666667, 0.}, {-4.395833333333333, 
       0.}, {-4.375, 0.}, {-4.375, 0.}, {-4.395833333333333, 
       0.}, {-4.416666666666667, 0.}, {-4.4375, 0.}, {-4.458333333333333, 
       0.}, {-4.479166666666667, 0.}, {-4.5, 0.}, {-4.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, 0.}, {-3.6041666666666665`, 
       0.}, {-3.5833333333333335`, 0.}, {-3.5625, 0.}, {-3.5416666666666665`, 
       0.}, {-3.5208333333333335`, 0.}, {-3.5, 0.}, {-3.5, 
       0.}, {-3.5208333333333335`, 0.}, {-3.5416666666666665`, 0.}, {-3.5625, 
       0.}, {-3.5833333333333335`, 0.}, {-3.6041666666666665`, 0.}, {-3.625, 
       0.}, {-3.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -0.5}, {-4., -0.4791666666666667}, {-4., \
-0.4583333333333333}, {-4., -0.4375}, {-4., -0.4166666666666667}, {-4., \
-0.39583333333333337`}, {-4., -0.375}, {-4., -0.375}, {-4., \
-0.3958333333333333}, {-4., -0.4166666666666667}, {-4., -0.4375}, {-4., \
-0.4583333333333333}, {-4., -0.47916666666666663`}, {-4., -0.5}, {-4., \
-0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 0.375}, {-4., 0.3958333333333333}, {-4., 
       0.4166666666666667}, {-4., 0.4375}, {-4., 0.4583333333333333}, {-4., 
       0.47916666666666663`}, {-4., 0.5}, {-4., 0.5}, {-4., 
       0.4791666666666667}, {-4., 0.4583333333333333}, {-4., 0.4375}, {-4., 
       0.4166666666666667}, {-4., 0.39583333333333337`}, {-4., 0.375}, {-4., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, 0.}, {-4.25, 0.}, {-4.125, 0.}, {-4., 0.}, {-3.875, 
       0.}, {-3.75, 0.}, {-3.625, 0.}, {-3.625, 0.}, {-3.75, 0.}, {-3.875, 
       0.}, {-4., 0.}, {-4.125, 0.}, {-4.25, 0.}, {-4.375, 0.}, {-4.375, 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -0.375}, {-4., -0.25}, {-4., -0.125}, {-4., 0.}, {-4., 
       0.125}, {-4., 0.25}, {-4., 0.375}, {-4., 0.375}, {-4., 0.25}, {-4., 
       0.125}, {-4., 
       0.}, {-4., -0.125}, {-4., -0.25}, {-4., -0.375}, {-4., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8B2AsMb1AR20p3gM3OmMW7bmxw/7CDvOqJ2m8
B/6DwXH7VKEUtY8PeA/czLl/puzHBXuwpga+Aw2WTnp3Tlyx3yj9VsrKkv+A
f3/Z16V61yHyDAJQ82/Yqxd1fkpKFjgQgCx/QACu/9y3sznt/IIHbkHNn6H8
5FCvj+ABFrDCE/ZfM8LjXxUJHngAdR/EfsEDXF3zfCwru2xg8ucg8vth+v9A
3L8fZv51iPn7YfbXQezfrwF1nx/EffvR3L9/E9R/UPfvZ4T6vwmqHxY+UPfv
h4UfG8T9+2Hh+w7qPlj4Q9w/aw8AtIeukQ==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByD0A/tQMOCF81evAgE+OB9CC6DJC6DpF0RT
L0SQHwbWdxWNfxRNPQwIHQiByO9H5V/dj6r+AQYfzX370dy/H81/+9H8vz8M
NXyg6nkI8sNQ3AfjH0VTDwM8MP/Zo/Kv2qOqf2APADkdY1s=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, -0.2651650429449553}, \
{-3.6752404735808355`, -0.1875}, {-3.595057255667003, -0.4049427443329971}, \
{-3.7348349570550448`, -0.2651650429449553}}], 
      PolygonBox[{{-3.5626550066464766`, -0.23025164253625516`}, \
{-3.595057255667003, -0.4049427443329971}, {-3.6752404735808355`, -0.1875}, \
{-3.5626550066464766`, -0.23025164253625516`}}], 
      PolygonBox[{{-3.6752404735808355`, -0.1875}, {-3.6377778151415994`, \
-0.0970571419134453}, {-3.5626550066464766`, -0.23025164253625516`}, \
{-3.6752404735808355`, -0.1875}}], 
      PolygonBox[{{-3.562500018967059, -0.08429258955606181}, \
{-3.5626550066464766`, -0.23025164253625516`}, {-3.6377778151415994`, \
-0.0970571419134453}, {-3.562500018967059, -0.08429258955606181}}], 
      PolygonBox[{{-3.6377778151415994`, -0.0970571419134453}, {-3.625, 
       0.}, {-3.562500018967059, -0.08429258955606181}, \
{-3.6377778151415994`, -0.0970571419134453}}], 
      PolygonBox[{{-3.5625, 
       0.}, {-3.562500018967059, -0.08429258955606181}, {-3.625, 
       0.}, {-3.5625, 0.}}], 
      PolygonBox[{{-3.625, 0.}, {-3.6377778151415994`, 
       0.09705714191344525}, {-3.5625, 0.}, {-3.625, 0.}}], 
      PolygonBox[{{-3.562500018967059, 0.08429258955606177}, {-3.5625, 
       0.}, {-3.6377778151415994`, 0.09705714191344525}, {-3.562500018967059, 
       0.08429258955606177}}], 
      PolygonBox[{{-3.6377778151415994`, 
       0.09705714191344525}, {-3.6752404735808355`, 
       0.18749999999999994`}, {-3.562500018967059, 
       0.08429258955606177}, {-3.6377778151415994`, 0.09705714191344525}}], 
      PolygonBox[{{-3.5626550066464766`, 
       0.23025164253625502`}, {-3.562500018967059, 
       0.08429258955606177}, {-3.6752404735808355`, 
       0.18749999999999994`}, {-3.5626550066464766`, 0.23025164253625502`}}], 
      PolygonBox[{{-3.6752404735808355`, 
       0.18749999999999994`}, {-3.7348349570550448`, 
       0.2651650429449553}, {-3.5626550066464766`, 
       0.23025164253625502`}, {-3.6752404735808355`, 0.18749999999999994`}}], 
      PolygonBox[{{-3.595057255667003, 
       0.40494274433299715`}, {-3.5626550066464766`, 
       0.23025164253625502`}, {-3.7348349570550448`, 
       0.2651650429449553}, {-3.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{-3.7348349570550448`, 0.2651650429449553}, {-3.8125, 
       0.3247595264191645}, {-3.595057255667003, 
       0.40494274433299715`}, {-3.7348349570550448`, 0.2651650429449553}}], 
      PolygonBox[{{-3.7697483574637447`, 
       0.4373449933535234}, {-3.595057255667003, 
       0.40494274433299715`}, {-3.8125, 
       0.3247595264191645}, {-3.7697483574637447`, 0.4373449933535234}}], 
      PolygonBox[{{-3.8125, 0.3247595264191645}, {-3.9029428580865546`, 
       0.3622221848584006}, {-3.7697483574637447`, 
       0.4373449933535234}, {-3.8125, 0.3247595264191645}}], 
      PolygonBox[{{-3.9157074104439396`, 
       0.4374999810329408}, {-3.7697483574637447`, 
       0.4373449933535234}, {-3.9029428580865546`, 
       0.3622221848584006}, {-3.9157074104439396`, 0.4374999810329408}}], 
      PolygonBox[{{-3.9029428580865546`, 0.3622221848584006}, {-4., 
       0.375}, {-3.9157074104439396`, 
       0.4374999810329408}, {-3.9029428580865546`, 0.3622221848584006}}], 
      PolygonBox[{{-3.9998944727795123`, 0.4375}, {-3.9157074104439396`, 
       0.4374999810329408}, {-4., 0.375}, {-3.9998944727795123`, 0.4375}}], 
      PolygonBox[{{-4., 0.375}, {-4.097057141913445, 
       0.36222218485840063`}, {-3.9998944727795123`, 0.4375}, {-4., 0.375}}], 
      PolygonBox[{{-4.084292589556057, 
       0.4374999810329408}, {-3.9998944727795123`, 
       0.4375}, {-4.097057141913445, 
       0.36222218485840063`}, {-4.084292589556057, 0.4374999810329408}}], 
      PolygonBox[{{-4.097057141913445, 0.36222218485840063`}, {-4.1875, 
       0.3247595264191645}, {-4.084292589556057, 
       0.4374999810329408}, {-4.097057141913445, 0.36222218485840063`}}], 
      PolygonBox[{{-4.230251642536255, 
       0.4373449933535234}, {-4.084292589556057, 
       0.4374999810329408}, {-4.1875, 
       0.3247595264191645}, {-4.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{-4.1875, 0.3247595264191645}, {-4.265165042944956, 
       0.26516504294495535`}, {-4.230251642536255, 
       0.4373449933535234}, {-4.1875, 0.3247595264191645}}], 
      PolygonBox[{{-4.404942744332997, 
       0.40494274433299715`}, {-4.230251642536255, 
       0.4373449933535234}, {-4.265165042944956, 
       0.26516504294495535`}, {-4.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{-4.265165042944956, 
       0.26516504294495535`}, {-4.3247595264191645`, 
       0.1875000000000001}, {-4.404942744332997, 
       0.40494274433299715`}, {-4.265165042944956, 0.26516504294495535`}}], 
      PolygonBox[{{-4.437344993353523, 
       0.2302516425362554}, {-4.404942744332997, 
       0.40494274433299715`}, {-4.3247595264191645`, 
       0.1875000000000001}, {-4.437344993353523, 0.2302516425362554}}], 
      PolygonBox[{{-4.3247595264191645`, 
       0.1875000000000001}, {-4.362222184858401, 
       0.09705714191344539}, {-4.437344993353523, 
       0.2302516425362554}, {-4.3247595264191645`, 0.1875000000000001}}], 
      PolygonBox[{{-4.437499981032941, 
       0.08429258955606238}, {-4.437344993353523, 
       0.2302516425362554}, {-4.362222184858401, 
       0.09705714191344539}, {-4.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-4.362222184858401, 0.09705714191344539}, {-4.375, 
       2.1245770866179924`*^-16}, {-4.437499981032941, 
       0.08429258955606238}, {-4.362222184858401, 0.09705714191344539}}], 
      PolygonBox[{{-4.4375, 0.00012317806299537147`}, {-4.437499981032941, 
       0.08429258955606238}, {-4.375, 2.1245770866179924`*^-16}, {-4.4375, 
       0.00012317806299537147`}}], 
      PolygonBox[{{-4.375, 
       2.1245770866179924`*^-16}, {-4.362222184858401, -0.09705714191344514}, \
{-4.4375, 0.00012317806299537147`}, {-4.375, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{-4.437499981032941, -0.084292589556055}, {-4.4375, 
       0.00012317806299537147`}, {-4.362222184858401, -0.09705714191344514}, \
{-4.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-4.362222184858401, -0.09705714191344514}, \
{-4.3247595264191645`, -0.18749999999999978`}, {-4.437499981032941, \
-0.084292589556055}, {-4.362222184858401, -0.09705714191344514}}], 
      PolygonBox[{{-4.437344993353523, -0.23025164253625477`}, \
{-4.437499981032941, -0.084292589556055}, {-4.3247595264191645`, \
-0.18749999999999978`}, {-4.437344993353523, -0.23025164253625477`}}], 
      PolygonBox[{{-4.3247595264191645`, -0.18749999999999978`}, \
{-4.265165042944956, -0.2651650429449553}, {-4.437344993353523, \
-0.23025164253625477`}, {-4.3247595264191645`, -0.18749999999999978`}}], 
      PolygonBox[{{-4.404942744332997, -0.4049427443329971}, \
{-4.437344993353523, -0.23025164253625477`}, {-4.265165042944956, \
-0.2651650429449553}, {-4.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-4.265165042944956, -0.2651650429449553}, {-4.1875, \
-0.3247595264191644}, {-4.404942744332997, -0.4049427443329971}, \
{-4.265165042944956, -0.2651650429449553}}], 
      PolygonBox[{{-4.230251642536255, -0.4373449933535234}, \
{-4.404942744332997, -0.4049427443329971}, {-4.1875, -0.3247595264191644}, \
{-4.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{-4.1875, -0.3247595264191644}, {-4.097057141913446, \
-0.3622221848584005}, {-4.230251642536255, -0.4373449933535234}, {-4.1875, \
-0.3247595264191644}}], 
      PolygonBox[{{-4.084292589556064, -0.4374999810329408}, \
{-4.230251642536255, -0.4373449933535234}, {-4.097057141913446, \
-0.3622221848584005}, {-4.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-4.097057141913446, -0.3622221848584005}, {-4., -0.375}, \
{-4.084292589556064, -0.4374999810329408}, {-4.097057141913446, \
-0.3622221848584005}}], 
      PolygonBox[{{-3.999865158168957, -0.4375}, {-4.084292589556064, \
-0.4374999810329408}, {-4., -0.375}, {-3.999865158168957, -0.4375}}], 
      PolygonBox[{{-4., -0.375}, {-3.902942858086555, -0.36222218485840063`}, \
{-3.999865158168957, -0.4375}, {-4., -0.375}}], 
      PolygonBox[{{-3.9157074104439467`, -0.4374999810329408}, \
{-3.999865158168957, -0.4375}, {-3.902942858086555, -0.36222218485840063`}, \
{-3.9157074104439467`, -0.4374999810329408}}], 
      PolygonBox[{{-3.902942858086555, -0.36222218485840063`}, \
{-3.8125000000000004`, -0.3247595264191646}, {-3.9157074104439467`, \
-0.4374999810329408}, {-3.902942858086555, -0.36222218485840063`}}], 
      PolygonBox[{{-3.769748357463745, -0.4373449933535234}, \
{-3.9157074104439467`, -0.4374999810329408}, {-3.8125000000000004`, \
-0.3247595264191646}, {-3.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{-3.8125000000000004`, -0.3247595264191646}, \
{-3.7348349570550448`, -0.26516504294495535`}, {-3.769748357463745, \
-0.4373449933535234}, {-3.8125000000000004`, -0.3247595264191646}}], 
      PolygonBox[{{-3.595057255667003, -0.40494274433299715`}, \
{-3.769748357463745, -0.4373449933535234}, {-3.7348349570550448`, \
-0.26516504294495535`}, {-3.595057255667003, -0.40494274433299715`}}], 
      PolygonBox[{{-3.7348349570550448`, -0.26516504294495535`}, \
{-3.7348349570550448`, -0.2651650429449553}, {-3.595057255667003, \
-0.40494274433299715`}, {-3.7348349570550448`, -0.26516504294495535`}}], 
      PolygonBox[{{-3.595057255667003, -0.4049427443329971}, \
{-3.595057255667003, -0.40494274433299715`}, {-3.7348349570550448`, \
-0.2651650429449553}, {-3.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{-3.595057255667003, -0.4049427443329971}, \
{-3.5626550066464766`, -0.23025164253625516`}, {-3.5, -0.5}, \
{-3.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{-3.5, -0.3576627826493677}, {-3.5, -0.5}, \
{-3.5626550066464766`, -0.23025164253625516`}, {-3.5, -0.3576627826493677}}], 
      PolygonBox[{{-3.5626550066464766`, -0.23025164253625516`}, \
{-3.562500018967059, -0.08429258955606181}, {-3.5, -0.3576627826493677}, \
{-3.5626550066464766`, -0.23025164253625516`}}], 
      PolygonBox[{{-3.5, -0.20590900530173997`}, {-3.5, -0.3576627826493677}, \
{-3.562500018967059, -0.08429258955606181}, {-3.5, -0.20590900530173997`}}], 
      PolygonBox[{{-3.562500018967059, -0.08429258955606181}, {-3.5625, 
       0.}, {-3.5, -0.20590900530173997`}, {-3.562500018967059, \
-0.08429258955606181}}], 
      PolygonBox[{{-3.5, 0.}, {-3.5, -0.20590900530173997`}, {-3.5625, 
       0.}, {-3.5, 0.}}], 
      PolygonBox[{{-3.5625, 0.}, {-3.562500018967059, 
       0.08429258955606177}, {-3.5, 0.}, {-3.5625, 0.}}], 
      PolygonBox[{{-3.5, 0.20590900530173992`}, {-3.5, 
       0.}, {-3.562500018967059, 0.08429258955606177}, {-3.5, 
       0.20590900530173992`}}], 
      PolygonBox[{{-3.562500018967059, 
       0.08429258955606177}, {-3.5626550066464766`, 
       0.23025164253625502`}, {-3.5, 
       0.20590900530173992`}, {-3.562500018967059, 0.08429258955606177}}], 
      PolygonBox[{{-3.5, 0.35766278264936757`}, {-3.5, 
       0.20590900530173992`}, {-3.5626550066464766`, 
       0.23025164253625502`}, {-3.5, 0.35766278264936757`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       0.23025164253625502`}, {-3.595057255667003, 
       0.40494274433299715`}, {-3.5, 
       0.35766278264936757`}, {-3.5626550066464766`, 0.23025164253625502`}}], 
      PolygonBox[{{-3.508553435038814, 0.491446564961186}, {-3.5, 
       0.35766278264936757`}, {-3.595057255667003, 
       0.40494274433299715`}, {-3.508553435038814, 0.491446564961186}}], 
      PolygonBox[{{-3.595057255667003, 
       0.40494274433299715`}, {-3.7697483574637447`, 
       0.4373449933535234}, {-3.508553435038814, 
       0.491446564961186}, {-3.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{-3.642337217350632, 0.5}, {-3.508553435038814, 
       0.491446564961186}, {-3.7697483574637447`, 
       0.4373449933535234}, {-3.642337217350632, 0.5}}], 
      PolygonBox[{{-3.7697483574637447`, 
       0.4373449933535234}, {-3.9157074104439396`, 
       0.4374999810329408}, {-3.642337217350632, 0.5}, {-3.7697483574637447`, 
       0.4373449933535234}}], 
      PolygonBox[{{-3.7940909946267443`, 0.5}, {-3.642337217350632, 
       0.5}, {-3.9157074104439396`, 
       0.4374999810329408}, {-3.7940909946267443`, 0.5}}], 
      PolygonBox[{{-3.9157074104439396`, 
       0.4374999810329408}, {-3.9998944727795123`, 
       0.4375}, {-3.7940909946267443`, 0.5}, {-3.9157074104439396`, 
       0.4374999810329408}}], 
      PolygonBox[{{-3.92205804197311, 0.5}, {-3.7940909946267443`, 
       0.5}, {-3.9998944727795123`, 0.4375}, {-3.92205804197311, 0.5}}], 
      PolygonBox[{{-3.9998944727795123`, 0.4375}, {-4.084292589556057, 
       0.4374999810329408}, {-3.92205804197311, 0.5}, {-3.9998944727795123`, 
       0.4375}}], 
      PolygonBox[{{-4.205909005304446, 0.5}, {-3.92205804197311, 
       0.5}, {-4.084292589556057, 0.4374999810329408}, {-4.205909005304446, 
       0.5}}], PolygonBox[{{-4.084292589556057, 
       0.4374999810329408}, {-4.230251642536255, 
       0.4373449933535234}, {-4.205909005304446, 0.5}, {-4.084292589556057, 
       0.4374999810329408}}], 
      PolygonBox[{{-4.357662782649366, 0.5}, {-4.205909005304446, 
       0.5}, {-4.230251642536255, 0.4373449933535234}, {-4.357662782649366, 
       0.5}}], PolygonBox[{{-4.230251642536255, 
       0.4373449933535234}, {-4.404942744332997, 
       0.40494274433299715`}, {-4.357662782649366, 0.5}, {-4.230251642536255, 
       0.4373449933535234}}], 
      PolygonBox[{{-3.5, 0.5}, {-4.357662782649366, 0.5}, {-4.404942744332997,
        0.40494274433299715`}, {-3.5, 0.5}}], 
      PolygonBox[{{-4.404942744332997, 
       0.40494274433299715`}, {-4.437344993353523, 0.2302516425362554}, {-3.5,
        0.5}, {-4.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{-4.5, 0.357662782649369}, {-3.5, 0.5}, {-4.437344993353523,
        0.2302516425362554}, {-4.5, 0.357662782649369}}], 
      PolygonBox[{{-4.437344993353523, 
       0.2302516425362554}, {-4.437499981032941, 0.08429258955606238}, {-4.5, 
       0.357662782649369}, {-4.437344993353523, 0.2302516425362554}}], 
      PolygonBox[{{-4.5, 0.20590900528289896`}, {-4.5, 
       0.357662782649369}, {-4.437499981032941, 0.08429258955606238}, {-4.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{-4.437499981032941, 0.08429258955606238}, {-4.4375, 
       0.00012317806299537147`}, {-4.5, 
       0.20590900528289896`}, {-4.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-4.5, 0.08067866675870025}, {-4.5, 
       0.20590900528289896`}, {-4.4375, 0.00012317806299537147`}, {-4.5, 
       0.08067866675870025}}], 
      PolygonBox[{{-4.4375, 
       0.00012317806299537147`}, {-4.437499981032941, -0.084292589556055}, \
{-4.5, 0.08067866675870025}, {-4.4375, 0.00012317806299537147`}}], 
      PolygonBox[{{-4.5, -0.20590900514527852`}, {-4.5, 
       0.08067866675870025}, {-4.437499981032941, -0.084292589556055}, {-4.5, \
-0.20590900514527852`}}], 
      PolygonBox[{{-4.437499981032941, -0.084292589556055}, \
{-4.437344993353523, -0.23025164253625477`}, {-4.5, -0.20590900514527852`}, \
{-4.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-4.5, -0.35766278264936535`}, {-4.5, \
-0.20590900514527852`}, {-4.437344993353523, -0.23025164253625477`}, {-4.5, \
-0.35766278264936535`}}], 
      PolygonBox[{{-4.437344993353523, -0.23025164253625477`}, \
{-4.404942744332997, -0.4049427443329971}, {-4.5, -0.35766278264936535`}, \
{-4.437344993353523, -0.23025164253625477`}}], 
      PolygonBox[{{-4.5, 
       0.5}, {-4.5, -0.35766278264936535`}, {-4.404942744332997, \
-0.4049427443329971}, {-4.5, 0.5}}], 
      PolygonBox[{{-4.404942744332997, -0.4049427443329971}, \
{-4.230251642536255, -0.4373449933535234}, {-4.5, 
       0.5}, {-4.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-4.5, -0.5}, {-4.5, 
       0.5}, {-4.230251642536255, -0.4373449933535234}, {-4.5, -0.5}}], 
      PolygonBox[{{-4.230251642536255, -0.4373449933535234}, \
{-4.084292589556064, -0.4374999810329408}, {-4.5, -0.5}, {-4.230251642536255, \
-0.4373449933535234}}], 
      PolygonBox[{{-4.205909005566828, -0.5}, {-4.5, -0.5}, \
{-4.084292589556064, -0.4374999810329408}, {-4.205909005566828, -0.5}}], 
      PolygonBox[{{-4.084292589556064, -0.4374999810329408}, \
{-3.999865158168957, -0.4375}, {-4.205909005566828, -0.5}, \
{-4.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-3.9176761295989384`, -0.5}, {-4.205909005566828, -0.5}, \
{-3.999865158168957, -0.4375}, {-3.9176761295989384`, -0.5}}], 
      PolygonBox[{{-3.999865158168957, -0.4375}, {-3.9157074104439467`, \
-0.4374999810329408}, {-3.9176761295989384`, -0.5}, {-3.999865158168957, \
-0.4375}}], 
      PolygonBox[{{-3.7940909946396024`, -0.5}, {-3.9176761295989384`, -0.5}, \
{-3.9157074104439467`, -0.4374999810329408}, {-3.7940909946396024`, -0.5}}], 
      PolygonBox[{{-3.9157074104439467`, -0.4374999810329408}, \
{-3.769748357463745, -0.4373449933535234}, {-3.7940909946396024`, -0.5}, \
{-3.9157074104439467`, -0.4374999810329408}}], 
      PolygonBox[{{-3.642337217350629, -0.5}, {-3.7940909946396024`, -0.5}, \
{-3.769748357463745, -0.4373449933535234}, {-3.642337217350629, -0.5}}], 
      PolygonBox[{{-3.769748357463745, -0.4373449933535234}, \
{-3.595057255667003, -0.40494274433299715`}, {-3.642337217350629, -0.5}, \
{-3.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{-3.5, -0.5}, {-3.642337217350629, -0.5}, \
{-3.595057255667003, -0.40494274433299715`}, {-3.5, -0.5}}], 
      PolygonBox[{{-3.595057255667003, -0.40494274433299715`}, \
{-3.595057255667003, -0.4049427443329971}, {-3.5, -0.5}, {-3.595057255667003, \
-0.40494274433299715`}}], 
      PolygonBox[{{-3.5, -0.5}, {-3.5, -0.5}, {-3.595057255667003, \
-0.4049427443329971}, {-3.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, 1.}, {-4.479166666666667, 1.}, {-4.458333333333333, 
       1.}, {-4.4375, 1.}, {-4.416666666666667, 1.}, {-4.395833333333333, 
       1.}, {-4.375, 1.}, {-4.375, 1.}, {-4.395833333333333, 
       1.}, {-4.416666666666667, 1.}, {-4.4375, 1.}, {-4.458333333333333, 
       1.}, {-4.479166666666667, 1.}, {-4.5, 1.}, {-4.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, 1.}, {-3.6041666666666665`, 
       1.}, {-3.5833333333333335`, 1.}, {-3.5625, 1.}, {-3.5416666666666665`, 
       1.}, {-3.5208333333333335`, 1.}, {-3.5, 1.}, {-3.5, 
       1.}, {-3.5208333333333335`, 1.}, {-3.5416666666666665`, 1.}, {-3.5625, 
       1.}, {-3.5833333333333335`, 1.}, {-3.6041666666666665`, 1.}, {-3.625, 
       1.}, {-3.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 0.5}, {-4., 0.5208333333333333}, {-4., 
       0.5416666666666667}, {-4., 0.5625}, {-4., 0.5833333333333333}, {-4., 
       0.6041666666666666}, {-4., 0.625}, {-4., 0.625}, {-4., 
       0.6041666666666667}, {-4., 0.5833333333333333}, {-4., 0.5625}, {-4., 
       0.5416666666666667}, {-4., 0.5208333333333334}, {-4., 0.5}, {-4., 
       0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 1.375}, {-4., 1.3958333333333333`}, {-4., 
       1.4166666666666667`}, {-4., 1.4375}, {-4., 1.4583333333333333`}, {-4., 
       1.4791666666666665`}, {-4., 1.5}, {-4., 1.5}, {-4., 
       1.4791666666666667`}, {-4., 1.4583333333333333`}, {-4., 1.4375}, {-4., 
       1.4166666666666667`}, {-4., 1.3958333333333335`}, {-4., 1.375}, {-4., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, 1.}, {-4.25, 1.}, {-4.125, 1.}, {-4., 1.}, {-3.875, 
       1.}, {-3.75, 1.}, {-3.625, 1.}, {-3.625, 1.}, {-3.75, 1.}, {-3.875, 
       1.}, {-4., 1.}, {-4.125, 1.}, {-4.25, 1.}, {-4.375, 1.}, {-4.375, 
       1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 0.625}, {-4., 0.75}, {-4., 0.875}, {-4., 1.}, {-4., 
       1.125}, {-4., 1.25}, {-4., 1.375}, {-4., 1.375}, {-4., 1.25}, {-4., 
       1.125}, {-4., 1.}, {-4., 0.875}, {-4., 0.75}, {-4., 0.625}, {-4., 
       0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByD0B3sxvUBHbSneA/NOqJ7q7v1of2GHedWT
NJj8Z/tUoRS1jw94D5jdNt8sa/fFHizcwHcgoW8Ct7nRV/uN0m+lrCz5D1xZ
HFu78vRXiDyDAFT/N3v1os5PSckCqPIHBOD6z307m9POLwg3f4byk0O9PoJw
+79mhMe/KhKEuw9iP0z+A1z+WN6W7BdP3sD1M4LlX8HNn+I5YeaR5udw+x0f
33sxcfZTew2o+yJ3uLCuzXiC5v4n9pug/ouAyjNC/W8P1Q8Ln8lQ82Hh9+8/
CLyEh+8hqPtg4Q+W/v/eHgCY56K6
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByD0D/tQMOCF81evAgE+OB9CC6DJC6DpF0RT
L0SQHwbW9xXOh5j7CU39BzT5V2j6n6Kpf4DBR3XfAzT3P0Dz3wM0/z+wD0MJ
H5h6HoL8UBT38RxYheJ+mPoPaPKf0PR/RVP/wx4AjINpEQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, 
       0.7348349570550448}, {-3.6752404735808355`, 
       0.8125}, {-3.595057255667003, 
       0.5950572556670028}, {-3.7348349570550448`, 0.7348349570550448}}], 
      PolygonBox[{{-3.5626550066464766`, 
       0.7697483574637448}, {-3.595057255667003, 
       0.5950572556670028}, {-3.6752404735808355`, 
       0.8125}, {-3.5626550066464766`, 0.7697483574637448}}], 
      PolygonBox[{{-3.6752404735808355`, 0.8125}, {-3.6377778151415994`, 
       0.9029428580865547}, {-3.5626550066464766`, 
       0.7697483574637448}, {-3.6752404735808355`, 0.8125}}], 
      PolygonBox[{{-3.562500018967059, 
       0.9157074104439382}, {-3.5626550066464766`, 
       0.7697483574637448}, {-3.6377778151415994`, 
       0.9029428580865547}, {-3.562500018967059, 0.9157074104439382}}], 
      PolygonBox[{{-3.6377778151415994`, 0.9029428580865547}, {-3.625, 
       1.}, {-3.562500018967059, 0.9157074104439382}, {-3.6377778151415994`, 
       0.9029428580865547}}], 
      PolygonBox[{{-3.5625, 1.}, {-3.562500018967059, 
       0.9157074104439382}, {-3.625, 1.}, {-3.5625, 1.}}], 
      PolygonBox[{{-3.625, 1.}, {-3.6377778151415994`, 
       1.0970571419134452`}, {-3.5625, 1.}, {-3.625, 1.}}], 
      PolygonBox[{{-3.562500018967059, 1.0842925895560618`}, {-3.5625, 
       1.}, {-3.6377778151415994`, 1.0970571419134452`}, {-3.562500018967059, 
       1.0842925895560618`}}], 
      PolygonBox[{{-3.6377778151415994`, 
       1.0970571419134452`}, {-3.6752404735808355`, 
       1.1875}, {-3.562500018967059, 
       1.0842925895560618`}, {-3.6377778151415994`, 1.0970571419134452`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       1.230251642536255}, {-3.562500018967059, 
       1.0842925895560618`}, {-3.6752404735808355`, 
       1.1875}, {-3.5626550066464766`, 1.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, 1.1875}, {-3.7348349570550448`, 
       1.2651650429449552`}, {-3.5626550066464766`, 
       1.230251642536255}, {-3.6752404735808355`, 1.1875}}], 
      PolygonBox[{{-3.595057255667003, 
       1.4049427443329972`}, {-3.5626550066464766`, 
       1.230251642536255}, {-3.7348349570550448`, 
       1.2651650429449552`}, {-3.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{-3.7348349570550448`, 1.2651650429449552`}, {-3.8125, 
       1.3247595264191645`}, {-3.595057255667003, 
       1.4049427443329972`}, {-3.7348349570550448`, 1.2651650429449552`}}], 
      PolygonBox[{{-3.7697483574637447`, 
       1.4373449933535234`}, {-3.595057255667003, 
       1.4049427443329972`}, {-3.8125, 
       1.3247595264191645`}, {-3.7697483574637447`, 1.4373449933535234`}}], 
      PolygonBox[{{-3.8125, 1.3247595264191645`}, {-3.9029428580865546`, 
       1.3622221848584006`}, {-3.7697483574637447`, 
       1.4373449933535234`}, {-3.8125, 1.3247595264191645`}}], 
      PolygonBox[{{-3.9157074104439396`, 
       1.4374999810329407`}, {-3.7697483574637447`, 
       1.4373449933535234`}, {-3.9029428580865546`, 
       1.3622221848584006`}, {-3.9157074104439396`, 1.4374999810329407`}}], 
      PolygonBox[{{-3.9029428580865546`, 1.3622221848584006`}, {-4., 
       1.375}, {-3.9157074104439396`, 
       1.4374999810329407`}, {-3.9029428580865546`, 1.3622221848584006`}}], 
      PolygonBox[{{-3.9998944727795123`, 1.4375}, {-3.9157074104439396`, 
       1.4374999810329407`}, {-4., 1.375}, {-3.9998944727795123`, 1.4375}}], 
      PolygonBox[{{-4., 1.375}, {-4.097057141913445, 
       1.3622221848584006`}, {-3.9998944727795123`, 1.4375}, {-4., 1.375}}], 
      PolygonBox[{{-4.084292589556057, 
       1.4374999810329407`}, {-3.9998944727795123`, 
       1.4375}, {-4.097057141913445, 
       1.3622221848584006`}, {-4.084292589556057, 1.4374999810329407`}}], 
      PolygonBox[{{-4.097057141913445, 1.3622221848584006`}, {-4.1875, 
       1.3247595264191645`}, {-4.084292589556057, 
       1.4374999810329407`}, {-4.097057141913445, 1.3622221848584006`}}], 
      PolygonBox[{{-4.230251642536255, 
       1.4373449933535234`}, {-4.084292589556057, 
       1.4374999810329407`}, {-4.1875, 
       1.3247595264191645`}, {-4.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{-4.1875, 1.3247595264191645`}, {-4.265165042944956, 
       1.2651650429449552`}, {-4.230251642536255, 
       1.4373449933535234`}, {-4.1875, 1.3247595264191645`}}], 
      PolygonBox[{{-4.404942744332997, 
       1.4049427443329972`}, {-4.230251642536255, 
       1.4373449933535234`}, {-4.265165042944956, 
       1.2651650429449552`}, {-4.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{-4.265165042944956, 
       1.2651650429449552`}, {-4.3247595264191645`, 
       1.1875}, {-4.404942744332997, 
       1.4049427443329972`}, {-4.265165042944956, 1.2651650429449552`}}], 
      PolygonBox[{{-4.437344993353523, 
       1.2302516425362553`}, {-4.404942744332997, 
       1.4049427443329972`}, {-4.3247595264191645`, 
       1.1875}, {-4.437344993353523, 1.2302516425362553`}}], 
      PolygonBox[{{-4.3247595264191645`, 1.1875}, {-4.362222184858401, 
       1.0970571419134454`}, {-4.437344993353523, 
       1.2302516425362553`}, {-4.3247595264191645`, 1.1875}}], 
      PolygonBox[{{-4.437499981032941, 
       1.0842925895560624`}, {-4.437344993353523, 
       1.2302516425362553`}, {-4.362222184858401, 
       1.0970571419134454`}, {-4.437499981032941, 1.0842925895560624`}}], 
      PolygonBox[{{-4.362222184858401, 1.0970571419134454`}, {-4.375, 
       1.0000000000000002`}, {-4.437499981032941, 
       1.0842925895560624`}, {-4.362222184858401, 1.0970571419134454`}}], 
      PolygonBox[{{-4.4375, 1.0001231780629953`}, {-4.437499981032941, 
       1.0842925895560624`}, {-4.375, 1.0000000000000002`}, {-4.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-4.375, 1.0000000000000002`}, {-4.362222184858401, 
       0.9029428580865548}, {-4.4375, 1.0001231780629953`}, {-4.375, 
       1.0000000000000002`}}], 
      PolygonBox[{{-4.437499981032941, 0.915707410443945}, {-4.4375, 
       1.0001231780629953`}, {-4.362222184858401, 
       0.9029428580865548}, {-4.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-4.362222184858401, 
       0.9029428580865548}, {-4.3247595264191645`, 
       0.8125000000000002}, {-4.437499981032941, 
       0.915707410443945}, {-4.362222184858401, 0.9029428580865548}}], 
      PolygonBox[{{-4.437344993353523, 
       0.7697483574637453}, {-4.437499981032941, 
       0.915707410443945}, {-4.3247595264191645`, 
       0.8125000000000002}, {-4.437344993353523, 0.7697483574637453}}], 
      PolygonBox[{{-4.3247595264191645`, 
       0.8125000000000002}, {-4.265165042944956, 
       0.7348349570550448}, {-4.437344993353523, 
       0.7697483574637453}, {-4.3247595264191645`, 0.8125000000000002}}], 
      PolygonBox[{{-4.404942744332997, 
       0.5950572556670028}, {-4.437344993353523, 
       0.7697483574637453}, {-4.265165042944956, 
       0.7348349570550448}, {-4.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-4.265165042944956, 0.7348349570550448}, {-4.1875, 
       0.6752404735808356}, {-4.404942744332997, 
       0.5950572556670028}, {-4.265165042944956, 0.7348349570550448}}], 
      PolygonBox[{{-4.230251642536255, 
       0.5626550066464766}, {-4.404942744332997, 
       0.5950572556670028}, {-4.1875, 
       0.6752404735808356}, {-4.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-4.1875, 0.6752404735808356}, {-4.097057141913446, 
       0.6377778151415995}, {-4.230251642536255, 
       0.5626550066464766}, {-4.1875, 0.6752404735808356}}], 
      PolygonBox[{{-4.084292589556064, 
       0.5625000189670593}, {-4.230251642536255, 
       0.5626550066464766}, {-4.097057141913446, 
       0.6377778151415995}, {-4.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-4.097057141913446, 0.6377778151415995}, {-4., 
       0.625}, {-4.084292589556064, 0.5625000189670593}, {-4.097057141913446, 
       0.6377778151415995}}], 
      PolygonBox[{{-3.999865158168957, 0.5625}, {-4.084292589556064, 
       0.5625000189670593}, {-4., 0.625}, {-3.999865158168957, 0.5625}}], 
      PolygonBox[{{-4., 0.625}, {-3.902942858086555, 
       0.6377778151415994}, {-3.999865158168957, 0.5625}, {-4., 0.625}}], 
      PolygonBox[{{-3.9157074104439467`, 
       0.5625000189670593}, {-3.999865158168957, 0.5625}, {-3.902942858086555,
        0.6377778151415994}, {-3.9157074104439467`, 0.5625000189670593}}], 
      PolygonBox[{{-3.902942858086555, 
       0.6377778151415994}, {-3.8125000000000004`, 
       0.6752404735808354}, {-3.9157074104439467`, 
       0.5625000189670593}, {-3.902942858086555, 0.6377778151415994}}], 
      PolygonBox[{{-3.769748357463745, 
       0.5626550066464766}, {-3.9157074104439467`, 
       0.5625000189670593}, {-3.8125000000000004`, 
       0.6752404735808354}, {-3.769748357463745, 0.5626550066464766}}], 
      PolygonBox[{{-3.8125000000000004`, 
       0.6752404735808354}, {-3.7348349570550448`, 
       0.7348349570550446}, {-3.769748357463745, 
       0.5626550066464766}, {-3.8125000000000004`, 0.6752404735808354}}], 
      PolygonBox[{{-3.595057255667003, 
       0.5950572556670028}, {-3.769748357463745, 
       0.5626550066464766}, {-3.7348349570550448`, 
       0.7348349570550446}, {-3.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-3.7348349570550448`, 
       0.7348349570550446}, {-3.7348349570550448`, 
       0.7348349570550448}, {-3.595057255667003, 
       0.5950572556670028}, {-3.7348349570550448`, 0.7348349570550446}}], 
      PolygonBox[{{-3.595057255667003, 
       0.5950572556670028}, {-3.595057255667003, 
       0.5950572556670028}, {-3.7348349570550448`, 
       0.7348349570550448}, {-3.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-3.595057255667003, 
       0.5950572556670028}, {-3.5626550066464766`, 0.7697483574637448}, {-3.5,
        0.5}, {-3.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-3.5, 0.6423372173506323}, {-3.5, 
       0.5}, {-3.5626550066464766`, 0.7697483574637448}, {-3.5, 
       0.6423372173506323}}], 
      PolygonBox[{{-3.5626550066464766`, 
       0.7697483574637448}, {-3.562500018967059, 0.9157074104439382}, {-3.5, 
       0.6423372173506323}, {-3.5626550066464766`, 0.7697483574637448}}], 
      PolygonBox[{{-3.5, 0.79409099469826}, {-3.5, 
       0.6423372173506323}, {-3.562500018967059, 0.9157074104439382}, {-3.5, 
       0.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, 0.9157074104439382}, {-3.5625, 
       1.}, {-3.5, 0.79409099469826}, {-3.562500018967059, 
       0.9157074104439382}}], 
      PolygonBox[{{-3.5, 1.}, {-3.5, 0.79409099469826}, {-3.5625, 1.}, {-3.5, 
       1.}}], PolygonBox[{{-3.5625, 1.}, {-3.562500018967059, 
       1.0842925895560618`}, {-3.5, 1.}, {-3.5625, 1.}}], 
      PolygonBox[{{-3.5, 1.2059090053017398`}, {-3.5, 
       1.}, {-3.562500018967059, 1.0842925895560618`}, {-3.5, 
       1.2059090053017398`}}], 
      PolygonBox[{{-3.562500018967059, 
       1.0842925895560618`}, {-3.5626550066464766`, 1.230251642536255}, {-3.5,
        1.2059090053017398`}, {-3.562500018967059, 1.0842925895560618`}}], 
      PolygonBox[{{-3.5, 1.3576627826493675`}, {-3.5, 
       1.2059090053017398`}, {-3.5626550066464766`, 1.230251642536255}, {-3.5,
        1.3576627826493675`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       1.230251642536255}, {-3.595057255667003, 1.4049427443329972`}, {-3.5, 
       1.3576627826493675`}, {-3.5626550066464766`, 1.230251642536255}}], 
      PolygonBox[{{-3.508553435038814, 1.491446564961186}, {-3.5, 
       1.3576627826493675`}, {-3.595057255667003, 
       1.4049427443329972`}, {-3.508553435038814, 1.491446564961186}}], 
      PolygonBox[{{-3.595057255667003, 
       1.4049427443329972`}, {-3.7697483574637447`, 
       1.4373449933535234`}, {-3.508553435038814, 
       1.491446564961186}, {-3.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{-3.642337217350632, 1.5}, {-3.508553435038814, 
       1.491446564961186}, {-3.7697483574637447`, 
       1.4373449933535234`}, {-3.642337217350632, 1.5}}], 
      PolygonBox[{{-3.7697483574637447`, 
       1.4373449933535234`}, {-3.9157074104439396`, 
       1.4374999810329407`}, {-3.642337217350632, 1.5}, {-3.7697483574637447`,
        1.4373449933535234`}}], 
      PolygonBox[{{-3.7940909946267443`, 1.5}, {-3.642337217350632, 
       1.5}, {-3.9157074104439396`, 
       1.4374999810329407`}, {-3.7940909946267443`, 1.5}}], 
      PolygonBox[{{-3.9157074104439396`, 
       1.4374999810329407`}, {-3.9998944727795123`, 
       1.4375}, {-3.7940909946267443`, 1.5}, {-3.9157074104439396`, 
       1.4374999810329407`}}], 
      PolygonBox[{{-3.92205804197311, 1.5}, {-3.7940909946267443`, 
       1.5}, {-3.9998944727795123`, 1.4375}, {-3.92205804197311, 1.5}}], 
      PolygonBox[{{-3.9998944727795123`, 1.4375}, {-4.084292589556057, 
       1.4374999810329407`}, {-3.92205804197311, 1.5}, {-3.9998944727795123`, 
       1.4375}}], 
      PolygonBox[{{-4.205909005304446, 1.5}, {-3.92205804197311, 
       1.5}, {-4.084292589556057, 1.4374999810329407`}, {-4.205909005304446, 
       1.5}}], PolygonBox[{{-4.084292589556057, 
       1.4374999810329407`}, {-4.230251642536255, 
       1.4373449933535234`}, {-4.205909005304446, 1.5}, {-4.084292589556057, 
       1.4374999810329407`}}], 
      PolygonBox[{{-4.357662782649366, 1.5}, {-4.205909005304446, 
       1.5}, {-4.230251642536255, 1.4373449933535234`}, {-4.357662782649366, 
       1.5}}], PolygonBox[{{-4.230251642536255, 
       1.4373449933535234`}, {-4.404942744332997, 
       1.4049427443329972`}, {-4.357662782649366, 1.5}, {-4.230251642536255, 
       1.4373449933535234`}}], 
      PolygonBox[{{-3.5, 1.5}, {-4.357662782649366, 1.5}, {-4.404942744332997,
        1.4049427443329972`}, {-3.5, 1.5}}], 
      PolygonBox[{{-4.404942744332997, 
       1.4049427443329972`}, {-4.437344993353523, 1.2302516425362553`}, {-3.5,
        1.5}, {-4.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{-4.5, 1.357662782649369}, {-3.5, 1.5}, {-4.437344993353523,
        1.2302516425362553`}, {-4.5, 1.357662782649369}}], 
      PolygonBox[{{-4.437344993353523, 
       1.2302516425362553`}, {-4.437499981032941, 1.0842925895560624`}, {-4.5,
        1.357662782649369}, {-4.437344993353523, 1.2302516425362553`}}], 
      PolygonBox[{{-4.5, 1.205909005282899}, {-4.5, 
       1.357662782649369}, {-4.437499981032941, 1.0842925895560624`}, {-4.5, 
       1.205909005282899}}], 
      PolygonBox[{{-4.437499981032941, 1.0842925895560624`}, {-4.4375, 
       1.0001231780629953`}, {-4.5, 1.205909005282899}, {-4.437499981032941, 
       1.0842925895560624`}}], 
      PolygonBox[{{-4.5, 1.0806786667587003`}, {-4.5, 
       1.205909005282899}, {-4.4375, 1.0001231780629953`}, {-4.5, 
       1.0806786667587003`}}], 
      PolygonBox[{{-4.4375, 1.0001231780629953`}, {-4.437499981032941, 
       0.915707410443945}, {-4.5, 1.0806786667587003`}, {-4.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-4.5, 0.7940909948547215}, {-4.5, 
       1.0806786667587003`}, {-4.437499981032941, 0.915707410443945}, {-4.5, 
       0.7940909948547215}}], 
      PolygonBox[{{-4.437499981032941, 
       0.915707410443945}, {-4.437344993353523, 0.7697483574637453}, {-4.5, 
       0.7940909948547215}, {-4.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-4.5, 0.6423372173506346}, {-4.5, 
       0.7940909948547215}, {-4.437344993353523, 0.7697483574637453}, {-4.5, 
       0.6423372173506346}}], 
      PolygonBox[{{-4.437344993353523, 
       0.7697483574637453}, {-4.404942744332997, 0.5950572556670028}, {-4.5, 
       0.6423372173506346}, {-4.437344993353523, 0.7697483574637453}}], 
      PolygonBox[{{-4.5, 1.5}, {-4.5, 
       0.6423372173506346}, {-4.404942744332997, 0.5950572556670028}, {-4.5, 
       1.5}}], PolygonBox[{{-4.404942744332997, 
       0.5950572556670028}, {-4.230251642536255, 0.5626550066464766}, {-4.5, 
       1.5}, {-4.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-4.5, 0.5}, {-4.5, 1.5}, {-4.230251642536255, 
       0.5626550066464766}, {-4.5, 0.5}}], 
      PolygonBox[{{-4.230251642536255, 
       0.5626550066464766}, {-4.084292589556064, 0.5625000189670593}, {-4.5, 
       0.5}, {-4.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-4.205909005566828, 0.5}, {-4.5, 0.5}, {-4.084292589556064,
        0.5625000189670593}, {-4.205909005566828, 0.5}}], 
      PolygonBox[{{-4.084292589556064, 
       0.5625000189670593}, {-3.999865158168957, 0.5625}, {-4.205909005566828,
        0.5}, {-4.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-3.9176761295989384`, 0.5}, {-4.205909005566828, 
       0.5}, {-3.999865158168957, 0.5625}, {-3.9176761295989384`, 0.5}}], 
      PolygonBox[{{-3.999865158168957, 0.5625}, {-3.9157074104439467`, 
       0.5625000189670593}, {-3.9176761295989384`, 0.5}, {-3.999865158168957, 
       0.5625}}], 
      PolygonBox[{{-3.7940909946396024`, 0.5}, {-3.9176761295989384`, 
       0.5}, {-3.9157074104439467`, 
       0.5625000189670593}, {-3.7940909946396024`, 0.5}}], 
      PolygonBox[{{-3.9157074104439467`, 
       0.5625000189670593}, {-3.769748357463745, 
       0.5626550066464766}, {-3.7940909946396024`, 
       0.5}, {-3.9157074104439467`, 0.5625000189670593}}], 
      PolygonBox[{{-3.642337217350629, 0.5}, {-3.7940909946396024`, 
       0.5}, {-3.769748357463745, 0.5626550066464766}, {-3.642337217350629, 
       0.5}}], PolygonBox[{{-3.769748357463745, 
       0.5626550066464766}, {-3.595057255667003, 
       0.5950572556670028}, {-3.642337217350629, 0.5}, {-3.769748357463745, 
       0.5626550066464766}}], 
      PolygonBox[{{-3.5, 0.5}, {-3.642337217350629, 0.5}, {-3.595057255667003,
        0.5950572556670028}, {-3.5, 0.5}}], 
      PolygonBox[{{-3.595057255667003, 
       0.5950572556670028}, {-3.595057255667003, 0.5950572556670028}, {-3.5, 
       0.5}, {-3.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-3.5, 0.5}, {-3.5, 0.5}, {-3.595057255667003, 
       0.5950572556670028}, {-3.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, 2.}, {-4.479166666666667, 2.}, {-4.458333333333333, 
       2.}, {-4.4375, 2.}, {-4.416666666666667, 2.}, {-4.395833333333333, 
       2.}, {-4.375, 2.}, {-4.375, 2.}, {-4.395833333333333, 
       2.}, {-4.416666666666667, 2.}, {-4.4375, 2.}, {-4.458333333333333, 
       2.}, {-4.479166666666667, 2.}, {-4.5, 2.}, {-4.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, 2.}, {-3.6041666666666665`, 
       2.}, {-3.5833333333333335`, 2.}, {-3.5625, 2.}, {-3.5416666666666665`, 
       2.}, {-3.5208333333333335`, 2.}, {-3.5, 2.}, {-3.5, 
       2.}, {-3.5208333333333335`, 2.}, {-3.5416666666666665`, 2.}, {-3.5625, 
       2.}, {-3.5833333333333335`, 2.}, {-3.6041666666666665`, 2.}, {-3.625, 
       2.}, {-3.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 1.5}, {-4., 1.5208333333333333`}, {-4., 
       1.5416666666666667`}, {-4., 1.5625}, {-4., 1.5833333333333333`}, {-4., 
       1.6041666666666665`}, {-4., 1.625}, {-4., 1.625}, {-4., 
       1.6041666666666667`}, {-4., 1.5833333333333333`}, {-4., 1.5625}, {-4., 
       1.5416666666666667`}, {-4., 1.5208333333333335`}, {-4., 1.5}, {-4., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 2.375}, {-4., 2.3958333333333335`}, {-4., 
       2.4166666666666665`}, {-4., 2.4375}, {-4., 2.4583333333333335`}, {-4., 
       2.4791666666666665`}, {-4., 2.5}, {-4., 2.5}, {-4., 
       2.4791666666666665`}, {-4., 2.4583333333333335`}, {-4., 2.4375}, {-4., 
       2.4166666666666665`}, {-4., 2.3958333333333335`}, {-4., 2.375}, {-4., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, 2.}, {-4.25, 2.}, {-4.125, 2.}, {-4., 2.}, {-3.875, 
       2.}, {-3.75, 2.}, {-3.625, 2.}, {-3.625, 2.}, {-3.75, 2.}, {-3.875, 
       2.}, {-4., 2.}, {-4.125, 2.}, {-4.25, 2.}, {-4.375, 2.}, {-4.375, 
       2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 1.625}, {-4., 1.75}, {-4., 1.875}, {-4., 2.}, {-4., 
       2.125}, {-4., 2.25}, {-4., 2.375}, {-4., 2.375}, {-4., 2.25}, {-4., 
       2.125}, {-4., 2.}, {-4., 1.875}, {-4., 1.75}, {-4., 1.625}, {-4., 
       1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8B6AMBzG9QEdtKd4D/k+Enh49xuBwYYd51ZM0
qHwDo0OqUIraxwe8B2a/nX2TT57JASLOd8DA/USr9Ewmh43Sb6WsLPkPvLq4
bt+Vp1B5BgGo+cwO6kWdn5KSBVDlDwjA9Z/7djannV8Qbv4M5SeHen0E4fZ/
zQiPf1UkCHcfRFwQ7n6YfLL5LdOSon/2KPoZ/trDzD+lcsLn0cHf9jD7FxTm
fzlx9pe9BtR9OjGLmsJMftmjuv+X/Sao/2DyjFD/w/TDwgdmPiz8/oPBH3tY
+CZC3Yce/gAkWZP2
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByA0i0MoGPDC+atXgQAfnA+hBdDkBdD0C6Kp
FyLIh5jDBOdDzGFEU88A54eB5f/ao+r/ZY+q/gcGH9V9P+xR3Q9TL4Amzwfn
h6GED0w9D0H+KhT38UD99xdNPcx/PGj+h+lnckBVz+IAAHzwXAs=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, 
       1.7348349570550448`}, {-3.6752404735808355`, 
       1.8125}, {-3.595057255667003, 
       1.5950572556670028`}, {-3.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       1.769748357463745}, {-3.595057255667003, 
       1.5950572556670028`}, {-3.6752404735808355`, 
       1.8125}, {-3.5626550066464766`, 1.769748357463745}}], 
      PolygonBox[{{-3.6752404735808355`, 1.8125}, {-3.6377778151415994`, 
       1.9029428580865546`}, {-3.5626550066464766`, 
       1.769748357463745}, {-3.6752404735808355`, 1.8125}}], 
      PolygonBox[{{-3.562500018967059, 
       1.9157074104439382`}, {-3.5626550066464766`, 
       1.769748357463745}, {-3.6377778151415994`, 
       1.9029428580865546`}, {-3.562500018967059, 1.9157074104439382`}}], 
      PolygonBox[{{-3.6377778151415994`, 1.9029428580865546`}, {-3.625, 
       2.}, {-3.562500018967059, 1.9157074104439382`}, {-3.6377778151415994`, 
       1.9029428580865546`}}], 
      PolygonBox[{{-3.5625, 2.}, {-3.562500018967059, 
       1.9157074104439382`}, {-3.625, 2.}, {-3.5625, 2.}}], 
      PolygonBox[{{-3.625, 2.}, {-3.6377778151415994`, 
       2.0970571419134454`}, {-3.5625, 2.}, {-3.625, 2.}}], 
      PolygonBox[{{-3.562500018967059, 2.084292589556062}, {-3.5625, 
       2.}, {-3.6377778151415994`, 2.0970571419134454`}, {-3.562500018967059, 
       2.084292589556062}}], 
      PolygonBox[{{-3.6377778151415994`, 
       2.0970571419134454`}, {-3.6752404735808355`, 
       2.1875}, {-3.562500018967059, 
       2.084292589556062}, {-3.6377778151415994`, 2.0970571419134454`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       2.230251642536255}, {-3.562500018967059, 
       2.084292589556062}, {-3.6752404735808355`, 
       2.1875}, {-3.5626550066464766`, 2.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, 2.1875}, {-3.7348349570550448`, 
       2.2651650429449552`}, {-3.5626550066464766`, 
       2.230251642536255}, {-3.6752404735808355`, 2.1875}}], 
      PolygonBox[{{-3.595057255667003, 
       2.404942744332997}, {-3.5626550066464766`, 
       2.230251642536255}, {-3.7348349570550448`, 
       2.2651650429449552`}, {-3.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, 2.2651650429449552`}, {-3.8125, 
       2.3247595264191645`}, {-3.595057255667003, 
       2.404942744332997}, {-3.7348349570550448`, 2.2651650429449552`}}], 
      PolygonBox[{{-3.7697483574637447`, 
       2.4373449933535234`}, {-3.595057255667003, 
       2.404942744332997}, {-3.8125, 
       2.3247595264191645`}, {-3.7697483574637447`, 2.4373449933535234`}}], 
      PolygonBox[{{-3.8125, 2.3247595264191645`}, {-3.9029428580865546`, 
       2.3622221848584006`}, {-3.7697483574637447`, 
       2.4373449933535234`}, {-3.8125, 2.3247595264191645`}}], 
      PolygonBox[{{-3.9157074104439396`, 
       2.437499981032941}, {-3.7697483574637447`, 
       2.4373449933535234`}, {-3.9029428580865546`, 
       2.3622221848584006`}, {-3.9157074104439396`, 2.437499981032941}}], 
      PolygonBox[{{-3.9029428580865546`, 2.3622221848584006`}, {-4., 
       2.375}, {-3.9157074104439396`, 
       2.437499981032941}, {-3.9029428580865546`, 2.3622221848584006`}}], 
      PolygonBox[{{-3.9998944727795123`, 2.4375}, {-3.9157074104439396`, 
       2.437499981032941}, {-4., 2.375}, {-3.9998944727795123`, 2.4375}}], 
      PolygonBox[{{-4., 2.375}, {-4.097057141913445, 
       2.3622221848584006`}, {-3.9998944727795123`, 2.4375}, {-4., 2.375}}], 
      PolygonBox[{{-4.084292589556057, 
       2.437499981032941}, {-3.9998944727795123`, 
       2.4375}, {-4.097057141913445, 
       2.3622221848584006`}, {-4.084292589556057, 2.437499981032941}}], 
      PolygonBox[{{-4.097057141913445, 2.3622221848584006`}, {-4.1875, 
       2.3247595264191645`}, {-4.084292589556057, 
       2.437499981032941}, {-4.097057141913445, 2.3622221848584006`}}], 
      PolygonBox[{{-4.230251642536255, 
       2.4373449933535234`}, {-4.084292589556057, 
       2.437499981032941}, {-4.1875, 
       2.3247595264191645`}, {-4.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{-4.1875, 2.3247595264191645`}, {-4.265165042944956, 
       2.2651650429449552`}, {-4.230251642536255, 
       2.4373449933535234`}, {-4.1875, 2.3247595264191645`}}], 
      PolygonBox[{{-4.404942744332997, 
       2.404942744332997}, {-4.230251642536255, 
       2.4373449933535234`}, {-4.265165042944956, 
       2.2651650429449552`}, {-4.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, 
       2.2651650429449552`}, {-4.3247595264191645`, 
       2.1875}, {-4.404942744332997, 2.404942744332997}, {-4.265165042944956, 
       2.2651650429449552`}}], 
      PolygonBox[{{-4.437344993353523, 
       2.2302516425362553`}, {-4.404942744332997, 
       2.404942744332997}, {-4.3247595264191645`, 
       2.1875}, {-4.437344993353523, 2.2302516425362553`}}], 
      PolygonBox[{{-4.3247595264191645`, 2.1875}, {-4.362222184858401, 
       2.0970571419134454`}, {-4.437344993353523, 
       2.2302516425362553`}, {-4.3247595264191645`, 2.1875}}], 
      PolygonBox[{{-4.437499981032941, 
       2.0842925895560622`}, {-4.437344993353523, 
       2.2302516425362553`}, {-4.362222184858401, 
       2.0970571419134454`}, {-4.437499981032941, 2.0842925895560622`}}], 
      PolygonBox[{{-4.362222184858401, 2.0970571419134454`}, {-4.375, 
       2.}, {-4.437499981032941, 2.0842925895560622`}, {-4.362222184858401, 
       2.0970571419134454`}}], 
      PolygonBox[{{-4.4375, 2.0001231780629953`}, {-4.437499981032941, 
       2.0842925895560622`}, {-4.375, 2.}, {-4.4375, 2.0001231780629953`}}], 
      PolygonBox[{{-4.375, 2.}, {-4.362222184858401, 
       1.9029428580865548`}, {-4.4375, 2.0001231780629953`}, {-4.375, 2.}}], 
      PolygonBox[{{-4.437499981032941, 1.915707410443945}, {-4.4375, 
       2.0001231780629953`}, {-4.362222184858401, 
       1.9029428580865548`}, {-4.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-4.362222184858401, 
       1.9029428580865548`}, {-4.3247595264191645`, 
       1.8125000000000002`}, {-4.437499981032941, 
       1.915707410443945}, {-4.362222184858401, 1.9029428580865548`}}], 
      PolygonBox[{{-4.437344993353523, 
       1.7697483574637451`}, {-4.437499981032941, 
       1.915707410443945}, {-4.3247595264191645`, 
       1.8125000000000002`}, {-4.437344993353523, 1.7697483574637451`}}], 
      PolygonBox[{{-4.3247595264191645`, 
       1.8125000000000002`}, {-4.265165042944956, 
       1.7348349570550448`}, {-4.437344993353523, 
       1.7697483574637451`}, {-4.3247595264191645`, 1.8125000000000002`}}], 
      PolygonBox[{{-4.404942744332997, 
       1.5950572556670028`}, {-4.437344993353523, 
       1.7697483574637451`}, {-4.265165042944956, 
       1.7348349570550448`}, {-4.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-4.265165042944956, 1.7348349570550448`}, {-4.1875, 
       1.6752404735808355`}, {-4.404942744332997, 
       1.5950572556670028`}, {-4.265165042944956, 1.7348349570550448`}}], 
      PolygonBox[{{-4.230251642536255, 
       1.5626550066464766`}, {-4.404942744332997, 
       1.5950572556670028`}, {-4.1875, 
       1.6752404735808355`}, {-4.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-4.1875, 1.6752404735808355`}, {-4.097057141913446, 
       1.6377778151415994`}, {-4.230251642536255, 
       1.5626550066464766`}, {-4.1875, 1.6752404735808355`}}], 
      PolygonBox[{{-4.084292589556064, 
       1.5625000189670593`}, {-4.230251642536255, 
       1.5626550066464766`}, {-4.097057141913446, 
       1.6377778151415994`}, {-4.084292589556064, 1.5625000189670593`}}], 
      PolygonBox[{{-4.097057141913446, 1.6377778151415994`}, {-4., 
       1.625}, {-4.084292589556064, 1.5625000189670593`}, {-4.097057141913446,
        1.6377778151415994`}}], 
      PolygonBox[{{-3.999865158168957, 1.5625}, {-4.084292589556064, 
       1.5625000189670593`}, {-4., 1.625}, {-3.999865158168957, 1.5625}}], 
      PolygonBox[{{-4., 1.625}, {-3.902942858086555, 
       1.6377778151415994`}, {-3.999865158168957, 1.5625}, {-4., 1.625}}], 
      PolygonBox[{{-3.9157074104439467`, 
       1.5625000189670593`}, {-3.999865158168957, 
       1.5625}, {-3.902942858086555, 
       1.6377778151415994`}, {-3.9157074104439467`, 1.5625000189670593`}}], 
      PolygonBox[{{-3.902942858086555, 
       1.6377778151415994`}, {-3.8125000000000004`, 
       1.6752404735808355`}, {-3.9157074104439467`, 
       1.5625000189670593`}, {-3.902942858086555, 1.6377778151415994`}}], 
      PolygonBox[{{-3.769748357463745, 
       1.5626550066464766`}, {-3.9157074104439467`, 
       1.5625000189670593`}, {-3.8125000000000004`, 
       1.6752404735808355`}, {-3.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{-3.8125000000000004`, 
       1.6752404735808355`}, {-3.7348349570550448`, 
       1.7348349570550448`}, {-3.769748357463745, 
       1.5626550066464766`}, {-3.8125000000000004`, 1.6752404735808355`}}], 
      PolygonBox[{{-3.595057255667003, 
       1.5950572556670028`}, {-3.769748357463745, 
       1.5626550066464766`}, {-3.7348349570550448`, 
       1.7348349570550448`}, {-3.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-3.7348349570550448`, 
       1.7348349570550448`}, {-3.7348349570550448`, 
       1.7348349570550448`}, {-3.595057255667003, 
       1.5950572556670028`}, {-3.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{-3.595057255667003, 
       1.5950572556670028`}, {-3.595057255667003, 
       1.5950572556670028`}, {-3.7348349570550448`, 
       1.7348349570550448`}, {-3.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-3.595057255667003, 
       1.5950572556670028`}, {-3.5626550066464766`, 1.769748357463745}, {-3.5,
        1.5}, {-3.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-3.5, 1.6423372173506323`}, {-3.5, 
       1.5}, {-3.5626550066464766`, 1.769748357463745}, {-3.5, 
       1.6423372173506323`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       1.769748357463745}, {-3.562500018967059, 1.9157074104439382`}, {-3.5, 
       1.6423372173506323`}, {-3.5626550066464766`, 1.769748357463745}}], 
      PolygonBox[{{-3.5, 1.79409099469826}, {-3.5, 
       1.6423372173506323`}, {-3.562500018967059, 1.9157074104439382`}, {-3.5,
        1.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, 1.9157074104439382`}, {-3.5625, 
       2.}, {-3.5, 1.79409099469826}, {-3.562500018967059, 
       1.9157074104439382`}}], 
      PolygonBox[{{-3.5, 2.}, {-3.5, 1.79409099469826}, {-3.5625, 2.}, {-3.5, 
       2.}}], PolygonBox[{{-3.5625, 2.}, {-3.562500018967059, 
       2.084292589556062}, {-3.5, 2.}, {-3.5625, 2.}}], 
      PolygonBox[{{-3.5, 2.20590900530174}, {-3.5, 2.}, {-3.562500018967059, 
       2.084292589556062}, {-3.5, 2.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, 
       2.084292589556062}, {-3.5626550066464766`, 2.230251642536255}, {-3.5, 
       2.20590900530174}, {-3.562500018967059, 2.084292589556062}}], 
      PolygonBox[{{-3.5, 2.3576627826493675`}, {-3.5, 
       2.20590900530174}, {-3.5626550066464766`, 2.230251642536255}, {-3.5, 
       2.3576627826493675`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       2.230251642536255}, {-3.595057255667003, 2.404942744332997}, {-3.5, 
       2.3576627826493675`}, {-3.5626550066464766`, 2.230251642536255}}], 
      PolygonBox[{{-3.508553435038814, 2.491446564961186}, {-3.5, 
       2.3576627826493675`}, {-3.595057255667003, 
       2.404942744332997}, {-3.508553435038814, 2.491446564961186}}], 
      PolygonBox[{{-3.595057255667003, 
       2.404942744332997}, {-3.7697483574637447`, 
       2.4373449933535234`}, {-3.508553435038814, 
       2.491446564961186}, {-3.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{-3.642337217350632, 2.5}, {-3.508553435038814, 
       2.491446564961186}, {-3.7697483574637447`, 
       2.4373449933535234`}, {-3.642337217350632, 2.5}}], 
      PolygonBox[{{-3.7697483574637447`, 
       2.4373449933535234`}, {-3.9157074104439396`, 
       2.437499981032941}, {-3.642337217350632, 2.5}, {-3.7697483574637447`, 
       2.4373449933535234`}}], 
      PolygonBox[{{-3.7940909946267443`, 2.5}, {-3.642337217350632, 
       2.5}, {-3.9157074104439396`, 2.437499981032941}, {-3.7940909946267443`,
        2.5}}], 
      PolygonBox[{{-3.9157074104439396`, 
       2.437499981032941}, {-3.9998944727795123`, 
       2.4375}, {-3.7940909946267443`, 2.5}, {-3.9157074104439396`, 
       2.437499981032941}}], 
      PolygonBox[{{-3.92205804197311, 2.5}, {-3.7940909946267443`, 
       2.5}, {-3.9998944727795123`, 2.4375}, {-3.92205804197311, 2.5}}], 
      PolygonBox[{{-3.9998944727795123`, 2.4375}, {-4.084292589556057, 
       2.437499981032941}, {-3.92205804197311, 2.5}, {-3.9998944727795123`, 
       2.4375}}], 
      PolygonBox[{{-4.205909005304446, 2.5}, {-3.92205804197311, 
       2.5}, {-4.084292589556057, 2.437499981032941}, {-4.205909005304446, 
       2.5}}], PolygonBox[{{-4.084292589556057, 
       2.437499981032941}, {-4.230251642536255, 
       2.4373449933535234`}, {-4.205909005304446, 2.5}, {-4.084292589556057, 
       2.437499981032941}}], 
      PolygonBox[{{-4.357662782649366, 2.5}, {-4.205909005304446, 
       2.5}, {-4.230251642536255, 2.4373449933535234`}, {-4.357662782649366, 
       2.5}}], PolygonBox[{{-4.230251642536255, 
       2.4373449933535234`}, {-4.404942744332997, 
       2.404942744332997}, {-4.357662782649366, 2.5}, {-4.230251642536255, 
       2.4373449933535234`}}], 
      PolygonBox[{{-3.5, 2.5}, {-4.357662782649366, 2.5}, {-4.404942744332997,
        2.404942744332997}, {-3.5, 2.5}}], 
      PolygonBox[{{-4.404942744332997, 
       2.404942744332997}, {-4.437344993353523, 2.2302516425362553`}, {-3.5, 
       2.5}, {-4.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-4.5, 2.357662782649369}, {-3.5, 2.5}, {-4.437344993353523,
        2.2302516425362553`}, {-4.5, 2.357662782649369}}], 
      PolygonBox[{{-4.437344993353523, 
       2.2302516425362553`}, {-4.437499981032941, 2.0842925895560622`}, {-4.5,
        2.357662782649369}, {-4.437344993353523, 2.2302516425362553`}}], 
      PolygonBox[{{-4.5, 2.205909005282899}, {-4.5, 
       2.357662782649369}, {-4.437499981032941, 2.0842925895560622`}, {-4.5, 
       2.205909005282899}}], 
      PolygonBox[{{-4.437499981032941, 2.0842925895560622`}, {-4.4375, 
       2.0001231780629953`}, {-4.5, 2.205909005282899}, {-4.437499981032941, 
       2.0842925895560622`}}], 
      PolygonBox[{{-4.5, 2.0806786667587}, {-4.5, 
       2.205909005282899}, {-4.4375, 2.0001231780629953`}, {-4.5, 
       2.0806786667587}}], 
      PolygonBox[{{-4.4375, 2.0001231780629953`}, {-4.437499981032941, 
       1.915707410443945}, {-4.5, 2.0806786667587}, {-4.4375, 
       2.0001231780629953`}}], 
      PolygonBox[{{-4.5, 1.7940909948547215`}, {-4.5, 
       2.0806786667587}, {-4.437499981032941, 1.915707410443945}, {-4.5, 
       1.7940909948547215`}}], 
      PolygonBox[{{-4.437499981032941, 
       1.915707410443945}, {-4.437344993353523, 1.7697483574637451`}, {-4.5, 
       1.7940909948547215`}, {-4.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-4.5, 1.6423372173506348`}, {-4.5, 
       1.7940909948547215`}, {-4.437344993353523, 1.7697483574637451`}, {-4.5,
        1.6423372173506348`}}], 
      PolygonBox[{{-4.437344993353523, 
       1.7697483574637451`}, {-4.404942744332997, 1.5950572556670028`}, {-4.5,
        1.6423372173506348`}, {-4.437344993353523, 1.7697483574637451`}}], 
      PolygonBox[{{-4.5, 2.5}, {-4.5, 
       1.6423372173506348`}, {-4.404942744332997, 1.5950572556670028`}, {-4.5,
        2.5}}], 
      PolygonBox[{{-4.404942744332997, 
       1.5950572556670028`}, {-4.230251642536255, 1.5626550066464766`}, {-4.5,
        2.5}, {-4.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-4.5, 1.5}, {-4.5, 2.5}, {-4.230251642536255, 
       1.5626550066464766`}, {-4.5, 1.5}}], 
      PolygonBox[{{-4.230251642536255, 
       1.5626550066464766`}, {-4.084292589556064, 1.5625000189670593`}, {-4.5,
        1.5}, {-4.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-4.205909005566828, 1.5}, {-4.5, 1.5}, {-4.084292589556064,
        1.5625000189670593`}, {-4.205909005566828, 1.5}}], 
      PolygonBox[{{-4.084292589556064, 
       1.5625000189670593`}, {-3.999865158168957, 
       1.5625}, {-4.205909005566828, 1.5}, {-4.084292589556064, 
       1.5625000189670593`}}], 
      PolygonBox[{{-3.9176761295989384`, 1.5}, {-4.205909005566828, 
       1.5}, {-3.999865158168957, 1.5625}, {-3.9176761295989384`, 1.5}}], 
      PolygonBox[{{-3.999865158168957, 1.5625}, {-3.9157074104439467`, 
       1.5625000189670593`}, {-3.9176761295989384`, 1.5}, {-3.999865158168957,
        1.5625}}], 
      PolygonBox[{{-3.7940909946396024`, 1.5}, {-3.9176761295989384`, 
       1.5}, {-3.9157074104439467`, 
       1.5625000189670593`}, {-3.7940909946396024`, 1.5}}], 
      PolygonBox[{{-3.9157074104439467`, 
       1.5625000189670593`}, {-3.769748357463745, 
       1.5626550066464766`}, {-3.7940909946396024`, 
       1.5}, {-3.9157074104439467`, 1.5625000189670593`}}], 
      PolygonBox[{{-3.642337217350629, 1.5}, {-3.7940909946396024`, 
       1.5}, {-3.769748357463745, 1.5626550066464766`}, {-3.642337217350629, 
       1.5}}], PolygonBox[{{-3.769748357463745, 
       1.5626550066464766`}, {-3.595057255667003, 
       1.5950572556670028`}, {-3.642337217350629, 1.5}, {-3.769748357463745, 
       1.5626550066464766`}}], 
      PolygonBox[{{-3.5, 1.5}, {-3.642337217350629, 1.5}, {-3.595057255667003,
        1.5950572556670028`}, {-3.5, 1.5}}], 
      PolygonBox[{{-3.595057255667003, 
       1.5950572556670028`}, {-3.595057255667003, 1.5950572556670028`}, {-3.5,
        1.5}, {-3.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-3.5, 1.5}, {-3.5, 1.5}, {-3.595057255667003, 
       1.5950572556670028`}, {-3.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, 3.}, {-4.479166666666667, 3.}, {-4.458333333333333, 
       3.}, {-4.4375, 3.}, {-4.416666666666667, 3.}, {-4.395833333333333, 
       3.}, {-4.375, 3.}, {-4.375, 3.}, {-4.395833333333333, 
       3.}, {-4.416666666666667, 3.}, {-4.4375, 3.}, {-4.458333333333333, 
       3.}, {-4.479166666666667, 3.}, {-4.5, 3.}, {-4.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, 3.}, {-3.6041666666666665`, 
       3.}, {-3.5833333333333335`, 3.}, {-3.5625, 3.}, {-3.5416666666666665`, 
       3.}, {-3.5208333333333335`, 3.}, {-3.5, 3.}, {-3.5, 
       3.}, {-3.5208333333333335`, 3.}, {-3.5416666666666665`, 3.}, {-3.5625, 
       3.}, {-3.5833333333333335`, 3.}, {-3.6041666666666665`, 3.}, {-3.625, 
       3.}, {-3.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 2.5}, {-4., 2.5208333333333335`}, {-4., 
       2.5416666666666665`}, {-4., 2.5625}, {-4., 2.5833333333333335`}, {-4., 
       2.6041666666666665`}, {-4., 2.625}, {-4., 2.625}, {-4., 
       2.6041666666666665`}, {-4., 2.5833333333333335`}, {-4., 2.5625}, {-4., 
       2.5416666666666665`}, {-4., 2.5208333333333335`}, {-4., 2.5}, {-4., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 3.375}, {-4., 3.3958333333333335`}, {-4., 
       3.4166666666666665`}, {-4., 3.4375}, {-4., 3.4583333333333335`}, {-4., 
       3.4791666666666665`}, {-4., 3.5}, {-4., 3.5}, {-4., 
       3.4791666666666665`}, {-4., 3.4583333333333335`}, {-4., 3.4375}, {-4., 
       3.4166666666666665`}, {-4., 3.3958333333333335`}, {-4., 3.375}, {-4., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, 3.}, {-4.25, 3.}, {-4.125, 3.}, {-4., 3.}, {-3.875, 
       3.}, {-3.75, 3.}, {-3.625, 3.}, {-3.625, 3.}, {-3.75, 3.}, {-3.875, 
       3.}, {-4., 3.}, {-4.125, 3.}, {-4.25, 3.}, {-4.375, 3.}, {-4.375, 
       3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 2.625}, {-4., 2.75}, {-4., 2.875}, {-4., 3.}, {-4., 
       3.125}, {-4., 3.25}, {-4., 3.375}, {-4., 3.375}, {-4., 3.25}, {-4., 
       3.125}, {-4., 3.}, {-4., 2.875}, {-4., 2.75}, {-4., 2.625}, {-4., 
       2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByA0h4OYXqCjthTvAf8nQk+PHuNwuLDDvOpJ
GlS+gdMhVShF7eMD3gOz386+ySfP5QAR5ztg4H6iVXoml8NG6bdSVpb8B15d
XLfvylOoPIMA1HxuB/Wizk9JyQKo8gcE4PrPfTub084vCDd/hvKTQ70+gnD7
v2aEx78qEoS7DyIuCHc/TH4T2B3saPrZ4OZD/MEKtx/iT1YHDaj7IOHAiuZ+
VodNUP/B5Bmh/ofph4UPzHzU8GODh+9GqPvQwx8A7ix/cA==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8B6C0QygY8ML5q1eBAB+cD6EF0OQF0PQLoqkX
IsiHmMMF50PM4URTz4Gmng3ODwOrZ0VTz4LBR3UfC5r7YeoF0OT54PwwlPCB
qechyA9FcR8Pmvth6jnQ1HPC+atQwgcRXwAllFAl
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, 
       2.7348349570550448`}, {-3.6752404735808355`, 
       2.8125}, {-3.595057255667003, 
       2.595057255667003}, {-3.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       2.7697483574637447`}, {-3.595057255667003, 
       2.595057255667003}, {-3.6752404735808355`, 
       2.8125}, {-3.5626550066464766`, 2.7697483574637447`}}], 
      PolygonBox[{{-3.6752404735808355`, 2.8125}, {-3.6377778151415994`, 
       2.9029428580865546`}, {-3.5626550066464766`, 
       2.7697483574637447`}, {-3.6752404735808355`, 2.8125}}], 
      PolygonBox[{{-3.562500018967059, 
       2.915707410443938}, {-3.5626550066464766`, 
       2.7697483574637447`}, {-3.6377778151415994`, 
       2.9029428580865546`}, {-3.562500018967059, 2.915707410443938}}], 
      PolygonBox[{{-3.6377778151415994`, 2.9029428580865546`}, {-3.625, 
       3.}, {-3.562500018967059, 2.915707410443938}, {-3.6377778151415994`, 
       2.9029428580865546`}}], 
      PolygonBox[{{-3.5625, 3.}, {-3.562500018967059, 
       2.915707410443938}, {-3.625, 3.}, {-3.5625, 3.}}], 
      PolygonBox[{{-3.625, 3.}, {-3.6377778151415994`, 
       3.0970571419134454`}, {-3.5625, 3.}, {-3.625, 3.}}], 
      PolygonBox[{{-3.562500018967059, 3.084292589556062}, {-3.5625, 
       3.}, {-3.6377778151415994`, 3.0970571419134454`}, {-3.562500018967059, 
       3.084292589556062}}], 
      PolygonBox[{{-3.6377778151415994`, 
       3.0970571419134454`}, {-3.6752404735808355`, 
       3.1875}, {-3.562500018967059, 
       3.084292589556062}, {-3.6377778151415994`, 3.0970571419134454`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       3.230251642536255}, {-3.562500018967059, 
       3.084292589556062}, {-3.6752404735808355`, 
       3.1875}, {-3.5626550066464766`, 3.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, 3.1875}, {-3.7348349570550448`, 
       3.2651650429449552`}, {-3.5626550066464766`, 
       3.230251642536255}, {-3.6752404735808355`, 3.1875}}], 
      PolygonBox[{{-3.595057255667003, 
       3.404942744332997}, {-3.5626550066464766`, 
       3.230251642536255}, {-3.7348349570550448`, 
       3.2651650429449552`}, {-3.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, 3.2651650429449552`}, {-3.8125, 
       3.3247595264191645`}, {-3.595057255667003, 
       3.404942744332997}, {-3.7348349570550448`, 3.2651650429449552`}}], 
      PolygonBox[{{-3.7697483574637447`, 
       3.4373449933535234`}, {-3.595057255667003, 
       3.404942744332997}, {-3.8125, 
       3.3247595264191645`}, {-3.7697483574637447`, 3.4373449933535234`}}], 
      PolygonBox[{{-3.8125, 3.3247595264191645`}, {-3.9029428580865546`, 
       3.3622221848584006`}, {-3.7697483574637447`, 
       3.4373449933535234`}, {-3.8125, 3.3247595264191645`}}], 
      PolygonBox[{{-3.9157074104439396`, 
       3.437499981032941}, {-3.7697483574637447`, 
       3.4373449933535234`}, {-3.9029428580865546`, 
       3.3622221848584006`}, {-3.9157074104439396`, 3.437499981032941}}], 
      PolygonBox[{{-3.9029428580865546`, 3.3622221848584006`}, {-4., 
       3.375}, {-3.9157074104439396`, 
       3.437499981032941}, {-3.9029428580865546`, 3.3622221848584006`}}], 
      PolygonBox[{{-3.9998944727795123`, 3.4375}, {-3.9157074104439396`, 
       3.437499981032941}, {-4., 3.375}, {-3.9998944727795123`, 3.4375}}], 
      PolygonBox[{{-4., 3.375}, {-4.097057141913445, 
       3.3622221848584006`}, {-3.9998944727795123`, 3.4375}, {-4., 3.375}}], 
      PolygonBox[{{-4.084292589556057, 
       3.437499981032941}, {-3.9998944727795123`, 
       3.4375}, {-4.097057141913445, 
       3.3622221848584006`}, {-4.084292589556057, 3.437499981032941}}], 
      PolygonBox[{{-4.097057141913445, 3.3622221848584006`}, {-4.1875, 
       3.3247595264191645`}, {-4.084292589556057, 
       3.437499981032941}, {-4.097057141913445, 3.3622221848584006`}}], 
      PolygonBox[{{-4.230251642536255, 
       3.4373449933535234`}, {-4.084292589556057, 
       3.437499981032941}, {-4.1875, 
       3.3247595264191645`}, {-4.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{-4.1875, 3.3247595264191645`}, {-4.265165042944956, 
       3.2651650429449552`}, {-4.230251642536255, 
       3.4373449933535234`}, {-4.1875, 3.3247595264191645`}}], 
      PolygonBox[{{-4.404942744332997, 
       3.404942744332997}, {-4.230251642536255, 
       3.4373449933535234`}, {-4.265165042944956, 
       3.2651650429449552`}, {-4.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, 
       3.2651650429449552`}, {-4.3247595264191645`, 
       3.1875}, {-4.404942744332997, 3.404942744332997}, {-4.265165042944956, 
       3.2651650429449552`}}], 
      PolygonBox[{{-4.437344993353523, 
       3.2302516425362553`}, {-4.404942744332997, 
       3.404942744332997}, {-4.3247595264191645`, 
       3.1875}, {-4.437344993353523, 3.2302516425362553`}}], 
      PolygonBox[{{-4.3247595264191645`, 3.1875}, {-4.362222184858401, 
       3.0970571419134454`}, {-4.437344993353523, 
       3.2302516425362553`}, {-4.3247595264191645`, 3.1875}}], 
      PolygonBox[{{-4.437499981032941, 
       3.0842925895560622`}, {-4.437344993353523, 
       3.2302516425362553`}, {-4.362222184858401, 
       3.0970571419134454`}, {-4.437499981032941, 3.0842925895560622`}}], 
      PolygonBox[{{-4.362222184858401, 3.0970571419134454`}, {-4.375, 
       3.}, {-4.437499981032941, 3.0842925895560622`}, {-4.362222184858401, 
       3.0970571419134454`}}], 
      PolygonBox[{{-4.4375, 3.0001231780629953`}, {-4.437499981032941, 
       3.0842925895560622`}, {-4.375, 3.}, {-4.4375, 3.0001231780629953`}}], 
      PolygonBox[{{-4.375, 3.}, {-4.362222184858401, 
       2.902942858086555}, {-4.4375, 3.0001231780629953`}, {-4.375, 3.}}], 
      PolygonBox[{{-4.437499981032941, 2.915707410443945}, {-4.4375, 
       3.0001231780629953`}, {-4.362222184858401, 
       2.902942858086555}, {-4.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-4.362222184858401, 
       2.902942858086555}, {-4.3247595264191645`, 
       2.8125}, {-4.437499981032941, 2.915707410443945}, {-4.362222184858401, 
       2.902942858086555}}], 
      PolygonBox[{{-4.437344993353523, 
       2.769748357463745}, {-4.437499981032941, 
       2.915707410443945}, {-4.3247595264191645`, 
       2.8125}, {-4.437344993353523, 2.769748357463745}}], 
      PolygonBox[{{-4.3247595264191645`, 2.8125}, {-4.265165042944956, 
       2.7348349570550448`}, {-4.437344993353523, 
       2.769748357463745}, {-4.3247595264191645`, 2.8125}}], 
      PolygonBox[{{-4.404942744332997, 
       2.595057255667003}, {-4.437344993353523, 
       2.769748357463745}, {-4.265165042944956, 
       2.7348349570550448`}, {-4.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-4.265165042944956, 2.7348349570550448`}, {-4.1875, 
       2.6752404735808355`}, {-4.404942744332997, 
       2.595057255667003}, {-4.265165042944956, 2.7348349570550448`}}], 
      PolygonBox[{{-4.230251642536255, 
       2.5626550066464766`}, {-4.404942744332997, 
       2.595057255667003}, {-4.1875, 
       2.6752404735808355`}, {-4.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-4.1875, 2.6752404735808355`}, {-4.097057141913446, 
       2.6377778151415994`}, {-4.230251642536255, 
       2.5626550066464766`}, {-4.1875, 2.6752404735808355`}}], 
      PolygonBox[{{-4.084292589556064, 
       2.562500018967059}, {-4.230251642536255, 
       2.5626550066464766`}, {-4.097057141913446, 
       2.6377778151415994`}, {-4.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-4.097057141913446, 2.6377778151415994`}, {-4., 
       2.625}, {-4.084292589556064, 2.562500018967059}, {-4.097057141913446, 
       2.6377778151415994`}}], 
      PolygonBox[{{-3.999865158168957, 2.5625}, {-4.084292589556064, 
       2.562500018967059}, {-4., 2.625}, {-3.999865158168957, 2.5625}}], 
      PolygonBox[{{-4., 2.625}, {-3.902942858086555, 
       2.6377778151415994`}, {-3.999865158168957, 2.5625}, {-4., 2.625}}], 
      PolygonBox[{{-3.9157074104439467`, 
       2.562500018967059}, {-3.999865158168957, 2.5625}, {-3.902942858086555, 
       2.6377778151415994`}, {-3.9157074104439467`, 2.562500018967059}}], 
      PolygonBox[{{-3.902942858086555, 
       2.6377778151415994`}, {-3.8125000000000004`, 
       2.6752404735808355`}, {-3.9157074104439467`, 
       2.562500018967059}, {-3.902942858086555, 2.6377778151415994`}}], 
      PolygonBox[{{-3.769748357463745, 
       2.5626550066464766`}, {-3.9157074104439467`, 
       2.562500018967059}, {-3.8125000000000004`, 
       2.6752404735808355`}, {-3.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{-3.8125000000000004`, 
       2.6752404735808355`}, {-3.7348349570550448`, 
       2.7348349570550448`}, {-3.769748357463745, 
       2.5626550066464766`}, {-3.8125000000000004`, 2.6752404735808355`}}], 
      PolygonBox[{{-3.595057255667003, 
       2.595057255667003}, {-3.769748357463745, 
       2.5626550066464766`}, {-3.7348349570550448`, 
       2.7348349570550448`}, {-3.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-3.7348349570550448`, 
       2.7348349570550448`}, {-3.7348349570550448`, 
       2.7348349570550448`}, {-3.595057255667003, 
       2.595057255667003}, {-3.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{-3.595057255667003, 
       2.595057255667003}, {-3.595057255667003, 
       2.595057255667003}, {-3.7348349570550448`, 
       2.7348349570550448`}, {-3.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-3.595057255667003, 
       2.595057255667003}, {-3.5626550066464766`, 2.7697483574637447`}, {-3.5,
        2.5}, {-3.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-3.5, 2.642337217350632}, {-3.5, 
       2.5}, {-3.5626550066464766`, 2.7697483574637447`}, {-3.5, 
       2.642337217350632}}], 
      PolygonBox[{{-3.5626550066464766`, 
       2.7697483574637447`}, {-3.562500018967059, 2.915707410443938}, {-3.5, 
       2.642337217350632}, {-3.5626550066464766`, 2.7697483574637447`}}], 
      PolygonBox[{{-3.5, 2.79409099469826}, {-3.5, 
       2.642337217350632}, {-3.562500018967059, 2.915707410443938}, {-3.5, 
       2.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, 2.915707410443938}, {-3.5625, 
       3.}, {-3.5, 2.79409099469826}, {-3.562500018967059, 
       2.915707410443938}}], 
      PolygonBox[{{-3.5, 3.}, {-3.5, 2.79409099469826}, {-3.5625, 3.}, {-3.5, 
       3.}}], PolygonBox[{{-3.5625, 3.}, {-3.562500018967059, 
       3.084292589556062}, {-3.5, 3.}, {-3.5625, 3.}}], 
      PolygonBox[{{-3.5, 3.20590900530174}, {-3.5, 3.}, {-3.562500018967059, 
       3.084292589556062}, {-3.5, 3.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, 
       3.084292589556062}, {-3.5626550066464766`, 3.230251642536255}, {-3.5, 
       3.20590900530174}, {-3.562500018967059, 3.084292589556062}}], 
      PolygonBox[{{-3.5, 3.3576627826493675`}, {-3.5, 
       3.20590900530174}, {-3.5626550066464766`, 3.230251642536255}, {-3.5, 
       3.3576627826493675`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       3.230251642536255}, {-3.595057255667003, 3.404942744332997}, {-3.5, 
       3.3576627826493675`}, {-3.5626550066464766`, 3.230251642536255}}], 
      PolygonBox[{{-3.508553435038814, 3.491446564961186}, {-3.5, 
       3.3576627826493675`}, {-3.595057255667003, 
       3.404942744332997}, {-3.508553435038814, 3.491446564961186}}], 
      PolygonBox[{{-3.595057255667003, 
       3.404942744332997}, {-3.7697483574637447`, 
       3.4373449933535234`}, {-3.508553435038814, 
       3.491446564961186}, {-3.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{-3.642337217350632, 3.5}, {-3.508553435038814, 
       3.491446564961186}, {-3.7697483574637447`, 
       3.4373449933535234`}, {-3.642337217350632, 3.5}}], 
      PolygonBox[{{-3.7697483574637447`, 
       3.4373449933535234`}, {-3.9157074104439396`, 
       3.437499981032941}, {-3.642337217350632, 3.5}, {-3.7697483574637447`, 
       3.4373449933535234`}}], 
      PolygonBox[{{-3.7940909946267443`, 3.5}, {-3.642337217350632, 
       3.5}, {-3.9157074104439396`, 3.437499981032941}, {-3.7940909946267443`,
        3.5}}], 
      PolygonBox[{{-3.9157074104439396`, 
       3.437499981032941}, {-3.9998944727795123`, 
       3.4375}, {-3.7940909946267443`, 3.5}, {-3.9157074104439396`, 
       3.437499981032941}}], 
      PolygonBox[{{-3.92205804197311, 3.5}, {-3.7940909946267443`, 
       3.5}, {-3.9998944727795123`, 3.4375}, {-3.92205804197311, 3.5}}], 
      PolygonBox[{{-3.9998944727795123`, 3.4375}, {-4.084292589556057, 
       3.437499981032941}, {-3.92205804197311, 3.5}, {-3.9998944727795123`, 
       3.4375}}], 
      PolygonBox[{{-4.205909005304446, 3.5}, {-3.92205804197311, 
       3.5}, {-4.084292589556057, 3.437499981032941}, {-4.205909005304446, 
       3.5}}], PolygonBox[{{-4.084292589556057, 
       3.437499981032941}, {-4.230251642536255, 
       3.4373449933535234`}, {-4.205909005304446, 3.5}, {-4.084292589556057, 
       3.437499981032941}}], 
      PolygonBox[{{-4.357662782649366, 3.5}, {-4.205909005304446, 
       3.5}, {-4.230251642536255, 3.4373449933535234`}, {-4.357662782649366, 
       3.5}}], 
      PolygonBox[{{-4.230251642536255, 
       3.4373449933535234`}, {-4.404942744332997, 
       3.404942744332997}, {-4.357662782649366, 3.5}, {-4.230251642536255, 
       3.4373449933535234`}}], 
      PolygonBox[{{-3.5, 3.5}, {-4.357662782649366, 3.5}, {-4.404942744332997,
        3.404942744332997}, {-3.5, 3.5}}], 
      PolygonBox[{{-4.404942744332997, 
       3.404942744332997}, {-4.437344993353523, 3.2302516425362553`}, {-3.5, 
       3.5}, {-4.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-4.5, 3.357662782649369}, {-3.5, 3.5}, {-4.437344993353523,
        3.2302516425362553`}, {-4.5, 3.357662782649369}}], 
      PolygonBox[{{-4.437344993353523, 
       3.2302516425362553`}, {-4.437499981032941, 3.0842925895560622`}, {-4.5,
        3.357662782649369}, {-4.437344993353523, 3.2302516425362553`}}], 
      PolygonBox[{{-4.5, 3.205909005282899}, {-4.5, 
       3.357662782649369}, {-4.437499981032941, 3.0842925895560622`}, {-4.5, 
       3.205909005282899}}], 
      PolygonBox[{{-4.437499981032941, 3.0842925895560622`}, {-4.4375, 
       3.0001231780629953`}, {-4.5, 3.205909005282899}, {-4.437499981032941, 
       3.0842925895560622`}}], 
      PolygonBox[{{-4.5, 3.0806786667587}, {-4.5, 
       3.205909005282899}, {-4.4375, 3.0001231780629953`}, {-4.5, 
       3.0806786667587}}], 
      PolygonBox[{{-4.4375, 3.0001231780629953`}, {-4.437499981032941, 
       2.915707410443945}, {-4.5, 3.0806786667587}, {-4.4375, 
       3.0001231780629953`}}], 
      PolygonBox[{{-4.5, 2.7940909948547215`}, {-4.5, 
       3.0806786667587}, {-4.437499981032941, 2.915707410443945}, {-4.5, 
       2.7940909948547215`}}], 
      PolygonBox[{{-4.437499981032941, 
       2.915707410443945}, {-4.437344993353523, 2.769748357463745}, {-4.5, 
       2.7940909948547215`}, {-4.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-4.5, 2.6423372173506348`}, {-4.5, 
       2.7940909948547215`}, {-4.437344993353523, 2.769748357463745}, {-4.5, 
       2.6423372173506348`}}], 
      PolygonBox[{{-4.437344993353523, 
       2.769748357463745}, {-4.404942744332997, 2.595057255667003}, {-4.5, 
       2.6423372173506348`}, {-4.437344993353523, 2.769748357463745}}], 
      PolygonBox[{{-4.5, 3.5}, {-4.5, 
       2.6423372173506348`}, {-4.404942744332997, 2.595057255667003}, {-4.5, 
       3.5}}], PolygonBox[{{-4.404942744332997, 
       2.595057255667003}, {-4.230251642536255, 2.5626550066464766`}, {-4.5, 
       3.5}, {-4.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-4.5, 2.5}, {-4.5, 3.5}, {-4.230251642536255, 
       2.5626550066464766`}, {-4.5, 2.5}}], 
      PolygonBox[{{-4.230251642536255, 
       2.5626550066464766`}, {-4.084292589556064, 2.562500018967059}, {-4.5, 
       2.5}, {-4.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-4.205909005566828, 2.5}, {-4.5, 2.5}, {-4.084292589556064,
        2.562500018967059}, {-4.205909005566828, 2.5}}], 
      PolygonBox[{{-4.084292589556064, 
       2.562500018967059}, {-3.999865158168957, 2.5625}, {-4.205909005566828, 
       2.5}, {-4.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-3.9176761295989384`, 2.5}, {-4.205909005566828, 
       2.5}, {-3.999865158168957, 2.5625}, {-3.9176761295989384`, 2.5}}], 
      PolygonBox[{{-3.999865158168957, 2.5625}, {-3.9157074104439467`, 
       2.562500018967059}, {-3.9176761295989384`, 2.5}, {-3.999865158168957, 
       2.5625}}], 
      PolygonBox[{{-3.7940909946396024`, 2.5}, {-3.9176761295989384`, 
       2.5}, {-3.9157074104439467`, 2.562500018967059}, {-3.7940909946396024`,
        2.5}}], 
      PolygonBox[{{-3.9157074104439467`, 
       2.562500018967059}, {-3.769748357463745, 
       2.5626550066464766`}, {-3.7940909946396024`, 
       2.5}, {-3.9157074104439467`, 2.562500018967059}}], 
      PolygonBox[{{-3.642337217350629, 2.5}, {-3.7940909946396024`, 
       2.5}, {-3.769748357463745, 2.5626550066464766`}, {-3.642337217350629, 
       2.5}}], PolygonBox[{{-3.769748357463745, 
       2.5626550066464766`}, {-3.595057255667003, 
       2.595057255667003}, {-3.642337217350629, 2.5}, {-3.769748357463745, 
       2.5626550066464766`}}], 
      PolygonBox[{{-3.5, 2.5}, {-3.642337217350629, 2.5}, {-3.595057255667003,
        2.595057255667003}, {-3.5, 2.5}}], 
      PolygonBox[{{-3.595057255667003, 
       2.595057255667003}, {-3.595057255667003, 2.595057255667003}, {-3.5, 
       2.5}, {-3.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-3.5, 2.5}, {-3.5, 2.5}, {-3.595057255667003, 
       2.595057255667003}, {-3.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, 4.}, {-4.479166666666667, 4.}, {-4.458333333333333, 
       4.}, {-4.4375, 4.}, {-4.416666666666667, 4.}, {-4.395833333333333, 
       4.}, {-4.375, 4.}, {-4.375, 4.}, {-4.395833333333333, 
       4.}, {-4.416666666666667, 4.}, {-4.4375, 4.}, {-4.458333333333333, 
       4.}, {-4.479166666666667, 4.}, {-4.5, 4.}, {-4.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, 4.}, {-3.6041666666666665`, 
       4.}, {-3.5833333333333335`, 4.}, {-3.5625, 4.}, {-3.5416666666666665`, 
       4.}, {-3.5208333333333335`, 4.}, {-3.5, 4.}, {-3.5, 
       4.}, {-3.5208333333333335`, 4.}, {-3.5416666666666665`, 4.}, {-3.5625, 
       4.}, {-3.5833333333333335`, 4.}, {-3.6041666666666665`, 4.}, {-3.625, 
       4.}, {-3.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 3.5}, {-4., 3.5208333333333335`}, {-4., 
       3.5416666666666665`}, {-4., 3.5625}, {-4., 3.5833333333333335`}, {-4., 
       3.6041666666666665`}, {-4., 3.625}, {-4., 3.625}, {-4., 
       3.6041666666666665`}, {-4., 3.5833333333333335`}, {-4., 3.5625}, {-4., 
       3.5416666666666665`}, {-4., 3.5208333333333335`}, {-4., 3.5}, {-4., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 4.375}, {-4., 4.395833333333333}, {-4., 
       4.416666666666667}, {-4., 4.4375}, {-4., 4.458333333333333}, {-4., 
       4.479166666666667}, {-4., 4.5}, {-4., 4.5}, {-4., 
       4.479166666666667}, {-4., 4.458333333333333}, {-4., 4.4375}, {-4., 
       4.416666666666667}, {-4., 4.395833333333333}, {-4., 4.375}, {-4., 
       4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, 4.}, {-4.25, 4.}, {-4.125, 4.}, {-4., 4.}, {-3.875, 
       4.}, {-3.75, 4.}, {-3.625, 4.}, {-3.625, 4.}, {-3.75, 4.}, {-3.875, 
       4.}, {-4., 4.}, {-4.125, 4.}, {-4.25, 4.}, {-4.375, 4.}, {-4.375, 
       4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 3.625}, {-4., 3.75}, {-4., 3.875}, {-4., 4.}, {-4., 
       4.125}, {-4., 4.25}, {-4., 4.375}, {-4., 4.375}, {-4., 4.25}, {-4., 
       4.125}, {-4., 4.}, {-4., 3.875}, {-4., 3.75}, {-4., 3.625}, {-4., 
       3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByC0gIOYXqCjthTvAfWizk9JyQIOF3aYVz1J
g8ofEHBIFUpR+/iA98C5b2dz2vkFHcDiDXwHZig/OdTrI+iwUfqtlJUl/4Gv
GeHxr4qg8gwCEP0Ngg5Qc1HlDwjA9UPNhZsPFYfbD9V3QAPqPqi5cPfD5DdB
3IGqv4EPbj7UH3D7of50gJp7ABoOqO5n4HWAmguXZ4T6H6YfFj4w81HCD2g/
LHyh4eSAHv4ADD5+7Q==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByC0kEMoGPDC+atXgQAfnA+hBdDkBdD0C6Kp
FyLIh+qD86HmoqkXQJPng/PDIO5GU8+DwUd1Hw+a+2HqBdDk+eD8MJTwgann
IcgPRXEfD5r7YeoF0OQF0PQLoqkXcgAAykBQ8A==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, 
       3.7348349570550448`}, {-3.6752404735808355`, 
       3.8125}, {-3.595057255667003, 
       3.595057255667003}, {-3.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{-3.5626550066464766`, 
       3.7697483574637447`}, {-3.595057255667003, 
       3.595057255667003}, {-3.6752404735808355`, 
       3.8125}, {-3.5626550066464766`, 3.7697483574637447`}}], 
      PolygonBox[{{-3.6752404735808355`, 3.8125}, {-3.6377778151415994`, 
       3.9029428580865546`}, {-3.5626550066464766`, 
       3.7697483574637447`}, {-3.6752404735808355`, 3.8125}}], 
      PolygonBox[{{-3.562500018967059, 
       3.915707410443938}, {-3.5626550066464766`, 
       3.7697483574637447`}, {-3.6377778151415994`, 
       3.9029428580865546`}, {-3.562500018967059, 3.915707410443938}}], 
      PolygonBox[{{-3.6377778151415994`, 3.9029428580865546`}, {-3.625, 
       4.}, {-3.562500018967059, 3.915707410443938}, {-3.6377778151415994`, 
       3.9029428580865546`}}], 
      PolygonBox[{{-3.5625, 4.}, {-3.562500018967059, 
       3.915707410443938}, {-3.625, 4.}, {-3.5625, 4.}}], 
      PolygonBox[{{-3.625, 4.}, {-3.6377778151415994`, 
       4.097057141913445}, {-3.5625, 4.}, {-3.625, 4.}}], 
      PolygonBox[{{-3.562500018967059, 4.084292589556061}, {-3.5625, 
       4.}, {-3.6377778151415994`, 4.097057141913445}, {-3.562500018967059, 
       4.084292589556061}}], 
      PolygonBox[{{-3.6377778151415994`, 
       4.097057141913445}, {-3.6752404735808355`, 
       4.1875}, {-3.562500018967059, 
       4.084292589556061}, {-3.6377778151415994`, 4.097057141913445}}], 
      PolygonBox[{{-3.5626550066464766`, 
       4.230251642536255}, {-3.562500018967059, 
       4.084292589556061}, {-3.6752404735808355`, 
       4.1875}, {-3.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, 4.1875}, {-3.7348349570550448`, 
       4.265165042944956}, {-3.5626550066464766`, 
       4.230251642536255}, {-3.6752404735808355`, 4.1875}}], 
      PolygonBox[{{-3.595057255667003, 
       4.404942744332997}, {-3.5626550066464766`, 
       4.230251642536255}, {-3.7348349570550448`, 
       4.265165042944956}, {-3.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, 4.265165042944956}, {-3.8125, 
       4.3247595264191645`}, {-3.595057255667003, 
       4.404942744332997}, {-3.7348349570550448`, 4.265165042944956}}], 
      PolygonBox[{{-3.7697483574637447`, 
       4.437344993353523}, {-3.595057255667003, 4.404942744332997}, {-3.8125, 
       4.3247595264191645`}, {-3.7697483574637447`, 4.437344993353523}}], 
      PolygonBox[{{-3.8125, 4.3247595264191645`}, {-3.9029428580865546`, 
       4.362222184858401}, {-3.7697483574637447`, 
       4.437344993353523}, {-3.8125, 4.3247595264191645`}}], 
      PolygonBox[{{-3.9157074104439396`, 
       4.437499981032941}, {-3.7697483574637447`, 
       4.437344993353523}, {-3.9029428580865546`, 
       4.362222184858401}, {-3.9157074104439396`, 4.437499981032941}}], 
      PolygonBox[{{-3.9029428580865546`, 4.362222184858401}, {-4., 
       4.375}, {-3.9157074104439396`, 
       4.437499981032941}, {-3.9029428580865546`, 4.362222184858401}}], 
      PolygonBox[{{-3.9998944727795123`, 4.4375}, {-3.9157074104439396`, 
       4.437499981032941}, {-4., 4.375}, {-3.9998944727795123`, 4.4375}}], 
      PolygonBox[{{-4., 4.375}, {-4.097057141913445, 
       4.362222184858401}, {-3.9998944727795123`, 4.4375}, {-4., 4.375}}], 
      PolygonBox[{{-4.084292589556057, 
       4.437499981032941}, {-3.9998944727795123`, 
       4.4375}, {-4.097057141913445, 4.362222184858401}, {-4.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-4.097057141913445, 4.362222184858401}, {-4.1875, 
       4.3247595264191645`}, {-4.084292589556057, 
       4.437499981032941}, {-4.097057141913445, 4.362222184858401}}], 
      PolygonBox[{{-4.230251642536255, 
       4.437344993353523}, {-4.084292589556057, 4.437499981032941}, {-4.1875, 
       4.3247595264191645`}, {-4.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{-4.1875, 4.3247595264191645`}, {-4.265165042944956, 
       4.265165042944956}, {-4.230251642536255, 4.437344993353523}, {-4.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{-4.404942744332997, 
       4.404942744332997}, {-4.230251642536255, 
       4.437344993353523}, {-4.265165042944956, 
       4.265165042944956}, {-4.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, 
       4.265165042944956}, {-4.3247595264191645`, 
       4.1875}, {-4.404942744332997, 4.404942744332997}, {-4.265165042944956, 
       4.265165042944956}}], 
      PolygonBox[{{-4.437344993353523, 
       4.230251642536255}, {-4.404942744332997, 
       4.404942744332997}, {-4.3247595264191645`, 
       4.1875}, {-4.437344993353523, 4.230251642536255}}], 
      PolygonBox[{{-4.3247595264191645`, 4.1875}, {-4.362222184858401, 
       4.097057141913446}, {-4.437344993353523, 
       4.230251642536255}, {-4.3247595264191645`, 4.1875}}], 
      PolygonBox[{{-4.437499981032941, 
       4.084292589556062}, {-4.437344993353523, 
       4.230251642536255}, {-4.362222184858401, 
       4.097057141913446}, {-4.437499981032941, 4.084292589556062}}], 
      PolygonBox[{{-4.362222184858401, 4.097057141913446}, {-4.375, 
       4.}, {-4.437499981032941, 4.084292589556062}, {-4.362222184858401, 
       4.097057141913446}}], 
      PolygonBox[{{-4.4375, 4.000123178062996}, {-4.437499981032941, 
       4.084292589556062}, {-4.375, 4.}, {-4.4375, 4.000123178062996}}], 
      PolygonBox[{{-4.375, 4.}, {-4.362222184858401, 
       3.902942858086555}, {-4.4375, 4.000123178062996}, {-4.375, 4.}}], 
      PolygonBox[{{-4.437499981032941, 3.915707410443945}, {-4.4375, 
       4.000123178062996}, {-4.362222184858401, 
       3.902942858086555}, {-4.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-4.362222184858401, 
       3.902942858086555}, {-4.3247595264191645`, 
       3.8125}, {-4.437499981032941, 3.915707410443945}, {-4.362222184858401, 
       3.902942858086555}}], 
      PolygonBox[{{-4.437344993353523, 
       3.769748357463745}, {-4.437499981032941, 
       3.915707410443945}, {-4.3247595264191645`, 
       3.8125}, {-4.437344993353523, 3.769748357463745}}], 
      PolygonBox[{{-4.3247595264191645`, 3.8125}, {-4.265165042944956, 
       3.7348349570550448`}, {-4.437344993353523, 
       3.769748357463745}, {-4.3247595264191645`, 3.8125}}], 
      PolygonBox[{{-4.404942744332997, 
       3.595057255667003}, {-4.437344993353523, 
       3.769748357463745}, {-4.265165042944956, 
       3.7348349570550448`}, {-4.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-4.265165042944956, 3.7348349570550448`}, {-4.1875, 
       3.6752404735808355`}, {-4.404942744332997, 
       3.595057255667003}, {-4.265165042944956, 3.7348349570550448`}}], 
      PolygonBox[{{-4.230251642536255, 
       3.5626550066464766`}, {-4.404942744332997, 
       3.595057255667003}, {-4.1875, 
       3.6752404735808355`}, {-4.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-4.1875, 3.6752404735808355`}, {-4.097057141913446, 
       3.6377778151415994`}, {-4.230251642536255, 
       3.5626550066464766`}, {-4.1875, 3.6752404735808355`}}], 
      PolygonBox[{{-4.084292589556064, 
       3.562500018967059}, {-4.230251642536255, 
       3.5626550066464766`}, {-4.097057141913446, 
       3.6377778151415994`}, {-4.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-4.097057141913446, 3.6377778151415994`}, {-4., 
       3.625}, {-4.084292589556064, 3.562500018967059}, {-4.097057141913446, 
       3.6377778151415994`}}], 
      PolygonBox[{{-3.999865158168957, 3.5625}, {-4.084292589556064, 
       3.562500018967059}, {-4., 3.625}, {-3.999865158168957, 3.5625}}], 
      PolygonBox[{{-4., 3.625}, {-3.902942858086555, 
       3.6377778151415994`}, {-3.999865158168957, 3.5625}, {-4., 3.625}}], 
      PolygonBox[{{-3.9157074104439467`, 
       3.562500018967059}, {-3.999865158168957, 3.5625}, {-3.902942858086555, 
       3.6377778151415994`}, {-3.9157074104439467`, 3.562500018967059}}], 
      PolygonBox[{{-3.902942858086555, 
       3.6377778151415994`}, {-3.8125000000000004`, 
       3.6752404735808355`}, {-3.9157074104439467`, 
       3.562500018967059}, {-3.902942858086555, 3.6377778151415994`}}], 
      PolygonBox[{{-3.769748357463745, 
       3.5626550066464766`}, {-3.9157074104439467`, 
       3.562500018967059}, {-3.8125000000000004`, 
       3.6752404735808355`}, {-3.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{-3.8125000000000004`, 
       3.6752404735808355`}, {-3.7348349570550448`, 
       3.7348349570550448`}, {-3.769748357463745, 
       3.5626550066464766`}, {-3.8125000000000004`, 3.6752404735808355`}}], 
      PolygonBox[{{-3.595057255667003, 
       3.595057255667003}, {-3.769748357463745, 
       3.5626550066464766`}, {-3.7348349570550448`, 
       3.7348349570550448`}, {-3.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-3.7348349570550448`, 
       3.7348349570550448`}, {-3.7348349570550448`, 
       3.7348349570550448`}, {-3.595057255667003, 
       3.595057255667003}, {-3.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{-3.595057255667003, 
       3.595057255667003}, {-3.595057255667003, 
       3.595057255667003}, {-3.7348349570550448`, 
       3.7348349570550448`}, {-3.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-3.595057255667003, 
       3.595057255667003}, {-3.5626550066464766`, 3.7697483574637447`}, {-3.5,
        3.5}, {-3.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-3.5, 3.642337217350632}, {-3.5, 
       3.5}, {-3.5626550066464766`, 3.7697483574637447`}, {-3.5, 
       3.642337217350632}}], 
      PolygonBox[{{-3.5626550066464766`, 
       3.7697483574637447`}, {-3.562500018967059, 3.915707410443938}, {-3.5, 
       3.642337217350632}, {-3.5626550066464766`, 3.7697483574637447`}}], 
      PolygonBox[{{-3.5, 3.79409099469826}, {-3.5, 
       3.642337217350632}, {-3.562500018967059, 3.915707410443938}, {-3.5, 
       3.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, 3.915707410443938}, {-3.5625, 
       4.}, {-3.5, 3.79409099469826}, {-3.562500018967059, 
       3.915707410443938}}], 
      PolygonBox[{{-3.5, 4.}, {-3.5, 3.79409099469826}, {-3.5625, 4.}, {-3.5, 
       4.}}], PolygonBox[{{-3.5625, 4.}, {-3.562500018967059, 
       4.084292589556061}, {-3.5, 4.}, {-3.5625, 4.}}], 
      PolygonBox[{{-3.5, 4.20590900530174}, {-3.5, 4.}, {-3.562500018967059, 
       4.084292589556061}, {-3.5, 4.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, 
       4.084292589556061}, {-3.5626550066464766`, 4.230251642536255}, {-3.5, 
       4.20590900530174}, {-3.562500018967059, 4.084292589556061}}], 
      PolygonBox[{{-3.5, 4.357662782649368}, {-3.5, 
       4.20590900530174}, {-3.5626550066464766`, 4.230251642536255}, {-3.5, 
       4.357662782649368}}], 
      PolygonBox[{{-3.5626550066464766`, 
       4.230251642536255}, {-3.595057255667003, 4.404942744332997}, {-3.5, 
       4.357662782649368}, {-3.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{-3.508553435038814, 4.491446564961186}, {-3.5, 
       4.357662782649368}, {-3.595057255667003, 
       4.404942744332997}, {-3.508553435038814, 4.491446564961186}}], 
      PolygonBox[{{-3.595057255667003, 
       4.404942744332997}, {-3.7697483574637447`, 
       4.437344993353523}, {-3.508553435038814, 
       4.491446564961186}, {-3.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{-3.642337217350632, 4.5}, {-3.508553435038814, 
       4.491446564961186}, {-3.7697483574637447`, 
       4.437344993353523}, {-3.642337217350632, 4.5}}], 
      PolygonBox[{{-3.7697483574637447`, 
       4.437344993353523}, {-3.9157074104439396`, 
       4.437499981032941}, {-3.642337217350632, 4.5}, {-3.7697483574637447`, 
       4.437344993353523}}], 
      PolygonBox[{{-3.7940909946267443`, 4.5}, {-3.642337217350632, 
       4.5}, {-3.9157074104439396`, 4.437499981032941}, {-3.7940909946267443`,
        4.5}}], 
      PolygonBox[{{-3.9157074104439396`, 
       4.437499981032941}, {-3.9998944727795123`, 
       4.4375}, {-3.7940909946267443`, 4.5}, {-3.9157074104439396`, 
       4.437499981032941}}], 
      PolygonBox[{{-3.92205804197311, 4.5}, {-3.7940909946267443`, 
       4.5}, {-3.9998944727795123`, 4.4375}, {-3.92205804197311, 4.5}}], 
      PolygonBox[{{-3.9998944727795123`, 4.4375}, {-4.084292589556057, 
       4.437499981032941}, {-3.92205804197311, 4.5}, {-3.9998944727795123`, 
       4.4375}}], 
      PolygonBox[{{-4.205909005304446, 4.5}, {-3.92205804197311, 
       4.5}, {-4.084292589556057, 4.437499981032941}, {-4.205909005304446, 
       4.5}}], PolygonBox[{{-4.084292589556057, 
       4.437499981032941}, {-4.230251642536255, 
       4.437344993353523}, {-4.205909005304446, 4.5}, {-4.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-4.357662782649366, 4.5}, {-4.205909005304446, 
       4.5}, {-4.230251642536255, 4.437344993353523}, {-4.357662782649366, 
       4.5}}], PolygonBox[{{-4.230251642536255, 
       4.437344993353523}, {-4.404942744332997, 
       4.404942744332997}, {-4.357662782649366, 4.5}, {-4.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{-3.5, 4.5}, {-4.357662782649366, 4.5}, {-4.404942744332997,
        4.404942744332997}, {-3.5, 4.5}}], 
      PolygonBox[{{-4.404942744332997, 
       4.404942744332997}, {-4.437344993353523, 4.230251642536255}, {-3.5, 
       4.5}, {-4.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-4.5, 4.357662782649369}, {-3.5, 4.5}, {-4.437344993353523,
        4.230251642536255}, {-4.5, 4.357662782649369}}], 
      PolygonBox[{{-4.437344993353523, 
       4.230251642536255}, {-4.437499981032941, 4.084292589556062}, {-4.5, 
       4.357662782649369}, {-4.437344993353523, 4.230251642536255}}], 
      PolygonBox[{{-4.5, 4.205909005282899}, {-4.5, 
       4.357662782649369}, {-4.437499981032941, 4.084292589556062}, {-4.5, 
       4.205909005282899}}], 
      PolygonBox[{{-4.437499981032941, 4.084292589556062}, {-4.4375, 
       4.000123178062996}, {-4.5, 4.205909005282899}, {-4.437499981032941, 
       4.084292589556062}}], 
      PolygonBox[{{-4.5, 4.0806786667587005`}, {-4.5, 
       4.205909005282899}, {-4.4375, 4.000123178062996}, {-4.5, 
       4.0806786667587005`}}], 
      PolygonBox[{{-4.4375, 4.000123178062996}, {-4.437499981032941, 
       3.915707410443945}, {-4.5, 4.0806786667587005`}, {-4.4375, 
       4.000123178062996}}], 
      PolygonBox[{{-4.5, 3.7940909948547215`}, {-4.5, 
       4.0806786667587005`}, {-4.437499981032941, 3.915707410443945}, {-4.5, 
       3.7940909948547215`}}], 
      PolygonBox[{{-4.437499981032941, 
       3.915707410443945}, {-4.437344993353523, 3.769748357463745}, {-4.5, 
       3.7940909948547215`}, {-4.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-4.5, 3.6423372173506348`}, {-4.5, 
       3.7940909948547215`}, {-4.437344993353523, 3.769748357463745}, {-4.5, 
       3.6423372173506348`}}], 
      PolygonBox[{{-4.437344993353523, 
       3.769748357463745}, {-4.404942744332997, 3.595057255667003}, {-4.5, 
       3.6423372173506348`}, {-4.437344993353523, 3.769748357463745}}], 
      PolygonBox[{{-4.5, 4.5}, {-4.5, 
       3.6423372173506348`}, {-4.404942744332997, 3.595057255667003}, {-4.5, 
       4.5}}], PolygonBox[{{-4.404942744332997, 
       3.595057255667003}, {-4.230251642536255, 3.5626550066464766`}, {-4.5, 
       4.5}, {-4.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-4.5, 3.5}, {-4.5, 4.5}, {-4.230251642536255, 
       3.5626550066464766`}, {-4.5, 3.5}}], 
      PolygonBox[{{-4.230251642536255, 
       3.5626550066464766`}, {-4.084292589556064, 3.562500018967059}, {-4.5, 
       3.5}, {-4.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-4.205909005566828, 3.5}, {-4.5, 3.5}, {-4.084292589556064,
        3.562500018967059}, {-4.205909005566828, 3.5}}], 
      PolygonBox[{{-4.084292589556064, 
       3.562500018967059}, {-3.999865158168957, 3.5625}, {-4.205909005566828, 
       3.5}, {-4.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-3.9176761295989384`, 3.5}, {-4.205909005566828, 
       3.5}, {-3.999865158168957, 3.5625}, {-3.9176761295989384`, 3.5}}], 
      PolygonBox[{{-3.999865158168957, 3.5625}, {-3.9157074104439467`, 
       3.562500018967059}, {-3.9176761295989384`, 3.5}, {-3.999865158168957, 
       3.5625}}], 
      PolygonBox[{{-3.7940909946396024`, 3.5}, {-3.9176761295989384`, 
       3.5}, {-3.9157074104439467`, 3.562500018967059}, {-3.7940909946396024`,
        3.5}}], 
      PolygonBox[{{-3.9157074104439467`, 
       3.562500018967059}, {-3.769748357463745, 
       3.5626550066464766`}, {-3.7940909946396024`, 
       3.5}, {-3.9157074104439467`, 3.562500018967059}}], 
      PolygonBox[{{-3.642337217350629, 3.5}, {-3.7940909946396024`, 
       3.5}, {-3.769748357463745, 3.5626550066464766`}, {-3.642337217350629, 
       3.5}}], PolygonBox[{{-3.769748357463745, 
       3.5626550066464766`}, {-3.595057255667003, 
       3.595057255667003}, {-3.642337217350629, 3.5}, {-3.769748357463745, 
       3.5626550066464766`}}], 
      PolygonBox[{{-3.5, 3.5}, {-3.642337217350629, 3.5}, {-3.595057255667003,
        3.595057255667003}, {-3.5, 3.5}}], 
      PolygonBox[{{-3.595057255667003, 
       3.595057255667003}, {-3.595057255667003, 3.595057255667003}, {-3.5, 
       3.5}, {-3.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-3.5, 3.5}, {-3.5, 3.5}, {-3.595057255667003, 
       3.595057255667003}, {-3.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5, 5.}, {-4.479166666666667, 5.}, {-4.458333333333333, 
       5.}, {-4.4375, 5.}, {-4.416666666666667, 5.}, {-4.395833333333333, 
       5.}, {-4.375, 5.}, {-4.375, 5.}, {-4.395833333333333, 
       5.}, {-4.416666666666667, 5.}, {-4.4375, 5.}, {-4.458333333333333, 
       5.}, {-4.479166666666667, 5.}, {-4.5, 5.}, {-4.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.625, 5.}, {-3.6041666666666665`, 
       5.}, {-3.5833333333333335`, 5.}, {-3.5625, 5.}, {-3.5416666666666665`, 
       5.}, {-3.5208333333333335`, 5.}, {-3.5, 5.}, {-3.5, 
       5.}, {-3.5208333333333335`, 5.}, {-3.5416666666666665`, 5.}, {-3.5625, 
       5.}, {-3.5833333333333335`, 5.}, {-3.6041666666666665`, 5.}, {-3.625, 
       5.}, {-3.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 4.5}, {-4., 4.520833333333333}, {-4., 
       4.541666666666667}, {-4., 4.5625}, {-4., 4.583333333333333}, {-4., 
       4.604166666666667}, {-4., 4.625}, {-4., 4.625}, {-4., 
       4.604166666666667}, {-4., 4.583333333333333}, {-4., 4.5625}, {-4., 
       4.541666666666667}, {-4., 4.520833333333333}, {-4., 4.5}, {-4., 
       4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 5.375}, {-4., 5.395833333333333}, {-4., 
       5.416666666666667}, {-4., 5.4375}, {-4., 5.458333333333333}, {-4., 
       5.479166666666667}, {-4., 5.5}, {-4., 5.5}, {-4., 
       5.479166666666667}, {-4., 5.458333333333333}, {-4., 5.4375}, {-4., 
       5.416666666666667}, {-4., 5.395833333333333}, {-4., 5.375}, {-4., 
       5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.375, 5.}, {-4.25, 5.}, {-4.125, 5.}, {-4., 5.}, {-3.875, 
       5.}, {-3.75, 5.}, {-3.625, 5.}, {-3.625, 5.}, {-3.75, 5.}, {-3.875, 
       5.}, {-4., 5.}, {-4.125, 5.}, {-4.25, 5.}, {-4.375, 5.}, {-4.375, 
       5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., 4.625}, {-4., 4.75}, {-4., 4.875}, {-4., 5.}, {-4., 
       5.125}, {-4., 5.25}, {-4., 5.375}, {-4., 5.375}, {-4., 5.25}, {-4., 
       5.125}, {-4., 5.}, {-4., 4.875}, {-4., 4.75}, {-4., 4.625}, {-4., 
       4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG8ByC0iIOYXqCjthTvAfWizk9JySIOF3aYVz1J
g8ofEHFIFUpR+/iA98C5b2dz2vlFHcDiDXwHZig/OdTrI+qwUfqtlJUl/4Gv
GeHxr4qg8gwCEP0Nog4QcwVQ5Q8IwPVDzBWEmw8RF4TbD9EneEAD6j6IuYJw
98Pkb/aW8c6dI4yq30EYbr4xp9Hkig9CcPsz7kjbFm0WctCAuo97+ooFor1C
aO4XctgE9R9MnhHqf5h+WPgYQc1HCT+g/bDwvQF1H3r4AwA70YGb
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8ByC0mEMoGPDC+atXgQAfnA+hBdDkBdD0C6Kp
FyLIh+gThfMh5oqgqRdBUy+Mpl4ITT0mH9V9Qmjuh6kXQJPng/PDUMIHpp6H
IB/VfTxo7oepF0FTL4KmXhRNvZgDADajUXU=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-3.7348349570550448`, 
       4.734834957055044}, {-3.6752404735808355`, 
       4.8125}, {-3.595057255667003, 
       4.595057255667003}, {-3.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{-3.5626550066464766`, 
       4.769748357463745}, {-3.595057255667003, 
       4.595057255667003}, {-3.6752404735808355`, 
       4.8125}, {-3.5626550066464766`, 4.769748357463745}}], 
      PolygonBox[{{-3.6752404735808355`, 4.8125}, {-3.6377778151415994`, 
       4.902942858086555}, {-3.5626550066464766`, 
       4.769748357463745}, {-3.6752404735808355`, 4.8125}}], 
      PolygonBox[{{-3.562500018967059, 
       4.915707410443938}, {-3.5626550066464766`, 
       4.769748357463745}, {-3.6377778151415994`, 
       4.902942858086555}, {-3.562500018967059, 4.915707410443938}}], 
      PolygonBox[{{-3.6377778151415994`, 4.902942858086555}, {-3.625, 
       5.}, {-3.562500018967059, 4.915707410443938}, {-3.6377778151415994`, 
       4.902942858086555}}], 
      PolygonBox[{{-3.5625, 5.}, {-3.562500018967059, 
       4.915707410443938}, {-3.625, 5.}, {-3.5625, 5.}}], 
      PolygonBox[{{-3.625, 5.}, {-3.6377778151415994`, 
       5.097057141913445}, {-3.5625, 5.}, {-3.625, 5.}}], 
      PolygonBox[{{-3.562500018967059, 5.084292589556061}, {-3.5625, 
       5.}, {-3.6377778151415994`, 5.097057141913445}, {-3.562500018967059, 
       5.084292589556061}}], 
      PolygonBox[{{-3.6377778151415994`, 
       5.097057141913445}, {-3.6752404735808355`, 
       5.1875}, {-3.562500018967059, 
       5.084292589556061}, {-3.6377778151415994`, 5.097057141913445}}], 
      PolygonBox[{{-3.5626550066464766`, 
       5.230251642536255}, {-3.562500018967059, 
       5.084292589556061}, {-3.6752404735808355`, 
       5.1875}, {-3.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{-3.6752404735808355`, 5.1875}, {-3.7348349570550448`, 
       5.265165042944956}, {-3.5626550066464766`, 
       5.230251642536255}, {-3.6752404735808355`, 5.1875}}], 
      PolygonBox[{{-3.595057255667003, 
       5.404942744332997}, {-3.5626550066464766`, 
       5.230251642536255}, {-3.7348349570550448`, 
       5.265165042944956}, {-3.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{-3.7348349570550448`, 5.265165042944956}, {-3.8125, 
       5.3247595264191645`}, {-3.595057255667003, 
       5.404942744332997}, {-3.7348349570550448`, 5.265165042944956}}], 
      PolygonBox[{{-3.7697483574637447`, 
       5.437344993353523}, {-3.595057255667003, 5.404942744332997}, {-3.8125, 
       5.3247595264191645`}, {-3.7697483574637447`, 5.437344993353523}}], 
      PolygonBox[{{-3.8125, 5.3247595264191645`}, {-3.9029428580865546`, 
       5.362222184858401}, {-3.7697483574637447`, 
       5.437344993353523}, {-3.8125, 5.3247595264191645`}}], 
      PolygonBox[{{-3.9157074104439396`, 
       5.437499981032941}, {-3.7697483574637447`, 
       5.437344993353523}, {-3.9029428580865546`, 
       5.362222184858401}, {-3.9157074104439396`, 5.437499981032941}}], 
      PolygonBox[{{-3.9029428580865546`, 5.362222184858401}, {-4., 
       5.375}, {-3.9157074104439396`, 
       5.437499981032941}, {-3.9029428580865546`, 5.362222184858401}}], 
      PolygonBox[{{-3.9998944727795123`, 5.4375}, {-3.9157074104439396`, 
       5.437499981032941}, {-4., 5.375}, {-3.9998944727795123`, 5.4375}}], 
      PolygonBox[{{-4., 5.375}, {-4.097057141913445, 
       5.362222184858401}, {-3.9998944727795123`, 5.4375}, {-4., 5.375}}], 
      PolygonBox[{{-4.084292589556057, 
       5.437499981032941}, {-3.9998944727795123`, 
       5.4375}, {-4.097057141913445, 5.362222184858401}, {-4.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-4.097057141913445, 5.362222184858401}, {-4.1875, 
       5.3247595264191645`}, {-4.084292589556057, 
       5.437499981032941}, {-4.097057141913445, 5.362222184858401}}], 
      PolygonBox[{{-4.230251642536255, 
       5.437344993353523}, {-4.084292589556057, 5.437499981032941}, {-4.1875, 
       5.3247595264191645`}, {-4.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{-4.1875, 5.3247595264191645`}, {-4.265165042944956, 
       5.265165042944956}, {-4.230251642536255, 5.437344993353523}, {-4.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{-4.404942744332997, 
       5.404942744332997}, {-4.230251642536255, 
       5.437344993353523}, {-4.265165042944956, 
       5.265165042944956}, {-4.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-4.265165042944956, 
       5.265165042944956}, {-4.3247595264191645`, 
       5.1875}, {-4.404942744332997, 5.404942744332997}, {-4.265165042944956, 
       5.265165042944956}}], 
      PolygonBox[{{-4.437344993353523, 
       5.230251642536255}, {-4.404942744332997, 
       5.404942744332997}, {-4.3247595264191645`, 
       5.1875}, {-4.437344993353523, 5.230251642536255}}], 
      PolygonBox[{{-4.3247595264191645`, 5.1875}, {-4.362222184858401, 
       5.097057141913446}, {-4.437344993353523, 
       5.230251642536255}, {-4.3247595264191645`, 5.1875}}], 
      PolygonBox[{{-4.437499981032941, 
       5.084292589556062}, {-4.437344993353523, 
       5.230251642536255}, {-4.362222184858401, 
       5.097057141913446}, {-4.437499981032941, 5.084292589556062}}], 
      PolygonBox[{{-4.362222184858401, 5.097057141913446}, {-4.375, 
       5.}, {-4.437499981032941, 5.084292589556062}, {-4.362222184858401, 
       5.097057141913446}}], 
      PolygonBox[{{-4.4375, 5.000123178062996}, {-4.437499981032941, 
       5.084292589556062}, {-4.375, 5.}, {-4.4375, 5.000123178062996}}], 
      PolygonBox[{{-4.375, 5.}, {-4.362222184858401, 
       4.902942858086555}, {-4.4375, 5.000123178062996}, {-4.375, 5.}}], 
      PolygonBox[{{-4.437499981032941, 4.915707410443945}, {-4.4375, 
       5.000123178062996}, {-4.362222184858401, 
       4.902942858086555}, {-4.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-4.362222184858401, 
       4.902942858086555}, {-4.3247595264191645`, 
       4.8125}, {-4.437499981032941, 4.915707410443945}, {-4.362222184858401, 
       4.902942858086555}}], 
      PolygonBox[{{-4.437344993353523, 
       4.769748357463746}, {-4.437499981032941, 
       4.915707410443945}, {-4.3247595264191645`, 
       4.8125}, {-4.437344993353523, 4.769748357463746}}], 
      PolygonBox[{{-4.3247595264191645`, 4.8125}, {-4.265165042944956, 
       4.734834957055044}, {-4.437344993353523, 
       4.769748357463746}, {-4.3247595264191645`, 4.8125}}], 
      PolygonBox[{{-4.404942744332997, 
       4.595057255667003}, {-4.437344993353523, 
       4.769748357463746}, {-4.265165042944956, 
       4.734834957055044}, {-4.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-4.265165042944956, 4.734834957055044}, {-4.1875, 
       4.6752404735808355`}, {-4.404942744332997, 
       4.595057255667003}, {-4.265165042944956, 4.734834957055044}}], 
      PolygonBox[{{-4.230251642536255, 
       4.562655006646477}, {-4.404942744332997, 4.595057255667003}, {-4.1875, 
       4.6752404735808355`}, {-4.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-4.1875, 4.6752404735808355`}, {-4.097057141913446, 
       4.637777815141599}, {-4.230251642536255, 4.562655006646477}, {-4.1875, 
       4.6752404735808355`}}], 
      PolygonBox[{{-4.084292589556064, 
       4.562500018967059}, {-4.230251642536255, 
       4.562655006646477}, {-4.097057141913446, 
       4.637777815141599}, {-4.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-4.097057141913446, 4.637777815141599}, {-4., 
       4.625}, {-4.084292589556064, 4.562500018967059}, {-4.097057141913446, 
       4.637777815141599}}], 
      PolygonBox[{{-3.999865158168957, 4.5625}, {-4.084292589556064, 
       4.562500018967059}, {-4., 4.625}, {-3.999865158168957, 4.5625}}], 
      PolygonBox[{{-4., 4.625}, {-3.902942858086555, 
       4.637777815141599}, {-3.999865158168957, 4.5625}, {-4., 4.625}}], 
      PolygonBox[{{-3.9157074104439467`, 
       4.562500018967059}, {-3.999865158168957, 4.5625}, {-3.902942858086555, 
       4.637777815141599}, {-3.9157074104439467`, 4.562500018967059}}], 
      PolygonBox[{{-3.902942858086555, 
       4.637777815141599}, {-3.8125000000000004`, 
       4.6752404735808355`}, {-3.9157074104439467`, 
       4.562500018967059}, {-3.902942858086555, 4.637777815141599}}], 
      PolygonBox[{{-3.769748357463745, 
       4.562655006646477}, {-3.9157074104439467`, 
       4.562500018967059}, {-3.8125000000000004`, 
       4.6752404735808355`}, {-3.769748357463745, 4.562655006646477}}], 
      PolygonBox[{{-3.8125000000000004`, 
       4.6752404735808355`}, {-3.7348349570550448`, 
       4.734834957055044}, {-3.769748357463745, 
       4.562655006646477}, {-3.8125000000000004`, 4.6752404735808355`}}], 
      PolygonBox[{{-3.595057255667003, 
       4.595057255667003}, {-3.769748357463745, 
       4.562655006646477}, {-3.7348349570550448`, 
       4.734834957055044}, {-3.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-3.7348349570550448`, 
       4.734834957055044}, {-3.7348349570550448`, 
       4.734834957055044}, {-3.595057255667003, 
       4.595057255667003}, {-3.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{-3.595057255667003, 
       4.595057255667003}, {-3.595057255667003, 
       4.595057255667003}, {-3.7348349570550448`, 
       4.734834957055044}, {-3.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-3.595057255667003, 
       4.595057255667003}, {-3.5626550066464766`, 4.769748357463745}, {-3.5, 
       4.5}, {-3.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-3.5, 4.642337217350632}, {-3.5, 
       4.5}, {-3.5626550066464766`, 4.769748357463745}, {-3.5, 
       4.642337217350632}}], 
      PolygonBox[{{-3.5626550066464766`, 
       4.769748357463745}, {-3.562500018967059, 4.915707410443938}, {-3.5, 
       4.642337217350632}, {-3.5626550066464766`, 4.769748357463745}}], 
      PolygonBox[{{-3.5, 4.79409099469826}, {-3.5, 
       4.642337217350632}, {-3.562500018967059, 4.915707410443938}, {-3.5, 
       4.79409099469826}}], 
      PolygonBox[{{-3.562500018967059, 4.915707410443938}, {-3.5625, 
       5.}, {-3.5, 4.79409099469826}, {-3.562500018967059, 
       4.915707410443938}}], 
      PolygonBox[{{-3.5, 5.}, {-3.5, 4.79409099469826}, {-3.5625, 5.}, {-3.5, 
       5.}}], PolygonBox[{{-3.5625, 5.}, {-3.562500018967059, 
       5.084292589556061}, {-3.5, 5.}, {-3.5625, 5.}}], 
      PolygonBox[{{-3.5, 5.20590900530174}, {-3.5, 5.}, {-3.562500018967059, 
       5.084292589556061}, {-3.5, 5.20590900530174}}], 
      PolygonBox[{{-3.562500018967059, 
       5.084292589556061}, {-3.5626550066464766`, 5.230251642536255}, {-3.5, 
       5.20590900530174}, {-3.562500018967059, 5.084292589556061}}], 
      PolygonBox[{{-3.5, 5.357662782649368}, {-3.5, 
       5.20590900530174}, {-3.5626550066464766`, 5.230251642536255}, {-3.5, 
       5.357662782649368}}], 
      PolygonBox[{{-3.5626550066464766`, 
       5.230251642536255}, {-3.595057255667003, 5.404942744332997}, {-3.5, 
       5.357662782649368}, {-3.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{-3.508553435038814, 5.491446564961186}, {-3.5, 
       5.357662782649368}, {-3.595057255667003, 
       5.404942744332997}, {-3.508553435038814, 5.491446564961186}}], 
      PolygonBox[{{-3.595057255667003, 
       5.404942744332997}, {-3.7697483574637447`, 
       5.437344993353523}, {-3.508553435038814, 
       5.491446564961186}, {-3.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{-3.642337217350632, 5.5}, {-3.508553435038814, 
       5.491446564961186}, {-3.7697483574637447`, 
       5.437344993353523}, {-3.642337217350632, 5.5}}], 
      PolygonBox[{{-3.7697483574637447`, 
       5.437344993353523}, {-3.9157074104439396`, 
       5.437499981032941}, {-3.642337217350632, 5.5}, {-3.7697483574637447`, 
       5.437344993353523}}], 
      PolygonBox[{{-3.7940909946267443`, 5.5}, {-3.642337217350632, 
       5.5}, {-3.9157074104439396`, 5.437499981032941}, {-3.7940909946267443`,
        5.5}}], 
      PolygonBox[{{-3.9157074104439396`, 
       5.437499981032941}, {-3.9998944727795123`, 
       5.4375}, {-3.7940909946267443`, 5.5}, {-3.9157074104439396`, 
       5.437499981032941}}], 
      PolygonBox[{{-3.92205804197311, 5.5}, {-3.7940909946267443`, 
       5.5}, {-3.9998944727795123`, 5.4375}, {-3.92205804197311, 5.5}}], 
      PolygonBox[{{-3.9998944727795123`, 5.4375}, {-4.084292589556057, 
       5.437499981032941}, {-3.92205804197311, 5.5}, {-3.9998944727795123`, 
       5.4375}}], 
      PolygonBox[{{-4.205909005304446, 5.5}, {-3.92205804197311, 
       5.5}, {-4.084292589556057, 5.437499981032941}, {-4.205909005304446, 
       5.5}}], PolygonBox[{{-4.084292589556057, 
       5.437499981032941}, {-4.230251642536255, 
       5.437344993353523}, {-4.205909005304446, 5.5}, {-4.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-4.357662782649366, 5.5}, {-4.205909005304446, 
       5.5}, {-4.230251642536255, 5.437344993353523}, {-4.357662782649366, 
       5.5}}], PolygonBox[{{-4.230251642536255, 
       5.437344993353523}, {-4.404942744332997, 
       5.404942744332997}, {-4.357662782649366, 5.5}, {-4.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{-3.5, 5.5}, {-4.357662782649366, 5.5}, {-4.404942744332997,
        5.404942744332997}, {-3.5, 5.5}}], 
      PolygonBox[{{-4.404942744332997, 
       5.404942744332997}, {-4.437344993353523, 5.230251642536255}, {-3.5, 
       5.5}, {-4.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-4.5, 5.357662782649369}, {-3.5, 5.5}, {-4.437344993353523,
        5.230251642536255}, {-4.5, 5.357662782649369}}], 
      PolygonBox[{{-4.437344993353523, 
       5.230251642536255}, {-4.437499981032941, 5.084292589556062}, {-4.5, 
       5.357662782649369}, {-4.437344993353523, 5.230251642536255}}], 
      PolygonBox[{{-4.5, 5.205909005282899}, {-4.5, 
       5.357662782649369}, {-4.437499981032941, 5.084292589556062}, {-4.5, 
       5.205909005282899}}], 
      PolygonBox[{{-4.437499981032941, 5.084292589556062}, {-4.4375, 
       5.000123178062996}, {-4.5, 5.205909005282899}, {-4.437499981032941, 
       5.084292589556062}}], 
      PolygonBox[{{-4.5, 5.0806786667587005`}, {-4.5, 
       5.205909005282899}, {-4.4375, 5.000123178062996}, {-4.5, 
       5.0806786667587005`}}], 
      PolygonBox[{{-4.4375, 5.000123178062996}, {-4.437499981032941, 
       4.915707410443945}, {-4.5, 5.0806786667587005`}, {-4.4375, 
       5.000123178062996}}], 
      PolygonBox[{{-4.5, 4.794090994854722}, {-4.5, 
       5.0806786667587005`}, {-4.437499981032941, 4.915707410443945}, {-4.5, 
       4.794090994854722}}], 
      PolygonBox[{{-4.437499981032941, 
       4.915707410443945}, {-4.437344993353523, 4.769748357463746}, {-4.5, 
       4.794090994854722}, {-4.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-4.5, 4.642337217350635}, {-4.5, 
       4.794090994854722}, {-4.437344993353523, 4.769748357463746}, {-4.5, 
       4.642337217350635}}], 
      PolygonBox[{{-4.437344993353523, 
       4.769748357463746}, {-4.404942744332997, 4.595057255667003}, {-4.5, 
       4.642337217350635}, {-4.437344993353523, 4.769748357463746}}], 
      PolygonBox[{{-4.5, 5.5}, {-4.5, 4.642337217350635}, {-4.404942744332997,
        4.595057255667003}, {-4.5, 5.5}}], 
      PolygonBox[{{-4.404942744332997, 
       4.595057255667003}, {-4.230251642536255, 4.562655006646477}, {-4.5, 
       5.5}, {-4.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-4.5, 4.5}, {-4.5, 5.5}, {-4.230251642536255, 
       4.562655006646477}, {-4.5, 4.5}}], 
      PolygonBox[{{-4.230251642536255, 
       4.562655006646477}, {-4.084292589556064, 4.562500018967059}, {-4.5, 
       4.5}, {-4.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-4.205909005566828, 4.5}, {-4.5, 4.5}, {-4.084292589556064,
        4.562500018967059}, {-4.205909005566828, 4.5}}], 
      PolygonBox[{{-4.084292589556064, 
       4.562500018967059}, {-3.999865158168957, 4.5625}, {-4.205909005566828, 
       4.5}, {-4.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-3.9176761295989384`, 4.5}, {-4.205909005566828, 
       4.5}, {-3.999865158168957, 4.5625}, {-3.9176761295989384`, 4.5}}], 
      PolygonBox[{{-3.999865158168957, 4.5625}, {-3.9157074104439467`, 
       4.562500018967059}, {-3.9176761295989384`, 4.5}, {-3.999865158168957, 
       4.5625}}], 
      PolygonBox[{{-3.7940909946396024`, 4.5}, {-3.9176761295989384`, 
       4.5}, {-3.9157074104439467`, 4.562500018967059}, {-3.7940909946396024`,
        4.5}}], 
      PolygonBox[{{-3.9157074104439467`, 
       4.562500018967059}, {-3.769748357463745, 
       4.562655006646477}, {-3.7940909946396024`, 4.5}, {-3.9157074104439467`,
        4.562500018967059}}], 
      PolygonBox[{{-3.642337217350629, 4.5}, {-3.7940909946396024`, 
       4.5}, {-3.769748357463745, 4.562655006646477}, {-3.642337217350629, 
       4.5}}], PolygonBox[{{-3.769748357463745, 
       4.562655006646477}, {-3.595057255667003, 
       4.595057255667003}, {-3.642337217350629, 4.5}, {-3.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{-3.5, 4.5}, {-3.642337217350629, 4.5}, {-3.595057255667003,
        4.595057255667003}, {-3.5, 4.5}}], 
      PolygonBox[{{-3.595057255667003, 
       4.595057255667003}, {-3.595057255667003, 4.595057255667003}, {-3.5, 
       4.5}, {-3.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-3.5, 4.5}, {-3.5, 4.5}, {-3.595057255667003, 
       4.595057255667003}, {-3.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, -5.}, {-3.4791666666666665`, -5.}, \
{-3.4583333333333335`, -5.}, {-3.4375, -5.}, {-3.4166666666666665`, -5.}, \
{-3.3958333333333335`, -5.}, {-3.375, -5.}, {-3.375, -5.}, \
{-3.3958333333333335`, -5.}, {-3.4166666666666665`, -5.}, {-3.4375, -5.}, \
{-3.4583333333333335`, -5.}, {-3.4791666666666665`, -5.}, {-3.5, -5.}, {-3.5, \
-5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, -5.}, {-2.6041666666666665`, -5.}, \
{-2.5833333333333335`, -5.}, {-2.5625, -5.}, {-2.5416666666666665`, -5.}, \
{-2.5208333333333335`, -5.}, {-2.5, -5.}, {-2.5, -5.}, {-2.5208333333333335`, \
-5.}, {-2.5416666666666665`, -5.}, {-2.5625, -5.}, {-2.5833333333333335`, \
-5.}, {-2.6041666666666665`, -5.}, {-2.625, -5.}, {-2.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -5.5}, {-3., -5.479166666666667}, {-3., \
-5.458333333333333}, {-3., -5.4375}, {-3., -5.416666666666667}, {-3., \
-5.395833333333333}, {-3., -5.375}, {-3., -5.375}, {-3., -5.395833333333333}, \
{-3., -5.416666666666667}, {-3., -5.4375}, {-3., -5.458333333333333}, {-3., \
-5.479166666666667}, {-3., -5.5}, {-3., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -4.625}, {-3., -4.604166666666667}, {-3., \
-4.583333333333333}, {-3., -4.5625}, {-3., -4.541666666666667}, {-3., \
-4.520833333333333}, {-3., -4.5}, {-3., -4.5}, {-3., -4.520833333333333}, \
{-3., -4.541666666666667}, {-3., -4.5625}, {-3., -4.583333333333333}, {-3., \
-4.604166666666667}, {-3., -4.625}, {-3., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, -5.}, {-3.25, -5.}, {-3.125, -5.}, {-3., -5.}, \
{-2.875, -5.}, {-2.75, -5.}, {-2.625, -5.}, {-2.625, -5.}, {-2.75, -5.}, \
{-2.875, -5.}, {-3., -5.}, {-3.125, -5.}, {-3.25, -5.}, {-3.375, -5.}, \
{-3.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -5.375}, {-3., -5.25}, {-3., -5.125}, {-3., -5.}, {-3., \
-4.875}, {-3., -4.75}, {-3., -4.625}, {-3., -4.625}, {-3., -4.75}, {-3., \
-4.875}, {-3., -5.}, {-3., -5.125}, {-3., -5.25}, {-3., -5.375}, {-3., \
-5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByC0yAExvUBHbSnWAzd7y3jnzhE+cGGHedWT
NKi8g/CBVKEUtY8PWA8YcRpNrvggBBFvYDuQcUfatmiz0IGN0m+lrCzZD3BP
X7FAtBcqz8ABVSd0wP+J0NOjxzhQ5Rs44fpnv519k0+eC26+gfuJVumZXHD7
X11ct+/KU64DN6Dug5jPDXc/TF69qPNTUrIIqv4DIgfmQM0/++1sTju/KNz+
GcpPDvX6iMLd9zUjPP5VkSia+0UPbIL6DybPCPU/TD8sfM5BzUcJvwOI8NWA
ug89/AHgso6d
      "]], LineBox[CompressedData["
1:eJyFkEEKgCAURCVMLFqpuWrTlYI6QNC6e+klPFrpR8Np4YAMDx46uJ73dnWM
seU9sSk8UKuwp/SFvYsRhakl+EPhpLsR/KnJ9M7HdK8G34BvwJ/Btz/21T4L
+7MvwReFj+p/ss+bXO/jsD/7BnwNvgJfhQdN1F6q
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, -5.265165042944956}, \
{-2.6752404735808355`, -5.1875}, {-2.595057255667003, -5.404942744332997}, \
{-2.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{-2.5626550066464766`, -5.230251642536255}, \
{-2.595057255667003, -5.404942744332997}, {-2.6752404735808355`, -5.1875}, \
{-2.5626550066464766`, -5.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, -5.1875}, {-2.6377778151415994`, \
-5.097057141913445}, {-2.5626550066464766`, -5.230251642536255}, \
{-2.6752404735808355`, -5.1875}}], 
      PolygonBox[{{-2.562500018967059, -5.084292589556062}, \
{-2.5626550066464766`, -5.230251642536255}, {-2.6377778151415994`, \
-5.097057141913445}, {-2.562500018967059, -5.084292589556062}}], 
      PolygonBox[{{-2.6377778151415994`, -5.097057141913445}, {-2.625, -5.}, \
{-2.562500018967059, -5.084292589556062}, {-2.6377778151415994`, \
-5.097057141913445}}], 
      PolygonBox[{{-2.5625, -5.}, {-2.562500018967059, -5.084292589556062}, \
{-2.625, -5.}, {-2.5625, -5.}}], 
      PolygonBox[{{-2.625, -5.}, {-2.6377778151415994`, -4.902942858086555}, \
{-2.5625, -5.}, {-2.625, -5.}}], 
      PolygonBox[{{-2.562500018967059, -4.915707410443939}, {-2.5625, -5.}, \
{-2.6377778151415994`, -4.902942858086555}, {-2.562500018967059, \
-4.915707410443939}}], 
      PolygonBox[{{-2.6377778151415994`, -4.902942858086555}, \
{-2.6752404735808355`, -4.8125}, {-2.562500018967059, -4.915707410443939}, \
{-2.6377778151415994`, -4.902942858086555}}], 
      PolygonBox[{{-2.5626550066464766`, -4.769748357463745}, \
{-2.562500018967059, -4.915707410443939}, {-2.6752404735808355`, -4.8125}, \
{-2.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{-2.6752404735808355`, -4.8125}, {-2.7348349570550448`, \
-4.734834957055044}, {-2.5626550066464766`, -4.769748357463745}, \
{-2.6752404735808355`, -4.8125}}], 
      PolygonBox[{{-2.595057255667003, -4.595057255667003}, \
{-2.5626550066464766`, -4.769748357463745}, {-2.7348349570550448`, \
-4.734834957055044}, {-2.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{-2.7348349570550448`, -4.734834957055044}, {-2.8125, \
-4.6752404735808355`}, {-2.595057255667003, -4.595057255667003}, \
{-2.7348349570550448`, -4.734834957055044}}], 
      PolygonBox[{{-2.7697483574637447`, -4.562655006646477}, \
{-2.595057255667003, -4.595057255667003}, {-2.8125, -4.6752404735808355`}, \
{-2.7697483574637447`, -4.562655006646477}}], 
      PolygonBox[{{-2.8125, -4.6752404735808355`}, {-2.9029428580865546`, \
-4.637777815141599}, {-2.7697483574637447`, -4.562655006646477}, {-2.8125, \
-4.6752404735808355`}}], 
      PolygonBox[{{-2.9157074104439396`, -4.562500018967059}, \
{-2.7697483574637447`, -4.562655006646477}, {-2.9029428580865546`, \
-4.637777815141599}, {-2.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-2.9029428580865546`, -4.637777815141599}, {-3., -4.625}, \
{-2.9157074104439396`, -4.562500018967059}, {-2.9029428580865546`, \
-4.637777815141599}}], 
      PolygonBox[{{-2.9998944727795123`, -4.5625}, {-2.9157074104439396`, \
-4.562500018967059}, {-3., -4.625}, {-2.9998944727795123`, -4.5625}}], 
      PolygonBox[{{-3., -4.625}, {-3.097057141913445, -4.637777815141599}, \
{-2.9998944727795123`, -4.5625}, {-3., -4.625}}], 
      PolygonBox[{{-3.084292589556057, -4.562500018967059}, \
{-2.9998944727795123`, -4.5625}, {-3.097057141913445, -4.637777815141599}, \
{-3.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-3.097057141913445, -4.637777815141599}, {-3.1875, \
-4.6752404735808355`}, {-3.084292589556057, -4.562500018967059}, \
{-3.097057141913445, -4.637777815141599}}], 
      PolygonBox[{{-3.230251642536255, -4.562655006646477}, \
{-3.084292589556057, -4.562500018967059}, {-3.1875, -4.6752404735808355`}, \
{-3.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-3.1875, -4.6752404735808355`}, {-3.2651650429449552`, \
-4.734834957055044}, {-3.230251642536255, -4.562655006646477}, {-3.1875, \
-4.6752404735808355`}}], 
      PolygonBox[{{-3.404942744332997, -4.595057255667003}, \
{-3.230251642536255, -4.562655006646477}, {-3.2651650429449552`, \
-4.734834957055044}, {-3.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{-3.2651650429449552`, -4.734834957055044}, \
{-3.3247595264191645`, -4.8125}, {-3.404942744332997, -4.595057255667003}, \
{-3.2651650429449552`, -4.734834957055044}}], 
      PolygonBox[{{-3.4373449933535234`, -4.769748357463745}, \
{-3.404942744332997, -4.595057255667003}, {-3.3247595264191645`, -4.8125}, \
{-3.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{-3.3247595264191645`, -4.8125}, {-3.3622221848584006`, \
-4.902942858086554}, {-3.4373449933535234`, -4.769748357463745}, \
{-3.3247595264191645`, -4.8125}}], 
      PolygonBox[{{-3.437499981032941, -4.915707410443938}, \
{-3.4373449933535234`, -4.769748357463745}, {-3.3622221848584006`, \
-4.902942858086554}, {-3.437499981032941, -4.915707410443938}}], 
      PolygonBox[{{-3.3622221848584006`, -4.902942858086554}, {-3.375, -5.}, \
{-3.437499981032941, -4.915707410443938}, {-3.3622221848584006`, \
-4.902942858086554}}], 
      PolygonBox[{{-3.4375, -4.999876821937004}, {-3.437499981032941, \
-4.915707410443938}, {-3.375, -5.}, {-3.4375, -4.999876821937004}}], 
      PolygonBox[{{-3.375, -5.}, {-3.3622221848584006`, -5.097057141913445}, \
{-3.4375, -4.999876821937004}, {-3.375, -5.}}], 
      PolygonBox[{{-3.437499981032941, -5.084292589556055}, {-3.4375, \
-4.999876821937004}, {-3.3622221848584006`, -5.097057141913445}, \
{-3.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-3.3622221848584006`, -5.097057141913445}, \
{-3.3247595264191645`, -5.1875}, {-3.437499981032941, -5.084292589556055}, \
{-3.3622221848584006`, -5.097057141913445}}], 
      PolygonBox[{{-3.4373449933535234`, -5.230251642536254}, \
{-3.437499981032941, -5.084292589556055}, {-3.3247595264191645`, -5.1875}, \
{-3.4373449933535234`, -5.230251642536254}}], 
      PolygonBox[{{-3.3247595264191645`, -5.1875}, {-3.2651650429449552`, \
-5.265165042944956}, {-3.4373449933535234`, -5.230251642536254}, \
{-3.3247595264191645`, -5.1875}}], 
      PolygonBox[{{-3.404942744332997, -5.404942744332997}, \
{-3.4373449933535234`, -5.230251642536254}, {-3.2651650429449552`, \
-5.265165042944956}, {-3.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, -5.265165042944956}, {-3.1875, \
-5.3247595264191645`}, {-3.404942744332997, -5.404942744332997}, \
{-3.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{-3.230251642536255, -5.437344993353523}, \
{-3.404942744332997, -5.404942744332997}, {-3.1875, -5.3247595264191645`}, \
{-3.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{-3.1875, -5.3247595264191645`}, {-3.0970571419134454`, \
-5.362222184858401}, {-3.230251642536255, -5.437344993353523}, {-3.1875, \
-5.3247595264191645`}}], 
      PolygonBox[{{-3.084292589556064, -5.437499981032941}, \
{-3.230251642536255, -5.437344993353523}, {-3.0970571419134454`, \
-5.362222184858401}, {-3.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-3.0970571419134454`, -5.362222184858401}, {-3., -5.375}, \
{-3.084292589556064, -5.437499981032941}, {-3.0970571419134454`, \
-5.362222184858401}}], 
      PolygonBox[{{-2.999865158168957, -5.4375}, {-3.084292589556064, \
-5.437499981032941}, {-3., -5.375}, {-2.999865158168957, -5.4375}}], 
      PolygonBox[{{-3., -5.375}, {-2.902942858086555, -5.362222184858401}, \
{-2.999865158168957, -5.4375}, {-3., -5.375}}], 
      PolygonBox[{{-2.9157074104439467`, -5.437499981032941}, \
{-2.999865158168957, -5.4375}, {-2.902942858086555, -5.362222184858401}, \
{-2.9157074104439467`, -5.437499981032941}}], 
      PolygonBox[{{-2.902942858086555, -5.362222184858401}, \
{-2.8125000000000004`, -5.3247595264191645`}, {-2.9157074104439467`, \
-5.437499981032941}, {-2.902942858086555, -5.362222184858401}}], 
      PolygonBox[{{-2.769748357463745, -5.437344993353523}, \
{-2.9157074104439467`, -5.437499981032941}, {-2.8125000000000004`, \
-5.3247595264191645`}, {-2.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{-2.8125000000000004`, -5.3247595264191645`}, \
{-2.7348349570550448`, -5.265165042944956}, {-2.769748357463745, \
-5.437344993353523}, {-2.8125000000000004`, -5.3247595264191645`}}], 
      PolygonBox[{{-2.595057255667003, -5.404942744332997}, \
{-2.769748357463745, -5.437344993353523}, {-2.7348349570550448`, \
-5.265165042944956}, {-2.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, -5.265165042944956}, \
{-2.7348349570550448`, -5.265165042944956}, {-2.595057255667003, \
-5.404942744332997}, {-2.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{-2.595057255667003, -5.404942744332997}, \
{-2.595057255667003, -5.404942744332997}, {-2.7348349570550448`, \
-5.265165042944956}, {-2.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-2.595057255667003, -5.404942744332997}, \
{-2.5626550066464766`, -5.230251642536255}, {-2.5, -5.5}, \
{-2.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{-2.5, -5.357662782649368}, {-2.5, -5.5}, \
{-2.5626550066464766`, -5.230251642536255}, {-2.5, -5.357662782649368}}], 
      PolygonBox[{{-2.5626550066464766`, -5.230251642536255}, \
{-2.562500018967059, -5.084292589556062}, {-2.5, -5.357662782649368}, \
{-2.5626550066464766`, -5.230251642536255}}], 
      PolygonBox[{{-2.5, -5.20590900530174}, {-2.5, -5.357662782649368}, \
{-2.562500018967059, -5.084292589556062}, {-2.5, -5.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, -5.084292589556062}, {-2.5625, -5.}, \
{-2.5, -5.20590900530174}, {-2.562500018967059, -5.084292589556062}}], 
      PolygonBox[{{-2.5, -5.}, {-2.5, -5.20590900530174}, {-2.5625, -5.}, \
{-2.5, -5.}}], 
      PolygonBox[{{-2.5625, -5.}, {-2.562500018967059, -4.915707410443939}, \
{-2.5, -5.}, {-2.5625, -5.}}], 
      PolygonBox[{{-2.5, -4.79409099469826}, {-2.5, -5.}, \
{-2.562500018967059, -4.915707410443939}, {-2.5, -4.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, -4.915707410443939}, \
{-2.5626550066464766`, -4.769748357463745}, {-2.5, -4.79409099469826}, \
{-2.562500018967059, -4.915707410443939}}], 
      PolygonBox[{{-2.5, -4.642337217350632}, {-2.5, -4.79409099469826}, \
{-2.5626550066464766`, -4.769748357463745}, {-2.5, -4.642337217350632}}], 
      PolygonBox[{{-2.5626550066464766`, -4.769748357463745}, \
{-2.595057255667003, -4.595057255667003}, {-2.5, -4.642337217350632}, \
{-2.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{-2.508553435038814, -4.508553435038814}, {-2.5, \
-4.642337217350632}, {-2.595057255667003, -4.595057255667003}, \
{-2.508553435038814, -4.508553435038814}}], 
      PolygonBox[{{-2.595057255667003, -4.595057255667003}, \
{-2.7697483574637447`, -4.562655006646477}, {-2.508553435038814, \
-4.508553435038814}, {-2.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{-2.642337217350632, -4.5}, {-2.508553435038814, \
-4.508553435038814}, {-2.7697483574637447`, -4.562655006646477}, \
{-2.642337217350632, -4.5}}], 
      PolygonBox[{{-2.7697483574637447`, -4.562655006646477}, \
{-2.9157074104439396`, -4.562500018967059}, {-2.642337217350632, -4.5}, \
{-2.7697483574637447`, -4.562655006646477}}], 
      PolygonBox[{{-2.7940909946267443`, -4.5}, {-2.642337217350632, -4.5}, \
{-2.9157074104439396`, -4.562500018967059}, {-2.7940909946267443`, -4.5}}], 
      PolygonBox[{{-2.9157074104439396`, -4.562500018967059}, \
{-2.9998944727795123`, -4.5625}, {-2.7940909946267443`, -4.5}, \
{-2.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-2.92205804197311, -4.5}, {-2.7940909946267443`, -4.5}, \
{-2.9998944727795123`, -4.5625}, {-2.92205804197311, -4.5}}], 
      PolygonBox[{{-2.9998944727795123`, -4.5625}, {-3.084292589556057, \
-4.562500018967059}, {-2.92205804197311, -4.5}, {-2.9998944727795123`, \
-4.5625}}], 
      PolygonBox[{{-3.2059090053044454`, -4.5}, {-2.92205804197311, -4.5}, \
{-3.084292589556057, -4.562500018967059}, {-3.2059090053044454`, -4.5}}], 
      PolygonBox[{{-3.084292589556057, -4.562500018967059}, \
{-3.230251642536255, -4.562655006646477}, {-3.2059090053044454`, -4.5}, \
{-3.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-3.357662782649366, -4.5}, {-3.2059090053044454`, -4.5}, \
{-3.230251642536255, -4.562655006646477}, {-3.357662782649366, -4.5}}], 
      PolygonBox[{{-3.230251642536255, -4.562655006646477}, \
{-3.404942744332997, -4.595057255667003}, {-3.357662782649366, -4.5}, \
{-3.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-2.5, -4.5}, {-3.357662782649366, -4.5}, \
{-3.404942744332997, -4.595057255667003}, {-2.5, -4.5}}], 
      PolygonBox[{{-3.404942744332997, -4.595057255667003}, \
{-3.4373449933535234`, -4.769748357463745}, {-2.5, -4.5}, \
{-3.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{-3.5, -4.642337217350631}, {-2.5, -4.5}, \
{-3.4373449933535234`, -4.769748357463745}, {-3.5, -4.642337217350631}}], 
      PolygonBox[{{-3.4373449933535234`, -4.769748357463745}, \
{-3.437499981032941, -4.915707410443938}, {-3.5, -4.642337217350631}, \
{-3.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{-3.5, -4.794090994717101}, {-3.5, -4.642337217350631}, \
{-3.437499981032941, -4.915707410443938}, {-3.5, -4.794090994717101}}], 
      PolygonBox[{{-3.437499981032941, -4.915707410443938}, {-3.4375, \
-4.999876821937004}, {-3.5, -4.794090994717101}, {-3.437499981032941, \
-4.915707410443938}}], 
      PolygonBox[{{-3.5, -4.9193213332412995`}, {-3.5, -4.794090994717101}, \
{-3.4375, -4.999876821937004}, {-3.5, -4.9193213332412995`}}], 
      PolygonBox[{{-3.4375, -4.999876821937004}, {-3.437499981032941, \
-5.084292589556055}, {-3.5, -4.9193213332412995`}, {-3.4375, \
-4.999876821937004}}], 
      PolygonBox[{{-3.5, -5.205909005145278}, {-3.5, -4.9193213332412995`}, \
{-3.437499981032941, -5.084292589556055}, {-3.5, -5.205909005145278}}], 
      PolygonBox[{{-3.437499981032941, -5.084292589556055}, \
{-3.4373449933535234`, -5.230251642536254}, {-3.5, -5.205909005145278}, \
{-3.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-3.5, -5.357662782649365}, {-3.5, -5.205909005145278}, \
{-3.4373449933535234`, -5.230251642536254}, {-3.5, -5.357662782649365}}], 
      PolygonBox[{{-3.4373449933535234`, -5.230251642536254}, \
{-3.404942744332997, -5.404942744332997}, {-3.5, -5.357662782649365}, \
{-3.4373449933535234`, -5.230251642536254}}], 
      PolygonBox[{{-3.5, -4.5}, {-3.5, -5.357662782649365}, \
{-3.404942744332997, -5.404942744332997}, {-3.5, -4.5}}], 
      PolygonBox[{{-3.404942744332997, -5.404942744332997}, \
{-3.230251642536255, -5.437344993353523}, {-3.5, -4.5}, {-3.404942744332997, \
-5.404942744332997}}], 
      PolygonBox[{{-3.5, -5.5}, {-3.5, -4.5}, {-3.230251642536255, \
-5.437344993353523}, {-3.5, -5.5}}], 
      PolygonBox[{{-3.230251642536255, -5.437344993353523}, \
{-3.084292589556064, -5.437499981032941}, {-3.5, -5.5}, {-3.230251642536255, \
-5.437344993353523}}], 
      PolygonBox[{{-3.205909005566828, -5.5}, {-3.5, -5.5}, \
{-3.084292589556064, -5.437499981032941}, {-3.205909005566828, -5.5}}], 
      PolygonBox[{{-3.084292589556064, -5.437499981032941}, \
{-2.999865158168957, -5.4375}, {-3.205909005566828, -5.5}, \
{-3.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-2.9176761295989384`, -5.5}, {-3.205909005566828, -5.5}, \
{-2.999865158168957, -5.4375}, {-2.9176761295989384`, -5.5}}], 
      PolygonBox[{{-2.999865158168957, -5.4375}, {-2.9157074104439467`, \
-5.437499981032941}, {-2.9176761295989384`, -5.5}, {-2.999865158168957, \
-5.4375}}], 
      PolygonBox[{{-2.7940909946396024`, -5.5}, {-2.9176761295989384`, -5.5}, \
{-2.9157074104439467`, -5.437499981032941}, {-2.7940909946396024`, -5.5}}], 
      PolygonBox[{{-2.9157074104439467`, -5.437499981032941}, \
{-2.769748357463745, -5.437344993353523}, {-2.7940909946396024`, -5.5}, \
{-2.9157074104439467`, -5.437499981032941}}], 
      PolygonBox[{{-2.642337217350629, -5.5}, {-2.7940909946396024`, -5.5}, \
{-2.769748357463745, -5.437344993353523}, {-2.642337217350629, -5.5}}], 
      PolygonBox[{{-2.769748357463745, -5.437344993353523}, \
{-2.595057255667003, -5.404942744332997}, {-2.642337217350629, -5.5}, \
{-2.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{-2.5, -5.5}, {-2.642337217350629, -5.5}, \
{-2.595057255667003, -5.404942744332997}, {-2.5, -5.5}}], 
      PolygonBox[{{-2.595057255667003, -5.404942744332997}, \
{-2.595057255667003, -5.404942744332997}, {-2.5, -5.5}, {-2.595057255667003, \
-5.404942744332997}}], 
      PolygonBox[{{-2.5, -5.5}, {-2.5, -5.5}, {-2.595057255667003, \
-5.404942744332997}, {-2.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, -4.}, {-3.4791666666666665`, -4.}, \
{-3.4583333333333335`, -4.}, {-3.4375, -4.}, {-3.4166666666666665`, -4.}, \
{-3.3958333333333335`, -4.}, {-3.375, -4.}, {-3.375, -4.}, \
{-3.3958333333333335`, -4.}, {-3.4166666666666665`, -4.}, {-3.4375, -4.}, \
{-3.4583333333333335`, -4.}, {-3.4791666666666665`, -4.}, {-3.5, -4.}, {-3.5, \
-4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, -4.}, {-2.6041666666666665`, -4.}, \
{-2.5833333333333335`, -4.}, {-2.5625, -4.}, {-2.5416666666666665`, -4.}, \
{-2.5208333333333335`, -4.}, {-2.5, -4.}, {-2.5, -4.}, {-2.5208333333333335`, \
-4.}, {-2.5416666666666665`, -4.}, {-2.5625, -4.}, {-2.5833333333333335`, \
-4.}, {-2.6041666666666665`, -4.}, {-2.625, -4.}, {-2.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -4.5}, {-3., -4.479166666666667}, {-3., \
-4.458333333333333}, {-3., -4.4375}, {-3., -4.416666666666667}, {-3., \
-4.395833333333333}, {-3., -4.375}, {-3., -4.375}, {-3., -4.395833333333333}, \
{-3., -4.416666666666667}, {-3., -4.4375}, {-3., -4.458333333333333}, {-3., \
-4.479166666666667}, {-3., -4.5}, {-3., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -3.625}, {-3., -3.6041666666666665`}, {-3., \
-3.5833333333333335`}, {-3., -3.5625}, {-3., -3.5416666666666665`}, {-3., \
-3.5208333333333335`}, {-3., -3.5}, {-3., -3.5}, {-3., -3.5208333333333335`}, \
{-3., -3.5416666666666665`}, {-3., -3.5625}, {-3., -3.5833333333333335`}, \
{-3., -3.6041666666666665`}, {-3., -3.625}, {-3., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, -4.}, {-3.25, -4.}, {-3.125, -4.}, {-3., -4.}, \
{-2.875, -4.}, {-2.75, -4.}, {-2.625, -4.}, {-2.625, -4.}, {-2.75, -4.}, \
{-2.875, -4.}, {-3., -4.}, {-3.125, -4.}, {-3.25, -4.}, {-3.375, -4.}, \
{-3.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -4.375}, {-3., -4.25}, {-3., -4.125}, {-3., -4.}, {-3., \
-3.875}, {-3., -3.75}, {-3., -3.625}, {-3., -3.625}, {-3., -3.75}, {-3., \
-3.875}, {-3., -4.}, {-3., -4.125}, {-3., -4.25}, {-3., -4.375}, {-3., \
-4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByC0wAExvUBHbSnWAxul30pZWfIfuLDDvOpJ
GlS+ge9AqlCK2scHrFCaFyrOBlXHC9XHDjUHKs/AAaV5D/g/EXp69BgHqnwD
J1z/7Lezb/LJc8HNN3A/0So9kwtu/6uL6/ZdecoFdx/EXG64+2Hy6kWdn5KS
BVD1HxA4MAdq/tlvZ3Pa+QXh9s9QfnKo10cQ7r6vGeHxr4oEUd3fIHhgE9R/
MHlGqP9h+mHhcw5qPkr4HUCErwbUfejhDwD5YYvv
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByA0z4FQMGCF81evAgE2OB9Cc6Cp54TzwcpX
caGpJ0xDzOFFs5cPTZ0AmrwAmn5BNPVCGPzVKO4TQnM/TD0Hmno2OD8MJXxg
6lkI8lHdx4Lmfph6ATR5Pjg/DCV8EPEFANRRXiU=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, -4.265165042944956}, \
{-2.6752404735808355`, -4.1875}, {-2.595057255667003, -4.404942744332997}, \
{-2.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{-2.5626550066464766`, -4.230251642536255}, \
{-2.595057255667003, -4.404942744332997}, {-2.6752404735808355`, -4.1875}, \
{-2.5626550066464766`, -4.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, -4.1875}, {-2.6377778151415994`, \
-4.097057141913445}, {-2.5626550066464766`, -4.230251642536255}, \
{-2.6752404735808355`, -4.1875}}], 
      PolygonBox[{{-2.562500018967059, -4.084292589556062}, \
{-2.5626550066464766`, -4.230251642536255}, {-2.6377778151415994`, \
-4.097057141913445}, {-2.562500018967059, -4.084292589556062}}], 
      PolygonBox[{{-2.6377778151415994`, -4.097057141913445}, {-2.625, -4.}, \
{-2.562500018967059, -4.084292589556062}, {-2.6377778151415994`, \
-4.097057141913445}}], 
      PolygonBox[{{-2.5625, -4.}, {-2.562500018967059, -4.084292589556062}, \
{-2.625, -4.}, {-2.5625, -4.}}], 
      PolygonBox[{{-2.625, -4.}, {-2.6377778151415994`, \
-3.9029428580865546`}, {-2.5625, -4.}, {-2.625, -4.}}], 
      PolygonBox[{{-2.562500018967059, -3.915707410443938}, {-2.5625, -4.}, \
{-2.6377778151415994`, -3.9029428580865546`}, {-2.562500018967059, \
-3.915707410443938}}], 
      PolygonBox[{{-2.6377778151415994`, -3.9029428580865546`}, \
{-2.6752404735808355`, -3.8125}, {-2.562500018967059, -3.915707410443938}, \
{-2.6377778151415994`, -3.9029428580865546`}}], 
      PolygonBox[{{-2.5626550066464766`, -3.769748357463745}, \
{-2.562500018967059, -3.915707410443938}, {-2.6752404735808355`, -3.8125}, \
{-2.5626550066464766`, -3.769748357463745}}], 
      PolygonBox[{{-2.6752404735808355`, -3.8125}, {-2.7348349570550448`, \
-3.7348349570550448`}, {-2.5626550066464766`, -3.769748357463745}, \
{-2.6752404735808355`, -3.8125}}], 
      PolygonBox[{{-2.595057255667003, -3.595057255667003}, \
{-2.5626550066464766`, -3.769748357463745}, {-2.7348349570550448`, \
-3.7348349570550448`}, {-2.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{-2.7348349570550448`, -3.7348349570550448`}, {-2.8125, \
-3.6752404735808355`}, {-2.595057255667003, -3.595057255667003}, \
{-2.7348349570550448`, -3.7348349570550448`}}], 
      PolygonBox[{{-2.7697483574637447`, -3.5626550066464766`}, \
{-2.595057255667003, -3.595057255667003}, {-2.8125, -3.6752404735808355`}, \
{-2.7697483574637447`, -3.5626550066464766`}}], 
      PolygonBox[{{-2.8125, -3.6752404735808355`}, {-2.9029428580865546`, \
-3.6377778151415994`}, {-2.7697483574637447`, -3.5626550066464766`}, \
{-2.8125, -3.6752404735808355`}}], 
      PolygonBox[{{-2.9157074104439396`, -3.562500018967059}, \
{-2.7697483574637447`, -3.5626550066464766`}, {-2.9029428580865546`, \
-3.6377778151415994`}, {-2.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-2.9029428580865546`, -3.6377778151415994`}, {-3., \
-3.625}, {-2.9157074104439396`, -3.562500018967059}, {-2.9029428580865546`, \
-3.6377778151415994`}}], 
      PolygonBox[{{-2.9998944727795123`, -3.5625}, {-2.9157074104439396`, \
-3.562500018967059}, {-3., -3.625}, {-2.9998944727795123`, -3.5625}}], 
      PolygonBox[{{-3., -3.625}, {-3.097057141913445, -3.6377778151415994`}, \
{-2.9998944727795123`, -3.5625}, {-3., -3.625}}], 
      PolygonBox[{{-3.084292589556057, -3.562500018967059}, \
{-2.9998944727795123`, -3.5625}, {-3.097057141913445, -3.6377778151415994`}, \
{-3.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-3.097057141913445, -3.6377778151415994`}, {-3.1875, \
-3.6752404735808355`}, {-3.084292589556057, -3.562500018967059}, \
{-3.097057141913445, -3.6377778151415994`}}], 
      PolygonBox[{{-3.230251642536255, -3.5626550066464766`}, \
{-3.084292589556057, -3.562500018967059}, {-3.1875, -3.6752404735808355`}, \
{-3.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-3.1875, -3.6752404735808355`}, {-3.2651650429449552`, \
-3.7348349570550448`}, {-3.230251642536255, -3.5626550066464766`}, {-3.1875, \
-3.6752404735808355`}}], 
      PolygonBox[{{-3.404942744332997, -3.595057255667003}, \
{-3.230251642536255, -3.5626550066464766`}, {-3.2651650429449552`, \
-3.7348349570550448`}, {-3.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-3.2651650429449552`, -3.7348349570550448`}, \
{-3.3247595264191645`, -3.8125}, {-3.404942744332997, -3.595057255667003}, \
{-3.2651650429449552`, -3.7348349570550448`}}], 
      PolygonBox[{{-3.4373449933535234`, -3.7697483574637447`}, \
{-3.404942744332997, -3.595057255667003}, {-3.3247595264191645`, -3.8125}, \
{-3.4373449933535234`, -3.7697483574637447`}}], 
      PolygonBox[{{-3.3247595264191645`, -3.8125}, {-3.3622221848584006`, \
-3.9029428580865546`}, {-3.4373449933535234`, -3.7697483574637447`}, \
{-3.3247595264191645`, -3.8125}}], 
      PolygonBox[{{-3.437499981032941, -3.9157074104439378`}, \
{-3.4373449933535234`, -3.7697483574637447`}, {-3.3622221848584006`, \
-3.9029428580865546`}, {-3.437499981032941, -3.9157074104439378`}}], 
      PolygonBox[{{-3.3622221848584006`, -3.9029428580865546`}, {-3.375, \
-4.}, {-3.437499981032941, -3.9157074104439378`}, {-3.3622221848584006`, \
-3.9029428580865546`}}], 
      PolygonBox[{{-3.4375, -3.9998768219370047`}, {-3.437499981032941, \
-3.9157074104439378`}, {-3.375, -4.}, {-3.4375, -3.9998768219370047`}}], 
      PolygonBox[{{-3.375, -4.}, {-3.3622221848584006`, -4.097057141913445}, \
{-3.4375, -3.9998768219370047`}, {-3.375, -4.}}], 
      PolygonBox[{{-3.437499981032941, -4.084292589556055}, {-3.4375, \
-3.9998768219370047`}, {-3.3622221848584006`, -4.097057141913445}, \
{-3.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-3.3622221848584006`, -4.097057141913445}, \
{-3.3247595264191645`, -4.1875}, {-3.437499981032941, -4.084292589556055}, \
{-3.3622221848584006`, -4.097057141913445}}], 
      PolygonBox[{{-3.4373449933535234`, -4.230251642536254}, \
{-3.437499981032941, -4.084292589556055}, {-3.3247595264191645`, -4.1875}, \
{-3.4373449933535234`, -4.230251642536254}}], 
      PolygonBox[{{-3.3247595264191645`, -4.1875}, {-3.2651650429449552`, \
-4.265165042944956}, {-3.4373449933535234`, -4.230251642536254}, \
{-3.3247595264191645`, -4.1875}}], 
      PolygonBox[{{-3.404942744332997, -4.404942744332997}, \
{-3.4373449933535234`, -4.230251642536254}, {-3.2651650429449552`, \
-4.265165042944956}, {-3.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, -4.265165042944956}, {-3.1875, \
-4.3247595264191645`}, {-3.404942744332997, -4.404942744332997}, \
{-3.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{-3.230251642536255, -4.437344993353523}, \
{-3.404942744332997, -4.404942744332997}, {-3.1875, -4.3247595264191645`}, \
{-3.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{-3.1875, -4.3247595264191645`}, {-3.0970571419134454`, \
-4.362222184858401}, {-3.230251642536255, -4.437344993353523}, {-3.1875, \
-4.3247595264191645`}}], 
      PolygonBox[{{-3.084292589556064, -4.437499981032941}, \
{-3.230251642536255, -4.437344993353523}, {-3.0970571419134454`, \
-4.362222184858401}, {-3.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-3.0970571419134454`, -4.362222184858401}, {-3., -4.375}, \
{-3.084292589556064, -4.437499981032941}, {-3.0970571419134454`, \
-4.362222184858401}}], 
      PolygonBox[{{-2.999865158168957, -4.4375}, {-3.084292589556064, \
-4.437499981032941}, {-3., -4.375}, {-2.999865158168957, -4.4375}}], 
      PolygonBox[{{-3., -4.375}, {-2.902942858086555, -4.362222184858401}, \
{-2.999865158168957, -4.4375}, {-3., -4.375}}], 
      PolygonBox[{{-2.9157074104439467`, -4.437499981032941}, \
{-2.999865158168957, -4.4375}, {-2.902942858086555, -4.362222184858401}, \
{-2.9157074104439467`, -4.437499981032941}}], 
      PolygonBox[{{-2.902942858086555, -4.362222184858401}, \
{-2.8125000000000004`, -4.3247595264191645`}, {-2.9157074104439467`, \
-4.437499981032941}, {-2.902942858086555, -4.362222184858401}}], 
      PolygonBox[{{-2.769748357463745, -4.437344993353523}, \
{-2.9157074104439467`, -4.437499981032941}, {-2.8125000000000004`, \
-4.3247595264191645`}, {-2.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{-2.8125000000000004`, -4.3247595264191645`}, \
{-2.7348349570550448`, -4.265165042944956}, {-2.769748357463745, \
-4.437344993353523}, {-2.8125000000000004`, -4.3247595264191645`}}], 
      PolygonBox[{{-2.595057255667003, -4.404942744332997}, \
{-2.769748357463745, -4.437344993353523}, {-2.7348349570550448`, \
-4.265165042944956}, {-2.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, -4.265165042944956}, \
{-2.7348349570550448`, -4.265165042944956}, {-2.595057255667003, \
-4.404942744332997}, {-2.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{-2.595057255667003, -4.404942744332997}, \
{-2.595057255667003, -4.404942744332997}, {-2.7348349570550448`, \
-4.265165042944956}, {-2.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-2.595057255667003, -4.404942744332997}, \
{-2.5626550066464766`, -4.230251642536255}, {-2.5, -4.5}, \
{-2.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{-2.5, -4.357662782649368}, {-2.5, -4.5}, \
{-2.5626550066464766`, -4.230251642536255}, {-2.5, -4.357662782649368}}], 
      PolygonBox[{{-2.5626550066464766`, -4.230251642536255}, \
{-2.562500018967059, -4.084292589556062}, {-2.5, -4.357662782649368}, \
{-2.5626550066464766`, -4.230251642536255}}], 
      PolygonBox[{{-2.5, -4.20590900530174}, {-2.5, -4.357662782649368}, \
{-2.562500018967059, -4.084292589556062}, {-2.5, -4.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, -4.084292589556062}, {-2.5625, -4.}, \
{-2.5, -4.20590900530174}, {-2.562500018967059, -4.084292589556062}}], 
      PolygonBox[{{-2.5, -4.}, {-2.5, -4.20590900530174}, {-2.5625, -4.}, \
{-2.5, -4.}}], 
      PolygonBox[{{-2.5625, -4.}, {-2.562500018967059, -3.915707410443938}, \
{-2.5, -4.}, {-2.5625, -4.}}], 
      PolygonBox[{{-2.5, -3.79409099469826}, {-2.5, -4.}, \
{-2.562500018967059, -3.915707410443938}, {-2.5, -3.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, -3.915707410443938}, \
{-2.5626550066464766`, -3.769748357463745}, {-2.5, -3.79409099469826}, \
{-2.562500018967059, -3.915707410443938}}], 
      PolygonBox[{{-2.5, -3.6423372173506325`}, {-2.5, -3.79409099469826}, \
{-2.5626550066464766`, -3.769748357463745}, {-2.5, -3.6423372173506325`}}], 
      PolygonBox[{{-2.5626550066464766`, -3.769748357463745}, \
{-2.595057255667003, -3.595057255667003}, {-2.5, -3.6423372173506325`}, \
{-2.5626550066464766`, -3.769748357463745}}], 
      PolygonBox[{{-2.508553435038814, -3.508553435038814}, {-2.5, \
-3.6423372173506325`}, {-2.595057255667003, -3.595057255667003}, \
{-2.508553435038814, -3.508553435038814}}], 
      PolygonBox[{{-2.595057255667003, -3.595057255667003}, \
{-2.7697483574637447`, -3.5626550066464766`}, {-2.508553435038814, \
-3.508553435038814}, {-2.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{-2.642337217350632, -3.5}, {-2.508553435038814, \
-3.508553435038814}, {-2.7697483574637447`, -3.5626550066464766`}, \
{-2.642337217350632, -3.5}}], 
      PolygonBox[{{-2.7697483574637447`, -3.5626550066464766`}, \
{-2.9157074104439396`, -3.562500018967059}, {-2.642337217350632, -3.5}, \
{-2.7697483574637447`, -3.5626550066464766`}}], 
      PolygonBox[{{-2.7940909946267443`, -3.5}, {-2.642337217350632, -3.5}, \
{-2.9157074104439396`, -3.562500018967059}, {-2.7940909946267443`, -3.5}}], 
      PolygonBox[{{-2.9157074104439396`, -3.562500018967059}, \
{-2.9998944727795123`, -3.5625}, {-2.7940909946267443`, -3.5}, \
{-2.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-2.92205804197311, -3.5}, {-2.7940909946267443`, -3.5}, \
{-2.9998944727795123`, -3.5625}, {-2.92205804197311, -3.5}}], 
      PolygonBox[{{-2.9998944727795123`, -3.5625}, {-3.084292589556057, \
-3.562500018967059}, {-2.92205804197311, -3.5}, {-2.9998944727795123`, \
-3.5625}}], 
      PolygonBox[{{-3.2059090053044454`, -3.5}, {-2.92205804197311, -3.5}, \
{-3.084292589556057, -3.562500018967059}, {-3.2059090053044454`, -3.5}}], 
      PolygonBox[{{-3.084292589556057, -3.562500018967059}, \
{-3.230251642536255, -3.5626550066464766`}, {-3.2059090053044454`, -3.5}, \
{-3.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-3.357662782649366, -3.5}, {-3.2059090053044454`, -3.5}, \
{-3.230251642536255, -3.5626550066464766`}, {-3.357662782649366, -3.5}}], 
      PolygonBox[{{-3.230251642536255, -3.5626550066464766`}, \
{-3.404942744332997, -3.595057255667003}, {-3.357662782649366, -3.5}, \
{-3.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-2.5, -3.5}, {-3.357662782649366, -3.5}, \
{-3.404942744332997, -3.595057255667003}, {-2.5, -3.5}}], 
      PolygonBox[{{-3.404942744332997, -3.595057255667003}, \
{-3.4373449933535234`, -3.7697483574637447`}, {-2.5, -3.5}, \
{-3.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-3.5, -3.642337217350631}, {-2.5, -3.5}, \
{-3.4373449933535234`, -3.7697483574637447`}, {-3.5, -3.642337217350631}}], 
      PolygonBox[{{-3.4373449933535234`, -3.7697483574637447`}, \
{-3.437499981032941, -3.9157074104439378`}, {-3.5, -3.642337217350631}, \
{-3.4373449933535234`, -3.7697483574637447`}}], 
      PolygonBox[{{-3.5, -3.794090994717101}, {-3.5, -3.642337217350631}, \
{-3.437499981032941, -3.9157074104439378`}, {-3.5, -3.794090994717101}}], 
      PolygonBox[{{-3.437499981032941, -3.9157074104439378`}, {-3.4375, \
-3.9998768219370047`}, {-3.5, -3.794090994717101}, {-3.437499981032941, \
-3.9157074104439378`}}], 
      PolygonBox[{{-3.5, -3.9193213332413}, {-3.5, -3.794090994717101}, \
{-3.4375, -3.9998768219370047`}, {-3.5, -3.9193213332413}}], 
      PolygonBox[{{-3.4375, -3.9998768219370047`}, {-3.437499981032941, \
-4.084292589556055}, {-3.5, -3.9193213332413}, {-3.4375, \
-3.9998768219370047`}}], 
      PolygonBox[{{-3.5, -4.205909005145278}, {-3.5, -3.9193213332413}, \
{-3.437499981032941, -4.084292589556055}, {-3.5, -4.205909005145278}}], 
      PolygonBox[{{-3.437499981032941, -4.084292589556055}, \
{-3.4373449933535234`, -4.230251642536254}, {-3.5, -4.205909005145278}, \
{-3.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-3.5, -4.357662782649365}, {-3.5, -4.205909005145278}, \
{-3.4373449933535234`, -4.230251642536254}, {-3.5, -4.357662782649365}}], 
      PolygonBox[{{-3.4373449933535234`, -4.230251642536254}, \
{-3.404942744332997, -4.404942744332997}, {-3.5, -4.357662782649365}, \
{-3.4373449933535234`, -4.230251642536254}}], 
      PolygonBox[{{-3.5, -3.5}, {-3.5, -4.357662782649365}, \
{-3.404942744332997, -4.404942744332997}, {-3.5, -3.5}}], 
      PolygonBox[{{-3.404942744332997, -4.404942744332997}, \
{-3.230251642536255, -4.437344993353523}, {-3.5, -3.5}, {-3.404942744332997, \
-4.404942744332997}}], 
      PolygonBox[{{-3.5, -4.5}, {-3.5, -3.5}, {-3.230251642536255, \
-4.437344993353523}, {-3.5, -4.5}}], 
      PolygonBox[{{-3.230251642536255, -4.437344993353523}, \
{-3.084292589556064, -4.437499981032941}, {-3.5, -4.5}, {-3.230251642536255, \
-4.437344993353523}}], 
      PolygonBox[{{-3.205909005566828, -4.5}, {-3.5, -4.5}, \
{-3.084292589556064, -4.437499981032941}, {-3.205909005566828, -4.5}}], 
      PolygonBox[{{-3.084292589556064, -4.437499981032941}, \
{-2.999865158168957, -4.4375}, {-3.205909005566828, -4.5}, \
{-3.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-2.9176761295989384`, -4.5}, {-3.205909005566828, -4.5}, \
{-2.999865158168957, -4.4375}, {-2.9176761295989384`, -4.5}}], 
      PolygonBox[{{-2.999865158168957, -4.4375}, {-2.9157074104439467`, \
-4.437499981032941}, {-2.9176761295989384`, -4.5}, {-2.999865158168957, \
-4.4375}}], 
      PolygonBox[{{-2.7940909946396024`, -4.5}, {-2.9176761295989384`, -4.5}, \
{-2.9157074104439467`, -4.437499981032941}, {-2.7940909946396024`, -4.5}}], 
      PolygonBox[{{-2.9157074104439467`, -4.437499981032941}, \
{-2.769748357463745, -4.437344993353523}, {-2.7940909946396024`, -4.5}, \
{-2.9157074104439467`, -4.437499981032941}}], 
      PolygonBox[{{-2.642337217350629, -4.5}, {-2.7940909946396024`, -4.5}, \
{-2.769748357463745, -4.437344993353523}, {-2.642337217350629, -4.5}}], 
      PolygonBox[{{-2.769748357463745, -4.437344993353523}, \
{-2.595057255667003, -4.404942744332997}, {-2.642337217350629, -4.5}, \
{-2.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{-2.5, -4.5}, {-2.642337217350629, -4.5}, \
{-2.595057255667003, -4.404942744332997}, {-2.5, -4.5}}], 
      PolygonBox[{{-2.595057255667003, -4.404942744332997}, \
{-2.595057255667003, -4.404942744332997}, {-2.5, -4.5}, {-2.595057255667003, \
-4.404942744332997}}], 
      PolygonBox[{{-2.5, -4.5}, {-2.5, -4.5}, {-2.595057255667003, \
-4.404942744332997}, {-2.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, -3.}, {-3.4791666666666665`, -3.}, \
{-3.4583333333333335`, -3.}, {-3.4375, -3.}, {-3.4166666666666665`, -3.}, \
{-3.3958333333333335`, -3.}, {-3.375, -3.}, {-3.375, -3.}, \
{-3.3958333333333335`, -3.}, {-3.4166666666666665`, -3.}, {-3.4375, -3.}, \
{-3.4583333333333335`, -3.}, {-3.4791666666666665`, -3.}, {-3.5, -3.}, {-3.5, \
-3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, -3.}, {-2.6041666666666665`, -3.}, \
{-2.5833333333333335`, -3.}, {-2.5625, -3.}, {-2.5416666666666665`, -3.}, \
{-2.5208333333333335`, -3.}, {-2.5, -3.}, {-2.5, -3.}, {-2.5208333333333335`, \
-3.}, {-2.5416666666666665`, -3.}, {-2.5625, -3.}, {-2.5833333333333335`, \
-3.}, {-2.6041666666666665`, -3.}, {-2.625, -3.}, {-2.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -3.5}, {-3., -3.4791666666666665`}, {-3., \
-3.4583333333333335`}, {-3., -3.4375}, {-3., -3.4166666666666665`}, {-3., \
-3.3958333333333335`}, {-3., -3.375}, {-3., -3.375}, {-3., \
-3.3958333333333335`}, {-3., -3.4166666666666665`}, {-3., -3.4375}, {-3., \
-3.4583333333333335`}, {-3., -3.4791666666666665`}, {-3., -3.5}, {-3., \
-3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -2.625}, {-3., -2.6041666666666665`}, {-3., \
-2.5833333333333335`}, {-3., -2.5625}, {-3., -2.5416666666666665`}, {-3., \
-2.5208333333333335`}, {-3., -2.5}, {-3., -2.5}, {-3., -2.5208333333333335`}, \
{-3., -2.5416666666666665`}, {-3., -2.5625}, {-3., -2.5833333333333335`}, \
{-3., -2.6041666666666665`}, {-3., -2.625}, {-3., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, -3.}, {-3.25, -3.}, {-3.125, -3.}, {-3., -3.}, \
{-2.875, -3.}, {-2.75, -3.}, {-2.625, -3.}, {-2.625, -3.}, {-2.75, -3.}, \
{-2.875, -3.}, {-3., -3.}, {-3.125, -3.}, {-3.25, -3.}, {-3.375, -3.}, \
{-3.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -3.375}, {-3., -3.25}, {-3., -3.125}, {-3., -3.}, {-3., \
-2.875}, {-3., -2.75}, {-3., -2.625}, {-3., -2.625}, {-3., -2.75}, {-3., \
-2.875}, {-3., -3.}, {-3., -3.125}, {-3., -3.25}, {-3., -3.375}, {-3., \
-3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByA0xwExvUBHbSnWAxul30pZWbIfuLDDvOpJ
GlS+ge1AqlCK2scHrHAaJg5TB9MHMwdmLswe/ydCT48e40CVb+CE65/9dvZN
PnkuuPkG7idapWdywe15dXHdvitPueD2QMzlhtsDk/eD2oOqn/PAHKj5MHtg
4jB1MPfBzEF1P/eBTVB7YfKMUHfB9MPcDTMfNfw44f6G2YMe/gDi74xy
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsB2B0KBiwwvmrV4EA2wFUdRxo6jnhfLDyVVxo
6nkI8lHt5UGzF6aeA009J5yPai8PTno1mjp0c9DtQXdHGJo7ifXnarRwQQ83
VHsxwz0MLV5gNAAihV1a
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, -3.2651650429449552`}, \
{-2.6752404735808355`, -3.1875}, {-2.595057255667003, -3.404942744332997}, \
{-2.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{-2.5626550066464766`, -3.2302516425362553`}, \
{-2.595057255667003, -3.404942744332997}, {-2.6752404735808355`, -3.1875}, \
{-2.5626550066464766`, -3.2302516425362553`}}], 
      PolygonBox[{{-2.6752404735808355`, -3.1875}, {-2.6377778151415994`, \
-3.0970571419134454`}, {-2.5626550066464766`, -3.2302516425362553`}, \
{-2.6752404735808355`, -3.1875}}], 
      PolygonBox[{{-2.562500018967059, -3.084292589556062}, \
{-2.5626550066464766`, -3.2302516425362553`}, {-2.6377778151415994`, \
-3.0970571419134454`}, {-2.562500018967059, -3.084292589556062}}], 
      PolygonBox[{{-2.6377778151415994`, -3.0970571419134454`}, {-2.625, \
-3.}, {-2.562500018967059, -3.084292589556062}, {-2.6377778151415994`, \
-3.0970571419134454`}}], 
      PolygonBox[{{-2.5625, -3.}, {-2.562500018967059, -3.084292589556062}, \
{-2.625, -3.}, {-2.5625, -3.}}], 
      PolygonBox[{{-2.625, -3.}, {-2.6377778151415994`, \
-2.9029428580865546`}, {-2.5625, -3.}, {-2.625, -3.}}], 
      PolygonBox[{{-2.562500018967059, -2.915707410443938}, {-2.5625, -3.}, \
{-2.6377778151415994`, -2.9029428580865546`}, {-2.562500018967059, \
-2.915707410443938}}], 
      PolygonBox[{{-2.6377778151415994`, -2.9029428580865546`}, \
{-2.6752404735808355`, -2.8125}, {-2.562500018967059, -2.915707410443938}, \
{-2.6377778151415994`, -2.9029428580865546`}}], 
      PolygonBox[{{-2.5626550066464766`, -2.769748357463745}, \
{-2.562500018967059, -2.915707410443938}, {-2.6752404735808355`, -2.8125}, \
{-2.5626550066464766`, -2.769748357463745}}], 
      PolygonBox[{{-2.6752404735808355`, -2.8125}, {-2.7348349570550448`, \
-2.7348349570550448`}, {-2.5626550066464766`, -2.769748357463745}, \
{-2.6752404735808355`, -2.8125}}], 
      PolygonBox[{{-2.595057255667003, -2.595057255667003}, \
{-2.5626550066464766`, -2.769748357463745}, {-2.7348349570550448`, \
-2.7348349570550448`}, {-2.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{-2.7348349570550448`, -2.7348349570550448`}, {-2.8125, \
-2.6752404735808355`}, {-2.595057255667003, -2.595057255667003}, \
{-2.7348349570550448`, -2.7348349570550448`}}], 
      PolygonBox[{{-2.7697483574637447`, -2.5626550066464766`}, \
{-2.595057255667003, -2.595057255667003}, {-2.8125, -2.6752404735808355`}, \
{-2.7697483574637447`, -2.5626550066464766`}}], 
      PolygonBox[{{-2.8125, -2.6752404735808355`}, {-2.9029428580865546`, \
-2.6377778151415994`}, {-2.7697483574637447`, -2.5626550066464766`}, \
{-2.8125, -2.6752404735808355`}}], 
      PolygonBox[{{-2.9157074104439396`, -2.562500018967059}, \
{-2.7697483574637447`, -2.5626550066464766`}, {-2.9029428580865546`, \
-2.6377778151415994`}, {-2.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-2.9029428580865546`, -2.6377778151415994`}, {-3., \
-2.625}, {-2.9157074104439396`, -2.562500018967059}, {-2.9029428580865546`, \
-2.6377778151415994`}}], 
      PolygonBox[{{-2.9998944727795123`, -2.5625}, {-2.9157074104439396`, \
-2.562500018967059}, {-3., -2.625}, {-2.9998944727795123`, -2.5625}}], 
      PolygonBox[{{-3., -2.625}, {-3.097057141913445, -2.6377778151415994`}, \
{-2.9998944727795123`, -2.5625}, {-3., -2.625}}], 
      PolygonBox[{{-3.084292589556057, -2.562500018967059}, \
{-2.9998944727795123`, -2.5625}, {-3.097057141913445, -2.6377778151415994`}, \
{-3.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-3.097057141913445, -2.6377778151415994`}, {-3.1875, \
-2.6752404735808355`}, {-3.084292589556057, -2.562500018967059}, \
{-3.097057141913445, -2.6377778151415994`}}], 
      PolygonBox[{{-3.230251642536255, -2.5626550066464766`}, \
{-3.084292589556057, -2.562500018967059}, {-3.1875, -2.6752404735808355`}, \
{-3.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-3.1875, -2.6752404735808355`}, {-3.2651650429449552`, \
-2.7348349570550448`}, {-3.230251642536255, -2.5626550066464766`}, {-3.1875, \
-2.6752404735808355`}}], 
      PolygonBox[{{-3.404942744332997, -2.595057255667003}, \
{-3.230251642536255, -2.5626550066464766`}, {-3.2651650429449552`, \
-2.7348349570550448`}, {-3.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-3.2651650429449552`, -2.7348349570550448`}, \
{-3.3247595264191645`, -2.8125}, {-3.404942744332997, -2.595057255667003}, \
{-3.2651650429449552`, -2.7348349570550448`}}], 
      PolygonBox[{{-3.4373449933535234`, -2.7697483574637447`}, \
{-3.404942744332997, -2.595057255667003}, {-3.3247595264191645`, -2.8125}, \
{-3.4373449933535234`, -2.7697483574637447`}}], 
      PolygonBox[{{-3.3247595264191645`, -2.8125}, {-3.3622221848584006`, \
-2.9029428580865546`}, {-3.4373449933535234`, -2.7697483574637447`}, \
{-3.3247595264191645`, -2.8125}}], 
      PolygonBox[{{-3.437499981032941, -2.9157074104439378`}, \
{-3.4373449933535234`, -2.7697483574637447`}, {-3.3622221848584006`, \
-2.9029428580865546`}, {-3.437499981032941, -2.9157074104439378`}}], 
      PolygonBox[{{-3.3622221848584006`, -2.9029428580865546`}, {-3.375, \
-3.}, {-3.437499981032941, -2.9157074104439378`}, {-3.3622221848584006`, \
-2.9029428580865546`}}], 
      PolygonBox[{{-3.4375, -2.9998768219370047`}, {-3.437499981032941, \
-2.9157074104439378`}, {-3.375, -3.}, {-3.4375, -2.9998768219370047`}}], 
      PolygonBox[{{-3.375, -3.}, {-3.3622221848584006`, -3.097057141913445}, \
{-3.4375, -2.9998768219370047`}, {-3.375, -3.}}], 
      PolygonBox[{{-3.437499981032941, -3.084292589556055}, {-3.4375, \
-2.9998768219370047`}, {-3.3622221848584006`, -3.097057141913445}, \
{-3.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-3.3622221848584006`, -3.097057141913445}, \
{-3.3247595264191645`, -3.1875}, {-3.437499981032941, -3.084292589556055}, \
{-3.3622221848584006`, -3.097057141913445}}], 
      PolygonBox[{{-3.4373449933535234`, -3.230251642536255}, \
{-3.437499981032941, -3.084292589556055}, {-3.3247595264191645`, -3.1875}, \
{-3.4373449933535234`, -3.230251642536255}}], 
      PolygonBox[{{-3.3247595264191645`, -3.1875}, {-3.2651650429449552`, \
-3.2651650429449552`}, {-3.4373449933535234`, -3.230251642536255}, \
{-3.3247595264191645`, -3.1875}}], 
      PolygonBox[{{-3.404942744332997, -3.404942744332997}, \
{-3.4373449933535234`, -3.230251642536255}, {-3.2651650429449552`, \
-3.2651650429449552`}, {-3.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, -3.2651650429449552`}, {-3.1875, \
-3.3247595264191645`}, {-3.404942744332997, -3.404942744332997}, \
{-3.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{-3.230251642536255, -3.4373449933535234`}, \
{-3.404942744332997, -3.404942744332997}, {-3.1875, -3.3247595264191645`}, \
{-3.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{-3.1875, -3.3247595264191645`}, {-3.0970571419134454`, \
-3.3622221848584006`}, {-3.230251642536255, -3.4373449933535234`}, {-3.1875, \
-3.3247595264191645`}}], 
      PolygonBox[{{-3.084292589556064, -3.437499981032941}, \
{-3.230251642536255, -3.4373449933535234`}, {-3.0970571419134454`, \
-3.3622221848584006`}, {-3.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-3.0970571419134454`, -3.3622221848584006`}, {-3., \
-3.375}, {-3.084292589556064, -3.437499981032941}, {-3.0970571419134454`, \
-3.3622221848584006`}}], 
      PolygonBox[{{-2.999865158168957, -3.4375}, {-3.084292589556064, \
-3.437499981032941}, {-3., -3.375}, {-2.999865158168957, -3.4375}}], 
      PolygonBox[{{-3., -3.375}, {-2.902942858086555, -3.3622221848584006`}, \
{-2.999865158168957, -3.4375}, {-3., -3.375}}], 
      PolygonBox[{{-2.9157074104439467`, -3.437499981032941}, \
{-2.999865158168957, -3.4375}, {-2.902942858086555, -3.3622221848584006`}, \
{-2.9157074104439467`, -3.437499981032941}}], 
      PolygonBox[{{-2.902942858086555, -3.3622221848584006`}, \
{-2.8125000000000004`, -3.3247595264191645`}, {-2.9157074104439467`, \
-3.437499981032941}, {-2.902942858086555, -3.3622221848584006`}}], 
      PolygonBox[{{-2.769748357463745, -3.4373449933535234`}, \
{-2.9157074104439467`, -3.437499981032941}, {-2.8125000000000004`, \
-3.3247595264191645`}, {-2.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{-2.8125000000000004`, -3.3247595264191645`}, \
{-2.7348349570550448`, -3.2651650429449552`}, {-2.769748357463745, \
-3.4373449933535234`}, {-2.8125000000000004`, -3.3247595264191645`}}], 
      PolygonBox[{{-2.595057255667003, -3.404942744332997}, \
{-2.769748357463745, -3.4373449933535234`}, {-2.7348349570550448`, \
-3.2651650429449552`}, {-2.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, -3.2651650429449552`}, \
{-2.7348349570550448`, -3.2651650429449552`}, {-2.595057255667003, \
-3.404942744332997}, {-2.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{-2.595057255667003, -3.404942744332997}, \
{-2.595057255667003, -3.404942744332997}, {-2.7348349570550448`, \
-3.2651650429449552`}, {-2.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-2.595057255667003, -3.404942744332997}, \
{-2.5626550066464766`, -3.2302516425362553`}, {-2.5, -3.5}, \
{-2.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{-2.5, -3.357662782649368}, {-2.5, -3.5}, \
{-2.5626550066464766`, -3.2302516425362553`}, {-2.5, -3.357662782649368}}], 
      PolygonBox[{{-2.5626550066464766`, -3.2302516425362553`}, \
{-2.562500018967059, -3.084292589556062}, {-2.5, -3.357662782649368}, \
{-2.5626550066464766`, -3.2302516425362553`}}], 
      PolygonBox[{{-2.5, -3.20590900530174}, {-2.5, -3.357662782649368}, \
{-2.562500018967059, -3.084292589556062}, {-2.5, -3.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, -3.084292589556062}, {-2.5625, -3.}, \
{-2.5, -3.20590900530174}, {-2.562500018967059, -3.084292589556062}}], 
      PolygonBox[{{-2.5, -3.}, {-2.5, -3.20590900530174}, {-2.5625, -3.}, \
{-2.5, -3.}}], 
      PolygonBox[{{-2.5625, -3.}, {-2.562500018967059, -2.915707410443938}, \
{-2.5, -3.}, {-2.5625, -3.}}], 
      PolygonBox[{{-2.5, -2.79409099469826}, {-2.5, -3.}, \
{-2.562500018967059, -2.915707410443938}, {-2.5, -2.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, -2.915707410443938}, \
{-2.5626550066464766`, -2.769748357463745}, {-2.5, -2.79409099469826}, \
{-2.562500018967059, -2.915707410443938}}], 
      PolygonBox[{{-2.5, -2.6423372173506325`}, {-2.5, -2.79409099469826}, \
{-2.5626550066464766`, -2.769748357463745}, {-2.5, -2.6423372173506325`}}], 
      PolygonBox[{{-2.5626550066464766`, -2.769748357463745}, \
{-2.595057255667003, -2.595057255667003}, {-2.5, -2.6423372173506325`}, \
{-2.5626550066464766`, -2.769748357463745}}], 
      PolygonBox[{{-2.508553435038814, -2.508553435038814}, {-2.5, \
-2.6423372173506325`}, {-2.595057255667003, -2.595057255667003}, \
{-2.508553435038814, -2.508553435038814}}], 
      PolygonBox[{{-2.595057255667003, -2.595057255667003}, \
{-2.7697483574637447`, -2.5626550066464766`}, {-2.508553435038814, \
-2.508553435038814}, {-2.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{-2.642337217350632, -2.5}, {-2.508553435038814, \
-2.508553435038814}, {-2.7697483574637447`, -2.5626550066464766`}, \
{-2.642337217350632, -2.5}}], 
      PolygonBox[{{-2.7697483574637447`, -2.5626550066464766`}, \
{-2.9157074104439396`, -2.562500018967059}, {-2.642337217350632, -2.5}, \
{-2.7697483574637447`, -2.5626550066464766`}}], 
      PolygonBox[{{-2.7940909946267443`, -2.5}, {-2.642337217350632, -2.5}, \
{-2.9157074104439396`, -2.562500018967059}, {-2.7940909946267443`, -2.5}}], 
      PolygonBox[{{-2.9157074104439396`, -2.562500018967059}, \
{-2.9998944727795123`, -2.5625}, {-2.7940909946267443`, -2.5}, \
{-2.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-2.92205804197311, -2.5}, {-2.7940909946267443`, -2.5}, \
{-2.9998944727795123`, -2.5625}, {-2.92205804197311, -2.5}}], 
      PolygonBox[{{-2.9998944727795123`, -2.5625}, {-3.084292589556057, \
-2.562500018967059}, {-2.92205804197311, -2.5}, {-2.9998944727795123`, \
-2.5625}}], 
      PolygonBox[{{-3.2059090053044454`, -2.5}, {-2.92205804197311, -2.5}, \
{-3.084292589556057, -2.562500018967059}, {-3.2059090053044454`, -2.5}}], 
      PolygonBox[{{-3.084292589556057, -2.562500018967059}, \
{-3.230251642536255, -2.5626550066464766`}, {-3.2059090053044454`, -2.5}, \
{-3.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-3.357662782649366, -2.5}, {-3.2059090053044454`, -2.5}, \
{-3.230251642536255, -2.5626550066464766`}, {-3.357662782649366, -2.5}}], 
      PolygonBox[{{-3.230251642536255, -2.5626550066464766`}, \
{-3.404942744332997, -2.595057255667003}, {-3.357662782649366, -2.5}, \
{-3.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-2.5, -2.5}, {-3.357662782649366, -2.5}, \
{-3.404942744332997, -2.595057255667003}, {-2.5, -2.5}}], 
      PolygonBox[{{-3.404942744332997, -2.595057255667003}, \
{-3.4373449933535234`, -2.7697483574637447`}, {-2.5, -2.5}, \
{-3.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-3.5, -2.642337217350631}, {-2.5, -2.5}, \
{-3.4373449933535234`, -2.7697483574637447`}, {-3.5, -2.642337217350631}}], 
      PolygonBox[{{-3.4373449933535234`, -2.7697483574637447`}, \
{-3.437499981032941, -2.9157074104439378`}, {-3.5, -2.642337217350631}, \
{-3.4373449933535234`, -2.7697483574637447`}}], 
      PolygonBox[{{-3.5, -2.794090994717101}, {-3.5, -2.642337217350631}, \
{-3.437499981032941, -2.9157074104439378`}, {-3.5, -2.794090994717101}}], 
      PolygonBox[{{-3.437499981032941, -2.9157074104439378`}, {-3.4375, \
-2.9998768219370047`}, {-3.5, -2.794090994717101}, {-3.437499981032941, \
-2.9157074104439378`}}], 
      PolygonBox[{{-3.5, -2.9193213332413}, {-3.5, -2.794090994717101}, \
{-3.4375, -2.9998768219370047`}, {-3.5, -2.9193213332413}}], 
      PolygonBox[{{-3.4375, -2.9998768219370047`}, {-3.437499981032941, \
-3.084292589556055}, {-3.5, -2.9193213332413}, {-3.4375, \
-2.9998768219370047`}}], 
      PolygonBox[{{-3.5, -3.2059090051452785`}, {-3.5, -2.9193213332413}, \
{-3.437499981032941, -3.084292589556055}, {-3.5, -3.2059090051452785`}}], 
      PolygonBox[{{-3.437499981032941, -3.084292589556055}, \
{-3.4373449933535234`, -3.230251642536255}, {-3.5, -3.2059090051452785`}, \
{-3.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-3.5, -3.3576627826493652`}, {-3.5, -3.2059090051452785`}, \
{-3.4373449933535234`, -3.230251642536255}, {-3.5, -3.3576627826493652`}}], 
      PolygonBox[{{-3.4373449933535234`, -3.230251642536255}, \
{-3.404942744332997, -3.404942744332997}, {-3.5, -3.3576627826493652`}, \
{-3.4373449933535234`, -3.230251642536255}}], 
      PolygonBox[{{-3.5, -2.5}, {-3.5, -3.3576627826493652`}, \
{-3.404942744332997, -3.404942744332997}, {-3.5, -2.5}}], 
      PolygonBox[{{-3.404942744332997, -3.404942744332997}, \
{-3.230251642536255, -3.4373449933535234`}, {-3.5, -2.5}, \
{-3.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-3.5, -3.5}, {-3.5, -2.5}, {-3.230251642536255, \
-3.4373449933535234`}, {-3.5, -3.5}}], 
      PolygonBox[{{-3.230251642536255, -3.4373449933535234`}, \
{-3.084292589556064, -3.437499981032941}, {-3.5, -3.5}, {-3.230251642536255, \
-3.4373449933535234`}}], 
      PolygonBox[{{-3.205909005566828, -3.5}, {-3.5, -3.5}, \
{-3.084292589556064, -3.437499981032941}, {-3.205909005566828, -3.5}}], 
      PolygonBox[{{-3.084292589556064, -3.437499981032941}, \
{-2.999865158168957, -3.4375}, {-3.205909005566828, -3.5}, \
{-3.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-2.9176761295989384`, -3.5}, {-3.205909005566828, -3.5}, \
{-2.999865158168957, -3.4375}, {-2.9176761295989384`, -3.5}}], 
      PolygonBox[{{-2.999865158168957, -3.4375}, {-2.9157074104439467`, \
-3.437499981032941}, {-2.9176761295989384`, -3.5}, {-2.999865158168957, \
-3.4375}}], 
      PolygonBox[{{-2.7940909946396024`, -3.5}, {-2.9176761295989384`, -3.5}, \
{-2.9157074104439467`, -3.437499981032941}, {-2.7940909946396024`, -3.5}}], 
      PolygonBox[{{-2.9157074104439467`, -3.437499981032941}, \
{-2.769748357463745, -3.4373449933535234`}, {-2.7940909946396024`, -3.5}, \
{-2.9157074104439467`, -3.437499981032941}}], 
      PolygonBox[{{-2.642337217350629, -3.5}, {-2.7940909946396024`, -3.5}, \
{-2.769748357463745, -3.4373449933535234`}, {-2.642337217350629, -3.5}}], 
      PolygonBox[{{-2.769748357463745, -3.4373449933535234`}, \
{-2.595057255667003, -3.404942744332997}, {-2.642337217350629, -3.5}, \
{-2.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{-2.5, -3.5}, {-2.642337217350629, -3.5}, \
{-2.595057255667003, -3.404942744332997}, {-2.5, -3.5}}], 
      PolygonBox[{{-2.595057255667003, -3.404942744332997}, \
{-2.595057255667003, -3.404942744332997}, {-2.5, -3.5}, {-2.595057255667003, \
-3.404942744332997}}], 
      PolygonBox[{{-2.5, -3.5}, {-2.5, -3.5}, {-2.595057255667003, \
-3.404942744332997}, {-2.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, -2.}, {-3.4791666666666665`, -2.}, \
{-3.4583333333333335`, -2.}, {-3.4375, -2.}, {-3.4166666666666665`, -2.}, \
{-3.3958333333333335`, -2.}, {-3.375, -2.}, {-3.375, -2.}, \
{-3.3958333333333335`, -2.}, {-3.4166666666666665`, -2.}, {-3.4375, -2.}, \
{-3.4583333333333335`, -2.}, {-3.4791666666666665`, -2.}, {-3.5, -2.}, {-3.5, \
-2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, -2.}, {-2.6041666666666665`, -2.}, \
{-2.5833333333333335`, -2.}, {-2.5625, -2.}, {-2.5416666666666665`, -2.}, \
{-2.5208333333333335`, -2.}, {-2.5, -2.}, {-2.5, -2.}, {-2.5208333333333335`, \
-2.}, {-2.5416666666666665`, -2.}, {-2.5625, -2.}, {-2.5833333333333335`, \
-2.}, {-2.6041666666666665`, -2.}, {-2.625, -2.}, {-2.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -2.5}, {-3., -2.4791666666666665`}, {-3., \
-2.4583333333333335`}, {-3., -2.4375}, {-3., -2.4166666666666665`}, {-3., \
-2.3958333333333335`}, {-3., -2.375}, {-3., -2.375}, {-3., \
-2.3958333333333335`}, {-3., -2.4166666666666665`}, {-3., -2.4375}, {-3., \
-2.4583333333333335`}, {-3., -2.4791666666666665`}, {-3., -2.5}, {-3., \
-2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -1.625}, {-3., -1.6041666666666667`}, {-3., \
-1.5833333333333333`}, {-3., -1.5625}, {-3., -1.5416666666666667`}, {-3., \
-1.5208333333333335`}, {-3., -1.5}, {-3., -1.5}, {-3., -1.5208333333333333`}, \
{-3., -1.5416666666666667`}, {-3., -1.5625}, {-3., -1.5833333333333333`}, \
{-3., -1.6041666666666665`}, {-3., -1.625}, {-3., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, -2.}, {-3.25, -2.}, {-3.125, -2.}, {-3., -2.}, \
{-2.875, -2.}, {-2.75, -2.}, {-2.625, -2.}, {-2.625, -2.}, {-2.75, -2.}, \
{-2.875, -2.}, {-3., -2.}, {-3.125, -2.}, {-3.25, -2.}, {-3.375, -2.}, \
{-3.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -2.375}, {-3., -2.25}, {-3., -2.125}, {-3., -2.}, {-3., \
-1.875}, {-3., -1.75}, {-3., -1.625}, {-3., -1.625}, {-3., -1.75}, {-3., \
-1.875}, {-3., -2.}, {-3., -2.125}, {-3., -2.25}, {-3., -2.375}, {-3., \
-2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsB6CMA2J6gY7aUqwHksxvmZYU/dt/YYd51ZM0
mPzf/alCKWofH7AeOKVywufRwd/7wcINbAcWFOZ/OXH21/6N0m+lrCzZD+jE
LGoKM/kFkWfggOr/td//idDTo8c4UOUbOOH6Z7+dfZNPngtuvoH7iVbpmVxw
+19dXLfvylMuuPsg4txw98Pk/cD2MBxA0d/AeGAO1HyIPUwHYPZD1DEdgLkP
Yg5UHu5+5gOboP6DyTNC/Q/TDwsfmPko4Qe0Hxa+/lD3oYc/ALpNmwA=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByD0j/2hYMAK569eBQJscD6E5kBTzwnng5Wv
4kJTz0OQD9H3C86HmPsXTT3DAVR5xgOo+pkOoKpnweCvRnEfywFU98PUc6Cp
Z4Pzw1DCh4VoejWK+1jQ3A9TxwDnh6H4H6b/135U9T/2AwB6u2lA
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, -2.2651650429449552`}, \
{-2.6752404735808355`, -2.1875}, {-2.595057255667003, -2.404942744332997}, \
{-2.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{-2.5626550066464766`, -2.2302516425362553`}, \
{-2.595057255667003, -2.404942744332997}, {-2.6752404735808355`, -2.1875}, \
{-2.5626550066464766`, -2.2302516425362553`}}], 
      PolygonBox[{{-2.6752404735808355`, -2.1875}, {-2.6377778151415994`, \
-2.0970571419134454`}, {-2.5626550066464766`, -2.2302516425362553`}, \
{-2.6752404735808355`, -2.1875}}], 
      PolygonBox[{{-2.562500018967059, -2.084292589556062}, \
{-2.5626550066464766`, -2.2302516425362553`}, {-2.6377778151415994`, \
-2.0970571419134454`}, {-2.562500018967059, -2.084292589556062}}], 
      PolygonBox[{{-2.6377778151415994`, -2.0970571419134454`}, {-2.625, \
-2.}, {-2.562500018967059, -2.084292589556062}, {-2.6377778151415994`, \
-2.0970571419134454`}}], 
      PolygonBox[{{-2.5625, -2.}, {-2.562500018967059, -2.084292589556062}, \
{-2.625, -2.}, {-2.5625, -2.}}], 
      PolygonBox[{{-2.625, -2.}, {-2.6377778151415994`, \
-1.9029428580865548`}, {-2.5625, -2.}, {-2.625, -2.}}], 
      PolygonBox[{{-2.562500018967059, -1.9157074104439382`}, {-2.5625, -2.}, \
{-2.6377778151415994`, -1.9029428580865548`}, {-2.562500018967059, \
-1.9157074104439382`}}], 
      PolygonBox[{{-2.6377778151415994`, -1.9029428580865548`}, \
{-2.6752404735808355`, -1.8125}, {-2.562500018967059, -1.9157074104439382`}, \
{-2.6377778151415994`, -1.9029428580865548`}}], 
      PolygonBox[{{-2.5626550066464766`, -1.769748357463745}, \
{-2.562500018967059, -1.9157074104439382`}, {-2.6752404735808355`, -1.8125}, \
{-2.5626550066464766`, -1.769748357463745}}], 
      PolygonBox[{{-2.6752404735808355`, -1.8125}, {-2.7348349570550448`, \
-1.7348349570550448`}, {-2.5626550066464766`, -1.769748357463745}, \
{-2.6752404735808355`, -1.8125}}], 
      PolygonBox[{{-2.595057255667003, -1.5950572556670028`}, \
{-2.5626550066464766`, -1.769748357463745}, {-2.7348349570550448`, \
-1.7348349570550448`}, {-2.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{-2.7348349570550448`, -1.7348349570550448`}, {-2.8125, \
-1.6752404735808355`}, {-2.595057255667003, -1.5950572556670028`}, \
{-2.7348349570550448`, -1.7348349570550448`}}], 
      PolygonBox[{{-2.7697483574637447`, -1.5626550066464766`}, \
{-2.595057255667003, -1.5950572556670028`}, {-2.8125, -1.6752404735808355`}, \
{-2.7697483574637447`, -1.5626550066464766`}}], 
      PolygonBox[{{-2.8125, -1.6752404735808355`}, {-2.9029428580865546`, \
-1.6377778151415994`}, {-2.7697483574637447`, -1.5626550066464766`}, \
{-2.8125, -1.6752404735808355`}}], 
      PolygonBox[{{-2.9157074104439396`, -1.5625000189670593`}, \
{-2.7697483574637447`, -1.5626550066464766`}, {-2.9029428580865546`, \
-1.6377778151415994`}, {-2.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-2.9029428580865546`, -1.6377778151415994`}, {-3., \
-1.625}, {-2.9157074104439396`, -1.5625000189670593`}, {-2.9029428580865546`, \
-1.6377778151415994`}}], 
      PolygonBox[{{-2.9998944727795123`, -1.5625}, {-2.9157074104439396`, \
-1.5625000189670593`}, {-3., -1.625}, {-2.9998944727795123`, -1.5625}}], 
      PolygonBox[{{-3., -1.625}, {-3.097057141913445, -1.6377778151415994`}, \
{-2.9998944727795123`, -1.5625}, {-3., -1.625}}], 
      PolygonBox[{{-3.084292589556057, -1.5625000189670593`}, \
{-2.9998944727795123`, -1.5625}, {-3.097057141913445, -1.6377778151415994`}, \
{-3.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-3.097057141913445, -1.6377778151415994`}, {-3.1875, \
-1.6752404735808355`}, {-3.084292589556057, -1.5625000189670593`}, \
{-3.097057141913445, -1.6377778151415994`}}], 
      PolygonBox[{{-3.230251642536255, -1.5626550066464766`}, \
{-3.084292589556057, -1.5625000189670593`}, {-3.1875, -1.6752404735808355`}, \
{-3.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-3.1875, -1.6752404735808355`}, {-3.2651650429449552`, \
-1.7348349570550448`}, {-3.230251642536255, -1.5626550066464766`}, {-3.1875, \
-1.6752404735808355`}}], 
      PolygonBox[{{-3.404942744332997, -1.5950572556670028`}, \
{-3.230251642536255, -1.5626550066464766`}, {-3.2651650429449552`, \
-1.7348349570550448`}, {-3.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-3.2651650429449552`, -1.7348349570550448`}, \
{-3.3247595264191645`, -1.8125}, {-3.404942744332997, -1.5950572556670028`}, \
{-3.2651650429449552`, -1.7348349570550448`}}], 
      PolygonBox[{{-3.4373449933535234`, -1.7697483574637447`}, \
{-3.404942744332997, -1.5950572556670028`}, {-3.3247595264191645`, -1.8125}, \
{-3.4373449933535234`, -1.7697483574637447`}}], 
      PolygonBox[{{-3.3247595264191645`, -1.8125}, {-3.3622221848584006`, \
-1.9029428580865546`}, {-3.4373449933535234`, -1.7697483574637447`}, \
{-3.3247595264191645`, -1.8125}}], 
      PolygonBox[{{-3.437499981032941, -1.9157074104439376`}, \
{-3.4373449933535234`, -1.7697483574637447`}, {-3.3622221848584006`, \
-1.9029428580865546`}, {-3.437499981032941, -1.9157074104439376`}}], 
      PolygonBox[{{-3.3622221848584006`, -1.9029428580865546`}, {-3.375, \
-1.9999999999999998`}, {-3.437499981032941, -1.9157074104439376`}, \
{-3.3622221848584006`, -1.9029428580865546`}}], 
      PolygonBox[{{-3.4375, -1.9998768219370047`}, {-3.437499981032941, \
-1.9157074104439376`}, {-3.375, -1.9999999999999998`}, {-3.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-3.375, -1.9999999999999998`}, {-3.3622221848584006`, \
-2.097057141913445}, {-3.4375, -1.9998768219370047`}, {-3.375, \
-1.9999999999999998`}}], 
      PolygonBox[{{-3.437499981032941, -2.084292589556055}, {-3.4375, \
-1.9998768219370047`}, {-3.3622221848584006`, -2.097057141913445}, \
{-3.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-3.3622221848584006`, -2.097057141913445}, \
{-3.3247595264191645`, -2.1875}, {-3.437499981032941, -2.084292589556055}, \
{-3.3622221848584006`, -2.097057141913445}}], 
      PolygonBox[{{-3.4373449933535234`, -2.230251642536255}, \
{-3.437499981032941, -2.084292589556055}, {-3.3247595264191645`, -2.1875}, \
{-3.4373449933535234`, -2.230251642536255}}], 
      PolygonBox[{{-3.3247595264191645`, -2.1875}, {-3.2651650429449552`, \
-2.2651650429449552`}, {-3.4373449933535234`, -2.230251642536255}, \
{-3.3247595264191645`, -2.1875}}], 
      PolygonBox[{{-3.404942744332997, -2.404942744332997}, \
{-3.4373449933535234`, -2.230251642536255}, {-3.2651650429449552`, \
-2.2651650429449552`}, {-3.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, -2.2651650429449552`}, {-3.1875, \
-2.3247595264191645`}, {-3.404942744332997, -2.404942744332997}, \
{-3.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{-3.230251642536255, -2.4373449933535234`}, \
{-3.404942744332997, -2.404942744332997}, {-3.1875, -2.3247595264191645`}, \
{-3.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{-3.1875, -2.3247595264191645`}, {-3.0970571419134454`, \
-2.3622221848584006`}, {-3.230251642536255, -2.4373449933535234`}, {-3.1875, \
-2.3247595264191645`}}], 
      PolygonBox[{{-3.084292589556064, -2.437499981032941}, \
{-3.230251642536255, -2.4373449933535234`}, {-3.0970571419134454`, \
-2.3622221848584006`}, {-3.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-3.0970571419134454`, -2.3622221848584006`}, {-3., \
-2.375}, {-3.084292589556064, -2.437499981032941}, {-3.0970571419134454`, \
-2.3622221848584006`}}], 
      PolygonBox[{{-2.999865158168957, -2.4375}, {-3.084292589556064, \
-2.437499981032941}, {-3., -2.375}, {-2.999865158168957, -2.4375}}], 
      PolygonBox[{{-3., -2.375}, {-2.902942858086555, -2.3622221848584006`}, \
{-2.999865158168957, -2.4375}, {-3., -2.375}}], 
      PolygonBox[{{-2.9157074104439467`, -2.437499981032941}, \
{-2.999865158168957, -2.4375}, {-2.902942858086555, -2.3622221848584006`}, \
{-2.9157074104439467`, -2.437499981032941}}], 
      PolygonBox[{{-2.902942858086555, -2.3622221848584006`}, \
{-2.8125000000000004`, -2.3247595264191645`}, {-2.9157074104439467`, \
-2.437499981032941}, {-2.902942858086555, -2.3622221848584006`}}], 
      PolygonBox[{{-2.769748357463745, -2.4373449933535234`}, \
{-2.9157074104439467`, -2.437499981032941}, {-2.8125000000000004`, \
-2.3247595264191645`}, {-2.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{-2.8125000000000004`, -2.3247595264191645`}, \
{-2.7348349570550448`, -2.2651650429449552`}, {-2.769748357463745, \
-2.4373449933535234`}, {-2.8125000000000004`, -2.3247595264191645`}}], 
      PolygonBox[{{-2.595057255667003, -2.404942744332997}, \
{-2.769748357463745, -2.4373449933535234`}, {-2.7348349570550448`, \
-2.2651650429449552`}, {-2.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, -2.2651650429449552`}, \
{-2.7348349570550448`, -2.2651650429449552`}, {-2.595057255667003, \
-2.404942744332997}, {-2.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{-2.595057255667003, -2.404942744332997}, \
{-2.595057255667003, -2.404942744332997}, {-2.7348349570550448`, \
-2.2651650429449552`}, {-2.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-2.595057255667003, -2.404942744332997}, \
{-2.5626550066464766`, -2.2302516425362553`}, {-2.5, -2.5}, \
{-2.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{-2.5, -2.357662782649368}, {-2.5, -2.5}, \
{-2.5626550066464766`, -2.2302516425362553`}, {-2.5, -2.357662782649368}}], 
      PolygonBox[{{-2.5626550066464766`, -2.2302516425362553`}, \
{-2.562500018967059, -2.084292589556062}, {-2.5, -2.357662782649368}, \
{-2.5626550066464766`, -2.2302516425362553`}}], 
      PolygonBox[{{-2.5, -2.20590900530174}, {-2.5, -2.357662782649368}, \
{-2.562500018967059, -2.084292589556062}, {-2.5, -2.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, -2.084292589556062}, {-2.5625, -2.}, \
{-2.5, -2.20590900530174}, {-2.562500018967059, -2.084292589556062}}], 
      PolygonBox[{{-2.5, -2.}, {-2.5, -2.20590900530174}, {-2.5625, -2.}, \
{-2.5, -2.}}], 
      PolygonBox[{{-2.5625, -2.}, {-2.562500018967059, -1.9157074104439382`}, \
{-2.5, -2.}, {-2.5625, -2.}}], 
      PolygonBox[{{-2.5, -1.7940909946982602`}, {-2.5, -2.}, \
{-2.562500018967059, -1.9157074104439382`}, {-2.5, -1.7940909946982602`}}], 
      PolygonBox[{{-2.562500018967059, -1.9157074104439382`}, \
{-2.5626550066464766`, -1.769748357463745}, {-2.5, -1.7940909946982602`}, \
{-2.562500018967059, -1.9157074104439382`}}], 
      PolygonBox[{{-2.5, -1.6423372173506325`}, {-2.5, -1.7940909946982602`}, \
{-2.5626550066464766`, -1.769748357463745}, {-2.5, -1.6423372173506325`}}], 
      PolygonBox[{{-2.5626550066464766`, -1.769748357463745}, \
{-2.595057255667003, -1.5950572556670028`}, {-2.5, -1.6423372173506325`}, \
{-2.5626550066464766`, -1.769748357463745}}], 
      PolygonBox[{{-2.508553435038814, -1.508553435038814}, {-2.5, \
-1.6423372173506325`}, {-2.595057255667003, -1.5950572556670028`}, \
{-2.508553435038814, -1.508553435038814}}], 
      PolygonBox[{{-2.595057255667003, -1.5950572556670028`}, \
{-2.7697483574637447`, -1.5626550066464766`}, {-2.508553435038814, \
-1.508553435038814}, {-2.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{-2.642337217350632, -1.5}, {-2.508553435038814, \
-1.508553435038814}, {-2.7697483574637447`, -1.5626550066464766`}, \
{-2.642337217350632, -1.5}}], 
      PolygonBox[{{-2.7697483574637447`, -1.5626550066464766`}, \
{-2.9157074104439396`, -1.5625000189670593`}, {-2.642337217350632, -1.5}, \
{-2.7697483574637447`, -1.5626550066464766`}}], 
      PolygonBox[{{-2.7940909946267443`, -1.5}, {-2.642337217350632, -1.5}, \
{-2.9157074104439396`, -1.5625000189670593`}, {-2.7940909946267443`, -1.5}}], 
      PolygonBox[{{-2.9157074104439396`, -1.5625000189670593`}, \
{-2.9998944727795123`, -1.5625}, {-2.7940909946267443`, -1.5}, \
{-2.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-2.92205804197311, -1.5}, {-2.7940909946267443`, -1.5}, \
{-2.9998944727795123`, -1.5625}, {-2.92205804197311, -1.5}}], 
      PolygonBox[{{-2.9998944727795123`, -1.5625}, {-3.084292589556057, \
-1.5625000189670593`}, {-2.92205804197311, -1.5}, {-2.9998944727795123`, \
-1.5625}}], 
      PolygonBox[{{-3.2059090053044454`, -1.5}, {-2.92205804197311, -1.5}, \
{-3.084292589556057, -1.5625000189670593`}, {-3.2059090053044454`, -1.5}}], 
      PolygonBox[{{-3.084292589556057, -1.5625000189670593`}, \
{-3.230251642536255, -1.5626550066464766`}, {-3.2059090053044454`, -1.5}, \
{-3.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-3.357662782649366, -1.5}, {-3.2059090053044454`, -1.5}, \
{-3.230251642536255, -1.5626550066464766`}, {-3.357662782649366, -1.5}}], 
      PolygonBox[{{-3.230251642536255, -1.5626550066464766`}, \
{-3.404942744332997, -1.5950572556670028`}, {-3.357662782649366, -1.5}, \
{-3.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-2.5, -1.5}, {-3.357662782649366, -1.5}, \
{-3.404942744332997, -1.5950572556670028`}, {-2.5, -1.5}}], 
      PolygonBox[{{-3.404942744332997, -1.5950572556670028`}, \
{-3.4373449933535234`, -1.7697483574637447`}, {-2.5, -1.5}, \
{-3.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-3.5, -1.642337217350631}, {-2.5, -1.5}, \
{-3.4373449933535234`, -1.7697483574637447`}, {-3.5, -1.642337217350631}}], 
      PolygonBox[{{-3.4373449933535234`, -1.7697483574637447`}, \
{-3.437499981032941, -1.9157074104439376`}, {-3.5, -1.642337217350631}, \
{-3.4373449933535234`, -1.7697483574637447`}}], 
      PolygonBox[{{-3.5, -1.794090994717101}, {-3.5, -1.642337217350631}, \
{-3.437499981032941, -1.9157074104439376`}, {-3.5, -1.794090994717101}}], 
      PolygonBox[{{-3.437499981032941, -1.9157074104439376`}, {-3.4375, \
-1.9998768219370047`}, {-3.5, -1.794090994717101}, {-3.437499981032941, \
-1.9157074104439376`}}], 
      PolygonBox[{{-3.5, -1.9193213332412997`}, {-3.5, -1.794090994717101}, \
{-3.4375, -1.9998768219370047`}, {-3.5, -1.9193213332412997`}}], 
      PolygonBox[{{-3.4375, -1.9998768219370047`}, {-3.437499981032941, \
-2.084292589556055}, {-3.5, -1.9193213332412997`}, {-3.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-3.5, -2.2059090051452785`}, {-3.5, -1.9193213332412997`}, \
{-3.437499981032941, -2.084292589556055}, {-3.5, -2.2059090051452785`}}], 
      PolygonBox[{{-3.437499981032941, -2.084292589556055}, \
{-3.4373449933535234`, -2.230251642536255}, {-3.5, -2.2059090051452785`}, \
{-3.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-3.5, -2.3576627826493652`}, {-3.5, -2.2059090051452785`}, \
{-3.4373449933535234`, -2.230251642536255}, {-3.5, -2.3576627826493652`}}], 
      PolygonBox[{{-3.4373449933535234`, -2.230251642536255}, \
{-3.404942744332997, -2.404942744332997}, {-3.5, -2.3576627826493652`}, \
{-3.4373449933535234`, -2.230251642536255}}], 
      PolygonBox[{{-3.5, -1.5}, {-3.5, -2.3576627826493652`}, \
{-3.404942744332997, -2.404942744332997}, {-3.5, -1.5}}], 
      PolygonBox[{{-3.404942744332997, -2.404942744332997}, \
{-3.230251642536255, -2.4373449933535234`}, {-3.5, -1.5}, \
{-3.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-3.5, -2.5}, {-3.5, -1.5}, {-3.230251642536255, \
-2.4373449933535234`}, {-3.5, -2.5}}], 
      PolygonBox[{{-3.230251642536255, -2.4373449933535234`}, \
{-3.084292589556064, -2.437499981032941}, {-3.5, -2.5}, {-3.230251642536255, \
-2.4373449933535234`}}], 
      PolygonBox[{{-3.205909005566828, -2.5}, {-3.5, -2.5}, \
{-3.084292589556064, -2.437499981032941}, {-3.205909005566828, -2.5}}], 
      PolygonBox[{{-3.084292589556064, -2.437499981032941}, \
{-2.999865158168957, -2.4375}, {-3.205909005566828, -2.5}, \
{-3.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-2.9176761295989384`, -2.5}, {-3.205909005566828, -2.5}, \
{-2.999865158168957, -2.4375}, {-2.9176761295989384`, -2.5}}], 
      PolygonBox[{{-2.999865158168957, -2.4375}, {-2.9157074104439467`, \
-2.437499981032941}, {-2.9176761295989384`, -2.5}, {-2.999865158168957, \
-2.4375}}], 
      PolygonBox[{{-2.7940909946396024`, -2.5}, {-2.9176761295989384`, -2.5}, \
{-2.9157074104439467`, -2.437499981032941}, {-2.7940909946396024`, -2.5}}], 
      PolygonBox[{{-2.9157074104439467`, -2.437499981032941}, \
{-2.769748357463745, -2.4373449933535234`}, {-2.7940909946396024`, -2.5}, \
{-2.9157074104439467`, -2.437499981032941}}], 
      PolygonBox[{{-2.642337217350629, -2.5}, {-2.7940909946396024`, -2.5}, \
{-2.769748357463745, -2.4373449933535234`}, {-2.642337217350629, -2.5}}], 
      PolygonBox[{{-2.769748357463745, -2.4373449933535234`}, \
{-2.595057255667003, -2.404942744332997}, {-2.642337217350629, -2.5}, \
{-2.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{-2.5, -2.5}, {-2.642337217350629, -2.5}, \
{-2.595057255667003, -2.404942744332997}, {-2.5, -2.5}}], 
      PolygonBox[{{-2.595057255667003, -2.404942744332997}, \
{-2.595057255667003, -2.404942744332997}, {-2.5, -2.5}, {-2.595057255667003, \
-2.404942744332997}}], 
      PolygonBox[{{-2.5, -2.5}, {-2.5, -2.5}, {-2.595057255667003, \
-2.404942744332997}, {-2.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, -1.}, {-3.4791666666666665`, -1.}, \
{-3.4583333333333335`, -1.}, {-3.4375, -1.}, {-3.4166666666666665`, -1.}, \
{-3.3958333333333335`, -1.}, {-3.375, -1.}, {-3.375, -1.}, \
{-3.3958333333333335`, -1.}, {-3.4166666666666665`, -1.}, {-3.4375, -1.}, \
{-3.4583333333333335`, -1.}, {-3.4791666666666665`, -1.}, {-3.5, -1.}, {-3.5, \
-1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, -1.}, {-2.6041666666666665`, -1.}, \
{-2.5833333333333335`, -1.}, {-2.5625, -1.}, {-2.5416666666666665`, -1.}, \
{-2.5208333333333335`, -1.}, {-2.5, -1.}, {-2.5, -1.}, {-2.5208333333333335`, \
-1.}, {-2.5416666666666665`, -1.}, {-2.5625, -1.}, {-2.5833333333333335`, \
-1.}, {-2.6041666666666665`, -1.}, {-2.625, -1.}, {-2.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -1.5}, {-3., -1.4791666666666667`}, {-3., \
-1.4583333333333333`}, {-3., -1.4375}, {-3., -1.4166666666666667`}, {-3., \
-1.3958333333333335`}, {-3., -1.375}, {-3., -1.375}, {-3., \
-1.3958333333333333`}, {-3., -1.4166666666666667`}, {-3., -1.4375}, {-3., \
-1.4583333333333333`}, {-3., -1.4791666666666665`}, {-3., -1.5}, {-3., \
-1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -0.625}, {-3., -0.6041666666666667}, {-3., \
-0.5833333333333333}, {-3., -0.5625}, {-3., -0.5416666666666667}, {-3., \
-0.5208333333333334}, {-3., -0.5}, {-3., -0.5}, {-3., -0.5208333333333333}, \
{-3., -0.5416666666666667}, {-3., -0.5625}, {-3., -0.5833333333333333}, {-3., \
-0.6041666666666666}, {-3., -0.625}, {-3., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, -1.}, {-3.25, -1.}, {-3.125, -1.}, {-3., -1.}, \
{-2.875, -1.}, {-2.75, -1.}, {-2.625, -1.}, {-2.625, -1.}, {-2.75, -1.}, \
{-2.875, -1.}, {-3., -1.}, {-3.125, -1.}, {-3.25, -1.}, {-3.375, -1.}, \
{-3.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -1.375}, {-3., -1.25}, {-3., -1.125}, {-3., -1.}, {-3., \
-0.875}, {-3., -0.75}, {-3., -0.625}, {-3., -0.625}, {-3., -0.75}, {-3., \
-0.875}, {-3., -1.}, {-3., -1.125}, {-3., -1.25}, {-3., -1.375}, {-3., \
-1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByD0h/1ieoGO2lKsB47mbcl+8eTN/gs7zKue
pMHkX+1PFUpR+/iA9cAUzwkzjzQ/3w8WbmA74PD43ouJs5/u3yj9VsrKkv1A
xA4X1rUZTyDyDBxQ/U/2+z8Renr0GAeqfAMnXP/st7Nv8slzHZgMNd/A/USr
9EyuA//B4OX+VxfX7bvylOvAEaj7IOZyw90Pk597QvVUd+9HuH6I/Of9c6Dm
m9023yxr9wVuf0LfBG5zo69w911ZHFu78vRXNPd/278J6j+YPCPU/zD9sPCB
mQ8LP0ao/bDwnQ91H3r4AwANpqnG
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByD0g/2hYMAK569eBQJscD6E5kBTzwnng5Wv
4kJTz0OQDzHnKZwPMecVmvoPaPKf0PR/RVP/A4O/GsV9P9Dc/wPNfz/Q/P9j
fxhK+MDUsxDkh6G4j+XAahT3w9R/QJN/hab/KZr6B/sBJbR2Rg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, -1.2651650429449552`}, \
{-2.6752404735808355`, -1.1875}, {-2.595057255667003, -1.4049427443329972`}, \
{-2.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{-2.5626550066464766`, -1.230251642536255}, \
{-2.595057255667003, -1.4049427443329972`}, {-2.6752404735808355`, -1.1875}, \
{-2.5626550066464766`, -1.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, -1.1875}, {-2.6377778151415994`, \
-1.0970571419134454`}, {-2.5626550066464766`, -1.230251642536255}, \
{-2.6752404735808355`, -1.1875}}], 
      PolygonBox[{{-2.562500018967059, -1.0842925895560618`}, \
{-2.5626550066464766`, -1.230251642536255}, {-2.6377778151415994`, \
-1.0970571419134454`}, {-2.562500018967059, -1.0842925895560618`}}], 
      PolygonBox[{{-2.6377778151415994`, -1.0970571419134454`}, {-2.625, \
-1.}, {-2.562500018967059, -1.0842925895560618`}, {-2.6377778151415994`, \
-1.0970571419134454`}}], 
      PolygonBox[{{-2.5625, -1.}, {-2.562500018967059, -1.0842925895560618`}, \
{-2.625, -1.}, {-2.5625, -1.}}], 
      PolygonBox[{{-2.625, -1.}, {-2.6377778151415994`, -0.9029428580865547}, \
{-2.5625, -1.}, {-2.625, -1.}}], 
      PolygonBox[{{-2.562500018967059, -0.9157074104439382}, {-2.5625, -1.}, \
{-2.6377778151415994`, -0.9029428580865547}, {-2.562500018967059, \
-0.9157074104439382}}], 
      PolygonBox[{{-2.6377778151415994`, -0.9029428580865547}, \
{-2.6752404735808355`, -0.8125}, {-2.562500018967059, -0.9157074104439382}, \
{-2.6377778151415994`, -0.9029428580865547}}], 
      PolygonBox[{{-2.5626550066464766`, -0.7697483574637449}, \
{-2.562500018967059, -0.9157074104439382}, {-2.6752404735808355`, -0.8125}, \
{-2.5626550066464766`, -0.7697483574637449}}], 
      PolygonBox[{{-2.6752404735808355`, -0.8125}, {-2.7348349570550448`, \
-0.7348349570550448}, {-2.5626550066464766`, -0.7697483574637449}, \
{-2.6752404735808355`, -0.8125}}], 
      PolygonBox[{{-2.595057255667003, -0.5950572556670028}, \
{-2.5626550066464766`, -0.7697483574637449}, {-2.7348349570550448`, \
-0.7348349570550448}, {-2.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{-2.7348349570550448`, -0.7348349570550448}, {-2.8125, \
-0.6752404735808355}, {-2.595057255667003, -0.5950572556670028}, \
{-2.7348349570550448`, -0.7348349570550448}}], 
      PolygonBox[{{-2.7697483574637447`, -0.5626550066464766}, \
{-2.595057255667003, -0.5950572556670028}, {-2.8125, -0.6752404735808355}, \
{-2.7697483574637447`, -0.5626550066464766}}], 
      PolygonBox[{{-2.8125, -0.6752404735808355}, {-2.9029428580865546`, \
-0.6377778151415994}, {-2.7697483574637447`, -0.5626550066464766}, {-2.8125, \
-0.6752404735808355}}], 
      PolygonBox[{{-2.9157074104439396`, -0.5625000189670593}, \
{-2.7697483574637447`, -0.5626550066464766}, {-2.9029428580865546`, \
-0.6377778151415994}, {-2.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-2.9029428580865546`, -0.6377778151415994}, {-3., -0.625}, \
{-2.9157074104439396`, -0.5625000189670593}, {-2.9029428580865546`, \
-0.6377778151415994}}], 
      PolygonBox[{{-2.9998944727795123`, -0.5625}, {-2.9157074104439396`, \
-0.5625000189670593}, {-3., -0.625}, {-2.9998944727795123`, -0.5625}}], 
      PolygonBox[{{-3., -0.625}, {-3.097057141913445, -0.6377778151415994}, \
{-2.9998944727795123`, -0.5625}, {-3., -0.625}}], 
      PolygonBox[{{-3.084292589556057, -0.5625000189670593}, \
{-2.9998944727795123`, -0.5625}, {-3.097057141913445, -0.6377778151415994}, \
{-3.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-3.097057141913445, -0.6377778151415994}, {-3.1875, \
-0.6752404735808355}, {-3.084292589556057, -0.5625000189670593}, \
{-3.097057141913445, -0.6377778151415994}}], 
      PolygonBox[{{-3.230251642536255, -0.5626550066464766}, \
{-3.084292589556057, -0.5625000189670593}, {-3.1875, -0.6752404735808355}, \
{-3.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-3.1875, -0.6752404735808355}, {-3.2651650429449552`, \
-0.7348349570550446}, {-3.230251642536255, -0.5626550066464766}, {-3.1875, \
-0.6752404735808355}}], 
      PolygonBox[{{-3.404942744332997, -0.5950572556670028}, \
{-3.230251642536255, -0.5626550066464766}, {-3.2651650429449552`, \
-0.7348349570550446}, {-3.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{-3.2651650429449552`, -0.7348349570550446}, \
{-3.3247595264191645`, -0.8124999999999999}, {-3.404942744332997, \
-0.5950572556670028}, {-3.2651650429449552`, -0.7348349570550446}}], 
      PolygonBox[{{-3.4373449933535234`, -0.7697483574637446}, \
{-3.404942744332997, -0.5950572556670028}, {-3.3247595264191645`, \
-0.8124999999999999}, {-3.4373449933535234`, -0.7697483574637446}}], 
      PolygonBox[{{-3.3247595264191645`, -0.8124999999999999}, \
{-3.3622221848584006`, -0.9029428580865546}, {-3.4373449933535234`, \
-0.7697483574637446}, {-3.3247595264191645`, -0.8124999999999999}}], 
      PolygonBox[{{-3.437499981032941, -0.9157074104439377}, \
{-3.4373449933535234`, -0.7697483574637446}, {-3.3622221848584006`, \
-0.9029428580865546}, {-3.437499981032941, -0.9157074104439377}}], 
      PolygonBox[{{-3.3622221848584006`, -0.9029428580865546}, {-3.375, \
-0.9999999999999998}, {-3.437499981032941, -0.9157074104439377}, \
{-3.3622221848584006`, -0.9029428580865546}}], 
      PolygonBox[{{-3.4375, -0.9998768219370047}, {-3.437499981032941, \
-0.9157074104439377}, {-3.375, -0.9999999999999998}, {-3.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-3.375, -0.9999999999999998}, {-3.3622221848584006`, \
-1.0970571419134452`}, {-3.4375, -0.9998768219370047}, {-3.375, \
-0.9999999999999998}}], 
      PolygonBox[{{-3.437499981032941, -1.084292589556055}, {-3.4375, \
-0.9998768219370047}, {-3.3622221848584006`, -1.0970571419134452`}, \
{-3.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-3.3622221848584006`, -1.0970571419134452`}, \
{-3.3247595264191645`, -1.1874999999999998`}, {-3.437499981032941, \
-1.084292589556055}, {-3.3622221848584006`, -1.0970571419134452`}}], 
      PolygonBox[{{-3.4373449933535234`, -1.2302516425362549`}, \
{-3.437499981032941, -1.084292589556055}, {-3.3247595264191645`, \
-1.1874999999999998`}, {-3.4373449933535234`, -1.2302516425362549`}}], 
      PolygonBox[{{-3.3247595264191645`, -1.1874999999999998`}, \
{-3.2651650429449552`, -1.2651650429449552`}, {-3.4373449933535234`, \
-1.2302516425362549`}, {-3.3247595264191645`, -1.1874999999999998`}}], 
      PolygonBox[{{-3.404942744332997, -1.4049427443329972`}, \
{-3.4373449933535234`, -1.2302516425362549`}, {-3.2651650429449552`, \
-1.2651650429449552`}, {-3.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-3.2651650429449552`, -1.2651650429449552`}, {-3.1875, \
-1.3247595264191645`}, {-3.404942744332997, -1.4049427443329972`}, \
{-3.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{-3.230251642536255, -1.4373449933535234`}, \
{-3.404942744332997, -1.4049427443329972`}, {-3.1875, -1.3247595264191645`}, \
{-3.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-3.1875, -1.3247595264191645`}, {-3.0970571419134454`, \
-1.3622221848584006`}, {-3.230251642536255, -1.4373449933535234`}, {-3.1875, \
-1.3247595264191645`}}], 
      PolygonBox[{{-3.084292589556064, -1.4374999810329407`}, \
{-3.230251642536255, -1.4373449933535234`}, {-3.0970571419134454`, \
-1.3622221848584006`}, {-3.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-3.0970571419134454`, -1.3622221848584006`}, {-3., \
-1.375}, {-3.084292589556064, -1.4374999810329407`}, {-3.0970571419134454`, \
-1.3622221848584006`}}], 
      PolygonBox[{{-2.999865158168957, -1.4375}, {-3.084292589556064, \
-1.4374999810329407`}, {-3., -1.375}, {-2.999865158168957, -1.4375}}], 
      PolygonBox[{{-3., -1.375}, {-2.902942858086555, -1.3622221848584006`}, \
{-2.999865158168957, -1.4375}, {-3., -1.375}}], 
      PolygonBox[{{-2.9157074104439467`, -1.4374999810329407`}, \
{-2.999865158168957, -1.4375}, {-2.902942858086555, -1.3622221848584006`}, \
{-2.9157074104439467`, -1.4374999810329407`}}], 
      PolygonBox[{{-2.902942858086555, -1.3622221848584006`}, \
{-2.8125000000000004`, -1.3247595264191645`}, {-2.9157074104439467`, \
-1.4374999810329407`}, {-2.902942858086555, -1.3622221848584006`}}], 
      PolygonBox[{{-2.769748357463745, -1.4373449933535234`}, \
{-2.9157074104439467`, -1.4374999810329407`}, {-2.8125000000000004`, \
-1.3247595264191645`}, {-2.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{-2.8125000000000004`, -1.3247595264191645`}, \
{-2.7348349570550448`, -1.2651650429449552`}, {-2.769748357463745, \
-1.4373449933535234`}, {-2.8125000000000004`, -1.3247595264191645`}}], 
      PolygonBox[{{-2.595057255667003, -1.4049427443329972`}, \
{-2.769748357463745, -1.4373449933535234`}, {-2.7348349570550448`, \
-1.2651650429449552`}, {-2.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-2.7348349570550448`, -1.2651650429449552`}, \
{-2.7348349570550448`, -1.2651650429449552`}, {-2.595057255667003, \
-1.4049427443329972`}, {-2.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{-2.595057255667003, -1.4049427443329972`}, \
{-2.595057255667003, -1.4049427443329972`}, {-2.7348349570550448`, \
-1.2651650429449552`}, {-2.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-2.595057255667003, -1.4049427443329972`}, \
{-2.5626550066464766`, -1.230251642536255}, {-2.5, -1.5}, \
{-2.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-2.5, -1.3576627826493677`}, {-2.5, -1.5}, \
{-2.5626550066464766`, -1.230251642536255}, {-2.5, -1.3576627826493677`}}], 
      PolygonBox[{{-2.5626550066464766`, -1.230251642536255}, \
{-2.562500018967059, -1.0842925895560618`}, {-2.5, -1.3576627826493677`}, \
{-2.5626550066464766`, -1.230251642536255}}], 
      PolygonBox[{{-2.5, -1.20590900530174}, {-2.5, -1.3576627826493677`}, \
{-2.562500018967059, -1.0842925895560618`}, {-2.5, -1.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, -1.0842925895560618`}, {-2.5625, -1.}, \
{-2.5, -1.20590900530174}, {-2.562500018967059, -1.0842925895560618`}}], 
      PolygonBox[{{-2.5, -1.}, {-2.5, -1.20590900530174}, {-2.5625, -1.}, \
{-2.5, -1.}}], 
      PolygonBox[{{-2.5625, -1.}, {-2.562500018967059, -0.9157074104439382}, \
{-2.5, -1.}, {-2.5625, -1.}}], 
      PolygonBox[{{-2.5, -0.79409099469826}, {-2.5, -1.}, \
{-2.562500018967059, -0.9157074104439382}, {-2.5, -0.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, -0.9157074104439382}, \
{-2.5626550066464766`, -0.7697483574637449}, {-2.5, -0.79409099469826}, \
{-2.562500018967059, -0.9157074104439382}}], 
      PolygonBox[{{-2.5, -0.6423372173506324}, {-2.5, -0.79409099469826}, \
{-2.5626550066464766`, -0.7697483574637449}, {-2.5, -0.6423372173506324}}], 
      PolygonBox[{{-2.5626550066464766`, -0.7697483574637449}, \
{-2.595057255667003, -0.5950572556670028}, {-2.5, -0.6423372173506324}, \
{-2.5626550066464766`, -0.7697483574637449}}], 
      PolygonBox[{{-2.508553435038814, -0.508553435038814}, {-2.5, \
-0.6423372173506324}, {-2.595057255667003, -0.5950572556670028}, \
{-2.508553435038814, -0.508553435038814}}], 
      PolygonBox[{{-2.595057255667003, -0.5950572556670028}, \
{-2.7697483574637447`, -0.5626550066464766}, {-2.508553435038814, \
-0.508553435038814}, {-2.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{-2.642337217350632, -0.5}, {-2.508553435038814, \
-0.508553435038814}, {-2.7697483574637447`, -0.5626550066464766}, \
{-2.642337217350632, -0.5}}], 
      PolygonBox[{{-2.7697483574637447`, -0.5626550066464766}, \
{-2.9157074104439396`, -0.5625000189670593}, {-2.642337217350632, -0.5}, \
{-2.7697483574637447`, -0.5626550066464766}}], 
      PolygonBox[{{-2.7940909946267443`, -0.5}, {-2.642337217350632, -0.5}, \
{-2.9157074104439396`, -0.5625000189670593}, {-2.7940909946267443`, -0.5}}], 
      PolygonBox[{{-2.9157074104439396`, -0.5625000189670593}, \
{-2.9998944727795123`, -0.5625}, {-2.7940909946267443`, -0.5}, \
{-2.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-2.92205804197311, -0.5}, {-2.7940909946267443`, -0.5}, \
{-2.9998944727795123`, -0.5625}, {-2.92205804197311, -0.5}}], 
      PolygonBox[{{-2.9998944727795123`, -0.5625}, {-3.084292589556057, \
-0.5625000189670593}, {-2.92205804197311, -0.5}, {-2.9998944727795123`, \
-0.5625}}], 
      PolygonBox[{{-3.2059090053044454`, -0.5}, {-2.92205804197311, -0.5}, \
{-3.084292589556057, -0.5625000189670593}, {-3.2059090053044454`, -0.5}}], 
      PolygonBox[{{-3.084292589556057, -0.5625000189670593}, \
{-3.230251642536255, -0.5626550066464766}, {-3.2059090053044454`, -0.5}, \
{-3.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-3.357662782649366, -0.5}, {-3.2059090053044454`, -0.5}, \
{-3.230251642536255, -0.5626550066464766}, {-3.357662782649366, -0.5}}], 
      PolygonBox[{{-3.230251642536255, -0.5626550066464766}, \
{-3.404942744332997, -0.5950572556670028}, {-3.357662782649366, -0.5}, \
{-3.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-2.5, -0.5}, {-3.357662782649366, -0.5}, \
{-3.404942744332997, -0.5950572556670028}, {-2.5, -0.5}}], 
      PolygonBox[{{-3.404942744332997, -0.5950572556670028}, \
{-3.4373449933535234`, -0.7697483574637446}, {-2.5, -0.5}, \
{-3.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{-3.5, -0.642337217350631}, {-2.5, -0.5}, \
{-3.4373449933535234`, -0.7697483574637446}, {-3.5, -0.642337217350631}}], 
      PolygonBox[{{-3.4373449933535234`, -0.7697483574637446}, \
{-3.437499981032941, -0.9157074104439377}, {-3.5, -0.642337217350631}, \
{-3.4373449933535234`, -0.7697483574637446}}], 
      PolygonBox[{{-3.5, -0.7940909947171011}, {-3.5, -0.642337217350631}, \
{-3.437499981032941, -0.9157074104439377}, {-3.5, -0.7940909947171011}}], 
      PolygonBox[{{-3.437499981032941, -0.9157074104439377}, {-3.4375, \
-0.9998768219370047}, {-3.5, -0.7940909947171011}, {-3.437499981032941, \
-0.9157074104439377}}], 
      PolygonBox[{{-3.5, -0.9193213332412997}, {-3.5, -0.7940909947171011}, \
{-3.4375, -0.9998768219370047}, {-3.5, -0.9193213332412997}}], 
      PolygonBox[{{-3.4375, -0.9998768219370047}, {-3.437499981032941, \
-1.084292589556055}, {-3.5, -0.9193213332412997}, {-3.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-3.5, -1.2059090051452785`}, {-3.5, -0.9193213332412997}, \
{-3.437499981032941, -1.084292589556055}, {-3.5, -1.2059090051452785`}}], 
      PolygonBox[{{-3.437499981032941, -1.084292589556055}, \
{-3.4373449933535234`, -1.2302516425362549`}, {-3.5, -1.2059090051452785`}, \
{-3.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-3.5, -1.3576627826493652`}, {-3.5, -1.2059090051452785`}, \
{-3.4373449933535234`, -1.2302516425362549`}, {-3.5, -1.3576627826493652`}}], 
      PolygonBox[{{-3.4373449933535234`, -1.2302516425362549`}, \
{-3.404942744332997, -1.4049427443329972`}, {-3.5, -1.3576627826493652`}, \
{-3.4373449933535234`, -1.2302516425362549`}}], 
      PolygonBox[{{-3.5, -0.5}, {-3.5, -1.3576627826493652`}, \
{-3.404942744332997, -1.4049427443329972`}, {-3.5, -0.5}}], 
      PolygonBox[{{-3.404942744332997, -1.4049427443329972`}, \
{-3.230251642536255, -1.4373449933535234`}, {-3.5, -0.5}, \
{-3.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-3.5, -1.5}, {-3.5, -0.5}, {-3.230251642536255, \
-1.4373449933535234`}, {-3.5, -1.5}}], 
      PolygonBox[{{-3.230251642536255, -1.4373449933535234`}, \
{-3.084292589556064, -1.4374999810329407`}, {-3.5, -1.5}, \
{-3.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-3.205909005566828, -1.5}, {-3.5, -1.5}, \
{-3.084292589556064, -1.4374999810329407`}, {-3.205909005566828, -1.5}}], 
      PolygonBox[{{-3.084292589556064, -1.4374999810329407`}, \
{-2.999865158168957, -1.4375}, {-3.205909005566828, -1.5}, \
{-3.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-2.9176761295989384`, -1.5}, {-3.205909005566828, -1.5}, \
{-2.999865158168957, -1.4375}, {-2.9176761295989384`, -1.5}}], 
      PolygonBox[{{-2.999865158168957, -1.4375}, {-2.9157074104439467`, \
-1.4374999810329407`}, {-2.9176761295989384`, -1.5}, {-2.999865158168957, \
-1.4375}}], 
      PolygonBox[{{-2.7940909946396024`, -1.5}, {-2.9176761295989384`, -1.5}, \
{-2.9157074104439467`, -1.4374999810329407`}, {-2.7940909946396024`, -1.5}}], 
      PolygonBox[{{-2.9157074104439467`, -1.4374999810329407`}, \
{-2.769748357463745, -1.4373449933535234`}, {-2.7940909946396024`, -1.5}, \
{-2.9157074104439467`, -1.4374999810329407`}}], 
      PolygonBox[{{-2.642337217350629, -1.5}, {-2.7940909946396024`, -1.5}, \
{-2.769748357463745, -1.4373449933535234`}, {-2.642337217350629, -1.5}}], 
      PolygonBox[{{-2.769748357463745, -1.4373449933535234`}, \
{-2.595057255667003, -1.4049427443329972`}, {-2.642337217350629, -1.5}, \
{-2.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{-2.5, -1.5}, {-2.642337217350629, -1.5}, \
{-2.595057255667003, -1.4049427443329972`}, {-2.5, -1.5}}], 
      PolygonBox[{{-2.595057255667003, -1.4049427443329972`}, \
{-2.595057255667003, -1.4049427443329972`}, {-2.5, -1.5}, \
{-2.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{-2.5, -1.5}, {-2.5, -1.5}, {-2.595057255667003, \
-1.4049427443329972`}, {-2.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, 0.}, {-3.4791666666666665`, 0.}, {-3.4583333333333335`, 
       0.}, {-3.4375, 0.}, {-3.4166666666666665`, 0.}, {-3.3958333333333335`, 
       0.}, {-3.375, 0.}, {-3.375, 0.}, {-3.3958333333333335`, 
       0.}, {-3.4166666666666665`, 0.}, {-3.4375, 0.}, {-3.4583333333333335`, 
       0.}, {-3.4791666666666665`, 0.}, {-3.5, 0.}, {-3.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, 0.}, {-2.6041666666666665`, 
       0.}, {-2.5833333333333335`, 0.}, {-2.5625, 0.}, {-2.5416666666666665`, 
       0.}, {-2.5208333333333335`, 0.}, {-2.5, 0.}, {-2.5, 
       0.}, {-2.5208333333333335`, 0.}, {-2.5416666666666665`, 0.}, {-2.5625, 
       0.}, {-2.5833333333333335`, 0.}, {-2.6041666666666665`, 0.}, {-2.625, 
       0.}, {-2.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -0.5}, {-3., -0.4791666666666667}, {-3., \
-0.4583333333333333}, {-3., -0.4375}, {-3., -0.4166666666666667}, {-3., \
-0.39583333333333337`}, {-3., -0.375}, {-3., -0.375}, {-3., \
-0.3958333333333333}, {-3., -0.4166666666666667}, {-3., -0.4375}, {-3., \
-0.4583333333333333}, {-3., -0.47916666666666663`}, {-3., -0.5}, {-3., \
-0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 0.375}, {-3., 0.3958333333333333}, {-3., 
       0.4166666666666667}, {-3., 0.4375}, {-3., 0.4583333333333333}, {-3., 
       0.47916666666666663`}, {-3., 0.5}, {-3., 0.5}, {-3., 
       0.4791666666666667}, {-3., 0.4583333333333333}, {-3., 0.4375}, {-3., 
       0.4166666666666667}, {-3., 0.39583333333333337`}, {-3., 0.375}, {-3., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, 0.}, {-3.25, 0.}, {-3.125, 0.}, {-3., 0.}, {-2.875, 
       0.}, {-2.75, 0.}, {-2.625, 0.}, {-2.625, 0.}, {-2.75, 0.}, {-2.875, 
       0.}, {-3., 0.}, {-3.125, 0.}, {-3.25, 0.}, {-3.375, 0.}, {-3.375, 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -0.375}, {-3., -0.25}, {-3., -0.125}, {-3., 0.}, {-3., 
       0.125}, {-3., 0.25}, {-3., 0.375}, {-3., 0.375}, {-3., 0.25}, {-3., 
       0.125}, {-3., 
       0.}, {-3., -0.125}, {-3., -0.25}, {-3., -0.375}, {-3., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsB2AsMb1AR20p1gM3OmMW7bmxw/7CDvOqJ2ms
B/6DwXH7VKEUtY8PWA/czLl/puzHBXuwpga2Aw2WTnp3Tlyx3yj9VsrKkv2A
f3/Z16V61yHyDBxQ82/Y+z8Renr0GMeBAGT5Bk64/tlvZ9/kk+c6cAtqvoH7
iVbpmVwHWMAKT9i/urhu35WnXAceQN0HMZf7AFfXPB/Lyi4bmPw5iPx+mP4/
EPfvnwM1/zrE/P0w++sg9u+Huc8P4r79aO7fvwnqP6j79zNC/d8E1Q8LH6j7
98PCjw3i/v2w8H0HdR8s/CHun7UHAB8crxU=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByD0A/tQMGCF81evAgE2OB9Cc6Cp54TzwcpX
caGp5yHIDwObcxWNfxRNPQzwHAiByO9H5V/dj6r+AQZ/Nar79qO5fz+a//aj
+X9/GGr4QNWzEOSHobgPxj+Kph4GWGD+s0flX7VHVf/AHgCKGmKQ
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, -0.2651650429449553}, \
{-2.6752404735808355`, -0.1875}, {-2.595057255667003, -0.4049427443329971}, \
{-2.7348349570550448`, -0.2651650429449553}}], 
      PolygonBox[{{-2.5626550066464766`, -0.23025164253625516`}, \
{-2.595057255667003, -0.4049427443329971}, {-2.6752404735808355`, -0.1875}, \
{-2.5626550066464766`, -0.23025164253625516`}}], 
      PolygonBox[{{-2.6752404735808355`, -0.1875}, {-2.6377778151415994`, \
-0.0970571419134453}, {-2.5626550066464766`, -0.23025164253625516`}, \
{-2.6752404735808355`, -0.1875}}], 
      PolygonBox[{{-2.562500018967059, -0.08429258955606181}, \
{-2.5626550066464766`, -0.23025164253625516`}, {-2.6377778151415994`, \
-0.0970571419134453}, {-2.562500018967059, -0.08429258955606181}}], 
      PolygonBox[{{-2.6377778151415994`, -0.0970571419134453}, {-2.625, 
       0.}, {-2.562500018967059, -0.08429258955606181}, \
{-2.6377778151415994`, -0.0970571419134453}}], 
      PolygonBox[{{-2.5625, 
       0.}, {-2.562500018967059, -0.08429258955606181}, {-2.625, 
       0.}, {-2.5625, 0.}}], 
      PolygonBox[{{-2.625, 0.}, {-2.6377778151415994`, 
       0.09705714191344525}, {-2.5625, 0.}, {-2.625, 0.}}], 
      PolygonBox[{{-2.562500018967059, 0.08429258955606177}, {-2.5625, 
       0.}, {-2.6377778151415994`, 0.09705714191344525}, {-2.562500018967059, 
       0.08429258955606177}}], 
      PolygonBox[{{-2.6377778151415994`, 
       0.09705714191344525}, {-2.6752404735808355`, 
       0.18749999999999994`}, {-2.562500018967059, 
       0.08429258955606177}, {-2.6377778151415994`, 0.09705714191344525}}], 
      PolygonBox[{{-2.5626550066464766`, 
       0.23025164253625502`}, {-2.562500018967059, 
       0.08429258955606177}, {-2.6752404735808355`, 
       0.18749999999999994`}, {-2.5626550066464766`, 0.23025164253625502`}}], 
      PolygonBox[{{-2.6752404735808355`, 
       0.18749999999999994`}, {-2.7348349570550448`, 
       0.2651650429449553}, {-2.5626550066464766`, 
       0.23025164253625502`}, {-2.6752404735808355`, 0.18749999999999994`}}], 
      PolygonBox[{{-2.595057255667003, 
       0.40494274433299715`}, {-2.5626550066464766`, 
       0.23025164253625502`}, {-2.7348349570550448`, 
       0.2651650429449553}, {-2.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{-2.7348349570550448`, 0.2651650429449553}, {-2.8125, 
       0.3247595264191645}, {-2.595057255667003, 
       0.40494274433299715`}, {-2.7348349570550448`, 0.2651650429449553}}], 
      PolygonBox[{{-2.7697483574637447`, 
       0.4373449933535234}, {-2.595057255667003, 
       0.40494274433299715`}, {-2.8125, 
       0.3247595264191645}, {-2.7697483574637447`, 0.4373449933535234}}], 
      PolygonBox[{{-2.8125, 0.3247595264191645}, {-2.9029428580865546`, 
       0.3622221848584006}, {-2.7697483574637447`, 
       0.4373449933535234}, {-2.8125, 0.3247595264191645}}], 
      PolygonBox[{{-2.9157074104439396`, 
       0.4374999810329408}, {-2.7697483574637447`, 
       0.4373449933535234}, {-2.9029428580865546`, 
       0.3622221848584006}, {-2.9157074104439396`, 0.4374999810329408}}], 
      PolygonBox[{{-2.9029428580865546`, 0.3622221848584006}, {-3., 
       0.375}, {-2.9157074104439396`, 
       0.4374999810329408}, {-2.9029428580865546`, 0.3622221848584006}}], 
      PolygonBox[{{-2.9998944727795123`, 0.4375}, {-2.9157074104439396`, 
       0.4374999810329408}, {-3., 0.375}, {-2.9998944727795123`, 0.4375}}], 
      PolygonBox[{{-3., 0.375}, {-3.097057141913445, 
       0.36222218485840063`}, {-2.9998944727795123`, 0.4375}, {-3., 0.375}}], 
      PolygonBox[{{-3.084292589556057, 
       0.4374999810329408}, {-2.9998944727795123`, 
       0.4375}, {-3.097057141913445, 
       0.36222218485840063`}, {-3.084292589556057, 0.4374999810329408}}], 
      PolygonBox[{{-3.097057141913445, 0.36222218485840063`}, {-3.1875, 
       0.3247595264191645}, {-3.084292589556057, 
       0.4374999810329408}, {-3.097057141913445, 0.36222218485840063`}}], 
      PolygonBox[{{-3.230251642536255, 
       0.4373449933535234}, {-3.084292589556057, 
       0.4374999810329408}, {-3.1875, 
       0.3247595264191645}, {-3.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{-3.1875, 0.3247595264191645}, {-3.2651650429449552`, 
       0.26516504294495535`}, {-3.230251642536255, 
       0.4373449933535234}, {-3.1875, 0.3247595264191645}}], 
      PolygonBox[{{-3.404942744332997, 
       0.40494274433299715`}, {-3.230251642536255, 
       0.4373449933535234}, {-3.2651650429449552`, 
       0.26516504294495535`}, {-3.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{-3.2651650429449552`, 
       0.26516504294495535`}, {-3.3247595264191645`, 
       0.1875000000000001}, {-3.404942744332997, 
       0.40494274433299715`}, {-3.2651650429449552`, 0.26516504294495535`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       0.2302516425362554}, {-3.404942744332997, 
       0.40494274433299715`}, {-3.3247595264191645`, 
       0.1875000000000001}, {-3.4373449933535234`, 0.2302516425362554}}], 
      PolygonBox[{{-3.3247595264191645`, 
       0.1875000000000001}, {-3.3622221848584006`, 
       0.09705714191344539}, {-3.4373449933535234`, 
       0.2302516425362554}, {-3.3247595264191645`, 0.1875000000000001}}], 
      PolygonBox[{{-3.437499981032941, 
       0.08429258955606238}, {-3.4373449933535234`, 
       0.2302516425362554}, {-3.3622221848584006`, 
       0.09705714191344539}, {-3.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-3.3622221848584006`, 0.09705714191344539}, {-3.375, 
       2.1245770866179924`*^-16}, {-3.437499981032941, 
       0.08429258955606238}, {-3.3622221848584006`, 0.09705714191344539}}], 
      PolygonBox[{{-3.4375, 0.00012317806299537147`}, {-3.437499981032941, 
       0.08429258955606238}, {-3.375, 2.1245770866179924`*^-16}, {-3.4375, 
       0.00012317806299537147`}}], 
      PolygonBox[{{-3.375, 
       2.1245770866179924`*^-16}, {-3.3622221848584006`, \
-0.09705714191344514}, {-3.4375, 0.00012317806299537147`}, {-3.375, 
       2.1245770866179924`*^-16}}], 
      PolygonBox[{{-3.437499981032941, -0.084292589556055}, {-3.4375, 
       0.00012317806299537147`}, {-3.3622221848584006`, \
-0.09705714191344514}, {-3.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-3.3622221848584006`, -0.09705714191344514}, \
{-3.3247595264191645`, -0.18749999999999978`}, {-3.437499981032941, \
-0.084292589556055}, {-3.3622221848584006`, -0.09705714191344514}}], 
      PolygonBox[{{-3.4373449933535234`, -0.23025164253625477`}, \
{-3.437499981032941, -0.084292589556055}, {-3.3247595264191645`, \
-0.18749999999999978`}, {-3.4373449933535234`, -0.23025164253625477`}}], 
      PolygonBox[{{-3.3247595264191645`, -0.18749999999999978`}, \
{-3.2651650429449552`, -0.2651650429449553}, {-3.4373449933535234`, \
-0.23025164253625477`}, {-3.3247595264191645`, -0.18749999999999978`}}], 
      PolygonBox[{{-3.404942744332997, -0.4049427443329971}, \
{-3.4373449933535234`, -0.23025164253625477`}, {-3.2651650429449552`, \
-0.2651650429449553}, {-3.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-3.2651650429449552`, -0.2651650429449553}, {-3.1875, \
-0.3247595264191644}, {-3.404942744332997, -0.4049427443329971}, \
{-3.2651650429449552`, -0.2651650429449553}}], 
      PolygonBox[{{-3.230251642536255, -0.4373449933535234}, \
{-3.404942744332997, -0.4049427443329971}, {-3.1875, -0.3247595264191644}, \
{-3.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{-3.1875, -0.3247595264191644}, {-3.0970571419134454`, \
-0.3622221848584005}, {-3.230251642536255, -0.4373449933535234}, {-3.1875, \
-0.3247595264191644}}], 
      PolygonBox[{{-3.084292589556064, -0.4374999810329408}, \
{-3.230251642536255, -0.4373449933535234}, {-3.0970571419134454`, \
-0.3622221848584005}, {-3.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-3.0970571419134454`, -0.3622221848584005}, {-3., -0.375}, \
{-3.084292589556064, -0.4374999810329408}, {-3.0970571419134454`, \
-0.3622221848584005}}], 
      PolygonBox[{{-2.999865158168957, -0.4375}, {-3.084292589556064, \
-0.4374999810329408}, {-3., -0.375}, {-2.999865158168957, -0.4375}}], 
      PolygonBox[{{-3., -0.375}, {-2.902942858086555, -0.36222218485840063`}, \
{-2.999865158168957, -0.4375}, {-3., -0.375}}], 
      PolygonBox[{{-2.9157074104439467`, -0.4374999810329408}, \
{-2.999865158168957, -0.4375}, {-2.902942858086555, -0.36222218485840063`}, \
{-2.9157074104439467`, -0.4374999810329408}}], 
      PolygonBox[{{-2.902942858086555, -0.36222218485840063`}, \
{-2.8125000000000004`, -0.3247595264191646}, {-2.9157074104439467`, \
-0.4374999810329408}, {-2.902942858086555, -0.36222218485840063`}}], 
      PolygonBox[{{-2.769748357463745, -0.4373449933535234}, \
{-2.9157074104439467`, -0.4374999810329408}, {-2.8125000000000004`, \
-0.3247595264191646}, {-2.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{-2.8125000000000004`, -0.3247595264191646}, \
{-2.7348349570550448`, -0.26516504294495535`}, {-2.769748357463745, \
-0.4373449933535234}, {-2.8125000000000004`, -0.3247595264191646}}], 
      PolygonBox[{{-2.595057255667003, -0.40494274433299715`}, \
{-2.769748357463745, -0.4373449933535234}, {-2.7348349570550448`, \
-0.26516504294495535`}, {-2.595057255667003, -0.40494274433299715`}}], 
      PolygonBox[{{-2.7348349570550448`, -0.26516504294495535`}, \
{-2.7348349570550448`, -0.2651650429449553}, {-2.595057255667003, \
-0.40494274433299715`}, {-2.7348349570550448`, -0.26516504294495535`}}], 
      PolygonBox[{{-2.595057255667003, -0.4049427443329971}, \
{-2.595057255667003, -0.40494274433299715`}, {-2.7348349570550448`, \
-0.2651650429449553}, {-2.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{-2.595057255667003, -0.4049427443329971}, \
{-2.5626550066464766`, -0.23025164253625516`}, {-2.5, -0.5}, \
{-2.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{-2.5, -0.3576627826493677}, {-2.5, -0.5}, \
{-2.5626550066464766`, -0.23025164253625516`}, {-2.5, -0.3576627826493677}}], 
      PolygonBox[{{-2.5626550066464766`, -0.23025164253625516`}, \
{-2.562500018967059, -0.08429258955606181}, {-2.5, -0.3576627826493677}, \
{-2.5626550066464766`, -0.23025164253625516`}}], 
      PolygonBox[{{-2.5, -0.20590900530173997`}, {-2.5, -0.3576627826493677}, \
{-2.562500018967059, -0.08429258955606181}, {-2.5, -0.20590900530173997`}}], 
      PolygonBox[{{-2.562500018967059, -0.08429258955606181}, {-2.5625, 
       0.}, {-2.5, -0.20590900530173997`}, {-2.562500018967059, \
-0.08429258955606181}}], 
      PolygonBox[{{-2.5, 0.}, {-2.5, -0.20590900530173997`}, {-2.5625, 
       0.}, {-2.5, 0.}}], 
      PolygonBox[{{-2.5625, 0.}, {-2.562500018967059, 
       0.08429258955606177}, {-2.5, 0.}, {-2.5625, 0.}}], 
      PolygonBox[{{-2.5, 0.20590900530173992`}, {-2.5, 
       0.}, {-2.562500018967059, 0.08429258955606177}, {-2.5, 
       0.20590900530173992`}}], 
      PolygonBox[{{-2.562500018967059, 
       0.08429258955606177}, {-2.5626550066464766`, 
       0.23025164253625502`}, {-2.5, 
       0.20590900530173992`}, {-2.562500018967059, 0.08429258955606177}}], 
      PolygonBox[{{-2.5, 0.35766278264936757`}, {-2.5, 
       0.20590900530173992`}, {-2.5626550066464766`, 
       0.23025164253625502`}, {-2.5, 0.35766278264936757`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       0.23025164253625502`}, {-2.595057255667003, 
       0.40494274433299715`}, {-2.5, 
       0.35766278264936757`}, {-2.5626550066464766`, 0.23025164253625502`}}], 
      PolygonBox[{{-2.508553435038814, 0.491446564961186}, {-2.5, 
       0.35766278264936757`}, {-2.595057255667003, 
       0.40494274433299715`}, {-2.508553435038814, 0.491446564961186}}], 
      PolygonBox[{{-2.595057255667003, 
       0.40494274433299715`}, {-2.7697483574637447`, 
       0.4373449933535234}, {-2.508553435038814, 
       0.491446564961186}, {-2.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{-2.642337217350632, 0.5}, {-2.508553435038814, 
       0.491446564961186}, {-2.7697483574637447`, 
       0.4373449933535234}, {-2.642337217350632, 0.5}}], 
      PolygonBox[{{-2.7697483574637447`, 
       0.4373449933535234}, {-2.9157074104439396`, 
       0.4374999810329408}, {-2.642337217350632, 0.5}, {-2.7697483574637447`, 
       0.4373449933535234}}], 
      PolygonBox[{{-2.7940909946267443`, 0.5}, {-2.642337217350632, 
       0.5}, {-2.9157074104439396`, 
       0.4374999810329408}, {-2.7940909946267443`, 0.5}}], 
      PolygonBox[{{-2.9157074104439396`, 
       0.4374999810329408}, {-2.9998944727795123`, 
       0.4375}, {-2.7940909946267443`, 0.5}, {-2.9157074104439396`, 
       0.4374999810329408}}], 
      PolygonBox[{{-2.92205804197311, 0.5}, {-2.7940909946267443`, 
       0.5}, {-2.9998944727795123`, 0.4375}, {-2.92205804197311, 0.5}}], 
      PolygonBox[{{-2.9998944727795123`, 0.4375}, {-3.084292589556057, 
       0.4374999810329408}, {-2.92205804197311, 0.5}, {-2.9998944727795123`, 
       0.4375}}], 
      PolygonBox[{{-3.2059090053044454`, 0.5}, {-2.92205804197311, 
       0.5}, {-3.084292589556057, 0.4374999810329408}, {-3.2059090053044454`, 
       0.5}}], PolygonBox[{{-3.084292589556057, 
       0.4374999810329408}, {-3.230251642536255, 
       0.4373449933535234}, {-3.2059090053044454`, 0.5}, {-3.084292589556057, 
       0.4374999810329408}}], 
      PolygonBox[{{-3.357662782649366, 0.5}, {-3.2059090053044454`, 
       0.5}, {-3.230251642536255, 0.4373449933535234}, {-3.357662782649366, 
       0.5}}], PolygonBox[{{-3.230251642536255, 
       0.4373449933535234}, {-3.404942744332997, 
       0.40494274433299715`}, {-3.357662782649366, 0.5}, {-3.230251642536255, 
       0.4373449933535234}}], 
      PolygonBox[{{-2.5, 0.5}, {-3.357662782649366, 0.5}, {-3.404942744332997,
        0.40494274433299715`}, {-2.5, 0.5}}], 
      PolygonBox[{{-3.404942744332997, 
       0.40494274433299715`}, {-3.4373449933535234`, 
       0.2302516425362554}, {-2.5, 0.5}, {-3.404942744332997, 
       0.40494274433299715`}}], 
      PolygonBox[{{-3.5, 0.357662782649369}, {-2.5, 
       0.5}, {-3.4373449933535234`, 0.2302516425362554}, {-3.5, 
       0.357662782649369}}], 
      PolygonBox[{{-3.4373449933535234`, 
       0.2302516425362554}, {-3.437499981032941, 0.08429258955606238}, {-3.5, 
       0.357662782649369}, {-3.4373449933535234`, 0.2302516425362554}}], 
      PolygonBox[{{-3.5, 0.20590900528289896`}, {-3.5, 
       0.357662782649369}, {-3.437499981032941, 0.08429258955606238}, {-3.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{-3.437499981032941, 0.08429258955606238}, {-3.4375, 
       0.00012317806299537147`}, {-3.5, 
       0.20590900528289896`}, {-3.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-3.5, 0.08067866675870025}, {-3.5, 
       0.20590900528289896`}, {-3.4375, 0.00012317806299537147`}, {-3.5, 
       0.08067866675870025}}], 
      PolygonBox[{{-3.4375, 
       0.00012317806299537147`}, {-3.437499981032941, -0.084292589556055}, \
{-3.5, 0.08067866675870025}, {-3.4375, 0.00012317806299537147`}}], 
      PolygonBox[{{-3.5, -0.20590900514527852`}, {-3.5, 
       0.08067866675870025}, {-3.437499981032941, -0.084292589556055}, {-3.5, \
-0.20590900514527852`}}], 
      PolygonBox[{{-3.437499981032941, -0.084292589556055}, \
{-3.4373449933535234`, -0.23025164253625477`}, {-3.5, -0.20590900514527852`}, \
{-3.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-3.5, -0.35766278264936535`}, {-3.5, \
-0.20590900514527852`}, {-3.4373449933535234`, -0.23025164253625477`}, {-3.5, \
-0.35766278264936535`}}], 
      PolygonBox[{{-3.4373449933535234`, -0.23025164253625477`}, \
{-3.404942744332997, -0.4049427443329971}, {-3.5, -0.35766278264936535`}, \
{-3.4373449933535234`, -0.23025164253625477`}}], 
      PolygonBox[{{-3.5, 
       0.5}, {-3.5, -0.35766278264936535`}, {-3.404942744332997, \
-0.4049427443329971}, {-3.5, 0.5}}], 
      PolygonBox[{{-3.404942744332997, -0.4049427443329971}, \
{-3.230251642536255, -0.4373449933535234}, {-3.5, 
       0.5}, {-3.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-3.5, -0.5}, {-3.5, 
       0.5}, {-3.230251642536255, -0.4373449933535234}, {-3.5, -0.5}}], 
      PolygonBox[{{-3.230251642536255, -0.4373449933535234}, \
{-3.084292589556064, -0.4374999810329408}, {-3.5, -0.5}, {-3.230251642536255, \
-0.4373449933535234}}], 
      PolygonBox[{{-3.205909005566828, -0.5}, {-3.5, -0.5}, \
{-3.084292589556064, -0.4374999810329408}, {-3.205909005566828, -0.5}}], 
      PolygonBox[{{-3.084292589556064, -0.4374999810329408}, \
{-2.999865158168957, -0.4375}, {-3.205909005566828, -0.5}, \
{-3.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-2.9176761295989384`, -0.5}, {-3.205909005566828, -0.5}, \
{-2.999865158168957, -0.4375}, {-2.9176761295989384`, -0.5}}], 
      PolygonBox[{{-2.999865158168957, -0.4375}, {-2.9157074104439467`, \
-0.4374999810329408}, {-2.9176761295989384`, -0.5}, {-2.999865158168957, \
-0.4375}}], 
      PolygonBox[{{-2.7940909946396024`, -0.5}, {-2.9176761295989384`, -0.5}, \
{-2.9157074104439467`, -0.4374999810329408}, {-2.7940909946396024`, -0.5}}], 
      PolygonBox[{{-2.9157074104439467`, -0.4374999810329408}, \
{-2.769748357463745, -0.4373449933535234}, {-2.7940909946396024`, -0.5}, \
{-2.9157074104439467`, -0.4374999810329408}}], 
      PolygonBox[{{-2.642337217350629, -0.5}, {-2.7940909946396024`, -0.5}, \
{-2.769748357463745, -0.4373449933535234}, {-2.642337217350629, -0.5}}], 
      PolygonBox[{{-2.769748357463745, -0.4373449933535234}, \
{-2.595057255667003, -0.40494274433299715`}, {-2.642337217350629, -0.5}, \
{-2.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{-2.5, -0.5}, {-2.642337217350629, -0.5}, \
{-2.595057255667003, -0.40494274433299715`}, {-2.5, -0.5}}], 
      PolygonBox[{{-2.595057255667003, -0.40494274433299715`}, \
{-2.595057255667003, -0.4049427443329971}, {-2.5, -0.5}, {-2.595057255667003, \
-0.40494274433299715`}}], 
      PolygonBox[{{-2.5, -0.5}, {-2.5, -0.5}, {-2.595057255667003, \
-0.4049427443329971}, {-2.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, 1.}, {-3.4791666666666665`, 1.}, {-3.4583333333333335`, 
       1.}, {-3.4375, 1.}, {-3.4166666666666665`, 1.}, {-3.3958333333333335`, 
       1.}, {-3.375, 1.}, {-3.375, 1.}, {-3.3958333333333335`, 
       1.}, {-3.4166666666666665`, 1.}, {-3.4375, 1.}, {-3.4583333333333335`, 
       1.}, {-3.4791666666666665`, 1.}, {-3.5, 1.}, {-3.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, 1.}, {-2.6041666666666665`, 
       1.}, {-2.5833333333333335`, 1.}, {-2.5625, 1.}, {-2.5416666666666665`, 
       1.}, {-2.5208333333333335`, 1.}, {-2.5, 1.}, {-2.5, 
       1.}, {-2.5208333333333335`, 1.}, {-2.5416666666666665`, 1.}, {-2.5625, 
       1.}, {-2.5833333333333335`, 1.}, {-2.6041666666666665`, 1.}, {-2.625, 
       1.}, {-2.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 0.5}, {-3., 0.5208333333333333}, {-3., 
       0.5416666666666667}, {-3., 0.5625}, {-3., 0.5833333333333333}, {-3., 
       0.6041666666666666}, {-3., 0.625}, {-3., 0.625}, {-3., 
       0.6041666666666667}, {-3., 0.5833333333333333}, {-3., 0.5625}, {-3., 
       0.5416666666666667}, {-3., 0.5208333333333334}, {-3., 0.5}, {-3., 
       0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 1.375}, {-3., 1.3958333333333333`}, {-3., 
       1.4166666666666667`}, {-3., 1.4375}, {-3., 1.4583333333333333`}, {-3., 
       1.4791666666666665`}, {-3., 1.5}, {-3., 1.5}, {-3., 
       1.4791666666666667`}, {-3., 1.4583333333333333`}, {-3., 1.4375}, {-3., 
       1.4166666666666667`}, {-3., 1.3958333333333335`}, {-3., 1.375}, {-3., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, 1.}, {-3.25, 1.}, {-3.125, 1.}, {-3., 1.}, {-2.875, 
       1.}, {-2.75, 1.}, {-2.625, 1.}, {-2.625, 1.}, {-2.75, 1.}, {-2.875, 
       1.}, {-3., 1.}, {-3.125, 1.}, {-3.25, 1.}, {-3.375, 1.}, {-3.375, 
       1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 0.625}, {-3., 0.75}, {-3., 0.875}, {-3., 1.}, {-3., 
       1.125}, {-3., 1.25}, {-3., 1.375}, {-3., 1.375}, {-3., 1.25}, {-3., 
       1.125}, {-3., 1.}, {-3., 0.875}, {-3., 0.75}, {-3., 0.625}, {-3., 
       0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByD0B3sxvUBHbSnWA/NOqJ7q7v1of2GHedWT
NJj8Z/tUoRS1jw9YD5jdNt8sa/fFHizcwHYgoW8Ct7nRV/uN0m+lrCzZD1xZ
HFu78vRXiDwDB1T/N3v/J0JPjx7jQJVv4ITrn/129k0+eS64+QbuJ1qlZ3LB
7X91cd2+K0+54O6DiHPD3Q+TP5a3JfvFkzdw/Yxg+Vf2c6DmT/GcMPNI83O4
/Y6P772YOPsp3H2RO1xY12Y8QXP/E/tNUP9FQOUZof63h+qHhc9kqPmw8Pv3
HwRewsP3ENR9sPAHS/9/bw8AA3yjPg==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByD0D/tQMGCF81evAgE2OB9Cc6Cp54TzwcpX
caGp5yHIDwOb8xXOh9j7CU39BzT5V2j6n6Kpf4DBX43ivgdo7n+A5r8HaP5/
YB+GEj4w9SwE+aEo7mM5sArF/TD1H9DkP6Hp/4qm/oc9AN2AaEY=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, 
       0.7348349570550448}, {-2.6752404735808355`, 
       0.8125}, {-2.595057255667003, 
       0.5950572556670028}, {-2.7348349570550448`, 0.7348349570550448}}], 
      PolygonBox[{{-2.5626550066464766`, 
       0.7697483574637448}, {-2.595057255667003, 
       0.5950572556670028}, {-2.6752404735808355`, 
       0.8125}, {-2.5626550066464766`, 0.7697483574637448}}], 
      PolygonBox[{{-2.6752404735808355`, 0.8125}, {-2.6377778151415994`, 
       0.9029428580865547}, {-2.5626550066464766`, 
       0.7697483574637448}, {-2.6752404735808355`, 0.8125}}], 
      PolygonBox[{{-2.562500018967059, 
       0.9157074104439382}, {-2.5626550066464766`, 
       0.7697483574637448}, {-2.6377778151415994`, 
       0.9029428580865547}, {-2.562500018967059, 0.9157074104439382}}], 
      PolygonBox[{{-2.6377778151415994`, 0.9029428580865547}, {-2.625, 
       1.}, {-2.562500018967059, 0.9157074104439382}, {-2.6377778151415994`, 
       0.9029428580865547}}], 
      PolygonBox[{{-2.5625, 1.}, {-2.562500018967059, 
       0.9157074104439382}, {-2.625, 1.}, {-2.5625, 1.}}], 
      PolygonBox[{{-2.625, 1.}, {-2.6377778151415994`, 
       1.0970571419134452`}, {-2.5625, 1.}, {-2.625, 1.}}], 
      PolygonBox[{{-2.562500018967059, 1.0842925895560618`}, {-2.5625, 
       1.}, {-2.6377778151415994`, 1.0970571419134452`}, {-2.562500018967059, 
       1.0842925895560618`}}], 
      PolygonBox[{{-2.6377778151415994`, 
       1.0970571419134452`}, {-2.6752404735808355`, 
       1.1875}, {-2.562500018967059, 
       1.0842925895560618`}, {-2.6377778151415994`, 1.0970571419134452`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       1.230251642536255}, {-2.562500018967059, 
       1.0842925895560618`}, {-2.6752404735808355`, 
       1.1875}, {-2.5626550066464766`, 1.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, 1.1875}, {-2.7348349570550448`, 
       1.2651650429449552`}, {-2.5626550066464766`, 
       1.230251642536255}, {-2.6752404735808355`, 1.1875}}], 
      PolygonBox[{{-2.595057255667003, 
       1.4049427443329972`}, {-2.5626550066464766`, 
       1.230251642536255}, {-2.7348349570550448`, 
       1.2651650429449552`}, {-2.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{-2.7348349570550448`, 1.2651650429449552`}, {-2.8125, 
       1.3247595264191645`}, {-2.595057255667003, 
       1.4049427443329972`}, {-2.7348349570550448`, 1.2651650429449552`}}], 
      PolygonBox[{{-2.7697483574637447`, 
       1.4373449933535234`}, {-2.595057255667003, 
       1.4049427443329972`}, {-2.8125, 
       1.3247595264191645`}, {-2.7697483574637447`, 1.4373449933535234`}}], 
      PolygonBox[{{-2.8125, 1.3247595264191645`}, {-2.9029428580865546`, 
       1.3622221848584006`}, {-2.7697483574637447`, 
       1.4373449933535234`}, {-2.8125, 1.3247595264191645`}}], 
      PolygonBox[{{-2.9157074104439396`, 
       1.4374999810329407`}, {-2.7697483574637447`, 
       1.4373449933535234`}, {-2.9029428580865546`, 
       1.3622221848584006`}, {-2.9157074104439396`, 1.4374999810329407`}}], 
      PolygonBox[{{-2.9029428580865546`, 1.3622221848584006`}, {-3., 
       1.375}, {-2.9157074104439396`, 
       1.4374999810329407`}, {-2.9029428580865546`, 1.3622221848584006`}}], 
      PolygonBox[{{-2.9998944727795123`, 1.4375}, {-2.9157074104439396`, 
       1.4374999810329407`}, {-3., 1.375}, {-2.9998944727795123`, 1.4375}}], 
      PolygonBox[{{-3., 1.375}, {-3.097057141913445, 
       1.3622221848584006`}, {-2.9998944727795123`, 1.4375}, {-3., 1.375}}], 
      PolygonBox[{{-3.084292589556057, 
       1.4374999810329407`}, {-2.9998944727795123`, 
       1.4375}, {-3.097057141913445, 
       1.3622221848584006`}, {-3.084292589556057, 1.4374999810329407`}}], 
      PolygonBox[{{-3.097057141913445, 1.3622221848584006`}, {-3.1875, 
       1.3247595264191645`}, {-3.084292589556057, 
       1.4374999810329407`}, {-3.097057141913445, 1.3622221848584006`}}], 
      PolygonBox[{{-3.230251642536255, 
       1.4373449933535234`}, {-3.084292589556057, 
       1.4374999810329407`}, {-3.1875, 
       1.3247595264191645`}, {-3.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{-3.1875, 1.3247595264191645`}, {-3.2651650429449552`, 
       1.2651650429449552`}, {-3.230251642536255, 
       1.4373449933535234`}, {-3.1875, 1.3247595264191645`}}], 
      PolygonBox[{{-3.404942744332997, 
       1.4049427443329972`}, {-3.230251642536255, 
       1.4373449933535234`}, {-3.2651650429449552`, 
       1.2651650429449552`}, {-3.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{-3.2651650429449552`, 
       1.2651650429449552`}, {-3.3247595264191645`, 
       1.1875}, {-3.404942744332997, 
       1.4049427443329972`}, {-3.2651650429449552`, 1.2651650429449552`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       1.2302516425362553`}, {-3.404942744332997, 
       1.4049427443329972`}, {-3.3247595264191645`, 
       1.1875}, {-3.4373449933535234`, 1.2302516425362553`}}], 
      PolygonBox[{{-3.3247595264191645`, 1.1875}, {-3.3622221848584006`, 
       1.0970571419134454`}, {-3.4373449933535234`, 
       1.2302516425362553`}, {-3.3247595264191645`, 1.1875}}], 
      PolygonBox[{{-3.437499981032941, 
       1.0842925895560624`}, {-3.4373449933535234`, 
       1.2302516425362553`}, {-3.3622221848584006`, 
       1.0970571419134454`}, {-3.437499981032941, 1.0842925895560624`}}], 
      PolygonBox[{{-3.3622221848584006`, 1.0970571419134454`}, {-3.375, 
       1.0000000000000002`}, {-3.437499981032941, 
       1.0842925895560624`}, {-3.3622221848584006`, 1.0970571419134454`}}], 
      PolygonBox[{{-3.4375, 1.0001231780629953`}, {-3.437499981032941, 
       1.0842925895560624`}, {-3.375, 1.0000000000000002`}, {-3.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-3.375, 1.0000000000000002`}, {-3.3622221848584006`, 
       0.9029428580865548}, {-3.4375, 1.0001231780629953`}, {-3.375, 
       1.0000000000000002`}}], 
      PolygonBox[{{-3.437499981032941, 0.915707410443945}, {-3.4375, 
       1.0001231780629953`}, {-3.3622221848584006`, 
       0.9029428580865548}, {-3.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-3.3622221848584006`, 
       0.9029428580865548}, {-3.3247595264191645`, 
       0.8125000000000002}, {-3.437499981032941, 
       0.915707410443945}, {-3.3622221848584006`, 0.9029428580865548}}], 
      PolygonBox[{{-3.4373449933535234`, 
       0.7697483574637453}, {-3.437499981032941, 
       0.915707410443945}, {-3.3247595264191645`, 
       0.8125000000000002}, {-3.4373449933535234`, 0.7697483574637453}}], 
      PolygonBox[{{-3.3247595264191645`, 
       0.8125000000000002}, {-3.2651650429449552`, 
       0.7348349570550448}, {-3.4373449933535234`, 
       0.7697483574637453}, {-3.3247595264191645`, 0.8125000000000002}}], 
      PolygonBox[{{-3.404942744332997, 
       0.5950572556670028}, {-3.4373449933535234`, 
       0.7697483574637453}, {-3.2651650429449552`, 
       0.7348349570550448}, {-3.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-3.2651650429449552`, 0.7348349570550448}, {-3.1875, 
       0.6752404735808356}, {-3.404942744332997, 
       0.5950572556670028}, {-3.2651650429449552`, 0.7348349570550448}}], 
      PolygonBox[{{-3.230251642536255, 
       0.5626550066464766}, {-3.404942744332997, 
       0.5950572556670028}, {-3.1875, 
       0.6752404735808356}, {-3.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-3.1875, 0.6752404735808356}, {-3.0970571419134454`, 
       0.6377778151415995}, {-3.230251642536255, 
       0.5626550066464766}, {-3.1875, 0.6752404735808356}}], 
      PolygonBox[{{-3.084292589556064, 
       0.5625000189670593}, {-3.230251642536255, 
       0.5626550066464766}, {-3.0970571419134454`, 
       0.6377778151415995}, {-3.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-3.0970571419134454`, 0.6377778151415995}, {-3., 
       0.625}, {-3.084292589556064, 
       0.5625000189670593}, {-3.0970571419134454`, 0.6377778151415995}}], 
      PolygonBox[{{-2.999865158168957, 0.5625}, {-3.084292589556064, 
       0.5625000189670593}, {-3., 0.625}, {-2.999865158168957, 0.5625}}], 
      PolygonBox[{{-3., 0.625}, {-2.902942858086555, 
       0.6377778151415994}, {-2.999865158168957, 0.5625}, {-3., 0.625}}], 
      PolygonBox[{{-2.9157074104439467`, 
       0.5625000189670593}, {-2.999865158168957, 0.5625}, {-2.902942858086555,
        0.6377778151415994}, {-2.9157074104439467`, 0.5625000189670593}}], 
      PolygonBox[{{-2.902942858086555, 
       0.6377778151415994}, {-2.8125000000000004`, 
       0.6752404735808354}, {-2.9157074104439467`, 
       0.5625000189670593}, {-2.902942858086555, 0.6377778151415994}}], 
      PolygonBox[{{-2.769748357463745, 
       0.5626550066464766}, {-2.9157074104439467`, 
       0.5625000189670593}, {-2.8125000000000004`, 
       0.6752404735808354}, {-2.769748357463745, 0.5626550066464766}}], 
      PolygonBox[{{-2.8125000000000004`, 
       0.6752404735808354}, {-2.7348349570550448`, 
       0.7348349570550446}, {-2.769748357463745, 
       0.5626550066464766}, {-2.8125000000000004`, 0.6752404735808354}}], 
      PolygonBox[{{-2.595057255667003, 
       0.5950572556670028}, {-2.769748357463745, 
       0.5626550066464766}, {-2.7348349570550448`, 
       0.7348349570550446}, {-2.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-2.7348349570550448`, 
       0.7348349570550446}, {-2.7348349570550448`, 
       0.7348349570550448}, {-2.595057255667003, 
       0.5950572556670028}, {-2.7348349570550448`, 0.7348349570550446}}], 
      PolygonBox[{{-2.595057255667003, 
       0.5950572556670028}, {-2.595057255667003, 
       0.5950572556670028}, {-2.7348349570550448`, 
       0.7348349570550448}, {-2.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-2.595057255667003, 
       0.5950572556670028}, {-2.5626550066464766`, 0.7697483574637448}, {-2.5,
        0.5}, {-2.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-2.5, 0.6423372173506323}, {-2.5, 
       0.5}, {-2.5626550066464766`, 0.7697483574637448}, {-2.5, 
       0.6423372173506323}}], 
      PolygonBox[{{-2.5626550066464766`, 
       0.7697483574637448}, {-2.562500018967059, 0.9157074104439382}, {-2.5, 
       0.6423372173506323}, {-2.5626550066464766`, 0.7697483574637448}}], 
      PolygonBox[{{-2.5, 0.79409099469826}, {-2.5, 
       0.6423372173506323}, {-2.562500018967059, 0.9157074104439382}, {-2.5, 
       0.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, 0.9157074104439382}, {-2.5625, 
       1.}, {-2.5, 0.79409099469826}, {-2.562500018967059, 
       0.9157074104439382}}], 
      PolygonBox[{{-2.5, 1.}, {-2.5, 0.79409099469826}, {-2.5625, 1.}, {-2.5, 
       1.}}], PolygonBox[{{-2.5625, 1.}, {-2.562500018967059, 
       1.0842925895560618`}, {-2.5, 1.}, {-2.5625, 1.}}], 
      PolygonBox[{{-2.5, 1.2059090053017398`}, {-2.5, 
       1.}, {-2.562500018967059, 1.0842925895560618`}, {-2.5, 
       1.2059090053017398`}}], 
      PolygonBox[{{-2.562500018967059, 
       1.0842925895560618`}, {-2.5626550066464766`, 1.230251642536255}, {-2.5,
        1.2059090053017398`}, {-2.562500018967059, 1.0842925895560618`}}], 
      PolygonBox[{{-2.5, 1.3576627826493675`}, {-2.5, 
       1.2059090053017398`}, {-2.5626550066464766`, 1.230251642536255}, {-2.5,
        1.3576627826493675`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       1.230251642536255}, {-2.595057255667003, 1.4049427443329972`}, {-2.5, 
       1.3576627826493675`}, {-2.5626550066464766`, 1.230251642536255}}], 
      PolygonBox[{{-2.508553435038814, 1.491446564961186}, {-2.5, 
       1.3576627826493675`}, {-2.595057255667003, 
       1.4049427443329972`}, {-2.508553435038814, 1.491446564961186}}], 
      PolygonBox[{{-2.595057255667003, 
       1.4049427443329972`}, {-2.7697483574637447`, 
       1.4373449933535234`}, {-2.508553435038814, 
       1.491446564961186}, {-2.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{-2.642337217350632, 1.5}, {-2.508553435038814, 
       1.491446564961186}, {-2.7697483574637447`, 
       1.4373449933535234`}, {-2.642337217350632, 1.5}}], 
      PolygonBox[{{-2.7697483574637447`, 
       1.4373449933535234`}, {-2.9157074104439396`, 
       1.4374999810329407`}, {-2.642337217350632, 1.5}, {-2.7697483574637447`,
        1.4373449933535234`}}], 
      PolygonBox[{{-2.7940909946267443`, 1.5}, {-2.642337217350632, 
       1.5}, {-2.9157074104439396`, 
       1.4374999810329407`}, {-2.7940909946267443`, 1.5}}], 
      PolygonBox[{{-2.9157074104439396`, 
       1.4374999810329407`}, {-2.9998944727795123`, 
       1.4375}, {-2.7940909946267443`, 1.5}, {-2.9157074104439396`, 
       1.4374999810329407`}}], 
      PolygonBox[{{-2.92205804197311, 1.5}, {-2.7940909946267443`, 
       1.5}, {-2.9998944727795123`, 1.4375}, {-2.92205804197311, 1.5}}], 
      PolygonBox[{{-2.9998944727795123`, 1.4375}, {-3.084292589556057, 
       1.4374999810329407`}, {-2.92205804197311, 1.5}, {-2.9998944727795123`, 
       1.4375}}], 
      PolygonBox[{{-3.2059090053044454`, 1.5}, {-2.92205804197311, 
       1.5}, {-3.084292589556057, 1.4374999810329407`}, {-3.2059090053044454`,
        1.5}}], 
      PolygonBox[{{-3.084292589556057, 
       1.4374999810329407`}, {-3.230251642536255, 
       1.4373449933535234`}, {-3.2059090053044454`, 1.5}, {-3.084292589556057,
        1.4374999810329407`}}], 
      PolygonBox[{{-3.357662782649366, 1.5}, {-3.2059090053044454`, 
       1.5}, {-3.230251642536255, 1.4373449933535234`}, {-3.357662782649366, 
       1.5}}], PolygonBox[{{-3.230251642536255, 
       1.4373449933535234`}, {-3.404942744332997, 
       1.4049427443329972`}, {-3.357662782649366, 1.5}, {-3.230251642536255, 
       1.4373449933535234`}}], 
      PolygonBox[{{-2.5, 1.5}, {-3.357662782649366, 1.5}, {-3.404942744332997,
        1.4049427443329972`}, {-2.5, 1.5}}], 
      PolygonBox[{{-3.404942744332997, 
       1.4049427443329972`}, {-3.4373449933535234`, 
       1.2302516425362553`}, {-2.5, 1.5}, {-3.404942744332997, 
       1.4049427443329972`}}], 
      PolygonBox[{{-3.5, 1.357662782649369}, {-2.5, 
       1.5}, {-3.4373449933535234`, 1.2302516425362553`}, {-3.5, 
       1.357662782649369}}], 
      PolygonBox[{{-3.4373449933535234`, 
       1.2302516425362553`}, {-3.437499981032941, 1.0842925895560624`}, {-3.5,
        1.357662782649369}, {-3.4373449933535234`, 1.2302516425362553`}}], 
      PolygonBox[{{-3.5, 1.205909005282899}, {-3.5, 
       1.357662782649369}, {-3.437499981032941, 1.0842925895560624`}, {-3.5, 
       1.205909005282899}}], 
      PolygonBox[{{-3.437499981032941, 1.0842925895560624`}, {-3.4375, 
       1.0001231780629953`}, {-3.5, 1.205909005282899}, {-3.437499981032941, 
       1.0842925895560624`}}], 
      PolygonBox[{{-3.5, 1.0806786667587003`}, {-3.5, 
       1.205909005282899}, {-3.4375, 1.0001231780629953`}, {-3.5, 
       1.0806786667587003`}}], 
      PolygonBox[{{-3.4375, 1.0001231780629953`}, {-3.437499981032941, 
       0.915707410443945}, {-3.5, 1.0806786667587003`}, {-3.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-3.5, 0.7940909948547215}, {-3.5, 
       1.0806786667587003`}, {-3.437499981032941, 0.915707410443945}, {-3.5, 
       0.7940909948547215}}], 
      PolygonBox[{{-3.437499981032941, 
       0.915707410443945}, {-3.4373449933535234`, 0.7697483574637453}, {-3.5, 
       0.7940909948547215}, {-3.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-3.5, 0.6423372173506346}, {-3.5, 
       0.7940909948547215}, {-3.4373449933535234`, 0.7697483574637453}, {-3.5,
        0.6423372173506346}}], 
      PolygonBox[{{-3.4373449933535234`, 
       0.7697483574637453}, {-3.404942744332997, 0.5950572556670028}, {-3.5, 
       0.6423372173506346}, {-3.4373449933535234`, 0.7697483574637453}}], 
      PolygonBox[{{-3.5, 1.5}, {-3.5, 
       0.6423372173506346}, {-3.404942744332997, 0.5950572556670028}, {-3.5, 
       1.5}}], PolygonBox[{{-3.404942744332997, 
       0.5950572556670028}, {-3.230251642536255, 0.5626550066464766}, {-3.5, 
       1.5}, {-3.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-3.5, 0.5}, {-3.5, 1.5}, {-3.230251642536255, 
       0.5626550066464766}, {-3.5, 0.5}}], 
      PolygonBox[{{-3.230251642536255, 
       0.5626550066464766}, {-3.084292589556064, 0.5625000189670593}, {-3.5, 
       0.5}, {-3.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-3.205909005566828, 0.5}, {-3.5, 0.5}, {-3.084292589556064,
        0.5625000189670593}, {-3.205909005566828, 0.5}}], 
      PolygonBox[{{-3.084292589556064, 
       0.5625000189670593}, {-2.999865158168957, 0.5625}, {-3.205909005566828,
        0.5}, {-3.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-2.9176761295989384`, 0.5}, {-3.205909005566828, 
       0.5}, {-2.999865158168957, 0.5625}, {-2.9176761295989384`, 0.5}}], 
      PolygonBox[{{-2.999865158168957, 0.5625}, {-2.9157074104439467`, 
       0.5625000189670593}, {-2.9176761295989384`, 0.5}, {-2.999865158168957, 
       0.5625}}], 
      PolygonBox[{{-2.7940909946396024`, 0.5}, {-2.9176761295989384`, 
       0.5}, {-2.9157074104439467`, 
       0.5625000189670593}, {-2.7940909946396024`, 0.5}}], 
      PolygonBox[{{-2.9157074104439467`, 
       0.5625000189670593}, {-2.769748357463745, 
       0.5626550066464766}, {-2.7940909946396024`, 
       0.5}, {-2.9157074104439467`, 0.5625000189670593}}], 
      PolygonBox[{{-2.642337217350629, 0.5}, {-2.7940909946396024`, 
       0.5}, {-2.769748357463745, 0.5626550066464766}, {-2.642337217350629, 
       0.5}}], PolygonBox[{{-2.769748357463745, 
       0.5626550066464766}, {-2.595057255667003, 
       0.5950572556670028}, {-2.642337217350629, 0.5}, {-2.769748357463745, 
       0.5626550066464766}}], 
      PolygonBox[{{-2.5, 0.5}, {-2.642337217350629, 0.5}, {-2.595057255667003,
        0.5950572556670028}, {-2.5, 0.5}}], 
      PolygonBox[{{-2.595057255667003, 
       0.5950572556670028}, {-2.595057255667003, 0.5950572556670028}, {-2.5, 
       0.5}, {-2.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{-2.5, 0.5}, {-2.5, 0.5}, {-2.595057255667003, 
       0.5950572556670028}, {-2.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, 2.}, {-3.4791666666666665`, 2.}, {-3.4583333333333335`, 
       2.}, {-3.4375, 2.}, {-3.4166666666666665`, 2.}, {-3.3958333333333335`, 
       2.}, {-3.375, 2.}, {-3.375, 2.}, {-3.3958333333333335`, 
       2.}, {-3.4166666666666665`, 2.}, {-3.4375, 2.}, {-3.4583333333333335`, 
       2.}, {-3.4791666666666665`, 2.}, {-3.5, 2.}, {-3.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, 2.}, {-2.6041666666666665`, 
       2.}, {-2.5833333333333335`, 2.}, {-2.5625, 2.}, {-2.5416666666666665`, 
       2.}, {-2.5208333333333335`, 2.}, {-2.5, 2.}, {-2.5, 
       2.}, {-2.5208333333333335`, 2.}, {-2.5416666666666665`, 2.}, {-2.5625, 
       2.}, {-2.5833333333333335`, 2.}, {-2.6041666666666665`, 2.}, {-2.625, 
       2.}, {-2.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 1.5}, {-3., 1.5208333333333333`}, {-3., 
       1.5416666666666667`}, {-3., 1.5625}, {-3., 1.5833333333333333`}, {-3., 
       1.6041666666666665`}, {-3., 1.625}, {-3., 1.625}, {-3., 
       1.6041666666666667`}, {-3., 1.5833333333333333`}, {-3., 1.5625}, {-3., 
       1.5416666666666667`}, {-3., 1.5208333333333335`}, {-3., 1.5}, {-3., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 2.375}, {-3., 2.3958333333333335`}, {-3., 
       2.4166666666666665`}, {-3., 2.4375}, {-3., 2.4583333333333335`}, {-3., 
       2.4791666666666665`}, {-3., 2.5}, {-3., 2.5}, {-3., 
       2.4791666666666665`}, {-3., 2.4583333333333335`}, {-3., 2.4375}, {-3., 
       2.4166666666666665`}, {-3., 2.3958333333333335`}, {-3., 2.375}, {-3., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, 2.}, {-3.25, 2.}, {-3.125, 2.}, {-3., 2.}, {-2.875, 
       2.}, {-2.75, 2.}, {-2.625, 2.}, {-2.625, 2.}, {-2.75, 2.}, {-2.875, 
       2.}, {-3., 2.}, {-3.125, 2.}, {-3.25, 2.}, {-3.375, 2.}, {-3.375, 
       2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 1.625}, {-3., 1.75}, {-3., 1.875}, {-3., 2.}, {-3., 
       2.125}, {-3., 2.25}, {-3., 2.375}, {-3., 2.375}, {-3., 2.25}, {-3., 
       2.125}, {-3., 2.}, {-3., 1.875}, {-3., 1.75}, {-3., 1.625}, {-3., 
       1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsB6AMBzG9QEdtKdYD/k+Enh49xuBwYYd51ZM0
qHwDo0OqUIraxwesB2a/nX2TT57JASLOdsDA/USr9Ewmh43Sb6WsLNkPvLq4
bt+Vp1B5Bg6o+cwOEHM5UOUbOOH6IeZywc2HiHPB7Yfo44K7D2IuN9z9MPlk
81umJUX/7FH0M/y1nwM1/5TKCZ9HB3/bw+xfUJj/5cTZX/Yw9+nELGoKM/ll
j+r+X/aboP6DyTNC/Q/TDwsfmPmw8PsPBn/sYeGbCHUfevgDAI7flHo=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsB6C0QygYsML5q1eBABucD6E50NRzwvlg5au4
0NTzEORD7GGC8yHmMqKpZ4Dzw8Dyf+1R9f+yR1X/A4O/GsV9P+xR3Q9Tz4Gm
ng3OD0MJH5h6FoL8VSjuY4H67y+aepj/WND8D9PP5ICqnsUBAM3tW0A=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, 
       1.7348349570550448`}, {-2.6752404735808355`, 
       1.8125}, {-2.595057255667003, 
       1.5950572556670028`}, {-2.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       1.769748357463745}, {-2.595057255667003, 
       1.5950572556670028`}, {-2.6752404735808355`, 
       1.8125}, {-2.5626550066464766`, 1.769748357463745}}], 
      PolygonBox[{{-2.6752404735808355`, 1.8125}, {-2.6377778151415994`, 
       1.9029428580865546`}, {-2.5626550066464766`, 
       1.769748357463745}, {-2.6752404735808355`, 1.8125}}], 
      PolygonBox[{{-2.562500018967059, 
       1.9157074104439382`}, {-2.5626550066464766`, 
       1.769748357463745}, {-2.6377778151415994`, 
       1.9029428580865546`}, {-2.562500018967059, 1.9157074104439382`}}], 
      PolygonBox[{{-2.6377778151415994`, 1.9029428580865546`}, {-2.625, 
       2.}, {-2.562500018967059, 1.9157074104439382`}, {-2.6377778151415994`, 
       1.9029428580865546`}}], 
      PolygonBox[{{-2.5625, 2.}, {-2.562500018967059, 
       1.9157074104439382`}, {-2.625, 2.}, {-2.5625, 2.}}], 
      PolygonBox[{{-2.625, 2.}, {-2.6377778151415994`, 
       2.0970571419134454`}, {-2.5625, 2.}, {-2.625, 2.}}], 
      PolygonBox[{{-2.562500018967059, 2.084292589556062}, {-2.5625, 
       2.}, {-2.6377778151415994`, 2.0970571419134454`}, {-2.562500018967059, 
       2.084292589556062}}], 
      PolygonBox[{{-2.6377778151415994`, 
       2.0970571419134454`}, {-2.6752404735808355`, 
       2.1875}, {-2.562500018967059, 
       2.084292589556062}, {-2.6377778151415994`, 2.0970571419134454`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       2.230251642536255}, {-2.562500018967059, 
       2.084292589556062}, {-2.6752404735808355`, 
       2.1875}, {-2.5626550066464766`, 2.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, 2.1875}, {-2.7348349570550448`, 
       2.2651650429449552`}, {-2.5626550066464766`, 
       2.230251642536255}, {-2.6752404735808355`, 2.1875}}], 
      PolygonBox[{{-2.595057255667003, 
       2.404942744332997}, {-2.5626550066464766`, 
       2.230251642536255}, {-2.7348349570550448`, 
       2.2651650429449552`}, {-2.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, 2.2651650429449552`}, {-2.8125, 
       2.3247595264191645`}, {-2.595057255667003, 
       2.404942744332997}, {-2.7348349570550448`, 2.2651650429449552`}}], 
      PolygonBox[{{-2.7697483574637447`, 
       2.4373449933535234`}, {-2.595057255667003, 
       2.404942744332997}, {-2.8125, 
       2.3247595264191645`}, {-2.7697483574637447`, 2.4373449933535234`}}], 
      PolygonBox[{{-2.8125, 2.3247595264191645`}, {-2.9029428580865546`, 
       2.3622221848584006`}, {-2.7697483574637447`, 
       2.4373449933535234`}, {-2.8125, 2.3247595264191645`}}], 
      PolygonBox[{{-2.9157074104439396`, 
       2.437499981032941}, {-2.7697483574637447`, 
       2.4373449933535234`}, {-2.9029428580865546`, 
       2.3622221848584006`}, {-2.9157074104439396`, 2.437499981032941}}], 
      PolygonBox[{{-2.9029428580865546`, 2.3622221848584006`}, {-3., 
       2.375}, {-2.9157074104439396`, 
       2.437499981032941}, {-2.9029428580865546`, 2.3622221848584006`}}], 
      PolygonBox[{{-2.9998944727795123`, 2.4375}, {-2.9157074104439396`, 
       2.437499981032941}, {-3., 2.375}, {-2.9998944727795123`, 2.4375}}], 
      PolygonBox[{{-3., 2.375}, {-3.097057141913445, 
       2.3622221848584006`}, {-2.9998944727795123`, 2.4375}, {-3., 2.375}}], 
      PolygonBox[{{-3.084292589556057, 
       2.437499981032941}, {-2.9998944727795123`, 
       2.4375}, {-3.097057141913445, 
       2.3622221848584006`}, {-3.084292589556057, 2.437499981032941}}], 
      PolygonBox[{{-3.097057141913445, 2.3622221848584006`}, {-3.1875, 
       2.3247595264191645`}, {-3.084292589556057, 
       2.437499981032941}, {-3.097057141913445, 2.3622221848584006`}}], 
      PolygonBox[{{-3.230251642536255, 
       2.4373449933535234`}, {-3.084292589556057, 
       2.437499981032941}, {-3.1875, 
       2.3247595264191645`}, {-3.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{-3.1875, 2.3247595264191645`}, {-3.2651650429449552`, 
       2.2651650429449552`}, {-3.230251642536255, 
       2.4373449933535234`}, {-3.1875, 2.3247595264191645`}}], 
      PolygonBox[{{-3.404942744332997, 
       2.404942744332997}, {-3.230251642536255, 
       2.4373449933535234`}, {-3.2651650429449552`, 
       2.2651650429449552`}, {-3.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, 
       2.2651650429449552`}, {-3.3247595264191645`, 
       2.1875}, {-3.404942744332997, 
       2.404942744332997}, {-3.2651650429449552`, 2.2651650429449552`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       2.2302516425362553`}, {-3.404942744332997, 
       2.404942744332997}, {-3.3247595264191645`, 
       2.1875}, {-3.4373449933535234`, 2.2302516425362553`}}], 
      PolygonBox[{{-3.3247595264191645`, 2.1875}, {-3.3622221848584006`, 
       2.0970571419134454`}, {-3.4373449933535234`, 
       2.2302516425362553`}, {-3.3247595264191645`, 2.1875}}], 
      PolygonBox[{{-3.437499981032941, 
       2.0842925895560622`}, {-3.4373449933535234`, 
       2.2302516425362553`}, {-3.3622221848584006`, 
       2.0970571419134454`}, {-3.437499981032941, 2.0842925895560622`}}], 
      PolygonBox[{{-3.3622221848584006`, 2.0970571419134454`}, {-3.375, 
       2.}, {-3.437499981032941, 2.0842925895560622`}, {-3.3622221848584006`, 
       2.0970571419134454`}}], 
      PolygonBox[{{-3.4375, 2.0001231780629953`}, {-3.437499981032941, 
       2.0842925895560622`}, {-3.375, 2.}, {-3.4375, 2.0001231780629953`}}], 
      PolygonBox[{{-3.375, 2.}, {-3.3622221848584006`, 
       1.9029428580865548`}, {-3.4375, 2.0001231780629953`}, {-3.375, 2.}}], 
      PolygonBox[{{-3.437499981032941, 1.915707410443945}, {-3.4375, 
       2.0001231780629953`}, {-3.3622221848584006`, 
       1.9029428580865548`}, {-3.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-3.3622221848584006`, 
       1.9029428580865548`}, {-3.3247595264191645`, 
       1.8125000000000002`}, {-3.437499981032941, 
       1.915707410443945}, {-3.3622221848584006`, 1.9029428580865548`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       1.7697483574637451`}, {-3.437499981032941, 
       1.915707410443945}, {-3.3247595264191645`, 
       1.8125000000000002`}, {-3.4373449933535234`, 1.7697483574637451`}}], 
      PolygonBox[{{-3.3247595264191645`, 
       1.8125000000000002`}, {-3.2651650429449552`, 
       1.7348349570550448`}, {-3.4373449933535234`, 
       1.7697483574637451`}, {-3.3247595264191645`, 1.8125000000000002`}}], 
      PolygonBox[{{-3.404942744332997, 
       1.5950572556670028`}, {-3.4373449933535234`, 
       1.7697483574637451`}, {-3.2651650429449552`, 
       1.7348349570550448`}, {-3.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-3.2651650429449552`, 1.7348349570550448`}, {-3.1875, 
       1.6752404735808355`}, {-3.404942744332997, 
       1.5950572556670028`}, {-3.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{-3.230251642536255, 
       1.5626550066464766`}, {-3.404942744332997, 
       1.5950572556670028`}, {-3.1875, 
       1.6752404735808355`}, {-3.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-3.1875, 1.6752404735808355`}, {-3.0970571419134454`, 
       1.6377778151415994`}, {-3.230251642536255, 
       1.5626550066464766`}, {-3.1875, 1.6752404735808355`}}], 
      PolygonBox[{{-3.084292589556064, 
       1.5625000189670593`}, {-3.230251642536255, 
       1.5626550066464766`}, {-3.0970571419134454`, 
       1.6377778151415994`}, {-3.084292589556064, 1.5625000189670593`}}], 
      PolygonBox[{{-3.0970571419134454`, 1.6377778151415994`}, {-3., 
       1.625}, {-3.084292589556064, 
       1.5625000189670593`}, {-3.0970571419134454`, 1.6377778151415994`}}], 
      PolygonBox[{{-2.999865158168957, 1.5625}, {-3.084292589556064, 
       1.5625000189670593`}, {-3., 1.625}, {-2.999865158168957, 1.5625}}], 
      PolygonBox[{{-3., 1.625}, {-2.902942858086555, 
       1.6377778151415994`}, {-2.999865158168957, 1.5625}, {-3., 1.625}}], 
      PolygonBox[{{-2.9157074104439467`, 
       1.5625000189670593`}, {-2.999865158168957, 
       1.5625}, {-2.902942858086555, 
       1.6377778151415994`}, {-2.9157074104439467`, 1.5625000189670593`}}], 
      PolygonBox[{{-2.902942858086555, 
       1.6377778151415994`}, {-2.8125000000000004`, 
       1.6752404735808355`}, {-2.9157074104439467`, 
       1.5625000189670593`}, {-2.902942858086555, 1.6377778151415994`}}], 
      PolygonBox[{{-2.769748357463745, 
       1.5626550066464766`}, {-2.9157074104439467`, 
       1.5625000189670593`}, {-2.8125000000000004`, 
       1.6752404735808355`}, {-2.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{-2.8125000000000004`, 
       1.6752404735808355`}, {-2.7348349570550448`, 
       1.7348349570550448`}, {-2.769748357463745, 
       1.5626550066464766`}, {-2.8125000000000004`, 1.6752404735808355`}}], 
      PolygonBox[{{-2.595057255667003, 
       1.5950572556670028`}, {-2.769748357463745, 
       1.5626550066464766`}, {-2.7348349570550448`, 
       1.7348349570550448`}, {-2.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-2.7348349570550448`, 
       1.7348349570550448`}, {-2.7348349570550448`, 
       1.7348349570550448`}, {-2.595057255667003, 
       1.5950572556670028`}, {-2.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{-2.595057255667003, 
       1.5950572556670028`}, {-2.595057255667003, 
       1.5950572556670028`}, {-2.7348349570550448`, 
       1.7348349570550448`}, {-2.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-2.595057255667003, 
       1.5950572556670028`}, {-2.5626550066464766`, 1.769748357463745}, {-2.5,
        1.5}, {-2.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-2.5, 1.6423372173506323`}, {-2.5, 
       1.5}, {-2.5626550066464766`, 1.769748357463745}, {-2.5, 
       1.6423372173506323`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       1.769748357463745}, {-2.562500018967059, 1.9157074104439382`}, {-2.5, 
       1.6423372173506323`}, {-2.5626550066464766`, 1.769748357463745}}], 
      PolygonBox[{{-2.5, 1.79409099469826}, {-2.5, 
       1.6423372173506323`}, {-2.562500018967059, 1.9157074104439382`}, {-2.5,
        1.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, 1.9157074104439382`}, {-2.5625, 
       2.}, {-2.5, 1.79409099469826}, {-2.562500018967059, 
       1.9157074104439382`}}], 
      PolygonBox[{{-2.5, 2.}, {-2.5, 1.79409099469826}, {-2.5625, 2.}, {-2.5, 
       2.}}], PolygonBox[{{-2.5625, 2.}, {-2.562500018967059, 
       2.084292589556062}, {-2.5, 2.}, {-2.5625, 2.}}], 
      PolygonBox[{{-2.5, 2.20590900530174}, {-2.5, 2.}, {-2.562500018967059, 
       2.084292589556062}, {-2.5, 2.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, 
       2.084292589556062}, {-2.5626550066464766`, 2.230251642536255}, {-2.5, 
       2.20590900530174}, {-2.562500018967059, 2.084292589556062}}], 
      PolygonBox[{{-2.5, 2.3576627826493675`}, {-2.5, 
       2.20590900530174}, {-2.5626550066464766`, 2.230251642536255}, {-2.5, 
       2.3576627826493675`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       2.230251642536255}, {-2.595057255667003, 2.404942744332997}, {-2.5, 
       2.3576627826493675`}, {-2.5626550066464766`, 2.230251642536255}}], 
      PolygonBox[{{-2.508553435038814, 2.491446564961186}, {-2.5, 
       2.3576627826493675`}, {-2.595057255667003, 
       2.404942744332997}, {-2.508553435038814, 2.491446564961186}}], 
      PolygonBox[{{-2.595057255667003, 
       2.404942744332997}, {-2.7697483574637447`, 
       2.4373449933535234`}, {-2.508553435038814, 
       2.491446564961186}, {-2.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{-2.642337217350632, 2.5}, {-2.508553435038814, 
       2.491446564961186}, {-2.7697483574637447`, 
       2.4373449933535234`}, {-2.642337217350632, 2.5}}], 
      PolygonBox[{{-2.7697483574637447`, 
       2.4373449933535234`}, {-2.9157074104439396`, 
       2.437499981032941}, {-2.642337217350632, 2.5}, {-2.7697483574637447`, 
       2.4373449933535234`}}], 
      PolygonBox[{{-2.7940909946267443`, 2.5}, {-2.642337217350632, 
       2.5}, {-2.9157074104439396`, 2.437499981032941}, {-2.7940909946267443`,
        2.5}}], 
      PolygonBox[{{-2.9157074104439396`, 
       2.437499981032941}, {-2.9998944727795123`, 
       2.4375}, {-2.7940909946267443`, 2.5}, {-2.9157074104439396`, 
       2.437499981032941}}], 
      PolygonBox[{{-2.92205804197311, 2.5}, {-2.7940909946267443`, 
       2.5}, {-2.9998944727795123`, 2.4375}, {-2.92205804197311, 2.5}}], 
      PolygonBox[{{-2.9998944727795123`, 2.4375}, {-3.084292589556057, 
       2.437499981032941}, {-2.92205804197311, 2.5}, {-2.9998944727795123`, 
       2.4375}}], 
      PolygonBox[{{-3.2059090053044454`, 2.5}, {-2.92205804197311, 
       2.5}, {-3.084292589556057, 2.437499981032941}, {-3.2059090053044454`, 
       2.5}}], PolygonBox[{{-3.084292589556057, 
       2.437499981032941}, {-3.230251642536255, 
       2.4373449933535234`}, {-3.2059090053044454`, 2.5}, {-3.084292589556057,
        2.437499981032941}}], 
      PolygonBox[{{-3.357662782649366, 2.5}, {-3.2059090053044454`, 
       2.5}, {-3.230251642536255, 2.4373449933535234`}, {-3.357662782649366, 
       2.5}}], PolygonBox[{{-3.230251642536255, 
       2.4373449933535234`}, {-3.404942744332997, 
       2.404942744332997}, {-3.357662782649366, 2.5}, {-3.230251642536255, 
       2.4373449933535234`}}], 
      PolygonBox[{{-2.5, 2.5}, {-3.357662782649366, 2.5}, {-3.404942744332997,
        2.404942744332997}, {-2.5, 2.5}}], 
      PolygonBox[{{-3.404942744332997, 
       2.404942744332997}, {-3.4373449933535234`, 2.2302516425362553`}, {-2.5,
        2.5}, {-3.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-3.5, 2.357662782649369}, {-2.5, 
       2.5}, {-3.4373449933535234`, 2.2302516425362553`}, {-3.5, 
       2.357662782649369}}], 
      PolygonBox[{{-3.4373449933535234`, 
       2.2302516425362553`}, {-3.437499981032941, 2.0842925895560622`}, {-3.5,
        2.357662782649369}, {-3.4373449933535234`, 2.2302516425362553`}}], 
      PolygonBox[{{-3.5, 2.205909005282899}, {-3.5, 
       2.357662782649369}, {-3.437499981032941, 2.0842925895560622`}, {-3.5, 
       2.205909005282899}}], 
      PolygonBox[{{-3.437499981032941, 2.0842925895560622`}, {-3.4375, 
       2.0001231780629953`}, {-3.5, 2.205909005282899}, {-3.437499981032941, 
       2.0842925895560622`}}], 
      PolygonBox[{{-3.5, 2.0806786667587}, {-3.5, 
       2.205909005282899}, {-3.4375, 2.0001231780629953`}, {-3.5, 
       2.0806786667587}}], 
      PolygonBox[{{-3.4375, 2.0001231780629953`}, {-3.437499981032941, 
       1.915707410443945}, {-3.5, 2.0806786667587}, {-3.4375, 
       2.0001231780629953`}}], 
      PolygonBox[{{-3.5, 1.7940909948547215`}, {-3.5, 
       2.0806786667587}, {-3.437499981032941, 1.915707410443945}, {-3.5, 
       1.7940909948547215`}}], 
      PolygonBox[{{-3.437499981032941, 
       1.915707410443945}, {-3.4373449933535234`, 1.7697483574637451`}, {-3.5,
        1.7940909948547215`}, {-3.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-3.5, 1.6423372173506348`}, {-3.5, 
       1.7940909948547215`}, {-3.4373449933535234`, 
       1.7697483574637451`}, {-3.5, 1.6423372173506348`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       1.7697483574637451`}, {-3.404942744332997, 1.5950572556670028`}, {-3.5,
        1.6423372173506348`}, {-3.4373449933535234`, 1.7697483574637451`}}], 
      PolygonBox[{{-3.5, 2.5}, {-3.5, 
       1.6423372173506348`}, {-3.404942744332997, 1.5950572556670028`}, {-3.5,
        2.5}}], 
      PolygonBox[{{-3.404942744332997, 
       1.5950572556670028`}, {-3.230251642536255, 1.5626550066464766`}, {-3.5,
        2.5}, {-3.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-3.5, 1.5}, {-3.5, 2.5}, {-3.230251642536255, 
       1.5626550066464766`}, {-3.5, 1.5}}], 
      PolygonBox[{{-3.230251642536255, 
       1.5626550066464766`}, {-3.084292589556064, 1.5625000189670593`}, {-3.5,
        1.5}, {-3.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-3.205909005566828, 1.5}, {-3.5, 1.5}, {-3.084292589556064,
        1.5625000189670593`}, {-3.205909005566828, 1.5}}], 
      PolygonBox[{{-3.084292589556064, 
       1.5625000189670593`}, {-2.999865158168957, 
       1.5625}, {-3.205909005566828, 1.5}, {-3.084292589556064, 
       1.5625000189670593`}}], 
      PolygonBox[{{-2.9176761295989384`, 1.5}, {-3.205909005566828, 
       1.5}, {-2.999865158168957, 1.5625}, {-2.9176761295989384`, 1.5}}], 
      PolygonBox[{{-2.999865158168957, 1.5625}, {-2.9157074104439467`, 
       1.5625000189670593`}, {-2.9176761295989384`, 1.5}, {-2.999865158168957,
        1.5625}}], 
      PolygonBox[{{-2.7940909946396024`, 1.5}, {-2.9176761295989384`, 
       1.5}, {-2.9157074104439467`, 
       1.5625000189670593`}, {-2.7940909946396024`, 1.5}}], 
      PolygonBox[{{-2.9157074104439467`, 
       1.5625000189670593`}, {-2.769748357463745, 
       1.5626550066464766`}, {-2.7940909946396024`, 
       1.5}, {-2.9157074104439467`, 1.5625000189670593`}}], 
      PolygonBox[{{-2.642337217350629, 1.5}, {-2.7940909946396024`, 
       1.5}, {-2.769748357463745, 1.5626550066464766`}, {-2.642337217350629, 
       1.5}}], PolygonBox[{{-2.769748357463745, 
       1.5626550066464766`}, {-2.595057255667003, 
       1.5950572556670028`}, {-2.642337217350629, 1.5}, {-2.769748357463745, 
       1.5626550066464766`}}], 
      PolygonBox[{{-2.5, 1.5}, {-2.642337217350629, 1.5}, {-2.595057255667003,
        1.5950572556670028`}, {-2.5, 1.5}}], 
      PolygonBox[{{-2.595057255667003, 
       1.5950572556670028`}, {-2.595057255667003, 1.5950572556670028`}, {-2.5,
        1.5}, {-2.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{-2.5, 1.5}, {-2.5, 1.5}, {-2.595057255667003, 
       1.5950572556670028`}, {-2.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, 3.}, {-3.4791666666666665`, 3.}, {-3.4583333333333335`, 
       3.}, {-3.4375, 3.}, {-3.4166666666666665`, 3.}, {-3.3958333333333335`, 
       3.}, {-3.375, 3.}, {-3.375, 3.}, {-3.3958333333333335`, 
       3.}, {-3.4166666666666665`, 3.}, {-3.4375, 3.}, {-3.4583333333333335`, 
       3.}, {-3.4791666666666665`, 3.}, {-3.5, 3.}, {-3.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, 3.}, {-2.6041666666666665`, 
       3.}, {-2.5833333333333335`, 3.}, {-2.5625, 3.}, {-2.5416666666666665`, 
       3.}, {-2.5208333333333335`, 3.}, {-2.5, 3.}, {-2.5, 
       3.}, {-2.5208333333333335`, 3.}, {-2.5416666666666665`, 3.}, {-2.5625, 
       3.}, {-2.5833333333333335`, 3.}, {-2.6041666666666665`, 3.}, {-2.625, 
       3.}, {-2.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 2.5}, {-3., 2.5208333333333335`}, {-3., 
       2.5416666666666665`}, {-3., 2.5625}, {-3., 2.5833333333333335`}, {-3., 
       2.6041666666666665`}, {-3., 2.625}, {-3., 2.625}, {-3., 
       2.6041666666666665`}, {-3., 2.5833333333333335`}, {-3., 2.5625}, {-3., 
       2.5416666666666665`}, {-3., 2.5208333333333335`}, {-3., 2.5}, {-3., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 3.375}, {-3., 3.3958333333333335`}, {-3., 
       3.4166666666666665`}, {-3., 3.4375}, {-3., 3.4583333333333335`}, {-3., 
       3.4791666666666665`}, {-3., 3.5}, {-3., 3.5}, {-3., 
       3.4791666666666665`}, {-3., 3.4583333333333335`}, {-3., 3.4375}, {-3., 
       3.4166666666666665`}, {-3., 3.3958333333333335`}, {-3., 3.375}, {-3., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, 3.}, {-3.25, 3.}, {-3.125, 3.}, {-3., 3.}, {-2.875, 
       3.}, {-2.75, 3.}, {-2.625, 3.}, {-2.625, 3.}, {-2.75, 3.}, {-2.875, 
       3.}, {-3., 3.}, {-3.125, 3.}, {-3.25, 3.}, {-3.375, 3.}, {-3.375, 
       3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 2.625}, {-3., 2.75}, {-3., 2.875}, {-3., 3.}, {-3., 
       3.125}, {-3., 3.25}, {-3., 3.375}, {-3., 3.375}, {-3., 3.25}, {-3., 
       3.125}, {-3., 3.}, {-3., 2.875}, {-3., 2.75}, {-3., 2.625}, {-3., 
       2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByA0h4OYXqCjthTrAf8nQk+PHuNwuLDDvOpJ
GlS+gdMhVShF7eMD1gOz386+ySfP5QARZztg4H6iVXoml8NG6bdSVpbsB15d
XLfvylOoPAMH1HxuB6i5qPINnHD9UHPh5kPF4fZD9cHdBzUX7n6Y/CaIO9D0
sznMgZoP9Qfcfqg/4e6DhgOa+1kdoObC5Rmh/ofph4UPzHzU8GODhy80nBzQ
wx8AWMF/9A==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByA0j0MoGLDC+atXgQAbnA+hOdDUc8L5YOWr
uNDU8xDkQ+zhgvOh5qKp50BTzwbnh0HcjaaeBYO/GsV9LGjuh6nnQFPPBueH
oYQPTD0LQX4oivtY0NwPU8+Bpp4Tzl+FEj6I+AIAdpFPWg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, 
       2.7348349570550448`}, {-2.6752404735808355`, 
       2.8125}, {-2.595057255667003, 
       2.595057255667003}, {-2.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       2.7697483574637447`}, {-2.595057255667003, 
       2.595057255667003}, {-2.6752404735808355`, 
       2.8125}, {-2.5626550066464766`, 2.7697483574637447`}}], 
      PolygonBox[{{-2.6752404735808355`, 2.8125}, {-2.6377778151415994`, 
       2.9029428580865546`}, {-2.5626550066464766`, 
       2.7697483574637447`}, {-2.6752404735808355`, 2.8125}}], 
      PolygonBox[{{-2.562500018967059, 
       2.915707410443938}, {-2.5626550066464766`, 
       2.7697483574637447`}, {-2.6377778151415994`, 
       2.9029428580865546`}, {-2.562500018967059, 2.915707410443938}}], 
      PolygonBox[{{-2.6377778151415994`, 2.9029428580865546`}, {-2.625, 
       3.}, {-2.562500018967059, 2.915707410443938}, {-2.6377778151415994`, 
       2.9029428580865546`}}], 
      PolygonBox[{{-2.5625, 3.}, {-2.562500018967059, 
       2.915707410443938}, {-2.625, 3.}, {-2.5625, 3.}}], 
      PolygonBox[{{-2.625, 3.}, {-2.6377778151415994`, 
       3.0970571419134454`}, {-2.5625, 3.}, {-2.625, 3.}}], 
      PolygonBox[{{-2.562500018967059, 3.084292589556062}, {-2.5625, 
       3.}, {-2.6377778151415994`, 3.0970571419134454`}, {-2.562500018967059, 
       3.084292589556062}}], 
      PolygonBox[{{-2.6377778151415994`, 
       3.0970571419134454`}, {-2.6752404735808355`, 
       3.1875}, {-2.562500018967059, 
       3.084292589556062}, {-2.6377778151415994`, 3.0970571419134454`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       3.230251642536255}, {-2.562500018967059, 
       3.084292589556062}, {-2.6752404735808355`, 
       3.1875}, {-2.5626550066464766`, 3.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, 3.1875}, {-2.7348349570550448`, 
       3.2651650429449552`}, {-2.5626550066464766`, 
       3.230251642536255}, {-2.6752404735808355`, 3.1875}}], 
      PolygonBox[{{-2.595057255667003, 
       3.404942744332997}, {-2.5626550066464766`, 
       3.230251642536255}, {-2.7348349570550448`, 
       3.2651650429449552`}, {-2.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, 3.2651650429449552`}, {-2.8125, 
       3.3247595264191645`}, {-2.595057255667003, 
       3.404942744332997}, {-2.7348349570550448`, 3.2651650429449552`}}], 
      PolygonBox[{{-2.7697483574637447`, 
       3.4373449933535234`}, {-2.595057255667003, 
       3.404942744332997}, {-2.8125, 
       3.3247595264191645`}, {-2.7697483574637447`, 3.4373449933535234`}}], 
      PolygonBox[{{-2.8125, 3.3247595264191645`}, {-2.9029428580865546`, 
       3.3622221848584006`}, {-2.7697483574637447`, 
       3.4373449933535234`}, {-2.8125, 3.3247595264191645`}}], 
      PolygonBox[{{-2.9157074104439396`, 
       3.437499981032941}, {-2.7697483574637447`, 
       3.4373449933535234`}, {-2.9029428580865546`, 
       3.3622221848584006`}, {-2.9157074104439396`, 3.437499981032941}}], 
      PolygonBox[{{-2.9029428580865546`, 3.3622221848584006`}, {-3., 
       3.375}, {-2.9157074104439396`, 
       3.437499981032941}, {-2.9029428580865546`, 3.3622221848584006`}}], 
      PolygonBox[{{-2.9998944727795123`, 3.4375}, {-2.9157074104439396`, 
       3.437499981032941}, {-3., 3.375}, {-2.9998944727795123`, 3.4375}}], 
      PolygonBox[{{-3., 3.375}, {-3.097057141913445, 
       3.3622221848584006`}, {-2.9998944727795123`, 3.4375}, {-3., 3.375}}], 
      PolygonBox[{{-3.084292589556057, 
       3.437499981032941}, {-2.9998944727795123`, 
       3.4375}, {-3.097057141913445, 
       3.3622221848584006`}, {-3.084292589556057, 3.437499981032941}}], 
      PolygonBox[{{-3.097057141913445, 3.3622221848584006`}, {-3.1875, 
       3.3247595264191645`}, {-3.084292589556057, 
       3.437499981032941}, {-3.097057141913445, 3.3622221848584006`}}], 
      PolygonBox[{{-3.230251642536255, 
       3.4373449933535234`}, {-3.084292589556057, 
       3.437499981032941}, {-3.1875, 
       3.3247595264191645`}, {-3.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{-3.1875, 3.3247595264191645`}, {-3.2651650429449552`, 
       3.2651650429449552`}, {-3.230251642536255, 
       3.4373449933535234`}, {-3.1875, 3.3247595264191645`}}], 
      PolygonBox[{{-3.404942744332997, 
       3.404942744332997}, {-3.230251642536255, 
       3.4373449933535234`}, {-3.2651650429449552`, 
       3.2651650429449552`}, {-3.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, 
       3.2651650429449552`}, {-3.3247595264191645`, 
       3.1875}, {-3.404942744332997, 
       3.404942744332997}, {-3.2651650429449552`, 3.2651650429449552`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       3.2302516425362553`}, {-3.404942744332997, 
       3.404942744332997}, {-3.3247595264191645`, 
       3.1875}, {-3.4373449933535234`, 3.2302516425362553`}}], 
      PolygonBox[{{-3.3247595264191645`, 3.1875}, {-3.3622221848584006`, 
       3.0970571419134454`}, {-3.4373449933535234`, 
       3.2302516425362553`}, {-3.3247595264191645`, 3.1875}}], 
      PolygonBox[{{-3.437499981032941, 
       3.0842925895560622`}, {-3.4373449933535234`, 
       3.2302516425362553`}, {-3.3622221848584006`, 
       3.0970571419134454`}, {-3.437499981032941, 3.0842925895560622`}}], 
      PolygonBox[{{-3.3622221848584006`, 3.0970571419134454`}, {-3.375, 
       3.}, {-3.437499981032941, 3.0842925895560622`}, {-3.3622221848584006`, 
       3.0970571419134454`}}], 
      PolygonBox[{{-3.4375, 3.0001231780629953`}, {-3.437499981032941, 
       3.0842925895560622`}, {-3.375, 3.}, {-3.4375, 3.0001231780629953`}}], 
      PolygonBox[{{-3.375, 3.}, {-3.3622221848584006`, 
       2.902942858086555}, {-3.4375, 3.0001231780629953`}, {-3.375, 3.}}], 
      PolygonBox[{{-3.437499981032941, 2.915707410443945}, {-3.4375, 
       3.0001231780629953`}, {-3.3622221848584006`, 
       2.902942858086555}, {-3.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-3.3622221848584006`, 
       2.902942858086555}, {-3.3247595264191645`, 
       2.8125}, {-3.437499981032941, 
       2.915707410443945}, {-3.3622221848584006`, 2.902942858086555}}], 
      PolygonBox[{{-3.4373449933535234`, 
       2.769748357463745}, {-3.437499981032941, 
       2.915707410443945}, {-3.3247595264191645`, 
       2.8125}, {-3.4373449933535234`, 2.769748357463745}}], 
      PolygonBox[{{-3.3247595264191645`, 2.8125}, {-3.2651650429449552`, 
       2.7348349570550448`}, {-3.4373449933535234`, 
       2.769748357463745}, {-3.3247595264191645`, 2.8125}}], 
      PolygonBox[{{-3.404942744332997, 
       2.595057255667003}, {-3.4373449933535234`, 
       2.769748357463745}, {-3.2651650429449552`, 
       2.7348349570550448`}, {-3.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-3.2651650429449552`, 2.7348349570550448`}, {-3.1875, 
       2.6752404735808355`}, {-3.404942744332997, 
       2.595057255667003}, {-3.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{-3.230251642536255, 
       2.5626550066464766`}, {-3.404942744332997, 
       2.595057255667003}, {-3.1875, 
       2.6752404735808355`}, {-3.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-3.1875, 2.6752404735808355`}, {-3.0970571419134454`, 
       2.6377778151415994`}, {-3.230251642536255, 
       2.5626550066464766`}, {-3.1875, 2.6752404735808355`}}], 
      PolygonBox[{{-3.084292589556064, 
       2.562500018967059}, {-3.230251642536255, 
       2.5626550066464766`}, {-3.0970571419134454`, 
       2.6377778151415994`}, {-3.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-3.0970571419134454`, 2.6377778151415994`}, {-3., 
       2.625}, {-3.084292589556064, 2.562500018967059}, {-3.0970571419134454`,
        2.6377778151415994`}}], 
      PolygonBox[{{-2.999865158168957, 2.5625}, {-3.084292589556064, 
       2.562500018967059}, {-3., 2.625}, {-2.999865158168957, 2.5625}}], 
      PolygonBox[{{-3., 2.625}, {-2.902942858086555, 
       2.6377778151415994`}, {-2.999865158168957, 2.5625}, {-3., 2.625}}], 
      PolygonBox[{{-2.9157074104439467`, 
       2.562500018967059}, {-2.999865158168957, 2.5625}, {-2.902942858086555, 
       2.6377778151415994`}, {-2.9157074104439467`, 2.562500018967059}}], 
      PolygonBox[{{-2.902942858086555, 
       2.6377778151415994`}, {-2.8125000000000004`, 
       2.6752404735808355`}, {-2.9157074104439467`, 
       2.562500018967059}, {-2.902942858086555, 2.6377778151415994`}}], 
      PolygonBox[{{-2.769748357463745, 
       2.5626550066464766`}, {-2.9157074104439467`, 
       2.562500018967059}, {-2.8125000000000004`, 
       2.6752404735808355`}, {-2.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{-2.8125000000000004`, 
       2.6752404735808355`}, {-2.7348349570550448`, 
       2.7348349570550448`}, {-2.769748357463745, 
       2.5626550066464766`}, {-2.8125000000000004`, 2.6752404735808355`}}], 
      PolygonBox[{{-2.595057255667003, 
       2.595057255667003}, {-2.769748357463745, 
       2.5626550066464766`}, {-2.7348349570550448`, 
       2.7348349570550448`}, {-2.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-2.7348349570550448`, 
       2.7348349570550448`}, {-2.7348349570550448`, 
       2.7348349570550448`}, {-2.595057255667003, 
       2.595057255667003}, {-2.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{-2.595057255667003, 
       2.595057255667003}, {-2.595057255667003, 
       2.595057255667003}, {-2.7348349570550448`, 
       2.7348349570550448`}, {-2.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-2.595057255667003, 
       2.595057255667003}, {-2.5626550066464766`, 2.7697483574637447`}, {-2.5,
        2.5}, {-2.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-2.5, 2.642337217350632}, {-2.5, 
       2.5}, {-2.5626550066464766`, 2.7697483574637447`}, {-2.5, 
       2.642337217350632}}], 
      PolygonBox[{{-2.5626550066464766`, 
       2.7697483574637447`}, {-2.562500018967059, 2.915707410443938}, {-2.5, 
       2.642337217350632}, {-2.5626550066464766`, 2.7697483574637447`}}], 
      PolygonBox[{{-2.5, 2.79409099469826}, {-2.5, 
       2.642337217350632}, {-2.562500018967059, 2.915707410443938}, {-2.5, 
       2.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, 2.915707410443938}, {-2.5625, 
       3.}, {-2.5, 2.79409099469826}, {-2.562500018967059, 
       2.915707410443938}}], 
      PolygonBox[{{-2.5, 3.}, {-2.5, 2.79409099469826}, {-2.5625, 3.}, {-2.5, 
       3.}}], PolygonBox[{{-2.5625, 3.}, {-2.562500018967059, 
       3.084292589556062}, {-2.5, 3.}, {-2.5625, 3.}}], 
      PolygonBox[{{-2.5, 3.20590900530174}, {-2.5, 3.}, {-2.562500018967059, 
       3.084292589556062}, {-2.5, 3.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, 
       3.084292589556062}, {-2.5626550066464766`, 3.230251642536255}, {-2.5, 
       3.20590900530174}, {-2.562500018967059, 3.084292589556062}}], 
      PolygonBox[{{-2.5, 3.3576627826493675`}, {-2.5, 
       3.20590900530174}, {-2.5626550066464766`, 3.230251642536255}, {-2.5, 
       3.3576627826493675`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       3.230251642536255}, {-2.595057255667003, 3.404942744332997}, {-2.5, 
       3.3576627826493675`}, {-2.5626550066464766`, 3.230251642536255}}], 
      PolygonBox[{{-2.508553435038814, 3.491446564961186}, {-2.5, 
       3.3576627826493675`}, {-2.595057255667003, 
       3.404942744332997}, {-2.508553435038814, 3.491446564961186}}], 
      PolygonBox[{{-2.595057255667003, 
       3.404942744332997}, {-2.7697483574637447`, 
       3.4373449933535234`}, {-2.508553435038814, 
       3.491446564961186}, {-2.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{-2.642337217350632, 3.5}, {-2.508553435038814, 
       3.491446564961186}, {-2.7697483574637447`, 
       3.4373449933535234`}, {-2.642337217350632, 3.5}}], 
      PolygonBox[{{-2.7697483574637447`, 
       3.4373449933535234`}, {-2.9157074104439396`, 
       3.437499981032941}, {-2.642337217350632, 3.5}, {-2.7697483574637447`, 
       3.4373449933535234`}}], 
      PolygonBox[{{-2.7940909946267443`, 3.5}, {-2.642337217350632, 
       3.5}, {-2.9157074104439396`, 3.437499981032941}, {-2.7940909946267443`,
        3.5}}], 
      PolygonBox[{{-2.9157074104439396`, 
       3.437499981032941}, {-2.9998944727795123`, 
       3.4375}, {-2.7940909946267443`, 3.5}, {-2.9157074104439396`, 
       3.437499981032941}}], 
      PolygonBox[{{-2.92205804197311, 3.5}, {-2.7940909946267443`, 
       3.5}, {-2.9998944727795123`, 3.4375}, {-2.92205804197311, 3.5}}], 
      PolygonBox[{{-2.9998944727795123`, 3.4375}, {-3.084292589556057, 
       3.437499981032941}, {-2.92205804197311, 3.5}, {-2.9998944727795123`, 
       3.4375}}], 
      PolygonBox[{{-3.2059090053044454`, 3.5}, {-2.92205804197311, 
       3.5}, {-3.084292589556057, 3.437499981032941}, {-3.2059090053044454`, 
       3.5}}], PolygonBox[{{-3.084292589556057, 
       3.437499981032941}, {-3.230251642536255, 
       3.4373449933535234`}, {-3.2059090053044454`, 3.5}, {-3.084292589556057,
        3.437499981032941}}], 
      PolygonBox[{{-3.357662782649366, 3.5}, {-3.2059090053044454`, 
       3.5}, {-3.230251642536255, 3.4373449933535234`}, {-3.357662782649366, 
       3.5}}], PolygonBox[{{-3.230251642536255, 
       3.4373449933535234`}, {-3.404942744332997, 
       3.404942744332997}, {-3.357662782649366, 3.5}, {-3.230251642536255, 
       3.4373449933535234`}}], 
      PolygonBox[{{-2.5, 3.5}, {-3.357662782649366, 3.5}, {-3.404942744332997,
        3.404942744332997}, {-2.5, 3.5}}], 
      PolygonBox[{{-3.404942744332997, 
       3.404942744332997}, {-3.4373449933535234`, 3.2302516425362553`}, {-2.5,
        3.5}, {-3.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-3.5, 3.357662782649369}, {-2.5, 
       3.5}, {-3.4373449933535234`, 3.2302516425362553`}, {-3.5, 
       3.357662782649369}}], 
      PolygonBox[{{-3.4373449933535234`, 
       3.2302516425362553`}, {-3.437499981032941, 3.0842925895560622`}, {-3.5,
        3.357662782649369}, {-3.4373449933535234`, 3.2302516425362553`}}], 
      PolygonBox[{{-3.5, 3.205909005282899}, {-3.5, 
       3.357662782649369}, {-3.437499981032941, 3.0842925895560622`}, {-3.5, 
       3.205909005282899}}], 
      PolygonBox[{{-3.437499981032941, 3.0842925895560622`}, {-3.4375, 
       3.0001231780629953`}, {-3.5, 3.205909005282899}, {-3.437499981032941, 
       3.0842925895560622`}}], 
      PolygonBox[{{-3.5, 3.0806786667587}, {-3.5, 
       3.205909005282899}, {-3.4375, 3.0001231780629953`}, {-3.5, 
       3.0806786667587}}], 
      PolygonBox[{{-3.4375, 3.0001231780629953`}, {-3.437499981032941, 
       2.915707410443945}, {-3.5, 3.0806786667587}, {-3.4375, 
       3.0001231780629953`}}], 
      PolygonBox[{{-3.5, 2.7940909948547215`}, {-3.5, 
       3.0806786667587}, {-3.437499981032941, 2.915707410443945}, {-3.5, 
       2.7940909948547215`}}], 
      PolygonBox[{{-3.437499981032941, 
       2.915707410443945}, {-3.4373449933535234`, 2.769748357463745}, {-3.5, 
       2.7940909948547215`}, {-3.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-3.5, 2.6423372173506348`}, {-3.5, 
       2.7940909948547215`}, {-3.4373449933535234`, 2.769748357463745}, {-3.5,
        2.6423372173506348`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       2.769748357463745}, {-3.404942744332997, 2.595057255667003}, {-3.5, 
       2.6423372173506348`}, {-3.4373449933535234`, 2.769748357463745}}], 
      PolygonBox[{{-3.5, 3.5}, {-3.5, 
       2.6423372173506348`}, {-3.404942744332997, 2.595057255667003}, {-3.5, 
       3.5}}], 
      PolygonBox[{{-3.404942744332997, 
       2.595057255667003}, {-3.230251642536255, 2.5626550066464766`}, {-3.5, 
       3.5}, {-3.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-3.5, 2.5}, {-3.5, 3.5}, {-3.230251642536255, 
       2.5626550066464766`}, {-3.5, 2.5}}], 
      PolygonBox[{{-3.230251642536255, 
       2.5626550066464766`}, {-3.084292589556064, 2.562500018967059}, {-3.5, 
       2.5}, {-3.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-3.205909005566828, 2.5}, {-3.5, 2.5}, {-3.084292589556064,
        2.562500018967059}, {-3.205909005566828, 2.5}}], 
      PolygonBox[{{-3.084292589556064, 
       2.562500018967059}, {-2.999865158168957, 2.5625}, {-3.205909005566828, 
       2.5}, {-3.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-2.9176761295989384`, 2.5}, {-3.205909005566828, 
       2.5}, {-2.999865158168957, 2.5625}, {-2.9176761295989384`, 2.5}}], 
      PolygonBox[{{-2.999865158168957, 2.5625}, {-2.9157074104439467`, 
       2.562500018967059}, {-2.9176761295989384`, 2.5}, {-2.999865158168957, 
       2.5625}}], 
      PolygonBox[{{-2.7940909946396024`, 2.5}, {-2.9176761295989384`, 
       2.5}, {-2.9157074104439467`, 2.562500018967059}, {-2.7940909946396024`,
        2.5}}], 
      PolygonBox[{{-2.9157074104439467`, 
       2.562500018967059}, {-2.769748357463745, 
       2.5626550066464766`}, {-2.7940909946396024`, 
       2.5}, {-2.9157074104439467`, 2.562500018967059}}], 
      PolygonBox[{{-2.642337217350629, 2.5}, {-2.7940909946396024`, 
       2.5}, {-2.769748357463745, 2.5626550066464766`}, {-2.642337217350629, 
       2.5}}], PolygonBox[{{-2.769748357463745, 
       2.5626550066464766`}, {-2.595057255667003, 
       2.595057255667003}, {-2.642337217350629, 2.5}, {-2.769748357463745, 
       2.5626550066464766`}}], 
      PolygonBox[{{-2.5, 2.5}, {-2.642337217350629, 2.5}, {-2.595057255667003,
        2.595057255667003}, {-2.5, 2.5}}], 
      PolygonBox[{{-2.595057255667003, 
       2.595057255667003}, {-2.595057255667003, 2.595057255667003}, {-2.5, 
       2.5}, {-2.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{-2.5, 2.5}, {-2.5, 2.5}, {-2.595057255667003, 
       2.595057255667003}, {-2.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, 4.}, {-3.4791666666666665`, 4.}, {-3.4583333333333335`, 
       4.}, {-3.4375, 4.}, {-3.4166666666666665`, 4.}, {-3.3958333333333335`, 
       4.}, {-3.375, 4.}, {-3.375, 4.}, {-3.3958333333333335`, 
       4.}, {-3.4166666666666665`, 4.}, {-3.4375, 4.}, {-3.4583333333333335`, 
       4.}, {-3.4791666666666665`, 4.}, {-3.5, 4.}, {-3.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, 4.}, {-2.6041666666666665`, 
       4.}, {-2.5833333333333335`, 4.}, {-2.5625, 4.}, {-2.5416666666666665`, 
       4.}, {-2.5208333333333335`, 4.}, {-2.5, 4.}, {-2.5, 
       4.}, {-2.5208333333333335`, 4.}, {-2.5416666666666665`, 4.}, {-2.5625, 
       4.}, {-2.5833333333333335`, 4.}, {-2.6041666666666665`, 4.}, {-2.625, 
       4.}, {-2.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 3.5}, {-3., 3.5208333333333335`}, {-3., 
       3.5416666666666665`}, {-3., 3.5625}, {-3., 3.5833333333333335`}, {-3., 
       3.6041666666666665`}, {-3., 3.625}, {-3., 3.625}, {-3., 
       3.6041666666666665`}, {-3., 3.5833333333333335`}, {-3., 3.5625}, {-3., 
       3.5416666666666665`}, {-3., 3.5208333333333335`}, {-3., 3.5}, {-3., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 4.375}, {-3., 4.395833333333333}, {-3., 
       4.416666666666667}, {-3., 4.4375}, {-3., 4.458333333333333}, {-3., 
       4.479166666666667}, {-3., 4.5}, {-3., 4.5}, {-3., 
       4.479166666666667}, {-3., 4.458333333333333}, {-3., 4.4375}, {-3., 
       4.416666666666667}, {-3., 4.395833333333333}, {-3., 4.375}, {-3., 
       4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, 4.}, {-3.25, 4.}, {-3.125, 4.}, {-3., 4.}, {-2.875, 
       4.}, {-2.75, 4.}, {-2.625, 4.}, {-2.625, 4.}, {-2.75, 4.}, {-2.875, 
       4.}, {-3., 4.}, {-3.125, 4.}, {-3.25, 4.}, {-3.375, 4.}, {-3.375, 
       4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 3.625}, {-3., 3.75}, {-3., 3.875}, {-3., 4.}, {-3., 
       4.125}, {-3., 4.25}, {-3., 4.375}, {-3., 4.375}, {-3., 4.25}, {-3., 
       4.125}, {-3., 4.}, {-3., 3.875}, {-3., 3.75}, {-3., 3.625}, {-3., 
       3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByC0gIOYXqCjthTrAfWizk9JyQIOF3aYVz1J
g8ofEHBIFUpR+/iA9cC5b2dz2vkFHcDiDWwHZig/OdTrI+iwUfqtlJUl+4Gv
GeHxr4qg8gwcEP0Ngg7+T4SeHj3GgSrfwAnXP/vt7Jt88lxw8w3cT7RKz+SC
2//q4rp9V55yHdCAug9iPjfc/TD5TWB38KPqb+BzmAM1H+IPXrj9EH/ywt0H
CQdeVPcz8DpsgvoPJs8I9T9MPyx8YOajhB/Qflj4boS6Dz38AXbEf3E=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByC0kEMoGLDC+atXgQAbnA+hOdDUc8L5YOWr
uNDU8xDkQ8wRhPMh9gqgqRdAk+eD88PA+nnR1PNg8FejuI8Hzf0w9Rxo6tng
/DCU8IGpZyHID0VxHwua+2HqBdDkBdD0C6KpF3IAABtMUCU=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, 
       3.7348349570550448`}, {-2.6752404735808355`, 
       3.8125}, {-2.595057255667003, 
       3.595057255667003}, {-2.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{-2.5626550066464766`, 
       3.7697483574637447`}, {-2.595057255667003, 
       3.595057255667003}, {-2.6752404735808355`, 
       3.8125}, {-2.5626550066464766`, 3.7697483574637447`}}], 
      PolygonBox[{{-2.6752404735808355`, 3.8125}, {-2.6377778151415994`, 
       3.9029428580865546`}, {-2.5626550066464766`, 
       3.7697483574637447`}, {-2.6752404735808355`, 3.8125}}], 
      PolygonBox[{{-2.562500018967059, 
       3.915707410443938}, {-2.5626550066464766`, 
       3.7697483574637447`}, {-2.6377778151415994`, 
       3.9029428580865546`}, {-2.562500018967059, 3.915707410443938}}], 
      PolygonBox[{{-2.6377778151415994`, 3.9029428580865546`}, {-2.625, 
       4.}, {-2.562500018967059, 3.915707410443938}, {-2.6377778151415994`, 
       3.9029428580865546`}}], 
      PolygonBox[{{-2.5625, 4.}, {-2.562500018967059, 
       3.915707410443938}, {-2.625, 4.}, {-2.5625, 4.}}], 
      PolygonBox[{{-2.625, 4.}, {-2.6377778151415994`, 
       4.097057141913445}, {-2.5625, 4.}, {-2.625, 4.}}], 
      PolygonBox[{{-2.562500018967059, 4.084292589556061}, {-2.5625, 
       4.}, {-2.6377778151415994`, 4.097057141913445}, {-2.562500018967059, 
       4.084292589556061}}], 
      PolygonBox[{{-2.6377778151415994`, 
       4.097057141913445}, {-2.6752404735808355`, 
       4.1875}, {-2.562500018967059, 
       4.084292589556061}, {-2.6377778151415994`, 4.097057141913445}}], 
      PolygonBox[{{-2.5626550066464766`, 
       4.230251642536255}, {-2.562500018967059, 
       4.084292589556061}, {-2.6752404735808355`, 
       4.1875}, {-2.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, 4.1875}, {-2.7348349570550448`, 
       4.265165042944956}, {-2.5626550066464766`, 
       4.230251642536255}, {-2.6752404735808355`, 4.1875}}], 
      PolygonBox[{{-2.595057255667003, 
       4.404942744332997}, {-2.5626550066464766`, 
       4.230251642536255}, {-2.7348349570550448`, 
       4.265165042944956}, {-2.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, 4.265165042944956}, {-2.8125, 
       4.3247595264191645`}, {-2.595057255667003, 
       4.404942744332997}, {-2.7348349570550448`, 4.265165042944956}}], 
      PolygonBox[{{-2.7697483574637447`, 
       4.437344993353523}, {-2.595057255667003, 4.404942744332997}, {-2.8125, 
       4.3247595264191645`}, {-2.7697483574637447`, 4.437344993353523}}], 
      PolygonBox[{{-2.8125, 4.3247595264191645`}, {-2.9029428580865546`, 
       4.362222184858401}, {-2.7697483574637447`, 
       4.437344993353523}, {-2.8125, 4.3247595264191645`}}], 
      PolygonBox[{{-2.9157074104439396`, 
       4.437499981032941}, {-2.7697483574637447`, 
       4.437344993353523}, {-2.9029428580865546`, 
       4.362222184858401}, {-2.9157074104439396`, 4.437499981032941}}], 
      PolygonBox[{{-2.9029428580865546`, 4.362222184858401}, {-3., 
       4.375}, {-2.9157074104439396`, 
       4.437499981032941}, {-2.9029428580865546`, 4.362222184858401}}], 
      PolygonBox[{{-2.9998944727795123`, 4.4375}, {-2.9157074104439396`, 
       4.437499981032941}, {-3., 4.375}, {-2.9998944727795123`, 4.4375}}], 
      PolygonBox[{{-3., 4.375}, {-3.097057141913445, 
       4.362222184858401}, {-2.9998944727795123`, 4.4375}, {-3., 4.375}}], 
      PolygonBox[{{-3.084292589556057, 
       4.437499981032941}, {-2.9998944727795123`, 
       4.4375}, {-3.097057141913445, 4.362222184858401}, {-3.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-3.097057141913445, 4.362222184858401}, {-3.1875, 
       4.3247595264191645`}, {-3.084292589556057, 
       4.437499981032941}, {-3.097057141913445, 4.362222184858401}}], 
      PolygonBox[{{-3.230251642536255, 
       4.437344993353523}, {-3.084292589556057, 4.437499981032941}, {-3.1875, 
       4.3247595264191645`}, {-3.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{-3.1875, 4.3247595264191645`}, {-3.2651650429449552`, 
       4.265165042944956}, {-3.230251642536255, 4.437344993353523}, {-3.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{-3.404942744332997, 
       4.404942744332997}, {-3.230251642536255, 
       4.437344993353523}, {-3.2651650429449552`, 
       4.265165042944956}, {-3.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, 
       4.265165042944956}, {-3.3247595264191645`, 
       4.1875}, {-3.404942744332997, 
       4.404942744332997}, {-3.2651650429449552`, 4.265165042944956}}], 
      PolygonBox[{{-3.4373449933535234`, 
       4.230251642536255}, {-3.404942744332997, 
       4.404942744332997}, {-3.3247595264191645`, 
       4.1875}, {-3.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{-3.3247595264191645`, 4.1875}, {-3.3622221848584006`, 
       4.097057141913446}, {-3.4373449933535234`, 
       4.230251642536255}, {-3.3247595264191645`, 4.1875}}], 
      PolygonBox[{{-3.437499981032941, 
       4.084292589556062}, {-3.4373449933535234`, 
       4.230251642536255}, {-3.3622221848584006`, 
       4.097057141913446}, {-3.437499981032941, 4.084292589556062}}], 
      PolygonBox[{{-3.3622221848584006`, 4.097057141913446}, {-3.375, 
       4.}, {-3.437499981032941, 4.084292589556062}, {-3.3622221848584006`, 
       4.097057141913446}}], 
      PolygonBox[{{-3.4375, 4.000123178062996}, {-3.437499981032941, 
       4.084292589556062}, {-3.375, 4.}, {-3.4375, 4.000123178062996}}], 
      PolygonBox[{{-3.375, 4.}, {-3.3622221848584006`, 
       3.902942858086555}, {-3.4375, 4.000123178062996}, {-3.375, 4.}}], 
      PolygonBox[{{-3.437499981032941, 3.915707410443945}, {-3.4375, 
       4.000123178062996}, {-3.3622221848584006`, 
       3.902942858086555}, {-3.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-3.3622221848584006`, 
       3.902942858086555}, {-3.3247595264191645`, 
       3.8125}, {-3.437499981032941, 
       3.915707410443945}, {-3.3622221848584006`, 3.902942858086555}}], 
      PolygonBox[{{-3.4373449933535234`, 
       3.769748357463745}, {-3.437499981032941, 
       3.915707410443945}, {-3.3247595264191645`, 
       3.8125}, {-3.4373449933535234`, 3.769748357463745}}], 
      PolygonBox[{{-3.3247595264191645`, 3.8125}, {-3.2651650429449552`, 
       3.7348349570550448`}, {-3.4373449933535234`, 
       3.769748357463745}, {-3.3247595264191645`, 3.8125}}], 
      PolygonBox[{{-3.404942744332997, 
       3.595057255667003}, {-3.4373449933535234`, 
       3.769748357463745}, {-3.2651650429449552`, 
       3.7348349570550448`}, {-3.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-3.2651650429449552`, 3.7348349570550448`}, {-3.1875, 
       3.6752404735808355`}, {-3.404942744332997, 
       3.595057255667003}, {-3.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{-3.230251642536255, 
       3.5626550066464766`}, {-3.404942744332997, 
       3.595057255667003}, {-3.1875, 
       3.6752404735808355`}, {-3.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-3.1875, 3.6752404735808355`}, {-3.0970571419134454`, 
       3.6377778151415994`}, {-3.230251642536255, 
       3.5626550066464766`}, {-3.1875, 3.6752404735808355`}}], 
      PolygonBox[{{-3.084292589556064, 
       3.562500018967059}, {-3.230251642536255, 
       3.5626550066464766`}, {-3.0970571419134454`, 
       3.6377778151415994`}, {-3.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-3.0970571419134454`, 3.6377778151415994`}, {-3., 
       3.625}, {-3.084292589556064, 3.562500018967059}, {-3.0970571419134454`,
        3.6377778151415994`}}], 
      PolygonBox[{{-2.999865158168957, 3.5625}, {-3.084292589556064, 
       3.562500018967059}, {-3., 3.625}, {-2.999865158168957, 3.5625}}], 
      PolygonBox[{{-3., 3.625}, {-2.902942858086555, 
       3.6377778151415994`}, {-2.999865158168957, 3.5625}, {-3., 3.625}}], 
      PolygonBox[{{-2.9157074104439467`, 
       3.562500018967059}, {-2.999865158168957, 3.5625}, {-2.902942858086555, 
       3.6377778151415994`}, {-2.9157074104439467`, 3.562500018967059}}], 
      PolygonBox[{{-2.902942858086555, 
       3.6377778151415994`}, {-2.8125000000000004`, 
       3.6752404735808355`}, {-2.9157074104439467`, 
       3.562500018967059}, {-2.902942858086555, 3.6377778151415994`}}], 
      PolygonBox[{{-2.769748357463745, 
       3.5626550066464766`}, {-2.9157074104439467`, 
       3.562500018967059}, {-2.8125000000000004`, 
       3.6752404735808355`}, {-2.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{-2.8125000000000004`, 
       3.6752404735808355`}, {-2.7348349570550448`, 
       3.7348349570550448`}, {-2.769748357463745, 
       3.5626550066464766`}, {-2.8125000000000004`, 3.6752404735808355`}}], 
      PolygonBox[{{-2.595057255667003, 
       3.595057255667003}, {-2.769748357463745, 
       3.5626550066464766`}, {-2.7348349570550448`, 
       3.7348349570550448`}, {-2.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-2.7348349570550448`, 
       3.7348349570550448`}, {-2.7348349570550448`, 
       3.7348349570550448`}, {-2.595057255667003, 
       3.595057255667003}, {-2.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{-2.595057255667003, 
       3.595057255667003}, {-2.595057255667003, 
       3.595057255667003}, {-2.7348349570550448`, 
       3.7348349570550448`}, {-2.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-2.595057255667003, 
       3.595057255667003}, {-2.5626550066464766`, 3.7697483574637447`}, {-2.5,
        3.5}, {-2.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-2.5, 3.642337217350632}, {-2.5, 
       3.5}, {-2.5626550066464766`, 3.7697483574637447`}, {-2.5, 
       3.642337217350632}}], 
      PolygonBox[{{-2.5626550066464766`, 
       3.7697483574637447`}, {-2.562500018967059, 3.915707410443938}, {-2.5, 
       3.642337217350632}, {-2.5626550066464766`, 3.7697483574637447`}}], 
      PolygonBox[{{-2.5, 3.79409099469826}, {-2.5, 
       3.642337217350632}, {-2.562500018967059, 3.915707410443938}, {-2.5, 
       3.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, 3.915707410443938}, {-2.5625, 
       4.}, {-2.5, 3.79409099469826}, {-2.562500018967059, 
       3.915707410443938}}], 
      PolygonBox[{{-2.5, 4.}, {-2.5, 3.79409099469826}, {-2.5625, 4.}, {-2.5, 
       4.}}], PolygonBox[{{-2.5625, 4.}, {-2.562500018967059, 
       4.084292589556061}, {-2.5, 4.}, {-2.5625, 4.}}], 
      PolygonBox[{{-2.5, 4.20590900530174}, {-2.5, 4.}, {-2.562500018967059, 
       4.084292589556061}, {-2.5, 4.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, 
       4.084292589556061}, {-2.5626550066464766`, 4.230251642536255}, {-2.5, 
       4.20590900530174}, {-2.562500018967059, 4.084292589556061}}], 
      PolygonBox[{{-2.5, 4.357662782649368}, {-2.5, 
       4.20590900530174}, {-2.5626550066464766`, 4.230251642536255}, {-2.5, 
       4.357662782649368}}], 
      PolygonBox[{{-2.5626550066464766`, 
       4.230251642536255}, {-2.595057255667003, 4.404942744332997}, {-2.5, 
       4.357662782649368}, {-2.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{-2.508553435038814, 4.491446564961186}, {-2.5, 
       4.357662782649368}, {-2.595057255667003, 
       4.404942744332997}, {-2.508553435038814, 4.491446564961186}}], 
      PolygonBox[{{-2.595057255667003, 
       4.404942744332997}, {-2.7697483574637447`, 
       4.437344993353523}, {-2.508553435038814, 
       4.491446564961186}, {-2.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{-2.642337217350632, 4.5}, {-2.508553435038814, 
       4.491446564961186}, {-2.7697483574637447`, 
       4.437344993353523}, {-2.642337217350632, 4.5}}], 
      PolygonBox[{{-2.7697483574637447`, 
       4.437344993353523}, {-2.9157074104439396`, 
       4.437499981032941}, {-2.642337217350632, 4.5}, {-2.7697483574637447`, 
       4.437344993353523}}], 
      PolygonBox[{{-2.7940909946267443`, 4.5}, {-2.642337217350632, 
       4.5}, {-2.9157074104439396`, 4.437499981032941}, {-2.7940909946267443`,
        4.5}}], 
      PolygonBox[{{-2.9157074104439396`, 
       4.437499981032941}, {-2.9998944727795123`, 
       4.4375}, {-2.7940909946267443`, 4.5}, {-2.9157074104439396`, 
       4.437499981032941}}], 
      PolygonBox[{{-2.92205804197311, 4.5}, {-2.7940909946267443`, 
       4.5}, {-2.9998944727795123`, 4.4375}, {-2.92205804197311, 4.5}}], 
      PolygonBox[{{-2.9998944727795123`, 4.4375}, {-3.084292589556057, 
       4.437499981032941}, {-2.92205804197311, 4.5}, {-2.9998944727795123`, 
       4.4375}}], 
      PolygonBox[{{-3.2059090053044454`, 4.5}, {-2.92205804197311, 
       4.5}, {-3.084292589556057, 4.437499981032941}, {-3.2059090053044454`, 
       4.5}}], PolygonBox[{{-3.084292589556057, 
       4.437499981032941}, {-3.230251642536255, 
       4.437344993353523}, {-3.2059090053044454`, 4.5}, {-3.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-3.357662782649366, 4.5}, {-3.2059090053044454`, 
       4.5}, {-3.230251642536255, 4.437344993353523}, {-3.357662782649366, 
       4.5}}], PolygonBox[{{-3.230251642536255, 
       4.437344993353523}, {-3.404942744332997, 
       4.404942744332997}, {-3.357662782649366, 4.5}, {-3.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{-2.5, 4.5}, {-3.357662782649366, 4.5}, {-3.404942744332997,
        4.404942744332997}, {-2.5, 4.5}}], 
      PolygonBox[{{-3.404942744332997, 
       4.404942744332997}, {-3.4373449933535234`, 4.230251642536255}, {-2.5, 
       4.5}, {-3.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-3.5, 4.357662782649369}, {-2.5, 
       4.5}, {-3.4373449933535234`, 4.230251642536255}, {-3.5, 
       4.357662782649369}}], 
      PolygonBox[{{-3.4373449933535234`, 
       4.230251642536255}, {-3.437499981032941, 4.084292589556062}, {-3.5, 
       4.357662782649369}, {-3.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{-3.5, 4.205909005282899}, {-3.5, 
       4.357662782649369}, {-3.437499981032941, 4.084292589556062}, {-3.5, 
       4.205909005282899}}], 
      PolygonBox[{{-3.437499981032941, 4.084292589556062}, {-3.4375, 
       4.000123178062996}, {-3.5, 4.205909005282899}, {-3.437499981032941, 
       4.084292589556062}}], 
      PolygonBox[{{-3.5, 4.0806786667587005`}, {-3.5, 
       4.205909005282899}, {-3.4375, 4.000123178062996}, {-3.5, 
       4.0806786667587005`}}], 
      PolygonBox[{{-3.4375, 4.000123178062996}, {-3.437499981032941, 
       3.915707410443945}, {-3.5, 4.0806786667587005`}, {-3.4375, 
       4.000123178062996}}], 
      PolygonBox[{{-3.5, 3.7940909948547215`}, {-3.5, 
       4.0806786667587005`}, {-3.437499981032941, 3.915707410443945}, {-3.5, 
       3.7940909948547215`}}], 
      PolygonBox[{{-3.437499981032941, 
       3.915707410443945}, {-3.4373449933535234`, 3.769748357463745}, {-3.5, 
       3.7940909948547215`}, {-3.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-3.5, 3.6423372173506348`}, {-3.5, 
       3.7940909948547215`}, {-3.4373449933535234`, 3.769748357463745}, {-3.5,
        3.6423372173506348`}}], 
      PolygonBox[{{-3.4373449933535234`, 
       3.769748357463745}, {-3.404942744332997, 3.595057255667003}, {-3.5, 
       3.6423372173506348`}, {-3.4373449933535234`, 3.769748357463745}}], 
      PolygonBox[{{-3.5, 4.5}, {-3.5, 
       3.6423372173506348`}, {-3.404942744332997, 3.595057255667003}, {-3.5, 
       4.5}}], PolygonBox[{{-3.404942744332997, 
       3.595057255667003}, {-3.230251642536255, 3.5626550066464766`}, {-3.5, 
       4.5}, {-3.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-3.5, 3.5}, {-3.5, 4.5}, {-3.230251642536255, 
       3.5626550066464766`}, {-3.5, 3.5}}], 
      PolygonBox[{{-3.230251642536255, 
       3.5626550066464766`}, {-3.084292589556064, 3.562500018967059}, {-3.5, 
       3.5}, {-3.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-3.205909005566828, 3.5}, {-3.5, 3.5}, {-3.084292589556064,
        3.562500018967059}, {-3.205909005566828, 3.5}}], 
      PolygonBox[{{-3.084292589556064, 
       3.562500018967059}, {-2.999865158168957, 3.5625}, {-3.205909005566828, 
       3.5}, {-3.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-2.9176761295989384`, 3.5}, {-3.205909005566828, 
       3.5}, {-2.999865158168957, 3.5625}, {-2.9176761295989384`, 3.5}}], 
      PolygonBox[{{-2.999865158168957, 3.5625}, {-2.9157074104439467`, 
       3.562500018967059}, {-2.9176761295989384`, 3.5}, {-2.999865158168957, 
       3.5625}}], 
      PolygonBox[{{-2.7940909946396024`, 3.5}, {-2.9176761295989384`, 
       3.5}, {-2.9157074104439467`, 3.562500018967059}, {-2.7940909946396024`,
        3.5}}], 
      PolygonBox[{{-2.9157074104439467`, 
       3.562500018967059}, {-2.769748357463745, 
       3.5626550066464766`}, {-2.7940909946396024`, 
       3.5}, {-2.9157074104439467`, 3.562500018967059}}], 
      PolygonBox[{{-2.642337217350629, 3.5}, {-2.7940909946396024`, 
       3.5}, {-2.769748357463745, 3.5626550066464766`}, {-2.642337217350629, 
       3.5}}], PolygonBox[{{-2.769748357463745, 
       3.5626550066464766`}, {-2.595057255667003, 
       3.595057255667003}, {-2.642337217350629, 3.5}, {-2.769748357463745, 
       3.5626550066464766`}}], 
      PolygonBox[{{-2.5, 3.5}, {-2.642337217350629, 3.5}, {-2.595057255667003,
        3.595057255667003}, {-2.5, 3.5}}], 
      PolygonBox[{{-2.595057255667003, 
       3.595057255667003}, {-2.595057255667003, 3.595057255667003}, {-2.5, 
       3.5}, {-2.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{-2.5, 3.5}, {-2.5, 3.5}, {-2.595057255667003, 
       3.595057255667003}, {-2.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5, 5.}, {-3.4791666666666665`, 5.}, {-3.4583333333333335`, 
       5.}, {-3.4375, 5.}, {-3.4166666666666665`, 5.}, {-3.3958333333333335`, 
       5.}, {-3.375, 5.}, {-3.375, 5.}, {-3.3958333333333335`, 
       5.}, {-3.4166666666666665`, 5.}, {-3.4375, 5.}, {-3.4583333333333335`, 
       5.}, {-3.4791666666666665`, 5.}, {-3.5, 5.}, {-3.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.625, 5.}, {-2.6041666666666665`, 
       5.}, {-2.5833333333333335`, 5.}, {-2.5625, 5.}, {-2.5416666666666665`, 
       5.}, {-2.5208333333333335`, 5.}, {-2.5, 5.}, {-2.5, 
       5.}, {-2.5208333333333335`, 5.}, {-2.5416666666666665`, 5.}, {-2.5625, 
       5.}, {-2.5833333333333335`, 5.}, {-2.6041666666666665`, 5.}, {-2.625, 
       5.}, {-2.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 4.5}, {-3., 4.520833333333333}, {-3., 
       4.541666666666667}, {-3., 4.5625}, {-3., 4.583333333333333}, {-3., 
       4.604166666666667}, {-3., 4.625}, {-3., 4.625}, {-3., 
       4.604166666666667}, {-3., 4.583333333333333}, {-3., 4.5625}, {-3., 
       4.541666666666667}, {-3., 4.520833333333333}, {-3., 4.5}, {-3., 
       4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 5.375}, {-3., 5.395833333333333}, {-3., 
       5.416666666666667}, {-3., 5.4375}, {-3., 5.458333333333333}, {-3., 
       5.479166666666667}, {-3., 5.5}, {-3., 5.5}, {-3., 
       5.479166666666667}, {-3., 5.458333333333333}, {-3., 5.4375}, {-3., 
       5.416666666666667}, {-3., 5.395833333333333}, {-3., 5.375}, {-3., 
       5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.375, 5.}, {-3.25, 5.}, {-3.125, 5.}, {-3., 5.}, {-2.875, 
       5.}, {-2.75, 5.}, {-2.625, 5.}, {-2.625, 5.}, {-2.75, 5.}, {-2.875, 
       5.}, {-3., 5.}, {-3.125, 5.}, {-3.25, 5.}, {-3.375, 5.}, {-3.375, 
       5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., 4.625}, {-3., 4.75}, {-3., 4.875}, {-3., 5.}, {-3., 
       5.125}, {-3., 5.25}, {-3., 5.375}, {-3., 5.375}, {-3., 5.25}, {-3., 
       5.125}, {-3., 5.}, {-3., 4.875}, {-3., 4.75}, {-3., 4.625}, {-3., 
       4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGsByC0iIOYXqCjthTrAfWizk9JySIOF3aYVz1J
g8ofEHFIFUpR+/iA9cC5b2dz2vlFHcDiDWwHZig/OdTrI+qwUfqtlJUl+4Gv
GeHxr4qg8gwcEP0Nog7+T4SeHj3GgSrfwAnXP/vt7Jt88lxw8w3cT7RKz+SC
2//q4rp9V55yHdCAug9iPjfc/TD5m71lvHPnCKPqdxB2mAM135jTaHLFByG4
/Rl3pG2LNgvB3cc9fcUC0V4hNPcLOWyC+g8mzwj1P0w/LHyMoOajhB/Qflj4
3oC6Dz38AaZXgh8=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsByC0mEMoGLDC+atXgQAbnA+hOdDUc8L5YOWr
uNDU8xDkQ8wRhfMh9oqgqRdBUy+Mpl4ITT0mfzWK+4TQ3A9Tz4Gmng3OD0MJ
H5h6FoJ8VPexoLkfpl4ETb0ImnpRNPViDgCHoFCq
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-2.7348349570550448`, 
       4.734834957055044}, {-2.6752404735808355`, 
       4.8125}, {-2.595057255667003, 
       4.595057255667003}, {-2.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{-2.5626550066464766`, 
       4.769748357463745}, {-2.595057255667003, 
       4.595057255667003}, {-2.6752404735808355`, 
       4.8125}, {-2.5626550066464766`, 4.769748357463745}}], 
      PolygonBox[{{-2.6752404735808355`, 4.8125}, {-2.6377778151415994`, 
       4.902942858086555}, {-2.5626550066464766`, 
       4.769748357463745}, {-2.6752404735808355`, 4.8125}}], 
      PolygonBox[{{-2.562500018967059, 
       4.915707410443938}, {-2.5626550066464766`, 
       4.769748357463745}, {-2.6377778151415994`, 
       4.902942858086555}, {-2.562500018967059, 4.915707410443938}}], 
      PolygonBox[{{-2.6377778151415994`, 4.902942858086555}, {-2.625, 
       5.}, {-2.562500018967059, 4.915707410443938}, {-2.6377778151415994`, 
       4.902942858086555}}], 
      PolygonBox[{{-2.5625, 5.}, {-2.562500018967059, 
       4.915707410443938}, {-2.625, 5.}, {-2.5625, 5.}}], 
      PolygonBox[{{-2.625, 5.}, {-2.6377778151415994`, 
       5.097057141913445}, {-2.5625, 5.}, {-2.625, 5.}}], 
      PolygonBox[{{-2.562500018967059, 5.084292589556061}, {-2.5625, 
       5.}, {-2.6377778151415994`, 5.097057141913445}, {-2.562500018967059, 
       5.084292589556061}}], 
      PolygonBox[{{-2.6377778151415994`, 
       5.097057141913445}, {-2.6752404735808355`, 
       5.1875}, {-2.562500018967059, 
       5.084292589556061}, {-2.6377778151415994`, 5.097057141913445}}], 
      PolygonBox[{{-2.5626550066464766`, 
       5.230251642536255}, {-2.562500018967059, 
       5.084292589556061}, {-2.6752404735808355`, 
       5.1875}, {-2.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{-2.6752404735808355`, 5.1875}, {-2.7348349570550448`, 
       5.265165042944956}, {-2.5626550066464766`, 
       5.230251642536255}, {-2.6752404735808355`, 5.1875}}], 
      PolygonBox[{{-2.595057255667003, 
       5.404942744332997}, {-2.5626550066464766`, 
       5.230251642536255}, {-2.7348349570550448`, 
       5.265165042944956}, {-2.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{-2.7348349570550448`, 5.265165042944956}, {-2.8125, 
       5.3247595264191645`}, {-2.595057255667003, 
       5.404942744332997}, {-2.7348349570550448`, 5.265165042944956}}], 
      PolygonBox[{{-2.7697483574637447`, 
       5.437344993353523}, {-2.595057255667003, 5.404942744332997}, {-2.8125, 
       5.3247595264191645`}, {-2.7697483574637447`, 5.437344993353523}}], 
      PolygonBox[{{-2.8125, 5.3247595264191645`}, {-2.9029428580865546`, 
       5.362222184858401}, {-2.7697483574637447`, 
       5.437344993353523}, {-2.8125, 5.3247595264191645`}}], 
      PolygonBox[{{-2.9157074104439396`, 
       5.437499981032941}, {-2.7697483574637447`, 
       5.437344993353523}, {-2.9029428580865546`, 
       5.362222184858401}, {-2.9157074104439396`, 5.437499981032941}}], 
      PolygonBox[{{-2.9029428580865546`, 5.362222184858401}, {-3., 
       5.375}, {-2.9157074104439396`, 
       5.437499981032941}, {-2.9029428580865546`, 5.362222184858401}}], 
      PolygonBox[{{-2.9998944727795123`, 5.4375}, {-2.9157074104439396`, 
       5.437499981032941}, {-3., 5.375}, {-2.9998944727795123`, 5.4375}}], 
      PolygonBox[{{-3., 5.375}, {-3.097057141913445, 
       5.362222184858401}, {-2.9998944727795123`, 5.4375}, {-3., 5.375}}], 
      PolygonBox[{{-3.084292589556057, 
       5.437499981032941}, {-2.9998944727795123`, 
       5.4375}, {-3.097057141913445, 5.362222184858401}, {-3.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-3.097057141913445, 5.362222184858401}, {-3.1875, 
       5.3247595264191645`}, {-3.084292589556057, 
       5.437499981032941}, {-3.097057141913445, 5.362222184858401}}], 
      PolygonBox[{{-3.230251642536255, 
       5.437344993353523}, {-3.084292589556057, 5.437499981032941}, {-3.1875, 
       5.3247595264191645`}, {-3.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{-3.1875, 5.3247595264191645`}, {-3.2651650429449552`, 
       5.265165042944956}, {-3.230251642536255, 5.437344993353523}, {-3.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{-3.404942744332997, 
       5.404942744332997}, {-3.230251642536255, 
       5.437344993353523}, {-3.2651650429449552`, 
       5.265165042944956}, {-3.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-3.2651650429449552`, 
       5.265165042944956}, {-3.3247595264191645`, 
       5.1875}, {-3.404942744332997, 
       5.404942744332997}, {-3.2651650429449552`, 5.265165042944956}}], 
      PolygonBox[{{-3.4373449933535234`, 
       5.230251642536255}, {-3.404942744332997, 
       5.404942744332997}, {-3.3247595264191645`, 
       5.1875}, {-3.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{-3.3247595264191645`, 5.1875}, {-3.3622221848584006`, 
       5.097057141913446}, {-3.4373449933535234`, 
       5.230251642536255}, {-3.3247595264191645`, 5.1875}}], 
      PolygonBox[{{-3.437499981032941, 
       5.084292589556062}, {-3.4373449933535234`, 
       5.230251642536255}, {-3.3622221848584006`, 
       5.097057141913446}, {-3.437499981032941, 5.084292589556062}}], 
      PolygonBox[{{-3.3622221848584006`, 5.097057141913446}, {-3.375, 
       5.}, {-3.437499981032941, 5.084292589556062}, {-3.3622221848584006`, 
       5.097057141913446}}], 
      PolygonBox[{{-3.4375, 5.000123178062996}, {-3.437499981032941, 
       5.084292589556062}, {-3.375, 5.}, {-3.4375, 5.000123178062996}}], 
      PolygonBox[{{-3.375, 5.}, {-3.3622221848584006`, 
       4.902942858086555}, {-3.4375, 5.000123178062996}, {-3.375, 5.}}], 
      PolygonBox[{{-3.437499981032941, 4.915707410443945}, {-3.4375, 
       5.000123178062996}, {-3.3622221848584006`, 
       4.902942858086555}, {-3.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-3.3622221848584006`, 
       4.902942858086555}, {-3.3247595264191645`, 
       4.8125}, {-3.437499981032941, 
       4.915707410443945}, {-3.3622221848584006`, 4.902942858086555}}], 
      PolygonBox[{{-3.4373449933535234`, 
       4.769748357463746}, {-3.437499981032941, 
       4.915707410443945}, {-3.3247595264191645`, 
       4.8125}, {-3.4373449933535234`, 4.769748357463746}}], 
      PolygonBox[{{-3.3247595264191645`, 4.8125}, {-3.2651650429449552`, 
       4.734834957055044}, {-3.4373449933535234`, 
       4.769748357463746}, {-3.3247595264191645`, 4.8125}}], 
      PolygonBox[{{-3.404942744332997, 
       4.595057255667003}, {-3.4373449933535234`, 
       4.769748357463746}, {-3.2651650429449552`, 
       4.734834957055044}, {-3.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-3.2651650429449552`, 4.734834957055044}, {-3.1875, 
       4.6752404735808355`}, {-3.404942744332997, 
       4.595057255667003}, {-3.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{-3.230251642536255, 
       4.562655006646477}, {-3.404942744332997, 4.595057255667003}, {-3.1875, 
       4.6752404735808355`}, {-3.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-3.1875, 4.6752404735808355`}, {-3.0970571419134454`, 
       4.637777815141599}, {-3.230251642536255, 4.562655006646477}, {-3.1875, 
       4.6752404735808355`}}], 
      PolygonBox[{{-3.084292589556064, 
       4.562500018967059}, {-3.230251642536255, 
       4.562655006646477}, {-3.0970571419134454`, 
       4.637777815141599}, {-3.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-3.0970571419134454`, 4.637777815141599}, {-3., 
       4.625}, {-3.084292589556064, 4.562500018967059}, {-3.0970571419134454`,
        4.637777815141599}}], 
      PolygonBox[{{-2.999865158168957, 4.5625}, {-3.084292589556064, 
       4.562500018967059}, {-3., 4.625}, {-2.999865158168957, 4.5625}}], 
      PolygonBox[{{-3., 4.625}, {-2.902942858086555, 
       4.637777815141599}, {-2.999865158168957, 4.5625}, {-3., 4.625}}], 
      PolygonBox[{{-2.9157074104439467`, 
       4.562500018967059}, {-2.999865158168957, 4.5625}, {-2.902942858086555, 
       4.637777815141599}, {-2.9157074104439467`, 4.562500018967059}}], 
      PolygonBox[{{-2.902942858086555, 
       4.637777815141599}, {-2.8125000000000004`, 
       4.6752404735808355`}, {-2.9157074104439467`, 
       4.562500018967059}, {-2.902942858086555, 4.637777815141599}}], 
      PolygonBox[{{-2.769748357463745, 
       4.562655006646477}, {-2.9157074104439467`, 
       4.562500018967059}, {-2.8125000000000004`, 
       4.6752404735808355`}, {-2.769748357463745, 4.562655006646477}}], 
      PolygonBox[{{-2.8125000000000004`, 
       4.6752404735808355`}, {-2.7348349570550448`, 
       4.734834957055044}, {-2.769748357463745, 
       4.562655006646477}, {-2.8125000000000004`, 4.6752404735808355`}}], 
      PolygonBox[{{-2.595057255667003, 
       4.595057255667003}, {-2.769748357463745, 
       4.562655006646477}, {-2.7348349570550448`, 
       4.734834957055044}, {-2.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-2.7348349570550448`, 
       4.734834957055044}, {-2.7348349570550448`, 
       4.734834957055044}, {-2.595057255667003, 
       4.595057255667003}, {-2.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{-2.595057255667003, 
       4.595057255667003}, {-2.595057255667003, 
       4.595057255667003}, {-2.7348349570550448`, 
       4.734834957055044}, {-2.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-2.595057255667003, 
       4.595057255667003}, {-2.5626550066464766`, 4.769748357463745}, {-2.5, 
       4.5}, {-2.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-2.5, 4.642337217350632}, {-2.5, 
       4.5}, {-2.5626550066464766`, 4.769748357463745}, {-2.5, 
       4.642337217350632}}], 
      PolygonBox[{{-2.5626550066464766`, 
       4.769748357463745}, {-2.562500018967059, 4.915707410443938}, {-2.5, 
       4.642337217350632}, {-2.5626550066464766`, 4.769748357463745}}], 
      PolygonBox[{{-2.5, 4.79409099469826}, {-2.5, 
       4.642337217350632}, {-2.562500018967059, 4.915707410443938}, {-2.5, 
       4.79409099469826}}], 
      PolygonBox[{{-2.562500018967059, 4.915707410443938}, {-2.5625, 
       5.}, {-2.5, 4.79409099469826}, {-2.562500018967059, 
       4.915707410443938}}], 
      PolygonBox[{{-2.5, 5.}, {-2.5, 4.79409099469826}, {-2.5625, 5.}, {-2.5, 
       5.}}], PolygonBox[{{-2.5625, 5.}, {-2.562500018967059, 
       5.084292589556061}, {-2.5, 5.}, {-2.5625, 5.}}], 
      PolygonBox[{{-2.5, 5.20590900530174}, {-2.5, 5.}, {-2.562500018967059, 
       5.084292589556061}, {-2.5, 5.20590900530174}}], 
      PolygonBox[{{-2.562500018967059, 
       5.084292589556061}, {-2.5626550066464766`, 5.230251642536255}, {-2.5, 
       5.20590900530174}, {-2.562500018967059, 5.084292589556061}}], 
      PolygonBox[{{-2.5, 5.357662782649368}, {-2.5, 
       5.20590900530174}, {-2.5626550066464766`, 5.230251642536255}, {-2.5, 
       5.357662782649368}}], 
      PolygonBox[{{-2.5626550066464766`, 
       5.230251642536255}, {-2.595057255667003, 5.404942744332997}, {-2.5, 
       5.357662782649368}, {-2.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{-2.508553435038814, 5.491446564961186}, {-2.5, 
       5.357662782649368}, {-2.595057255667003, 
       5.404942744332997}, {-2.508553435038814, 5.491446564961186}}], 
      PolygonBox[{{-2.595057255667003, 
       5.404942744332997}, {-2.7697483574637447`, 
       5.437344993353523}, {-2.508553435038814, 
       5.491446564961186}, {-2.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{-2.642337217350632, 5.5}, {-2.508553435038814, 
       5.491446564961186}, {-2.7697483574637447`, 
       5.437344993353523}, {-2.642337217350632, 5.5}}], 
      PolygonBox[{{-2.7697483574637447`, 
       5.437344993353523}, {-2.9157074104439396`, 
       5.437499981032941}, {-2.642337217350632, 5.5}, {-2.7697483574637447`, 
       5.437344993353523}}], 
      PolygonBox[{{-2.7940909946267443`, 5.5}, {-2.642337217350632, 
       5.5}, {-2.9157074104439396`, 5.437499981032941}, {-2.7940909946267443`,
        5.5}}], 
      PolygonBox[{{-2.9157074104439396`, 
       5.437499981032941}, {-2.9998944727795123`, 
       5.4375}, {-2.7940909946267443`, 5.5}, {-2.9157074104439396`, 
       5.437499981032941}}], 
      PolygonBox[{{-2.92205804197311, 5.5}, {-2.7940909946267443`, 
       5.5}, {-2.9998944727795123`, 5.4375}, {-2.92205804197311, 5.5}}], 
      PolygonBox[{{-2.9998944727795123`, 5.4375}, {-3.084292589556057, 
       5.437499981032941}, {-2.92205804197311, 5.5}, {-2.9998944727795123`, 
       5.4375}}], 
      PolygonBox[{{-3.2059090053044454`, 5.5}, {-2.92205804197311, 
       5.5}, {-3.084292589556057, 5.437499981032941}, {-3.2059090053044454`, 
       5.5}}], PolygonBox[{{-3.084292589556057, 
       5.437499981032941}, {-3.230251642536255, 
       5.437344993353523}, {-3.2059090053044454`, 5.5}, {-3.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-3.357662782649366, 5.5}, {-3.2059090053044454`, 
       5.5}, {-3.230251642536255, 5.437344993353523}, {-3.357662782649366, 
       5.5}}], PolygonBox[{{-3.230251642536255, 
       5.437344993353523}, {-3.404942744332997, 
       5.404942744332997}, {-3.357662782649366, 5.5}, {-3.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{-2.5, 5.5}, {-3.357662782649366, 5.5}, {-3.404942744332997,
        5.404942744332997}, {-2.5, 5.5}}], 
      PolygonBox[{{-3.404942744332997, 
       5.404942744332997}, {-3.4373449933535234`, 5.230251642536255}, {-2.5, 
       5.5}, {-3.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-3.5, 5.357662782649369}, {-2.5, 
       5.5}, {-3.4373449933535234`, 5.230251642536255}, {-3.5, 
       5.357662782649369}}], 
      PolygonBox[{{-3.4373449933535234`, 
       5.230251642536255}, {-3.437499981032941, 5.084292589556062}, {-3.5, 
       5.357662782649369}, {-3.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{-3.5, 5.205909005282899}, {-3.5, 
       5.357662782649369}, {-3.437499981032941, 5.084292589556062}, {-3.5, 
       5.205909005282899}}], 
      PolygonBox[{{-3.437499981032941, 5.084292589556062}, {-3.4375, 
       5.000123178062996}, {-3.5, 5.205909005282899}, {-3.437499981032941, 
       5.084292589556062}}], 
      PolygonBox[{{-3.5, 5.0806786667587005`}, {-3.5, 
       5.205909005282899}, {-3.4375, 5.000123178062996}, {-3.5, 
       5.0806786667587005`}}], 
      PolygonBox[{{-3.4375, 5.000123178062996}, {-3.437499981032941, 
       4.915707410443945}, {-3.5, 5.0806786667587005`}, {-3.4375, 
       5.000123178062996}}], 
      PolygonBox[{{-3.5, 4.794090994854722}, {-3.5, 
       5.0806786667587005`}, {-3.437499981032941, 4.915707410443945}, {-3.5, 
       4.794090994854722}}], 
      PolygonBox[{{-3.437499981032941, 
       4.915707410443945}, {-3.4373449933535234`, 4.769748357463746}, {-3.5, 
       4.794090994854722}, {-3.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-3.5, 4.642337217350635}, {-3.5, 
       4.794090994854722}, {-3.4373449933535234`, 4.769748357463746}, {-3.5, 
       4.642337217350635}}], 
      PolygonBox[{{-3.4373449933535234`, 
       4.769748357463746}, {-3.404942744332997, 4.595057255667003}, {-3.5, 
       4.642337217350635}, {-3.4373449933535234`, 4.769748357463746}}], 
      PolygonBox[{{-3.5, 5.5}, {-3.5, 4.642337217350635}, {-3.404942744332997,
        4.595057255667003}, {-3.5, 5.5}}], 
      PolygonBox[{{-3.404942744332997, 
       4.595057255667003}, {-3.230251642536255, 4.562655006646477}, {-3.5, 
       5.5}, {-3.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-3.5, 4.5}, {-3.5, 5.5}, {-3.230251642536255, 
       4.562655006646477}, {-3.5, 4.5}}], 
      PolygonBox[{{-3.230251642536255, 
       4.562655006646477}, {-3.084292589556064, 4.562500018967059}, {-3.5, 
       4.5}, {-3.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-3.205909005566828, 4.5}, {-3.5, 4.5}, {-3.084292589556064,
        4.562500018967059}, {-3.205909005566828, 4.5}}], 
      PolygonBox[{{-3.084292589556064, 
       4.562500018967059}, {-2.999865158168957, 4.5625}, {-3.205909005566828, 
       4.5}, {-3.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-2.9176761295989384`, 4.5}, {-3.205909005566828, 
       4.5}, {-2.999865158168957, 4.5625}, {-2.9176761295989384`, 4.5}}], 
      PolygonBox[{{-2.999865158168957, 4.5625}, {-2.9157074104439467`, 
       4.562500018967059}, {-2.9176761295989384`, 4.5}, {-2.999865158168957, 
       4.5625}}], 
      PolygonBox[{{-2.7940909946396024`, 4.5}, {-2.9176761295989384`, 
       4.5}, {-2.9157074104439467`, 4.562500018967059}, {-2.7940909946396024`,
        4.5}}], 
      PolygonBox[{{-2.9157074104439467`, 
       4.562500018967059}, {-2.769748357463745, 
       4.562655006646477}, {-2.7940909946396024`, 4.5}, {-2.9157074104439467`,
        4.562500018967059}}], 
      PolygonBox[{{-2.642337217350629, 4.5}, {-2.7940909946396024`, 
       4.5}, {-2.769748357463745, 4.562655006646477}, {-2.642337217350629, 
       4.5}}], PolygonBox[{{-2.769748357463745, 
       4.562655006646477}, {-2.595057255667003, 
       4.595057255667003}, {-2.642337217350629, 4.5}, {-2.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{-2.5, 4.5}, {-2.642337217350629, 4.5}, {-2.595057255667003,
        4.595057255667003}, {-2.5, 4.5}}], 
      PolygonBox[{{-2.595057255667003, 
       4.595057255667003}, {-2.595057255667003, 4.595057255667003}, {-2.5, 
       4.5}, {-2.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{-2.5, 4.5}, {-2.5, 4.5}, {-2.595057255667003, 
       4.595057255667003}, {-2.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, -5.}, {-2.4791666666666665`, -5.}, \
{-2.4583333333333335`, -5.}, {-2.4375, -5.}, {-2.4166666666666665`, -5.}, \
{-2.3958333333333335`, -5.}, {-2.375, -5.}, {-2.375, -5.}, \
{-2.3958333333333335`, -5.}, {-2.4166666666666665`, -5.}, {-2.4375, -5.}, \
{-2.4583333333333335`, -5.}, {-2.4791666666666665`, -5.}, {-2.5, -5.}, {-2.5, \
-5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, -5.}, {-1.6041666666666667`, -5.}, \
{-1.5833333333333333`, -5.}, {-1.5625, -5.}, {-1.5416666666666667`, -5.}, \
{-1.5208333333333335`, -5.}, {-1.5, -5.}, {-1.5, -5.}, {-1.5208333333333333`, \
-5.}, {-1.5416666666666667`, -5.}, {-1.5625, -5.}, {-1.5833333333333333`, \
-5.}, {-1.6041666666666665`, -5.}, {-1.625, -5.}, {-1.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -5.5}, {-2., -5.479166666666667}, {-2., \
-5.458333333333333}, {-2., -5.4375}, {-2., -5.416666666666667}, {-2., \
-5.395833333333333}, {-2., -5.375}, {-2., -5.375}, {-2., -5.395833333333333}, \
{-2., -5.416666666666667}, {-2., -5.4375}, {-2., -5.458333333333333}, {-2., \
-5.479166666666667}, {-2., -5.5}, {-2., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -4.625}, {-2., -4.604166666666667}, {-2., \
-4.583333333333333}, {-2., -4.5625}, {-2., -4.541666666666667}, {-2., \
-4.520833333333333}, {-2., -4.5}, {-2., -4.5}, {-2., -4.520833333333333}, \
{-2., -4.541666666666667}, {-2., -4.5625}, {-2., -4.583333333333333}, {-2., \
-4.604166666666667}, {-2., -4.625}, {-2., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, -5.}, {-2.25, -5.}, {-2.125, -5.}, {-2., -5.}, \
{-1.875, -5.}, {-1.75, -5.}, {-1.625, -5.}, {-1.625, -5.}, {-1.75, -5.}, \
{-1.875, -5.}, {-2., -5.}, {-2.125, -5.}, {-2.25, -5.}, {-2.375, -5.}, \
{-2.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -5.375}, {-2., -5.25}, {-2., -5.125}, {-2., -5.}, {-2., \
-4.875}, {-2., -4.75}, {-2., -4.625}, {-2., -4.625}, {-2., -4.75}, {-2., \
-4.875}, {-2., -5.}, {-2., -5.125}, {-2., -5.25}, {-2., -5.375}, {-2., \
-5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kNokQM6MYuawkx+7b/ZW8Y7d47wgQWF+V9O
nIXKOwgfOKVywufRwd/7jTiNJld8EDoA0fd3f8YdaduizUIHksxvmZYU/dvP
PX3FAtFemDwDhG4QOuD/ROjp0WMMB1DkGxgPwPTPfjv7Jp880wGY+QbuJ1ql
ZzIdgNn/6uK6fVeeMh24AXUfxHjmAzD3w+TVizo/JSWLoOo/IHJgDtT8s9/O
5rTzi8Ltn6H85FCvjyjcfV8zwuNfFYmiuV/0QDLUfzB5Rqj/Yfph4XMOaj5K
+B1AhK8G1H3o4Q8AMt2eJw==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNooQOrwOAXnB8KBn/hfKiGA6jyjAdQ9TMd
QFXPQpC/GqwPwYeYK4ymXgRNvQiaelE09WIY/NUo7hNDcz9MPQOcH4bif5j+
X/tR1f8gyEd134/9qO6HqRdBUy+Mpl4ITb3QAQCYwGqQ
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, -5.265165042944956}, \
{-1.6752404735808355`, -5.1875}, {-1.5950572556670028`, -5.404942744332997}, \
{-1.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{-1.5626550066464766`, -5.230251642536255}, \
{-1.5950572556670028`, -5.404942744332997}, {-1.6752404735808355`, -5.1875}, \
{-1.5626550066464766`, -5.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, -5.1875}, {-1.6377778151415994`, \
-5.097057141913445}, {-1.5626550066464766`, -5.230251642536255}, \
{-1.6752404735808355`, -5.1875}}], 
      PolygonBox[{{-1.5625000189670593`, -5.084292589556062}, \
{-1.5626550066464766`, -5.230251642536255}, {-1.6377778151415994`, \
-5.097057141913445}, {-1.5625000189670593`, -5.084292589556062}}], 
      PolygonBox[{{-1.6377778151415994`, -5.097057141913445}, {-1.625, -5.}, \
{-1.5625000189670593`, -5.084292589556062}, {-1.6377778151415994`, \
-5.097057141913445}}], 
      PolygonBox[{{-1.5625, -5.}, {-1.5625000189670593`, -5.084292589556062}, \
{-1.625, -5.}, {-1.5625, -5.}}], 
      PolygonBox[{{-1.625, -5.}, {-1.6377778151415994`, -4.902942858086555}, \
{-1.5625, -5.}, {-1.625, -5.}}], 
      PolygonBox[{{-1.5625000189670593`, -4.915707410443939}, {-1.5625, -5.}, \
{-1.6377778151415994`, -4.902942858086555}, {-1.5625000189670593`, \
-4.915707410443939}}], 
      PolygonBox[{{-1.6377778151415994`, -4.902942858086555}, \
{-1.6752404735808355`, -4.8125}, {-1.5625000189670593`, -4.915707410443939}, \
{-1.6377778151415994`, -4.902942858086555}}], 
      PolygonBox[{{-1.5626550066464766`, -4.769748357463745}, \
{-1.5625000189670593`, -4.915707410443939}, {-1.6752404735808355`, -4.8125}, \
{-1.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{-1.6752404735808355`, -4.8125}, {-1.7348349570550448`, \
-4.734834957055044}, {-1.5626550066464766`, -4.769748357463745}, \
{-1.6752404735808355`, -4.8125}}], 
      PolygonBox[{{-1.5950572556670028`, -4.595057255667003}, \
{-1.5626550066464766`, -4.769748357463745}, {-1.7348349570550448`, \
-4.734834957055044}, {-1.5950572556670028`, -4.595057255667003}}], 
      PolygonBox[{{-1.7348349570550448`, -4.734834957055044}, {-1.8125, \
-4.6752404735808355`}, {-1.5950572556670028`, -4.595057255667003}, \
{-1.7348349570550448`, -4.734834957055044}}], 
      PolygonBox[{{-1.769748357463745, -4.562655006646477}, \
{-1.5950572556670028`, -4.595057255667003}, {-1.8125, -4.6752404735808355`}, \
{-1.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{-1.8125, -4.6752404735808355`}, {-1.9029428580865546`, \
-4.637777815141599}, {-1.769748357463745, -4.562655006646477}, {-1.8125, \
-4.6752404735808355`}}], 
      PolygonBox[{{-1.9157074104439396`, -4.562500018967059}, \
{-1.769748357463745, -4.562655006646477}, {-1.9029428580865546`, \
-4.637777815141599}, {-1.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-1.9029428580865546`, -4.637777815141599}, {-2., -4.625}, \
{-1.9157074104439396`, -4.562500018967059}, {-1.9029428580865546`, \
-4.637777815141599}}], 
      PolygonBox[{{-1.9998944727795123`, -4.5625}, {-1.9157074104439396`, \
-4.562500018967059}, {-2., -4.625}, {-1.9998944727795123`, -4.5625}}], 
      PolygonBox[{{-2., -4.625}, {-2.097057141913445, -4.637777815141599}, \
{-1.9998944727795123`, -4.5625}, {-2., -4.625}}], 
      PolygonBox[{{-2.084292589556057, -4.562500018967059}, \
{-1.9998944727795123`, -4.5625}, {-2.097057141913445, -4.637777815141599}, \
{-2.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-2.097057141913445, -4.637777815141599}, {-2.1875, \
-4.6752404735808355`}, {-2.084292589556057, -4.562500018967059}, \
{-2.097057141913445, -4.637777815141599}}], 
      PolygonBox[{{-2.230251642536255, -4.562655006646477}, \
{-2.084292589556057, -4.562500018967059}, {-2.1875, -4.6752404735808355`}, \
{-2.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-2.1875, -4.6752404735808355`}, {-2.2651650429449552`, \
-4.734834957055044}, {-2.230251642536255, -4.562655006646477}, {-2.1875, \
-4.6752404735808355`}}], 
      PolygonBox[{{-2.404942744332997, -4.595057255667003}, \
{-2.230251642536255, -4.562655006646477}, {-2.2651650429449552`, \
-4.734834957055044}, {-2.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{-2.2651650429449552`, -4.734834957055044}, \
{-2.3247595264191645`, -4.8125}, {-2.404942744332997, -4.595057255667003}, \
{-2.2651650429449552`, -4.734834957055044}}], 
      PolygonBox[{{-2.4373449933535234`, -4.769748357463745}, \
{-2.404942744332997, -4.595057255667003}, {-2.3247595264191645`, -4.8125}, \
{-2.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{-2.3247595264191645`, -4.8125}, {-2.3622221848584006`, \
-4.902942858086554}, {-2.4373449933535234`, -4.769748357463745}, \
{-2.3247595264191645`, -4.8125}}], 
      PolygonBox[{{-2.437499981032941, -4.915707410443938}, \
{-2.4373449933535234`, -4.769748357463745}, {-2.3622221848584006`, \
-4.902942858086554}, {-2.437499981032941, -4.915707410443938}}], 
      PolygonBox[{{-2.3622221848584006`, -4.902942858086554}, {-2.375, -5.}, \
{-2.437499981032941, -4.915707410443938}, {-2.3622221848584006`, \
-4.902942858086554}}], 
      PolygonBox[{{-2.4375, -4.999876821937004}, {-2.437499981032941, \
-4.915707410443938}, {-2.375, -5.}, {-2.4375, -4.999876821937004}}], 
      PolygonBox[{{-2.375, -5.}, {-2.3622221848584006`, -5.097057141913445}, \
{-2.4375, -4.999876821937004}, {-2.375, -5.}}], 
      PolygonBox[{{-2.437499981032941, -5.084292589556055}, {-2.4375, \
-4.999876821937004}, {-2.3622221848584006`, -5.097057141913445}, \
{-2.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-2.3622221848584006`, -5.097057141913445}, \
{-2.3247595264191645`, -5.1875}, {-2.437499981032941, -5.084292589556055}, \
{-2.3622221848584006`, -5.097057141913445}}], 
      PolygonBox[{{-2.4373449933535234`, -5.230251642536254}, \
{-2.437499981032941, -5.084292589556055}, {-2.3247595264191645`, -5.1875}, \
{-2.4373449933535234`, -5.230251642536254}}], 
      PolygonBox[{{-2.3247595264191645`, -5.1875}, {-2.2651650429449552`, \
-5.265165042944956}, {-2.4373449933535234`, -5.230251642536254}, \
{-2.3247595264191645`, -5.1875}}], 
      PolygonBox[{{-2.404942744332997, -5.404942744332997}, \
{-2.4373449933535234`, -5.230251642536254}, {-2.2651650429449552`, \
-5.265165042944956}, {-2.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, -5.265165042944956}, {-2.1875, \
-5.3247595264191645`}, {-2.404942744332997, -5.404942744332997}, \
{-2.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{-2.230251642536255, -5.437344993353523}, \
{-2.404942744332997, -5.404942744332997}, {-2.1875, -5.3247595264191645`}, \
{-2.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{-2.1875, -5.3247595264191645`}, {-2.0970571419134454`, \
-5.362222184858401}, {-2.230251642536255, -5.437344993353523}, {-2.1875, \
-5.3247595264191645`}}], 
      PolygonBox[{{-2.084292589556064, -5.437499981032941}, \
{-2.230251642536255, -5.437344993353523}, {-2.0970571419134454`, \
-5.362222184858401}, {-2.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-2.0970571419134454`, -5.362222184858401}, {-2., -5.375}, \
{-2.084292589556064, -5.437499981032941}, {-2.0970571419134454`, \
-5.362222184858401}}], 
      PolygonBox[{{-1.999865158168957, -5.4375}, {-2.084292589556064, \
-5.437499981032941}, {-2., -5.375}, {-1.999865158168957, -5.4375}}], 
      PolygonBox[{{-2., -5.375}, {-1.9029428580865548`, -5.362222184858401}, \
{-1.999865158168957, -5.4375}, {-2., -5.375}}], 
      PolygonBox[{{-1.9157074104439469`, -5.437499981032941}, \
{-1.999865158168957, -5.4375}, {-1.9029428580865548`, -5.362222184858401}, \
{-1.9157074104439469`, -5.437499981032941}}], 
      PolygonBox[{{-1.9029428580865548`, -5.362222184858401}, \
{-1.8125000000000002`, -5.3247595264191645`}, {-1.9157074104439469`, \
-5.437499981032941}, {-1.9029428580865548`, -5.362222184858401}}], 
      PolygonBox[{{-1.7697483574637454`, -5.437344993353523}, \
{-1.9157074104439469`, -5.437499981032941}, {-1.8125000000000002`, \
-5.3247595264191645`}, {-1.7697483574637454`, -5.437344993353523}}], 
      PolygonBox[{{-1.8125000000000002`, -5.3247595264191645`}, \
{-1.7348349570550448`, -5.265165042944956}, {-1.7697483574637454`, \
-5.437344993353523}, {-1.8125000000000002`, -5.3247595264191645`}}], 
      PolygonBox[{{-1.5950572556670028`, -5.404942744332997}, \
{-1.7697483574637454`, -5.437344993353523}, {-1.7348349570550448`, \
-5.265165042944956}, {-1.5950572556670028`, -5.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, -5.265165042944956}, \
{-1.7348349570550448`, -5.265165042944956}, {-1.5950572556670028`, \
-5.404942744332997}, {-1.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{-1.5950572556670028`, -5.404942744332997}, \
{-1.5950572556670028`, -5.404942744332997}, {-1.7348349570550448`, \
-5.265165042944956}, {-1.5950572556670028`, -5.404942744332997}}], 
      PolygonBox[{{-1.5950572556670028`, -5.404942744332997}, \
{-1.5626550066464766`, -5.230251642536255}, {-1.5, -5.5}, \
{-1.5950572556670028`, -5.404942744332997}}], 
      PolygonBox[{{-1.5, -5.357662782649368}, {-1.5, -5.5}, \
{-1.5626550066464766`, -5.230251642536255}, {-1.5, -5.357662782649368}}], 
      PolygonBox[{{-1.5626550066464766`, -5.230251642536255}, \
{-1.5625000189670593`, -5.084292589556062}, {-1.5, -5.357662782649368}, \
{-1.5626550066464766`, -5.230251642536255}}], 
      PolygonBox[{{-1.5, -5.20590900530174}, {-1.5, -5.357662782649368}, \
{-1.5625000189670593`, -5.084292589556062}, {-1.5, -5.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, -5.084292589556062}, {-1.5625, -5.}, \
{-1.5, -5.20590900530174}, {-1.5625000189670593`, -5.084292589556062}}], 
      PolygonBox[{{-1.5, -5.}, {-1.5, -5.20590900530174}, {-1.5625, -5.}, \
{-1.5, -5.}}], 
      PolygonBox[{{-1.5625, -5.}, {-1.5625000189670593`, -4.915707410443939}, \
{-1.5, -5.}, {-1.5625, -5.}}], 
      PolygonBox[{{-1.5, -4.79409099469826}, {-1.5, -5.}, \
{-1.5625000189670593`, -4.915707410443939}, {-1.5, -4.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, -4.915707410443939}, \
{-1.5626550066464766`, -4.769748357463745}, {-1.5, -4.79409099469826}, \
{-1.5625000189670593`, -4.915707410443939}}], 
      PolygonBox[{{-1.5, -4.642337217350632}, {-1.5, -4.79409099469826}, \
{-1.5626550066464766`, -4.769748357463745}, {-1.5, -4.642337217350632}}], 
      PolygonBox[{{-1.5626550066464766`, -4.769748357463745}, \
{-1.5950572556670028`, -4.595057255667003}, {-1.5, -4.642337217350632}, \
{-1.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{-1.508553435038814, -4.508553435038814}, {-1.5, \
-4.642337217350632}, {-1.5950572556670028`, -4.595057255667003}, \
{-1.508553435038814, -4.508553435038814}}], 
      PolygonBox[{{-1.5950572556670028`, -4.595057255667003}, \
{-1.769748357463745, -4.562655006646477}, {-1.508553435038814, \
-4.508553435038814}, {-1.5950572556670028`, -4.595057255667003}}], 
      PolygonBox[{{-1.6423372173506319`, -4.5}, {-1.508553435038814, \
-4.508553435038814}, {-1.769748357463745, -4.562655006646477}, \
{-1.6423372173506319`, -4.5}}], 
      PolygonBox[{{-1.769748357463745, -4.562655006646477}, \
{-1.9157074104439396`, -4.562500018967059}, {-1.6423372173506319`, -4.5}, \
{-1.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{-1.7940909946267443`, -4.5}, {-1.6423372173506319`, -4.5}, \
{-1.9157074104439396`, -4.562500018967059}, {-1.7940909946267443`, -4.5}}], 
      PolygonBox[{{-1.9157074104439396`, -4.562500018967059}, \
{-1.9998944727795123`, -4.5625}, {-1.7940909946267443`, -4.5}, \
{-1.9157074104439396`, -4.562500018967059}}], 
      PolygonBox[{{-1.92205804197311, -4.5}, {-1.7940909946267443`, -4.5}, \
{-1.9998944727795123`, -4.5625}, {-1.92205804197311, -4.5}}], 
      PolygonBox[{{-1.9998944727795123`, -4.5625}, {-2.084292589556057, \
-4.562500018967059}, {-1.92205804197311, -4.5}, {-1.9998944727795123`, \
-4.5625}}], 
      PolygonBox[{{-2.2059090053044454`, -4.5}, {-1.92205804197311, -4.5}, \
{-2.084292589556057, -4.562500018967059}, {-2.2059090053044454`, -4.5}}], 
      PolygonBox[{{-2.084292589556057, -4.562500018967059}, \
{-2.230251642536255, -4.562655006646477}, {-2.2059090053044454`, -4.5}, \
{-2.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-2.357662782649366, -4.5}, {-2.2059090053044454`, -4.5}, \
{-2.230251642536255, -4.562655006646477}, {-2.357662782649366, -4.5}}], 
      PolygonBox[{{-2.230251642536255, -4.562655006646477}, \
{-2.404942744332997, -4.595057255667003}, {-2.357662782649366, -4.5}, \
{-2.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-1.5, -4.5}, {-2.357662782649366, -4.5}, \
{-2.404942744332997, -4.595057255667003}, {-1.5, -4.5}}], 
      PolygonBox[{{-2.404942744332997, -4.595057255667003}, \
{-2.4373449933535234`, -4.769748357463745}, {-1.5, -4.5}, \
{-2.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{-2.5, -4.642337217350631}, {-1.5, -4.5}, \
{-2.4373449933535234`, -4.769748357463745}, {-2.5, -4.642337217350631}}], 
      PolygonBox[{{-2.4373449933535234`, -4.769748357463745}, \
{-2.437499981032941, -4.915707410443938}, {-2.5, -4.642337217350631}, \
{-2.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{-2.5, -4.794090994717101}, {-2.5, -4.642337217350631}, \
{-2.437499981032941, -4.915707410443938}, {-2.5, -4.794090994717101}}], 
      PolygonBox[{{-2.437499981032941, -4.915707410443938}, {-2.4375, \
-4.999876821937004}, {-2.5, -4.794090994717101}, {-2.437499981032941, \
-4.915707410443938}}], 
      PolygonBox[{{-2.5, -4.9193213332412995`}, {-2.5, -4.794090994717101}, \
{-2.4375, -4.999876821937004}, {-2.5, -4.9193213332412995`}}], 
      PolygonBox[{{-2.4375, -4.999876821937004}, {-2.437499981032941, \
-5.084292589556055}, {-2.5, -4.9193213332412995`}, {-2.4375, \
-4.999876821937004}}], 
      PolygonBox[{{-2.5, -5.205909005145278}, {-2.5, -4.9193213332412995`}, \
{-2.437499981032941, -5.084292589556055}, {-2.5, -5.205909005145278}}], 
      PolygonBox[{{-2.437499981032941, -5.084292589556055}, \
{-2.4373449933535234`, -5.230251642536254}, {-2.5, -5.205909005145278}, \
{-2.437499981032941, -5.084292589556055}}], 
      PolygonBox[{{-2.5, -5.357662782649365}, {-2.5, -5.205909005145278}, \
{-2.4373449933535234`, -5.230251642536254}, {-2.5, -5.357662782649365}}], 
      PolygonBox[{{-2.4373449933535234`, -5.230251642536254}, \
{-2.404942744332997, -5.404942744332997}, {-2.5, -5.357662782649365}, \
{-2.4373449933535234`, -5.230251642536254}}], 
      PolygonBox[{{-2.5, -4.5}, {-2.5, -5.357662782649365}, \
{-2.404942744332997, -5.404942744332997}, {-2.5, -4.5}}], 
      PolygonBox[{{-2.404942744332997, -5.404942744332997}, \
{-2.230251642536255, -5.437344993353523}, {-2.5, -4.5}, {-2.404942744332997, \
-5.404942744332997}}], 
      PolygonBox[{{-2.5, -5.5}, {-2.5, -4.5}, {-2.230251642536255, \
-5.437344993353523}, {-2.5, -5.5}}], 
      PolygonBox[{{-2.230251642536255, -5.437344993353523}, \
{-2.084292589556064, -5.437499981032941}, {-2.5, -5.5}, {-2.230251642536255, \
-5.437344993353523}}], 
      PolygonBox[{{-2.205909005566828, -5.5}, {-2.5, -5.5}, \
{-2.084292589556064, -5.437499981032941}, {-2.205909005566828, -5.5}}], 
      PolygonBox[{{-2.084292589556064, -5.437499981032941}, \
{-1.999865158168957, -5.4375}, {-2.205909005566828, -5.5}, \
{-2.084292589556064, -5.437499981032941}}], 
      PolygonBox[{{-1.9176761295989384`, -5.5}, {-2.205909005566828, -5.5}, \
{-1.999865158168957, -5.4375}, {-1.9176761295989384`, -5.5}}], 
      PolygonBox[{{-1.999865158168957, -5.4375}, {-1.9157074104439469`, \
-5.437499981032941}, {-1.9176761295989384`, -5.5}, {-1.999865158168957, \
-5.4375}}], 
      PolygonBox[{{-1.7940909946396026`, -5.5}, {-1.9176761295989384`, -5.5}, \
{-1.9157074104439469`, -5.437499981032941}, {-1.7940909946396026`, -5.5}}], 
      PolygonBox[{{-1.9157074104439469`, -5.437499981032941}, \
{-1.7697483574637454`, -5.437344993353523}, {-1.7940909946396026`, -5.5}, \
{-1.9157074104439469`, -5.437499981032941}}], 
      PolygonBox[{{-1.642337217350629, -5.5}, {-1.7940909946396026`, -5.5}, \
{-1.7697483574637454`, -5.437344993353523}, {-1.642337217350629, -5.5}}], 
      PolygonBox[{{-1.7697483574637454`, -5.437344993353523}, \
{-1.5950572556670028`, -5.404942744332997}, {-1.642337217350629, -5.5}, \
{-1.7697483574637454`, -5.437344993353523}}], 
      PolygonBox[{{-1.5, -5.5}, {-1.642337217350629, -5.5}, \
{-1.5950572556670028`, -5.404942744332997}, {-1.5, -5.5}}], 
      PolygonBox[{{-1.5950572556670028`, -5.404942744332997}, \
{-1.5950572556670028`, -5.404942744332997}, {-1.5, -5.5}, \
{-1.5950572556670028`, -5.404942744332997}}], 
      PolygonBox[{{-1.5, -5.5}, {-1.5, -5.5}, {-1.5950572556670028`, \
-5.404942744332997}, {-1.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, -4.}, {-2.4791666666666665`, -4.}, \
{-2.4583333333333335`, -4.}, {-2.4375, -4.}, {-2.4166666666666665`, -4.}, \
{-2.3958333333333335`, -4.}, {-2.375, -4.}, {-2.375, -4.}, \
{-2.3958333333333335`, -4.}, {-2.4166666666666665`, -4.}, {-2.4375, -4.}, \
{-2.4583333333333335`, -4.}, {-2.4791666666666665`, -4.}, {-2.5, -4.}, {-2.5, \
-4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, -4.}, {-1.6041666666666667`, -4.}, \
{-1.5833333333333333`, -4.}, {-1.5625, -4.}, {-1.5416666666666667`, -4.}, \
{-1.5208333333333335`, -4.}, {-1.5, -4.}, {-1.5, -4.}, {-1.5208333333333333`, \
-4.}, {-1.5416666666666667`, -4.}, {-1.5625, -4.}, {-1.5833333333333333`, \
-4.}, {-1.6041666666666665`, -4.}, {-1.625, -4.}, {-1.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -4.5}, {-2., -4.479166666666667}, {-2., \
-4.458333333333333}, {-2., -4.4375}, {-2., -4.416666666666667}, {-2., \
-4.395833333333333}, {-2., -4.375}, {-2., -4.375}, {-2., -4.395833333333333}, \
{-2., -4.416666666666667}, {-2., -4.4375}, {-2., -4.458333333333333}, {-2., \
-4.479166666666667}, {-2., -4.5}, {-2., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -3.625}, {-2., -3.6041666666666665`}, {-2., \
-3.5833333333333335`}, {-2., -3.5625}, {-2., -3.5416666666666665`}, {-2., \
-3.5208333333333335`}, {-2., -3.5}, {-2., -3.5}, {-2., -3.5208333333333335`}, \
{-2., -3.5416666666666665`}, {-2., -3.5625}, {-2., -3.5833333333333335`}, \
{-2., -3.6041666666666665`}, {-2., -3.625}, {-2., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, -4.}, {-2.25, -4.}, {-2.125, -4.}, {-2., -4.}, \
{-1.875, -4.}, {-1.75, -4.}, {-1.625, -4.}, {-1.625, -4.}, {-1.75, -4.}, \
{-1.875, -4.}, {-2., -4.}, {-2.125, -4.}, {-2.25, -4.}, {-2.375, -4.}, \
{-2.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -4.375}, {-2., -4.25}, {-2., -4.125}, {-2., -4.}, {-2., \
-3.875}, {-2., -3.75}, {-2., -3.625}, {-2., -3.625}, {-2., -3.75}, {-2., \
-3.875}, {-2., -4.}, {-2., -4.125}, {-2., -4.25}, {-2., -4.375}, {-2., \
-4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kNogQM6MYuawkx+7d8o/VbKypL/wILC/C8n
zkLlG/gOnFI54fPo4O/9qUIpah8f8B6A6Pu7/8IO86onabwHksxvmZYU/dsv
phfoqC0Fk2eA0rwH/J8IPT16jOEAinwD4wGY/tlvZ9/kk2c6ADPfwP1Eq/RM
pgMw+19dXLfvylOmAzD3QcxlPgBzP0xevajzU1KyAKr+AwIH5kDNP/vtbE47
vyDc/hnKTw71+gjC3fc1Izz+VZEgqvsbBA8kQ/0Hk2eE+h+mHxY+56Dmo4Tf
AUT4akDdhx7+AEuMm3k=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNongOrwOAXnB8KBn/hfKiGA6jyjAdQ9TMd
QFXPQpAPMYcXzl8NNocPTb0AmrwAmn5BNPVCGPzVKO4TQnM/TD0DnB+G4n+Y
/l/7UdX/IMhHdd+P/ajuh6kXQJPng/PDUMIHEV8AH0xqCw==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, -4.265165042944956}, \
{-1.6752404735808355`, -4.1875}, {-1.5950572556670028`, -4.404942744332997}, \
{-1.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{-1.5626550066464766`, -4.230251642536255}, \
{-1.5950572556670028`, -4.404942744332997}, {-1.6752404735808355`, -4.1875}, \
{-1.5626550066464766`, -4.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, -4.1875}, {-1.6377778151415994`, \
-4.097057141913445}, {-1.5626550066464766`, -4.230251642536255}, \
{-1.6752404735808355`, -4.1875}}], 
      PolygonBox[{{-1.5625000189670593`, -4.084292589556062}, \
{-1.5626550066464766`, -4.230251642536255}, {-1.6377778151415994`, \
-4.097057141913445}, {-1.5625000189670593`, -4.084292589556062}}], 
      PolygonBox[{{-1.6377778151415994`, -4.097057141913445}, {-1.625, -4.}, \
{-1.5625000189670593`, -4.084292589556062}, {-1.6377778151415994`, \
-4.097057141913445}}], 
      PolygonBox[{{-1.5625, -4.}, {-1.5625000189670593`, -4.084292589556062}, \
{-1.625, -4.}, {-1.5625, -4.}}], 
      PolygonBox[{{-1.625, -4.}, {-1.6377778151415994`, \
-3.9029428580865546`}, {-1.5625, -4.}, {-1.625, -4.}}], 
      PolygonBox[{{-1.5625000189670593`, -3.915707410443938}, {-1.5625, -4.}, \
{-1.6377778151415994`, -3.9029428580865546`}, {-1.5625000189670593`, \
-3.915707410443938}}], 
      PolygonBox[{{-1.6377778151415994`, -3.9029428580865546`}, \
{-1.6752404735808355`, -3.8125}, {-1.5625000189670593`, -3.915707410443938}, \
{-1.6377778151415994`, -3.9029428580865546`}}], 
      PolygonBox[{{-1.5626550066464766`, -3.769748357463745}, \
{-1.5625000189670593`, -3.915707410443938}, {-1.6752404735808355`, -3.8125}, \
{-1.5626550066464766`, -3.769748357463745}}], 
      PolygonBox[{{-1.6752404735808355`, -3.8125}, {-1.7348349570550448`, \
-3.7348349570550448`}, {-1.5626550066464766`, -3.769748357463745}, \
{-1.6752404735808355`, -3.8125}}], 
      PolygonBox[{{-1.5950572556670028`, -3.595057255667003}, \
{-1.5626550066464766`, -3.769748357463745}, {-1.7348349570550448`, \
-3.7348349570550448`}, {-1.5950572556670028`, -3.595057255667003}}], 
      PolygonBox[{{-1.7348349570550448`, -3.7348349570550448`}, {-1.8125, \
-3.6752404735808355`}, {-1.5950572556670028`, -3.595057255667003}, \
{-1.7348349570550448`, -3.7348349570550448`}}], 
      PolygonBox[{{-1.769748357463745, -3.5626550066464766`}, \
{-1.5950572556670028`, -3.595057255667003}, {-1.8125, -3.6752404735808355`}, \
{-1.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{-1.8125, -3.6752404735808355`}, {-1.9029428580865546`, \
-3.6377778151415994`}, {-1.769748357463745, -3.5626550066464766`}, {-1.8125, \
-3.6752404735808355`}}], 
      PolygonBox[{{-1.9157074104439396`, -3.562500018967059}, \
{-1.769748357463745, -3.5626550066464766`}, {-1.9029428580865546`, \
-3.6377778151415994`}, {-1.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-1.9029428580865546`, -3.6377778151415994`}, {-2., \
-3.625}, {-1.9157074104439396`, -3.562500018967059}, {-1.9029428580865546`, \
-3.6377778151415994`}}], 
      PolygonBox[{{-1.9998944727795123`, -3.5625}, {-1.9157074104439396`, \
-3.562500018967059}, {-2., -3.625}, {-1.9998944727795123`, -3.5625}}], 
      PolygonBox[{{-2., -3.625}, {-2.097057141913445, -3.6377778151415994`}, \
{-1.9998944727795123`, -3.5625}, {-2., -3.625}}], 
      PolygonBox[{{-2.084292589556057, -3.562500018967059}, \
{-1.9998944727795123`, -3.5625}, {-2.097057141913445, -3.6377778151415994`}, \
{-2.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-2.097057141913445, -3.6377778151415994`}, {-2.1875, \
-3.6752404735808355`}, {-2.084292589556057, -3.562500018967059}, \
{-2.097057141913445, -3.6377778151415994`}}], 
      PolygonBox[{{-2.230251642536255, -3.5626550066464766`}, \
{-2.084292589556057, -3.562500018967059}, {-2.1875, -3.6752404735808355`}, \
{-2.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-2.1875, -3.6752404735808355`}, {-2.2651650429449552`, \
-3.7348349570550448`}, {-2.230251642536255, -3.5626550066464766`}, {-2.1875, \
-3.6752404735808355`}}], 
      PolygonBox[{{-2.404942744332997, -3.595057255667003}, \
{-2.230251642536255, -3.5626550066464766`}, {-2.2651650429449552`, \
-3.7348349570550448`}, {-2.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-2.2651650429449552`, -3.7348349570550448`}, \
{-2.3247595264191645`, -3.8125}, {-2.404942744332997, -3.595057255667003}, \
{-2.2651650429449552`, -3.7348349570550448`}}], 
      PolygonBox[{{-2.4373449933535234`, -3.7697483574637447`}, \
{-2.404942744332997, -3.595057255667003}, {-2.3247595264191645`, -3.8125}, \
{-2.4373449933535234`, -3.7697483574637447`}}], 
      PolygonBox[{{-2.3247595264191645`, -3.8125}, {-2.3622221848584006`, \
-3.9029428580865546`}, {-2.4373449933535234`, -3.7697483574637447`}, \
{-2.3247595264191645`, -3.8125}}], 
      PolygonBox[{{-2.437499981032941, -3.9157074104439378`}, \
{-2.4373449933535234`, -3.7697483574637447`}, {-2.3622221848584006`, \
-3.9029428580865546`}, {-2.437499981032941, -3.9157074104439378`}}], 
      PolygonBox[{{-2.3622221848584006`, -3.9029428580865546`}, {-2.375, \
-4.}, {-2.437499981032941, -3.9157074104439378`}, {-2.3622221848584006`, \
-3.9029428580865546`}}], 
      PolygonBox[{{-2.4375, -3.9998768219370047`}, {-2.437499981032941, \
-3.9157074104439378`}, {-2.375, -4.}, {-2.4375, -3.9998768219370047`}}], 
      PolygonBox[{{-2.375, -4.}, {-2.3622221848584006`, -4.097057141913445}, \
{-2.4375, -3.9998768219370047`}, {-2.375, -4.}}], 
      PolygonBox[{{-2.437499981032941, -4.084292589556055}, {-2.4375, \
-3.9998768219370047`}, {-2.3622221848584006`, -4.097057141913445}, \
{-2.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-2.3622221848584006`, -4.097057141913445}, \
{-2.3247595264191645`, -4.1875}, {-2.437499981032941, -4.084292589556055}, \
{-2.3622221848584006`, -4.097057141913445}}], 
      PolygonBox[{{-2.4373449933535234`, -4.230251642536254}, \
{-2.437499981032941, -4.084292589556055}, {-2.3247595264191645`, -4.1875}, \
{-2.4373449933535234`, -4.230251642536254}}], 
      PolygonBox[{{-2.3247595264191645`, -4.1875}, {-2.2651650429449552`, \
-4.265165042944956}, {-2.4373449933535234`, -4.230251642536254}, \
{-2.3247595264191645`, -4.1875}}], 
      PolygonBox[{{-2.404942744332997, -4.404942744332997}, \
{-2.4373449933535234`, -4.230251642536254}, {-2.2651650429449552`, \
-4.265165042944956}, {-2.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, -4.265165042944956}, {-2.1875, \
-4.3247595264191645`}, {-2.404942744332997, -4.404942744332997}, \
{-2.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{-2.230251642536255, -4.437344993353523}, \
{-2.404942744332997, -4.404942744332997}, {-2.1875, -4.3247595264191645`}, \
{-2.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{-2.1875, -4.3247595264191645`}, {-2.0970571419134454`, \
-4.362222184858401}, {-2.230251642536255, -4.437344993353523}, {-2.1875, \
-4.3247595264191645`}}], 
      PolygonBox[{{-2.084292589556064, -4.437499981032941}, \
{-2.230251642536255, -4.437344993353523}, {-2.0970571419134454`, \
-4.362222184858401}, {-2.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-2.0970571419134454`, -4.362222184858401}, {-2., -4.375}, \
{-2.084292589556064, -4.437499981032941}, {-2.0970571419134454`, \
-4.362222184858401}}], 
      PolygonBox[{{-1.999865158168957, -4.4375}, {-2.084292589556064, \
-4.437499981032941}, {-2., -4.375}, {-1.999865158168957, -4.4375}}], 
      PolygonBox[{{-2., -4.375}, {-1.9029428580865548`, -4.362222184858401}, \
{-1.999865158168957, -4.4375}, {-2., -4.375}}], 
      PolygonBox[{{-1.9157074104439469`, -4.437499981032941}, \
{-1.999865158168957, -4.4375}, {-1.9029428580865548`, -4.362222184858401}, \
{-1.9157074104439469`, -4.437499981032941}}], 
      PolygonBox[{{-1.9029428580865548`, -4.362222184858401}, \
{-1.8125000000000002`, -4.3247595264191645`}, {-1.9157074104439469`, \
-4.437499981032941}, {-1.9029428580865548`, -4.362222184858401}}], 
      PolygonBox[{{-1.7697483574637454`, -4.437344993353523}, \
{-1.9157074104439469`, -4.437499981032941}, {-1.8125000000000002`, \
-4.3247595264191645`}, {-1.7697483574637454`, -4.437344993353523}}], 
      PolygonBox[{{-1.8125000000000002`, -4.3247595264191645`}, \
{-1.7348349570550448`, -4.265165042944956}, {-1.7697483574637454`, \
-4.437344993353523}, {-1.8125000000000002`, -4.3247595264191645`}}], 
      PolygonBox[{{-1.5950572556670028`, -4.404942744332997}, \
{-1.7697483574637454`, -4.437344993353523}, {-1.7348349570550448`, \
-4.265165042944956}, {-1.5950572556670028`, -4.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, -4.265165042944956}, \
{-1.7348349570550448`, -4.265165042944956}, {-1.5950572556670028`, \
-4.404942744332997}, {-1.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{-1.5950572556670028`, -4.404942744332997}, \
{-1.5950572556670028`, -4.404942744332997}, {-1.7348349570550448`, \
-4.265165042944956}, {-1.5950572556670028`, -4.404942744332997}}], 
      PolygonBox[{{-1.5950572556670028`, -4.404942744332997}, \
{-1.5626550066464766`, -4.230251642536255}, {-1.5, -4.5}, \
{-1.5950572556670028`, -4.404942744332997}}], 
      PolygonBox[{{-1.5, -4.357662782649368}, {-1.5, -4.5}, \
{-1.5626550066464766`, -4.230251642536255}, {-1.5, -4.357662782649368}}], 
      PolygonBox[{{-1.5626550066464766`, -4.230251642536255}, \
{-1.5625000189670593`, -4.084292589556062}, {-1.5, -4.357662782649368}, \
{-1.5626550066464766`, -4.230251642536255}}], 
      PolygonBox[{{-1.5, -4.20590900530174}, {-1.5, -4.357662782649368}, \
{-1.5625000189670593`, -4.084292589556062}, {-1.5, -4.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, -4.084292589556062}, {-1.5625, -4.}, \
{-1.5, -4.20590900530174}, {-1.5625000189670593`, -4.084292589556062}}], 
      PolygonBox[{{-1.5, -4.}, {-1.5, -4.20590900530174}, {-1.5625, -4.}, \
{-1.5, -4.}}], 
      PolygonBox[{{-1.5625, -4.}, {-1.5625000189670593`, -3.915707410443938}, \
{-1.5, -4.}, {-1.5625, -4.}}], 
      PolygonBox[{{-1.5, -3.79409099469826}, {-1.5, -4.}, \
{-1.5625000189670593`, -3.915707410443938}, {-1.5, -3.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, -3.915707410443938}, \
{-1.5626550066464766`, -3.769748357463745}, {-1.5, -3.79409099469826}, \
{-1.5625000189670593`, -3.915707410443938}}], 
      PolygonBox[{{-1.5, -3.6423372173506325`}, {-1.5, -3.79409099469826}, \
{-1.5626550066464766`, -3.769748357463745}, {-1.5, -3.6423372173506325`}}], 
      PolygonBox[{{-1.5626550066464766`, -3.769748357463745}, \
{-1.5950572556670028`, -3.595057255667003}, {-1.5, -3.6423372173506325`}, \
{-1.5626550066464766`, -3.769748357463745}}], 
      PolygonBox[{{-1.508553435038814, -3.508553435038814}, {-1.5, \
-3.6423372173506325`}, {-1.5950572556670028`, -3.595057255667003}, \
{-1.508553435038814, -3.508553435038814}}], 
      PolygonBox[{{-1.5950572556670028`, -3.595057255667003}, \
{-1.769748357463745, -3.5626550066464766`}, {-1.508553435038814, \
-3.508553435038814}, {-1.5950572556670028`, -3.595057255667003}}], 
      PolygonBox[{{-1.6423372173506319`, -3.5}, {-1.508553435038814, \
-3.508553435038814}, {-1.769748357463745, -3.5626550066464766`}, \
{-1.6423372173506319`, -3.5}}], 
      PolygonBox[{{-1.769748357463745, -3.5626550066464766`}, \
{-1.9157074104439396`, -3.562500018967059}, {-1.6423372173506319`, -3.5}, \
{-1.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{-1.7940909946267443`, -3.5}, {-1.6423372173506319`, -3.5}, \
{-1.9157074104439396`, -3.562500018967059}, {-1.7940909946267443`, -3.5}}], 
      PolygonBox[{{-1.9157074104439396`, -3.562500018967059}, \
{-1.9998944727795123`, -3.5625}, {-1.7940909946267443`, -3.5}, \
{-1.9157074104439396`, -3.562500018967059}}], 
      PolygonBox[{{-1.92205804197311, -3.5}, {-1.7940909946267443`, -3.5}, \
{-1.9998944727795123`, -3.5625}, {-1.92205804197311, -3.5}}], 
      PolygonBox[{{-1.9998944727795123`, -3.5625}, {-2.084292589556057, \
-3.562500018967059}, {-1.92205804197311, -3.5}, {-1.9998944727795123`, \
-3.5625}}], 
      PolygonBox[{{-2.2059090053044454`, -3.5}, {-1.92205804197311, -3.5}, \
{-2.084292589556057, -3.562500018967059}, {-2.2059090053044454`, -3.5}}], 
      PolygonBox[{{-2.084292589556057, -3.562500018967059}, \
{-2.230251642536255, -3.5626550066464766`}, {-2.2059090053044454`, -3.5}, \
{-2.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-2.357662782649366, -3.5}, {-2.2059090053044454`, -3.5}, \
{-2.230251642536255, -3.5626550066464766`}, {-2.357662782649366, -3.5}}], 
      PolygonBox[{{-2.230251642536255, -3.5626550066464766`}, \
{-2.404942744332997, -3.595057255667003}, {-2.357662782649366, -3.5}, \
{-2.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-1.5, -3.5}, {-2.357662782649366, -3.5}, \
{-2.404942744332997, -3.595057255667003}, {-1.5, -3.5}}], 
      PolygonBox[{{-2.404942744332997, -3.595057255667003}, \
{-2.4373449933535234`, -3.7697483574637447`}, {-1.5, -3.5}, \
{-2.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{-2.5, -3.642337217350631}, {-1.5, -3.5}, \
{-2.4373449933535234`, -3.7697483574637447`}, {-2.5, -3.642337217350631}}], 
      PolygonBox[{{-2.4373449933535234`, -3.7697483574637447`}, \
{-2.437499981032941, -3.9157074104439378`}, {-2.5, -3.642337217350631}, \
{-2.4373449933535234`, -3.7697483574637447`}}], 
      PolygonBox[{{-2.5, -3.794090994717101}, {-2.5, -3.642337217350631}, \
{-2.437499981032941, -3.9157074104439378`}, {-2.5, -3.794090994717101}}], 
      PolygonBox[{{-2.437499981032941, -3.9157074104439378`}, {-2.4375, \
-3.9998768219370047`}, {-2.5, -3.794090994717101}, {-2.437499981032941, \
-3.9157074104439378`}}], 
      PolygonBox[{{-2.5, -3.9193213332413}, {-2.5, -3.794090994717101}, \
{-2.4375, -3.9998768219370047`}, {-2.5, -3.9193213332413}}], 
      PolygonBox[{{-2.4375, -3.9998768219370047`}, {-2.437499981032941, \
-4.084292589556055}, {-2.5, -3.9193213332413}, {-2.4375, \
-3.9998768219370047`}}], 
      PolygonBox[{{-2.5, -4.205909005145278}, {-2.5, -3.9193213332413}, \
{-2.437499981032941, -4.084292589556055}, {-2.5, -4.205909005145278}}], 
      PolygonBox[{{-2.437499981032941, -4.084292589556055}, \
{-2.4373449933535234`, -4.230251642536254}, {-2.5, -4.205909005145278}, \
{-2.437499981032941, -4.084292589556055}}], 
      PolygonBox[{{-2.5, -4.357662782649365}, {-2.5, -4.205909005145278}, \
{-2.4373449933535234`, -4.230251642536254}, {-2.5, -4.357662782649365}}], 
      PolygonBox[{{-2.4373449933535234`, -4.230251642536254}, \
{-2.404942744332997, -4.404942744332997}, {-2.5, -4.357662782649365}, \
{-2.4373449933535234`, -4.230251642536254}}], 
      PolygonBox[{{-2.5, -3.5}, {-2.5, -4.357662782649365}, \
{-2.404942744332997, -4.404942744332997}, {-2.5, -3.5}}], 
      PolygonBox[{{-2.404942744332997, -4.404942744332997}, \
{-2.230251642536255, -4.437344993353523}, {-2.5, -3.5}, {-2.404942744332997, \
-4.404942744332997}}], 
      PolygonBox[{{-2.5, -4.5}, {-2.5, -3.5}, {-2.230251642536255, \
-4.437344993353523}, {-2.5, -4.5}}], 
      PolygonBox[{{-2.230251642536255, -4.437344993353523}, \
{-2.084292589556064, -4.437499981032941}, {-2.5, -4.5}, {-2.230251642536255, \
-4.437344993353523}}], 
      PolygonBox[{{-2.205909005566828, -4.5}, {-2.5, -4.5}, \
{-2.084292589556064, -4.437499981032941}, {-2.205909005566828, -4.5}}], 
      PolygonBox[{{-2.084292589556064, -4.437499981032941}, \
{-1.999865158168957, -4.4375}, {-2.205909005566828, -4.5}, \
{-2.084292589556064, -4.437499981032941}}], 
      PolygonBox[{{-1.9176761295989384`, -4.5}, {-2.205909005566828, -4.5}, \
{-1.999865158168957, -4.4375}, {-1.9176761295989384`, -4.5}}], 
      PolygonBox[{{-1.999865158168957, -4.4375}, {-1.9157074104439469`, \
-4.437499981032941}, {-1.9176761295989384`, -4.5}, {-1.999865158168957, \
-4.4375}}], 
      PolygonBox[{{-1.7940909946396026`, -4.5}, {-1.9176761295989384`, -4.5}, \
{-1.9157074104439469`, -4.437499981032941}, {-1.7940909946396026`, -4.5}}], 
      PolygonBox[{{-1.9157074104439469`, -4.437499981032941}, \
{-1.7697483574637454`, -4.437344993353523}, {-1.7940909946396026`, -4.5}, \
{-1.9157074104439469`, -4.437499981032941}}], 
      PolygonBox[{{-1.642337217350629, -4.5}, {-1.7940909946396026`, -4.5}, \
{-1.7697483574637454`, -4.437344993353523}, {-1.642337217350629, -4.5}}], 
      PolygonBox[{{-1.7697483574637454`, -4.437344993353523}, \
{-1.5950572556670028`, -4.404942744332997}, {-1.642337217350629, -4.5}, \
{-1.7697483574637454`, -4.437344993353523}}], 
      PolygonBox[{{-1.5, -4.5}, {-1.642337217350629, -4.5}, \
{-1.5950572556670028`, -4.404942744332997}, {-1.5, -4.5}}], 
      PolygonBox[{{-1.5950572556670028`, -4.404942744332997}, \
{-1.5950572556670028`, -4.404942744332997}, {-1.5, -4.5}, \
{-1.5950572556670028`, -4.404942744332997}}], 
      PolygonBox[{{-1.5, -4.5}, {-1.5, -4.5}, {-1.5950572556670028`, \
-4.404942744332997}, {-1.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, -3.}, {-2.4791666666666665`, -3.}, \
{-2.4583333333333335`, -3.}, {-2.4375, -3.}, {-2.4166666666666665`, -3.}, \
{-2.3958333333333335`, -3.}, {-2.375, -3.}, {-2.375, -3.}, \
{-2.3958333333333335`, -3.}, {-2.4166666666666665`, -3.}, {-2.4375, -3.}, \
{-2.4583333333333335`, -3.}, {-2.4791666666666665`, -3.}, {-2.5, -3.}, {-2.5, \
-3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, -3.}, {-1.6041666666666667`, -3.}, \
{-1.5833333333333333`, -3.}, {-1.5625, -3.}, {-1.5416666666666667`, -3.}, \
{-1.5208333333333335`, -3.}, {-1.5, -3.}, {-1.5, -3.}, {-1.5208333333333333`, \
-3.}, {-1.5416666666666667`, -3.}, {-1.5625, -3.}, {-1.5833333333333333`, \
-3.}, {-1.6041666666666665`, -3.}, {-1.625, -3.}, {-1.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -3.5}, {-2., -3.4791666666666665`}, {-2., \
-3.4583333333333335`}, {-2., -3.4375}, {-2., -3.4166666666666665`}, {-2., \
-3.3958333333333335`}, {-2., -3.375}, {-2., -3.375}, {-2., \
-3.3958333333333335`}, {-2., -3.4166666666666665`}, {-2., -3.4375}, {-2., \
-3.4583333333333335`}, {-2., -3.4791666666666665`}, {-2., -3.5}, {-2., \
-3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -2.625}, {-2., -2.6041666666666665`}, {-2., \
-2.5833333333333335`}, {-2., -2.5625}, {-2., -2.5416666666666665`}, {-2., \
-2.5208333333333335`}, {-2., -2.5}, {-2., -2.5}, {-2., -2.5208333333333335`}, \
{-2., -2.5416666666666665`}, {-2., -2.5625}, {-2., -2.5833333333333335`}, \
{-2., -2.6041666666666665`}, {-2., -2.625}, {-2., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, -3.}, {-2.25, -3.}, {-2.125, -3.}, {-2., -3.}, \
{-1.875, -3.}, {-1.75, -3.}, {-1.625, -3.}, {-1.625, -3.}, {-1.75, -3.}, \
{-1.875, -3.}, {-2., -3.}, {-2.125, -3.}, {-2.25, -3.}, {-2.375, -3.}, \
{-2.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -3.375}, {-2., -3.25}, {-2., -3.125}, {-2., -3.}, {-2., \
-2.875}, {-2., -2.75}, {-2., -2.625}, {-2., -2.625}, {-2., -2.75}, {-2., \
-2.875}, {-2., -3.}, {-2., -3.125}, {-2., -3.25}, {-2., -3.375}, {-2., \
-3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kNojgM6MYuawkx+7d8o/VbKypL9wILC/C8n
zkLlG9gOnFI54fPo4O/9qUIpah8fsB6A6Pu7/8IO86onaawHksxvmZYU/dsv
phfoqC0Fk2eA0qwH/J8IPT16jOEAinwD4wGY/tlvZ9/kk2c6ADPfwP1Eq/RM
pgMw+19dXLfvylOmAzD3QcxlPgBzP0zeD2wPB5p+zgNzoOZD7OGC2w9RxwV3
H8QcLjT3cx9IhvoPJs8I9T9MPyx8YOajhh8nPHz9oe5DD38ANRqb/A==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNolgOrwOAXnB8KBn/hfKiGA6jyjAdQ9TMd
QFVPmIaYwwrnrwabw4amjgNNPSeavVxo6nkw+KtR3MeD5n6YegY4PwzF/zD9
v/ajqv9BkL8axX0/9qO6H6aeA009G5wfhhI+iPgCAG1xaUA=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, -3.2651650429449552`}, \
{-1.6752404735808355`, -3.1875}, {-1.5950572556670028`, -3.404942744332997}, \
{-1.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{-1.5626550066464766`, -3.2302516425362553`}, \
{-1.5950572556670028`, -3.404942744332997}, {-1.6752404735808355`, -3.1875}, \
{-1.5626550066464766`, -3.2302516425362553`}}], 
      PolygonBox[{{-1.6752404735808355`, -3.1875}, {-1.6377778151415994`, \
-3.0970571419134454`}, {-1.5626550066464766`, -3.2302516425362553`}, \
{-1.6752404735808355`, -3.1875}}], 
      PolygonBox[{{-1.5625000189670593`, -3.084292589556062}, \
{-1.5626550066464766`, -3.2302516425362553`}, {-1.6377778151415994`, \
-3.0970571419134454`}, {-1.5625000189670593`, -3.084292589556062}}], 
      PolygonBox[{{-1.6377778151415994`, -3.0970571419134454`}, {-1.625, \
-3.}, {-1.5625000189670593`, -3.084292589556062}, {-1.6377778151415994`, \
-3.0970571419134454`}}], 
      PolygonBox[{{-1.5625, -3.}, {-1.5625000189670593`, -3.084292589556062}, \
{-1.625, -3.}, {-1.5625, -3.}}], 
      PolygonBox[{{-1.625, -3.}, {-1.6377778151415994`, \
-2.9029428580865546`}, {-1.5625, -3.}, {-1.625, -3.}}], 
      PolygonBox[{{-1.5625000189670593`, -2.915707410443938}, {-1.5625, -3.}, \
{-1.6377778151415994`, -2.9029428580865546`}, {-1.5625000189670593`, \
-2.915707410443938}}], 
      PolygonBox[{{-1.6377778151415994`, -2.9029428580865546`}, \
{-1.6752404735808355`, -2.8125}, {-1.5625000189670593`, -2.915707410443938}, \
{-1.6377778151415994`, -2.9029428580865546`}}], 
      PolygonBox[{{-1.5626550066464766`, -2.769748357463745}, \
{-1.5625000189670593`, -2.915707410443938}, {-1.6752404735808355`, -2.8125}, \
{-1.5626550066464766`, -2.769748357463745}}], 
      PolygonBox[{{-1.6752404735808355`, -2.8125}, {-1.7348349570550448`, \
-2.7348349570550448`}, {-1.5626550066464766`, -2.769748357463745}, \
{-1.6752404735808355`, -2.8125}}], 
      PolygonBox[{{-1.5950572556670028`, -2.595057255667003}, \
{-1.5626550066464766`, -2.769748357463745}, {-1.7348349570550448`, \
-2.7348349570550448`}, {-1.5950572556670028`, -2.595057255667003}}], 
      PolygonBox[{{-1.7348349570550448`, -2.7348349570550448`}, {-1.8125, \
-2.6752404735808355`}, {-1.5950572556670028`, -2.595057255667003}, \
{-1.7348349570550448`, -2.7348349570550448`}}], 
      PolygonBox[{{-1.769748357463745, -2.5626550066464766`}, \
{-1.5950572556670028`, -2.595057255667003}, {-1.8125, -2.6752404735808355`}, \
{-1.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{-1.8125, -2.6752404735808355`}, {-1.9029428580865546`, \
-2.6377778151415994`}, {-1.769748357463745, -2.5626550066464766`}, {-1.8125, \
-2.6752404735808355`}}], 
      PolygonBox[{{-1.9157074104439396`, -2.562500018967059}, \
{-1.769748357463745, -2.5626550066464766`}, {-1.9029428580865546`, \
-2.6377778151415994`}, {-1.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-1.9029428580865546`, -2.6377778151415994`}, {-2., \
-2.625}, {-1.9157074104439396`, -2.562500018967059}, {-1.9029428580865546`, \
-2.6377778151415994`}}], 
      PolygonBox[{{-1.9998944727795123`, -2.5625}, {-1.9157074104439396`, \
-2.562500018967059}, {-2., -2.625}, {-1.9998944727795123`, -2.5625}}], 
      PolygonBox[{{-2., -2.625}, {-2.097057141913445, -2.6377778151415994`}, \
{-1.9998944727795123`, -2.5625}, {-2., -2.625}}], 
      PolygonBox[{{-2.084292589556057, -2.562500018967059}, \
{-1.9998944727795123`, -2.5625}, {-2.097057141913445, -2.6377778151415994`}, \
{-2.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-2.097057141913445, -2.6377778151415994`}, {-2.1875, \
-2.6752404735808355`}, {-2.084292589556057, -2.562500018967059}, \
{-2.097057141913445, -2.6377778151415994`}}], 
      PolygonBox[{{-2.230251642536255, -2.5626550066464766`}, \
{-2.084292589556057, -2.562500018967059}, {-2.1875, -2.6752404735808355`}, \
{-2.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-2.1875, -2.6752404735808355`}, {-2.2651650429449552`, \
-2.7348349570550448`}, {-2.230251642536255, -2.5626550066464766`}, {-2.1875, \
-2.6752404735808355`}}], 
      PolygonBox[{{-2.404942744332997, -2.595057255667003}, \
{-2.230251642536255, -2.5626550066464766`}, {-2.2651650429449552`, \
-2.7348349570550448`}, {-2.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-2.2651650429449552`, -2.7348349570550448`}, \
{-2.3247595264191645`, -2.8125}, {-2.404942744332997, -2.595057255667003}, \
{-2.2651650429449552`, -2.7348349570550448`}}], 
      PolygonBox[{{-2.4373449933535234`, -2.7697483574637447`}, \
{-2.404942744332997, -2.595057255667003}, {-2.3247595264191645`, -2.8125}, \
{-2.4373449933535234`, -2.7697483574637447`}}], 
      PolygonBox[{{-2.3247595264191645`, -2.8125}, {-2.3622221848584006`, \
-2.9029428580865546`}, {-2.4373449933535234`, -2.7697483574637447`}, \
{-2.3247595264191645`, -2.8125}}], 
      PolygonBox[{{-2.437499981032941, -2.9157074104439378`}, \
{-2.4373449933535234`, -2.7697483574637447`}, {-2.3622221848584006`, \
-2.9029428580865546`}, {-2.437499981032941, -2.9157074104439378`}}], 
      PolygonBox[{{-2.3622221848584006`, -2.9029428580865546`}, {-2.375, \
-3.}, {-2.437499981032941, -2.9157074104439378`}, {-2.3622221848584006`, \
-2.9029428580865546`}}], 
      PolygonBox[{{-2.4375, -2.9998768219370047`}, {-2.437499981032941, \
-2.9157074104439378`}, {-2.375, -3.}, {-2.4375, -2.9998768219370047`}}], 
      PolygonBox[{{-2.375, -3.}, {-2.3622221848584006`, -3.097057141913445}, \
{-2.4375, -2.9998768219370047`}, {-2.375, -3.}}], 
      PolygonBox[{{-2.437499981032941, -3.084292589556055}, {-2.4375, \
-2.9998768219370047`}, {-2.3622221848584006`, -3.097057141913445}, \
{-2.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-2.3622221848584006`, -3.097057141913445}, \
{-2.3247595264191645`, -3.1875}, {-2.437499981032941, -3.084292589556055}, \
{-2.3622221848584006`, -3.097057141913445}}], 
      PolygonBox[{{-2.4373449933535234`, -3.230251642536255}, \
{-2.437499981032941, -3.084292589556055}, {-2.3247595264191645`, -3.1875}, \
{-2.4373449933535234`, -3.230251642536255}}], 
      PolygonBox[{{-2.3247595264191645`, -3.1875}, {-2.2651650429449552`, \
-3.2651650429449552`}, {-2.4373449933535234`, -3.230251642536255}, \
{-2.3247595264191645`, -3.1875}}], 
      PolygonBox[{{-2.404942744332997, -3.404942744332997}, \
{-2.4373449933535234`, -3.230251642536255}, {-2.2651650429449552`, \
-3.2651650429449552`}, {-2.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, -3.2651650429449552`}, {-2.1875, \
-3.3247595264191645`}, {-2.404942744332997, -3.404942744332997}, \
{-2.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{-2.230251642536255, -3.4373449933535234`}, \
{-2.404942744332997, -3.404942744332997}, {-2.1875, -3.3247595264191645`}, \
{-2.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{-2.1875, -3.3247595264191645`}, {-2.0970571419134454`, \
-3.3622221848584006`}, {-2.230251642536255, -3.4373449933535234`}, {-2.1875, \
-3.3247595264191645`}}], 
      PolygonBox[{{-2.084292589556064, -3.437499981032941}, \
{-2.230251642536255, -3.4373449933535234`}, {-2.0970571419134454`, \
-3.3622221848584006`}, {-2.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-2.0970571419134454`, -3.3622221848584006`}, {-2., \
-3.375}, {-2.084292589556064, -3.437499981032941}, {-2.0970571419134454`, \
-3.3622221848584006`}}], 
      PolygonBox[{{-1.999865158168957, -3.4375}, {-2.084292589556064, \
-3.437499981032941}, {-2., -3.375}, {-1.999865158168957, -3.4375}}], 
      PolygonBox[{{-2., -3.375}, {-1.9029428580865548`, \
-3.3622221848584006`}, {-1.999865158168957, -3.4375}, {-2., -3.375}}], 
      PolygonBox[{{-1.9157074104439469`, -3.437499981032941}, \
{-1.999865158168957, -3.4375}, {-1.9029428580865548`, -3.3622221848584006`}, \
{-1.9157074104439469`, -3.437499981032941}}], 
      PolygonBox[{{-1.9029428580865548`, -3.3622221848584006`}, \
{-1.8125000000000002`, -3.3247595264191645`}, {-1.9157074104439469`, \
-3.437499981032941}, {-1.9029428580865548`, -3.3622221848584006`}}], 
      PolygonBox[{{-1.7697483574637454`, -3.4373449933535234`}, \
{-1.9157074104439469`, -3.437499981032941}, {-1.8125000000000002`, \
-3.3247595264191645`}, {-1.7697483574637454`, -3.4373449933535234`}}], 
      PolygonBox[{{-1.8125000000000002`, -3.3247595264191645`}, \
{-1.7348349570550448`, -3.2651650429449552`}, {-1.7697483574637454`, \
-3.4373449933535234`}, {-1.8125000000000002`, -3.3247595264191645`}}], 
      PolygonBox[{{-1.5950572556670028`, -3.404942744332997}, \
{-1.7697483574637454`, -3.4373449933535234`}, {-1.7348349570550448`, \
-3.2651650429449552`}, {-1.5950572556670028`, -3.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, -3.2651650429449552`}, \
{-1.7348349570550448`, -3.2651650429449552`}, {-1.5950572556670028`, \
-3.404942744332997}, {-1.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{-1.5950572556670028`, -3.404942744332997}, \
{-1.5950572556670028`, -3.404942744332997}, {-1.7348349570550448`, \
-3.2651650429449552`}, {-1.5950572556670028`, -3.404942744332997}}], 
      PolygonBox[{{-1.5950572556670028`, -3.404942744332997}, \
{-1.5626550066464766`, -3.2302516425362553`}, {-1.5, -3.5}, \
{-1.5950572556670028`, -3.404942744332997}}], 
      PolygonBox[{{-1.5, -3.357662782649368}, {-1.5, -3.5}, \
{-1.5626550066464766`, -3.2302516425362553`}, {-1.5, -3.357662782649368}}], 
      PolygonBox[{{-1.5626550066464766`, -3.2302516425362553`}, \
{-1.5625000189670593`, -3.084292589556062}, {-1.5, -3.357662782649368}, \
{-1.5626550066464766`, -3.2302516425362553`}}], 
      PolygonBox[{{-1.5, -3.20590900530174}, {-1.5, -3.357662782649368}, \
{-1.5625000189670593`, -3.084292589556062}, {-1.5, -3.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, -3.084292589556062}, {-1.5625, -3.}, \
{-1.5, -3.20590900530174}, {-1.5625000189670593`, -3.084292589556062}}], 
      PolygonBox[{{-1.5, -3.}, {-1.5, -3.20590900530174}, {-1.5625, -3.}, \
{-1.5, -3.}}], 
      PolygonBox[{{-1.5625, -3.}, {-1.5625000189670593`, -2.915707410443938}, \
{-1.5, -3.}, {-1.5625, -3.}}], 
      PolygonBox[{{-1.5, -2.79409099469826}, {-1.5, -3.}, \
{-1.5625000189670593`, -2.915707410443938}, {-1.5, -2.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, -2.915707410443938}, \
{-1.5626550066464766`, -2.769748357463745}, {-1.5, -2.79409099469826}, \
{-1.5625000189670593`, -2.915707410443938}}], 
      PolygonBox[{{-1.5, -2.6423372173506325`}, {-1.5, -2.79409099469826}, \
{-1.5626550066464766`, -2.769748357463745}, {-1.5, -2.6423372173506325`}}], 
      PolygonBox[{{-1.5626550066464766`, -2.769748357463745}, \
{-1.5950572556670028`, -2.595057255667003}, {-1.5, -2.6423372173506325`}, \
{-1.5626550066464766`, -2.769748357463745}}], 
      PolygonBox[{{-1.508553435038814, -2.508553435038814}, {-1.5, \
-2.6423372173506325`}, {-1.5950572556670028`, -2.595057255667003}, \
{-1.508553435038814, -2.508553435038814}}], 
      PolygonBox[{{-1.5950572556670028`, -2.595057255667003}, \
{-1.769748357463745, -2.5626550066464766`}, {-1.508553435038814, \
-2.508553435038814}, {-1.5950572556670028`, -2.595057255667003}}], 
      PolygonBox[{{-1.6423372173506319`, -2.5}, {-1.508553435038814, \
-2.508553435038814}, {-1.769748357463745, -2.5626550066464766`}, \
{-1.6423372173506319`, -2.5}}], 
      PolygonBox[{{-1.769748357463745, -2.5626550066464766`}, \
{-1.9157074104439396`, -2.562500018967059}, {-1.6423372173506319`, -2.5}, \
{-1.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{-1.7940909946267443`, -2.5}, {-1.6423372173506319`, -2.5}, \
{-1.9157074104439396`, -2.562500018967059}, {-1.7940909946267443`, -2.5}}], 
      PolygonBox[{{-1.9157074104439396`, -2.562500018967059}, \
{-1.9998944727795123`, -2.5625}, {-1.7940909946267443`, -2.5}, \
{-1.9157074104439396`, -2.562500018967059}}], 
      PolygonBox[{{-1.92205804197311, -2.5}, {-1.7940909946267443`, -2.5}, \
{-1.9998944727795123`, -2.5625}, {-1.92205804197311, -2.5}}], 
      PolygonBox[{{-1.9998944727795123`, -2.5625}, {-2.084292589556057, \
-2.562500018967059}, {-1.92205804197311, -2.5}, {-1.9998944727795123`, \
-2.5625}}], 
      PolygonBox[{{-2.2059090053044454`, -2.5}, {-1.92205804197311, -2.5}, \
{-2.084292589556057, -2.562500018967059}, {-2.2059090053044454`, -2.5}}], 
      PolygonBox[{{-2.084292589556057, -2.562500018967059}, \
{-2.230251642536255, -2.5626550066464766`}, {-2.2059090053044454`, -2.5}, \
{-2.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-2.357662782649366, -2.5}, {-2.2059090053044454`, -2.5}, \
{-2.230251642536255, -2.5626550066464766`}, {-2.357662782649366, -2.5}}], 
      PolygonBox[{{-2.230251642536255, -2.5626550066464766`}, \
{-2.404942744332997, -2.595057255667003}, {-2.357662782649366, -2.5}, \
{-2.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-1.5, -2.5}, {-2.357662782649366, -2.5}, \
{-2.404942744332997, -2.595057255667003}, {-1.5, -2.5}}], 
      PolygonBox[{{-2.404942744332997, -2.595057255667003}, \
{-2.4373449933535234`, -2.7697483574637447`}, {-1.5, -2.5}, \
{-2.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{-2.5, -2.642337217350631}, {-1.5, -2.5}, \
{-2.4373449933535234`, -2.7697483574637447`}, {-2.5, -2.642337217350631}}], 
      PolygonBox[{{-2.4373449933535234`, -2.7697483574637447`}, \
{-2.437499981032941, -2.9157074104439378`}, {-2.5, -2.642337217350631}, \
{-2.4373449933535234`, -2.7697483574637447`}}], 
      PolygonBox[{{-2.5, -2.794090994717101}, {-2.5, -2.642337217350631}, \
{-2.437499981032941, -2.9157074104439378`}, {-2.5, -2.794090994717101}}], 
      PolygonBox[{{-2.437499981032941, -2.9157074104439378`}, {-2.4375, \
-2.9998768219370047`}, {-2.5, -2.794090994717101}, {-2.437499981032941, \
-2.9157074104439378`}}], 
      PolygonBox[{{-2.5, -2.9193213332413}, {-2.5, -2.794090994717101}, \
{-2.4375, -2.9998768219370047`}, {-2.5, -2.9193213332413}}], 
      PolygonBox[{{-2.4375, -2.9998768219370047`}, {-2.437499981032941, \
-3.084292589556055}, {-2.5, -2.9193213332413}, {-2.4375, \
-2.9998768219370047`}}], 
      PolygonBox[{{-2.5, -3.2059090051452785`}, {-2.5, -2.9193213332413}, \
{-2.437499981032941, -3.084292589556055}, {-2.5, -3.2059090051452785`}}], 
      PolygonBox[{{-2.437499981032941, -3.084292589556055}, \
{-2.4373449933535234`, -3.230251642536255}, {-2.5, -3.2059090051452785`}, \
{-2.437499981032941, -3.084292589556055}}], 
      PolygonBox[{{-2.5, -3.3576627826493652`}, {-2.5, -3.2059090051452785`}, \
{-2.4373449933535234`, -3.230251642536255}, {-2.5, -3.3576627826493652`}}], 
      PolygonBox[{{-2.4373449933535234`, -3.230251642536255}, \
{-2.404942744332997, -3.404942744332997}, {-2.5, -3.3576627826493652`}, \
{-2.4373449933535234`, -3.230251642536255}}], 
      PolygonBox[{{-2.5, -2.5}, {-2.5, -3.3576627826493652`}, \
{-2.404942744332997, -3.404942744332997}, {-2.5, -2.5}}], 
      PolygonBox[{{-2.404942744332997, -3.404942744332997}, \
{-2.230251642536255, -3.4373449933535234`}, {-2.5, -2.5}, \
{-2.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{-2.5, -3.5}, {-2.5, -2.5}, {-2.230251642536255, \
-3.4373449933535234`}, {-2.5, -3.5}}], 
      PolygonBox[{{-2.230251642536255, -3.4373449933535234`}, \
{-2.084292589556064, -3.437499981032941}, {-2.5, -3.5}, {-2.230251642536255, \
-3.4373449933535234`}}], 
      PolygonBox[{{-2.205909005566828, -3.5}, {-2.5, -3.5}, \
{-2.084292589556064, -3.437499981032941}, {-2.205909005566828, -3.5}}], 
      PolygonBox[{{-2.084292589556064, -3.437499981032941}, \
{-1.999865158168957, -3.4375}, {-2.205909005566828, -3.5}, \
{-2.084292589556064, -3.437499981032941}}], 
      PolygonBox[{{-1.9176761295989384`, -3.5}, {-2.205909005566828, -3.5}, \
{-1.999865158168957, -3.4375}, {-1.9176761295989384`, -3.5}}], 
      PolygonBox[{{-1.999865158168957, -3.4375}, {-1.9157074104439469`, \
-3.437499981032941}, {-1.9176761295989384`, -3.5}, {-1.999865158168957, \
-3.4375}}], 
      PolygonBox[{{-1.7940909946396026`, -3.5}, {-1.9176761295989384`, -3.5}, \
{-1.9157074104439469`, -3.437499981032941}, {-1.7940909946396026`, -3.5}}], 
      PolygonBox[{{-1.9157074104439469`, -3.437499981032941}, \
{-1.7697483574637454`, -3.4373449933535234`}, {-1.7940909946396026`, -3.5}, \
{-1.9157074104439469`, -3.437499981032941}}], 
      PolygonBox[{{-1.642337217350629, -3.5}, {-1.7940909946396026`, -3.5}, \
{-1.7697483574637454`, -3.4373449933535234`}, {-1.642337217350629, -3.5}}], 
      PolygonBox[{{-1.7697483574637454`, -3.4373449933535234`}, \
{-1.5950572556670028`, -3.404942744332997}, {-1.642337217350629, -3.5}, \
{-1.7697483574637454`, -3.4373449933535234`}}], 
      PolygonBox[{{-1.5, -3.5}, {-1.642337217350629, -3.5}, \
{-1.5950572556670028`, -3.404942744332997}, {-1.5, -3.5}}], 
      PolygonBox[{{-1.5950572556670028`, -3.404942744332997}, \
{-1.5950572556670028`, -3.404942744332997}, {-1.5, -3.5}, \
{-1.5950572556670028`, -3.404942744332997}}], 
      PolygonBox[{{-1.5, -3.5}, {-1.5, -3.5}, {-1.5950572556670028`, \
-3.404942744332997}, {-1.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, -2.}, {-2.4791666666666665`, -2.}, \
{-2.4583333333333335`, -2.}, {-2.4375, -2.}, {-2.4166666666666665`, -2.}, \
{-2.3958333333333335`, -2.}, {-2.375, -2.}, {-2.375, -2.}, \
{-2.3958333333333335`, -2.}, {-2.4166666666666665`, -2.}, {-2.4375, -2.}, \
{-2.4583333333333335`, -2.}, {-2.4791666666666665`, -2.}, {-2.5, -2.}, {-2.5, \
-2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, -2.}, {-1.6041666666666667`, -2.}, \
{-1.5833333333333333`, -2.}, {-1.5625, -2.}, {-1.5416666666666667`, -2.}, \
{-1.5208333333333335`, -2.}, {-1.5, -2.}, {-1.5, -2.}, {-1.5208333333333333`, \
-2.}, {-1.5416666666666667`, -2.}, {-1.5625, -2.}, {-1.5833333333333333`, \
-2.}, {-1.6041666666666665`, -2.}, {-1.625, -2.}, {-1.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -2.5}, {-2., -2.4791666666666665`}, {-2., \
-2.4583333333333335`}, {-2., -2.4375}, {-2., -2.4166666666666665`}, {-2., \
-2.3958333333333335`}, {-2., -2.375}, {-2., -2.375}, {-2., \
-2.3958333333333335`}, {-2., -2.4166666666666665`}, {-2., -2.4375}, {-2., \
-2.4583333333333335`}, {-2., -2.4791666666666665`}, {-2., -2.5}, {-2., \
-2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -1.625}, {-2., -1.6041666666666667`}, {-2., \
-1.5833333333333333`}, {-2., -1.5625}, {-2., -1.5416666666666667`}, {-2., \
-1.5208333333333335`}, {-2., -1.5}, {-2., -1.5}, {-2., -1.5208333333333333`}, \
{-2., -1.5416666666666667`}, {-2., -1.5625}, {-2., -1.5833333333333333`}, \
{-2., -1.6041666666666665`}, {-2., -1.625}, {-2., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, -2.}, {-2.25, -2.}, {-2.125, -2.}, {-2., -2.}, \
{-1.875, -2.}, {-1.75, -2.}, {-1.625, -2.}, {-1.625, -2.}, {-1.75, -2.}, \
{-1.875, -2.}, {-2., -2.}, {-2.125, -2.}, {-2.25, -2.}, {-2.375, -2.}, \
{-2.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -2.375}, {-2., -2.25}, {-2., -2.125}, {-2., -2.}, {-2., \
-1.875}, {-2., -1.75}, {-2., -1.625}, {-2., -1.625}, {-2., -1.75}, {-2., \
-1.875}, {-2., -2.}, {-2., -2.125}, {-2., -2.25}, {-2., -2.375}, {-2., \
-2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kMZB3RiFjWFmfzan2R+y7Sk6N/+BYX5X06c
hcn/3X9K5YTPo4O/4TRMHKYOpg9mDsxcmD3+T4SeHj2GsAcs3MB4AKZ/9tvZ
N/nkmQ7AzDdwP9EqPZPpAMyeVxfX7bvylOkAzB6IOPMBmD0weT+oPSj6gfbM
gZoPswcmDlMHcx/MHFT3Mx9IhtoLk2eEugumH+ZumPko4Qe0B+ZvmD3o4Q8A
DHiqig==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9sPoVWDwC84PBYO/+1HVMRxAlWc8gKqf6QCq
ehaCfFR7WQ6g2gtTD7MXJs94AFU/0wFU9Zj0ajR16Oag2xOG5o7VaO4k1p+r
0cIFPdxQ7f2xPwwt3FejxQuMBgDFp3Um
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, -2.2651650429449552`}, \
{-1.6752404735808355`, -2.1875}, {-1.5950572556670028`, -2.404942744332997}, \
{-1.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{-1.5626550066464766`, -2.2302516425362553`}, \
{-1.5950572556670028`, -2.404942744332997}, {-1.6752404735808355`, -2.1875}, \
{-1.5626550066464766`, -2.2302516425362553`}}], 
      PolygonBox[{{-1.6752404735808355`, -2.1875}, {-1.6377778151415994`, \
-2.0970571419134454`}, {-1.5626550066464766`, -2.2302516425362553`}, \
{-1.6752404735808355`, -2.1875}}], 
      PolygonBox[{{-1.5625000189670593`, -2.084292589556062}, \
{-1.5626550066464766`, -2.2302516425362553`}, {-1.6377778151415994`, \
-2.0970571419134454`}, {-1.5625000189670593`, -2.084292589556062}}], 
      PolygonBox[{{-1.6377778151415994`, -2.0970571419134454`}, {-1.625, \
-2.}, {-1.5625000189670593`, -2.084292589556062}, {-1.6377778151415994`, \
-2.0970571419134454`}}], 
      PolygonBox[{{-1.5625, -2.}, {-1.5625000189670593`, -2.084292589556062}, \
{-1.625, -2.}, {-1.5625, -2.}}], 
      PolygonBox[{{-1.625, -2.}, {-1.6377778151415994`, \
-1.9029428580865548`}, {-1.5625, -2.}, {-1.625, -2.}}], 
      PolygonBox[{{-1.5625000189670593`, -1.9157074104439382`}, {-1.5625, \
-2.}, {-1.6377778151415994`, -1.9029428580865548`}, {-1.5625000189670593`, \
-1.9157074104439382`}}], 
      PolygonBox[{{-1.6377778151415994`, -1.9029428580865548`}, \
{-1.6752404735808355`, -1.8125}, {-1.5625000189670593`, \
-1.9157074104439382`}, {-1.6377778151415994`, -1.9029428580865548`}}], 
      PolygonBox[{{-1.5626550066464766`, -1.769748357463745}, \
{-1.5625000189670593`, -1.9157074104439382`}, {-1.6752404735808355`, \
-1.8125}, {-1.5626550066464766`, -1.769748357463745}}], 
      PolygonBox[{{-1.6752404735808355`, -1.8125}, {-1.7348349570550448`, \
-1.7348349570550448`}, {-1.5626550066464766`, -1.769748357463745}, \
{-1.6752404735808355`, -1.8125}}], 
      PolygonBox[{{-1.5950572556670028`, -1.5950572556670028`}, \
{-1.5626550066464766`, -1.769748357463745}, {-1.7348349570550448`, \
-1.7348349570550448`}, {-1.5950572556670028`, -1.5950572556670028`}}], 
      PolygonBox[{{-1.7348349570550448`, -1.7348349570550448`}, {-1.8125, \
-1.6752404735808355`}, {-1.5950572556670028`, -1.5950572556670028`}, \
{-1.7348349570550448`, -1.7348349570550448`}}], 
      PolygonBox[{{-1.769748357463745, -1.5626550066464766`}, \
{-1.5950572556670028`, -1.5950572556670028`}, {-1.8125, \
-1.6752404735808355`}, {-1.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{-1.8125, -1.6752404735808355`}, {-1.9029428580865546`, \
-1.6377778151415994`}, {-1.769748357463745, -1.5626550066464766`}, {-1.8125, \
-1.6752404735808355`}}], 
      PolygonBox[{{-1.9157074104439396`, -1.5625000189670593`}, \
{-1.769748357463745, -1.5626550066464766`}, {-1.9029428580865546`, \
-1.6377778151415994`}, {-1.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-1.9029428580865546`, -1.6377778151415994`}, {-2., \
-1.625}, {-1.9157074104439396`, -1.5625000189670593`}, {-1.9029428580865546`, \
-1.6377778151415994`}}], 
      PolygonBox[{{-1.9998944727795123`, -1.5625}, {-1.9157074104439396`, \
-1.5625000189670593`}, {-2., -1.625}, {-1.9998944727795123`, -1.5625}}], 
      PolygonBox[{{-2., -1.625}, {-2.097057141913445, -1.6377778151415994`}, \
{-1.9998944727795123`, -1.5625}, {-2., -1.625}}], 
      PolygonBox[{{-2.084292589556057, -1.5625000189670593`}, \
{-1.9998944727795123`, -1.5625}, {-2.097057141913445, -1.6377778151415994`}, \
{-2.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-2.097057141913445, -1.6377778151415994`}, {-2.1875, \
-1.6752404735808355`}, {-2.084292589556057, -1.5625000189670593`}, \
{-2.097057141913445, -1.6377778151415994`}}], 
      PolygonBox[{{-2.230251642536255, -1.5626550066464766`}, \
{-2.084292589556057, -1.5625000189670593`}, {-2.1875, -1.6752404735808355`}, \
{-2.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-2.1875, -1.6752404735808355`}, {-2.2651650429449552`, \
-1.7348349570550448`}, {-2.230251642536255, -1.5626550066464766`}, {-2.1875, \
-1.6752404735808355`}}], 
      PolygonBox[{{-2.404942744332997, -1.5950572556670028`}, \
{-2.230251642536255, -1.5626550066464766`}, {-2.2651650429449552`, \
-1.7348349570550448`}, {-2.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-2.2651650429449552`, -1.7348349570550448`}, \
{-2.3247595264191645`, -1.8125}, {-2.404942744332997, -1.5950572556670028`}, \
{-2.2651650429449552`, -1.7348349570550448`}}], 
      PolygonBox[{{-2.4373449933535234`, -1.7697483574637447`}, \
{-2.404942744332997, -1.5950572556670028`}, {-2.3247595264191645`, -1.8125}, \
{-2.4373449933535234`, -1.7697483574637447`}}], 
      PolygonBox[{{-2.3247595264191645`, -1.8125}, {-2.3622221848584006`, \
-1.9029428580865546`}, {-2.4373449933535234`, -1.7697483574637447`}, \
{-2.3247595264191645`, -1.8125}}], 
      PolygonBox[{{-2.437499981032941, -1.9157074104439376`}, \
{-2.4373449933535234`, -1.7697483574637447`}, {-2.3622221848584006`, \
-1.9029428580865546`}, {-2.437499981032941, -1.9157074104439376`}}], 
      PolygonBox[{{-2.3622221848584006`, -1.9029428580865546`}, {-2.375, \
-1.9999999999999998`}, {-2.437499981032941, -1.9157074104439376`}, \
{-2.3622221848584006`, -1.9029428580865546`}}], 
      PolygonBox[{{-2.4375, -1.9998768219370047`}, {-2.437499981032941, \
-1.9157074104439376`}, {-2.375, -1.9999999999999998`}, {-2.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-2.375, -1.9999999999999998`}, {-2.3622221848584006`, \
-2.097057141913445}, {-2.4375, -1.9998768219370047`}, {-2.375, \
-1.9999999999999998`}}], 
      PolygonBox[{{-2.437499981032941, -2.084292589556055}, {-2.4375, \
-1.9998768219370047`}, {-2.3622221848584006`, -2.097057141913445}, \
{-2.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-2.3622221848584006`, -2.097057141913445}, \
{-2.3247595264191645`, -2.1875}, {-2.437499981032941, -2.084292589556055}, \
{-2.3622221848584006`, -2.097057141913445}}], 
      PolygonBox[{{-2.4373449933535234`, -2.230251642536255}, \
{-2.437499981032941, -2.084292589556055}, {-2.3247595264191645`, -2.1875}, \
{-2.4373449933535234`, -2.230251642536255}}], 
      PolygonBox[{{-2.3247595264191645`, -2.1875}, {-2.2651650429449552`, \
-2.2651650429449552`}, {-2.4373449933535234`, -2.230251642536255}, \
{-2.3247595264191645`, -2.1875}}], 
      PolygonBox[{{-2.404942744332997, -2.404942744332997}, \
{-2.4373449933535234`, -2.230251642536255}, {-2.2651650429449552`, \
-2.2651650429449552`}, {-2.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, -2.2651650429449552`}, {-2.1875, \
-2.3247595264191645`}, {-2.404942744332997, -2.404942744332997}, \
{-2.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{-2.230251642536255, -2.4373449933535234`}, \
{-2.404942744332997, -2.404942744332997}, {-2.1875, -2.3247595264191645`}, \
{-2.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{-2.1875, -2.3247595264191645`}, {-2.0970571419134454`, \
-2.3622221848584006`}, {-2.230251642536255, -2.4373449933535234`}, {-2.1875, \
-2.3247595264191645`}}], 
      PolygonBox[{{-2.084292589556064, -2.437499981032941}, \
{-2.230251642536255, -2.4373449933535234`}, {-2.0970571419134454`, \
-2.3622221848584006`}, {-2.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-2.0970571419134454`, -2.3622221848584006`}, {-2., \
-2.375}, {-2.084292589556064, -2.437499981032941}, {-2.0970571419134454`, \
-2.3622221848584006`}}], 
      PolygonBox[{{-1.999865158168957, -2.4375}, {-2.084292589556064, \
-2.437499981032941}, {-2., -2.375}, {-1.999865158168957, -2.4375}}], 
      PolygonBox[{{-2., -2.375}, {-1.9029428580865548`, \
-2.3622221848584006`}, {-1.999865158168957, -2.4375}, {-2., -2.375}}], 
      PolygonBox[{{-1.9157074104439469`, -2.437499981032941}, \
{-1.999865158168957, -2.4375}, {-1.9029428580865548`, -2.3622221848584006`}, \
{-1.9157074104439469`, -2.437499981032941}}], 
      PolygonBox[{{-1.9029428580865548`, -2.3622221848584006`}, \
{-1.8125000000000002`, -2.3247595264191645`}, {-1.9157074104439469`, \
-2.437499981032941}, {-1.9029428580865548`, -2.3622221848584006`}}], 
      PolygonBox[{{-1.7697483574637454`, -2.4373449933535234`}, \
{-1.9157074104439469`, -2.437499981032941}, {-1.8125000000000002`, \
-2.3247595264191645`}, {-1.7697483574637454`, -2.4373449933535234`}}], 
      PolygonBox[{{-1.8125000000000002`, -2.3247595264191645`}, \
{-1.7348349570550448`, -2.2651650429449552`}, {-1.7697483574637454`, \
-2.4373449933535234`}, {-1.8125000000000002`, -2.3247595264191645`}}], 
      PolygonBox[{{-1.5950572556670028`, -2.404942744332997}, \
{-1.7697483574637454`, -2.4373449933535234`}, {-1.7348349570550448`, \
-2.2651650429449552`}, {-1.5950572556670028`, -2.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, -2.2651650429449552`}, \
{-1.7348349570550448`, -2.2651650429449552`}, {-1.5950572556670028`, \
-2.404942744332997}, {-1.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{-1.5950572556670028`, -2.404942744332997}, \
{-1.5950572556670028`, -2.404942744332997}, {-1.7348349570550448`, \
-2.2651650429449552`}, {-1.5950572556670028`, -2.404942744332997}}], 
      PolygonBox[{{-1.5950572556670028`, -2.404942744332997}, \
{-1.5626550066464766`, -2.2302516425362553`}, {-1.5, -2.5}, \
{-1.5950572556670028`, -2.404942744332997}}], 
      PolygonBox[{{-1.5, -2.357662782649368}, {-1.5, -2.5}, \
{-1.5626550066464766`, -2.2302516425362553`}, {-1.5, -2.357662782649368}}], 
      PolygonBox[{{-1.5626550066464766`, -2.2302516425362553`}, \
{-1.5625000189670593`, -2.084292589556062}, {-1.5, -2.357662782649368}, \
{-1.5626550066464766`, -2.2302516425362553`}}], 
      PolygonBox[{{-1.5, -2.20590900530174}, {-1.5, -2.357662782649368}, \
{-1.5625000189670593`, -2.084292589556062}, {-1.5, -2.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, -2.084292589556062}, {-1.5625, -2.}, \
{-1.5, -2.20590900530174}, {-1.5625000189670593`, -2.084292589556062}}], 
      PolygonBox[{{-1.5, -2.}, {-1.5, -2.20590900530174}, {-1.5625, -2.}, \
{-1.5, -2.}}], 
      PolygonBox[{{-1.5625, -2.}, {-1.5625000189670593`, \
-1.9157074104439382`}, {-1.5, -2.}, {-1.5625, -2.}}], 
      PolygonBox[{{-1.5, -1.7940909946982602`}, {-1.5, -2.}, \
{-1.5625000189670593`, -1.9157074104439382`}, {-1.5, -1.7940909946982602`}}], 
      PolygonBox[{{-1.5625000189670593`, -1.9157074104439382`}, \
{-1.5626550066464766`, -1.769748357463745}, {-1.5, -1.7940909946982602`}, \
{-1.5625000189670593`, -1.9157074104439382`}}], 
      PolygonBox[{{-1.5, -1.6423372173506325`}, {-1.5, -1.7940909946982602`}, \
{-1.5626550066464766`, -1.769748357463745}, {-1.5, -1.6423372173506325`}}], 
      PolygonBox[{{-1.5626550066464766`, -1.769748357463745}, \
{-1.5950572556670028`, -1.5950572556670028`}, {-1.5, -1.6423372173506325`}, \
{-1.5626550066464766`, -1.769748357463745}}], 
      PolygonBox[{{-1.508553435038814, -1.508553435038814}, {-1.5, \
-1.6423372173506325`}, {-1.5950572556670028`, -1.5950572556670028`}, \
{-1.508553435038814, -1.508553435038814}}], 
      PolygonBox[{{-1.5950572556670028`, -1.5950572556670028`}, \
{-1.769748357463745, -1.5626550066464766`}, {-1.508553435038814, \
-1.508553435038814}, {-1.5950572556670028`, -1.5950572556670028`}}], 
      PolygonBox[{{-1.6423372173506319`, -1.5}, {-1.508553435038814, \
-1.508553435038814}, {-1.769748357463745, -1.5626550066464766`}, \
{-1.6423372173506319`, -1.5}}], 
      PolygonBox[{{-1.769748357463745, -1.5626550066464766`}, \
{-1.9157074104439396`, -1.5625000189670593`}, {-1.6423372173506319`, -1.5}, \
{-1.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{-1.7940909946267443`, -1.5}, {-1.6423372173506319`, -1.5}, \
{-1.9157074104439396`, -1.5625000189670593`}, {-1.7940909946267443`, -1.5}}], 
      PolygonBox[{{-1.9157074104439396`, -1.5625000189670593`}, \
{-1.9998944727795123`, -1.5625}, {-1.7940909946267443`, -1.5}, \
{-1.9157074104439396`, -1.5625000189670593`}}], 
      PolygonBox[{{-1.92205804197311, -1.5}, {-1.7940909946267443`, -1.5}, \
{-1.9998944727795123`, -1.5625}, {-1.92205804197311, -1.5}}], 
      PolygonBox[{{-1.9998944727795123`, -1.5625}, {-2.084292589556057, \
-1.5625000189670593`}, {-1.92205804197311, -1.5}, {-1.9998944727795123`, \
-1.5625}}], 
      PolygonBox[{{-2.2059090053044454`, -1.5}, {-1.92205804197311, -1.5}, \
{-2.084292589556057, -1.5625000189670593`}, {-2.2059090053044454`, -1.5}}], 
      PolygonBox[{{-2.084292589556057, -1.5625000189670593`}, \
{-2.230251642536255, -1.5626550066464766`}, {-2.2059090053044454`, -1.5}, \
{-2.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-2.357662782649366, -1.5}, {-2.2059090053044454`, -1.5}, \
{-2.230251642536255, -1.5626550066464766`}, {-2.357662782649366, -1.5}}], 
      PolygonBox[{{-2.230251642536255, -1.5626550066464766`}, \
{-2.404942744332997, -1.5950572556670028`}, {-2.357662782649366, -1.5}, \
{-2.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-1.5, -1.5}, {-2.357662782649366, -1.5}, \
{-2.404942744332997, -1.5950572556670028`}, {-1.5, -1.5}}], 
      PolygonBox[{{-2.404942744332997, -1.5950572556670028`}, \
{-2.4373449933535234`, -1.7697483574637447`}, {-1.5, -1.5}, \
{-2.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{-2.5, -1.642337217350631}, {-1.5, -1.5}, \
{-2.4373449933535234`, -1.7697483574637447`}, {-2.5, -1.642337217350631}}], 
      PolygonBox[{{-2.4373449933535234`, -1.7697483574637447`}, \
{-2.437499981032941, -1.9157074104439376`}, {-2.5, -1.642337217350631}, \
{-2.4373449933535234`, -1.7697483574637447`}}], 
      PolygonBox[{{-2.5, -1.794090994717101}, {-2.5, -1.642337217350631}, \
{-2.437499981032941, -1.9157074104439376`}, {-2.5, -1.794090994717101}}], 
      PolygonBox[{{-2.437499981032941, -1.9157074104439376`}, {-2.4375, \
-1.9998768219370047`}, {-2.5, -1.794090994717101}, {-2.437499981032941, \
-1.9157074104439376`}}], 
      PolygonBox[{{-2.5, -1.9193213332412997`}, {-2.5, -1.794090994717101}, \
{-2.4375, -1.9998768219370047`}, {-2.5, -1.9193213332412997`}}], 
      PolygonBox[{{-2.4375, -1.9998768219370047`}, {-2.437499981032941, \
-2.084292589556055}, {-2.5, -1.9193213332412997`}, {-2.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-2.5, -2.2059090051452785`}, {-2.5, -1.9193213332412997`}, \
{-2.437499981032941, -2.084292589556055}, {-2.5, -2.2059090051452785`}}], 
      PolygonBox[{{-2.437499981032941, -2.084292589556055}, \
{-2.4373449933535234`, -2.230251642536255}, {-2.5, -2.2059090051452785`}, \
{-2.437499981032941, -2.084292589556055}}], 
      PolygonBox[{{-2.5, -2.3576627826493652`}, {-2.5, -2.2059090051452785`}, \
{-2.4373449933535234`, -2.230251642536255}, {-2.5, -2.3576627826493652`}}], 
      PolygonBox[{{-2.4373449933535234`, -2.230251642536255}, \
{-2.404942744332997, -2.404942744332997}, {-2.5, -2.3576627826493652`}, \
{-2.4373449933535234`, -2.230251642536255}}], 
      PolygonBox[{{-2.5, -1.5}, {-2.5, -2.3576627826493652`}, \
{-2.404942744332997, -2.404942744332997}, {-2.5, -1.5}}], 
      PolygonBox[{{-2.404942744332997, -2.404942744332997}, \
{-2.230251642536255, -2.4373449933535234`}, {-2.5, -1.5}, \
{-2.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{-2.5, -2.5}, {-2.5, -1.5}, {-2.230251642536255, \
-2.4373449933535234`}, {-2.5, -2.5}}], 
      PolygonBox[{{-2.230251642536255, -2.4373449933535234`}, \
{-2.084292589556064, -2.437499981032941}, {-2.5, -2.5}, {-2.230251642536255, \
-2.4373449933535234`}}], 
      PolygonBox[{{-2.205909005566828, -2.5}, {-2.5, -2.5}, \
{-2.084292589556064, -2.437499981032941}, {-2.205909005566828, -2.5}}], 
      PolygonBox[{{-2.084292589556064, -2.437499981032941}, \
{-1.999865158168957, -2.4375}, {-2.205909005566828, -2.5}, \
{-2.084292589556064, -2.437499981032941}}], 
      PolygonBox[{{-1.9176761295989384`, -2.5}, {-2.205909005566828, -2.5}, \
{-1.999865158168957, -2.4375}, {-1.9176761295989384`, -2.5}}], 
      PolygonBox[{{-1.999865158168957, -2.4375}, {-1.9157074104439469`, \
-2.437499981032941}, {-1.9176761295989384`, -2.5}, {-1.999865158168957, \
-2.4375}}], 
      PolygonBox[{{-1.7940909946396026`, -2.5}, {-1.9176761295989384`, -2.5}, \
{-1.9157074104439469`, -2.437499981032941}, {-1.7940909946396026`, -2.5}}], 
      PolygonBox[{{-1.9157074104439469`, -2.437499981032941}, \
{-1.7697483574637454`, -2.4373449933535234`}, {-1.7940909946396026`, -2.5}, \
{-1.9157074104439469`, -2.437499981032941}}], 
      PolygonBox[{{-1.642337217350629, -2.5}, {-1.7940909946396026`, -2.5}, \
{-1.7697483574637454`, -2.4373449933535234`}, {-1.642337217350629, -2.5}}], 
      PolygonBox[{{-1.7697483574637454`, -2.4373449933535234`}, \
{-1.5950572556670028`, -2.404942744332997}, {-1.642337217350629, -2.5}, \
{-1.7697483574637454`, -2.4373449933535234`}}], 
      PolygonBox[{{-1.5, -2.5}, {-1.642337217350629, -2.5}, \
{-1.5950572556670028`, -2.404942744332997}, {-1.5, -2.5}}], 
      PolygonBox[{{-1.5950572556670028`, -2.404942744332997}, \
{-1.5950572556670028`, -2.404942744332997}, {-1.5, -2.5}, \
{-1.5950572556670028`, -2.404942744332997}}], 
      PolygonBox[{{-1.5, -2.5}, {-1.5, -2.5}, {-1.5950572556670028`, \
-2.404942744332997}, {-1.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, -1.}, {-2.4791666666666665`, -1.}, \
{-2.4583333333333335`, -1.}, {-2.4375, -1.}, {-2.4166666666666665`, -1.}, \
{-2.3958333333333335`, -1.}, {-2.375, -1.}, {-2.375, -1.}, \
{-2.3958333333333335`, -1.}, {-2.4166666666666665`, -1.}, {-2.4375, -1.}, \
{-2.4583333333333335`, -1.}, {-2.4791666666666665`, -1.}, {-2.5, -1.}, {-2.5, \
-1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, -1.}, {-1.6041666666666667`, -1.}, \
{-1.5833333333333333`, -1.}, {-1.5625, -1.}, {-1.5416666666666667`, -1.}, \
{-1.5208333333333335`, -1.}, {-1.5, -1.}, {-1.5, -1.}, {-1.5208333333333333`, \
-1.}, {-1.5416666666666667`, -1.}, {-1.5625, -1.}, {-1.5833333333333333`, \
-1.}, {-1.6041666666666665`, -1.}, {-1.625, -1.}, {-1.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -1.5}, {-2., -1.4791666666666667`}, {-2., \
-1.4583333333333333`}, {-2., -1.4375}, {-2., -1.4166666666666667`}, {-2., \
-1.3958333333333335`}, {-2., -1.375}, {-2., -1.375}, {-2., \
-1.3958333333333333`}, {-2., -1.4166666666666667`}, {-2., -1.4375}, {-2., \
-1.4583333333333333`}, {-2., -1.4791666666666665`}, {-2., -1.5}, {-2., \
-1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -0.625}, {-2., -0.6041666666666667}, {-2., \
-0.5833333333333333}, {-2., -0.5625}, {-2., -0.5416666666666667}, {-2., \
-0.5208333333333334}, {-2., -0.5}, {-2., -0.5}, {-2., -0.5208333333333333}, \
{-2., -0.5416666666666667}, {-2., -0.5625}, {-2., -0.5833333333333333}, {-2., \
-0.6041666666666666}, {-2., -0.625}, {-2., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, -1.}, {-2.25, -1.}, {-2.125, -1.}, {-2., -1.}, \
{-1.875, -1.}, {-1.75, -1.}, {-1.625, -1.}, {-1.625, -1.}, {-1.75, -1.}, \
{-1.875, -1.}, {-2., -1.}, {-2.125, -1.}, {-2.25, -1.}, {-2.375, -1.}, \
{-2.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -1.375}, {-2., -1.25}, {-2., -1.125}, {-2., -1.}, {-2., \
-0.875}, {-2., -0.75}, {-2., -0.625}, {-2., -0.625}, {-2., -0.75}, {-2., \
-0.875}, {-2., -1.}, {-2., -1.125}, {-2., -1.25}, {-2., -1.375}, {-2., \
-1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kPoD/t1YhY1hZn82n80b0v2iydv9i8ozP9y
4ixM/tX+UyonfB4d/L1/iueEmUean0PF/+53eHzvxcTZT/cnmd8yLSn6tz9i
hwvr2ownUHmGAxDqyX7/J0JPjx5jOIAi38B4AKZ/9tvZN/nkmQ5Mhppv4H6i
VXom04H/YPBy/6uL6/Zdecp04AjUfRBzmQ/A3A+Tn3tC9VR370e4foj85/1z
oOab3TbfLGv3BW5/Qt8EbnOjr3D3XVkcW7vy9Fc093/bnwz1H0yeEep/mH5Y
+MDMh4UfI9R+WPjOh7oPPfwBX8K5UA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kPoB/tXgcEvOD8UDP7C+VANB1DlGQ+g6mc6
gKqehSAfYs5TOB9izis09R/Q5D+h6f+Kpv4HBn81ivt+oLn/B5r/fuwPQ/E/
TP+v/ajqCdNhKO6DmfMJTd0HNPlXaPqfoql/sB8AcKCCLA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, -1.2651650429449552`}, \
{-1.6752404735808355`, -1.1875}, {-1.5950572556670028`, \
-1.4049427443329972`}, {-1.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{-1.5626550066464766`, -1.230251642536255}, \
{-1.5950572556670028`, -1.4049427443329972`}, {-1.6752404735808355`, \
-1.1875}, {-1.5626550066464766`, -1.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, -1.1875}, {-1.6377778151415994`, \
-1.0970571419134454`}, {-1.5626550066464766`, -1.230251642536255}, \
{-1.6752404735808355`, -1.1875}}], 
      PolygonBox[{{-1.5625000189670593`, -1.0842925895560618`}, \
{-1.5626550066464766`, -1.230251642536255}, {-1.6377778151415994`, \
-1.0970571419134454`}, {-1.5625000189670593`, -1.0842925895560618`}}], 
      PolygonBox[{{-1.6377778151415994`, -1.0970571419134454`}, {-1.625, \
-1.}, {-1.5625000189670593`, -1.0842925895560618`}, {-1.6377778151415994`, \
-1.0970571419134454`}}], 
      PolygonBox[{{-1.5625, -1.}, {-1.5625000189670593`, \
-1.0842925895560618`}, {-1.625, -1.}, {-1.5625, -1.}}], 
      PolygonBox[{{-1.625, -1.}, {-1.6377778151415994`, -0.9029428580865547}, \
{-1.5625, -1.}, {-1.625, -1.}}], 
      PolygonBox[{{-1.5625000189670593`, -0.9157074104439382}, {-1.5625, \
-1.}, {-1.6377778151415994`, -0.9029428580865547}, {-1.5625000189670593`, \
-0.9157074104439382}}], 
      PolygonBox[{{-1.6377778151415994`, -0.9029428580865547}, \
{-1.6752404735808355`, -0.8125}, {-1.5625000189670593`, -0.9157074104439382}, \
{-1.6377778151415994`, -0.9029428580865547}}], 
      PolygonBox[{{-1.5626550066464766`, -0.7697483574637449}, \
{-1.5625000189670593`, -0.9157074104439382}, {-1.6752404735808355`, -0.8125}, \
{-1.5626550066464766`, -0.7697483574637449}}], 
      PolygonBox[{{-1.6752404735808355`, -0.8125}, {-1.7348349570550448`, \
-0.7348349570550448}, {-1.5626550066464766`, -0.7697483574637449}, \
{-1.6752404735808355`, -0.8125}}], 
      PolygonBox[{{-1.5950572556670028`, -0.5950572556670028}, \
{-1.5626550066464766`, -0.7697483574637449}, {-1.7348349570550448`, \
-0.7348349570550448}, {-1.5950572556670028`, -0.5950572556670028}}], 
      PolygonBox[{{-1.7348349570550448`, -0.7348349570550448}, {-1.8125, \
-0.6752404735808355}, {-1.5950572556670028`, -0.5950572556670028}, \
{-1.7348349570550448`, -0.7348349570550448}}], 
      PolygonBox[{{-1.769748357463745, -0.5626550066464766}, \
{-1.5950572556670028`, -0.5950572556670028}, {-1.8125, -0.6752404735808355}, \
{-1.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{-1.8125, -0.6752404735808355}, {-1.9029428580865546`, \
-0.6377778151415994}, {-1.769748357463745, -0.5626550066464766}, {-1.8125, \
-0.6752404735808355}}], 
      PolygonBox[{{-1.9157074104439396`, -0.5625000189670593}, \
{-1.769748357463745, -0.5626550066464766}, {-1.9029428580865546`, \
-0.6377778151415994}, {-1.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-1.9029428580865546`, -0.6377778151415994}, {-2., -0.625}, \
{-1.9157074104439396`, -0.5625000189670593}, {-1.9029428580865546`, \
-0.6377778151415994}}], 
      PolygonBox[{{-1.9998944727795123`, -0.5625}, {-1.9157074104439396`, \
-0.5625000189670593}, {-2., -0.625}, {-1.9998944727795123`, -0.5625}}], 
      PolygonBox[{{-2., -0.625}, {-2.097057141913445, -0.6377778151415994}, \
{-1.9998944727795123`, -0.5625}, {-2., -0.625}}], 
      PolygonBox[{{-2.084292589556057, -0.5625000189670593}, \
{-1.9998944727795123`, -0.5625}, {-2.097057141913445, -0.6377778151415994}, \
{-2.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-2.097057141913445, -0.6377778151415994}, {-2.1875, \
-0.6752404735808355}, {-2.084292589556057, -0.5625000189670593}, \
{-2.097057141913445, -0.6377778151415994}}], 
      PolygonBox[{{-2.230251642536255, -0.5626550066464766}, \
{-2.084292589556057, -0.5625000189670593}, {-2.1875, -0.6752404735808355}, \
{-2.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-2.1875, -0.6752404735808355}, {-2.2651650429449552`, \
-0.7348349570550446}, {-2.230251642536255, -0.5626550066464766}, {-2.1875, \
-0.6752404735808355}}], 
      PolygonBox[{{-2.404942744332997, -0.5950572556670028}, \
{-2.230251642536255, -0.5626550066464766}, {-2.2651650429449552`, \
-0.7348349570550446}, {-2.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{-2.2651650429449552`, -0.7348349570550446}, \
{-2.3247595264191645`, -0.8124999999999999}, {-2.404942744332997, \
-0.5950572556670028}, {-2.2651650429449552`, -0.7348349570550446}}], 
      PolygonBox[{{-2.4373449933535234`, -0.7697483574637446}, \
{-2.404942744332997, -0.5950572556670028}, {-2.3247595264191645`, \
-0.8124999999999999}, {-2.4373449933535234`, -0.7697483574637446}}], 
      PolygonBox[{{-2.3247595264191645`, -0.8124999999999999}, \
{-2.3622221848584006`, -0.9029428580865546}, {-2.4373449933535234`, \
-0.7697483574637446}, {-2.3247595264191645`, -0.8124999999999999}}], 
      PolygonBox[{{-2.437499981032941, -0.9157074104439377}, \
{-2.4373449933535234`, -0.7697483574637446}, {-2.3622221848584006`, \
-0.9029428580865546}, {-2.437499981032941, -0.9157074104439377}}], 
      PolygonBox[{{-2.3622221848584006`, -0.9029428580865546}, {-2.375, \
-0.9999999999999998}, {-2.437499981032941, -0.9157074104439377}, \
{-2.3622221848584006`, -0.9029428580865546}}], 
      PolygonBox[{{-2.4375, -0.9998768219370047}, {-2.437499981032941, \
-0.9157074104439377}, {-2.375, -0.9999999999999998}, {-2.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-2.375, -0.9999999999999998}, {-2.3622221848584006`, \
-1.0970571419134452`}, {-2.4375, -0.9998768219370047}, {-2.375, \
-0.9999999999999998}}], 
      PolygonBox[{{-2.437499981032941, -1.084292589556055}, {-2.4375, \
-0.9998768219370047}, {-2.3622221848584006`, -1.0970571419134452`}, \
{-2.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-2.3622221848584006`, -1.0970571419134452`}, \
{-2.3247595264191645`, -1.1874999999999998`}, {-2.437499981032941, \
-1.084292589556055}, {-2.3622221848584006`, -1.0970571419134452`}}], 
      PolygonBox[{{-2.4373449933535234`, -1.2302516425362549`}, \
{-2.437499981032941, -1.084292589556055}, {-2.3247595264191645`, \
-1.1874999999999998`}, {-2.4373449933535234`, -1.2302516425362549`}}], 
      PolygonBox[{{-2.3247595264191645`, -1.1874999999999998`}, \
{-2.2651650429449552`, -1.2651650429449552`}, {-2.4373449933535234`, \
-1.2302516425362549`}, {-2.3247595264191645`, -1.1874999999999998`}}], 
      PolygonBox[{{-2.404942744332997, -1.4049427443329972`}, \
{-2.4373449933535234`, -1.2302516425362549`}, {-2.2651650429449552`, \
-1.2651650429449552`}, {-2.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-2.2651650429449552`, -1.2651650429449552`}, {-2.1875, \
-1.3247595264191645`}, {-2.404942744332997, -1.4049427443329972`}, \
{-2.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{-2.230251642536255, -1.4373449933535234`}, \
{-2.404942744332997, -1.4049427443329972`}, {-2.1875, -1.3247595264191645`}, \
{-2.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-2.1875, -1.3247595264191645`}, {-2.0970571419134454`, \
-1.3622221848584006`}, {-2.230251642536255, -1.4373449933535234`}, {-2.1875, \
-1.3247595264191645`}}], 
      PolygonBox[{{-2.084292589556064, -1.4374999810329407`}, \
{-2.230251642536255, -1.4373449933535234`}, {-2.0970571419134454`, \
-1.3622221848584006`}, {-2.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-2.0970571419134454`, -1.3622221848584006`}, {-2., \
-1.375}, {-2.084292589556064, -1.4374999810329407`}, {-2.0970571419134454`, \
-1.3622221848584006`}}], 
      PolygonBox[{{-1.999865158168957, -1.4375}, {-2.084292589556064, \
-1.4374999810329407`}, {-2., -1.375}, {-1.999865158168957, -1.4375}}], 
      PolygonBox[{{-2., -1.375}, {-1.9029428580865548`, \
-1.3622221848584006`}, {-1.999865158168957, -1.4375}, {-2., -1.375}}], 
      PolygonBox[{{-1.9157074104439469`, -1.4374999810329407`}, \
{-1.999865158168957, -1.4375}, {-1.9029428580865548`, -1.3622221848584006`}, \
{-1.9157074104439469`, -1.4374999810329407`}}], 
      PolygonBox[{{-1.9029428580865548`, -1.3622221848584006`}, \
{-1.8125000000000002`, -1.3247595264191645`}, {-1.9157074104439469`, \
-1.4374999810329407`}, {-1.9029428580865548`, -1.3622221848584006`}}], 
      PolygonBox[{{-1.7697483574637454`, -1.4373449933535234`}, \
{-1.9157074104439469`, -1.4374999810329407`}, {-1.8125000000000002`, \
-1.3247595264191645`}, {-1.7697483574637454`, -1.4373449933535234`}}], 
      PolygonBox[{{-1.8125000000000002`, -1.3247595264191645`}, \
{-1.7348349570550448`, -1.2651650429449552`}, {-1.7697483574637454`, \
-1.4373449933535234`}, {-1.8125000000000002`, -1.3247595264191645`}}], 
      PolygonBox[{{-1.5950572556670028`, -1.4049427443329972`}, \
{-1.7697483574637454`, -1.4373449933535234`}, {-1.7348349570550448`, \
-1.2651650429449552`}, {-1.5950572556670028`, -1.4049427443329972`}}], 
      PolygonBox[{{-1.7348349570550448`, -1.2651650429449552`}, \
{-1.7348349570550448`, -1.2651650429449552`}, {-1.5950572556670028`, \
-1.4049427443329972`}, {-1.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{-1.5950572556670028`, -1.4049427443329972`}, \
{-1.5950572556670028`, -1.4049427443329972`}, {-1.7348349570550448`, \
-1.2651650429449552`}, {-1.5950572556670028`, -1.4049427443329972`}}], 
      PolygonBox[{{-1.5950572556670028`, -1.4049427443329972`}, \
{-1.5626550066464766`, -1.230251642536255}, {-1.5, -1.5}, \
{-1.5950572556670028`, -1.4049427443329972`}}], 
      PolygonBox[{{-1.5, -1.3576627826493677`}, {-1.5, -1.5}, \
{-1.5626550066464766`, -1.230251642536255}, {-1.5, -1.3576627826493677`}}], 
      PolygonBox[{{-1.5626550066464766`, -1.230251642536255}, \
{-1.5625000189670593`, -1.0842925895560618`}, {-1.5, -1.3576627826493677`}, \
{-1.5626550066464766`, -1.230251642536255}}], 
      PolygonBox[{{-1.5, -1.20590900530174}, {-1.5, -1.3576627826493677`}, \
{-1.5625000189670593`, -1.0842925895560618`}, {-1.5, -1.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, -1.0842925895560618`}, {-1.5625, \
-1.}, {-1.5, -1.20590900530174}, {-1.5625000189670593`, \
-1.0842925895560618`}}], 
      PolygonBox[{{-1.5, -1.}, {-1.5, -1.20590900530174}, {-1.5625, -1.}, \
{-1.5, -1.}}], 
      PolygonBox[{{-1.5625, -1.}, {-1.5625000189670593`, \
-0.9157074104439382}, {-1.5, -1.}, {-1.5625, -1.}}], 
      PolygonBox[{{-1.5, -0.79409099469826}, {-1.5, -1.}, \
{-1.5625000189670593`, -0.9157074104439382}, {-1.5, -0.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, -0.9157074104439382}, \
{-1.5626550066464766`, -0.7697483574637449}, {-1.5, -0.79409099469826}, \
{-1.5625000189670593`, -0.9157074104439382}}], 
      PolygonBox[{{-1.5, -0.6423372173506324}, {-1.5, -0.79409099469826}, \
{-1.5626550066464766`, -0.7697483574637449}, {-1.5, -0.6423372173506324}}], 
      PolygonBox[{{-1.5626550066464766`, -0.7697483574637449}, \
{-1.5950572556670028`, -0.5950572556670028}, {-1.5, -0.6423372173506324}, \
{-1.5626550066464766`, -0.7697483574637449}}], 
      PolygonBox[{{-1.508553435038814, -0.508553435038814}, {-1.5, \
-0.6423372173506324}, {-1.5950572556670028`, -0.5950572556670028}, \
{-1.508553435038814, -0.508553435038814}}], 
      PolygonBox[{{-1.5950572556670028`, -0.5950572556670028}, \
{-1.769748357463745, -0.5626550066464766}, {-1.508553435038814, \
-0.508553435038814}, {-1.5950572556670028`, -0.5950572556670028}}], 
      PolygonBox[{{-1.6423372173506319`, -0.5}, {-1.508553435038814, \
-0.508553435038814}, {-1.769748357463745, -0.5626550066464766}, \
{-1.6423372173506319`, -0.5}}], 
      PolygonBox[{{-1.769748357463745, -0.5626550066464766}, \
{-1.9157074104439396`, -0.5625000189670593}, {-1.6423372173506319`, -0.5}, \
{-1.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{-1.7940909946267443`, -0.5}, {-1.6423372173506319`, -0.5}, \
{-1.9157074104439396`, -0.5625000189670593}, {-1.7940909946267443`, -0.5}}], 
      PolygonBox[{{-1.9157074104439396`, -0.5625000189670593}, \
{-1.9998944727795123`, -0.5625}, {-1.7940909946267443`, -0.5}, \
{-1.9157074104439396`, -0.5625000189670593}}], 
      PolygonBox[{{-1.92205804197311, -0.5}, {-1.7940909946267443`, -0.5}, \
{-1.9998944727795123`, -0.5625}, {-1.92205804197311, -0.5}}], 
      PolygonBox[{{-1.9998944727795123`, -0.5625}, {-2.084292589556057, \
-0.5625000189670593}, {-1.92205804197311, -0.5}, {-1.9998944727795123`, \
-0.5625}}], 
      PolygonBox[{{-2.2059090053044454`, -0.5}, {-1.92205804197311, -0.5}, \
{-2.084292589556057, -0.5625000189670593}, {-2.2059090053044454`, -0.5}}], 
      PolygonBox[{{-2.084292589556057, -0.5625000189670593}, \
{-2.230251642536255, -0.5626550066464766}, {-2.2059090053044454`, -0.5}, \
{-2.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-2.357662782649366, -0.5}, {-2.2059090053044454`, -0.5}, \
{-2.230251642536255, -0.5626550066464766}, {-2.357662782649366, -0.5}}], 
      PolygonBox[{{-2.230251642536255, -0.5626550066464766}, \
{-2.404942744332997, -0.5950572556670028}, {-2.357662782649366, -0.5}, \
{-2.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-1.5, -0.5}, {-2.357662782649366, -0.5}, \
{-2.404942744332997, -0.5950572556670028}, {-1.5, -0.5}}], 
      PolygonBox[{{-2.404942744332997, -0.5950572556670028}, \
{-2.4373449933535234`, -0.7697483574637446}, {-1.5, -0.5}, \
{-2.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{-2.5, -0.642337217350631}, {-1.5, -0.5}, \
{-2.4373449933535234`, -0.7697483574637446}, {-2.5, -0.642337217350631}}], 
      PolygonBox[{{-2.4373449933535234`, -0.7697483574637446}, \
{-2.437499981032941, -0.9157074104439377}, {-2.5, -0.642337217350631}, \
{-2.4373449933535234`, -0.7697483574637446}}], 
      PolygonBox[{{-2.5, -0.7940909947171011}, {-2.5, -0.642337217350631}, \
{-2.437499981032941, -0.9157074104439377}, {-2.5, -0.7940909947171011}}], 
      PolygonBox[{{-2.437499981032941, -0.9157074104439377}, {-2.4375, \
-0.9998768219370047}, {-2.5, -0.7940909947171011}, {-2.437499981032941, \
-0.9157074104439377}}], 
      PolygonBox[{{-2.5, -0.9193213332412997}, {-2.5, -0.7940909947171011}, \
{-2.4375, -0.9998768219370047}, {-2.5, -0.9193213332412997}}], 
      PolygonBox[{{-2.4375, -0.9998768219370047}, {-2.437499981032941, \
-1.084292589556055}, {-2.5, -0.9193213332412997}, {-2.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-2.5, -1.2059090051452785`}, {-2.5, -0.9193213332412997}, \
{-2.437499981032941, -1.084292589556055}, {-2.5, -1.2059090051452785`}}], 
      PolygonBox[{{-2.437499981032941, -1.084292589556055}, \
{-2.4373449933535234`, -1.2302516425362549`}, {-2.5, -1.2059090051452785`}, \
{-2.437499981032941, -1.084292589556055}}], 
      PolygonBox[{{-2.5, -1.3576627826493652`}, {-2.5, -1.2059090051452785`}, \
{-2.4373449933535234`, -1.2302516425362549`}, {-2.5, -1.3576627826493652`}}], 
      PolygonBox[{{-2.4373449933535234`, -1.2302516425362549`}, \
{-2.404942744332997, -1.4049427443329972`}, {-2.5, -1.3576627826493652`}, \
{-2.4373449933535234`, -1.2302516425362549`}}], 
      PolygonBox[{{-2.5, -0.5}, {-2.5, -1.3576627826493652`}, \
{-2.404942744332997, -1.4049427443329972`}, {-2.5, -0.5}}], 
      PolygonBox[{{-2.404942744332997, -1.4049427443329972`}, \
{-2.230251642536255, -1.4373449933535234`}, {-2.5, -0.5}, \
{-2.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{-2.5, -1.5}, {-2.5, -0.5}, {-2.230251642536255, \
-1.4373449933535234`}, {-2.5, -1.5}}], 
      PolygonBox[{{-2.230251642536255, -1.4373449933535234`}, \
{-2.084292589556064, -1.4374999810329407`}, {-2.5, -1.5}, \
{-2.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-2.205909005566828, -1.5}, {-2.5, -1.5}, \
{-2.084292589556064, -1.4374999810329407`}, {-2.205909005566828, -1.5}}], 
      PolygonBox[{{-2.084292589556064, -1.4374999810329407`}, \
{-1.999865158168957, -1.4375}, {-2.205909005566828, -1.5}, \
{-2.084292589556064, -1.4374999810329407`}}], 
      PolygonBox[{{-1.9176761295989384`, -1.5}, {-2.205909005566828, -1.5}, \
{-1.999865158168957, -1.4375}, {-1.9176761295989384`, -1.5}}], 
      PolygonBox[{{-1.999865158168957, -1.4375}, {-1.9157074104439469`, \
-1.4374999810329407`}, {-1.9176761295989384`, -1.5}, {-1.999865158168957, \
-1.4375}}], 
      PolygonBox[{{-1.7940909946396026`, -1.5}, {-1.9176761295989384`, -1.5}, \
{-1.9157074104439469`, -1.4374999810329407`}, {-1.7940909946396026`, -1.5}}], 
      PolygonBox[{{-1.9157074104439469`, -1.4374999810329407`}, \
{-1.7697483574637454`, -1.4373449933535234`}, {-1.7940909946396026`, -1.5}, \
{-1.9157074104439469`, -1.4374999810329407`}}], 
      PolygonBox[{{-1.642337217350629, -1.5}, {-1.7940909946396026`, -1.5}, \
{-1.7697483574637454`, -1.4373449933535234`}, {-1.642337217350629, -1.5}}], 
      PolygonBox[{{-1.7697483574637454`, -1.4373449933535234`}, \
{-1.5950572556670028`, -1.4049427443329972`}, {-1.642337217350629, -1.5}, \
{-1.7697483574637454`, -1.4373449933535234`}}], 
      PolygonBox[{{-1.5, -1.5}, {-1.642337217350629, -1.5}, \
{-1.5950572556670028`, -1.4049427443329972`}, {-1.5, -1.5}}], 
      PolygonBox[{{-1.5950572556670028`, -1.4049427443329972`}, \
{-1.5950572556670028`, -1.4049427443329972`}, {-1.5, -1.5}, \
{-1.5950572556670028`, -1.4049427443329972`}}], 
      PolygonBox[{{-1.5, -1.5}, {-1.5, -1.5}, {-1.5950572556670028`, \
-1.4049427443329972`}, {-1.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, 0.}, {-2.4791666666666665`, 0.}, {-2.4583333333333335`, 
       0.}, {-2.4375, 0.}, {-2.4166666666666665`, 0.}, {-2.3958333333333335`, 
       0.}, {-2.375, 0.}, {-2.375, 0.}, {-2.3958333333333335`, 
       0.}, {-2.4166666666666665`, 0.}, {-2.4375, 0.}, {-2.4583333333333335`, 
       0.}, {-2.4791666666666665`, 0.}, {-2.5, 0.}, {-2.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, 0.}, {-1.6041666666666667`, 
       0.}, {-1.5833333333333333`, 0.}, {-1.5625, 0.}, {-1.5416666666666667`, 
       0.}, {-1.5208333333333335`, 0.}, {-1.5, 0.}, {-1.5, 
       0.}, {-1.5208333333333333`, 0.}, {-1.5416666666666667`, 0.}, {-1.5625, 
       0.}, {-1.5833333333333333`, 0.}, {-1.6041666666666665`, 0.}, {-1.625, 
       0.}, {-1.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -0.5}, {-2., -0.4791666666666667}, {-2., \
-0.4583333333333333}, {-2., -0.4375}, {-2., -0.4166666666666667}, {-2., \
-0.39583333333333337`}, {-2., -0.375}, {-2., -0.375}, {-2., \
-0.3958333333333333}, {-2., -0.4166666666666667}, {-2., -0.4375}, {-2., \
-0.4583333333333333}, {-2., -0.47916666666666663`}, {-2., -0.5}, {-2., \
-0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 0.375}, {-2., 0.3958333333333333}, {-2., 
       0.4166666666666667}, {-2., 0.4375}, {-2., 0.4583333333333333}, {-2., 
       0.47916666666666663`}, {-2., 0.5}, {-2., 0.5}, {-2., 
       0.4791666666666667}, {-2., 0.4583333333333333}, {-2., 0.4375}, {-2., 
       0.4166666666666667}, {-2., 0.39583333333333337`}, {-2., 0.375}, {-2., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, 0.}, {-2.25, 0.}, {-2.125, 0.}, {-2., 0.}, {-1.875, 
       0.}, {-1.75, 0.}, {-1.625, 0.}, {-1.625, 0.}, {-1.75, 0.}, {-1.875, 
       0.}, {-2., 0.}, {-2.125, 0.}, {-2.25, 0.}, {-2.375, 0.}, {-2.375, 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -0.375}, {-2., -0.25}, {-2., -0.125}, {-2., 0.}, {-2., 
       0.125}, {-2., 0.25}, {-2., 0.375}, {-2., 0.375}, {-2., 0.25}, {-2., 
       0.125}, {-2., 
       0.}, {-2., -0.125}, {-2., -0.25}, {-2., -0.375}, {-2., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9sNYOjGLmsJMfu2/0RmzaM+NHfYLCvO/nDj7
a/9/MDhuf0rlhM+jg7/338y5f6bsxwV7iK6/+xssnfTunLhin2R+y7Sk6N9+
//6yr0v1rkPlGQ5AqBv2/k+Enh49xnAgAFm+gfEATP/st7Nv8skzHbgFNd/A
/USr9EymAyxghSfsX11ct+/KU6YDD6Dug5jLfICra56PZWWXDUz+HER+P0z/
H4j798+Bmn8dYv5+mP11EPv3w9znB3HffjT370+G+g/q/v2MUP83QfXDwgfq
/v2w8GODuH8/LHzfQd0HC3+I+2ftAQBxOL6f
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kPoB/arwOAXnB8KBn/hfKiGA6jyjAdQ9TMd
QFXPQpAfBjbnKhr/KJp6GGA5EAKR34/Kv7ofVf0DDP5qVPftR3P/fjT/7Q9D
9T9UPzx8oPQPgvwwFPfB+EfR1MPAj/0hKP6H8a/ao6p/YA8A1QZudg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, -0.2651650429449553}, \
{-1.6752404735808355`, -0.1875}, {-1.5950572556670028`, -0.4049427443329971}, \
{-1.7348349570550448`, -0.2651650429449553}}], 
      PolygonBox[{{-1.5626550066464766`, -0.23025164253625516`}, \
{-1.5950572556670028`, -0.4049427443329971}, {-1.6752404735808355`, -0.1875}, \
{-1.5626550066464766`, -0.23025164253625516`}}], 
      PolygonBox[{{-1.6752404735808355`, -0.1875}, {-1.6377778151415994`, \
-0.0970571419134453}, {-1.5626550066464766`, -0.23025164253625516`}, \
{-1.6752404735808355`, -0.1875}}], 
      PolygonBox[{{-1.5625000189670593`, -0.08429258955606181}, \
{-1.5626550066464766`, -0.23025164253625516`}, {-1.6377778151415994`, \
-0.0970571419134453}, {-1.5625000189670593`, -0.08429258955606181}}], 
      PolygonBox[{{-1.6377778151415994`, -0.0970571419134453}, {-1.625, 
       0.}, {-1.5625000189670593`, -0.08429258955606181}, \
{-1.6377778151415994`, -0.0970571419134453}}], 
      PolygonBox[{{-1.5625, 
       0.}, {-1.5625000189670593`, -0.08429258955606181}, {-1.625, 
       0.}, {-1.5625, 0.}}], 
      PolygonBox[{{-1.625, 0.}, {-1.6377778151415994`, 
       0.09705714191344525}, {-1.5625, 0.}, {-1.625, 0.}}], 
      PolygonBox[{{-1.5625000189670593`, 0.08429258955606177}, {-1.5625, 
       0.}, {-1.6377778151415994`, 
       0.09705714191344525}, {-1.5625000189670593`, 0.08429258955606177}}], 
      PolygonBox[{{-1.6377778151415994`, 
       0.09705714191344525}, {-1.6752404735808355`, 
       0.18749999999999994`}, {-1.5625000189670593`, 
       0.08429258955606177}, {-1.6377778151415994`, 0.09705714191344525}}], 
      PolygonBox[{{-1.5626550066464766`, 
       0.23025164253625502`}, {-1.5625000189670593`, 
       0.08429258955606177}, {-1.6752404735808355`, 
       0.18749999999999994`}, {-1.5626550066464766`, 0.23025164253625502`}}], 
      PolygonBox[{{-1.6752404735808355`, 
       0.18749999999999994`}, {-1.7348349570550448`, 
       0.2651650429449553}, {-1.5626550066464766`, 
       0.23025164253625502`}, {-1.6752404735808355`, 0.18749999999999994`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       0.40494274433299715`}, {-1.5626550066464766`, 
       0.23025164253625502`}, {-1.7348349570550448`, 
       0.2651650429449553}, {-1.5950572556670028`, 0.40494274433299715`}}], 
      PolygonBox[{{-1.7348349570550448`, 0.2651650429449553}, {-1.8125, 
       0.3247595264191645}, {-1.5950572556670028`, 
       0.40494274433299715`}, {-1.7348349570550448`, 0.2651650429449553}}], 
      PolygonBox[{{-1.769748357463745, 
       0.4373449933535234}, {-1.5950572556670028`, 
       0.40494274433299715`}, {-1.8125, 
       0.3247595264191645}, {-1.769748357463745, 0.4373449933535234}}], 
      PolygonBox[{{-1.8125, 0.3247595264191645}, {-1.9029428580865546`, 
       0.3622221848584006}, {-1.769748357463745, 
       0.4373449933535234}, {-1.8125, 0.3247595264191645}}], 
      PolygonBox[{{-1.9157074104439396`, 
       0.4374999810329408}, {-1.769748357463745, 
       0.4373449933535234}, {-1.9029428580865546`, 
       0.3622221848584006}, {-1.9157074104439396`, 0.4374999810329408}}], 
      PolygonBox[{{-1.9029428580865546`, 0.3622221848584006}, {-2., 
       0.375}, {-1.9157074104439396`, 
       0.4374999810329408}, {-1.9029428580865546`, 0.3622221848584006}}], 
      PolygonBox[{{-1.9998944727795123`, 0.4375}, {-1.9157074104439396`, 
       0.4374999810329408}, {-2., 0.375}, {-1.9998944727795123`, 0.4375}}], 
      PolygonBox[{{-2., 0.375}, {-2.097057141913445, 
       0.36222218485840063`}, {-1.9998944727795123`, 0.4375}, {-2., 0.375}}], 
      PolygonBox[{{-2.084292589556057, 
       0.4374999810329408}, {-1.9998944727795123`, 
       0.4375}, {-2.097057141913445, 
       0.36222218485840063`}, {-2.084292589556057, 0.4374999810329408}}], 
      PolygonBox[{{-2.097057141913445, 0.36222218485840063`}, {-2.1875, 
       0.3247595264191645}, {-2.084292589556057, 
       0.4374999810329408}, {-2.097057141913445, 0.36222218485840063`}}], 
      PolygonBox[{{-2.230251642536255, 
       0.4373449933535234}, {-2.084292589556057, 
       0.4374999810329408}, {-2.1875, 
       0.3247595264191645}, {-2.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{-2.1875, 0.3247595264191645}, {-2.2651650429449552`, 
       0.26516504294495535`}, {-2.230251642536255, 
       0.4373449933535234}, {-2.1875, 0.3247595264191645}}], 
      PolygonBox[{{-2.404942744332997, 
       0.40494274433299715`}, {-2.230251642536255, 
       0.4373449933535234}, {-2.2651650429449552`, 
       0.26516504294495535`}, {-2.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{-2.2651650429449552`, 
       0.26516504294495535`}, {-2.3247595264191645`, 
       0.1875000000000001}, {-2.404942744332997, 
       0.40494274433299715`}, {-2.2651650429449552`, 0.26516504294495535`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       0.2302516425362554}, {-2.404942744332997, 
       0.40494274433299715`}, {-2.3247595264191645`, 
       0.1875000000000001}, {-2.4373449933535234`, 0.2302516425362554}}], 
      PolygonBox[{{-2.3247595264191645`, 
       0.1875000000000001}, {-2.3622221848584006`, 
       0.09705714191344539}, {-2.4373449933535234`, 
       0.2302516425362554}, {-2.3247595264191645`, 0.1875000000000001}}], 
      PolygonBox[{{-2.437499981032941, 
       0.08429258955606238}, {-2.4373449933535234`, 
       0.2302516425362554}, {-2.3622221848584006`, 
       0.09705714191344539}, {-2.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-2.3622221848584006`, 0.09705714191344539}, {-2.375, 
       2.1245770866179924`*^-16}, {-2.437499981032941, 
       0.08429258955606238}, {-2.3622221848584006`, 0.09705714191344539}}], 
      PolygonBox[{{-2.4375, 0.00012317806299537147`}, {-2.437499981032941, 
       0.08429258955606238}, {-2.375, 2.1245770866179924`*^-16}, {-2.4375, 
       0.00012317806299537147`}}], 
      PolygonBox[{{-2.375, 
       2.1245770866179924`*^-16}, {-2.3622221848584006`, \
-0.09705714191344514}, {-2.4375, 0.00012317806299537147`}, {-2.375, 
       2.1245770866179924`*^-16}}], 
      PolygonBox[{{-2.437499981032941, -0.084292589556055}, {-2.4375, 
       0.00012317806299537147`}, {-2.3622221848584006`, \
-0.09705714191344514}, {-2.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-2.3622221848584006`, -0.09705714191344514}, \
{-2.3247595264191645`, -0.18749999999999978`}, {-2.437499981032941, \
-0.084292589556055}, {-2.3622221848584006`, -0.09705714191344514}}], 
      PolygonBox[{{-2.4373449933535234`, -0.23025164253625477`}, \
{-2.437499981032941, -0.084292589556055}, {-2.3247595264191645`, \
-0.18749999999999978`}, {-2.4373449933535234`, -0.23025164253625477`}}], 
      PolygonBox[{{-2.3247595264191645`, -0.18749999999999978`}, \
{-2.2651650429449552`, -0.2651650429449553}, {-2.4373449933535234`, \
-0.23025164253625477`}, {-2.3247595264191645`, -0.18749999999999978`}}], 
      PolygonBox[{{-2.404942744332997, -0.4049427443329971}, \
{-2.4373449933535234`, -0.23025164253625477`}, {-2.2651650429449552`, \
-0.2651650429449553}, {-2.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-2.2651650429449552`, -0.2651650429449553}, {-2.1875, \
-0.3247595264191644}, {-2.404942744332997, -0.4049427443329971}, \
{-2.2651650429449552`, -0.2651650429449553}}], 
      PolygonBox[{{-2.230251642536255, -0.4373449933535234}, \
{-2.404942744332997, -0.4049427443329971}, {-2.1875, -0.3247595264191644}, \
{-2.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{-2.1875, -0.3247595264191644}, {-2.0970571419134454`, \
-0.3622221848584005}, {-2.230251642536255, -0.4373449933535234}, {-2.1875, \
-0.3247595264191644}}], 
      PolygonBox[{{-2.084292589556064, -0.4374999810329408}, \
{-2.230251642536255, -0.4373449933535234}, {-2.0970571419134454`, \
-0.3622221848584005}, {-2.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-2.0970571419134454`, -0.3622221848584005}, {-2., -0.375}, \
{-2.084292589556064, -0.4374999810329408}, {-2.0970571419134454`, \
-0.3622221848584005}}], 
      PolygonBox[{{-1.999865158168957, -0.4375}, {-2.084292589556064, \
-0.4374999810329408}, {-2., -0.375}, {-1.999865158168957, -0.4375}}], 
      PolygonBox[{{-2., -0.375}, {-1.9029428580865548`, \
-0.36222218485840063`}, {-1.999865158168957, -0.4375}, {-2., -0.375}}], 
      PolygonBox[{{-1.9157074104439469`, -0.4374999810329408}, \
{-1.999865158168957, -0.4375}, {-1.9029428580865548`, -0.36222218485840063`}, \
{-1.9157074104439469`, -0.4374999810329408}}], 
      PolygonBox[{{-1.9029428580865548`, -0.36222218485840063`}, \
{-1.8125000000000002`, -0.3247595264191646}, {-1.9157074104439469`, \
-0.4374999810329408}, {-1.9029428580865548`, -0.36222218485840063`}}], 
      PolygonBox[{{-1.7697483574637454`, -0.4373449933535234}, \
{-1.9157074104439469`, -0.4374999810329408}, {-1.8125000000000002`, \
-0.3247595264191646}, {-1.7697483574637454`, -0.4373449933535234}}], 
      PolygonBox[{{-1.8125000000000002`, -0.3247595264191646}, \
{-1.7348349570550448`, -0.26516504294495535`}, {-1.7697483574637454`, \
-0.4373449933535234}, {-1.8125000000000002`, -0.3247595264191646}}], 
      PolygonBox[{{-1.5950572556670028`, -0.40494274433299715`}, \
{-1.7697483574637454`, -0.4373449933535234}, {-1.7348349570550448`, \
-0.26516504294495535`}, {-1.5950572556670028`, -0.40494274433299715`}}], 
      PolygonBox[{{-1.7348349570550448`, -0.26516504294495535`}, \
{-1.7348349570550448`, -0.2651650429449553}, {-1.5950572556670028`, \
-0.40494274433299715`}, {-1.7348349570550448`, -0.26516504294495535`}}], 
      PolygonBox[{{-1.5950572556670028`, -0.4049427443329971}, \
{-1.5950572556670028`, -0.40494274433299715`}, {-1.7348349570550448`, \
-0.2651650429449553}, {-1.5950572556670028`, -0.4049427443329971}}], 
      PolygonBox[{{-1.5950572556670028`, -0.4049427443329971}, \
{-1.5626550066464766`, -0.23025164253625516`}, {-1.5, -0.5}, \
{-1.5950572556670028`, -0.4049427443329971}}], 
      PolygonBox[{{-1.5, -0.3576627826493677}, {-1.5, -0.5}, \
{-1.5626550066464766`, -0.23025164253625516`}, {-1.5, -0.3576627826493677}}], 
      PolygonBox[{{-1.5626550066464766`, -0.23025164253625516`}, \
{-1.5625000189670593`, -0.08429258955606181}, {-1.5, -0.3576627826493677}, \
{-1.5626550066464766`, -0.23025164253625516`}}], 
      PolygonBox[{{-1.5, -0.20590900530173997`}, {-1.5, -0.3576627826493677}, \
{-1.5625000189670593`, -0.08429258955606181}, {-1.5, -0.20590900530173997`}}],
       PolygonBox[{{-1.5625000189670593`, -0.08429258955606181}, {-1.5625, 
       0.}, {-1.5, -0.20590900530173997`}, {-1.5625000189670593`, \
-0.08429258955606181}}], 
      PolygonBox[{{-1.5, 0.}, {-1.5, -0.20590900530173997`}, {-1.5625, 
       0.}, {-1.5, 0.}}], 
      PolygonBox[{{-1.5625, 0.}, {-1.5625000189670593`, 
       0.08429258955606177}, {-1.5, 0.}, {-1.5625, 0.}}], 
      PolygonBox[{{-1.5, 0.20590900530173992`}, {-1.5, 
       0.}, {-1.5625000189670593`, 0.08429258955606177}, {-1.5, 
       0.20590900530173992`}}], 
      PolygonBox[{{-1.5625000189670593`, 
       0.08429258955606177}, {-1.5626550066464766`, 
       0.23025164253625502`}, {-1.5, 
       0.20590900530173992`}, {-1.5625000189670593`, 0.08429258955606177}}], 
      PolygonBox[{{-1.5, 0.35766278264936757`}, {-1.5, 
       0.20590900530173992`}, {-1.5626550066464766`, 
       0.23025164253625502`}, {-1.5, 0.35766278264936757`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       0.23025164253625502`}, {-1.5950572556670028`, 
       0.40494274433299715`}, {-1.5, 
       0.35766278264936757`}, {-1.5626550066464766`, 0.23025164253625502`}}], 
      PolygonBox[{{-1.508553435038814, 0.491446564961186}, {-1.5, 
       0.35766278264936757`}, {-1.5950572556670028`, 
       0.40494274433299715`}, {-1.508553435038814, 0.491446564961186}}], 
      PolygonBox[{{-1.5950572556670028`, 
       0.40494274433299715`}, {-1.769748357463745, 
       0.4373449933535234}, {-1.508553435038814, 
       0.491446564961186}, {-1.5950572556670028`, 0.40494274433299715`}}], 
      PolygonBox[{{-1.6423372173506319`, 0.5}, {-1.508553435038814, 
       0.491446564961186}, {-1.769748357463745, 
       0.4373449933535234}, {-1.6423372173506319`, 0.5}}], 
      PolygonBox[{{-1.769748357463745, 
       0.4373449933535234}, {-1.9157074104439396`, 
       0.4374999810329408}, {-1.6423372173506319`, 0.5}, {-1.769748357463745, 
       0.4373449933535234}}], 
      PolygonBox[{{-1.7940909946267443`, 0.5}, {-1.6423372173506319`, 
       0.5}, {-1.9157074104439396`, 
       0.4374999810329408}, {-1.7940909946267443`, 0.5}}], 
      PolygonBox[{{-1.9157074104439396`, 
       0.4374999810329408}, {-1.9998944727795123`, 
       0.4375}, {-1.7940909946267443`, 0.5}, {-1.9157074104439396`, 
       0.4374999810329408}}], 
      PolygonBox[{{-1.92205804197311, 0.5}, {-1.7940909946267443`, 
       0.5}, {-1.9998944727795123`, 0.4375}, {-1.92205804197311, 0.5}}], 
      PolygonBox[{{-1.9998944727795123`, 0.4375}, {-2.084292589556057, 
       0.4374999810329408}, {-1.92205804197311, 0.5}, {-1.9998944727795123`, 
       0.4375}}], 
      PolygonBox[{{-2.2059090053044454`, 0.5}, {-1.92205804197311, 
       0.5}, {-2.084292589556057, 0.4374999810329408}, {-2.2059090053044454`, 
       0.5}}], PolygonBox[{{-2.084292589556057, 
       0.4374999810329408}, {-2.230251642536255, 
       0.4373449933535234}, {-2.2059090053044454`, 0.5}, {-2.084292589556057, 
       0.4374999810329408}}], 
      PolygonBox[{{-2.357662782649366, 0.5}, {-2.2059090053044454`, 
       0.5}, {-2.230251642536255, 0.4373449933535234}, {-2.357662782649366, 
       0.5}}], PolygonBox[{{-2.230251642536255, 
       0.4373449933535234}, {-2.404942744332997, 
       0.40494274433299715`}, {-2.357662782649366, 0.5}, {-2.230251642536255, 
       0.4373449933535234}}], 
      PolygonBox[{{-1.5, 0.5}, {-2.357662782649366, 0.5}, {-2.404942744332997,
        0.40494274433299715`}, {-1.5, 0.5}}], 
      PolygonBox[{{-2.404942744332997, 
       0.40494274433299715`}, {-2.4373449933535234`, 
       0.2302516425362554}, {-1.5, 0.5}, {-2.404942744332997, 
       0.40494274433299715`}}], 
      PolygonBox[{{-2.5, 0.357662782649369}, {-1.5, 
       0.5}, {-2.4373449933535234`, 0.2302516425362554}, {-2.5, 
       0.357662782649369}}], 
      PolygonBox[{{-2.4373449933535234`, 
       0.2302516425362554}, {-2.437499981032941, 0.08429258955606238}, {-2.5, 
       0.357662782649369}, {-2.4373449933535234`, 0.2302516425362554}}], 
      PolygonBox[{{-2.5, 0.20590900528289896`}, {-2.5, 
       0.357662782649369}, {-2.437499981032941, 0.08429258955606238}, {-2.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{-2.437499981032941, 0.08429258955606238}, {-2.4375, 
       0.00012317806299537147`}, {-2.5, 
       0.20590900528289896`}, {-2.437499981032941, 0.08429258955606238}}], 
      PolygonBox[{{-2.5, 0.08067866675870025}, {-2.5, 
       0.20590900528289896`}, {-2.4375, 0.00012317806299537147`}, {-2.5, 
       0.08067866675870025}}], 
      PolygonBox[{{-2.4375, 
       0.00012317806299537147`}, {-2.437499981032941, -0.084292589556055}, \
{-2.5, 0.08067866675870025}, {-2.4375, 0.00012317806299537147`}}], 
      PolygonBox[{{-2.5, -0.20590900514527852`}, {-2.5, 
       0.08067866675870025}, {-2.437499981032941, -0.084292589556055}, {-2.5, \
-0.20590900514527852`}}], 
      PolygonBox[{{-2.437499981032941, -0.084292589556055}, \
{-2.4373449933535234`, -0.23025164253625477`}, {-2.5, -0.20590900514527852`}, \
{-2.437499981032941, -0.084292589556055}}], 
      PolygonBox[{{-2.5, -0.35766278264936535`}, {-2.5, \
-0.20590900514527852`}, {-2.4373449933535234`, -0.23025164253625477`}, {-2.5, \
-0.35766278264936535`}}], 
      PolygonBox[{{-2.4373449933535234`, -0.23025164253625477`}, \
{-2.404942744332997, -0.4049427443329971}, {-2.5, -0.35766278264936535`}, \
{-2.4373449933535234`, -0.23025164253625477`}}], 
      PolygonBox[{{-2.5, 
       0.5}, {-2.5, -0.35766278264936535`}, {-2.404942744332997, \
-0.4049427443329971}, {-2.5, 0.5}}], 
      PolygonBox[{{-2.404942744332997, -0.4049427443329971}, \
{-2.230251642536255, -0.4373449933535234}, {-2.5, 
       0.5}, {-2.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{-2.5, -0.5}, {-2.5, 
       0.5}, {-2.230251642536255, -0.4373449933535234}, {-2.5, -0.5}}], 
      PolygonBox[{{-2.230251642536255, -0.4373449933535234}, \
{-2.084292589556064, -0.4374999810329408}, {-2.5, -0.5}, {-2.230251642536255, \
-0.4373449933535234}}], 
      PolygonBox[{{-2.205909005566828, -0.5}, {-2.5, -0.5}, \
{-2.084292589556064, -0.4374999810329408}, {-2.205909005566828, -0.5}}], 
      PolygonBox[{{-2.084292589556064, -0.4374999810329408}, \
{-1.999865158168957, -0.4375}, {-2.205909005566828, -0.5}, \
{-2.084292589556064, -0.4374999810329408}}], 
      PolygonBox[{{-1.9176761295989384`, -0.5}, {-2.205909005566828, -0.5}, \
{-1.999865158168957, -0.4375}, {-1.9176761295989384`, -0.5}}], 
      PolygonBox[{{-1.999865158168957, -0.4375}, {-1.9157074104439469`, \
-0.4374999810329408}, {-1.9176761295989384`, -0.5}, {-1.999865158168957, \
-0.4375}}], 
      PolygonBox[{{-1.7940909946396026`, -0.5}, {-1.9176761295989384`, -0.5}, \
{-1.9157074104439469`, -0.4374999810329408}, {-1.7940909946396026`, -0.5}}], 
      PolygonBox[{{-1.9157074104439469`, -0.4374999810329408}, \
{-1.7697483574637454`, -0.4373449933535234}, {-1.7940909946396026`, -0.5}, \
{-1.9157074104439469`, -0.4374999810329408}}], 
      PolygonBox[{{-1.642337217350629, -0.5}, {-1.7940909946396026`, -0.5}, \
{-1.7697483574637454`, -0.4373449933535234}, {-1.642337217350629, -0.5}}], 
      PolygonBox[{{-1.7697483574637454`, -0.4373449933535234}, \
{-1.5950572556670028`, -0.40494274433299715`}, {-1.642337217350629, -0.5}, \
{-1.7697483574637454`, -0.4373449933535234}}], 
      PolygonBox[{{-1.5, -0.5}, {-1.642337217350629, -0.5}, \
{-1.5950572556670028`, -0.40494274433299715`}, {-1.5, -0.5}}], 
      PolygonBox[{{-1.5950572556670028`, -0.40494274433299715`}, \
{-1.5950572556670028`, -0.4049427443329971}, {-1.5, -0.5}, \
{-1.5950572556670028`, -0.40494274433299715`}}], 
      PolygonBox[{{-1.5, -0.5}, {-1.5, -0.5}, {-1.5950572556670028`, \
-0.4049427443329971}, {-1.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, 1.}, {-2.4791666666666665`, 1.}, {-2.4583333333333335`, 
       1.}, {-2.4375, 1.}, {-2.4166666666666665`, 1.}, {-2.3958333333333335`, 
       1.}, {-2.375, 1.}, {-2.375, 1.}, {-2.3958333333333335`, 
       1.}, {-2.4166666666666665`, 1.}, {-2.4375, 1.}, {-2.4583333333333335`, 
       1.}, {-2.4791666666666665`, 1.}, {-2.5, 1.}, {-2.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, 1.}, {-1.6041666666666667`, 
       1.}, {-1.5833333333333333`, 1.}, {-1.5625, 1.}, {-1.5416666666666667`, 
       1.}, {-1.5208333333333335`, 1.}, {-1.5, 1.}, {-1.5, 
       1.}, {-1.5208333333333333`, 1.}, {-1.5416666666666667`, 1.}, {-1.5625, 
       1.}, {-1.5833333333333333`, 1.}, {-1.6041666666666665`, 1.}, {-1.625, 
       1.}, {-1.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 0.5}, {-2., 0.5208333333333333}, {-2., 
       0.5416666666666667}, {-2., 0.5625}, {-2., 0.5833333333333333}, {-2., 
       0.6041666666666666}, {-2., 0.625}, {-2., 0.625}, {-2., 
       0.6041666666666667}, {-2., 0.5833333333333333}, {-2., 0.5625}, {-2., 
       0.5416666666666667}, {-2., 0.5208333333333334}, {-2., 0.5}, {-2., 
       0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 1.375}, {-2., 1.3958333333333333`}, {-2., 
       1.4166666666666667`}, {-2., 1.4375}, {-2., 1.4583333333333333`}, {-2., 
       1.4791666666666665`}, {-2., 1.5}, {-2., 1.5}, {-2., 
       1.4791666666666667`}, {-2., 1.4583333333333333`}, {-2., 1.4375}, {-2., 
       1.4166666666666667`}, {-2., 1.3958333333333335`}, {-2., 1.375}, {-2., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, 1.}, {-2.25, 1.}, {-2.125, 1.}, {-2., 1.}, {-1.875, 
       1.}, {-1.75, 1.}, {-1.625, 1.}, {-1.625, 1.}, {-1.75, 1.}, {-1.875, 
       1.}, {-2., 1.}, {-2.125, 1.}, {-2.25, 1.}, {-2.375, 1.}, {-2.375, 
       1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 0.625}, {-2., 0.75}, {-2., 0.875}, {-2., 1.}, {-2., 
       1.125}, {-2., 1.25}, {-2., 1.375}, {-2., 1.375}, {-2., 1.25}, {-2., 
       1.125}, {-2., 1.}, {-2., 0.875}, {-2., 0.75}, {-2., 0.625}, {-2., 
       0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kPoD/Y6MYuawkx+7Z93QvVUd+9H+wWF+V9O
nIXJf7Y/pXLC59HB3/vNbptvlrX7Yg8R/7s/oW8Ct7nRV/sk81umJUX/9l9Z
HFu78vRXqDzDAQj1zd7/idDTo8cYDqDINzAegOmf/Xb2TT55pgMw8w3cT7RK
z2Q6ALP/1cV1+648ZToAcx9EnPkAzP0w+WN5W7JfPHkD188Iln9lPwdq/hTP
CTOPND+H2+/4+N6LibOfwt0XucOFdW3GEzT3P7FPhvovAirPCPW/PVQ/LHwm
Q82Hhd+//yDwEh6+h6Dug4U/WPr/e3sAVZiyyA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNp+1Vg8AvODwWDv3A+VMMBVHnGA6j6mQ6g
qmchyA8Dm/MVzl8NNucTmvoPaPKv0PQ/RVP/AIO/GsV9D9Dc/wDNfw/sw1D8
D9P/az+q+h8E+aEo7vuxfxWK+2HqP6DJf0LT/xVN/Q97ACh7dCw=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, 
       0.7348349570550448}, {-1.6752404735808355`, 
       0.8125}, {-1.5950572556670028`, 
       0.5950572556670028}, {-1.7348349570550448`, 0.7348349570550448}}], 
      PolygonBox[{{-1.5626550066464766`, 
       0.7697483574637448}, {-1.5950572556670028`, 
       0.5950572556670028}, {-1.6752404735808355`, 
       0.8125}, {-1.5626550066464766`, 0.7697483574637448}}], 
      PolygonBox[{{-1.6752404735808355`, 0.8125}, {-1.6377778151415994`, 
       0.9029428580865547}, {-1.5626550066464766`, 
       0.7697483574637448}, {-1.6752404735808355`, 0.8125}}], 
      PolygonBox[{{-1.5625000189670593`, 
       0.9157074104439382}, {-1.5626550066464766`, 
       0.7697483574637448}, {-1.6377778151415994`, 
       0.9029428580865547}, {-1.5625000189670593`, 0.9157074104439382}}], 
      PolygonBox[{{-1.6377778151415994`, 0.9029428580865547}, {-1.625, 
       1.}, {-1.5625000189670593`, 0.9157074104439382}, {-1.6377778151415994`,
        0.9029428580865547}}], 
      PolygonBox[{{-1.5625, 1.}, {-1.5625000189670593`, 
       0.9157074104439382}, {-1.625, 1.}, {-1.5625, 1.}}], 
      PolygonBox[{{-1.625, 1.}, {-1.6377778151415994`, 
       1.0970571419134452`}, {-1.5625, 1.}, {-1.625, 1.}}], 
      PolygonBox[{{-1.5625000189670593`, 1.0842925895560618`}, {-1.5625, 
       1.}, {-1.6377778151415994`, 
       1.0970571419134452`}, {-1.5625000189670593`, 1.0842925895560618`}}], 
      PolygonBox[{{-1.6377778151415994`, 
       1.0970571419134452`}, {-1.6752404735808355`, 
       1.1875}, {-1.5625000189670593`, 
       1.0842925895560618`}, {-1.6377778151415994`, 1.0970571419134452`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       1.230251642536255}, {-1.5625000189670593`, 
       1.0842925895560618`}, {-1.6752404735808355`, 
       1.1875}, {-1.5626550066464766`, 1.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, 1.1875}, {-1.7348349570550448`, 
       1.2651650429449552`}, {-1.5626550066464766`, 
       1.230251642536255}, {-1.6752404735808355`, 1.1875}}], 
      PolygonBox[{{-1.5950572556670028`, 
       1.4049427443329972`}, {-1.5626550066464766`, 
       1.230251642536255}, {-1.7348349570550448`, 
       1.2651650429449552`}, {-1.5950572556670028`, 1.4049427443329972`}}], 
      PolygonBox[{{-1.7348349570550448`, 1.2651650429449552`}, {-1.8125, 
       1.3247595264191645`}, {-1.5950572556670028`, 
       1.4049427443329972`}, {-1.7348349570550448`, 1.2651650429449552`}}], 
      PolygonBox[{{-1.769748357463745, 
       1.4373449933535234`}, {-1.5950572556670028`, 
       1.4049427443329972`}, {-1.8125, 
       1.3247595264191645`}, {-1.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{-1.8125, 1.3247595264191645`}, {-1.9029428580865546`, 
       1.3622221848584006`}, {-1.769748357463745, 
       1.4373449933535234`}, {-1.8125, 1.3247595264191645`}}], 
      PolygonBox[{{-1.9157074104439396`, 
       1.4374999810329407`}, {-1.769748357463745, 
       1.4373449933535234`}, {-1.9029428580865546`, 
       1.3622221848584006`}, {-1.9157074104439396`, 1.4374999810329407`}}], 
      PolygonBox[{{-1.9029428580865546`, 1.3622221848584006`}, {-2., 
       1.375}, {-1.9157074104439396`, 
       1.4374999810329407`}, {-1.9029428580865546`, 1.3622221848584006`}}], 
      PolygonBox[{{-1.9998944727795123`, 1.4375}, {-1.9157074104439396`, 
       1.4374999810329407`}, {-2., 1.375}, {-1.9998944727795123`, 1.4375}}], 
      PolygonBox[{{-2., 1.375}, {-2.097057141913445, 
       1.3622221848584006`}, {-1.9998944727795123`, 1.4375}, {-2., 1.375}}], 
      PolygonBox[{{-2.084292589556057, 
       1.4374999810329407`}, {-1.9998944727795123`, 
       1.4375}, {-2.097057141913445, 
       1.3622221848584006`}, {-2.084292589556057, 1.4374999810329407`}}], 
      PolygonBox[{{-2.097057141913445, 1.3622221848584006`}, {-2.1875, 
       1.3247595264191645`}, {-2.084292589556057, 
       1.4374999810329407`}, {-2.097057141913445, 1.3622221848584006`}}], 
      PolygonBox[{{-2.230251642536255, 
       1.4373449933535234`}, {-2.084292589556057, 
       1.4374999810329407`}, {-2.1875, 
       1.3247595264191645`}, {-2.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{-2.1875, 1.3247595264191645`}, {-2.2651650429449552`, 
       1.2651650429449552`}, {-2.230251642536255, 
       1.4373449933535234`}, {-2.1875, 1.3247595264191645`}}], 
      PolygonBox[{{-2.404942744332997, 
       1.4049427443329972`}, {-2.230251642536255, 
       1.4373449933535234`}, {-2.2651650429449552`, 
       1.2651650429449552`}, {-2.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{-2.2651650429449552`, 
       1.2651650429449552`}, {-2.3247595264191645`, 
       1.1875}, {-2.404942744332997, 
       1.4049427443329972`}, {-2.2651650429449552`, 1.2651650429449552`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       1.2302516425362553`}, {-2.404942744332997, 
       1.4049427443329972`}, {-2.3247595264191645`, 
       1.1875}, {-2.4373449933535234`, 1.2302516425362553`}}], 
      PolygonBox[{{-2.3247595264191645`, 1.1875}, {-2.3622221848584006`, 
       1.0970571419134454`}, {-2.4373449933535234`, 
       1.2302516425362553`}, {-2.3247595264191645`, 1.1875}}], 
      PolygonBox[{{-2.437499981032941, 
       1.0842925895560624`}, {-2.4373449933535234`, 
       1.2302516425362553`}, {-2.3622221848584006`, 
       1.0970571419134454`}, {-2.437499981032941, 1.0842925895560624`}}], 
      PolygonBox[{{-2.3622221848584006`, 1.0970571419134454`}, {-2.375, 
       1.0000000000000002`}, {-2.437499981032941, 
       1.0842925895560624`}, {-2.3622221848584006`, 1.0970571419134454`}}], 
      PolygonBox[{{-2.4375, 1.0001231780629953`}, {-2.437499981032941, 
       1.0842925895560624`}, {-2.375, 1.0000000000000002`}, {-2.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-2.375, 1.0000000000000002`}, {-2.3622221848584006`, 
       0.9029428580865548}, {-2.4375, 1.0001231780629953`}, {-2.375, 
       1.0000000000000002`}}], 
      PolygonBox[{{-2.437499981032941, 0.915707410443945}, {-2.4375, 
       1.0001231780629953`}, {-2.3622221848584006`, 
       0.9029428580865548}, {-2.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-2.3622221848584006`, 
       0.9029428580865548}, {-2.3247595264191645`, 
       0.8125000000000002}, {-2.437499981032941, 
       0.915707410443945}, {-2.3622221848584006`, 0.9029428580865548}}], 
      PolygonBox[{{-2.4373449933535234`, 
       0.7697483574637453}, {-2.437499981032941, 
       0.915707410443945}, {-2.3247595264191645`, 
       0.8125000000000002}, {-2.4373449933535234`, 0.7697483574637453}}], 
      PolygonBox[{{-2.3247595264191645`, 
       0.8125000000000002}, {-2.2651650429449552`, 
       0.7348349570550448}, {-2.4373449933535234`, 
       0.7697483574637453}, {-2.3247595264191645`, 0.8125000000000002}}], 
      PolygonBox[{{-2.404942744332997, 
       0.5950572556670028}, {-2.4373449933535234`, 
       0.7697483574637453}, {-2.2651650429449552`, 
       0.7348349570550448}, {-2.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-2.2651650429449552`, 0.7348349570550448}, {-2.1875, 
       0.6752404735808356}, {-2.404942744332997, 
       0.5950572556670028}, {-2.2651650429449552`, 0.7348349570550448}}], 
      PolygonBox[{{-2.230251642536255, 
       0.5626550066464766}, {-2.404942744332997, 
       0.5950572556670028}, {-2.1875, 
       0.6752404735808356}, {-2.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-2.1875, 0.6752404735808356}, {-2.0970571419134454`, 
       0.6377778151415995}, {-2.230251642536255, 
       0.5626550066464766}, {-2.1875, 0.6752404735808356}}], 
      PolygonBox[{{-2.084292589556064, 
       0.5625000189670593}, {-2.230251642536255, 
       0.5626550066464766}, {-2.0970571419134454`, 
       0.6377778151415995}, {-2.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-2.0970571419134454`, 0.6377778151415995}, {-2., 
       0.625}, {-2.084292589556064, 
       0.5625000189670593}, {-2.0970571419134454`, 0.6377778151415995}}], 
      PolygonBox[{{-1.999865158168957, 0.5625}, {-2.084292589556064, 
       0.5625000189670593}, {-2., 0.625}, {-1.999865158168957, 0.5625}}], 
      PolygonBox[{{-2., 0.625}, {-1.9029428580865548`, 
       0.6377778151415994}, {-1.999865158168957, 0.5625}, {-2., 0.625}}], 
      PolygonBox[{{-1.9157074104439469`, 
       0.5625000189670593}, {-1.999865158168957, 
       0.5625}, {-1.9029428580865548`, 
       0.6377778151415994}, {-1.9157074104439469`, 0.5625000189670593}}], 
      PolygonBox[{{-1.9029428580865548`, 
       0.6377778151415994}, {-1.8125000000000002`, 
       0.6752404735808354}, {-1.9157074104439469`, 
       0.5625000189670593}, {-1.9029428580865548`, 0.6377778151415994}}], 
      PolygonBox[{{-1.7697483574637454`, 
       0.5626550066464766}, {-1.9157074104439469`, 
       0.5625000189670593}, {-1.8125000000000002`, 
       0.6752404735808354}, {-1.7697483574637454`, 0.5626550066464766}}], 
      PolygonBox[{{-1.8125000000000002`, 
       0.6752404735808354}, {-1.7348349570550448`, 
       0.7348349570550446}, {-1.7697483574637454`, 
       0.5626550066464766}, {-1.8125000000000002`, 0.6752404735808354}}], 
      PolygonBox[{{-1.5950572556670028`, 
       0.5950572556670028}, {-1.7697483574637454`, 
       0.5626550066464766}, {-1.7348349570550448`, 
       0.7348349570550446}, {-1.5950572556670028`, 0.5950572556670028}}], 
      PolygonBox[{{-1.7348349570550448`, 
       0.7348349570550446}, {-1.7348349570550448`, 
       0.7348349570550448}, {-1.5950572556670028`, 
       0.5950572556670028}, {-1.7348349570550448`, 0.7348349570550446}}], 
      PolygonBox[{{-1.5950572556670028`, 
       0.5950572556670028}, {-1.5950572556670028`, 
       0.5950572556670028}, {-1.7348349570550448`, 
       0.7348349570550448}, {-1.5950572556670028`, 0.5950572556670028}}], 
      PolygonBox[{{-1.5950572556670028`, 
       0.5950572556670028}, {-1.5626550066464766`, 0.7697483574637448}, {-1.5,
        0.5}, {-1.5950572556670028`, 0.5950572556670028}}], 
      PolygonBox[{{-1.5, 0.6423372173506323}, {-1.5, 
       0.5}, {-1.5626550066464766`, 0.7697483574637448}, {-1.5, 
       0.6423372173506323}}], 
      PolygonBox[{{-1.5626550066464766`, 
       0.7697483574637448}, {-1.5625000189670593`, 0.9157074104439382}, {-1.5,
        0.6423372173506323}, {-1.5626550066464766`, 0.7697483574637448}}], 
      PolygonBox[{{-1.5, 0.79409099469826}, {-1.5, 
       0.6423372173506323}, {-1.5625000189670593`, 0.9157074104439382}, {-1.5,
        0.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, 0.9157074104439382}, {-1.5625, 
       1.}, {-1.5, 0.79409099469826}, {-1.5625000189670593`, 
       0.9157074104439382}}], 
      PolygonBox[{{-1.5, 1.}, {-1.5, 0.79409099469826}, {-1.5625, 1.}, {-1.5, 
       1.}}], PolygonBox[{{-1.5625, 1.}, {-1.5625000189670593`, 
       1.0842925895560618`}, {-1.5, 1.}, {-1.5625, 1.}}], 
      PolygonBox[{{-1.5, 1.2059090053017398`}, {-1.5, 
       1.}, {-1.5625000189670593`, 1.0842925895560618`}, {-1.5, 
       1.2059090053017398`}}], 
      PolygonBox[{{-1.5625000189670593`, 
       1.0842925895560618`}, {-1.5626550066464766`, 1.230251642536255}, {-1.5,
        1.2059090053017398`}, {-1.5625000189670593`, 1.0842925895560618`}}], 
      PolygonBox[{{-1.5, 1.3576627826493675`}, {-1.5, 
       1.2059090053017398`}, {-1.5626550066464766`, 1.230251642536255}, {-1.5,
        1.3576627826493675`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       1.230251642536255}, {-1.5950572556670028`, 1.4049427443329972`}, {-1.5,
        1.3576627826493675`}, {-1.5626550066464766`, 1.230251642536255}}], 
      PolygonBox[{{-1.508553435038814, 1.491446564961186}, {-1.5, 
       1.3576627826493675`}, {-1.5950572556670028`, 
       1.4049427443329972`}, {-1.508553435038814, 1.491446564961186}}], 
      PolygonBox[{{-1.5950572556670028`, 
       1.4049427443329972`}, {-1.769748357463745, 
       1.4373449933535234`}, {-1.508553435038814, 
       1.491446564961186}, {-1.5950572556670028`, 1.4049427443329972`}}], 
      PolygonBox[{{-1.6423372173506319`, 1.5}, {-1.508553435038814, 
       1.491446564961186}, {-1.769748357463745, 
       1.4373449933535234`}, {-1.6423372173506319`, 1.5}}], 
      PolygonBox[{{-1.769748357463745, 
       1.4373449933535234`}, {-1.9157074104439396`, 
       1.4374999810329407`}, {-1.6423372173506319`, 1.5}, {-1.769748357463745,
        1.4373449933535234`}}], 
      PolygonBox[{{-1.7940909946267443`, 1.5}, {-1.6423372173506319`, 
       1.5}, {-1.9157074104439396`, 
       1.4374999810329407`}, {-1.7940909946267443`, 1.5}}], 
      PolygonBox[{{-1.9157074104439396`, 
       1.4374999810329407`}, {-1.9998944727795123`, 
       1.4375}, {-1.7940909946267443`, 1.5}, {-1.9157074104439396`, 
       1.4374999810329407`}}], 
      PolygonBox[{{-1.92205804197311, 1.5}, {-1.7940909946267443`, 
       1.5}, {-1.9998944727795123`, 1.4375}, {-1.92205804197311, 1.5}}], 
      PolygonBox[{{-1.9998944727795123`, 1.4375}, {-2.084292589556057, 
       1.4374999810329407`}, {-1.92205804197311, 1.5}, {-1.9998944727795123`, 
       1.4375}}], 
      PolygonBox[{{-2.2059090053044454`, 1.5}, {-1.92205804197311, 
       1.5}, {-2.084292589556057, 1.4374999810329407`}, {-2.2059090053044454`,
        1.5}}], 
      PolygonBox[{{-2.084292589556057, 
       1.4374999810329407`}, {-2.230251642536255, 
       1.4373449933535234`}, {-2.2059090053044454`, 1.5}, {-2.084292589556057,
        1.4374999810329407`}}], 
      PolygonBox[{{-2.357662782649366, 1.5}, {-2.2059090053044454`, 
       1.5}, {-2.230251642536255, 1.4373449933535234`}, {-2.357662782649366, 
       1.5}}], 
      PolygonBox[{{-2.230251642536255, 
       1.4373449933535234`}, {-2.404942744332997, 
       1.4049427443329972`}, {-2.357662782649366, 1.5}, {-2.230251642536255, 
       1.4373449933535234`}}], 
      PolygonBox[{{-1.5, 1.5}, {-2.357662782649366, 1.5}, {-2.404942744332997,
        1.4049427443329972`}, {-1.5, 1.5}}], 
      PolygonBox[{{-2.404942744332997, 
       1.4049427443329972`}, {-2.4373449933535234`, 
       1.2302516425362553`}, {-1.5, 1.5}, {-2.404942744332997, 
       1.4049427443329972`}}], 
      PolygonBox[{{-2.5, 1.357662782649369}, {-1.5, 
       1.5}, {-2.4373449933535234`, 1.2302516425362553`}, {-2.5, 
       1.357662782649369}}], 
      PolygonBox[{{-2.4373449933535234`, 
       1.2302516425362553`}, {-2.437499981032941, 1.0842925895560624`}, {-2.5,
        1.357662782649369}, {-2.4373449933535234`, 1.2302516425362553`}}], 
      PolygonBox[{{-2.5, 1.205909005282899}, {-2.5, 
       1.357662782649369}, {-2.437499981032941, 1.0842925895560624`}, {-2.5, 
       1.205909005282899}}], 
      PolygonBox[{{-2.437499981032941, 1.0842925895560624`}, {-2.4375, 
       1.0001231780629953`}, {-2.5, 1.205909005282899}, {-2.437499981032941, 
       1.0842925895560624`}}], 
      PolygonBox[{{-2.5, 1.0806786667587003`}, {-2.5, 
       1.205909005282899}, {-2.4375, 1.0001231780629953`}, {-2.5, 
       1.0806786667587003`}}], 
      PolygonBox[{{-2.4375, 1.0001231780629953`}, {-2.437499981032941, 
       0.915707410443945}, {-2.5, 1.0806786667587003`}, {-2.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-2.5, 0.7940909948547215}, {-2.5, 
       1.0806786667587003`}, {-2.437499981032941, 0.915707410443945}, {-2.5, 
       0.7940909948547215}}], 
      PolygonBox[{{-2.437499981032941, 
       0.915707410443945}, {-2.4373449933535234`, 0.7697483574637453}, {-2.5, 
       0.7940909948547215}, {-2.437499981032941, 0.915707410443945}}], 
      PolygonBox[{{-2.5, 0.6423372173506346}, {-2.5, 
       0.7940909948547215}, {-2.4373449933535234`, 0.7697483574637453}, {-2.5,
        0.6423372173506346}}], 
      PolygonBox[{{-2.4373449933535234`, 
       0.7697483574637453}, {-2.404942744332997, 0.5950572556670028}, {-2.5, 
       0.6423372173506346}, {-2.4373449933535234`, 0.7697483574637453}}], 
      PolygonBox[{{-2.5, 1.5}, {-2.5, 
       0.6423372173506346}, {-2.404942744332997, 0.5950572556670028}, {-2.5, 
       1.5}}], PolygonBox[{{-2.404942744332997, 
       0.5950572556670028}, {-2.230251642536255, 0.5626550066464766}, {-2.5, 
       1.5}, {-2.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{-2.5, 0.5}, {-2.5, 1.5}, {-2.230251642536255, 
       0.5626550066464766}, {-2.5, 0.5}}], 
      PolygonBox[{{-2.230251642536255, 
       0.5626550066464766}, {-2.084292589556064, 0.5625000189670593}, {-2.5, 
       0.5}, {-2.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-2.205909005566828, 0.5}, {-2.5, 0.5}, {-2.084292589556064,
        0.5625000189670593}, {-2.205909005566828, 0.5}}], 
      PolygonBox[{{-2.084292589556064, 
       0.5625000189670593}, {-1.999865158168957, 0.5625}, {-2.205909005566828,
        0.5}, {-2.084292589556064, 0.5625000189670593}}], 
      PolygonBox[{{-1.9176761295989384`, 0.5}, {-2.205909005566828, 
       0.5}, {-1.999865158168957, 0.5625}, {-1.9176761295989384`, 0.5}}], 
      PolygonBox[{{-1.999865158168957, 0.5625}, {-1.9157074104439469`, 
       0.5625000189670593}, {-1.9176761295989384`, 0.5}, {-1.999865158168957, 
       0.5625}}], 
      PolygonBox[{{-1.7940909946396026`, 0.5}, {-1.9176761295989384`, 
       0.5}, {-1.9157074104439469`, 
       0.5625000189670593}, {-1.7940909946396026`, 0.5}}], 
      PolygonBox[{{-1.9157074104439469`, 
       0.5625000189670593}, {-1.7697483574637454`, 
       0.5626550066464766}, {-1.7940909946396026`, 
       0.5}, {-1.9157074104439469`, 0.5625000189670593}}], 
      PolygonBox[{{-1.642337217350629, 0.5}, {-1.7940909946396026`, 
       0.5}, {-1.7697483574637454`, 0.5626550066464766}, {-1.642337217350629, 
       0.5}}], PolygonBox[{{-1.7697483574637454`, 
       0.5626550066464766}, {-1.5950572556670028`, 
       0.5950572556670028}, {-1.642337217350629, 0.5}, {-1.7697483574637454`, 
       0.5626550066464766}}], 
      PolygonBox[{{-1.5, 0.5}, {-1.642337217350629, 
       0.5}, {-1.5950572556670028`, 0.5950572556670028}, {-1.5, 0.5}}], 
      PolygonBox[{{-1.5950572556670028`, 
       0.5950572556670028}, {-1.5950572556670028`, 0.5950572556670028}, {-1.5,
        0.5}, {-1.5950572556670028`, 0.5950572556670028}}], 
      PolygonBox[{{-1.5, 0.5}, {-1.5, 0.5}, {-1.5950572556670028`, 
       0.5950572556670028}, {-1.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, 2.}, {-2.4791666666666665`, 2.}, {-2.4583333333333335`, 
       2.}, {-2.4375, 2.}, {-2.4166666666666665`, 2.}, {-2.3958333333333335`, 
       2.}, {-2.375, 2.}, {-2.375, 2.}, {-2.3958333333333335`, 
       2.}, {-2.4166666666666665`, 2.}, {-2.4375, 2.}, {-2.4583333333333335`, 
       2.}, {-2.4791666666666665`, 2.}, {-2.5, 2.}, {-2.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, 2.}, {-1.6041666666666667`, 
       2.}, {-1.5833333333333333`, 2.}, {-1.5625, 2.}, {-1.5416666666666667`, 
       2.}, {-1.5208333333333335`, 2.}, {-1.5, 2.}, {-1.5, 
       2.}, {-1.5208333333333333`, 2.}, {-1.5416666666666667`, 2.}, {-1.5625, 
       2.}, {-1.5833333333333333`, 2.}, {-1.6041666666666665`, 2.}, {-1.625, 
       2.}, {-1.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 1.5}, {-2., 1.5208333333333333`}, {-2., 
       1.5416666666666667`}, {-2., 1.5625}, {-2., 1.5833333333333333`}, {-2., 
       1.6041666666666665`}, {-2., 1.625}, {-2., 1.625}, {-2., 
       1.6041666666666667`}, {-2., 1.5833333333333333`}, {-2., 1.5625}, {-2., 
       1.5416666666666667`}, {-2., 1.5208333333333335`}, {-2., 1.5}, {-2., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 2.375}, {-2., 2.3958333333333335`}, {-2., 
       2.4166666666666665`}, {-2., 2.4375}, {-2., 2.4583333333333335`}, {-2., 
       2.4791666666666665`}, {-2., 2.5}, {-2., 2.5}, {-2., 
       2.4791666666666665`}, {-2., 2.4583333333333335`}, {-2., 2.4375}, {-2., 
       2.4166666666666665`}, {-2., 2.3958333333333335`}, {-2., 2.375}, {-2., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, 2.}, {-2.25, 2.}, {-2.125, 2.}, {-2., 2.}, {-1.875, 
       2.}, {-1.75, 2.}, {-1.625, 2.}, {-1.625, 2.}, {-1.75, 2.}, {-1.875, 
       2.}, {-2., 2.}, {-2.125, 2.}, {-2.25, 2.}, {-2.375, 2.}, {-2.375, 
       2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 1.625}, {-2., 1.75}, {-2., 1.875}, {-2., 2.}, {-2., 
       2.125}, {-2., 2.25}, {-2., 2.375}, {-2., 2.375}, {-2., 2.25}, {-2., 
       2.125}, {-2., 2.}, {-2., 1.875}, {-2., 1.75}, {-2., 1.625}, {-2., 
       1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kMZDjoxi5rCTH7t938i9PToMQaHBYX5X06c
hco3MDqcUjnh8+jg7/2z386+ySfP5ADR9ne/gfuJVumZTA5J5rdMS4r+7X91
cd2+K09h8gwHIBSzA9TcAyjyDYwHYPqh5h6AmQ8VPwCzH6rvAMx9UHMPwNwP
k0+GuMMeRT/DX/s5UPOh/rCH2Q/1pz3MfdBwsEd1/y97qLn7YfKMUP/D9MPC
B2Y+LPz+g8Efe1j4JkLdhx7+AOD7pAQ=
      "]], LineBox[CompressedData["
1:eJyFj9EJgDAMRGPpGP44STuDUAcQ/HYvO0Q7VigIamsCpx89KOGRu3KZ1n3e
DBGN93tmE6c2rT+qinKoOpXfQMb9kDFvMvptl2PLKb//fvykvLReDvPFoZ9/
HKEfO+wvflJe4H7Jl4R+7vIB/TgF6C9+uU/2g8e88ei3/gIY6Gcm
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, 
       1.7348349570550448`}, {-1.6752404735808355`, 
       1.8125}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       1.769748357463745}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.6752404735808355`, 
       1.8125}, {-1.5626550066464766`, 1.769748357463745}}], 
      PolygonBox[{{-1.6752404735808355`, 1.8125}, {-1.6377778151415994`, 
       1.9029428580865546`}, {-1.5626550066464766`, 
       1.769748357463745}, {-1.6752404735808355`, 1.8125}}], 
      PolygonBox[{{-1.5625000189670593`, 
       1.9157074104439382`}, {-1.5626550066464766`, 
       1.769748357463745}, {-1.6377778151415994`, 
       1.9029428580865546`}, {-1.5625000189670593`, 1.9157074104439382`}}], 
      PolygonBox[{{-1.6377778151415994`, 1.9029428580865546`}, {-1.625, 
       2.}, {-1.5625000189670593`, 
       1.9157074104439382`}, {-1.6377778151415994`, 1.9029428580865546`}}], 
      PolygonBox[{{-1.5625, 2.}, {-1.5625000189670593`, 
       1.9157074104439382`}, {-1.625, 2.}, {-1.5625, 2.}}], 
      PolygonBox[{{-1.625, 2.}, {-1.6377778151415994`, 
       2.0970571419134454`}, {-1.5625, 2.}, {-1.625, 2.}}], 
      PolygonBox[{{-1.5625000189670593`, 2.084292589556062}, {-1.5625, 
       2.}, {-1.6377778151415994`, 
       2.0970571419134454`}, {-1.5625000189670593`, 2.084292589556062}}], 
      PolygonBox[{{-1.6377778151415994`, 
       2.0970571419134454`}, {-1.6752404735808355`, 
       2.1875}, {-1.5625000189670593`, 
       2.084292589556062}, {-1.6377778151415994`, 2.0970571419134454`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       2.230251642536255}, {-1.5625000189670593`, 
       2.084292589556062}, {-1.6752404735808355`, 
       2.1875}, {-1.5626550066464766`, 2.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, 2.1875}, {-1.7348349570550448`, 
       2.2651650429449552`}, {-1.5626550066464766`, 
       2.230251642536255}, {-1.6752404735808355`, 2.1875}}], 
      PolygonBox[{{-1.5950572556670028`, 
       2.404942744332997}, {-1.5626550066464766`, 
       2.230251642536255}, {-1.7348349570550448`, 
       2.2651650429449552`}, {-1.5950572556670028`, 2.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, 2.2651650429449552`}, {-1.8125, 
       2.3247595264191645`}, {-1.5950572556670028`, 
       2.404942744332997}, {-1.7348349570550448`, 2.2651650429449552`}}], 
      PolygonBox[{{-1.769748357463745, 
       2.4373449933535234`}, {-1.5950572556670028`, 
       2.404942744332997}, {-1.8125, 
       2.3247595264191645`}, {-1.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{-1.8125, 2.3247595264191645`}, {-1.9029428580865546`, 
       2.3622221848584006`}, {-1.769748357463745, 
       2.4373449933535234`}, {-1.8125, 2.3247595264191645`}}], 
      PolygonBox[{{-1.9157074104439396`, 
       2.437499981032941}, {-1.769748357463745, 
       2.4373449933535234`}, {-1.9029428580865546`, 
       2.3622221848584006`}, {-1.9157074104439396`, 2.437499981032941}}], 
      PolygonBox[{{-1.9029428580865546`, 2.3622221848584006`}, {-2., 
       2.375}, {-1.9157074104439396`, 
       2.437499981032941}, {-1.9029428580865546`, 2.3622221848584006`}}], 
      PolygonBox[{{-1.9998944727795123`, 2.4375}, {-1.9157074104439396`, 
       2.437499981032941}, {-2., 2.375}, {-1.9998944727795123`, 2.4375}}], 
      PolygonBox[{{-2., 2.375}, {-2.097057141913445, 
       2.3622221848584006`}, {-1.9998944727795123`, 2.4375}, {-2., 2.375}}], 
      PolygonBox[{{-2.084292589556057, 
       2.437499981032941}, {-1.9998944727795123`, 
       2.4375}, {-2.097057141913445, 
       2.3622221848584006`}, {-2.084292589556057, 2.437499981032941}}], 
      PolygonBox[{{-2.097057141913445, 2.3622221848584006`}, {-2.1875, 
       2.3247595264191645`}, {-2.084292589556057, 
       2.437499981032941}, {-2.097057141913445, 2.3622221848584006`}}], 
      PolygonBox[{{-2.230251642536255, 
       2.4373449933535234`}, {-2.084292589556057, 
       2.437499981032941}, {-2.1875, 
       2.3247595264191645`}, {-2.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{-2.1875, 2.3247595264191645`}, {-2.2651650429449552`, 
       2.2651650429449552`}, {-2.230251642536255, 
       2.4373449933535234`}, {-2.1875, 2.3247595264191645`}}], 
      PolygonBox[{{-2.404942744332997, 
       2.404942744332997}, {-2.230251642536255, 
       2.4373449933535234`}, {-2.2651650429449552`, 
       2.2651650429449552`}, {-2.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, 
       2.2651650429449552`}, {-2.3247595264191645`, 
       2.1875}, {-2.404942744332997, 
       2.404942744332997}, {-2.2651650429449552`, 2.2651650429449552`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       2.2302516425362553`}, {-2.404942744332997, 
       2.404942744332997}, {-2.3247595264191645`, 
       2.1875}, {-2.4373449933535234`, 2.2302516425362553`}}], 
      PolygonBox[{{-2.3247595264191645`, 2.1875}, {-2.3622221848584006`, 
       2.0970571419134454`}, {-2.4373449933535234`, 
       2.2302516425362553`}, {-2.3247595264191645`, 2.1875}}], 
      PolygonBox[{{-2.437499981032941, 
       2.0842925895560622`}, {-2.4373449933535234`, 
       2.2302516425362553`}, {-2.3622221848584006`, 
       2.0970571419134454`}, {-2.437499981032941, 2.0842925895560622`}}], 
      PolygonBox[{{-2.3622221848584006`, 2.0970571419134454`}, {-2.375, 
       2.}, {-2.437499981032941, 2.0842925895560622`}, {-2.3622221848584006`, 
       2.0970571419134454`}}], 
      PolygonBox[{{-2.4375, 2.0001231780629953`}, {-2.437499981032941, 
       2.0842925895560622`}, {-2.375, 2.}, {-2.4375, 2.0001231780629953`}}], 
      PolygonBox[{{-2.375, 2.}, {-2.3622221848584006`, 
       1.9029428580865548`}, {-2.4375, 2.0001231780629953`}, {-2.375, 2.}}], 
      PolygonBox[{{-2.437499981032941, 1.915707410443945}, {-2.4375, 
       2.0001231780629953`}, {-2.3622221848584006`, 
       1.9029428580865548`}, {-2.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-2.3622221848584006`, 
       1.9029428580865548`}, {-2.3247595264191645`, 
       1.8125000000000002`}, {-2.437499981032941, 
       1.915707410443945}, {-2.3622221848584006`, 1.9029428580865548`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       1.7697483574637451`}, {-2.437499981032941, 
       1.915707410443945}, {-2.3247595264191645`, 
       1.8125000000000002`}, {-2.4373449933535234`, 1.7697483574637451`}}], 
      PolygonBox[{{-2.3247595264191645`, 
       1.8125000000000002`}, {-2.2651650429449552`, 
       1.7348349570550448`}, {-2.4373449933535234`, 
       1.7697483574637451`}, {-2.3247595264191645`, 1.8125000000000002`}}], 
      PolygonBox[{{-2.404942744332997, 
       1.5950572556670028`}, {-2.4373449933535234`, 
       1.7697483574637451`}, {-2.2651650429449552`, 
       1.7348349570550448`}, {-2.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-2.2651650429449552`, 1.7348349570550448`}, {-2.1875, 
       1.6752404735808355`}, {-2.404942744332997, 
       1.5950572556670028`}, {-2.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{-2.230251642536255, 
       1.5626550066464766`}, {-2.404942744332997, 
       1.5950572556670028`}, {-2.1875, 
       1.6752404735808355`}, {-2.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-2.1875, 1.6752404735808355`}, {-2.0970571419134454`, 
       1.6377778151415994`}, {-2.230251642536255, 
       1.5626550066464766`}, {-2.1875, 1.6752404735808355`}}], 
      PolygonBox[{{-2.084292589556064, 
       1.5625000189670593`}, {-2.230251642536255, 
       1.5626550066464766`}, {-2.0970571419134454`, 
       1.6377778151415994`}, {-2.084292589556064, 1.5625000189670593`}}], 
      PolygonBox[{{-2.0970571419134454`, 1.6377778151415994`}, {-2., 
       1.625}, {-2.084292589556064, 
       1.5625000189670593`}, {-2.0970571419134454`, 1.6377778151415994`}}], 
      PolygonBox[{{-1.999865158168957, 1.5625}, {-2.084292589556064, 
       1.5625000189670593`}, {-2., 1.625}, {-1.999865158168957, 1.5625}}], 
      PolygonBox[{{-2., 1.625}, {-1.9029428580865548`, 
       1.6377778151415994`}, {-1.999865158168957, 1.5625}, {-2., 1.625}}], 
      PolygonBox[{{-1.9157074104439469`, 
       1.5625000189670593`}, {-1.999865158168957, 
       1.5625}, {-1.9029428580865548`, 
       1.6377778151415994`}, {-1.9157074104439469`, 1.5625000189670593`}}], 
      PolygonBox[{{-1.9029428580865548`, 
       1.6377778151415994`}, {-1.8125000000000002`, 
       1.6752404735808355`}, {-1.9157074104439469`, 
       1.5625000189670593`}, {-1.9029428580865548`, 1.6377778151415994`}}], 
      PolygonBox[{{-1.7697483574637454`, 
       1.5626550066464766`}, {-1.9157074104439469`, 
       1.5625000189670593`}, {-1.8125000000000002`, 
       1.6752404735808355`}, {-1.7697483574637454`, 1.5626550066464766`}}], 
      PolygonBox[{{-1.8125000000000002`, 
       1.6752404735808355`}, {-1.7348349570550448`, 
       1.7348349570550448`}, {-1.7697483574637454`, 
       1.5626550066464766`}, {-1.8125000000000002`, 1.6752404735808355`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       1.5950572556670028`}, {-1.7697483574637454`, 
       1.5626550066464766`}, {-1.7348349570550448`, 
       1.7348349570550448`}, {-1.5950572556670028`, 1.5950572556670028`}}], 
      PolygonBox[{{-1.7348349570550448`, 
       1.7348349570550448`}, {-1.7348349570550448`, 
       1.7348349570550448`}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       1.5950572556670028`}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.7348349570550448`, 
       1.7348349570550448`}, {-1.5950572556670028`, 1.5950572556670028`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       1.5950572556670028`}, {-1.5626550066464766`, 1.769748357463745}, {-1.5,
        1.5}, {-1.5950572556670028`, 1.5950572556670028`}}], 
      PolygonBox[{{-1.5, 1.6423372173506323`}, {-1.5, 
       1.5}, {-1.5626550066464766`, 1.769748357463745}, {-1.5, 
       1.6423372173506323`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       1.769748357463745}, {-1.5625000189670593`, 1.9157074104439382`}, {-1.5,
        1.6423372173506323`}, {-1.5626550066464766`, 1.769748357463745}}], 
      PolygonBox[{{-1.5, 1.79409099469826}, {-1.5, 
       1.6423372173506323`}, {-1.5625000189670593`, 
       1.9157074104439382`}, {-1.5, 1.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, 1.9157074104439382`}, {-1.5625, 
       2.}, {-1.5, 1.79409099469826}, {-1.5625000189670593`, 
       1.9157074104439382`}}], 
      PolygonBox[{{-1.5, 2.}, {-1.5, 1.79409099469826}, {-1.5625, 2.}, {-1.5, 
       2.}}], PolygonBox[{{-1.5625, 2.}, {-1.5625000189670593`, 
       2.084292589556062}, {-1.5, 2.}, {-1.5625, 2.}}], 
      PolygonBox[{{-1.5, 2.20590900530174}, {-1.5, 2.}, {-1.5625000189670593`,
        2.084292589556062}, {-1.5, 2.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, 
       2.084292589556062}, {-1.5626550066464766`, 2.230251642536255}, {-1.5, 
       2.20590900530174}, {-1.5625000189670593`, 2.084292589556062}}], 
      PolygonBox[{{-1.5, 2.3576627826493675`}, {-1.5, 
       2.20590900530174}, {-1.5626550066464766`, 2.230251642536255}, {-1.5, 
       2.3576627826493675`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       2.230251642536255}, {-1.5950572556670028`, 2.404942744332997}, {-1.5, 
       2.3576627826493675`}, {-1.5626550066464766`, 2.230251642536255}}], 
      PolygonBox[{{-1.508553435038814, 2.491446564961186}, {-1.5, 
       2.3576627826493675`}, {-1.5950572556670028`, 
       2.404942744332997}, {-1.508553435038814, 2.491446564961186}}], 
      PolygonBox[{{-1.5950572556670028`, 
       2.404942744332997}, {-1.769748357463745, 
       2.4373449933535234`}, {-1.508553435038814, 
       2.491446564961186}, {-1.5950572556670028`, 2.404942744332997}}], 
      PolygonBox[{{-1.6423372173506319`, 2.5}, {-1.508553435038814, 
       2.491446564961186}, {-1.769748357463745, 
       2.4373449933535234`}, {-1.6423372173506319`, 2.5}}], 
      PolygonBox[{{-1.769748357463745, 
       2.4373449933535234`}, {-1.9157074104439396`, 
       2.437499981032941}, {-1.6423372173506319`, 2.5}, {-1.769748357463745, 
       2.4373449933535234`}}], 
      PolygonBox[{{-1.7940909946267443`, 2.5}, {-1.6423372173506319`, 
       2.5}, {-1.9157074104439396`, 2.437499981032941}, {-1.7940909946267443`,
        2.5}}], 
      PolygonBox[{{-1.9157074104439396`, 
       2.437499981032941}, {-1.9998944727795123`, 
       2.4375}, {-1.7940909946267443`, 2.5}, {-1.9157074104439396`, 
       2.437499981032941}}], 
      PolygonBox[{{-1.92205804197311, 2.5}, {-1.7940909946267443`, 
       2.5}, {-1.9998944727795123`, 2.4375}, {-1.92205804197311, 2.5}}], 
      PolygonBox[{{-1.9998944727795123`, 2.4375}, {-2.084292589556057, 
       2.437499981032941}, {-1.92205804197311, 2.5}, {-1.9998944727795123`, 
       2.4375}}], 
      PolygonBox[{{-2.2059090053044454`, 2.5}, {-1.92205804197311, 
       2.5}, {-2.084292589556057, 2.437499981032941}, {-2.2059090053044454`, 
       2.5}}], PolygonBox[{{-2.084292589556057, 
       2.437499981032941}, {-2.230251642536255, 
       2.4373449933535234`}, {-2.2059090053044454`, 2.5}, {-2.084292589556057,
        2.437499981032941}}], 
      PolygonBox[{{-2.357662782649366, 2.5}, {-2.2059090053044454`, 
       2.5}, {-2.230251642536255, 2.4373449933535234`}, {-2.357662782649366, 
       2.5}}], PolygonBox[{{-2.230251642536255, 
       2.4373449933535234`}, {-2.404942744332997, 
       2.404942744332997}, {-2.357662782649366, 2.5}, {-2.230251642536255, 
       2.4373449933535234`}}], 
      PolygonBox[{{-1.5, 2.5}, {-2.357662782649366, 2.5}, {-2.404942744332997,
        2.404942744332997}, {-1.5, 2.5}}], 
      PolygonBox[{{-2.404942744332997, 
       2.404942744332997}, {-2.4373449933535234`, 2.2302516425362553`}, {-1.5,
        2.5}, {-2.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{-2.5, 2.357662782649369}, {-1.5, 
       2.5}, {-2.4373449933535234`, 2.2302516425362553`}, {-2.5, 
       2.357662782649369}}], 
      PolygonBox[{{-2.4373449933535234`, 
       2.2302516425362553`}, {-2.437499981032941, 2.0842925895560622`}, {-2.5,
        2.357662782649369}, {-2.4373449933535234`, 2.2302516425362553`}}], 
      PolygonBox[{{-2.5, 2.205909005282899}, {-2.5, 
       2.357662782649369}, {-2.437499981032941, 2.0842925895560622`}, {-2.5, 
       2.205909005282899}}], 
      PolygonBox[{{-2.437499981032941, 2.0842925895560622`}, {-2.4375, 
       2.0001231780629953`}, {-2.5, 2.205909005282899}, {-2.437499981032941, 
       2.0842925895560622`}}], 
      PolygonBox[{{-2.5, 2.0806786667587}, {-2.5, 
       2.205909005282899}, {-2.4375, 2.0001231780629953`}, {-2.5, 
       2.0806786667587}}], 
      PolygonBox[{{-2.4375, 2.0001231780629953`}, {-2.437499981032941, 
       1.915707410443945}, {-2.5, 2.0806786667587}, {-2.4375, 
       2.0001231780629953`}}], 
      PolygonBox[{{-2.5, 1.7940909948547215`}, {-2.5, 
       2.0806786667587}, {-2.437499981032941, 1.915707410443945}, {-2.5, 
       1.7940909948547215`}}], 
      PolygonBox[{{-2.437499981032941, 
       1.915707410443945}, {-2.4373449933535234`, 1.7697483574637451`}, {-2.5,
        1.7940909948547215`}, {-2.437499981032941, 1.915707410443945}}], 
      PolygonBox[{{-2.5, 1.6423372173506348`}, {-2.5, 
       1.7940909948547215`}, {-2.4373449933535234`, 
       1.7697483574637451`}, {-2.5, 1.6423372173506348`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       1.7697483574637451`}, {-2.404942744332997, 1.5950572556670028`}, {-2.5,
        1.6423372173506348`}, {-2.4373449933535234`, 1.7697483574637451`}}], 
      PolygonBox[{{-2.5, 2.5}, {-2.5, 
       1.6423372173506348`}, {-2.404942744332997, 1.5950572556670028`}, {-2.5,
        2.5}}], 
      PolygonBox[{{-2.404942744332997, 
       1.5950572556670028`}, {-2.230251642536255, 1.5626550066464766`}, {-2.5,
        2.5}, {-2.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{-2.5, 1.5}, {-2.5, 2.5}, {-2.230251642536255, 
       1.5626550066464766`}, {-2.5, 1.5}}], 
      PolygonBox[{{-2.230251642536255, 
       1.5626550066464766`}, {-2.084292589556064, 1.5625000189670593`}, {-2.5,
        1.5}, {-2.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-2.205909005566828, 1.5}, {-2.5, 1.5}, {-2.084292589556064,
        1.5625000189670593`}, {-2.205909005566828, 1.5}}], 
      PolygonBox[{{-2.084292589556064, 
       1.5625000189670593`}, {-1.999865158168957, 
       1.5625}, {-2.205909005566828, 1.5}, {-2.084292589556064, 
       1.5625000189670593`}}], 
      PolygonBox[{{-1.9176761295989384`, 1.5}, {-2.205909005566828, 
       1.5}, {-1.999865158168957, 1.5625}, {-1.9176761295989384`, 1.5}}], 
      PolygonBox[{{-1.999865158168957, 1.5625}, {-1.9157074104439469`, 
       1.5625000189670593`}, {-1.9176761295989384`, 1.5}, {-1.999865158168957,
        1.5625}}], 
      PolygonBox[{{-1.7940909946396026`, 1.5}, {-1.9176761295989384`, 
       1.5}, {-1.9157074104439469`, 
       1.5625000189670593`}, {-1.7940909946396026`, 1.5}}], 
      PolygonBox[{{-1.9157074104439469`, 
       1.5625000189670593`}, {-1.7697483574637454`, 
       1.5626550066464766`}, {-1.7940909946396026`, 
       1.5}, {-1.9157074104439469`, 1.5625000189670593`}}], 
      PolygonBox[{{-1.642337217350629, 1.5}, {-1.7940909946396026`, 
       1.5}, {-1.7697483574637454`, 1.5626550066464766`}, {-1.642337217350629,
        1.5}}], 
      PolygonBox[{{-1.7697483574637454`, 
       1.5626550066464766`}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.642337217350629, 1.5}, {-1.7697483574637454`,
        1.5626550066464766`}}], 
      PolygonBox[{{-1.5, 1.5}, {-1.642337217350629, 
       1.5}, {-1.5950572556670028`, 1.5950572556670028`}, {-1.5, 1.5}}], 
      PolygonBox[{{-1.5950572556670028`, 
       1.5950572556670028`}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.5, 1.5}, {-1.5950572556670028`, 
       1.5950572556670028`}}], 
      PolygonBox[{{-1.5, 1.5}, {-1.5, 1.5}, {-1.5950572556670028`, 
       1.5950572556670028`}, {-1.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, 3.}, {-2.4791666666666665`, 3.}, {-2.4583333333333335`, 
       3.}, {-2.4375, 3.}, {-2.4166666666666665`, 3.}, {-2.3958333333333335`, 
       3.}, {-2.375, 3.}, {-2.375, 3.}, {-2.3958333333333335`, 
       3.}, {-2.4166666666666665`, 3.}, {-2.4375, 3.}, {-2.4583333333333335`, 
       3.}, {-2.4791666666666665`, 3.}, {-2.5, 3.}, {-2.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, 3.}, {-1.6041666666666667`, 
       3.}, {-1.5833333333333333`, 3.}, {-1.5625, 3.}, {-1.5416666666666667`, 
       3.}, {-1.5208333333333335`, 3.}, {-1.5, 3.}, {-1.5, 
       3.}, {-1.5208333333333333`, 3.}, {-1.5416666666666667`, 3.}, {-1.5625, 
       3.}, {-1.5833333333333333`, 3.}, {-1.6041666666666665`, 3.}, {-1.625, 
       3.}, {-1.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 2.5}, {-2., 2.5208333333333335`}, {-2., 
       2.5416666666666665`}, {-2., 2.5625}, {-2., 2.5833333333333335`}, {-2., 
       2.6041666666666665`}, {-2., 2.625}, {-2., 2.625}, {-2., 
       2.6041666666666665`}, {-2., 2.5833333333333335`}, {-2., 2.5625}, {-2., 
       2.5416666666666665`}, {-2., 2.5208333333333335`}, {-2., 2.5}, {-2., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 3.375}, {-2., 3.3958333333333335`}, {-2., 
       3.4166666666666665`}, {-2., 3.4375}, {-2., 3.4583333333333335`}, {-2., 
       3.4791666666666665`}, {-2., 3.5}, {-2., 3.5}, {-2., 
       3.4791666666666665`}, {-2., 3.4583333333333335`}, {-2., 3.4375}, {-2., 
       3.4166666666666665`}, {-2., 3.3958333333333335`}, {-2., 3.375}, {-2., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, 3.}, {-2.25, 3.}, {-2.125, 3.}, {-2., 3.}, {-1.875, 
       3.}, {-1.75, 3.}, {-1.625, 3.}, {-1.625, 3.}, {-1.75, 3.}, {-1.875, 
       3.}, {-2., 3.}, {-2.125, 3.}, {-2.25, 3.}, {-2.375, 3.}, {-2.375, 
       3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 2.625}, {-2., 2.75}, {-2., 2.875}, {-2., 3.}, {-2., 
       3.125}, {-2., 3.25}, {-2., 3.375}, {-2., 3.375}, {-2., 3.25}, {-2., 
       3.125}, {-2., 3.}, {-2., 2.875}, {-2., 2.75}, {-2., 2.625}, {-2., 
       2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kNoDgedmEVNYSa/9vs/EXp69BiHw4LC/C8n
zkLlGzgdTqmc8Hl08Pf+2W9n3+ST53KA6Pu738D9RKv0TC6HJPNbpiVF//a/
urhu35WnMHmGAxCK2wFiLsMBFPkGxgMw/RBzmQ7AzIeIMx2A2Q/Rx3QA5j6I
ucwHYO6HyW+SfitlZcmOpp/NYQ7U/FShFLWPD1jh9l/YYV71JI0V7j4xvUBH
bSlWNPezOiRD/QeTZ4T6H6YfFj4w81HDjw0evhuh7kMPfwCq3Y9+
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNoHodVYPALzg8Fg79wPlTDAVR5xgOo+pkO
oKpnIchfDdbHBedDzOVEU8+Bpp4Nzg8Dq2dFU8+CwV+N4j4WNPfD1DPA+WEo
/ofp/7UfVf0PgvxQFPf92I/qfph6DjT1nHD+KpTwQcQXAMF9W0A=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, 
       2.7348349570550448`}, {-1.6752404735808355`, 
       2.8125}, {-1.5950572556670028`, 
       2.595057255667003}, {-1.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       2.7697483574637447`}, {-1.5950572556670028`, 
       2.595057255667003}, {-1.6752404735808355`, 
       2.8125}, {-1.5626550066464766`, 2.7697483574637447`}}], 
      PolygonBox[{{-1.6752404735808355`, 2.8125}, {-1.6377778151415994`, 
       2.9029428580865546`}, {-1.5626550066464766`, 
       2.7697483574637447`}, {-1.6752404735808355`, 2.8125}}], 
      PolygonBox[{{-1.5625000189670593`, 
       2.915707410443938}, {-1.5626550066464766`, 
       2.7697483574637447`}, {-1.6377778151415994`, 
       2.9029428580865546`}, {-1.5625000189670593`, 2.915707410443938}}], 
      PolygonBox[{{-1.6377778151415994`, 2.9029428580865546`}, {-1.625, 
       3.}, {-1.5625000189670593`, 2.915707410443938}, {-1.6377778151415994`, 
       2.9029428580865546`}}], 
      PolygonBox[{{-1.5625, 3.}, {-1.5625000189670593`, 
       2.915707410443938}, {-1.625, 3.}, {-1.5625, 3.}}], 
      PolygonBox[{{-1.625, 3.}, {-1.6377778151415994`, 
       3.0970571419134454`}, {-1.5625, 3.}, {-1.625, 3.}}], 
      PolygonBox[{{-1.5625000189670593`, 3.084292589556062}, {-1.5625, 
       3.}, {-1.6377778151415994`, 
       3.0970571419134454`}, {-1.5625000189670593`, 3.084292589556062}}], 
      PolygonBox[{{-1.6377778151415994`, 
       3.0970571419134454`}, {-1.6752404735808355`, 
       3.1875}, {-1.5625000189670593`, 
       3.084292589556062}, {-1.6377778151415994`, 3.0970571419134454`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       3.230251642536255}, {-1.5625000189670593`, 
       3.084292589556062}, {-1.6752404735808355`, 
       3.1875}, {-1.5626550066464766`, 3.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, 3.1875}, {-1.7348349570550448`, 
       3.2651650429449552`}, {-1.5626550066464766`, 
       3.230251642536255}, {-1.6752404735808355`, 3.1875}}], 
      PolygonBox[{{-1.5950572556670028`, 
       3.404942744332997}, {-1.5626550066464766`, 
       3.230251642536255}, {-1.7348349570550448`, 
       3.2651650429449552`}, {-1.5950572556670028`, 3.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, 3.2651650429449552`}, {-1.8125, 
       3.3247595264191645`}, {-1.5950572556670028`, 
       3.404942744332997}, {-1.7348349570550448`, 3.2651650429449552`}}], 
      PolygonBox[{{-1.769748357463745, 
       3.4373449933535234`}, {-1.5950572556670028`, 
       3.404942744332997}, {-1.8125, 
       3.3247595264191645`}, {-1.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{-1.8125, 3.3247595264191645`}, {-1.9029428580865546`, 
       3.3622221848584006`}, {-1.769748357463745, 
       3.4373449933535234`}, {-1.8125, 3.3247595264191645`}}], 
      PolygonBox[{{-1.9157074104439396`, 
       3.437499981032941}, {-1.769748357463745, 
       3.4373449933535234`}, {-1.9029428580865546`, 
       3.3622221848584006`}, {-1.9157074104439396`, 3.437499981032941}}], 
      PolygonBox[{{-1.9029428580865546`, 3.3622221848584006`}, {-2., 
       3.375}, {-1.9157074104439396`, 
       3.437499981032941}, {-1.9029428580865546`, 3.3622221848584006`}}], 
      PolygonBox[{{-1.9998944727795123`, 3.4375}, {-1.9157074104439396`, 
       3.437499981032941}, {-2., 3.375}, {-1.9998944727795123`, 3.4375}}], 
      PolygonBox[{{-2., 3.375}, {-2.097057141913445, 
       3.3622221848584006`}, {-1.9998944727795123`, 3.4375}, {-2., 3.375}}], 
      PolygonBox[{{-2.084292589556057, 
       3.437499981032941}, {-1.9998944727795123`, 
       3.4375}, {-2.097057141913445, 
       3.3622221848584006`}, {-2.084292589556057, 3.437499981032941}}], 
      PolygonBox[{{-2.097057141913445, 3.3622221848584006`}, {-2.1875, 
       3.3247595264191645`}, {-2.084292589556057, 
       3.437499981032941}, {-2.097057141913445, 3.3622221848584006`}}], 
      PolygonBox[{{-2.230251642536255, 
       3.4373449933535234`}, {-2.084292589556057, 
       3.437499981032941}, {-2.1875, 
       3.3247595264191645`}, {-2.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{-2.1875, 3.3247595264191645`}, {-2.2651650429449552`, 
       3.2651650429449552`}, {-2.230251642536255, 
       3.4373449933535234`}, {-2.1875, 3.3247595264191645`}}], 
      PolygonBox[{{-2.404942744332997, 
       3.404942744332997}, {-2.230251642536255, 
       3.4373449933535234`}, {-2.2651650429449552`, 
       3.2651650429449552`}, {-2.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, 
       3.2651650429449552`}, {-2.3247595264191645`, 
       3.1875}, {-2.404942744332997, 
       3.404942744332997}, {-2.2651650429449552`, 3.2651650429449552`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       3.2302516425362553`}, {-2.404942744332997, 
       3.404942744332997}, {-2.3247595264191645`, 
       3.1875}, {-2.4373449933535234`, 3.2302516425362553`}}], 
      PolygonBox[{{-2.3247595264191645`, 3.1875}, {-2.3622221848584006`, 
       3.0970571419134454`}, {-2.4373449933535234`, 
       3.2302516425362553`}, {-2.3247595264191645`, 3.1875}}], 
      PolygonBox[{{-2.437499981032941, 
       3.0842925895560622`}, {-2.4373449933535234`, 
       3.2302516425362553`}, {-2.3622221848584006`, 
       3.0970571419134454`}, {-2.437499981032941, 3.0842925895560622`}}], 
      PolygonBox[{{-2.3622221848584006`, 3.0970571419134454`}, {-2.375, 
       3.}, {-2.437499981032941, 3.0842925895560622`}, {-2.3622221848584006`, 
       3.0970571419134454`}}], 
      PolygonBox[{{-2.4375, 3.0001231780629953`}, {-2.437499981032941, 
       3.0842925895560622`}, {-2.375, 3.}, {-2.4375, 3.0001231780629953`}}], 
      PolygonBox[{{-2.375, 3.}, {-2.3622221848584006`, 
       2.902942858086555}, {-2.4375, 3.0001231780629953`}, {-2.375, 3.}}], 
      PolygonBox[{{-2.437499981032941, 2.915707410443945}, {-2.4375, 
       3.0001231780629953`}, {-2.3622221848584006`, 
       2.902942858086555}, {-2.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-2.3622221848584006`, 
       2.902942858086555}, {-2.3247595264191645`, 
       2.8125}, {-2.437499981032941, 
       2.915707410443945}, {-2.3622221848584006`, 2.902942858086555}}], 
      PolygonBox[{{-2.4373449933535234`, 
       2.769748357463745}, {-2.437499981032941, 
       2.915707410443945}, {-2.3247595264191645`, 
       2.8125}, {-2.4373449933535234`, 2.769748357463745}}], 
      PolygonBox[{{-2.3247595264191645`, 2.8125}, {-2.2651650429449552`, 
       2.7348349570550448`}, {-2.4373449933535234`, 
       2.769748357463745}, {-2.3247595264191645`, 2.8125}}], 
      PolygonBox[{{-2.404942744332997, 
       2.595057255667003}, {-2.4373449933535234`, 
       2.769748357463745}, {-2.2651650429449552`, 
       2.7348349570550448`}, {-2.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-2.2651650429449552`, 2.7348349570550448`}, {-2.1875, 
       2.6752404735808355`}, {-2.404942744332997, 
       2.595057255667003}, {-2.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{-2.230251642536255, 
       2.5626550066464766`}, {-2.404942744332997, 
       2.595057255667003}, {-2.1875, 
       2.6752404735808355`}, {-2.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-2.1875, 2.6752404735808355`}, {-2.0970571419134454`, 
       2.6377778151415994`}, {-2.230251642536255, 
       2.5626550066464766`}, {-2.1875, 2.6752404735808355`}}], 
      PolygonBox[{{-2.084292589556064, 
       2.562500018967059}, {-2.230251642536255, 
       2.5626550066464766`}, {-2.0970571419134454`, 
       2.6377778151415994`}, {-2.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-2.0970571419134454`, 2.6377778151415994`}, {-2., 
       2.625}, {-2.084292589556064, 2.562500018967059}, {-2.0970571419134454`,
        2.6377778151415994`}}], 
      PolygonBox[{{-1.999865158168957, 2.5625}, {-2.084292589556064, 
       2.562500018967059}, {-2., 2.625}, {-1.999865158168957, 2.5625}}], 
      PolygonBox[{{-2., 2.625}, {-1.9029428580865548`, 
       2.6377778151415994`}, {-1.999865158168957, 2.5625}, {-2., 2.625}}], 
      PolygonBox[{{-1.9157074104439469`, 
       2.562500018967059}, {-1.999865158168957, 
       2.5625}, {-1.9029428580865548`, 
       2.6377778151415994`}, {-1.9157074104439469`, 2.562500018967059}}], 
      PolygonBox[{{-1.9029428580865548`, 
       2.6377778151415994`}, {-1.8125000000000002`, 
       2.6752404735808355`}, {-1.9157074104439469`, 
       2.562500018967059}, {-1.9029428580865548`, 2.6377778151415994`}}], 
      PolygonBox[{{-1.7697483574637454`, 
       2.5626550066464766`}, {-1.9157074104439469`, 
       2.562500018967059}, {-1.8125000000000002`, 
       2.6752404735808355`}, {-1.7697483574637454`, 2.5626550066464766`}}], 
      PolygonBox[{{-1.8125000000000002`, 
       2.6752404735808355`}, {-1.7348349570550448`, 
       2.7348349570550448`}, {-1.7697483574637454`, 
       2.5626550066464766`}, {-1.8125000000000002`, 2.6752404735808355`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       2.595057255667003}, {-1.7697483574637454`, 
       2.5626550066464766`}, {-1.7348349570550448`, 
       2.7348349570550448`}, {-1.5950572556670028`, 2.595057255667003}}], 
      PolygonBox[{{-1.7348349570550448`, 
       2.7348349570550448`}, {-1.7348349570550448`, 
       2.7348349570550448`}, {-1.5950572556670028`, 
       2.595057255667003}, {-1.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       2.595057255667003}, {-1.5950572556670028`, 
       2.595057255667003}, {-1.7348349570550448`, 
       2.7348349570550448`}, {-1.5950572556670028`, 2.595057255667003}}], 
      PolygonBox[{{-1.5950572556670028`, 
       2.595057255667003}, {-1.5626550066464766`, 2.7697483574637447`}, {-1.5,
        2.5}, {-1.5950572556670028`, 2.595057255667003}}], 
      PolygonBox[{{-1.5, 2.642337217350632}, {-1.5, 
       2.5}, {-1.5626550066464766`, 2.7697483574637447`}, {-1.5, 
       2.642337217350632}}], 
      PolygonBox[{{-1.5626550066464766`, 
       2.7697483574637447`}, {-1.5625000189670593`, 2.915707410443938}, {-1.5,
        2.642337217350632}, {-1.5626550066464766`, 2.7697483574637447`}}], 
      PolygonBox[{{-1.5, 2.79409099469826}, {-1.5, 
       2.642337217350632}, {-1.5625000189670593`, 2.915707410443938}, {-1.5, 
       2.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, 2.915707410443938}, {-1.5625, 
       3.}, {-1.5, 2.79409099469826}, {-1.5625000189670593`, 
       2.915707410443938}}], 
      PolygonBox[{{-1.5, 3.}, {-1.5, 2.79409099469826}, {-1.5625, 3.}, {-1.5, 
       3.}}], PolygonBox[{{-1.5625, 3.}, {-1.5625000189670593`, 
       3.084292589556062}, {-1.5, 3.}, {-1.5625, 3.}}], 
      PolygonBox[{{-1.5, 3.20590900530174}, {-1.5, 3.}, {-1.5625000189670593`,
        3.084292589556062}, {-1.5, 3.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, 
       3.084292589556062}, {-1.5626550066464766`, 3.230251642536255}, {-1.5, 
       3.20590900530174}, {-1.5625000189670593`, 3.084292589556062}}], 
      PolygonBox[{{-1.5, 3.3576627826493675`}, {-1.5, 
       3.20590900530174}, {-1.5626550066464766`, 3.230251642536255}, {-1.5, 
       3.3576627826493675`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       3.230251642536255}, {-1.5950572556670028`, 3.404942744332997}, {-1.5, 
       3.3576627826493675`}, {-1.5626550066464766`, 3.230251642536255}}], 
      PolygonBox[{{-1.508553435038814, 3.491446564961186}, {-1.5, 
       3.3576627826493675`}, {-1.5950572556670028`, 
       3.404942744332997}, {-1.508553435038814, 3.491446564961186}}], 
      PolygonBox[{{-1.5950572556670028`, 
       3.404942744332997}, {-1.769748357463745, 
       3.4373449933535234`}, {-1.508553435038814, 
       3.491446564961186}, {-1.5950572556670028`, 3.404942744332997}}], 
      PolygonBox[{{-1.6423372173506319`, 3.5}, {-1.508553435038814, 
       3.491446564961186}, {-1.769748357463745, 
       3.4373449933535234`}, {-1.6423372173506319`, 3.5}}], 
      PolygonBox[{{-1.769748357463745, 
       3.4373449933535234`}, {-1.9157074104439396`, 
       3.437499981032941}, {-1.6423372173506319`, 3.5}, {-1.769748357463745, 
       3.4373449933535234`}}], 
      PolygonBox[{{-1.7940909946267443`, 3.5}, {-1.6423372173506319`, 
       3.5}, {-1.9157074104439396`, 3.437499981032941}, {-1.7940909946267443`,
        3.5}}], 
      PolygonBox[{{-1.9157074104439396`, 
       3.437499981032941}, {-1.9998944727795123`, 
       3.4375}, {-1.7940909946267443`, 3.5}, {-1.9157074104439396`, 
       3.437499981032941}}], 
      PolygonBox[{{-1.92205804197311, 3.5}, {-1.7940909946267443`, 
       3.5}, {-1.9998944727795123`, 3.4375}, {-1.92205804197311, 3.5}}], 
      PolygonBox[{{-1.9998944727795123`, 3.4375}, {-2.084292589556057, 
       3.437499981032941}, {-1.92205804197311, 3.5}, {-1.9998944727795123`, 
       3.4375}}], 
      PolygonBox[{{-2.2059090053044454`, 3.5}, {-1.92205804197311, 
       3.5}, {-2.084292589556057, 3.437499981032941}, {-2.2059090053044454`, 
       3.5}}], PolygonBox[{{-2.084292589556057, 
       3.437499981032941}, {-2.230251642536255, 
       3.4373449933535234`}, {-2.2059090053044454`, 3.5}, {-2.084292589556057,
        3.437499981032941}}], 
      PolygonBox[{{-2.357662782649366, 3.5}, {-2.2059090053044454`, 
       3.5}, {-2.230251642536255, 3.4373449933535234`}, {-2.357662782649366, 
       3.5}}], PolygonBox[{{-2.230251642536255, 
       3.4373449933535234`}, {-2.404942744332997, 
       3.404942744332997}, {-2.357662782649366, 3.5}, {-2.230251642536255, 
       3.4373449933535234`}}], 
      PolygonBox[{{-1.5, 3.5}, {-2.357662782649366, 3.5}, {-2.404942744332997,
        3.404942744332997}, {-1.5, 3.5}}], 
      PolygonBox[{{-2.404942744332997, 
       3.404942744332997}, {-2.4373449933535234`, 3.2302516425362553`}, {-1.5,
        3.5}, {-2.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{-2.5, 3.357662782649369}, {-1.5, 
       3.5}, {-2.4373449933535234`, 3.2302516425362553`}, {-2.5, 
       3.357662782649369}}], 
      PolygonBox[{{-2.4373449933535234`, 
       3.2302516425362553`}, {-2.437499981032941, 3.0842925895560622`}, {-2.5,
        3.357662782649369}, {-2.4373449933535234`, 3.2302516425362553`}}], 
      PolygonBox[{{-2.5, 3.205909005282899}, {-2.5, 
       3.357662782649369}, {-2.437499981032941, 3.0842925895560622`}, {-2.5, 
       3.205909005282899}}], 
      PolygonBox[{{-2.437499981032941, 3.0842925895560622`}, {-2.4375, 
       3.0001231780629953`}, {-2.5, 3.205909005282899}, {-2.437499981032941, 
       3.0842925895560622`}}], 
      PolygonBox[{{-2.5, 3.0806786667587}, {-2.5, 
       3.205909005282899}, {-2.4375, 3.0001231780629953`}, {-2.5, 
       3.0806786667587}}], 
      PolygonBox[{{-2.4375, 3.0001231780629953`}, {-2.437499981032941, 
       2.915707410443945}, {-2.5, 3.0806786667587}, {-2.4375, 
       3.0001231780629953`}}], 
      PolygonBox[{{-2.5, 2.7940909948547215`}, {-2.5, 
       3.0806786667587}, {-2.437499981032941, 2.915707410443945}, {-2.5, 
       2.7940909948547215`}}], 
      PolygonBox[{{-2.437499981032941, 
       2.915707410443945}, {-2.4373449933535234`, 2.769748357463745}, {-2.5, 
       2.7940909948547215`}, {-2.437499981032941, 2.915707410443945}}], 
      PolygonBox[{{-2.5, 2.6423372173506348`}, {-2.5, 
       2.7940909948547215`}, {-2.4373449933535234`, 2.769748357463745}, {-2.5,
        2.6423372173506348`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       2.769748357463745}, {-2.404942744332997, 2.595057255667003}, {-2.5, 
       2.6423372173506348`}, {-2.4373449933535234`, 2.769748357463745}}], 
      PolygonBox[{{-2.5, 3.5}, {-2.5, 
       2.6423372173506348`}, {-2.404942744332997, 2.595057255667003}, {-2.5, 
       3.5}}], PolygonBox[{{-2.404942744332997, 
       2.595057255667003}, {-2.230251642536255, 2.5626550066464766`}, {-2.5, 
       3.5}, {-2.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{-2.5, 2.5}, {-2.5, 3.5}, {-2.230251642536255, 
       2.5626550066464766`}, {-2.5, 2.5}}], 
      PolygonBox[{{-2.230251642536255, 
       2.5626550066464766`}, {-2.084292589556064, 2.562500018967059}, {-2.5, 
       2.5}, {-2.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-2.205909005566828, 2.5}, {-2.5, 2.5}, {-2.084292589556064,
        2.562500018967059}, {-2.205909005566828, 2.5}}], 
      PolygonBox[{{-2.084292589556064, 
       2.562500018967059}, {-1.999865158168957, 2.5625}, {-2.205909005566828, 
       2.5}, {-2.084292589556064, 2.562500018967059}}], 
      PolygonBox[{{-1.9176761295989384`, 2.5}, {-2.205909005566828, 
       2.5}, {-1.999865158168957, 2.5625}, {-1.9176761295989384`, 2.5}}], 
      PolygonBox[{{-1.999865158168957, 2.5625}, {-1.9157074104439469`, 
       2.562500018967059}, {-1.9176761295989384`, 2.5}, {-1.999865158168957, 
       2.5625}}], 
      PolygonBox[{{-1.7940909946396026`, 2.5}, {-1.9176761295989384`, 
       2.5}, {-1.9157074104439469`, 2.562500018967059}, {-1.7940909946396026`,
        2.5}}], 
      PolygonBox[{{-1.9157074104439469`, 
       2.562500018967059}, {-1.7697483574637454`, 
       2.5626550066464766`}, {-1.7940909946396026`, 
       2.5}, {-1.9157074104439469`, 2.562500018967059}}], 
      PolygonBox[{{-1.642337217350629, 2.5}, {-1.7940909946396026`, 
       2.5}, {-1.7697483574637454`, 2.5626550066464766`}, {-1.642337217350629,
        2.5}}], 
      PolygonBox[{{-1.7697483574637454`, 
       2.5626550066464766`}, {-1.5950572556670028`, 
       2.595057255667003}, {-1.642337217350629, 2.5}, {-1.7697483574637454`, 
       2.5626550066464766`}}], 
      PolygonBox[{{-1.5, 2.5}, {-1.642337217350629, 
       2.5}, {-1.5950572556670028`, 2.595057255667003}, {-1.5, 2.5}}], 
      PolygonBox[{{-1.5950572556670028`, 
       2.595057255667003}, {-1.5950572556670028`, 2.595057255667003}, {-1.5, 
       2.5}, {-1.5950572556670028`, 2.595057255667003}}], 
      PolygonBox[{{-1.5, 2.5}, {-1.5, 2.5}, {-1.5950572556670028`, 
       2.595057255667003}, {-1.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, 4.}, {-2.4791666666666665`, 4.}, {-2.4583333333333335`, 
       4.}, {-2.4375, 4.}, {-2.4166666666666665`, 4.}, {-2.3958333333333335`, 
       4.}, {-2.375, 4.}, {-2.375, 4.}, {-2.3958333333333335`, 
       4.}, {-2.4166666666666665`, 4.}, {-2.4375, 4.}, {-2.4583333333333335`, 
       4.}, {-2.4791666666666665`, 4.}, {-2.5, 4.}, {-2.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, 4.}, {-1.6041666666666667`, 
       4.}, {-1.5833333333333333`, 4.}, {-1.5625, 4.}, {-1.5416666666666667`, 
       4.}, {-1.5208333333333335`, 4.}, {-1.5, 4.}, {-1.5, 
       4.}, {-1.5208333333333333`, 4.}, {-1.5416666666666667`, 4.}, {-1.5625, 
       4.}, {-1.5833333333333333`, 4.}, {-1.6041666666666665`, 4.}, {-1.625, 
       4.}, {-1.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 3.5}, {-2., 3.5208333333333335`}, {-2., 
       3.5416666666666665`}, {-2., 3.5625}, {-2., 3.5833333333333335`}, {-2., 
       3.6041666666666665`}, {-2., 3.625}, {-2., 3.625}, {-2., 
       3.6041666666666665`}, {-2., 3.5833333333333335`}, {-2., 3.5625}, {-2., 
       3.5416666666666665`}, {-2., 3.5208333333333335`}, {-2., 3.5}, {-2., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 4.375}, {-2., 4.395833333333333}, {-2., 
       4.416666666666667}, {-2., 4.4375}, {-2., 4.458333333333333}, {-2., 
       4.479166666666667}, {-2., 4.5}, {-2., 4.5}, {-2., 
       4.479166666666667}, {-2., 4.458333333333333}, {-2., 4.4375}, {-2., 
       4.416666666666667}, {-2., 4.395833333333333}, {-2., 4.375}, {-2., 
       4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, 4.}, {-2.25, 4.}, {-2.125, 4.}, {-2., 4.}, {-1.875, 
       4.}, {-1.75, 4.}, {-1.625, 4.}, {-1.625, 4.}, {-1.75, 4.}, {-1.875, 
       4.}, {-2., 4.}, {-2.125, 4.}, {-2.25, 4.}, {-2.375, 4.}, {-2.375, 
       4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 3.625}, {-2., 3.75}, {-2., 3.875}, {-2., 4.}, {-2., 
       4.125}, {-2., 4.25}, {-2., 4.375}, {-2., 4.375}, {-2., 4.25}, {-2., 
       4.125}, {-2., 4.}, {-2., 3.875}, {-2., 3.75}, {-2., 3.625}, {-2., 
       3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kNoAQedmEVNYSa/9qsXdX5KShZwWFCY/+XE
Waj8AQGHUyonfB4d/L3/3LezOe38gg4QfX/3z1B+cqjXR9AhyfyWaUnRv/1f
M8LjXxXB5BkOgMkGQQf/J0JPjx5jOIAi38B4AKZ/9tvZN/nkmQ7AzDdwP9Eq
PZPpAMz+VxfX7bvylOmABtR9EOOZD8DcD5PfJP1WysqSH1V/A5/DHKj5qUIp
ah8f8MLtv7DDvOpJGi/cfWJ6gY7aUryo7mfgdUiG+g8mzwj1P0w/LHxg5qOE
H9B+WPhuhLoPPfwByOCO+w==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNoIYdVYPALzg8Fg79wPlTDAVR5xgOo+pkO
oKpnIciHmCMI568GmyOApl4ATZ4Pzg8D6+dFU8+DwV+N4j4eNPfD1DPA+WEo
/ofp/7UfVf0PgvxQFPf92I/qfph6ATR5ATT9gmjqhRwAZjhcCw==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, 
       3.7348349570550448`}, {-1.6752404735808355`, 
       3.8125}, {-1.5950572556670028`, 
       3.595057255667003}, {-1.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{-1.5626550066464766`, 
       3.7697483574637447`}, {-1.5950572556670028`, 
       3.595057255667003}, {-1.6752404735808355`, 
       3.8125}, {-1.5626550066464766`, 3.7697483574637447`}}], 
      PolygonBox[{{-1.6752404735808355`, 3.8125}, {-1.6377778151415994`, 
       3.9029428580865546`}, {-1.5626550066464766`, 
       3.7697483574637447`}, {-1.6752404735808355`, 3.8125}}], 
      PolygonBox[{{-1.5625000189670593`, 
       3.915707410443938}, {-1.5626550066464766`, 
       3.7697483574637447`}, {-1.6377778151415994`, 
       3.9029428580865546`}, {-1.5625000189670593`, 3.915707410443938}}], 
      PolygonBox[{{-1.6377778151415994`, 3.9029428580865546`}, {-1.625, 
       4.}, {-1.5625000189670593`, 3.915707410443938}, {-1.6377778151415994`, 
       3.9029428580865546`}}], 
      PolygonBox[{{-1.5625, 4.}, {-1.5625000189670593`, 
       3.915707410443938}, {-1.625, 4.}, {-1.5625, 4.}}], 
      PolygonBox[{{-1.625, 4.}, {-1.6377778151415994`, 
       4.097057141913445}, {-1.5625, 4.}, {-1.625, 4.}}], 
      PolygonBox[{{-1.5625000189670593`, 4.084292589556061}, {-1.5625, 
       4.}, {-1.6377778151415994`, 4.097057141913445}, {-1.5625000189670593`, 
       4.084292589556061}}], 
      PolygonBox[{{-1.6377778151415994`, 
       4.097057141913445}, {-1.6752404735808355`, 
       4.1875}, {-1.5625000189670593`, 
       4.084292589556061}, {-1.6377778151415994`, 4.097057141913445}}], 
      PolygonBox[{{-1.5626550066464766`, 
       4.230251642536255}, {-1.5625000189670593`, 
       4.084292589556061}, {-1.6752404735808355`, 
       4.1875}, {-1.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, 4.1875}, {-1.7348349570550448`, 
       4.265165042944956}, {-1.5626550066464766`, 
       4.230251642536255}, {-1.6752404735808355`, 4.1875}}], 
      PolygonBox[{{-1.5950572556670028`, 
       4.404942744332997}, {-1.5626550066464766`, 
       4.230251642536255}, {-1.7348349570550448`, 
       4.265165042944956}, {-1.5950572556670028`, 4.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, 4.265165042944956}, {-1.8125, 
       4.3247595264191645`}, {-1.5950572556670028`, 
       4.404942744332997}, {-1.7348349570550448`, 4.265165042944956}}], 
      PolygonBox[{{-1.769748357463745, 
       4.437344993353523}, {-1.5950572556670028`, 
       4.404942744332997}, {-1.8125, 
       4.3247595264191645`}, {-1.769748357463745, 4.437344993353523}}], 
      PolygonBox[{{-1.8125, 4.3247595264191645`}, {-1.9029428580865546`, 
       4.362222184858401}, {-1.769748357463745, 4.437344993353523}, {-1.8125, 
       4.3247595264191645`}}], 
      PolygonBox[{{-1.9157074104439396`, 
       4.437499981032941}, {-1.769748357463745, 
       4.437344993353523}, {-1.9029428580865546`, 
       4.362222184858401}, {-1.9157074104439396`, 4.437499981032941}}], 
      PolygonBox[{{-1.9029428580865546`, 4.362222184858401}, {-2., 
       4.375}, {-1.9157074104439396`, 
       4.437499981032941}, {-1.9029428580865546`, 4.362222184858401}}], 
      PolygonBox[{{-1.9998944727795123`, 4.4375}, {-1.9157074104439396`, 
       4.437499981032941}, {-2., 4.375}, {-1.9998944727795123`, 4.4375}}], 
      PolygonBox[{{-2., 4.375}, {-2.097057141913445, 
       4.362222184858401}, {-1.9998944727795123`, 4.4375}, {-2., 4.375}}], 
      PolygonBox[{{-2.084292589556057, 
       4.437499981032941}, {-1.9998944727795123`, 
       4.4375}, {-2.097057141913445, 4.362222184858401}, {-2.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-2.097057141913445, 4.362222184858401}, {-2.1875, 
       4.3247595264191645`}, {-2.084292589556057, 
       4.437499981032941}, {-2.097057141913445, 4.362222184858401}}], 
      PolygonBox[{{-2.230251642536255, 
       4.437344993353523}, {-2.084292589556057, 4.437499981032941}, {-2.1875, 
       4.3247595264191645`}, {-2.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{-2.1875, 4.3247595264191645`}, {-2.2651650429449552`, 
       4.265165042944956}, {-2.230251642536255, 4.437344993353523}, {-2.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{-2.404942744332997, 
       4.404942744332997}, {-2.230251642536255, 
       4.437344993353523}, {-2.2651650429449552`, 
       4.265165042944956}, {-2.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, 
       4.265165042944956}, {-2.3247595264191645`, 
       4.1875}, {-2.404942744332997, 
       4.404942744332997}, {-2.2651650429449552`, 4.265165042944956}}], 
      PolygonBox[{{-2.4373449933535234`, 
       4.230251642536255}, {-2.404942744332997, 
       4.404942744332997}, {-2.3247595264191645`, 
       4.1875}, {-2.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{-2.3247595264191645`, 4.1875}, {-2.3622221848584006`, 
       4.097057141913446}, {-2.4373449933535234`, 
       4.230251642536255}, {-2.3247595264191645`, 4.1875}}], 
      PolygonBox[{{-2.437499981032941, 
       4.084292589556062}, {-2.4373449933535234`, 
       4.230251642536255}, {-2.3622221848584006`, 
       4.097057141913446}, {-2.437499981032941, 4.084292589556062}}], 
      PolygonBox[{{-2.3622221848584006`, 4.097057141913446}, {-2.375, 
       4.}, {-2.437499981032941, 4.084292589556062}, {-2.3622221848584006`, 
       4.097057141913446}}], 
      PolygonBox[{{-2.4375, 4.000123178062996}, {-2.437499981032941, 
       4.084292589556062}, {-2.375, 4.}, {-2.4375, 4.000123178062996}}], 
      PolygonBox[{{-2.375, 4.}, {-2.3622221848584006`, 
       3.902942858086555}, {-2.4375, 4.000123178062996}, {-2.375, 4.}}], 
      PolygonBox[{{-2.437499981032941, 3.915707410443945}, {-2.4375, 
       4.000123178062996}, {-2.3622221848584006`, 
       3.902942858086555}, {-2.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-2.3622221848584006`, 
       3.902942858086555}, {-2.3247595264191645`, 
       3.8125}, {-2.437499981032941, 
       3.915707410443945}, {-2.3622221848584006`, 3.902942858086555}}], 
      PolygonBox[{{-2.4373449933535234`, 
       3.769748357463745}, {-2.437499981032941, 
       3.915707410443945}, {-2.3247595264191645`, 
       3.8125}, {-2.4373449933535234`, 3.769748357463745}}], 
      PolygonBox[{{-2.3247595264191645`, 3.8125}, {-2.2651650429449552`, 
       3.7348349570550448`}, {-2.4373449933535234`, 
       3.769748357463745}, {-2.3247595264191645`, 3.8125}}], 
      PolygonBox[{{-2.404942744332997, 
       3.595057255667003}, {-2.4373449933535234`, 
       3.769748357463745}, {-2.2651650429449552`, 
       3.7348349570550448`}, {-2.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-2.2651650429449552`, 3.7348349570550448`}, {-2.1875, 
       3.6752404735808355`}, {-2.404942744332997, 
       3.595057255667003}, {-2.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{-2.230251642536255, 
       3.5626550066464766`}, {-2.404942744332997, 
       3.595057255667003}, {-2.1875, 
       3.6752404735808355`}, {-2.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-2.1875, 3.6752404735808355`}, {-2.0970571419134454`, 
       3.6377778151415994`}, {-2.230251642536255, 
       3.5626550066464766`}, {-2.1875, 3.6752404735808355`}}], 
      PolygonBox[{{-2.084292589556064, 
       3.562500018967059}, {-2.230251642536255, 
       3.5626550066464766`}, {-2.0970571419134454`, 
       3.6377778151415994`}, {-2.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-2.0970571419134454`, 3.6377778151415994`}, {-2., 
       3.625}, {-2.084292589556064, 3.562500018967059}, {-2.0970571419134454`,
        3.6377778151415994`}}], 
      PolygonBox[{{-1.999865158168957, 3.5625}, {-2.084292589556064, 
       3.562500018967059}, {-2., 3.625}, {-1.999865158168957, 3.5625}}], 
      PolygonBox[{{-2., 3.625}, {-1.9029428580865548`, 
       3.6377778151415994`}, {-1.999865158168957, 3.5625}, {-2., 3.625}}], 
      PolygonBox[{{-1.9157074104439469`, 
       3.562500018967059}, {-1.999865158168957, 
       3.5625}, {-1.9029428580865548`, 
       3.6377778151415994`}, {-1.9157074104439469`, 3.562500018967059}}], 
      PolygonBox[{{-1.9029428580865548`, 
       3.6377778151415994`}, {-1.8125000000000002`, 
       3.6752404735808355`}, {-1.9157074104439469`, 
       3.562500018967059}, {-1.9029428580865548`, 3.6377778151415994`}}], 
      PolygonBox[{{-1.7697483574637454`, 
       3.5626550066464766`}, {-1.9157074104439469`, 
       3.562500018967059}, {-1.8125000000000002`, 
       3.6752404735808355`}, {-1.7697483574637454`, 3.5626550066464766`}}], 
      PolygonBox[{{-1.8125000000000002`, 
       3.6752404735808355`}, {-1.7348349570550448`, 
       3.7348349570550448`}, {-1.7697483574637454`, 
       3.5626550066464766`}, {-1.8125000000000002`, 3.6752404735808355`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       3.595057255667003}, {-1.7697483574637454`, 
       3.5626550066464766`}, {-1.7348349570550448`, 
       3.7348349570550448`}, {-1.5950572556670028`, 3.595057255667003}}], 
      PolygonBox[{{-1.7348349570550448`, 
       3.7348349570550448`}, {-1.7348349570550448`, 
       3.7348349570550448`}, {-1.5950572556670028`, 
       3.595057255667003}, {-1.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       3.595057255667003}, {-1.5950572556670028`, 
       3.595057255667003}, {-1.7348349570550448`, 
       3.7348349570550448`}, {-1.5950572556670028`, 3.595057255667003}}], 
      PolygonBox[{{-1.5950572556670028`, 
       3.595057255667003}, {-1.5626550066464766`, 3.7697483574637447`}, {-1.5,
        3.5}, {-1.5950572556670028`, 3.595057255667003}}], 
      PolygonBox[{{-1.5, 3.642337217350632}, {-1.5, 
       3.5}, {-1.5626550066464766`, 3.7697483574637447`}, {-1.5, 
       3.642337217350632}}], 
      PolygonBox[{{-1.5626550066464766`, 
       3.7697483574637447`}, {-1.5625000189670593`, 3.915707410443938}, {-1.5,
        3.642337217350632}, {-1.5626550066464766`, 3.7697483574637447`}}], 
      PolygonBox[{{-1.5, 3.79409099469826}, {-1.5, 
       3.642337217350632}, {-1.5625000189670593`, 3.915707410443938}, {-1.5, 
       3.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, 3.915707410443938}, {-1.5625, 
       4.}, {-1.5, 3.79409099469826}, {-1.5625000189670593`, 
       3.915707410443938}}], 
      PolygonBox[{{-1.5, 4.}, {-1.5, 3.79409099469826}, {-1.5625, 4.}, {-1.5, 
       4.}}], PolygonBox[{{-1.5625, 4.}, {-1.5625000189670593`, 
       4.084292589556061}, {-1.5, 4.}, {-1.5625, 4.}}], 
      PolygonBox[{{-1.5, 4.20590900530174}, {-1.5, 4.}, {-1.5625000189670593`,
        4.084292589556061}, {-1.5, 4.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, 
       4.084292589556061}, {-1.5626550066464766`, 4.230251642536255}, {-1.5, 
       4.20590900530174}, {-1.5625000189670593`, 4.084292589556061}}], 
      PolygonBox[{{-1.5, 4.357662782649368}, {-1.5, 
       4.20590900530174}, {-1.5626550066464766`, 4.230251642536255}, {-1.5, 
       4.357662782649368}}], 
      PolygonBox[{{-1.5626550066464766`, 
       4.230251642536255}, {-1.5950572556670028`, 4.404942744332997}, {-1.5, 
       4.357662782649368}, {-1.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{-1.508553435038814, 4.491446564961186}, {-1.5, 
       4.357662782649368}, {-1.5950572556670028`, 
       4.404942744332997}, {-1.508553435038814, 4.491446564961186}}], 
      PolygonBox[{{-1.5950572556670028`, 
       4.404942744332997}, {-1.769748357463745, 
       4.437344993353523}, {-1.508553435038814, 
       4.491446564961186}, {-1.5950572556670028`, 4.404942744332997}}], 
      PolygonBox[{{-1.6423372173506319`, 4.5}, {-1.508553435038814, 
       4.491446564961186}, {-1.769748357463745, 
       4.437344993353523}, {-1.6423372173506319`, 4.5}}], 
      PolygonBox[{{-1.769748357463745, 
       4.437344993353523}, {-1.9157074104439396`, 
       4.437499981032941}, {-1.6423372173506319`, 4.5}, {-1.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{-1.7940909946267443`, 4.5}, {-1.6423372173506319`, 
       4.5}, {-1.9157074104439396`, 4.437499981032941}, {-1.7940909946267443`,
        4.5}}], 
      PolygonBox[{{-1.9157074104439396`, 
       4.437499981032941}, {-1.9998944727795123`, 
       4.4375}, {-1.7940909946267443`, 4.5}, {-1.9157074104439396`, 
       4.437499981032941}}], 
      PolygonBox[{{-1.92205804197311, 4.5}, {-1.7940909946267443`, 
       4.5}, {-1.9998944727795123`, 4.4375}, {-1.92205804197311, 4.5}}], 
      PolygonBox[{{-1.9998944727795123`, 4.4375}, {-2.084292589556057, 
       4.437499981032941}, {-1.92205804197311, 4.5}, {-1.9998944727795123`, 
       4.4375}}], 
      PolygonBox[{{-2.2059090053044454`, 4.5}, {-1.92205804197311, 
       4.5}, {-2.084292589556057, 4.437499981032941}, {-2.2059090053044454`, 
       4.5}}], PolygonBox[{{-2.084292589556057, 
       4.437499981032941}, {-2.230251642536255, 
       4.437344993353523}, {-2.2059090053044454`, 4.5}, {-2.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-2.357662782649366, 4.5}, {-2.2059090053044454`, 
       4.5}, {-2.230251642536255, 4.437344993353523}, {-2.357662782649366, 
       4.5}}], PolygonBox[{{-2.230251642536255, 
       4.437344993353523}, {-2.404942744332997, 
       4.404942744332997}, {-2.357662782649366, 4.5}, {-2.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{-1.5, 4.5}, {-2.357662782649366, 4.5}, {-2.404942744332997,
        4.404942744332997}, {-1.5, 4.5}}], 
      PolygonBox[{{-2.404942744332997, 
       4.404942744332997}, {-2.4373449933535234`, 4.230251642536255}, {-1.5, 
       4.5}, {-2.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{-2.5, 4.357662782649369}, {-1.5, 
       4.5}, {-2.4373449933535234`, 4.230251642536255}, {-2.5, 
       4.357662782649369}}], 
      PolygonBox[{{-2.4373449933535234`, 
       4.230251642536255}, {-2.437499981032941, 4.084292589556062}, {-2.5, 
       4.357662782649369}, {-2.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{-2.5, 4.205909005282899}, {-2.5, 
       4.357662782649369}, {-2.437499981032941, 4.084292589556062}, {-2.5, 
       4.205909005282899}}], 
      PolygonBox[{{-2.437499981032941, 4.084292589556062}, {-2.4375, 
       4.000123178062996}, {-2.5, 4.205909005282899}, {-2.437499981032941, 
       4.084292589556062}}], 
      PolygonBox[{{-2.5, 4.0806786667587005`}, {-2.5, 
       4.205909005282899}, {-2.4375, 4.000123178062996}, {-2.5, 
       4.0806786667587005`}}], 
      PolygonBox[{{-2.4375, 4.000123178062996}, {-2.437499981032941, 
       3.915707410443945}, {-2.5, 4.0806786667587005`}, {-2.4375, 
       4.000123178062996}}], 
      PolygonBox[{{-2.5, 3.7940909948547215`}, {-2.5, 
       4.0806786667587005`}, {-2.437499981032941, 3.915707410443945}, {-2.5, 
       3.7940909948547215`}}], 
      PolygonBox[{{-2.437499981032941, 
       3.915707410443945}, {-2.4373449933535234`, 3.769748357463745}, {-2.5, 
       3.7940909948547215`}, {-2.437499981032941, 3.915707410443945}}], 
      PolygonBox[{{-2.5, 3.6423372173506348`}, {-2.5, 
       3.7940909948547215`}, {-2.4373449933535234`, 3.769748357463745}, {-2.5,
        3.6423372173506348`}}], 
      PolygonBox[{{-2.4373449933535234`, 
       3.769748357463745}, {-2.404942744332997, 3.595057255667003}, {-2.5, 
       3.6423372173506348`}, {-2.4373449933535234`, 3.769748357463745}}], 
      PolygonBox[{{-2.5, 4.5}, {-2.5, 
       3.6423372173506348`}, {-2.404942744332997, 3.595057255667003}, {-2.5, 
       4.5}}], PolygonBox[{{-2.404942744332997, 
       3.595057255667003}, {-2.230251642536255, 3.5626550066464766`}, {-2.5, 
       4.5}, {-2.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{-2.5, 3.5}, {-2.5, 4.5}, {-2.230251642536255, 
       3.5626550066464766`}, {-2.5, 3.5}}], 
      PolygonBox[{{-2.230251642536255, 
       3.5626550066464766`}, {-2.084292589556064, 3.562500018967059}, {-2.5, 
       3.5}, {-2.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-2.205909005566828, 3.5}, {-2.5, 3.5}, {-2.084292589556064,
        3.562500018967059}, {-2.205909005566828, 3.5}}], 
      PolygonBox[{{-2.084292589556064, 
       3.562500018967059}, {-1.999865158168957, 3.5625}, {-2.205909005566828, 
       3.5}, {-2.084292589556064, 3.562500018967059}}], 
      PolygonBox[{{-1.9176761295989384`, 3.5}, {-2.205909005566828, 
       3.5}, {-1.999865158168957, 3.5625}, {-1.9176761295989384`, 3.5}}], 
      PolygonBox[{{-1.999865158168957, 3.5625}, {-1.9157074104439469`, 
       3.562500018967059}, {-1.9176761295989384`, 3.5}, {-1.999865158168957, 
       3.5625}}], 
      PolygonBox[{{-1.7940909946396026`, 3.5}, {-1.9176761295989384`, 
       3.5}, {-1.9157074104439469`, 3.562500018967059}, {-1.7940909946396026`,
        3.5}}], 
      PolygonBox[{{-1.9157074104439469`, 
       3.562500018967059}, {-1.7697483574637454`, 
       3.5626550066464766`}, {-1.7940909946396026`, 
       3.5}, {-1.9157074104439469`, 3.562500018967059}}], 
      PolygonBox[{{-1.642337217350629, 3.5}, {-1.7940909946396026`, 
       3.5}, {-1.7697483574637454`, 3.5626550066464766`}, {-1.642337217350629,
        3.5}}], 
      PolygonBox[{{-1.7697483574637454`, 
       3.5626550066464766`}, {-1.5950572556670028`, 
       3.595057255667003}, {-1.642337217350629, 3.5}, {-1.7697483574637454`, 
       3.5626550066464766`}}], 
      PolygonBox[{{-1.5, 3.5}, {-1.642337217350629, 
       3.5}, {-1.5950572556670028`, 3.595057255667003}, {-1.5, 3.5}}], 
      PolygonBox[{{-1.5950572556670028`, 
       3.595057255667003}, {-1.5950572556670028`, 3.595057255667003}, {-1.5, 
       3.5}, {-1.5950572556670028`, 3.595057255667003}}], 
      PolygonBox[{{-1.5, 3.5}, {-1.5, 3.5}, {-1.5950572556670028`, 
       3.595057255667003}, {-1.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5, 5.}, {-2.4791666666666665`, 5.}, {-2.4583333333333335`, 
       5.}, {-2.4375, 5.}, {-2.4166666666666665`, 5.}, {-2.3958333333333335`, 
       5.}, {-2.375, 5.}, {-2.375, 5.}, {-2.3958333333333335`, 
       5.}, {-2.4166666666666665`, 5.}, {-2.4375, 5.}, {-2.4583333333333335`, 
       5.}, {-2.4791666666666665`, 5.}, {-2.5, 5.}, {-2.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.625, 5.}, {-1.6041666666666667`, 
       5.}, {-1.5833333333333333`, 5.}, {-1.5625, 5.}, {-1.5416666666666667`, 
       5.}, {-1.5208333333333335`, 5.}, {-1.5, 5.}, {-1.5, 
       5.}, {-1.5208333333333333`, 5.}, {-1.5416666666666667`, 5.}, {-1.5625, 
       5.}, {-1.5833333333333333`, 5.}, {-1.6041666666666665`, 5.}, {-1.625, 
       5.}, {-1.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 4.5}, {-2., 4.520833333333333}, {-2., 
       4.541666666666667}, {-2., 4.5625}, {-2., 4.583333333333333}, {-2., 
       4.604166666666667}, {-2., 4.625}, {-2., 4.625}, {-2., 
       4.604166666666667}, {-2., 4.583333333333333}, {-2., 4.5625}, {-2., 
       4.541666666666667}, {-2., 4.520833333333333}, {-2., 4.5}, {-2., 
       4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 5.375}, {-2., 5.395833333333333}, {-2., 
       5.416666666666667}, {-2., 5.4375}, {-2., 5.458333333333333}, {-2., 
       5.479166666666667}, {-2., 5.5}, {-2., 5.5}, {-2., 
       5.479166666666667}, {-2., 5.458333333333333}, {-2., 5.4375}, {-2., 
       5.416666666666667}, {-2., 5.395833333333333}, {-2., 5.375}, {-2., 
       5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.375, 5.}, {-2.25, 5.}, {-2.125, 5.}, {-2., 5.}, {-1.875, 
       5.}, {-1.75, 5.}, {-1.625, 5.}, {-1.625, 5.}, {-1.75, 5.}, {-1.875, 
       5.}, {-2., 5.}, {-2.125, 5.}, {-2.25, 5.}, {-2.375, 5.}, {-2.375, 
       5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., 4.625}, {-2., 4.75}, {-2., 4.875}, {-2., 5.}, {-2., 
       5.125}, {-2., 5.25}, {-2., 5.375}, {-2., 5.375}, {-2., 5.25}, {-2., 
       5.125}, {-2., 5.}, {-2., 4.875}, {-2., 4.75}, {-2., 4.625}, {-2., 
       4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQG/9kNoEQedmEVNYSa/9qsXdX5KShZxWFCY/+XE
Waj8ARGHUyonfB4d/L3/3LezOe38og4QfX/3z1B+cqjXR9QhyfyWaUnRv/1f
M8LjXxXB5BkOgMkGUQf/J0JPjx5jOIAi38B4AKZ/9tvZN/nkmQ7AzDdwP9Eq
PZPpAMz+VxfX7bvylOmABtR9EOOZD8DcD5O/2VvGO3eOMKp+B2GHOVDzjTmN
Jld8EILbn3FH2rZosxDcfdzTVywQ7RVCc7+QQzLUfzB5Rqj/Yfph4WMENR8l
/ID2w8L3BtR96OEPAPhzkak=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/9kNoMYdVYPALzg8Fg79wPlTDAVR5xgOo+pkO
oKpnIciHmCMK568GmyOCpl4ETb0wmnohNPWY/NUo7hNCcz9MPQOcH4bif5j+
X/tR1f8gyEd134/9qO6HqRdBUy+Cpl4UTb2YAwDSjFyQ
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-1.7348349570550448`, 
       4.734834957055044}, {-1.6752404735808355`, 
       4.8125}, {-1.5950572556670028`, 
       4.595057255667003}, {-1.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{-1.5626550066464766`, 
       4.769748357463745}, {-1.5950572556670028`, 
       4.595057255667003}, {-1.6752404735808355`, 
       4.8125}, {-1.5626550066464766`, 4.769748357463745}}], 
      PolygonBox[{{-1.6752404735808355`, 4.8125}, {-1.6377778151415994`, 
       4.902942858086555}, {-1.5626550066464766`, 
       4.769748357463745}, {-1.6752404735808355`, 4.8125}}], 
      PolygonBox[{{-1.5625000189670593`, 
       4.915707410443938}, {-1.5626550066464766`, 
       4.769748357463745}, {-1.6377778151415994`, 
       4.902942858086555}, {-1.5625000189670593`, 4.915707410443938}}], 
      PolygonBox[{{-1.6377778151415994`, 4.902942858086555}, {-1.625, 
       5.}, {-1.5625000189670593`, 4.915707410443938}, {-1.6377778151415994`, 
       4.902942858086555}}], 
      PolygonBox[{{-1.5625, 5.}, {-1.5625000189670593`, 
       4.915707410443938}, {-1.625, 5.}, {-1.5625, 5.}}], 
      PolygonBox[{{-1.625, 5.}, {-1.6377778151415994`, 
       5.097057141913445}, {-1.5625, 5.}, {-1.625, 5.}}], 
      PolygonBox[{{-1.5625000189670593`, 5.084292589556061}, {-1.5625, 
       5.}, {-1.6377778151415994`, 5.097057141913445}, {-1.5625000189670593`, 
       5.084292589556061}}], 
      PolygonBox[{{-1.6377778151415994`, 
       5.097057141913445}, {-1.6752404735808355`, 
       5.1875}, {-1.5625000189670593`, 
       5.084292589556061}, {-1.6377778151415994`, 5.097057141913445}}], 
      PolygonBox[{{-1.5626550066464766`, 
       5.230251642536255}, {-1.5625000189670593`, 
       5.084292589556061}, {-1.6752404735808355`, 
       5.1875}, {-1.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{-1.6752404735808355`, 5.1875}, {-1.7348349570550448`, 
       5.265165042944956}, {-1.5626550066464766`, 
       5.230251642536255}, {-1.6752404735808355`, 5.1875}}], 
      PolygonBox[{{-1.5950572556670028`, 
       5.404942744332997}, {-1.5626550066464766`, 
       5.230251642536255}, {-1.7348349570550448`, 
       5.265165042944956}, {-1.5950572556670028`, 5.404942744332997}}], 
      PolygonBox[{{-1.7348349570550448`, 5.265165042944956}, {-1.8125, 
       5.3247595264191645`}, {-1.5950572556670028`, 
       5.404942744332997}, {-1.7348349570550448`, 5.265165042944956}}], 
      PolygonBox[{{-1.769748357463745, 
       5.437344993353523}, {-1.5950572556670028`, 
       5.404942744332997}, {-1.8125, 
       5.3247595264191645`}, {-1.769748357463745, 5.437344993353523}}], 
      PolygonBox[{{-1.8125, 5.3247595264191645`}, {-1.9029428580865546`, 
       5.362222184858401}, {-1.769748357463745, 5.437344993353523}, {-1.8125, 
       5.3247595264191645`}}], 
      PolygonBox[{{-1.9157074104439396`, 
       5.437499981032941}, {-1.769748357463745, 
       5.437344993353523}, {-1.9029428580865546`, 
       5.362222184858401}, {-1.9157074104439396`, 5.437499981032941}}], 
      PolygonBox[{{-1.9029428580865546`, 5.362222184858401}, {-2., 
       5.375}, {-1.9157074104439396`, 
       5.437499981032941}, {-1.9029428580865546`, 5.362222184858401}}], 
      PolygonBox[{{-1.9998944727795123`, 5.4375}, {-1.9157074104439396`, 
       5.437499981032941}, {-2., 5.375}, {-1.9998944727795123`, 5.4375}}], 
      PolygonBox[{{-2., 5.375}, {-2.097057141913445, 
       5.362222184858401}, {-1.9998944727795123`, 5.4375}, {-2., 5.375}}], 
      PolygonBox[{{-2.084292589556057, 
       5.437499981032941}, {-1.9998944727795123`, 
       5.4375}, {-2.097057141913445, 5.362222184858401}, {-2.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-2.097057141913445, 5.362222184858401}, {-2.1875, 
       5.3247595264191645`}, {-2.084292589556057, 
       5.437499981032941}, {-2.097057141913445, 5.362222184858401}}], 
      PolygonBox[{{-2.230251642536255, 
       5.437344993353523}, {-2.084292589556057, 5.437499981032941}, {-2.1875, 
       5.3247595264191645`}, {-2.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{-2.1875, 5.3247595264191645`}, {-2.2651650429449552`, 
       5.265165042944956}, {-2.230251642536255, 5.437344993353523}, {-2.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{-2.404942744332997, 
       5.404942744332997}, {-2.230251642536255, 
       5.437344993353523}, {-2.2651650429449552`, 
       5.265165042944956}, {-2.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-2.2651650429449552`, 
       5.265165042944956}, {-2.3247595264191645`, 
       5.1875}, {-2.404942744332997, 
       5.404942744332997}, {-2.2651650429449552`, 5.265165042944956}}], 
      PolygonBox[{{-2.4373449933535234`, 
       5.230251642536255}, {-2.404942744332997, 
       5.404942744332997}, {-2.3247595264191645`, 
       5.1875}, {-2.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{-2.3247595264191645`, 5.1875}, {-2.3622221848584006`, 
       5.097057141913446}, {-2.4373449933535234`, 
       5.230251642536255}, {-2.3247595264191645`, 5.1875}}], 
      PolygonBox[{{-2.437499981032941, 
       5.084292589556062}, {-2.4373449933535234`, 
       5.230251642536255}, {-2.3622221848584006`, 
       5.097057141913446}, {-2.437499981032941, 5.084292589556062}}], 
      PolygonBox[{{-2.3622221848584006`, 5.097057141913446}, {-2.375, 
       5.}, {-2.437499981032941, 5.084292589556062}, {-2.3622221848584006`, 
       5.097057141913446}}], 
      PolygonBox[{{-2.4375, 5.000123178062996}, {-2.437499981032941, 
       5.084292589556062}, {-2.375, 5.}, {-2.4375, 5.000123178062996}}], 
      PolygonBox[{{-2.375, 5.}, {-2.3622221848584006`, 
       4.902942858086555}, {-2.4375, 5.000123178062996}, {-2.375, 5.}}], 
      PolygonBox[{{-2.437499981032941, 4.915707410443945}, {-2.4375, 
       5.000123178062996}, {-2.3622221848584006`, 
       4.902942858086555}, {-2.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-2.3622221848584006`, 
       4.902942858086555}, {-2.3247595264191645`, 
       4.8125}, {-2.437499981032941, 
       4.915707410443945}, {-2.3622221848584006`, 4.902942858086555}}], 
      PolygonBox[{{-2.4373449933535234`, 
       4.769748357463746}, {-2.437499981032941, 
       4.915707410443945}, {-2.3247595264191645`, 
       4.8125}, {-2.4373449933535234`, 4.769748357463746}}], 
      PolygonBox[{{-2.3247595264191645`, 4.8125}, {-2.2651650429449552`, 
       4.734834957055044}, {-2.4373449933535234`, 
       4.769748357463746}, {-2.3247595264191645`, 4.8125}}], 
      PolygonBox[{{-2.404942744332997, 
       4.595057255667003}, {-2.4373449933535234`, 
       4.769748357463746}, {-2.2651650429449552`, 
       4.734834957055044}, {-2.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-2.2651650429449552`, 4.734834957055044}, {-2.1875, 
       4.6752404735808355`}, {-2.404942744332997, 
       4.595057255667003}, {-2.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{-2.230251642536255, 
       4.562655006646477}, {-2.404942744332997, 4.595057255667003}, {-2.1875, 
       4.6752404735808355`}, {-2.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-2.1875, 4.6752404735808355`}, {-2.0970571419134454`, 
       4.637777815141599}, {-2.230251642536255, 4.562655006646477}, {-2.1875, 
       4.6752404735808355`}}], 
      PolygonBox[{{-2.084292589556064, 
       4.562500018967059}, {-2.230251642536255, 
       4.562655006646477}, {-2.0970571419134454`, 
       4.637777815141599}, {-2.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-2.0970571419134454`, 4.637777815141599}, {-2., 
       4.625}, {-2.084292589556064, 4.562500018967059}, {-2.0970571419134454`,
        4.637777815141599}}], 
      PolygonBox[{{-1.999865158168957, 4.5625}, {-2.084292589556064, 
       4.562500018967059}, {-2., 4.625}, {-1.999865158168957, 4.5625}}], 
      PolygonBox[{{-2., 4.625}, {-1.9029428580865548`, 
       4.637777815141599}, {-1.999865158168957, 4.5625}, {-2., 4.625}}], 
      PolygonBox[{{-1.9157074104439469`, 
       4.562500018967059}, {-1.999865158168957, 
       4.5625}, {-1.9029428580865548`, 
       4.637777815141599}, {-1.9157074104439469`, 4.562500018967059}}], 
      PolygonBox[{{-1.9029428580865548`, 
       4.637777815141599}, {-1.8125000000000002`, 
       4.6752404735808355`}, {-1.9157074104439469`, 
       4.562500018967059}, {-1.9029428580865548`, 4.637777815141599}}], 
      PolygonBox[{{-1.7697483574637454`, 
       4.562655006646477}, {-1.9157074104439469`, 
       4.562500018967059}, {-1.8125000000000002`, 
       4.6752404735808355`}, {-1.7697483574637454`, 4.562655006646477}}], 
      PolygonBox[{{-1.8125000000000002`, 
       4.6752404735808355`}, {-1.7348349570550448`, 
       4.734834957055044}, {-1.7697483574637454`, 
       4.562655006646477}, {-1.8125000000000002`, 4.6752404735808355`}}], 
      PolygonBox[{{-1.5950572556670028`, 
       4.595057255667003}, {-1.7697483574637454`, 
       4.562655006646477}, {-1.7348349570550448`, 
       4.734834957055044}, {-1.5950572556670028`, 4.595057255667003}}], 
      PolygonBox[{{-1.7348349570550448`, 
       4.734834957055044}, {-1.7348349570550448`, 
       4.734834957055044}, {-1.5950572556670028`, 
       4.595057255667003}, {-1.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{-1.5950572556670028`, 
       4.595057255667003}, {-1.5950572556670028`, 
       4.595057255667003}, {-1.7348349570550448`, 
       4.734834957055044}, {-1.5950572556670028`, 4.595057255667003}}], 
      PolygonBox[{{-1.5950572556670028`, 
       4.595057255667003}, {-1.5626550066464766`, 4.769748357463745}, {-1.5, 
       4.5}, {-1.5950572556670028`, 4.595057255667003}}], 
      PolygonBox[{{-1.5, 4.642337217350632}, {-1.5, 
       4.5}, {-1.5626550066464766`, 4.769748357463745}, {-1.5, 
       4.642337217350632}}], 
      PolygonBox[{{-1.5626550066464766`, 
       4.769748357463745}, {-1.5625000189670593`, 4.915707410443938}, {-1.5, 
       4.642337217350632}, {-1.5626550066464766`, 4.769748357463745}}], 
      PolygonBox[{{-1.5, 4.79409099469826}, {-1.5, 
       4.642337217350632}, {-1.5625000189670593`, 4.915707410443938}, {-1.5, 
       4.79409099469826}}], 
      PolygonBox[{{-1.5625000189670593`, 4.915707410443938}, {-1.5625, 
       5.}, {-1.5, 4.79409099469826}, {-1.5625000189670593`, 
       4.915707410443938}}], 
      PolygonBox[{{-1.5, 5.}, {-1.5, 4.79409099469826}, {-1.5625, 5.}, {-1.5, 
       5.}}], PolygonBox[{{-1.5625, 5.}, {-1.5625000189670593`, 
       5.084292589556061}, {-1.5, 5.}, {-1.5625, 5.}}], 
      PolygonBox[{{-1.5, 5.20590900530174}, {-1.5, 5.}, {-1.5625000189670593`,
        5.084292589556061}, {-1.5, 5.20590900530174}}], 
      PolygonBox[{{-1.5625000189670593`, 
       5.084292589556061}, {-1.5626550066464766`, 5.230251642536255}, {-1.5, 
       5.20590900530174}, {-1.5625000189670593`, 5.084292589556061}}], 
      PolygonBox[{{-1.5, 5.357662782649368}, {-1.5, 
       5.20590900530174}, {-1.5626550066464766`, 5.230251642536255}, {-1.5, 
       5.357662782649368}}], 
      PolygonBox[{{-1.5626550066464766`, 
       5.230251642536255}, {-1.5950572556670028`, 5.404942744332997}, {-1.5, 
       5.357662782649368}, {-1.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{-1.508553435038814, 5.491446564961186}, {-1.5, 
       5.357662782649368}, {-1.5950572556670028`, 
       5.404942744332997}, {-1.508553435038814, 5.491446564961186}}], 
      PolygonBox[{{-1.5950572556670028`, 
       5.404942744332997}, {-1.769748357463745, 
       5.437344993353523}, {-1.508553435038814, 
       5.491446564961186}, {-1.5950572556670028`, 5.404942744332997}}], 
      PolygonBox[{{-1.6423372173506319`, 5.5}, {-1.508553435038814, 
       5.491446564961186}, {-1.769748357463745, 
       5.437344993353523}, {-1.6423372173506319`, 5.5}}], 
      PolygonBox[{{-1.769748357463745, 
       5.437344993353523}, {-1.9157074104439396`, 
       5.437499981032941}, {-1.6423372173506319`, 5.5}, {-1.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{-1.7940909946267443`, 5.5}, {-1.6423372173506319`, 
       5.5}, {-1.9157074104439396`, 5.437499981032941}, {-1.7940909946267443`,
        5.5}}], 
      PolygonBox[{{-1.9157074104439396`, 
       5.437499981032941}, {-1.9998944727795123`, 
       5.4375}, {-1.7940909946267443`, 5.5}, {-1.9157074104439396`, 
       5.437499981032941}}], 
      PolygonBox[{{-1.92205804197311, 5.5}, {-1.7940909946267443`, 
       5.5}, {-1.9998944727795123`, 5.4375}, {-1.92205804197311, 5.5}}], 
      PolygonBox[{{-1.9998944727795123`, 5.4375}, {-2.084292589556057, 
       5.437499981032941}, {-1.92205804197311, 5.5}, {-1.9998944727795123`, 
       5.4375}}], 
      PolygonBox[{{-2.2059090053044454`, 5.5}, {-1.92205804197311, 
       5.5}, {-2.084292589556057, 5.437499981032941}, {-2.2059090053044454`, 
       5.5}}], PolygonBox[{{-2.084292589556057, 
       5.437499981032941}, {-2.230251642536255, 
       5.437344993353523}, {-2.2059090053044454`, 5.5}, {-2.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-2.357662782649366, 5.5}, {-2.2059090053044454`, 
       5.5}, {-2.230251642536255, 5.437344993353523}, {-2.357662782649366, 
       5.5}}], 
      PolygonBox[{{-2.230251642536255, 
       5.437344993353523}, {-2.404942744332997, 
       5.404942744332997}, {-2.357662782649366, 5.5}, {-2.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{-1.5, 5.5}, {-2.357662782649366, 5.5}, {-2.404942744332997,
        5.404942744332997}, {-1.5, 5.5}}], 
      PolygonBox[{{-2.404942744332997, 
       5.404942744332997}, {-2.4373449933535234`, 5.230251642536255}, {-1.5, 
       5.5}, {-2.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{-2.5, 5.357662782649369}, {-1.5, 
       5.5}, {-2.4373449933535234`, 5.230251642536255}, {-2.5, 
       5.357662782649369}}], 
      PolygonBox[{{-2.4373449933535234`, 
       5.230251642536255}, {-2.437499981032941, 5.084292589556062}, {-2.5, 
       5.357662782649369}, {-2.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{-2.5, 5.205909005282899}, {-2.5, 
       5.357662782649369}, {-2.437499981032941, 5.084292589556062}, {-2.5, 
       5.205909005282899}}], 
      PolygonBox[{{-2.437499981032941, 5.084292589556062}, {-2.4375, 
       5.000123178062996}, {-2.5, 5.205909005282899}, {-2.437499981032941, 
       5.084292589556062}}], 
      PolygonBox[{{-2.5, 5.0806786667587005`}, {-2.5, 
       5.205909005282899}, {-2.4375, 5.000123178062996}, {-2.5, 
       5.0806786667587005`}}], 
      PolygonBox[{{-2.4375, 5.000123178062996}, {-2.437499981032941, 
       4.915707410443945}, {-2.5, 5.0806786667587005`}, {-2.4375, 
       5.000123178062996}}], 
      PolygonBox[{{-2.5, 4.794090994854722}, {-2.5, 
       5.0806786667587005`}, {-2.437499981032941, 4.915707410443945}, {-2.5, 
       4.794090994854722}}], 
      PolygonBox[{{-2.437499981032941, 
       4.915707410443945}, {-2.4373449933535234`, 4.769748357463746}, {-2.5, 
       4.794090994854722}, {-2.437499981032941, 4.915707410443945}}], 
      PolygonBox[{{-2.5, 4.642337217350635}, {-2.5, 
       4.794090994854722}, {-2.4373449933535234`, 4.769748357463746}, {-2.5, 
       4.642337217350635}}], 
      PolygonBox[{{-2.4373449933535234`, 
       4.769748357463746}, {-2.404942744332997, 4.595057255667003}, {-2.5, 
       4.642337217350635}, {-2.4373449933535234`, 4.769748357463746}}], 
      PolygonBox[{{-2.5, 5.5}, {-2.5, 4.642337217350635}, {-2.404942744332997,
        4.595057255667003}, {-2.5, 5.5}}], 
      PolygonBox[{{-2.404942744332997, 
       4.595057255667003}, {-2.230251642536255, 4.562655006646477}, {-2.5, 
       5.5}, {-2.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{-2.5, 4.5}, {-2.5, 5.5}, {-2.230251642536255, 
       4.562655006646477}, {-2.5, 4.5}}], 
      PolygonBox[{{-2.230251642536255, 
       4.562655006646477}, {-2.084292589556064, 4.562500018967059}, {-2.5, 
       4.5}, {-2.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-2.205909005566828, 4.5}, {-2.5, 4.5}, {-2.084292589556064,
        4.562500018967059}, {-2.205909005566828, 4.5}}], 
      PolygonBox[{{-2.084292589556064, 
       4.562500018967059}, {-1.999865158168957, 4.5625}, {-2.205909005566828, 
       4.5}, {-2.084292589556064, 4.562500018967059}}], 
      PolygonBox[{{-1.9176761295989384`, 4.5}, {-2.205909005566828, 
       4.5}, {-1.999865158168957, 4.5625}, {-1.9176761295989384`, 4.5}}], 
      PolygonBox[{{-1.999865158168957, 4.5625}, {-1.9157074104439469`, 
       4.562500018967059}, {-1.9176761295989384`, 4.5}, {-1.999865158168957, 
       4.5625}}], 
      PolygonBox[{{-1.7940909946396026`, 4.5}, {-1.9176761295989384`, 
       4.5}, {-1.9157074104439469`, 4.562500018967059}, {-1.7940909946396026`,
        4.5}}], 
      PolygonBox[{{-1.9157074104439469`, 
       4.562500018967059}, {-1.7697483574637454`, 
       4.562655006646477}, {-1.7940909946396026`, 4.5}, {-1.9157074104439469`,
        4.562500018967059}}], 
      PolygonBox[{{-1.642337217350629, 4.5}, {-1.7940909946396026`, 
       4.5}, {-1.7697483574637454`, 4.562655006646477}, {-1.642337217350629, 
       4.5}}], PolygonBox[{{-1.7697483574637454`, 
       4.562655006646477}, {-1.5950572556670028`, 
       4.595057255667003}, {-1.642337217350629, 4.5}, {-1.7697483574637454`, 
       4.562655006646477}}], 
      PolygonBox[{{-1.5, 4.5}, {-1.642337217350629, 
       4.5}, {-1.5950572556670028`, 4.595057255667003}, {-1.5, 4.5}}], 
      PolygonBox[{{-1.5950572556670028`, 
       4.595057255667003}, {-1.5950572556670028`, 4.595057255667003}, {-1.5, 
       4.5}, {-1.5950572556670028`, 4.595057255667003}}], 
      PolygonBox[{{-1.5, 4.5}, {-1.5, 4.5}, {-1.5950572556670028`, 
       4.595057255667003}, {-1.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, -5.}, {-1.4791666666666667`, -5.}, \
{-1.4583333333333333`, -5.}, {-1.4375, -5.}, {-1.4166666666666667`, -5.}, \
{-1.3958333333333335`, -5.}, {-1.375, -5.}, {-1.375, -5.}, \
{-1.3958333333333333`, -5.}, {-1.4166666666666667`, -5.}, {-1.4375, -5.}, \
{-1.4583333333333333`, -5.}, {-1.4791666666666665`, -5.}, {-1.5, -5.}, {-1.5, \
-5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, -5.}, {-0.6041666666666667, -5.}, \
{-0.5833333333333333, -5.}, {-0.5625, -5.}, {-0.5416666666666667, -5.}, \
{-0.5208333333333334, -5.}, {-0.5, -5.}, {-0.5, -5.}, {-0.5208333333333333, \
-5.}, {-0.5416666666666667, -5.}, {-0.5625, -5.}, {-0.5833333333333333, -5.}, \
{-0.6041666666666666, -5.}, {-0.625, -5.}, {-0.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -5.5}, {-1., -5.479166666666667}, {-1., \
-5.458333333333333}, {-1., -5.4375}, {-1., -5.416666666666667}, {-1., \
-5.395833333333333}, {-1., -5.375}, {-1., -5.375}, {-1., -5.395833333333333}, \
{-1., -5.416666666666667}, {-1., -5.4375}, {-1., -5.458333333333333}, {-1., \
-5.479166666666667}, {-1., -5.5}, {-1., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -4.625}, {-1., -4.604166666666667}, {-1., \
-4.583333333333333}, {-1., -4.5625}, {-1., -4.541666666666667}, {-1., \
-4.520833333333333}, {-1., -4.5}, {-1., -4.5}, {-1., -4.520833333333333}, \
{-1., -4.541666666666667}, {-1., -4.5625}, {-1., -4.583333333333333}, {-1., \
-4.604166666666667}, {-1., -4.625}, {-1., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, -5.}, {-1.25, -5.}, {-1.125, -5.}, {-1., -5.}, \
{-0.875, -5.}, {-0.75, -5.}, {-0.625, -5.}, {-0.625, -5.}, {-0.75, -5.}, \
{-0.875, -5.}, {-1., -5.}, {-1.125, -5.}, {-1.25, -5.}, {-1.375, -5.}, \
{-1.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -5.375}, {-1., -5.25}, {-1., -5.125}, {-1., -5.}, {-1., \
-4.875}, {-1., -4.75}, {-1., -4.625}, {-1., -4.625}, {-1., -4.75}, {-1., \
-4.875}, {-1., -5.}, {-1., -5.125}, {-1., -5.25}, {-1., -5.375}, {-1., \
-5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kNokQMRO1xY12Y82X+zt4x37hzhAw6P772Y
OPspRN5B+MBkzwkzjzQ/32/EaTS54oPQAYi+V/sz7kjbFm0WOnAkb0v2iydv
9nNPX7FAtBcm/wGiv0HowNwTqqe6ez+iyX+G6ze7bb5Z1u4L3PyEvgnc5kZf
4fZfWRxbu/L01/03oO6D6P8Gdz9MXr2o81NSsgiq/gMiB8yh5p/9djannV/0
ACPU/hnKTw71+ogemA9139eM8PhXRaJo7hc9cAzqP5g8E9T/MP1ToOFzDmq+
I3L4Ae2PhIavBtR96OEPAE+UpfE=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNooQOhYPAUzl8FBq/gfAj9AU3+E5r+r2jq
fxDkrwabg+BDzBFGUy+Cpl4ETb0omnoxDH4YivvEDqxGcT9M/Qc0+Vdo+p+i
qX9AkI/qvgdo7n+A5r8HaP5/gBY+iPgCAITyd5Y=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, -5.265165042944956}, \
{-0.6752404735808355, -5.1875}, {-0.5950572556670028, -5.404942744332997}, \
{-0.7348349570550446, -5.265165042944956}}], 
      PolygonBox[{{-0.5626550066464766, -5.230251642536255}, \
{-0.5950572556670028, -5.404942744332997}, {-0.6752404735808355, -5.1875}, \
{-0.5626550066464766, -5.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, -5.1875}, {-0.6377778151415994, \
-5.097057141913445}, {-0.5626550066464766, -5.230251642536255}, \
{-0.6752404735808355, -5.1875}}], 
      PolygonBox[{{-0.5625000189670593, -5.084292589556062}, \
{-0.5626550066464766, -5.230251642536255}, {-0.6377778151415994, \
-5.097057141913445}, {-0.5625000189670593, -5.084292589556062}}], 
      PolygonBox[{{-0.6377778151415994, -5.097057141913445}, {-0.625, -5.}, \
{-0.5625000189670593, -5.084292589556062}, {-0.6377778151415994, \
-5.097057141913445}}], 
      PolygonBox[{{-0.5625, -5.}, {-0.5625000189670593, -5.084292589556062}, \
{-0.625, -5.}, {-0.5625, -5.}}], 
      PolygonBox[{{-0.625, -5.}, {-0.6377778151415994, -4.902942858086555}, \
{-0.5625, -5.}, {-0.625, -5.}}], 
      PolygonBox[{{-0.5625000189670593, -4.915707410443939}, {-0.5625, -5.}, \
{-0.6377778151415994, -4.902942858086555}, {-0.5625000189670593, \
-4.915707410443939}}], 
      PolygonBox[{{-0.6377778151415994, -4.902942858086555}, \
{-0.6752404735808355, -4.8125}, {-0.5625000189670593, -4.915707410443939}, \
{-0.6377778151415994, -4.902942858086555}}], 
      PolygonBox[{{-0.5626550066464766, -4.769748357463745}, \
{-0.5625000189670593, -4.915707410443939}, {-0.6752404735808355, -4.8125}, \
{-0.5626550066464766, -4.769748357463745}}], 
      PolygonBox[{{-0.6752404735808355, -4.8125}, {-0.7348349570550446, \
-4.734834957055044}, {-0.5626550066464766, -4.769748357463745}, \
{-0.6752404735808355, -4.8125}}], 
      PolygonBox[{{-0.5950572556670028, -4.595057255667003}, \
{-0.5626550066464766, -4.769748357463745}, {-0.7348349570550446, \
-4.734834957055044}, {-0.5950572556670028, -4.595057255667003}}], 
      PolygonBox[{{-0.7348349570550446, -4.734834957055044}, {-0.8125, \
-4.6752404735808355`}, {-0.5950572556670028, -4.595057255667003}, \
{-0.7348349570550446, -4.734834957055044}}], 
      PolygonBox[{{-0.7697483574637448, -4.562655006646477}, \
{-0.5950572556670028, -4.595057255667003}, {-0.8125, -4.6752404735808355`}, \
{-0.7697483574637448, -4.562655006646477}}], 
      PolygonBox[{{-0.8125, -4.6752404735808355`}, {-0.9029428580865546, \
-4.637777815141599}, {-0.7697483574637448, -4.562655006646477}, {-0.8125, \
-4.6752404735808355`}}], 
      PolygonBox[{{-0.9157074104439394, -4.562500018967059}, \
{-0.7697483574637448, -4.562655006646477}, {-0.9029428580865546, \
-4.637777815141599}, {-0.9157074104439394, -4.562500018967059}}], 
      PolygonBox[{{-0.9029428580865546, -4.637777815141599}, {-1., -4.625}, \
{-0.9157074104439394, -4.562500018967059}, {-0.9029428580865546, \
-4.637777815141599}}], 
      PolygonBox[{{-0.9998944727795123, -4.5625}, {-0.9157074104439394, \
-4.562500018967059}, {-1., -4.625}, {-0.9998944727795123, -4.5625}}], 
      PolygonBox[{{-1., -4.625}, {-1.0970571419134452`, -4.637777815141599}, \
{-0.9998944727795123, -4.5625}, {-1., -4.625}}], 
      PolygonBox[{{-1.084292589556057, -4.562500018967059}, \
{-0.9998944727795123, -4.5625}, {-1.0970571419134452`, -4.637777815141599}, \
{-1.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-1.0970571419134452`, -4.637777815141599}, {-1.1875, \
-4.6752404735808355`}, {-1.084292589556057, -4.562500018967059}, \
{-1.0970571419134452`, -4.637777815141599}}], 
      PolygonBox[{{-1.230251642536255, -4.562655006646477}, \
{-1.084292589556057, -4.562500018967059}, {-1.1875, -4.6752404735808355`}, \
{-1.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-1.1875, -4.6752404735808355`}, {-1.2651650429449552`, \
-4.734834957055044}, {-1.230251642536255, -4.562655006646477}, {-1.1875, \
-4.6752404735808355`}}], 
      PolygonBox[{{-1.4049427443329972`, -4.595057255667003}, \
{-1.230251642536255, -4.562655006646477}, {-1.2651650429449552`, \
-4.734834957055044}, {-1.4049427443329972`, -4.595057255667003}}], 
      PolygonBox[{{-1.2651650429449552`, -4.734834957055044}, \
{-1.3247595264191645`, -4.8125}, {-1.4049427443329972`, -4.595057255667003}, \
{-1.2651650429449552`, -4.734834957055044}}], 
      PolygonBox[{{-1.4373449933535234`, -4.769748357463745}, \
{-1.4049427443329972`, -4.595057255667003}, {-1.3247595264191645`, -4.8125}, \
{-1.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{-1.3247595264191645`, -4.8125}, {-1.3622221848584006`, \
-4.902942858086554}, {-1.4373449933535234`, -4.769748357463745}, \
{-1.3247595264191645`, -4.8125}}], 
      PolygonBox[{{-1.4374999810329407`, -4.915707410443938}, \
{-1.4373449933535234`, -4.769748357463745}, {-1.3622221848584006`, \
-4.902942858086554}, {-1.4374999810329407`, -4.915707410443938}}], 
      PolygonBox[{{-1.3622221848584006`, -4.902942858086554}, {-1.375, -5.}, \
{-1.4374999810329407`, -4.915707410443938}, {-1.3622221848584006`, \
-4.902942858086554}}], 
      PolygonBox[{{-1.4375, -4.999876821937004}, {-1.4374999810329407`, \
-4.915707410443938}, {-1.375, -5.}, {-1.4375, -4.999876821937004}}], 
      PolygonBox[{{-1.375, -5.}, {-1.3622221848584006`, -5.097057141913445}, \
{-1.4375, -4.999876821937004}, {-1.375, -5.}}], 
      PolygonBox[{{-1.4374999810329407`, -5.084292589556055}, {-1.4375, \
-4.999876821937004}, {-1.3622221848584006`, -5.097057141913445}, \
{-1.4374999810329407`, -5.084292589556055}}], 
      PolygonBox[{{-1.3622221848584006`, -5.097057141913445}, \
{-1.3247595264191645`, -5.1875}, {-1.4374999810329407`, -5.084292589556055}, \
{-1.3622221848584006`, -5.097057141913445}}], 
      PolygonBox[{{-1.4373449933535234`, -5.230251642536254}, \
{-1.4374999810329407`, -5.084292589556055}, {-1.3247595264191645`, -5.1875}, \
{-1.4373449933535234`, -5.230251642536254}}], 
      PolygonBox[{{-1.3247595264191645`, -5.1875}, {-1.2651650429449552`, \
-5.265165042944956}, {-1.4373449933535234`, -5.230251642536254}, \
{-1.3247595264191645`, -5.1875}}], 
      PolygonBox[{{-1.4049427443329972`, -5.404942744332997}, \
{-1.4373449933535234`, -5.230251642536254}, {-1.2651650429449552`, \
-5.265165042944956}, {-1.4049427443329972`, -5.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, -5.265165042944956}, \
{-1.1875000000000002`, -5.3247595264191645`}, {-1.4049427443329972`, \
-5.404942744332997}, {-1.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{-1.230251642536255, -5.437344993353523}, \
{-1.4049427443329972`, -5.404942744332997}, {-1.1875000000000002`, \
-5.3247595264191645`}, {-1.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{-1.1875000000000002`, -5.3247595264191645`}, \
{-1.0970571419134456`, -5.362222184858401}, {-1.230251642536255, \
-5.437344993353523}, {-1.1875000000000002`, -5.3247595264191645`}}], 
      PolygonBox[{{-1.0842925895560642`, -5.437499981032941}, \
{-1.230251642536255, -5.437344993353523}, {-1.0970571419134456`, \
-5.362222184858401}, {-1.0842925895560642`, -5.437499981032941}}], 
      PolygonBox[{{-1.0970571419134456`, -5.362222184858401}, \
{-0.9999999999999999, -5.375}, {-1.0842925895560642`, -5.437499981032941}, \
{-1.0970571419134456`, -5.362222184858401}}], 
      PolygonBox[{{-0.999865158168957, -5.4375}, {-1.0842925895560642`, \
-5.437499981032941}, {-0.9999999999999999, -5.375}, {-0.999865158168957, \
-5.4375}}], 
      PolygonBox[{{-0.9999999999999999, -5.375}, {-0.9029428580865548, \
-5.362222184858401}, {-0.999865158168957, -5.4375}, {-0.9999999999999999, \
-5.375}}], 
      PolygonBox[{{-0.9157074104439469, -5.437499981032941}, \
{-0.999865158168957, -5.4375}, {-0.9029428580865548, -5.362222184858401}, \
{-0.9157074104439469, -5.437499981032941}}], 
      PolygonBox[{{-0.9029428580865548, -5.362222184858401}, \
{-0.8125000000000002, -5.3247595264191645`}, {-0.9157074104439469, \
-5.437499981032941}, {-0.9029428580865548, -5.362222184858401}}], 
      PolygonBox[{{-0.7697483574637453, -5.437344993353523}, \
{-0.9157074104439469, -5.437499981032941}, {-0.8125000000000002, \
-5.3247595264191645`}, {-0.7697483574637453, -5.437344993353523}}], 
      PolygonBox[{{-0.8125000000000002, -5.3247595264191645`}, \
{-0.7348349570550448, -5.265165042944956}, {-0.7697483574637453, \
-5.437344993353523}, {-0.8125000000000002, -5.3247595264191645`}}], 
      PolygonBox[{{-0.5950572556670028, -5.404942744332997}, \
{-0.7697483574637453, -5.437344993353523}, {-0.7348349570550448, \
-5.265165042944956}, {-0.5950572556670028, -5.404942744332997}}], 
      PolygonBox[{{-0.7348349570550448, -5.265165042944956}, \
{-0.7348349570550446, -5.265165042944956}, {-0.5950572556670028, \
-5.404942744332997}, {-0.7348349570550448, -5.265165042944956}}], 
      PolygonBox[{{-0.5950572556670028, -5.404942744332997}, \
{-0.5950572556670028, -5.404942744332997}, {-0.7348349570550446, \
-5.265165042944956}, {-0.5950572556670028, -5.404942744332997}}], 
      PolygonBox[{{-0.5950572556670028, -5.404942744332997}, \
{-0.5626550066464766, -5.230251642536255}, {-0.5, -5.5}, \
{-0.5950572556670028, -5.404942744332997}}], 
      PolygonBox[{{-0.5, -5.357662782649368}, {-0.5, -5.5}, \
{-0.5626550066464766, -5.230251642536255}, {-0.5, -5.357662782649368}}], 
      PolygonBox[{{-0.5626550066464766, -5.230251642536255}, \
{-0.5625000189670593, -5.084292589556062}, {-0.5, -5.357662782649368}, \
{-0.5626550066464766, -5.230251642536255}}], 
      PolygonBox[{{-0.5, -5.20590900530174}, {-0.5, -5.357662782649368}, \
{-0.5625000189670593, -5.084292589556062}, {-0.5, -5.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, -5.084292589556062}, {-0.5625, -5.}, \
{-0.5, -5.20590900530174}, {-0.5625000189670593, -5.084292589556062}}], 
      PolygonBox[{{-0.5, -5.}, {-0.5, -5.20590900530174}, {-0.5625, -5.}, \
{-0.5, -5.}}], 
      PolygonBox[{{-0.5625, -5.}, {-0.5625000189670593, -4.915707410443939}, \
{-0.5, -5.}, {-0.5625, -5.}}], 
      PolygonBox[{{-0.5, -4.79409099469826}, {-0.5, -5.}, \
{-0.5625000189670593, -4.915707410443939}, {-0.5, -4.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, -4.915707410443939}, \
{-0.5626550066464766, -4.769748357463745}, {-0.5, -4.79409099469826}, \
{-0.5625000189670593, -4.915707410443939}}], 
      PolygonBox[{{-0.5, -4.642337217350632}, {-0.5, -4.79409099469826}, \
{-0.5626550066464766, -4.769748357463745}, {-0.5, -4.642337217350632}}], 
      PolygonBox[{{-0.5626550066464766, -4.769748357463745}, \
{-0.5950572556670028, -4.595057255667003}, {-0.5, -4.642337217350632}, \
{-0.5626550066464766, -4.769748357463745}}], 
      PolygonBox[{{-0.508553435038814, -4.508553435038814}, {-0.5, \
-4.642337217350632}, {-0.5950572556670028, -4.595057255667003}, \
{-0.508553435038814, -4.508553435038814}}], 
      PolygonBox[{{-0.5950572556670028, -4.595057255667003}, \
{-0.7697483574637448, -4.562655006646477}, {-0.508553435038814, \
-4.508553435038814}, {-0.5950572556670028, -4.595057255667003}}], 
      PolygonBox[{{-0.6423372173506319, -4.5}, {-0.508553435038814, \
-4.508553435038814}, {-0.7697483574637448, -4.562655006646477}, \
{-0.6423372173506319, -4.5}}], 
      PolygonBox[{{-0.7697483574637448, -4.562655006646477}, \
{-0.9157074104439394, -4.562500018967059}, {-0.6423372173506319, -4.5}, \
{-0.7697483574637448, -4.562655006646477}}], 
      PolygonBox[{{-0.7940909946267442, -4.5}, {-0.6423372173506319, -4.5}, \
{-0.9157074104439394, -4.562500018967059}, {-0.7940909946267442, -4.5}}], 
      PolygonBox[{{-0.9157074104439394, -4.562500018967059}, \
{-0.9998944727795123, -4.5625}, {-0.7940909946267442, -4.5}, \
{-0.9157074104439394, -4.562500018967059}}], 
      PolygonBox[{{-0.9220580419731099, -4.5}, {-0.7940909946267442, -4.5}, \
{-0.9998944727795123, -4.5625}, {-0.9220580419731099, -4.5}}], 
      PolygonBox[{{-0.9998944727795123, -4.5625}, {-1.084292589556057, \
-4.562500018967059}, {-0.9220580419731099, -4.5}, {-0.9998944727795123, \
-4.5625}}], 
      PolygonBox[{{-1.2059090053044457`, -4.5}, {-0.9220580419731099, -4.5}, \
{-1.084292589556057, -4.562500018967059}, {-1.2059090053044457`, -4.5}}], 
      PolygonBox[{{-1.084292589556057, -4.562500018967059}, \
{-1.230251642536255, -4.562655006646477}, {-1.2059090053044457`, -4.5}, \
{-1.084292589556057, -4.562500018967059}}], 
      PolygonBox[{{-1.3576627826493661`, -4.5}, {-1.2059090053044457`, -4.5}, \
{-1.230251642536255, -4.562655006646477}, {-1.3576627826493661`, -4.5}}], 
      PolygonBox[{{-1.230251642536255, -4.562655006646477}, \
{-1.4049427443329972`, -4.595057255667003}, {-1.3576627826493661`, -4.5}, \
{-1.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{-0.5, -4.5}, {-1.3576627826493661`, -4.5}, \
{-1.4049427443329972`, -4.595057255667003}, {-0.5, -4.5}}], 
      PolygonBox[{{-1.4049427443329972`, -4.595057255667003}, \
{-1.4373449933535234`, -4.769748357463745}, {-0.5, -4.5}, \
{-1.4049427443329972`, -4.595057255667003}}], 
      PolygonBox[{{-1.5, -4.642337217350631}, {-0.5, -4.5}, \
{-1.4373449933535234`, -4.769748357463745}, {-1.5, -4.642337217350631}}], 
      PolygonBox[{{-1.4373449933535234`, -4.769748357463745}, \
{-1.4374999810329407`, -4.915707410443938}, {-1.5, -4.642337217350631}, \
{-1.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{-1.5, -4.794090994717101}, {-1.5, -4.642337217350631}, \
{-1.4374999810329407`, -4.915707410443938}, {-1.5, -4.794090994717101}}], 
      PolygonBox[{{-1.4374999810329407`, -4.915707410443938}, {-1.4375, \
-4.999876821937004}, {-1.5, -4.794090994717101}, {-1.4374999810329407`, \
-4.915707410443938}}], 
      PolygonBox[{{-1.5, -4.9193213332412995`}, {-1.5, -4.794090994717101}, \
{-1.4375, -4.999876821937004}, {-1.5, -4.9193213332412995`}}], 
      PolygonBox[{{-1.4375, -4.999876821937004}, {-1.4374999810329407`, \
-5.084292589556055}, {-1.5, -4.9193213332412995`}, {-1.4375, \
-4.999876821937004}}], 
      PolygonBox[{{-1.5, -5.205909005145278}, {-1.5, -4.9193213332412995`}, \
{-1.4374999810329407`, -5.084292589556055}, {-1.5, -5.205909005145278}}], 
      PolygonBox[{{-1.4374999810329407`, -5.084292589556055}, \
{-1.4373449933535234`, -5.230251642536254}, {-1.5, -5.205909005145278}, \
{-1.4374999810329407`, -5.084292589556055}}], 
      PolygonBox[{{-1.5, -5.357662782649365}, {-1.5, -5.205909005145278}, \
{-1.4373449933535234`, -5.230251642536254}, {-1.5, -5.357662782649365}}], 
      PolygonBox[{{-1.4373449933535234`, -5.230251642536254}, \
{-1.4049427443329972`, -5.404942744332997}, {-1.5, -5.357662782649365}, \
{-1.4373449933535234`, -5.230251642536254}}], 
      PolygonBox[{{-1.5, -4.5}, {-1.5, -5.357662782649365}, \
{-1.4049427443329972`, -5.404942744332997}, {-1.5, -4.5}}], 
      PolygonBox[{{-1.4049427443329972`, -5.404942744332997}, \
{-1.230251642536255, -5.437344993353523}, {-1.5, -4.5}, \
{-1.4049427443329972`, -5.404942744332997}}], 
      PolygonBox[{{-1.5, -5.5}, {-1.5, -4.5}, {-1.230251642536255, \
-5.437344993353523}, {-1.5, -5.5}}], 
      PolygonBox[{{-1.230251642536255, -5.437344993353523}, \
{-1.0842925895560642`, -5.437499981032941}, {-1.5, -5.5}, \
{-1.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{-1.205909005566828, -5.5}, {-1.5, -5.5}, \
{-1.0842925895560642`, -5.437499981032941}, {-1.205909005566828, -5.5}}], 
      PolygonBox[{{-1.0842925895560642`, -5.437499981032941}, \
{-0.999865158168957, -5.4375}, {-1.205909005566828, -5.5}, \
{-1.0842925895560642`, -5.437499981032941}}], 
      PolygonBox[{{-0.9176761295989384, -5.5}, {-1.205909005566828, -5.5}, \
{-0.999865158168957, -5.4375}, {-0.9176761295989384, -5.5}}], 
      PolygonBox[{{-0.999865158168957, -5.4375}, {-0.9157074104439469, \
-5.437499981032941}, {-0.9176761295989384, -5.5}, {-0.999865158168957, \
-5.4375}}], 
      PolygonBox[{{-0.7940909946396026, -5.5}, {-0.9176761295989384, -5.5}, \
{-0.9157074104439469, -5.437499981032941}, {-0.7940909946396026, -5.5}}], 
      PolygonBox[{{-0.9157074104439469, -5.437499981032941}, \
{-0.7697483574637453, -5.437344993353523}, {-0.7940909946396026, -5.5}, \
{-0.9157074104439469, -5.437499981032941}}], 
      PolygonBox[{{-0.642337217350629, -5.5}, {-0.7940909946396026, -5.5}, \
{-0.7697483574637453, -5.437344993353523}, {-0.642337217350629, -5.5}}], 
      PolygonBox[{{-0.7697483574637453, -5.437344993353523}, \
{-0.5950572556670028, -5.404942744332997}, {-0.642337217350629, -5.5}, \
{-0.7697483574637453, -5.437344993353523}}], 
      PolygonBox[{{-0.5, -5.5}, {-0.642337217350629, -5.5}, \
{-0.5950572556670028, -5.404942744332997}, {-0.5, -5.5}}], 
      PolygonBox[{{-0.5950572556670028, -5.404942744332997}, \
{-0.5950572556670028, -5.404942744332997}, {-0.5, -5.5}, \
{-0.5950572556670028, -5.404942744332997}}], 
      PolygonBox[{{-0.5, -5.5}, {-0.5, -5.5}, {-0.5950572556670028, \
-5.404942744332997}, {-0.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, -4.}, {-1.4791666666666667`, -4.}, \
{-1.4583333333333333`, -4.}, {-1.4375, -4.}, {-1.4166666666666667`, -4.}, \
{-1.3958333333333335`, -4.}, {-1.375, -4.}, {-1.375, -4.}, \
{-1.3958333333333333`, -4.}, {-1.4166666666666667`, -4.}, {-1.4375, -4.}, \
{-1.4583333333333333`, -4.}, {-1.4791666666666665`, -4.}, {-1.5, -4.}, {-1.5, \
-4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, -4.}, {-0.6041666666666667, -4.}, \
{-0.5833333333333333, -4.}, {-0.5625, -4.}, {-0.5416666666666667, -4.}, \
{-0.5208333333333334, -4.}, {-0.5, -4.}, {-0.5, -4.}, {-0.5208333333333333, \
-4.}, {-0.5416666666666667, -4.}, {-0.5625, -4.}, {-0.5833333333333333, -4.}, \
{-0.6041666666666666, -4.}, {-0.625, -4.}, {-0.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -4.5}, {-1., -4.479166666666667}, {-1., \
-4.458333333333333}, {-1., -4.4375}, {-1., -4.416666666666667}, {-1., \
-4.395833333333333}, {-1., -4.375}, {-1., -4.375}, {-1., -4.395833333333333}, \
{-1., -4.416666666666667}, {-1., -4.4375}, {-1., -4.458333333333333}, {-1., \
-4.479166666666667}, {-1., -4.5}, {-1., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -3.625}, {-1., -3.6041666666666665`}, {-1., \
-3.5833333333333335`}, {-1., -3.5625}, {-1., -3.5416666666666665`}, {-1., \
-3.5208333333333335`}, {-1., -3.5}, {-1., -3.5}, {-1., -3.5208333333333335`}, \
{-1., -3.5416666666666665`}, {-1., -3.5625}, {-1., -3.5833333333333335`}, \
{-1., -3.6041666666666665`}, {-1., -3.625}, {-1., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, -4.}, {-1.25, -4.}, {-1.125, -4.}, {-1., -4.}, \
{-0.875, -4.}, {-0.75, -4.}, {-0.625, -4.}, {-0.625, -4.}, {-0.75, -4.}, \
{-0.875, -4.}, {-1., -4.}, {-1.125, -4.}, {-1.25, -4.}, {-1.375, -4.}, \
{-1.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -4.375}, {-1., -4.25}, {-1., -4.125}, {-1., -4.}, {-1., \
-3.875}, {-1., -3.75}, {-1., -3.625}, {-1., -3.625}, {-1., -3.75}, {-1., \
-3.875}, {-1., -4.}, {-1., -4.125}, {-1., -4.25}, {-1., -4.375}, {-1., \
-4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kNogQMRO1xY12Y82b9R+q2UlSX/AYfH915M
nP0UIt/Ad2Cy54SZR5qf708VSlH7+ID3AETfq/0XdphXPUnjPXAkb0v2iydv
9ovpBTpqS8HkP0DN5z0w94Tqqe7ej2jyn+H6zW6bb5a1+wI3P6FvAre50Ve4
/VcWx9auPP0V7j6I/m9w98Pk1Ys6PyUlC6DqPyBwwBxq/tlvZ3Pa+QUPMELt
n6H85FCvj+CB+VD3fc0Ij39VJIjq/gbBA8eg/oPJM0H9D9M/BRo+56DmOyKH
H9D+SGj4akDdhx7+AGhDo0M=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNongOhYPAUzl8FBq/gfAj9AU3+E5r+r2jq
fxDkQ/TxwvmrwebyoakXQJMXQNMviKZeCIMfhuI+oQOrUdwPU/8BTf4Vmv6n
aOofEOSjuu8BmvsfoPnvAZr/H+wPQwkfRHwBAAt+dxE=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, -4.265165042944956}, \
{-0.6752404735808355, -4.1875}, {-0.5950572556670028, -4.404942744332997}, \
{-0.7348349570550446, -4.265165042944956}}], 
      PolygonBox[{{-0.5626550066464766, -4.230251642536255}, \
{-0.5950572556670028, -4.404942744332997}, {-0.6752404735808355, -4.1875}, \
{-0.5626550066464766, -4.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, -4.1875}, {-0.6377778151415994, \
-4.097057141913445}, {-0.5626550066464766, -4.230251642536255}, \
{-0.6752404735808355, -4.1875}}], 
      PolygonBox[{{-0.5625000189670593, -4.084292589556062}, \
{-0.5626550066464766, -4.230251642536255}, {-0.6377778151415994, \
-4.097057141913445}, {-0.5625000189670593, -4.084292589556062}}], 
      PolygonBox[{{-0.6377778151415994, -4.097057141913445}, {-0.625, -4.}, \
{-0.5625000189670593, -4.084292589556062}, {-0.6377778151415994, \
-4.097057141913445}}], 
      PolygonBox[{{-0.5625, -4.}, {-0.5625000189670593, -4.084292589556062}, \
{-0.625, -4.}, {-0.5625, -4.}}], 
      PolygonBox[{{-0.625, -4.}, {-0.6377778151415994, -3.9029428580865546`}, \
{-0.5625, -4.}, {-0.625, -4.}}], 
      PolygonBox[{{-0.5625000189670593, -3.915707410443938}, {-0.5625, -4.}, \
{-0.6377778151415994, -3.9029428580865546`}, {-0.5625000189670593, \
-3.915707410443938}}], 
      PolygonBox[{{-0.6377778151415994, -3.9029428580865546`}, \
{-0.6752404735808355, -3.8125}, {-0.5625000189670593, -3.915707410443938}, \
{-0.6377778151415994, -3.9029428580865546`}}], 
      PolygonBox[{{-0.5626550066464766, -3.769748357463745}, \
{-0.5625000189670593, -3.915707410443938}, {-0.6752404735808355, -3.8125}, \
{-0.5626550066464766, -3.769748357463745}}], 
      PolygonBox[{{-0.6752404735808355, -3.8125}, {-0.7348349570550446, \
-3.7348349570550448`}, {-0.5626550066464766, -3.769748357463745}, \
{-0.6752404735808355, -3.8125}}], 
      PolygonBox[{{-0.5950572556670028, -3.595057255667003}, \
{-0.5626550066464766, -3.769748357463745}, {-0.7348349570550446, \
-3.7348349570550448`}, {-0.5950572556670028, -3.595057255667003}}], 
      PolygonBox[{{-0.7348349570550446, -3.7348349570550448`}, {-0.8125, \
-3.6752404735808355`}, {-0.5950572556670028, -3.595057255667003}, \
{-0.7348349570550446, -3.7348349570550448`}}], 
      PolygonBox[{{-0.7697483574637448, -3.5626550066464766`}, \
{-0.5950572556670028, -3.595057255667003}, {-0.8125, -3.6752404735808355`}, \
{-0.7697483574637448, -3.5626550066464766`}}], 
      PolygonBox[{{-0.8125, -3.6752404735808355`}, {-0.9029428580865546, \
-3.6377778151415994`}, {-0.7697483574637448, -3.5626550066464766`}, {-0.8125, \
-3.6752404735808355`}}], 
      PolygonBox[{{-0.9157074104439394, -3.562500018967059}, \
{-0.7697483574637448, -3.5626550066464766`}, {-0.9029428580865546, \
-3.6377778151415994`}, {-0.9157074104439394, -3.562500018967059}}], 
      PolygonBox[{{-0.9029428580865546, -3.6377778151415994`}, {-1., -3.625}, \
{-0.9157074104439394, -3.562500018967059}, {-0.9029428580865546, \
-3.6377778151415994`}}], 
      PolygonBox[{{-0.9998944727795123, -3.5625}, {-0.9157074104439394, \
-3.562500018967059}, {-1., -3.625}, {-0.9998944727795123, -3.5625}}], 
      PolygonBox[{{-1., -3.625}, {-1.0970571419134452`, \
-3.6377778151415994`}, {-0.9998944727795123, -3.5625}, {-1., -3.625}}], 
      PolygonBox[{{-1.084292589556057, -3.562500018967059}, \
{-0.9998944727795123, -3.5625}, {-1.0970571419134452`, -3.6377778151415994`}, \
{-1.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-1.0970571419134452`, -3.6377778151415994`}, {-1.1875, \
-3.6752404735808355`}, {-1.084292589556057, -3.562500018967059}, \
{-1.0970571419134452`, -3.6377778151415994`}}], 
      PolygonBox[{{-1.230251642536255, -3.5626550066464766`}, \
{-1.084292589556057, -3.562500018967059}, {-1.1875, -3.6752404735808355`}, \
{-1.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-1.1875, -3.6752404735808355`}, {-1.2651650429449552`, \
-3.7348349570550448`}, {-1.230251642536255, -3.5626550066464766`}, {-1.1875, \
-3.6752404735808355`}}], 
      PolygonBox[{{-1.4049427443329972`, -3.595057255667003}, \
{-1.230251642536255, -3.5626550066464766`}, {-1.2651650429449552`, \
-3.7348349570550448`}, {-1.4049427443329972`, -3.595057255667003}}], 
      PolygonBox[{{-1.2651650429449552`, -3.7348349570550448`}, \
{-1.3247595264191645`, -3.8125}, {-1.4049427443329972`, -3.595057255667003}, \
{-1.2651650429449552`, -3.7348349570550448`}}], 
      PolygonBox[{{-1.4373449933535234`, -3.7697483574637447`}, \
{-1.4049427443329972`, -3.595057255667003}, {-1.3247595264191645`, -3.8125}, \
{-1.4373449933535234`, -3.7697483574637447`}}], 
      PolygonBox[{{-1.3247595264191645`, -3.8125}, {-1.3622221848584006`, \
-3.9029428580865546`}, {-1.4373449933535234`, -3.7697483574637447`}, \
{-1.3247595264191645`, -3.8125}}], 
      PolygonBox[{{-1.4374999810329407`, -3.9157074104439378`}, \
{-1.4373449933535234`, -3.7697483574637447`}, {-1.3622221848584006`, \
-3.9029428580865546`}, {-1.4374999810329407`, -3.9157074104439378`}}], 
      PolygonBox[{{-1.3622221848584006`, -3.9029428580865546`}, {-1.375, \
-4.}, {-1.4374999810329407`, -3.9157074104439378`}, {-1.3622221848584006`, \
-3.9029428580865546`}}], 
      PolygonBox[{{-1.4375, -3.9998768219370047`}, {-1.4374999810329407`, \
-3.9157074104439378`}, {-1.375, -4.}, {-1.4375, -3.9998768219370047`}}], 
      PolygonBox[{{-1.375, -4.}, {-1.3622221848584006`, -4.097057141913445}, \
{-1.4375, -3.9998768219370047`}, {-1.375, -4.}}], 
      PolygonBox[{{-1.4374999810329407`, -4.084292589556055}, {-1.4375, \
-3.9998768219370047`}, {-1.3622221848584006`, -4.097057141913445}, \
{-1.4374999810329407`, -4.084292589556055}}], 
      PolygonBox[{{-1.3622221848584006`, -4.097057141913445}, \
{-1.3247595264191645`, -4.1875}, {-1.4374999810329407`, -4.084292589556055}, \
{-1.3622221848584006`, -4.097057141913445}}], 
      PolygonBox[{{-1.4373449933535234`, -4.230251642536254}, \
{-1.4374999810329407`, -4.084292589556055}, {-1.3247595264191645`, -4.1875}, \
{-1.4373449933535234`, -4.230251642536254}}], 
      PolygonBox[{{-1.3247595264191645`, -4.1875}, {-1.2651650429449552`, \
-4.265165042944956}, {-1.4373449933535234`, -4.230251642536254}, \
{-1.3247595264191645`, -4.1875}}], 
      PolygonBox[{{-1.4049427443329972`, -4.404942744332997}, \
{-1.4373449933535234`, -4.230251642536254}, {-1.2651650429449552`, \
-4.265165042944956}, {-1.4049427443329972`, -4.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, -4.265165042944956}, \
{-1.1875000000000002`, -4.3247595264191645`}, {-1.4049427443329972`, \
-4.404942744332997}, {-1.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{-1.230251642536255, -4.437344993353523}, \
{-1.4049427443329972`, -4.404942744332997}, {-1.1875000000000002`, \
-4.3247595264191645`}, {-1.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{-1.1875000000000002`, -4.3247595264191645`}, \
{-1.0970571419134456`, -4.362222184858401}, {-1.230251642536255, \
-4.437344993353523}, {-1.1875000000000002`, -4.3247595264191645`}}], 
      PolygonBox[{{-1.0842925895560642`, -4.437499981032941}, \
{-1.230251642536255, -4.437344993353523}, {-1.0970571419134456`, \
-4.362222184858401}, {-1.0842925895560642`, -4.437499981032941}}], 
      PolygonBox[{{-1.0970571419134456`, -4.362222184858401}, \
{-0.9999999999999999, -4.375}, {-1.0842925895560642`, -4.437499981032941}, \
{-1.0970571419134456`, -4.362222184858401}}], 
      PolygonBox[{{-0.999865158168957, -4.4375}, {-1.0842925895560642`, \
-4.437499981032941}, {-0.9999999999999999, -4.375}, {-0.999865158168957, \
-4.4375}}], 
      PolygonBox[{{-0.9999999999999999, -4.375}, {-0.9029428580865548, \
-4.362222184858401}, {-0.999865158168957, -4.4375}, {-0.9999999999999999, \
-4.375}}], 
      PolygonBox[{{-0.9157074104439469, -4.437499981032941}, \
{-0.999865158168957, -4.4375}, {-0.9029428580865548, -4.362222184858401}, \
{-0.9157074104439469, -4.437499981032941}}], 
      PolygonBox[{{-0.9029428580865548, -4.362222184858401}, \
{-0.8125000000000002, -4.3247595264191645`}, {-0.9157074104439469, \
-4.437499981032941}, {-0.9029428580865548, -4.362222184858401}}], 
      PolygonBox[{{-0.7697483574637453, -4.437344993353523}, \
{-0.9157074104439469, -4.437499981032941}, {-0.8125000000000002, \
-4.3247595264191645`}, {-0.7697483574637453, -4.437344993353523}}], 
      PolygonBox[{{-0.8125000000000002, -4.3247595264191645`}, \
{-0.7348349570550448, -4.265165042944956}, {-0.7697483574637453, \
-4.437344993353523}, {-0.8125000000000002, -4.3247595264191645`}}], 
      PolygonBox[{{-0.5950572556670028, -4.404942744332997}, \
{-0.7697483574637453, -4.437344993353523}, {-0.7348349570550448, \
-4.265165042944956}, {-0.5950572556670028, -4.404942744332997}}], 
      PolygonBox[{{-0.7348349570550448, -4.265165042944956}, \
{-0.7348349570550446, -4.265165042944956}, {-0.5950572556670028, \
-4.404942744332997}, {-0.7348349570550448, -4.265165042944956}}], 
      PolygonBox[{{-0.5950572556670028, -4.404942744332997}, \
{-0.5950572556670028, -4.404942744332997}, {-0.7348349570550446, \
-4.265165042944956}, {-0.5950572556670028, -4.404942744332997}}], 
      PolygonBox[{{-0.5950572556670028, -4.404942744332997}, \
{-0.5626550066464766, -4.230251642536255}, {-0.5, -4.5}, \
{-0.5950572556670028, -4.404942744332997}}], 
      PolygonBox[{{-0.5, -4.357662782649368}, {-0.5, -4.5}, \
{-0.5626550066464766, -4.230251642536255}, {-0.5, -4.357662782649368}}], 
      PolygonBox[{{-0.5626550066464766, -4.230251642536255}, \
{-0.5625000189670593, -4.084292589556062}, {-0.5, -4.357662782649368}, \
{-0.5626550066464766, -4.230251642536255}}], 
      PolygonBox[{{-0.5, -4.20590900530174}, {-0.5, -4.357662782649368}, \
{-0.5625000189670593, -4.084292589556062}, {-0.5, -4.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, -4.084292589556062}, {-0.5625, -4.}, \
{-0.5, -4.20590900530174}, {-0.5625000189670593, -4.084292589556062}}], 
      PolygonBox[{{-0.5, -4.}, {-0.5, -4.20590900530174}, {-0.5625, -4.}, \
{-0.5, -4.}}], 
      PolygonBox[{{-0.5625, -4.}, {-0.5625000189670593, -3.915707410443938}, \
{-0.5, -4.}, {-0.5625, -4.}}], 
      PolygonBox[{{-0.5, -3.79409099469826}, {-0.5, -4.}, \
{-0.5625000189670593, -3.915707410443938}, {-0.5, -3.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, -3.915707410443938}, \
{-0.5626550066464766, -3.769748357463745}, {-0.5, -3.79409099469826}, \
{-0.5625000189670593, -3.915707410443938}}], 
      PolygonBox[{{-0.5, -3.6423372173506325`}, {-0.5, -3.79409099469826}, \
{-0.5626550066464766, -3.769748357463745}, {-0.5, -3.6423372173506325`}}], 
      PolygonBox[{{-0.5626550066464766, -3.769748357463745}, \
{-0.5950572556670028, -3.595057255667003}, {-0.5, -3.6423372173506325`}, \
{-0.5626550066464766, -3.769748357463745}}], 
      PolygonBox[{{-0.508553435038814, -3.508553435038814}, {-0.5, \
-3.6423372173506325`}, {-0.5950572556670028, -3.595057255667003}, \
{-0.508553435038814, -3.508553435038814}}], 
      PolygonBox[{{-0.5950572556670028, -3.595057255667003}, \
{-0.7697483574637448, -3.5626550066464766`}, {-0.508553435038814, \
-3.508553435038814}, {-0.5950572556670028, -3.595057255667003}}], 
      PolygonBox[{{-0.6423372173506319, -3.5}, {-0.508553435038814, \
-3.508553435038814}, {-0.7697483574637448, -3.5626550066464766`}, \
{-0.6423372173506319, -3.5}}], 
      PolygonBox[{{-0.7697483574637448, -3.5626550066464766`}, \
{-0.9157074104439394, -3.562500018967059}, {-0.6423372173506319, -3.5}, \
{-0.7697483574637448, -3.5626550066464766`}}], 
      PolygonBox[{{-0.7940909946267442, -3.5}, {-0.6423372173506319, -3.5}, \
{-0.9157074104439394, -3.562500018967059}, {-0.7940909946267442, -3.5}}], 
      PolygonBox[{{-0.9157074104439394, -3.562500018967059}, \
{-0.9998944727795123, -3.5625}, {-0.7940909946267442, -3.5}, \
{-0.9157074104439394, -3.562500018967059}}], 
      PolygonBox[{{-0.9220580419731099, -3.5}, {-0.7940909946267442, -3.5}, \
{-0.9998944727795123, -3.5625}, {-0.9220580419731099, -3.5}}], 
      PolygonBox[{{-0.9998944727795123, -3.5625}, {-1.084292589556057, \
-3.562500018967059}, {-0.9220580419731099, -3.5}, {-0.9998944727795123, \
-3.5625}}], 
      PolygonBox[{{-1.2059090053044457`, -3.5}, {-0.9220580419731099, -3.5}, \
{-1.084292589556057, -3.562500018967059}, {-1.2059090053044457`, -3.5}}], 
      PolygonBox[{{-1.084292589556057, -3.562500018967059}, \
{-1.230251642536255, -3.5626550066464766`}, {-1.2059090053044457`, -3.5}, \
{-1.084292589556057, -3.562500018967059}}], 
      PolygonBox[{{-1.3576627826493661`, -3.5}, {-1.2059090053044457`, -3.5}, \
{-1.230251642536255, -3.5626550066464766`}, {-1.3576627826493661`, -3.5}}], 
      PolygonBox[{{-1.230251642536255, -3.5626550066464766`}, \
{-1.4049427443329972`, -3.595057255667003}, {-1.3576627826493661`, -3.5}, \
{-1.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{-0.5, -3.5}, {-1.3576627826493661`, -3.5}, \
{-1.4049427443329972`, -3.595057255667003}, {-0.5, -3.5}}], 
      PolygonBox[{{-1.4049427443329972`, -3.595057255667003}, \
{-1.4373449933535234`, -3.7697483574637447`}, {-0.5, -3.5}, \
{-1.4049427443329972`, -3.595057255667003}}], 
      PolygonBox[{{-1.5, -3.642337217350631}, {-0.5, -3.5}, \
{-1.4373449933535234`, -3.7697483574637447`}, {-1.5, -3.642337217350631}}], 
      PolygonBox[{{-1.4373449933535234`, -3.7697483574637447`}, \
{-1.4374999810329407`, -3.9157074104439378`}, {-1.5, -3.642337217350631}, \
{-1.4373449933535234`, -3.7697483574637447`}}], 
      PolygonBox[{{-1.5, -3.794090994717101}, {-1.5, -3.642337217350631}, \
{-1.4374999810329407`, -3.9157074104439378`}, {-1.5, -3.794090994717101}}], 
      PolygonBox[{{-1.4374999810329407`, -3.9157074104439378`}, {-1.4375, \
-3.9998768219370047`}, {-1.5, -3.794090994717101}, {-1.4374999810329407`, \
-3.9157074104439378`}}], 
      PolygonBox[{{-1.5, -3.9193213332413}, {-1.5, -3.794090994717101}, \
{-1.4375, -3.9998768219370047`}, {-1.5, -3.9193213332413}}], 
      PolygonBox[{{-1.4375, -3.9998768219370047`}, {-1.4374999810329407`, \
-4.084292589556055}, {-1.5, -3.9193213332413}, {-1.4375, \
-3.9998768219370047`}}], 
      PolygonBox[{{-1.5, -4.205909005145278}, {-1.5, -3.9193213332413}, \
{-1.4374999810329407`, -4.084292589556055}, {-1.5, -4.205909005145278}}], 
      PolygonBox[{{-1.4374999810329407`, -4.084292589556055}, \
{-1.4373449933535234`, -4.230251642536254}, {-1.5, -4.205909005145278}, \
{-1.4374999810329407`, -4.084292589556055}}], 
      PolygonBox[{{-1.5, -4.357662782649365}, {-1.5, -4.205909005145278}, \
{-1.4373449933535234`, -4.230251642536254}, {-1.5, -4.357662782649365}}], 
      PolygonBox[{{-1.4373449933535234`, -4.230251642536254}, \
{-1.4049427443329972`, -4.404942744332997}, {-1.5, -4.357662782649365}, \
{-1.4373449933535234`, -4.230251642536254}}], 
      PolygonBox[{{-1.5, -3.5}, {-1.5, -4.357662782649365}, \
{-1.4049427443329972`, -4.404942744332997}, {-1.5, -3.5}}], 
      PolygonBox[{{-1.4049427443329972`, -4.404942744332997}, \
{-1.230251642536255, -4.437344993353523}, {-1.5, -3.5}, \
{-1.4049427443329972`, -4.404942744332997}}], 
      PolygonBox[{{-1.5, -4.5}, {-1.5, -3.5}, {-1.230251642536255, \
-4.437344993353523}, {-1.5, -4.5}}], 
      PolygonBox[{{-1.230251642536255, -4.437344993353523}, \
{-1.0842925895560642`, -4.437499981032941}, {-1.5, -4.5}, \
{-1.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{-1.205909005566828, -4.5}, {-1.5, -4.5}, \
{-1.0842925895560642`, -4.437499981032941}, {-1.205909005566828, -4.5}}], 
      PolygonBox[{{-1.0842925895560642`, -4.437499981032941}, \
{-0.999865158168957, -4.4375}, {-1.205909005566828, -4.5}, \
{-1.0842925895560642`, -4.437499981032941}}], 
      PolygonBox[{{-0.9176761295989384, -4.5}, {-1.205909005566828, -4.5}, \
{-0.999865158168957, -4.4375}, {-0.9176761295989384, -4.5}}], 
      PolygonBox[{{-0.999865158168957, -4.4375}, {-0.9157074104439469, \
-4.437499981032941}, {-0.9176761295989384, -4.5}, {-0.999865158168957, \
-4.4375}}], 
      PolygonBox[{{-0.7940909946396026, -4.5}, {-0.9176761295989384, -4.5}, \
{-0.9157074104439469, -4.437499981032941}, {-0.7940909946396026, -4.5}}], 
      PolygonBox[{{-0.9157074104439469, -4.437499981032941}, \
{-0.7697483574637453, -4.437344993353523}, {-0.7940909946396026, -4.5}, \
{-0.9157074104439469, -4.437499981032941}}], 
      PolygonBox[{{-0.642337217350629, -4.5}, {-0.7940909946396026, -4.5}, \
{-0.7697483574637453, -4.437344993353523}, {-0.642337217350629, -4.5}}], 
      PolygonBox[{{-0.7697483574637453, -4.437344993353523}, \
{-0.5950572556670028, -4.404942744332997}, {-0.642337217350629, -4.5}, \
{-0.7697483574637453, -4.437344993353523}}], 
      PolygonBox[{{-0.5, -4.5}, {-0.642337217350629, -4.5}, \
{-0.5950572556670028, -4.404942744332997}, {-0.5, -4.5}}], 
      PolygonBox[{{-0.5950572556670028, -4.404942744332997}, \
{-0.5950572556670028, -4.404942744332997}, {-0.5, -4.5}, \
{-0.5950572556670028, -4.404942744332997}}], 
      PolygonBox[{{-0.5, -4.5}, {-0.5, -4.5}, {-0.5950572556670028, \
-4.404942744332997}, {-0.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, -3.}, {-1.4791666666666667`, -3.}, \
{-1.4583333333333333`, -3.}, {-1.4375, -3.}, {-1.4166666666666667`, -3.}, \
{-1.3958333333333335`, -3.}, {-1.375, -3.}, {-1.375, -3.}, \
{-1.3958333333333333`, -3.}, {-1.4166666666666667`, -3.}, {-1.4375, -3.}, \
{-1.4583333333333333`, -3.}, {-1.4791666666666665`, -3.}, {-1.5, -3.}, {-1.5, \
-3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, -3.}, {-0.6041666666666667, -3.}, \
{-0.5833333333333333, -3.}, {-0.5625, -3.}, {-0.5416666666666667, -3.}, \
{-0.5208333333333334, -3.}, {-0.5, -3.}, {-0.5, -3.}, {-0.5208333333333333, \
-3.}, {-0.5416666666666667, -3.}, {-0.5625, -3.}, {-0.5833333333333333, -3.}, \
{-0.6041666666666666, -3.}, {-0.625, -3.}, {-0.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -3.5}, {-1., -3.4791666666666665`}, {-1., \
-3.4583333333333335`}, {-1., -3.4375}, {-1., -3.4166666666666665`}, {-1., \
-3.3958333333333335`}, {-1., -3.375}, {-1., -3.375}, {-1., \
-3.3958333333333335`}, {-1., -3.4166666666666665`}, {-1., -3.4375}, {-1., \
-3.4583333333333335`}, {-1., -3.4791666666666665`}, {-1., -3.5}, {-1., \
-3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -2.625}, {-1., -2.6041666666666665`}, {-1., \
-2.5833333333333335`}, {-1., -2.5625}, {-1., -2.5416666666666665`}, {-1., \
-2.5208333333333335`}, {-1., -2.5}, {-1., -2.5}, {-1., -2.5208333333333335`}, \
{-1., -2.5416666666666665`}, {-1., -2.5625}, {-1., -2.5833333333333335`}, \
{-1., -2.6041666666666665`}, {-1., -2.625}, {-1., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, -3.}, {-1.25, -3.}, {-1.125, -3.}, {-1., -3.}, \
{-0.875, -3.}, {-0.75, -3.}, {-0.625, -3.}, {-0.625, -3.}, {-0.75, -3.}, \
{-0.875, -3.}, {-1., -3.}, {-1.125, -3.}, {-1.25, -3.}, {-1.375, -3.}, \
{-1.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -3.375}, {-1., -3.25}, {-1., -3.125}, {-1., -3.}, {-1., \
-2.875}, {-1., -2.75}, {-1., -2.625}, {-1., -2.625}, {-1., -2.75}, {-1., \
-2.875}, {-1., -3.}, {-1., -3.125}, {-1., -3.25}, {-1., -3.375}, {-1., \
-3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kNojgMRO1xY12Y82b9R+q2UlSX7AYfH915M
nP0UIt/AdmCy54SZR5qf708VSlH7+ID1AETfq/0XdphXPUljPXAkb0v2iydv
9ovpBTpqS8HkP0DNZz0w94Tqqe7ej2jyn+H6zW6bb5a1+wI3P6FvAre50Ve4
/VcWx9auPP0V7j6I/m9w98Pk/Z4IPT16jANNP+cBc6j5s9/Ovsknz3WAEWq/
gfuJVumZXAfmQ9336uK6fVeecqG5n/vAMaj/YPJMUP/D9E+Bhg/MfEeU8OM8
EAkNX3+o+9DDHwBR0aPG
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNolgOhYPAUzl8FBq/gfAj9AU3+E5r+r2jq
fxDkQ/SxwvmrweayoannQFPPCedD3MGFpp4Hgx+G4j6eA6tR3A9T/wFN/hWa
/qdo6h8Q5K9Gcd8DNPc/QPPfAzT/P9gfhhI+iPgCAFmjdkY=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, -3.2651650429449552`}, \
{-0.6752404735808355, -3.1875}, {-0.5950572556670028, -3.404942744332997}, \
{-0.7348349570550446, -3.2651650429449552`}}], 
      PolygonBox[{{-0.5626550066464766, -3.2302516425362553`}, \
{-0.5950572556670028, -3.404942744332997}, {-0.6752404735808355, -3.1875}, \
{-0.5626550066464766, -3.2302516425362553`}}], 
      PolygonBox[{{-0.6752404735808355, -3.1875}, {-0.6377778151415994, \
-3.0970571419134454`}, {-0.5626550066464766, -3.2302516425362553`}, \
{-0.6752404735808355, -3.1875}}], 
      PolygonBox[{{-0.5625000189670593, -3.084292589556062}, \
{-0.5626550066464766, -3.2302516425362553`}, {-0.6377778151415994, \
-3.0970571419134454`}, {-0.5625000189670593, -3.084292589556062}}], 
      PolygonBox[{{-0.6377778151415994, -3.0970571419134454`}, {-0.625, -3.}, \
{-0.5625000189670593, -3.084292589556062}, {-0.6377778151415994, \
-3.0970571419134454`}}], 
      PolygonBox[{{-0.5625, -3.}, {-0.5625000189670593, -3.084292589556062}, \
{-0.625, -3.}, {-0.5625, -3.}}], 
      PolygonBox[{{-0.625, -3.}, {-0.6377778151415994, -2.9029428580865546`}, \
{-0.5625, -3.}, {-0.625, -3.}}], 
      PolygonBox[{{-0.5625000189670593, -2.915707410443938}, {-0.5625, -3.}, \
{-0.6377778151415994, -2.9029428580865546`}, {-0.5625000189670593, \
-2.915707410443938}}], 
      PolygonBox[{{-0.6377778151415994, -2.9029428580865546`}, \
{-0.6752404735808355, -2.8125}, {-0.5625000189670593, -2.915707410443938}, \
{-0.6377778151415994, -2.9029428580865546`}}], 
      PolygonBox[{{-0.5626550066464766, -2.769748357463745}, \
{-0.5625000189670593, -2.915707410443938}, {-0.6752404735808355, -2.8125}, \
{-0.5626550066464766, -2.769748357463745}}], 
      PolygonBox[{{-0.6752404735808355, -2.8125}, {-0.7348349570550446, \
-2.7348349570550448`}, {-0.5626550066464766, -2.769748357463745}, \
{-0.6752404735808355, -2.8125}}], 
      PolygonBox[{{-0.5950572556670028, -2.595057255667003}, \
{-0.5626550066464766, -2.769748357463745}, {-0.7348349570550446, \
-2.7348349570550448`}, {-0.5950572556670028, -2.595057255667003}}], 
      PolygonBox[{{-0.7348349570550446, -2.7348349570550448`}, {-0.8125, \
-2.6752404735808355`}, {-0.5950572556670028, -2.595057255667003}, \
{-0.7348349570550446, -2.7348349570550448`}}], 
      PolygonBox[{{-0.7697483574637448, -2.5626550066464766`}, \
{-0.5950572556670028, -2.595057255667003}, {-0.8125, -2.6752404735808355`}, \
{-0.7697483574637448, -2.5626550066464766`}}], 
      PolygonBox[{{-0.8125, -2.6752404735808355`}, {-0.9029428580865546, \
-2.6377778151415994`}, {-0.7697483574637448, -2.5626550066464766`}, {-0.8125, \
-2.6752404735808355`}}], 
      PolygonBox[{{-0.9157074104439394, -2.562500018967059}, \
{-0.7697483574637448, -2.5626550066464766`}, {-0.9029428580865546, \
-2.6377778151415994`}, {-0.9157074104439394, -2.562500018967059}}], 
      PolygonBox[{{-0.9029428580865546, -2.6377778151415994`}, {-1., -2.625}, \
{-0.9157074104439394, -2.562500018967059}, {-0.9029428580865546, \
-2.6377778151415994`}}], 
      PolygonBox[{{-0.9998944727795123, -2.5625}, {-0.9157074104439394, \
-2.562500018967059}, {-1., -2.625}, {-0.9998944727795123, -2.5625}}], 
      PolygonBox[{{-1., -2.625}, {-1.0970571419134452`, \
-2.6377778151415994`}, {-0.9998944727795123, -2.5625}, {-1., -2.625}}], 
      PolygonBox[{{-1.084292589556057, -2.562500018967059}, \
{-0.9998944727795123, -2.5625}, {-1.0970571419134452`, -2.6377778151415994`}, \
{-1.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-1.0970571419134452`, -2.6377778151415994`}, {-1.1875, \
-2.6752404735808355`}, {-1.084292589556057, -2.562500018967059}, \
{-1.0970571419134452`, -2.6377778151415994`}}], 
      PolygonBox[{{-1.230251642536255, -2.5626550066464766`}, \
{-1.084292589556057, -2.562500018967059}, {-1.1875, -2.6752404735808355`}, \
{-1.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-1.1875, -2.6752404735808355`}, {-1.2651650429449552`, \
-2.7348349570550448`}, {-1.230251642536255, -2.5626550066464766`}, {-1.1875, \
-2.6752404735808355`}}], 
      PolygonBox[{{-1.4049427443329972`, -2.595057255667003}, \
{-1.230251642536255, -2.5626550066464766`}, {-1.2651650429449552`, \
-2.7348349570550448`}, {-1.4049427443329972`, -2.595057255667003}}], 
      PolygonBox[{{-1.2651650429449552`, -2.7348349570550448`}, \
{-1.3247595264191645`, -2.8125}, {-1.4049427443329972`, -2.595057255667003}, \
{-1.2651650429449552`, -2.7348349570550448`}}], 
      PolygonBox[{{-1.4373449933535234`, -2.7697483574637447`}, \
{-1.4049427443329972`, -2.595057255667003}, {-1.3247595264191645`, -2.8125}, \
{-1.4373449933535234`, -2.7697483574637447`}}], 
      PolygonBox[{{-1.3247595264191645`, -2.8125}, {-1.3622221848584006`, \
-2.9029428580865546`}, {-1.4373449933535234`, -2.7697483574637447`}, \
{-1.3247595264191645`, -2.8125}}], 
      PolygonBox[{{-1.4374999810329407`, -2.9157074104439378`}, \
{-1.4373449933535234`, -2.7697483574637447`}, {-1.3622221848584006`, \
-2.9029428580865546`}, {-1.4374999810329407`, -2.9157074104439378`}}], 
      PolygonBox[{{-1.3622221848584006`, -2.9029428580865546`}, {-1.375, \
-3.}, {-1.4374999810329407`, -2.9157074104439378`}, {-1.3622221848584006`, \
-2.9029428580865546`}}], 
      PolygonBox[{{-1.4375, -2.9998768219370047`}, {-1.4374999810329407`, \
-2.9157074104439378`}, {-1.375, -3.}, {-1.4375, -2.9998768219370047`}}], 
      PolygonBox[{{-1.375, -3.}, {-1.3622221848584006`, -3.097057141913445}, \
{-1.4375, -2.9998768219370047`}, {-1.375, -3.}}], 
      PolygonBox[{{-1.4374999810329407`, -3.084292589556055}, {-1.4375, \
-2.9998768219370047`}, {-1.3622221848584006`, -3.097057141913445}, \
{-1.4374999810329407`, -3.084292589556055}}], 
      PolygonBox[{{-1.3622221848584006`, -3.097057141913445}, \
{-1.3247595264191645`, -3.1875}, {-1.4374999810329407`, -3.084292589556055}, \
{-1.3622221848584006`, -3.097057141913445}}], 
      PolygonBox[{{-1.4373449933535234`, -3.230251642536255}, \
{-1.4374999810329407`, -3.084292589556055}, {-1.3247595264191645`, -3.1875}, \
{-1.4373449933535234`, -3.230251642536255}}], 
      PolygonBox[{{-1.3247595264191645`, -3.1875}, {-1.2651650429449552`, \
-3.2651650429449552`}, {-1.4373449933535234`, -3.230251642536255}, \
{-1.3247595264191645`, -3.1875}}], 
      PolygonBox[{{-1.4049427443329972`, -3.404942744332997}, \
{-1.4373449933535234`, -3.230251642536255}, {-1.2651650429449552`, \
-3.2651650429449552`}, {-1.4049427443329972`, -3.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, -3.2651650429449552`}, \
{-1.1875000000000002`, -3.3247595264191645`}, {-1.4049427443329972`, \
-3.404942744332997}, {-1.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{-1.230251642536255, -3.4373449933535234`}, \
{-1.4049427443329972`, -3.404942744332997}, {-1.1875000000000002`, \
-3.3247595264191645`}, {-1.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{-1.1875000000000002`, -3.3247595264191645`}, \
{-1.0970571419134456`, -3.3622221848584006`}, {-1.230251642536255, \
-3.4373449933535234`}, {-1.1875000000000002`, -3.3247595264191645`}}], 
      PolygonBox[{{-1.0842925895560642`, -3.437499981032941}, \
{-1.230251642536255, -3.4373449933535234`}, {-1.0970571419134456`, \
-3.3622221848584006`}, {-1.0842925895560642`, -3.437499981032941}}], 
      PolygonBox[{{-1.0970571419134456`, -3.3622221848584006`}, \
{-0.9999999999999999, -3.375}, {-1.0842925895560642`, -3.437499981032941}, \
{-1.0970571419134456`, -3.3622221848584006`}}], 
      PolygonBox[{{-0.999865158168957, -3.4375}, {-1.0842925895560642`, \
-3.437499981032941}, {-0.9999999999999999, -3.375}, {-0.999865158168957, \
-3.4375}}], 
      PolygonBox[{{-0.9999999999999999, -3.375}, {-0.9029428580865548, \
-3.3622221848584006`}, {-0.999865158168957, -3.4375}, {-0.9999999999999999, \
-3.375}}], 
      PolygonBox[{{-0.9157074104439469, -3.437499981032941}, \
{-0.999865158168957, -3.4375}, {-0.9029428580865548, -3.3622221848584006`}, \
{-0.9157074104439469, -3.437499981032941}}], 
      PolygonBox[{{-0.9029428580865548, -3.3622221848584006`}, \
{-0.8125000000000002, -3.3247595264191645`}, {-0.9157074104439469, \
-3.437499981032941}, {-0.9029428580865548, -3.3622221848584006`}}], 
      PolygonBox[{{-0.7697483574637453, -3.4373449933535234`}, \
{-0.9157074104439469, -3.437499981032941}, {-0.8125000000000002, \
-3.3247595264191645`}, {-0.7697483574637453, -3.4373449933535234`}}], 
      PolygonBox[{{-0.8125000000000002, -3.3247595264191645`}, \
{-0.7348349570550448, -3.2651650429449552`}, {-0.7697483574637453, \
-3.4373449933535234`}, {-0.8125000000000002, -3.3247595264191645`}}], 
      PolygonBox[{{-0.5950572556670028, -3.404942744332997}, \
{-0.7697483574637453, -3.4373449933535234`}, {-0.7348349570550448, \
-3.2651650429449552`}, {-0.5950572556670028, -3.404942744332997}}], 
      PolygonBox[{{-0.7348349570550448, -3.2651650429449552`}, \
{-0.7348349570550446, -3.2651650429449552`}, {-0.5950572556670028, \
-3.404942744332997}, {-0.7348349570550448, -3.2651650429449552`}}], 
      PolygonBox[{{-0.5950572556670028, -3.404942744332997}, \
{-0.5950572556670028, -3.404942744332997}, {-0.7348349570550446, \
-3.2651650429449552`}, {-0.5950572556670028, -3.404942744332997}}], 
      PolygonBox[{{-0.5950572556670028, -3.404942744332997}, \
{-0.5626550066464766, -3.2302516425362553`}, {-0.5, -3.5}, \
{-0.5950572556670028, -3.404942744332997}}], 
      PolygonBox[{{-0.5, -3.357662782649368}, {-0.5, -3.5}, \
{-0.5626550066464766, -3.2302516425362553`}, {-0.5, -3.357662782649368}}], 
      PolygonBox[{{-0.5626550066464766, -3.2302516425362553`}, \
{-0.5625000189670593, -3.084292589556062}, {-0.5, -3.357662782649368}, \
{-0.5626550066464766, -3.2302516425362553`}}], 
      PolygonBox[{{-0.5, -3.20590900530174}, {-0.5, -3.357662782649368}, \
{-0.5625000189670593, -3.084292589556062}, {-0.5, -3.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, -3.084292589556062}, {-0.5625, -3.}, \
{-0.5, -3.20590900530174}, {-0.5625000189670593, -3.084292589556062}}], 
      PolygonBox[{{-0.5, -3.}, {-0.5, -3.20590900530174}, {-0.5625, -3.}, \
{-0.5, -3.}}], 
      PolygonBox[{{-0.5625, -3.}, {-0.5625000189670593, -2.915707410443938}, \
{-0.5, -3.}, {-0.5625, -3.}}], 
      PolygonBox[{{-0.5, -2.79409099469826}, {-0.5, -3.}, \
{-0.5625000189670593, -2.915707410443938}, {-0.5, -2.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, -2.915707410443938}, \
{-0.5626550066464766, -2.769748357463745}, {-0.5, -2.79409099469826}, \
{-0.5625000189670593, -2.915707410443938}}], 
      PolygonBox[{{-0.5, -2.6423372173506325`}, {-0.5, -2.79409099469826}, \
{-0.5626550066464766, -2.769748357463745}, {-0.5, -2.6423372173506325`}}], 
      PolygonBox[{{-0.5626550066464766, -2.769748357463745}, \
{-0.5950572556670028, -2.595057255667003}, {-0.5, -2.6423372173506325`}, \
{-0.5626550066464766, -2.769748357463745}}], 
      PolygonBox[{{-0.508553435038814, -2.508553435038814}, {-0.5, \
-2.6423372173506325`}, {-0.5950572556670028, -2.595057255667003}, \
{-0.508553435038814, -2.508553435038814}}], 
      PolygonBox[{{-0.5950572556670028, -2.595057255667003}, \
{-0.7697483574637448, -2.5626550066464766`}, {-0.508553435038814, \
-2.508553435038814}, {-0.5950572556670028, -2.595057255667003}}], 
      PolygonBox[{{-0.6423372173506319, -2.5}, {-0.508553435038814, \
-2.508553435038814}, {-0.7697483574637448, -2.5626550066464766`}, \
{-0.6423372173506319, -2.5}}], 
      PolygonBox[{{-0.7697483574637448, -2.5626550066464766`}, \
{-0.9157074104439394, -2.562500018967059}, {-0.6423372173506319, -2.5}, \
{-0.7697483574637448, -2.5626550066464766`}}], 
      PolygonBox[{{-0.7940909946267442, -2.5}, {-0.6423372173506319, -2.5}, \
{-0.9157074104439394, -2.562500018967059}, {-0.7940909946267442, -2.5}}], 
      PolygonBox[{{-0.9157074104439394, -2.562500018967059}, \
{-0.9998944727795123, -2.5625}, {-0.7940909946267442, -2.5}, \
{-0.9157074104439394, -2.562500018967059}}], 
      PolygonBox[{{-0.9220580419731099, -2.5}, {-0.7940909946267442, -2.5}, \
{-0.9998944727795123, -2.5625}, {-0.9220580419731099, -2.5}}], 
      PolygonBox[{{-0.9998944727795123, -2.5625}, {-1.084292589556057, \
-2.562500018967059}, {-0.9220580419731099, -2.5}, {-0.9998944727795123, \
-2.5625}}], 
      PolygonBox[{{-1.2059090053044457`, -2.5}, {-0.9220580419731099, -2.5}, \
{-1.084292589556057, -2.562500018967059}, {-1.2059090053044457`, -2.5}}], 
      PolygonBox[{{-1.084292589556057, -2.562500018967059}, \
{-1.230251642536255, -2.5626550066464766`}, {-1.2059090053044457`, -2.5}, \
{-1.084292589556057, -2.562500018967059}}], 
      PolygonBox[{{-1.3576627826493661`, -2.5}, {-1.2059090053044457`, -2.5}, \
{-1.230251642536255, -2.5626550066464766`}, {-1.3576627826493661`, -2.5}}], 
      PolygonBox[{{-1.230251642536255, -2.5626550066464766`}, \
{-1.4049427443329972`, -2.595057255667003}, {-1.3576627826493661`, -2.5}, \
{-1.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{-0.5, -2.5}, {-1.3576627826493661`, -2.5}, \
{-1.4049427443329972`, -2.595057255667003}, {-0.5, -2.5}}], 
      PolygonBox[{{-1.4049427443329972`, -2.595057255667003}, \
{-1.4373449933535234`, -2.7697483574637447`}, {-0.5, -2.5}, \
{-1.4049427443329972`, -2.595057255667003}}], 
      PolygonBox[{{-1.5, -2.642337217350631}, {-0.5, -2.5}, \
{-1.4373449933535234`, -2.7697483574637447`}, {-1.5, -2.642337217350631}}], 
      PolygonBox[{{-1.4373449933535234`, -2.7697483574637447`}, \
{-1.4374999810329407`, -2.9157074104439378`}, {-1.5, -2.642337217350631}, \
{-1.4373449933535234`, -2.7697483574637447`}}], 
      PolygonBox[{{-1.5, -2.794090994717101}, {-1.5, -2.642337217350631}, \
{-1.4374999810329407`, -2.9157074104439378`}, {-1.5, -2.794090994717101}}], 
      PolygonBox[{{-1.4374999810329407`, -2.9157074104439378`}, {-1.4375, \
-2.9998768219370047`}, {-1.5, -2.794090994717101}, {-1.4374999810329407`, \
-2.9157074104439378`}}], 
      PolygonBox[{{-1.5, -2.9193213332413}, {-1.5, -2.794090994717101}, \
{-1.4375, -2.9998768219370047`}, {-1.5, -2.9193213332413}}], 
      PolygonBox[{{-1.4375, -2.9998768219370047`}, {-1.4374999810329407`, \
-3.084292589556055}, {-1.5, -2.9193213332413}, {-1.4375, \
-2.9998768219370047`}}], 
      PolygonBox[{{-1.5, -3.2059090051452785`}, {-1.5, -2.9193213332413}, \
{-1.4374999810329407`, -3.084292589556055}, {-1.5, -3.2059090051452785`}}], 
      PolygonBox[{{-1.4374999810329407`, -3.084292589556055}, \
{-1.4373449933535234`, -3.230251642536255}, {-1.5, -3.2059090051452785`}, \
{-1.4374999810329407`, -3.084292589556055}}], 
      PolygonBox[{{-1.5, -3.3576627826493652`}, {-1.5, -3.2059090051452785`}, \
{-1.4373449933535234`, -3.230251642536255}, {-1.5, -3.3576627826493652`}}], 
      PolygonBox[{{-1.4373449933535234`, -3.230251642536255}, \
{-1.4049427443329972`, -3.404942744332997}, {-1.5, -3.3576627826493652`}, \
{-1.4373449933535234`, -3.230251642536255}}], 
      PolygonBox[{{-1.5, -2.5}, {-1.5, -3.3576627826493652`}, \
{-1.4049427443329972`, -3.404942744332997}, {-1.5, -2.5}}], 
      PolygonBox[{{-1.4049427443329972`, -3.404942744332997}, \
{-1.230251642536255, -3.4373449933535234`}, {-1.5, -2.5}, \
{-1.4049427443329972`, -3.404942744332997}}], 
      PolygonBox[{{-1.5, -3.5}, {-1.5, -2.5}, {-1.230251642536255, \
-3.4373449933535234`}, {-1.5, -3.5}}], 
      PolygonBox[{{-1.230251642536255, -3.4373449933535234`}, \
{-1.0842925895560642`, -3.437499981032941}, {-1.5, -3.5}, \
{-1.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{-1.205909005566828, -3.5}, {-1.5, -3.5}, \
{-1.0842925895560642`, -3.437499981032941}, {-1.205909005566828, -3.5}}], 
      PolygonBox[{{-1.0842925895560642`, -3.437499981032941}, \
{-0.999865158168957, -3.4375}, {-1.205909005566828, -3.5}, \
{-1.0842925895560642`, -3.437499981032941}}], 
      PolygonBox[{{-0.9176761295989384, -3.5}, {-1.205909005566828, -3.5}, \
{-0.999865158168957, -3.4375}, {-0.9176761295989384, -3.5}}], 
      PolygonBox[{{-0.999865158168957, -3.4375}, {-0.9157074104439469, \
-3.437499981032941}, {-0.9176761295989384, -3.5}, {-0.999865158168957, \
-3.4375}}], 
      PolygonBox[{{-0.7940909946396026, -3.5}, {-0.9176761295989384, -3.5}, \
{-0.9157074104439469, -3.437499981032941}, {-0.7940909946396026, -3.5}}], 
      PolygonBox[{{-0.9157074104439469, -3.437499981032941}, \
{-0.7697483574637453, -3.4373449933535234`}, {-0.7940909946396026, -3.5}, \
{-0.9157074104439469, -3.437499981032941}}], 
      PolygonBox[{{-0.642337217350629, -3.5}, {-0.7940909946396026, -3.5}, \
{-0.7697483574637453, -3.4373449933535234`}, {-0.642337217350629, -3.5}}], 
      PolygonBox[{{-0.7697483574637453, -3.4373449933535234`}, \
{-0.5950572556670028, -3.404942744332997}, {-0.642337217350629, -3.5}, \
{-0.7697483574637453, -3.4373449933535234`}}], 
      PolygonBox[{{-0.5, -3.5}, {-0.642337217350629, -3.5}, \
{-0.5950572556670028, -3.404942744332997}, {-0.5, -3.5}}], 
      PolygonBox[{{-0.5950572556670028, -3.404942744332997}, \
{-0.5950572556670028, -3.404942744332997}, {-0.5, -3.5}, \
{-0.5950572556670028, -3.404942744332997}}], 
      PolygonBox[{{-0.5, -3.5}, {-0.5, -3.5}, {-0.5950572556670028, \
-3.404942744332997}, {-0.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, -2.}, {-1.4791666666666667`, -2.}, \
{-1.4583333333333333`, -2.}, {-1.4375, -2.}, {-1.4166666666666667`, -2.}, \
{-1.3958333333333335`, -2.}, {-1.375, -2.}, {-1.375, -2.}, \
{-1.3958333333333333`, -2.}, {-1.4166666666666667`, -2.}, {-1.4375, -2.}, \
{-1.4583333333333333`, -2.}, {-1.4791666666666665`, -2.}, {-1.5, -2.}, {-1.5, \
-2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, -2.}, {-0.6041666666666667, -2.}, \
{-0.5833333333333333, -2.}, {-0.5625, -2.}, {-0.5416666666666667, -2.}, \
{-0.5208333333333334, -2.}, {-0.5, -2.}, {-0.5, -2.}, {-0.5208333333333333, \
-2.}, {-0.5416666666666667, -2.}, {-0.5625, -2.}, {-0.5833333333333333, -2.}, \
{-0.6041666666666666, -2.}, {-0.625, -2.}, {-0.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -2.5}, {-1., -2.4791666666666665`}, {-1., \
-2.4583333333333335`}, {-1., -2.4375}, {-1., -2.4166666666666665`}, {-1., \
-2.3958333333333335`}, {-1., -2.375}, {-1., -2.375}, {-1., \
-2.3958333333333335`}, {-1., -2.4166666666666665`}, {-1., -2.4375}, {-1., \
-2.4583333333333335`}, {-1., -2.4791666666666665`}, {-1., -2.5}, {-1., \
-2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -1.625}, {-1., -1.6041666666666667`}, {-1., \
-1.5833333333333333`}, {-1., -1.5625}, {-1., -1.5416666666666667`}, {-1., \
-1.5208333333333335`}, {-1., -1.5}, {-1., -1.5}, {-1., -1.5208333333333333`}, \
{-1., -1.5416666666666667`}, {-1., -1.5625}, {-1., -1.5833333333333333`}, \
{-1., -1.6041666666666665`}, {-1., -1.625}, {-1., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, -2.}, {-1.25, -2.}, {-1.125, -2.}, {-1., -2.}, \
{-0.875, -2.}, {-0.75, -2.}, {-0.625, -2.}, {-0.625, -2.}, {-0.75, -2.}, \
{-0.875, -2.}, {-1., -2.}, {-1.125, -2.}, {-1.25, -2.}, {-1.375, -2.}, \
{-1.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -2.375}, {-1., -2.25}, {-1., -2.125}, {-1., -2.}, {-1., \
-1.875}, {-1., -1.75}, {-1., -1.625}, {-1., -1.625}, {-1., -1.75}, {-1., \
-1.875}, {-1., -2.}, {-1., -2.125}, {-1., -2.25}, {-1., -2.375}, {-1., \
-2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kMZByJ2uLCuzXiyP8n8lmlJ0b/9Do/vvZg4
+ylU/u/+yZ4TZh5pfr7/lMoJn0cHf0PFX+1fUJj/5cTZX/uP5G3JfvHkzX6d
mEVNYSa/oPIfoPSv/XNPqJ7q7v2IJv8Zrt/stvlmWbsvcPMT+iZwmxt9hdt/
ZXFs7crTX+Hug4h/g7sfJu/3ROjp0WMMB1D0NzAeMIeaP/vt7Jt88kwHGKH2
G7ifaJWeyXRgPtR9ry6u23flKdMBVPczHzgG9R9Mngnqf5j+KdDwgZnviBx+
QPsjoeHrD3UfevgDACkvslQ=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kPoH/tDweApnL8KDF7B+RD6A5r8JzT9X9HU
E6Yh5vxCM+cvmjqGA6jyjAdQ9TMdQFXPgsEPQ3Efy4HVKO6Hqf+AJv8KTf9T
NPUPCPJXo7jvAZr7H6D578H+MBT/w/T/2o+q/sd+ALHZgiw=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, -2.2651650429449552`}, \
{-0.6752404735808355, -2.1875}, {-0.5950572556670028, -2.404942744332997}, \
{-0.7348349570550446, -2.2651650429449552`}}], 
      PolygonBox[{{-0.5626550066464766, -2.2302516425362553`}, \
{-0.5950572556670028, -2.404942744332997}, {-0.6752404735808355, -2.1875}, \
{-0.5626550066464766, -2.2302516425362553`}}], 
      PolygonBox[{{-0.6752404735808355, -2.1875}, {-0.6377778151415994, \
-2.0970571419134454`}, {-0.5626550066464766, -2.2302516425362553`}, \
{-0.6752404735808355, -2.1875}}], 
      PolygonBox[{{-0.5625000189670593, -2.084292589556062}, \
{-0.5626550066464766, -2.2302516425362553`}, {-0.6377778151415994, \
-2.0970571419134454`}, {-0.5625000189670593, -2.084292589556062}}], 
      PolygonBox[{{-0.6377778151415994, -2.0970571419134454`}, {-0.625, -2.}, \
{-0.5625000189670593, -2.084292589556062}, {-0.6377778151415994, \
-2.0970571419134454`}}], 
      PolygonBox[{{-0.5625, -2.}, {-0.5625000189670593, -2.084292589556062}, \
{-0.625, -2.}, {-0.5625, -2.}}], 
      PolygonBox[{{-0.625, -2.}, {-0.6377778151415994, -1.9029428580865548`}, \
{-0.5625, -2.}, {-0.625, -2.}}], 
      PolygonBox[{{-0.5625000189670593, -1.9157074104439382`}, {-0.5625, \
-2.}, {-0.6377778151415994, -1.9029428580865548`}, {-0.5625000189670593, \
-1.9157074104439382`}}], 
      PolygonBox[{{-0.6377778151415994, -1.9029428580865548`}, \
{-0.6752404735808355, -1.8125}, {-0.5625000189670593, -1.9157074104439382`}, \
{-0.6377778151415994, -1.9029428580865548`}}], 
      PolygonBox[{{-0.5626550066464766, -1.769748357463745}, \
{-0.5625000189670593, -1.9157074104439382`}, {-0.6752404735808355, -1.8125}, \
{-0.5626550066464766, -1.769748357463745}}], 
      PolygonBox[{{-0.6752404735808355, -1.8125}, {-0.7348349570550446, \
-1.7348349570550448`}, {-0.5626550066464766, -1.769748357463745}, \
{-0.6752404735808355, -1.8125}}], 
      PolygonBox[{{-0.5950572556670028, -1.5950572556670028`}, \
{-0.5626550066464766, -1.769748357463745}, {-0.7348349570550446, \
-1.7348349570550448`}, {-0.5950572556670028, -1.5950572556670028`}}], 
      PolygonBox[{{-0.7348349570550446, -1.7348349570550448`}, {-0.8125, \
-1.6752404735808355`}, {-0.5950572556670028, -1.5950572556670028`}, \
{-0.7348349570550446, -1.7348349570550448`}}], 
      PolygonBox[{{-0.7697483574637448, -1.5626550066464766`}, \
{-0.5950572556670028, -1.5950572556670028`}, {-0.8125, -1.6752404735808355`}, \
{-0.7697483574637448, -1.5626550066464766`}}], 
      PolygonBox[{{-0.8125, -1.6752404735808355`}, {-0.9029428580865546, \
-1.6377778151415994`}, {-0.7697483574637448, -1.5626550066464766`}, {-0.8125, \
-1.6752404735808355`}}], 
      PolygonBox[{{-0.9157074104439394, -1.5625000189670593`}, \
{-0.7697483574637448, -1.5626550066464766`}, {-0.9029428580865546, \
-1.6377778151415994`}, {-0.9157074104439394, -1.5625000189670593`}}], 
      PolygonBox[{{-0.9029428580865546, -1.6377778151415994`}, {-1., -1.625}, \
{-0.9157074104439394, -1.5625000189670593`}, {-0.9029428580865546, \
-1.6377778151415994`}}], 
      PolygonBox[{{-0.9998944727795123, -1.5625}, {-0.9157074104439394, \
-1.5625000189670593`}, {-1., -1.625}, {-0.9998944727795123, -1.5625}}], 
      PolygonBox[{{-1., -1.625}, {-1.0970571419134452`, \
-1.6377778151415994`}, {-0.9998944727795123, -1.5625}, {-1., -1.625}}], 
      PolygonBox[{{-1.084292589556057, -1.5625000189670593`}, \
{-0.9998944727795123, -1.5625}, {-1.0970571419134452`, -1.6377778151415994`}, \
{-1.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-1.0970571419134452`, -1.6377778151415994`}, {-1.1875, \
-1.6752404735808355`}, {-1.084292589556057, -1.5625000189670593`}, \
{-1.0970571419134452`, -1.6377778151415994`}}], 
      PolygonBox[{{-1.230251642536255, -1.5626550066464766`}, \
{-1.084292589556057, -1.5625000189670593`}, {-1.1875, -1.6752404735808355`}, \
{-1.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-1.1875, -1.6752404735808355`}, {-1.2651650429449552`, \
-1.7348349570550448`}, {-1.230251642536255, -1.5626550066464766`}, {-1.1875, \
-1.6752404735808355`}}], 
      PolygonBox[{{-1.4049427443329972`, -1.5950572556670028`}, \
{-1.230251642536255, -1.5626550066464766`}, {-1.2651650429449552`, \
-1.7348349570550448`}, {-1.4049427443329972`, -1.5950572556670028`}}], 
      PolygonBox[{{-1.2651650429449552`, -1.7348349570550448`}, \
{-1.3247595264191645`, -1.8125}, {-1.4049427443329972`, \
-1.5950572556670028`}, {-1.2651650429449552`, -1.7348349570550448`}}], 
      PolygonBox[{{-1.4373449933535234`, -1.7697483574637447`}, \
{-1.4049427443329972`, -1.5950572556670028`}, {-1.3247595264191645`, \
-1.8125}, {-1.4373449933535234`, -1.7697483574637447`}}], 
      PolygonBox[{{-1.3247595264191645`, -1.8125}, {-1.3622221848584006`, \
-1.9029428580865546`}, {-1.4373449933535234`, -1.7697483574637447`}, \
{-1.3247595264191645`, -1.8125}}], 
      PolygonBox[{{-1.4374999810329407`, -1.9157074104439376`}, \
{-1.4373449933535234`, -1.7697483574637447`}, {-1.3622221848584006`, \
-1.9029428580865546`}, {-1.4374999810329407`, -1.9157074104439376`}}], 
      PolygonBox[{{-1.3622221848584006`, -1.9029428580865546`}, {-1.375, \
-1.9999999999999998`}, {-1.4374999810329407`, -1.9157074104439376`}, \
{-1.3622221848584006`, -1.9029428580865546`}}], 
      PolygonBox[{{-1.4375, -1.9998768219370047`}, {-1.4374999810329407`, \
-1.9157074104439376`}, {-1.375, -1.9999999999999998`}, {-1.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-1.375, -1.9999999999999998`}, {-1.3622221848584006`, \
-2.097057141913445}, {-1.4375, -1.9998768219370047`}, {-1.375, \
-1.9999999999999998`}}], 
      PolygonBox[{{-1.4374999810329407`, -2.084292589556055}, {-1.4375, \
-1.9998768219370047`}, {-1.3622221848584006`, -2.097057141913445}, \
{-1.4374999810329407`, -2.084292589556055}}], 
      PolygonBox[{{-1.3622221848584006`, -2.097057141913445}, \
{-1.3247595264191645`, -2.1875}, {-1.4374999810329407`, -2.084292589556055}, \
{-1.3622221848584006`, -2.097057141913445}}], 
      PolygonBox[{{-1.4373449933535234`, -2.230251642536255}, \
{-1.4374999810329407`, -2.084292589556055}, {-1.3247595264191645`, -2.1875}, \
{-1.4373449933535234`, -2.230251642536255}}], 
      PolygonBox[{{-1.3247595264191645`, -2.1875}, {-1.2651650429449552`, \
-2.2651650429449552`}, {-1.4373449933535234`, -2.230251642536255}, \
{-1.3247595264191645`, -2.1875}}], 
      PolygonBox[{{-1.4049427443329972`, -2.404942744332997}, \
{-1.4373449933535234`, -2.230251642536255}, {-1.2651650429449552`, \
-2.2651650429449552`}, {-1.4049427443329972`, -2.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, -2.2651650429449552`}, \
{-1.1875000000000002`, -2.3247595264191645`}, {-1.4049427443329972`, \
-2.404942744332997}, {-1.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{-1.230251642536255, -2.4373449933535234`}, \
{-1.4049427443329972`, -2.404942744332997}, {-1.1875000000000002`, \
-2.3247595264191645`}, {-1.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{-1.1875000000000002`, -2.3247595264191645`}, \
{-1.0970571419134456`, -2.3622221848584006`}, {-1.230251642536255, \
-2.4373449933535234`}, {-1.1875000000000002`, -2.3247595264191645`}}], 
      PolygonBox[{{-1.0842925895560642`, -2.437499981032941}, \
{-1.230251642536255, -2.4373449933535234`}, {-1.0970571419134456`, \
-2.3622221848584006`}, {-1.0842925895560642`, -2.437499981032941}}], 
      PolygonBox[{{-1.0970571419134456`, -2.3622221848584006`}, \
{-0.9999999999999999, -2.375}, {-1.0842925895560642`, -2.437499981032941}, \
{-1.0970571419134456`, -2.3622221848584006`}}], 
      PolygonBox[{{-0.999865158168957, -2.4375}, {-1.0842925895560642`, \
-2.437499981032941}, {-0.9999999999999999, -2.375}, {-0.999865158168957, \
-2.4375}}], 
      PolygonBox[{{-0.9999999999999999, -2.375}, {-0.9029428580865548, \
-2.3622221848584006`}, {-0.999865158168957, -2.4375}, {-0.9999999999999999, \
-2.375}}], 
      PolygonBox[{{-0.9157074104439469, -2.437499981032941}, \
{-0.999865158168957, -2.4375}, {-0.9029428580865548, -2.3622221848584006`}, \
{-0.9157074104439469, -2.437499981032941}}], 
      PolygonBox[{{-0.9029428580865548, -2.3622221848584006`}, \
{-0.8125000000000002, -2.3247595264191645`}, {-0.9157074104439469, \
-2.437499981032941}, {-0.9029428580865548, -2.3622221848584006`}}], 
      PolygonBox[{{-0.7697483574637453, -2.4373449933535234`}, \
{-0.9157074104439469, -2.437499981032941}, {-0.8125000000000002, \
-2.3247595264191645`}, {-0.7697483574637453, -2.4373449933535234`}}], 
      PolygonBox[{{-0.8125000000000002, -2.3247595264191645`}, \
{-0.7348349570550448, -2.2651650429449552`}, {-0.7697483574637453, \
-2.4373449933535234`}, {-0.8125000000000002, -2.3247595264191645`}}], 
      PolygonBox[{{-0.5950572556670028, -2.404942744332997}, \
{-0.7697483574637453, -2.4373449933535234`}, {-0.7348349570550448, \
-2.2651650429449552`}, {-0.5950572556670028, -2.404942744332997}}], 
      PolygonBox[{{-0.7348349570550448, -2.2651650429449552`}, \
{-0.7348349570550446, -2.2651650429449552`}, {-0.5950572556670028, \
-2.404942744332997}, {-0.7348349570550448, -2.2651650429449552`}}], 
      PolygonBox[{{-0.5950572556670028, -2.404942744332997}, \
{-0.5950572556670028, -2.404942744332997}, {-0.7348349570550446, \
-2.2651650429449552`}, {-0.5950572556670028, -2.404942744332997}}], 
      PolygonBox[{{-0.5950572556670028, -2.404942744332997}, \
{-0.5626550066464766, -2.2302516425362553`}, {-0.5, -2.5}, \
{-0.5950572556670028, -2.404942744332997}}], 
      PolygonBox[{{-0.5, -2.357662782649368}, {-0.5, -2.5}, \
{-0.5626550066464766, -2.2302516425362553`}, {-0.5, -2.357662782649368}}], 
      PolygonBox[{{-0.5626550066464766, -2.2302516425362553`}, \
{-0.5625000189670593, -2.084292589556062}, {-0.5, -2.357662782649368}, \
{-0.5626550066464766, -2.2302516425362553`}}], 
      PolygonBox[{{-0.5, -2.20590900530174}, {-0.5, -2.357662782649368}, \
{-0.5625000189670593, -2.084292589556062}, {-0.5, -2.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, -2.084292589556062}, {-0.5625, -2.}, \
{-0.5, -2.20590900530174}, {-0.5625000189670593, -2.084292589556062}}], 
      PolygonBox[{{-0.5, -2.}, {-0.5, -2.20590900530174}, {-0.5625, -2.}, \
{-0.5, -2.}}], 
      PolygonBox[{{-0.5625, -2.}, {-0.5625000189670593, \
-1.9157074104439382`}, {-0.5, -2.}, {-0.5625, -2.}}], 
      PolygonBox[{{-0.5, -1.7940909946982602`}, {-0.5, -2.}, \
{-0.5625000189670593, -1.9157074104439382`}, {-0.5, -1.7940909946982602`}}], 
      PolygonBox[{{-0.5625000189670593, -1.9157074104439382`}, \
{-0.5626550066464766, -1.769748357463745}, {-0.5, -1.7940909946982602`}, \
{-0.5625000189670593, -1.9157074104439382`}}], 
      PolygonBox[{{-0.5, -1.6423372173506325`}, {-0.5, -1.7940909946982602`}, \
{-0.5626550066464766, -1.769748357463745}, {-0.5, -1.6423372173506325`}}], 
      PolygonBox[{{-0.5626550066464766, -1.769748357463745}, \
{-0.5950572556670028, -1.5950572556670028`}, {-0.5, -1.6423372173506325`}, \
{-0.5626550066464766, -1.769748357463745}}], 
      PolygonBox[{{-0.508553435038814, -1.508553435038814}, {-0.5, \
-1.6423372173506325`}, {-0.5950572556670028, -1.5950572556670028`}, \
{-0.508553435038814, -1.508553435038814}}], 
      PolygonBox[{{-0.5950572556670028, -1.5950572556670028`}, \
{-0.7697483574637448, -1.5626550066464766`}, {-0.508553435038814, \
-1.508553435038814}, {-0.5950572556670028, -1.5950572556670028`}}], 
      PolygonBox[{{-0.6423372173506319, -1.5}, {-0.508553435038814, \
-1.508553435038814}, {-0.7697483574637448, -1.5626550066464766`}, \
{-0.6423372173506319, -1.5}}], 
      PolygonBox[{{-0.7697483574637448, -1.5626550066464766`}, \
{-0.9157074104439394, -1.5625000189670593`}, {-0.6423372173506319, -1.5}, \
{-0.7697483574637448, -1.5626550066464766`}}], 
      PolygonBox[{{-0.7940909946267442, -1.5}, {-0.6423372173506319, -1.5}, \
{-0.9157074104439394, -1.5625000189670593`}, {-0.7940909946267442, -1.5}}], 
      PolygonBox[{{-0.9157074104439394, -1.5625000189670593`}, \
{-0.9998944727795123, -1.5625}, {-0.7940909946267442, -1.5}, \
{-0.9157074104439394, -1.5625000189670593`}}], 
      PolygonBox[{{-0.9220580419731099, -1.5}, {-0.7940909946267442, -1.5}, \
{-0.9998944727795123, -1.5625}, {-0.9220580419731099, -1.5}}], 
      PolygonBox[{{-0.9998944727795123, -1.5625}, {-1.084292589556057, \
-1.5625000189670593`}, {-0.9220580419731099, -1.5}, {-0.9998944727795123, \
-1.5625}}], 
      PolygonBox[{{-1.2059090053044457`, -1.5}, {-0.9220580419731099, -1.5}, \
{-1.084292589556057, -1.5625000189670593`}, {-1.2059090053044457`, -1.5}}], 
      PolygonBox[{{-1.084292589556057, -1.5625000189670593`}, \
{-1.230251642536255, -1.5626550066464766`}, {-1.2059090053044457`, -1.5}, \
{-1.084292589556057, -1.5625000189670593`}}], 
      PolygonBox[{{-1.3576627826493661`, -1.5}, {-1.2059090053044457`, -1.5}, \
{-1.230251642536255, -1.5626550066464766`}, {-1.3576627826493661`, -1.5}}], 
      PolygonBox[{{-1.230251642536255, -1.5626550066464766`}, \
{-1.4049427443329972`, -1.5950572556670028`}, {-1.3576627826493661`, -1.5}, \
{-1.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{-0.5, -1.5}, {-1.3576627826493661`, -1.5}, \
{-1.4049427443329972`, -1.5950572556670028`}, {-0.5, -1.5}}], 
      PolygonBox[{{-1.4049427443329972`, -1.5950572556670028`}, \
{-1.4373449933535234`, -1.7697483574637447`}, {-0.5, -1.5}, \
{-1.4049427443329972`, -1.5950572556670028`}}], 
      PolygonBox[{{-1.5, -1.642337217350631}, {-0.5, -1.5}, \
{-1.4373449933535234`, -1.7697483574637447`}, {-1.5, -1.642337217350631}}], 
      PolygonBox[{{-1.4373449933535234`, -1.7697483574637447`}, \
{-1.4374999810329407`, -1.9157074104439376`}, {-1.5, -1.642337217350631}, \
{-1.4373449933535234`, -1.7697483574637447`}}], 
      PolygonBox[{{-1.5, -1.794090994717101}, {-1.5, -1.642337217350631}, \
{-1.4374999810329407`, -1.9157074104439376`}, {-1.5, -1.794090994717101}}], 
      PolygonBox[{{-1.4374999810329407`, -1.9157074104439376`}, {-1.4375, \
-1.9998768219370047`}, {-1.5, -1.794090994717101}, {-1.4374999810329407`, \
-1.9157074104439376`}}], 
      PolygonBox[{{-1.5, -1.9193213332412997`}, {-1.5, -1.794090994717101}, \
{-1.4375, -1.9998768219370047`}, {-1.5, -1.9193213332412997`}}], 
      PolygonBox[{{-1.4375, -1.9998768219370047`}, {-1.4374999810329407`, \
-2.084292589556055}, {-1.5, -1.9193213332412997`}, {-1.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-1.5, -2.2059090051452785`}, {-1.5, -1.9193213332412997`}, \
{-1.4374999810329407`, -2.084292589556055}, {-1.5, -2.2059090051452785`}}], 
      PolygonBox[{{-1.4374999810329407`, -2.084292589556055}, \
{-1.4373449933535234`, -2.230251642536255}, {-1.5, -2.2059090051452785`}, \
{-1.4374999810329407`, -2.084292589556055}}], 
      PolygonBox[{{-1.5, -2.3576627826493652`}, {-1.5, -2.2059090051452785`}, \
{-1.4373449933535234`, -2.230251642536255}, {-1.5, -2.3576627826493652`}}], 
      PolygonBox[{{-1.4373449933535234`, -2.230251642536255}, \
{-1.4049427443329972`, -2.404942744332997}, {-1.5, -2.3576627826493652`}, \
{-1.4373449933535234`, -2.230251642536255}}], 
      PolygonBox[{{-1.5, -1.5}, {-1.5, -2.3576627826493652`}, \
{-1.4049427443329972`, -2.404942744332997}, {-1.5, -1.5}}], 
      PolygonBox[{{-1.4049427443329972`, -2.404942744332997}, \
{-1.230251642536255, -2.4373449933535234`}, {-1.5, -1.5}, \
{-1.4049427443329972`, -2.404942744332997}}], 
      PolygonBox[{{-1.5, -2.5}, {-1.5, -1.5}, {-1.230251642536255, \
-2.4373449933535234`}, {-1.5, -2.5}}], 
      PolygonBox[{{-1.230251642536255, -2.4373449933535234`}, \
{-1.0842925895560642`, -2.437499981032941}, {-1.5, -2.5}, \
{-1.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{-1.205909005566828, -2.5}, {-1.5, -2.5}, \
{-1.0842925895560642`, -2.437499981032941}, {-1.205909005566828, -2.5}}], 
      PolygonBox[{{-1.0842925895560642`, -2.437499981032941}, \
{-0.999865158168957, -2.4375}, {-1.205909005566828, -2.5}, \
{-1.0842925895560642`, -2.437499981032941}}], 
      PolygonBox[{{-0.9176761295989384, -2.5}, {-1.205909005566828, -2.5}, \
{-0.999865158168957, -2.4375}, {-0.9176761295989384, -2.5}}], 
      PolygonBox[{{-0.999865158168957, -2.4375}, {-0.9157074104439469, \
-2.437499981032941}, {-0.9176761295989384, -2.5}, {-0.999865158168957, \
-2.4375}}], 
      PolygonBox[{{-0.7940909946396026, -2.5}, {-0.9176761295989384, -2.5}, \
{-0.9157074104439469, -2.437499981032941}, {-0.7940909946396026, -2.5}}], 
      PolygonBox[{{-0.9157074104439469, -2.437499981032941}, \
{-0.7697483574637453, -2.4373449933535234`}, {-0.7940909946396026, -2.5}, \
{-0.9157074104439469, -2.437499981032941}}], 
      PolygonBox[{{-0.642337217350629, -2.5}, {-0.7940909946396026, -2.5}, \
{-0.7697483574637453, -2.4373449933535234`}, {-0.642337217350629, -2.5}}], 
      PolygonBox[{{-0.7697483574637453, -2.4373449933535234`}, \
{-0.5950572556670028, -2.404942744332997}, {-0.642337217350629, -2.5}, \
{-0.7697483574637453, -2.4373449933535234`}}], 
      PolygonBox[{{-0.5, -2.5}, {-0.642337217350629, -2.5}, \
{-0.5950572556670028, -2.404942744332997}, {-0.5, -2.5}}], 
      PolygonBox[{{-0.5950572556670028, -2.404942744332997}, \
{-0.5950572556670028, -2.404942744332997}, {-0.5, -2.5}, \
{-0.5950572556670028, -2.404942744332997}}], 
      PolygonBox[{{-0.5, -2.5}, {-0.5, -2.5}, {-0.5950572556670028, \
-2.404942744332997}, {-0.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, -1.}, {-1.4791666666666667`, -1.}, \
{-1.4583333333333333`, -1.}, {-1.4375, -1.}, {-1.4166666666666667`, -1.}, \
{-1.3958333333333335`, -1.}, {-1.375, -1.}, {-1.375, -1.}, \
{-1.3958333333333333`, -1.}, {-1.4166666666666667`, -1.}, {-1.4375, -1.}, \
{-1.4583333333333333`, -1.}, {-1.4791666666666665`, -1.}, {-1.5, -1.}, {-1.5, \
-1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, -1.}, {-0.6041666666666667, -1.}, \
{-0.5833333333333333, -1.}, {-0.5625, -1.}, {-0.5416666666666667, -1.}, \
{-0.5208333333333334, -1.}, {-0.5, -1.}, {-0.5, -1.}, {-0.5208333333333333, \
-1.}, {-0.5416666666666667, -1.}, {-0.5625, -1.}, {-0.5833333333333333, -1.}, \
{-0.6041666666666666, -1.}, {-0.625, -1.}, {-0.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -1.5}, {-1., -1.4791666666666667`}, {-1., \
-1.4583333333333333`}, {-1., -1.4375}, {-1., -1.4166666666666667`}, {-1., \
-1.3958333333333335`}, {-1., -1.375}, {-1., -1.375}, {-1., \
-1.3958333333333333`}, {-1., -1.4166666666666667`}, {-1., -1.4375}, {-1., \
-1.4583333333333333`}, {-1., -1.4791666666666665`}, {-1., -1.5}, {-1., \
-1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -0.625}, {-1., -0.6041666666666667}, {-1., \
-0.5833333333333333}, {-1., -0.5625}, {-1., -0.5416666666666667}, {-1., \
-0.5208333333333334}, {-1., -0.5}, {-1., -0.5}, {-1., -0.5208333333333333}, \
{-1., -0.5416666666666667}, {-1., -0.5625}, {-1., -0.5833333333333333}, {-1., \
-0.6041666666666666}, {-1., -0.625}, {-1., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, -1.}, {-1.25, -1.}, {-1.125, -1.}, {-1., -1.}, \
{-0.875, -1.}, {-0.75, -1.}, {-0.625, -1.}, {-0.625, -1.}, {-0.75, -1.}, \
{-0.875, -1.}, {-1., -1.}, {-1.125, -1.}, {-1.25, -1.}, {-1.375, -1.}, \
{-1.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -1.375}, {-1., -1.25}, {-1., -1.125}, {-1., -1.}, {-1., \
-0.875}, {-1., -0.75}, {-1., -0.625}, {-1., -0.625}, {-1., -0.75}, {-1., \
-0.875}, {-1., -1.}, {-1., -1.125}, {-1., -1.25}, {-1., -1.375}, {-1., \
-1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kPoD/sjdriwrs14sv9o3pbsF0/e7Hd4fO/F
xNlPofKv9k/2nDDzSPPz/VOgNEwcpu4IVB/MHJi5MHvmnlA91d37EU3+M1y/
2W3zzbJ2X+D2JPRN4DY3+rr/Pxi83H9lcWztytNf4fZA9H+D2wOTh9kD0w+z
xxxqPsweRqg4TN18qD6YOaju/7b/GNRemDwT1P8w/bBwgZnvCPUXzJ5IqL9h
9qCHPwB8ecEa
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9sPoUDB4CuevAoNX+1HVfUCT/4Sm/yua+h8E
+aj2/kCz9weavT/Q7P2BZu8PnHQYmrrVaOag27MazR1haO4k1p9haOGyGi3c
0MN1NVq4h6HFC4wGAFzSjzI=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, -1.2651650429449552`}, \
{-0.6752404735808355, -1.1875}, {-0.5950572556670028, -1.4049427443329972`}, \
{-0.7348349570550446, -1.2651650429449552`}}], 
      PolygonBox[{{-0.5626550066464766, -1.230251642536255}, \
{-0.5950572556670028, -1.4049427443329972`}, {-0.6752404735808355, -1.1875}, \
{-0.5626550066464766, -1.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, -1.1875}, {-0.6377778151415994, \
-1.0970571419134454`}, {-0.5626550066464766, -1.230251642536255}, \
{-0.6752404735808355, -1.1875}}], 
      PolygonBox[{{-0.5625000189670593, -1.0842925895560618`}, \
{-0.5626550066464766, -1.230251642536255}, {-0.6377778151415994, \
-1.0970571419134454`}, {-0.5625000189670593, -1.0842925895560618`}}], 
      PolygonBox[{{-0.6377778151415994, -1.0970571419134454`}, {-0.625, -1.}, \
{-0.5625000189670593, -1.0842925895560618`}, {-0.6377778151415994, \
-1.0970571419134454`}}], 
      PolygonBox[{{-0.5625, -1.}, {-0.5625000189670593, \
-1.0842925895560618`}, {-0.625, -1.}, {-0.5625, -1.}}], 
      PolygonBox[{{-0.625, -1.}, {-0.6377778151415994, -0.9029428580865547}, \
{-0.5625, -1.}, {-0.625, -1.}}], 
      PolygonBox[{{-0.5625000189670593, -0.9157074104439382}, {-0.5625, -1.}, \
{-0.6377778151415994, -0.9029428580865547}, {-0.5625000189670593, \
-0.9157074104439382}}], 
      PolygonBox[{{-0.6377778151415994, -0.9029428580865547}, \
{-0.6752404735808355, -0.8125}, {-0.5625000189670593, -0.9157074104439382}, \
{-0.6377778151415994, -0.9029428580865547}}], 
      PolygonBox[{{-0.5626550066464766, -0.7697483574637449}, \
{-0.5625000189670593, -0.9157074104439382}, {-0.6752404735808355, -0.8125}, \
{-0.5626550066464766, -0.7697483574637449}}], 
      PolygonBox[{{-0.6752404735808355, -0.8125}, {-0.7348349570550446, \
-0.7348349570550448}, {-0.5626550066464766, -0.7697483574637449}, \
{-0.6752404735808355, -0.8125}}], 
      PolygonBox[{{-0.5950572556670028, -0.5950572556670028}, \
{-0.5626550066464766, -0.7697483574637449}, {-0.7348349570550446, \
-0.7348349570550448}, {-0.5950572556670028, -0.5950572556670028}}], 
      PolygonBox[{{-0.7348349570550446, -0.7348349570550448}, {-0.8125, \
-0.6752404735808355}, {-0.5950572556670028, -0.5950572556670028}, \
{-0.7348349570550446, -0.7348349570550448}}], 
      PolygonBox[{{-0.7697483574637448, -0.5626550066464766}, \
{-0.5950572556670028, -0.5950572556670028}, {-0.8125, -0.6752404735808355}, \
{-0.7697483574637448, -0.5626550066464766}}], 
      PolygonBox[{{-0.8125, -0.6752404735808355}, {-0.9029428580865546, \
-0.6377778151415994}, {-0.7697483574637448, -0.5626550066464766}, {-0.8125, \
-0.6752404735808355}}], 
      PolygonBox[{{-0.9157074104439394, -0.5625000189670593}, \
{-0.7697483574637448, -0.5626550066464766}, {-0.9029428580865546, \
-0.6377778151415994}, {-0.9157074104439394, -0.5625000189670593}}], 
      PolygonBox[{{-0.9029428580865546, -0.6377778151415994}, {-1., -0.625}, \
{-0.9157074104439394, -0.5625000189670593}, {-0.9029428580865546, \
-0.6377778151415994}}], 
      PolygonBox[{{-0.9998944727795123, -0.5625}, {-0.9157074104439394, \
-0.5625000189670593}, {-1., -0.625}, {-0.9998944727795123, -0.5625}}], 
      PolygonBox[{{-1., -0.625}, {-1.0970571419134452`, -0.6377778151415994}, \
{-0.9998944727795123, -0.5625}, {-1., -0.625}}], 
      PolygonBox[{{-1.084292589556057, -0.5625000189670593}, \
{-0.9998944727795123, -0.5625}, {-1.0970571419134452`, -0.6377778151415994}, \
{-1.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-1.0970571419134452`, -0.6377778151415994}, {-1.1875, \
-0.6752404735808355}, {-1.084292589556057, -0.5625000189670593}, \
{-1.0970571419134452`, -0.6377778151415994}}], 
      PolygonBox[{{-1.230251642536255, -0.5626550066464766}, \
{-1.084292589556057, -0.5625000189670593}, {-1.1875, -0.6752404735808355}, \
{-1.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-1.1875, -0.6752404735808355}, {-1.2651650429449552`, \
-0.7348349570550446}, {-1.230251642536255, -0.5626550066464766}, {-1.1875, \
-0.6752404735808355}}], 
      PolygonBox[{{-1.4049427443329972`, -0.5950572556670028}, \
{-1.230251642536255, -0.5626550066464766}, {-1.2651650429449552`, \
-0.7348349570550446}, {-1.4049427443329972`, -0.5950572556670028}}], 
      PolygonBox[{{-1.2651650429449552`, -0.7348349570550446}, \
{-1.3247595264191645`, -0.8124999999999999}, {-1.4049427443329972`, \
-0.5950572556670028}, {-1.2651650429449552`, -0.7348349570550446}}], 
      PolygonBox[{{-1.4373449933535234`, -0.7697483574637446}, \
{-1.4049427443329972`, -0.5950572556670028}, {-1.3247595264191645`, \
-0.8124999999999999}, {-1.4373449933535234`, -0.7697483574637446}}], 
      PolygonBox[{{-1.3247595264191645`, -0.8124999999999999}, \
{-1.3622221848584006`, -0.9029428580865546}, {-1.4373449933535234`, \
-0.7697483574637446}, {-1.3247595264191645`, -0.8124999999999999}}], 
      PolygonBox[{{-1.4374999810329407`, -0.9157074104439377}, \
{-1.4373449933535234`, -0.7697483574637446}, {-1.3622221848584006`, \
-0.9029428580865546}, {-1.4374999810329407`, -0.9157074104439377}}], 
      PolygonBox[{{-1.3622221848584006`, -0.9029428580865546}, {-1.375, \
-0.9999999999999998}, {-1.4374999810329407`, -0.9157074104439377}, \
{-1.3622221848584006`, -0.9029428580865546}}], 
      PolygonBox[{{-1.4375, -0.9998768219370047}, {-1.4374999810329407`, \
-0.9157074104439377}, {-1.375, -0.9999999999999998}, {-1.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-1.375, -0.9999999999999998}, {-1.3622221848584006`, \
-1.0970571419134452`}, {-1.4375, -0.9998768219370047}, {-1.375, \
-0.9999999999999998}}], 
      PolygonBox[{{-1.4374999810329407`, -1.084292589556055}, {-1.4375, \
-0.9998768219370047}, {-1.3622221848584006`, -1.0970571419134452`}, \
{-1.4374999810329407`, -1.084292589556055}}], 
      PolygonBox[{{-1.3622221848584006`, -1.0970571419134452`}, \
{-1.3247595264191645`, -1.1874999999999998`}, {-1.4374999810329407`, \
-1.084292589556055}, {-1.3622221848584006`, -1.0970571419134452`}}], 
      PolygonBox[{{-1.4373449933535234`, -1.2302516425362549`}, \
{-1.4374999810329407`, -1.084292589556055}, {-1.3247595264191645`, \
-1.1874999999999998`}, {-1.4373449933535234`, -1.2302516425362549`}}], 
      PolygonBox[{{-1.3247595264191645`, -1.1874999999999998`}, \
{-1.2651650429449552`, -1.2651650429449552`}, {-1.4373449933535234`, \
-1.2302516425362549`}, {-1.3247595264191645`, -1.1874999999999998`}}], 
      PolygonBox[{{-1.4049427443329972`, -1.4049427443329972`}, \
{-1.4373449933535234`, -1.2302516425362549`}, {-1.2651650429449552`, \
-1.2651650429449552`}, {-1.4049427443329972`, -1.4049427443329972`}}], 
      PolygonBox[{{-1.2651650429449552`, -1.2651650429449552`}, \
{-1.1875000000000002`, -1.3247595264191645`}, {-1.4049427443329972`, \
-1.4049427443329972`}, {-1.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{-1.230251642536255, -1.4373449933535234`}, \
{-1.4049427443329972`, -1.4049427443329972`}, {-1.1875000000000002`, \
-1.3247595264191645`}, {-1.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-1.1875000000000002`, -1.3247595264191645`}, \
{-1.0970571419134456`, -1.3622221848584006`}, {-1.230251642536255, \
-1.4373449933535234`}, {-1.1875000000000002`, -1.3247595264191645`}}], 
      PolygonBox[{{-1.0842925895560642`, -1.4374999810329407`}, \
{-1.230251642536255, -1.4373449933535234`}, {-1.0970571419134456`, \
-1.3622221848584006`}, {-1.0842925895560642`, -1.4374999810329407`}}], 
      PolygonBox[{{-1.0970571419134456`, -1.3622221848584006`}, \
{-0.9999999999999999, -1.375}, {-1.0842925895560642`, -1.4374999810329407`}, \
{-1.0970571419134456`, -1.3622221848584006`}}], 
      PolygonBox[{{-0.999865158168957, -1.4375}, {-1.0842925895560642`, \
-1.4374999810329407`}, {-0.9999999999999999, -1.375}, {-0.999865158168957, \
-1.4375}}], 
      PolygonBox[{{-0.9999999999999999, -1.375}, {-0.9029428580865548, \
-1.3622221848584006`}, {-0.999865158168957, -1.4375}, {-0.9999999999999999, \
-1.375}}], 
      PolygonBox[{{-0.9157074104439469, -1.4374999810329407`}, \
{-0.999865158168957, -1.4375}, {-0.9029428580865548, -1.3622221848584006`}, \
{-0.9157074104439469, -1.4374999810329407`}}], 
      PolygonBox[{{-0.9029428580865548, -1.3622221848584006`}, \
{-0.8125000000000002, -1.3247595264191645`}, {-0.9157074104439469, \
-1.4374999810329407`}, {-0.9029428580865548, -1.3622221848584006`}}], 
      PolygonBox[{{-0.7697483574637453, -1.4373449933535234`}, \
{-0.9157074104439469, -1.4374999810329407`}, {-0.8125000000000002, \
-1.3247595264191645`}, {-0.7697483574637453, -1.4373449933535234`}}], 
      PolygonBox[{{-0.8125000000000002, -1.3247595264191645`}, \
{-0.7348349570550448, -1.2651650429449552`}, {-0.7697483574637453, \
-1.4373449933535234`}, {-0.8125000000000002, -1.3247595264191645`}}], 
      PolygonBox[{{-0.5950572556670028, -1.4049427443329972`}, \
{-0.7697483574637453, -1.4373449933535234`}, {-0.7348349570550448, \
-1.2651650429449552`}, {-0.5950572556670028, -1.4049427443329972`}}], 
      PolygonBox[{{-0.7348349570550448, -1.2651650429449552`}, \
{-0.7348349570550446, -1.2651650429449552`}, {-0.5950572556670028, \
-1.4049427443329972`}, {-0.7348349570550448, -1.2651650429449552`}}], 
      PolygonBox[{{-0.5950572556670028, -1.4049427443329972`}, \
{-0.5950572556670028, -1.4049427443329972`}, {-0.7348349570550446, \
-1.2651650429449552`}, {-0.5950572556670028, -1.4049427443329972`}}], 
      PolygonBox[{{-0.5950572556670028, -1.4049427443329972`}, \
{-0.5626550066464766, -1.230251642536255}, {-0.5, -1.5}, \
{-0.5950572556670028, -1.4049427443329972`}}], 
      PolygonBox[{{-0.5, -1.3576627826493677`}, {-0.5, -1.5}, \
{-0.5626550066464766, -1.230251642536255}, {-0.5, -1.3576627826493677`}}], 
      PolygonBox[{{-0.5626550066464766, -1.230251642536255}, \
{-0.5625000189670593, -1.0842925895560618`}, {-0.5, -1.3576627826493677`}, \
{-0.5626550066464766, -1.230251642536255}}], 
      PolygonBox[{{-0.5, -1.20590900530174}, {-0.5, -1.3576627826493677`}, \
{-0.5625000189670593, -1.0842925895560618`}, {-0.5, -1.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, -1.0842925895560618`}, {-0.5625, \
-1.}, {-0.5, -1.20590900530174}, {-0.5625000189670593, \
-1.0842925895560618`}}], 
      PolygonBox[{{-0.5, -1.}, {-0.5, -1.20590900530174}, {-0.5625, -1.}, \
{-0.5, -1.}}], 
      PolygonBox[{{-0.5625, -1.}, {-0.5625000189670593, -0.9157074104439382}, \
{-0.5, -1.}, {-0.5625, -1.}}], 
      PolygonBox[{{-0.5, -0.79409099469826}, {-0.5, -1.}, \
{-0.5625000189670593, -0.9157074104439382}, {-0.5, -0.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, -0.9157074104439382}, \
{-0.5626550066464766, -0.7697483574637449}, {-0.5, -0.79409099469826}, \
{-0.5625000189670593, -0.9157074104439382}}], 
      PolygonBox[{{-0.5, -0.6423372173506324}, {-0.5, -0.79409099469826}, \
{-0.5626550066464766, -0.7697483574637449}, {-0.5, -0.6423372173506324}}], 
      PolygonBox[{{-0.5626550066464766, -0.7697483574637449}, \
{-0.5950572556670028, -0.5950572556670028}, {-0.5, -0.6423372173506324}, \
{-0.5626550066464766, -0.7697483574637449}}], 
      PolygonBox[{{-0.508553435038814, -0.508553435038814}, {-0.5, \
-0.6423372173506324}, {-0.5950572556670028, -0.5950572556670028}, \
{-0.508553435038814, -0.508553435038814}}], 
      PolygonBox[{{-0.5950572556670028, -0.5950572556670028}, \
{-0.7697483574637448, -0.5626550066464766}, {-0.508553435038814, \
-0.508553435038814}, {-0.5950572556670028, -0.5950572556670028}}], 
      PolygonBox[{{-0.6423372173506319, -0.5}, {-0.508553435038814, \
-0.508553435038814}, {-0.7697483574637448, -0.5626550066464766}, \
{-0.6423372173506319, -0.5}}], 
      PolygonBox[{{-0.7697483574637448, -0.5626550066464766}, \
{-0.9157074104439394, -0.5625000189670593}, {-0.6423372173506319, -0.5}, \
{-0.7697483574637448, -0.5626550066464766}}], 
      PolygonBox[{{-0.7940909946267442, -0.5}, {-0.6423372173506319, -0.5}, \
{-0.9157074104439394, -0.5625000189670593}, {-0.7940909946267442, -0.5}}], 
      PolygonBox[{{-0.9157074104439394, -0.5625000189670593}, \
{-0.9998944727795123, -0.5625}, {-0.7940909946267442, -0.5}, \
{-0.9157074104439394, -0.5625000189670593}}], 
      PolygonBox[{{-0.9220580419731099, -0.5}, {-0.7940909946267442, -0.5}, \
{-0.9998944727795123, -0.5625}, {-0.9220580419731099, -0.5}}], 
      PolygonBox[{{-0.9998944727795123, -0.5625}, {-1.084292589556057, \
-0.5625000189670593}, {-0.9220580419731099, -0.5}, {-0.9998944727795123, \
-0.5625}}], 
      PolygonBox[{{-1.2059090053044457`, -0.5}, {-0.9220580419731099, -0.5}, \
{-1.084292589556057, -0.5625000189670593}, {-1.2059090053044457`, -0.5}}], 
      PolygonBox[{{-1.084292589556057, -0.5625000189670593}, \
{-1.230251642536255, -0.5626550066464766}, {-1.2059090053044457`, -0.5}, \
{-1.084292589556057, -0.5625000189670593}}], 
      PolygonBox[{{-1.3576627826493661`, -0.5}, {-1.2059090053044457`, -0.5}, \
{-1.230251642536255, -0.5626550066464766}, {-1.3576627826493661`, -0.5}}], 
      PolygonBox[{{-1.230251642536255, -0.5626550066464766}, \
{-1.4049427443329972`, -0.5950572556670028}, {-1.3576627826493661`, -0.5}, \
{-1.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{-0.5, -0.5}, {-1.3576627826493661`, -0.5}, \
{-1.4049427443329972`, -0.5950572556670028}, {-0.5, -0.5}}], 
      PolygonBox[{{-1.4049427443329972`, -0.5950572556670028}, \
{-1.4373449933535234`, -0.7697483574637446}, {-0.5, -0.5}, \
{-1.4049427443329972`, -0.5950572556670028}}], 
      PolygonBox[{{-1.5, -0.642337217350631}, {-0.5, -0.5}, \
{-1.4373449933535234`, -0.7697483574637446}, {-1.5, -0.642337217350631}}], 
      PolygonBox[{{-1.4373449933535234`, -0.7697483574637446}, \
{-1.4374999810329407`, -0.9157074104439377}, {-1.5, -0.642337217350631}, \
{-1.4373449933535234`, -0.7697483574637446}}], 
      PolygonBox[{{-1.5, -0.7940909947171011}, {-1.5, -0.642337217350631}, \
{-1.4374999810329407`, -0.9157074104439377}, {-1.5, -0.7940909947171011}}], 
      PolygonBox[{{-1.4374999810329407`, -0.9157074104439377}, {-1.4375, \
-0.9998768219370047}, {-1.5, -0.7940909947171011}, {-1.4374999810329407`, \
-0.9157074104439377}}], 
      PolygonBox[{{-1.5, -0.9193213332412997}, {-1.5, -0.7940909947171011}, \
{-1.4375, -0.9998768219370047}, {-1.5, -0.9193213332412997}}], 
      PolygonBox[{{-1.4375, -0.9998768219370047}, {-1.4374999810329407`, \
-1.084292589556055}, {-1.5, -0.9193213332412997}, {-1.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-1.5, -1.2059090051452785`}, {-1.5, -0.9193213332412997}, \
{-1.4374999810329407`, -1.084292589556055}, {-1.5, -1.2059090051452785`}}], 
      PolygonBox[{{-1.4374999810329407`, -1.084292589556055}, \
{-1.4373449933535234`, -1.2302516425362549`}, {-1.5, -1.2059090051452785`}, \
{-1.4374999810329407`, -1.084292589556055}}], 
      PolygonBox[{{-1.5, -1.3576627826493652`}, {-1.5, -1.2059090051452785`}, \
{-1.4373449933535234`, -1.2302516425362549`}, {-1.5, -1.3576627826493652`}}], 
      PolygonBox[{{-1.4373449933535234`, -1.2302516425362549`}, \
{-1.4049427443329972`, -1.4049427443329972`}, {-1.5, -1.3576627826493652`}, \
{-1.4373449933535234`, -1.2302516425362549`}}], 
      PolygonBox[{{-1.5, -0.5}, {-1.5, -1.3576627826493652`}, \
{-1.4049427443329972`, -1.4049427443329972`}, {-1.5, -0.5}}], 
      PolygonBox[{{-1.4049427443329972`, -1.4049427443329972`}, \
{-1.230251642536255, -1.4373449933535234`}, {-1.5, -0.5}, \
{-1.4049427443329972`, -1.4049427443329972`}}], 
      PolygonBox[{{-1.5, -1.5}, {-1.5, -0.5}, {-1.230251642536255, \
-1.4373449933535234`}, {-1.5, -1.5}}], 
      PolygonBox[{{-1.230251642536255, -1.4373449933535234`}, \
{-1.0842925895560642`, -1.4374999810329407`}, {-1.5, -1.5}, \
{-1.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{-1.205909005566828, -1.5}, {-1.5, -1.5}, \
{-1.0842925895560642`, -1.4374999810329407`}, {-1.205909005566828, -1.5}}], 
      PolygonBox[{{-1.0842925895560642`, -1.4374999810329407`}, \
{-0.999865158168957, -1.4375}, {-1.205909005566828, -1.5}, \
{-1.0842925895560642`, -1.4374999810329407`}}], 
      PolygonBox[{{-0.9176761295989384, -1.5}, {-1.205909005566828, -1.5}, \
{-0.999865158168957, -1.4375}, {-0.9176761295989384, -1.5}}], 
      PolygonBox[{{-0.999865158168957, -1.4375}, {-0.9157074104439469, \
-1.4374999810329407`}, {-0.9176761295989384, -1.5}, {-0.999865158168957, \
-1.4375}}], 
      PolygonBox[{{-0.7940909946396026, -1.5}, {-0.9176761295989384, -1.5}, \
{-0.9157074104439469, -1.4374999810329407`}, {-0.7940909946396026, -1.5}}], 
      PolygonBox[{{-0.9157074104439469, -1.4374999810329407`}, \
{-0.7697483574637453, -1.4373449933535234`}, {-0.7940909946396026, -1.5}, \
{-0.9157074104439469, -1.4374999810329407`}}], 
      PolygonBox[{{-0.642337217350629, -1.5}, {-0.7940909946396026, -1.5}, \
{-0.7697483574637453, -1.4373449933535234`}, {-0.642337217350629, -1.5}}], 
      PolygonBox[{{-0.7697483574637453, -1.4373449933535234`}, \
{-0.5950572556670028, -1.4049427443329972`}, {-0.642337217350629, -1.5}, \
{-0.7697483574637453, -1.4373449933535234`}}], 
      PolygonBox[{{-0.5, -1.5}, {-0.642337217350629, -1.5}, \
{-0.5950572556670028, -1.4049427443329972`}, {-0.5, -1.5}}], 
      PolygonBox[{{-0.5950572556670028, -1.4049427443329972`}, \
{-0.5950572556670028, -1.4049427443329972`}, {-0.5, -1.5}, \
{-0.5950572556670028, -1.4049427443329972`}}], 
      PolygonBox[{{-0.5, -1.5}, {-0.5, -1.5}, {-0.5950572556670028, \
-1.4049427443329972`}, {-0.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, 0.}, {-1.4791666666666667`, 0.}, {-1.4583333333333333`, 
       0.}, {-1.4375, 0.}, {-1.4166666666666667`, 0.}, {-1.3958333333333335`, 
       0.}, {-1.375, 0.}, {-1.375, 0.}, {-1.3958333333333333`, 
       0.}, {-1.4166666666666667`, 0.}, {-1.4375, 0.}, {-1.4583333333333333`, 
       0.}, {-1.4791666666666665`, 0.}, {-1.5, 0.}, {-1.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, 0.}, {-0.6041666666666667, 0.}, {-0.5833333333333333, 
       0.}, {-0.5625, 0.}, {-0.5416666666666667, 0.}, {-0.5208333333333334, 
       0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5208333333333333, 
       0.}, {-0.5416666666666667, 0.}, {-0.5625, 0.}, {-0.5833333333333333, 
       0.}, {-0.6041666666666666, 0.}, {-0.625, 0.}, {-0.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -0.5}, {-1., -0.4791666666666667}, {-1., \
-0.4583333333333333}, {-1., -0.4375}, {-1., -0.4166666666666667}, {-1., \
-0.39583333333333337`}, {-1., -0.375}, {-1., -0.375}, {-1., \
-0.3958333333333333}, {-1., -0.4166666666666667}, {-1., -0.4375}, {-1., \
-0.4583333333333333}, {-1., -0.47916666666666663`}, {-1., -0.5}, {-1., \
-0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 0.375}, {-1., 0.3958333333333333}, {-1., 
       0.4166666666666667}, {-1., 0.4375}, {-1., 0.4583333333333333}, {-1., 
       0.47916666666666663`}, {-1., 0.5}, {-1., 0.5}, {-1., 
       0.4791666666666667}, {-1., 0.4583333333333333}, {-1., 0.4375}, {-1., 
       0.4166666666666667}, {-1., 0.39583333333333337`}, {-1., 0.375}, {-1., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, 0.}, {-1.25, 0.}, {-1.125, 0.}, {-1., 0.}, {-0.875, 
       0.}, {-0.75, 0.}, {-0.625, 0.}, {-0.625, 0.}, {-0.75, 0.}, {-0.875, 
       0.}, {-1., 0.}, {-1.125, 0.}, {-1.25, 0.}, {-1.375, 0.}, {-1.375, 
       0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -0.375}, {-1., -0.25}, {-1., -0.125}, {-1., 0.}, {-1., 
       0.125}, {-1., 0.25}, {-1., 0.375}, {-1., 0.375}, {-1., 0.25}, {-1., 
       0.125}, {-1., 
       0.}, {-1., -0.125}, {-1., -0.25}, {-1., -0.375}, {-1., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9sNYETtcWNdmPNl/ozNm0Z4bO+wdHt97MXH2
0/3/weC4/WTPCTOPND/ffzPn/pmyHxfsIbpe7W+wdNK7c+KK/ZG8LdkvnrzZ
799f9nWp3nWo/Aeo+Tfs555QPdXd+3F/AIr8Z7h+s9vmm2Xtvuy/BTU/oW8C
t7nR1/0sYHUn7K8sjq1defrr/gdQ90H0f9vP1TXPx7KyywYmfw4ivx+m/w/E
/fvNoeZfh5i/nxFqfx3E/v3zoe7zg7hvP5r79x+D+g/q/v1MUP83QfVPgYYP
1P37HaHhxwZx//5IaPi+g7oPFv4Q98/aAwCN78Zp
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNp+1AweArnrwKDV3A+hP6AJv8JTf9XNPU/
CPLDwPquovGPoqmHgR/7QyDy+1H5V/ejqn+AwQ9Ddd/+1aju34/mP6j8KzT9
T9HUE6bDUNwH4x9FUwcDD2D+s0flX7VHM9ceAME4e3w=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, -0.2651650429449553}, \
{-0.6752404735808355, -0.1875}, {-0.5950572556670028, -0.4049427443329971}, \
{-0.7348349570550446, -0.2651650429449553}}], 
      PolygonBox[{{-0.5626550066464766, -0.23025164253625516`}, \
{-0.5950572556670028, -0.4049427443329971}, {-0.6752404735808355, -0.1875}, \
{-0.5626550066464766, -0.23025164253625516`}}], 
      PolygonBox[{{-0.6752404735808355, -0.1875}, {-0.6377778151415994, \
-0.0970571419134453}, {-0.5626550066464766, -0.23025164253625516`}, \
{-0.6752404735808355, -0.1875}}], 
      PolygonBox[{{-0.5625000189670593, -0.08429258955606181}, \
{-0.5626550066464766, -0.23025164253625516`}, {-0.6377778151415994, \
-0.0970571419134453}, {-0.5625000189670593, -0.08429258955606181}}], 
      PolygonBox[{{-0.6377778151415994, -0.0970571419134453}, {-0.625, 
       0.}, {-0.5625000189670593, -0.08429258955606181}, \
{-0.6377778151415994, -0.0970571419134453}}], 
      PolygonBox[{{-0.5625, 
       0.}, {-0.5625000189670593, -0.08429258955606181}, {-0.625, 
       0.}, {-0.5625, 0.}}], 
      PolygonBox[{{-0.625, 0.}, {-0.6377778151415994, 
       0.09705714191344525}, {-0.5625, 0.}, {-0.625, 0.}}], 
      PolygonBox[{{-0.5625000189670593, 0.08429258955606177}, {-0.5625, 
       0.}, {-0.6377778151415994, 0.09705714191344525}, {-0.5625000189670593, 
       0.08429258955606177}}], 
      PolygonBox[{{-0.6377778151415994, 
       0.09705714191344525}, {-0.6752404735808355, 
       0.18749999999999994`}, {-0.5625000189670593, 
       0.08429258955606177}, {-0.6377778151415994, 0.09705714191344525}}], 
      PolygonBox[{{-0.5626550066464766, 
       0.23025164253625502`}, {-0.5625000189670593, 
       0.08429258955606177}, {-0.6752404735808355, 
       0.18749999999999994`}, {-0.5626550066464766, 0.23025164253625502`}}], 
      PolygonBox[{{-0.6752404735808355, 
       0.18749999999999994`}, {-0.7348349570550446, 
       0.2651650429449553}, {-0.5626550066464766, 
       0.23025164253625502`}, {-0.6752404735808355, 0.18749999999999994`}}], 
      PolygonBox[{{-0.5950572556670028, 
       0.40494274433299715`}, {-0.5626550066464766, 
       0.23025164253625502`}, {-0.7348349570550446, 
       0.2651650429449553}, {-0.5950572556670028, 0.40494274433299715`}}], 
      PolygonBox[{{-0.7348349570550446, 0.2651650429449553}, {-0.8125, 
       0.3247595264191645}, {-0.5950572556670028, 
       0.40494274433299715`}, {-0.7348349570550446, 0.2651650429449553}}], 
      PolygonBox[{{-0.7697483574637448, 
       0.4373449933535234}, {-0.5950572556670028, 
       0.40494274433299715`}, {-0.8125, 
       0.3247595264191645}, {-0.7697483574637448, 0.4373449933535234}}], 
      PolygonBox[{{-0.8125, 0.3247595264191645}, {-0.9029428580865546, 
       0.3622221848584006}, {-0.7697483574637448, 
       0.4373449933535234}, {-0.8125, 0.3247595264191645}}], 
      PolygonBox[{{-0.9157074104439394, 
       0.4374999810329408}, {-0.7697483574637448, 
       0.4373449933535234}, {-0.9029428580865546, 
       0.3622221848584006}, {-0.9157074104439394, 0.4374999810329408}}], 
      PolygonBox[{{-0.9029428580865546, 0.3622221848584006}, {-1., 
       0.375}, {-0.9157074104439394, 
       0.4374999810329408}, {-0.9029428580865546, 0.3622221848584006}}], 
      PolygonBox[{{-0.9998944727795123, 0.4375}, {-0.9157074104439394, 
       0.4374999810329408}, {-1., 0.375}, {-0.9998944727795123, 0.4375}}], 
      PolygonBox[{{-1., 0.375}, {-1.0970571419134452`, 
       0.36222218485840063`}, {-0.9998944727795123, 0.4375}, {-1., 0.375}}], 
      PolygonBox[{{-1.084292589556057, 
       0.4374999810329408}, {-0.9998944727795123, 
       0.4375}, {-1.0970571419134452`, 
       0.36222218485840063`}, {-1.084292589556057, 0.4374999810329408}}], 
      PolygonBox[{{-1.0970571419134452`, 0.36222218485840063`}, {-1.1875, 
       0.3247595264191645}, {-1.084292589556057, 
       0.4374999810329408}, {-1.0970571419134452`, 0.36222218485840063`}}], 
      PolygonBox[{{-1.230251642536255, 
       0.4373449933535234}, {-1.084292589556057, 
       0.4374999810329408}, {-1.1875, 
       0.3247595264191645}, {-1.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{-1.1875, 0.3247595264191645}, {-1.2651650429449552`, 
       0.26516504294495535`}, {-1.230251642536255, 
       0.4373449933535234}, {-1.1875, 0.3247595264191645}}], 
      PolygonBox[{{-1.4049427443329972`, 
       0.40494274433299715`}, {-1.230251642536255, 
       0.4373449933535234}, {-1.2651650429449552`, 
       0.26516504294495535`}, {-1.4049427443329972`, 0.40494274433299715`}}], 
      PolygonBox[{{-1.2651650429449552`, 
       0.26516504294495535`}, {-1.3247595264191645`, 
       0.1875000000000001}, {-1.4049427443329972`, 
       0.40494274433299715`}, {-1.2651650429449552`, 0.26516504294495535`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       0.2302516425362554}, {-1.4049427443329972`, 
       0.40494274433299715`}, {-1.3247595264191645`, 
       0.1875000000000001}, {-1.4373449933535234`, 0.2302516425362554}}], 
      PolygonBox[{{-1.3247595264191645`, 
       0.1875000000000001}, {-1.3622221848584006`, 
       0.09705714191344539}, {-1.4373449933535234`, 
       0.2302516425362554}, {-1.3247595264191645`, 0.1875000000000001}}], 
      PolygonBox[{{-1.4374999810329407`, 
       0.08429258955606238}, {-1.4373449933535234`, 
       0.2302516425362554}, {-1.3622221848584006`, 
       0.09705714191344539}, {-1.4374999810329407`, 0.08429258955606238}}], 
      PolygonBox[{{-1.3622221848584006`, 0.09705714191344539}, {-1.375, 
       2.1245770866179924`*^-16}, {-1.4374999810329407`, 
       0.08429258955606238}, {-1.3622221848584006`, 0.09705714191344539}}], 
      PolygonBox[{{-1.4375, 0.00012317806299537147`}, {-1.4374999810329407`, 
       0.08429258955606238}, {-1.375, 2.1245770866179924`*^-16}, {-1.4375, 
       0.00012317806299537147`}}], 
      PolygonBox[{{-1.375, 
       2.1245770866179924`*^-16}, {-1.3622221848584006`, \
-0.09705714191344514}, {-1.4375, 0.00012317806299537147`}, {-1.375, 
       2.1245770866179924`*^-16}}], 
      PolygonBox[{{-1.4374999810329407`, -0.084292589556055}, {-1.4375, 
       0.00012317806299537147`}, {-1.3622221848584006`, \
-0.09705714191344514}, {-1.4374999810329407`, -0.084292589556055}}], 
      PolygonBox[{{-1.3622221848584006`, -0.09705714191344514}, \
{-1.3247595264191645`, -0.18749999999999978`}, {-1.4374999810329407`, \
-0.084292589556055}, {-1.3622221848584006`, -0.09705714191344514}}], 
      PolygonBox[{{-1.4373449933535234`, -0.23025164253625477`}, \
{-1.4374999810329407`, -0.084292589556055}, {-1.3247595264191645`, \
-0.18749999999999978`}, {-1.4373449933535234`, -0.23025164253625477`}}], 
      PolygonBox[{{-1.3247595264191645`, -0.18749999999999978`}, \
{-1.2651650429449552`, -0.2651650429449553}, {-1.4373449933535234`, \
-0.23025164253625477`}, {-1.3247595264191645`, -0.18749999999999978`}}], 
      PolygonBox[{{-1.4049427443329972`, -0.4049427443329971}, \
{-1.4373449933535234`, -0.23025164253625477`}, {-1.2651650429449552`, \
-0.2651650429449553}, {-1.4049427443329972`, -0.4049427443329971}}], 
      PolygonBox[{{-1.2651650429449552`, -0.2651650429449553}, \
{-1.1875000000000002`, -0.3247595264191644}, {-1.4049427443329972`, \
-0.4049427443329971}, {-1.2651650429449552`, -0.2651650429449553}}], 
      PolygonBox[{{-1.230251642536255, -0.4373449933535234}, \
{-1.4049427443329972`, -0.4049427443329971}, {-1.1875000000000002`, \
-0.3247595264191644}, {-1.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{-1.1875000000000002`, -0.3247595264191644}, \
{-1.0970571419134456`, -0.3622221848584005}, {-1.230251642536255, \
-0.4373449933535234}, {-1.1875000000000002`, -0.3247595264191644}}], 
      PolygonBox[{{-1.0842925895560642`, -0.4374999810329408}, \
{-1.230251642536255, -0.4373449933535234}, {-1.0970571419134456`, \
-0.3622221848584005}, {-1.0842925895560642`, -0.4374999810329408}}], 
      PolygonBox[{{-1.0970571419134456`, -0.3622221848584005}, \
{-0.9999999999999999, -0.375}, {-1.0842925895560642`, -0.4374999810329408}, \
{-1.0970571419134456`, -0.3622221848584005}}], 
      PolygonBox[{{-0.999865158168957, -0.4375}, {-1.0842925895560642`, \
-0.4374999810329408}, {-0.9999999999999999, -0.375}, {-0.999865158168957, \
-0.4375}}], 
      PolygonBox[{{-0.9999999999999999, -0.375}, {-0.9029428580865548, \
-0.36222218485840063`}, {-0.999865158168957, -0.4375}, {-0.9999999999999999, \
-0.375}}], 
      PolygonBox[{{-0.9157074104439469, -0.4374999810329408}, \
{-0.999865158168957, -0.4375}, {-0.9029428580865548, -0.36222218485840063`}, \
{-0.9157074104439469, -0.4374999810329408}}], 
      PolygonBox[{{-0.9029428580865548, -0.36222218485840063`}, \
{-0.8125000000000002, -0.3247595264191646}, {-0.9157074104439469, \
-0.4374999810329408}, {-0.9029428580865548, -0.36222218485840063`}}], 
      PolygonBox[{{-0.7697483574637453, -0.4373449933535234}, \
{-0.9157074104439469, -0.4374999810329408}, {-0.8125000000000002, \
-0.3247595264191646}, {-0.7697483574637453, -0.4373449933535234}}], 
      PolygonBox[{{-0.8125000000000002, -0.3247595264191646}, \
{-0.7348349570550448, -0.26516504294495535`}, {-0.7697483574637453, \
-0.4373449933535234}, {-0.8125000000000002, -0.3247595264191646}}], 
      PolygonBox[{{-0.5950572556670028, -0.40494274433299715`}, \
{-0.7697483574637453, -0.4373449933535234}, {-0.7348349570550448, \
-0.26516504294495535`}, {-0.5950572556670028, -0.40494274433299715`}}], 
      PolygonBox[{{-0.7348349570550448, -0.26516504294495535`}, \
{-0.7348349570550446, -0.2651650429449553}, {-0.5950572556670028, \
-0.40494274433299715`}, {-0.7348349570550448, -0.26516504294495535`}}], 
      PolygonBox[{{-0.5950572556670028, -0.4049427443329971}, \
{-0.5950572556670028, -0.40494274433299715`}, {-0.7348349570550446, \
-0.2651650429449553}, {-0.5950572556670028, -0.4049427443329971}}], 
      PolygonBox[{{-0.5950572556670028, -0.4049427443329971}, \
{-0.5626550066464766, -0.23025164253625516`}, {-0.5, -0.5}, \
{-0.5950572556670028, -0.4049427443329971}}], 
      PolygonBox[{{-0.5, -0.3576627826493677}, {-0.5, -0.5}, \
{-0.5626550066464766, -0.23025164253625516`}, {-0.5, -0.3576627826493677}}], 
      PolygonBox[{{-0.5626550066464766, -0.23025164253625516`}, \
{-0.5625000189670593, -0.08429258955606181}, {-0.5, -0.3576627826493677}, \
{-0.5626550066464766, -0.23025164253625516`}}], 
      PolygonBox[{{-0.5, -0.20590900530173997`}, {-0.5, -0.3576627826493677}, \
{-0.5625000189670593, -0.08429258955606181}, {-0.5, -0.20590900530173997`}}], 
      PolygonBox[{{-0.5625000189670593, -0.08429258955606181}, {-0.5625, 
       0.}, {-0.5, -0.20590900530173997`}, {-0.5625000189670593, \
-0.08429258955606181}}], 
      PolygonBox[{{-0.5, 0.}, {-0.5, -0.20590900530173997`}, {-0.5625, 
       0.}, {-0.5, 0.}}], 
      PolygonBox[{{-0.5625, 0.}, {-0.5625000189670593, 
       0.08429258955606177}, {-0.5, 0.}, {-0.5625, 0.}}], 
      PolygonBox[{{-0.5, 0.20590900530173992`}, {-0.5, 
       0.}, {-0.5625000189670593, 0.08429258955606177}, {-0.5, 
       0.20590900530173992`}}], 
      PolygonBox[{{-0.5625000189670593, 
       0.08429258955606177}, {-0.5626550066464766, 
       0.23025164253625502`}, {-0.5, 
       0.20590900530173992`}, {-0.5625000189670593, 0.08429258955606177}}], 
      PolygonBox[{{-0.5, 0.35766278264936757`}, {-0.5, 
       0.20590900530173992`}, {-0.5626550066464766, 
       0.23025164253625502`}, {-0.5, 0.35766278264936757`}}], 
      PolygonBox[{{-0.5626550066464766, 
       0.23025164253625502`}, {-0.5950572556670028, 
       0.40494274433299715`}, {-0.5, 
       0.35766278264936757`}, {-0.5626550066464766, 0.23025164253625502`}}], 
      PolygonBox[{{-0.508553435038814, 0.491446564961186}, {-0.5, 
       0.35766278264936757`}, {-0.5950572556670028, 
       0.40494274433299715`}, {-0.508553435038814, 0.491446564961186}}], 
      PolygonBox[{{-0.5950572556670028, 
       0.40494274433299715`}, {-0.7697483574637448, 
       0.4373449933535234}, {-0.508553435038814, 
       0.491446564961186}, {-0.5950572556670028, 0.40494274433299715`}}], 
      PolygonBox[{{-0.6423372173506319, 0.5}, {-0.508553435038814, 
       0.491446564961186}, {-0.7697483574637448, 
       0.4373449933535234}, {-0.6423372173506319, 0.5}}], 
      PolygonBox[{{-0.7697483574637448, 
       0.4373449933535234}, {-0.9157074104439394, 
       0.4374999810329408}, {-0.6423372173506319, 0.5}, {-0.7697483574637448, 
       0.4373449933535234}}], 
      PolygonBox[{{-0.7940909946267442, 0.5}, {-0.6423372173506319, 
       0.5}, {-0.9157074104439394, 0.4374999810329408}, {-0.7940909946267442, 
       0.5}}], PolygonBox[{{-0.9157074104439394, 
       0.4374999810329408}, {-0.9998944727795123, 
       0.4375}, {-0.7940909946267442, 0.5}, {-0.9157074104439394, 
       0.4374999810329408}}], 
      PolygonBox[{{-0.9220580419731099, 0.5}, {-0.7940909946267442, 
       0.5}, {-0.9998944727795123, 0.4375}, {-0.9220580419731099, 0.5}}], 
      PolygonBox[{{-0.9998944727795123, 0.4375}, {-1.084292589556057, 
       0.4374999810329408}, {-0.9220580419731099, 0.5}, {-0.9998944727795123, 
       0.4375}}], 
      PolygonBox[{{-1.2059090053044457`, 0.5}, {-0.9220580419731099, 
       0.5}, {-1.084292589556057, 0.4374999810329408}, {-1.2059090053044457`, 
       0.5}}], PolygonBox[{{-1.084292589556057, 
       0.4374999810329408}, {-1.230251642536255, 
       0.4373449933535234}, {-1.2059090053044457`, 0.5}, {-1.084292589556057, 
       0.4374999810329408}}], 
      PolygonBox[{{-1.3576627826493661`, 0.5}, {-1.2059090053044457`, 
       0.5}, {-1.230251642536255, 0.4373449933535234}, {-1.3576627826493661`, 
       0.5}}], PolygonBox[{{-1.230251642536255, 
       0.4373449933535234}, {-1.4049427443329972`, 
       0.40494274433299715`}, {-1.3576627826493661`, 
       0.5}, {-1.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{-0.5, 0.5}, {-1.3576627826493661`, 
       0.5}, {-1.4049427443329972`, 0.40494274433299715`}, {-0.5, 0.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       0.40494274433299715`}, {-1.4373449933535234`, 
       0.2302516425362554}, {-0.5, 0.5}, {-1.4049427443329972`, 
       0.40494274433299715`}}], 
      PolygonBox[{{-1.5, 0.357662782649369}, {-0.5, 
       0.5}, {-1.4373449933535234`, 0.2302516425362554}, {-1.5, 
       0.357662782649369}}], 
      PolygonBox[{{-1.4373449933535234`, 
       0.2302516425362554}, {-1.4374999810329407`, 
       0.08429258955606238}, {-1.5, 0.357662782649369}, {-1.4373449933535234`,
        0.2302516425362554}}], 
      PolygonBox[{{-1.5, 0.20590900528289896`}, {-1.5, 
       0.357662782649369}, {-1.4374999810329407`, 0.08429258955606238}, {-1.5,
        0.20590900528289896`}}], 
      PolygonBox[{{-1.4374999810329407`, 0.08429258955606238}, {-1.4375, 
       0.00012317806299537147`}, {-1.5, 
       0.20590900528289896`}, {-1.4374999810329407`, 0.08429258955606238}}], 
      PolygonBox[{{-1.5, 0.08067866675870025}, {-1.5, 
       0.20590900528289896`}, {-1.4375, 0.00012317806299537147`}, {-1.5, 
       0.08067866675870025}}], 
      PolygonBox[{{-1.4375, 
       0.00012317806299537147`}, {-1.4374999810329407`, -0.084292589556055}, \
{-1.5, 0.08067866675870025}, {-1.4375, 0.00012317806299537147`}}], 
      PolygonBox[{{-1.5, -0.20590900514527852`}, {-1.5, 
       0.08067866675870025}, {-1.4374999810329407`, -0.084292589556055}, \
{-1.5, -0.20590900514527852`}}], 
      PolygonBox[{{-1.4374999810329407`, -0.084292589556055}, \
{-1.4373449933535234`, -0.23025164253625477`}, {-1.5, -0.20590900514527852`}, \
{-1.4374999810329407`, -0.084292589556055}}], 
      PolygonBox[{{-1.5, -0.35766278264936535`}, {-1.5, \
-0.20590900514527852`}, {-1.4373449933535234`, -0.23025164253625477`}, {-1.5, \
-0.35766278264936535`}}], 
      PolygonBox[{{-1.4373449933535234`, -0.23025164253625477`}, \
{-1.4049427443329972`, -0.4049427443329971}, {-1.5, -0.35766278264936535`}, \
{-1.4373449933535234`, -0.23025164253625477`}}], 
      PolygonBox[{{-1.5, 
       0.5}, {-1.5, -0.35766278264936535`}, {-1.4049427443329972`, \
-0.4049427443329971}, {-1.5, 0.5}}], 
      PolygonBox[{{-1.4049427443329972`, -0.4049427443329971}, \
{-1.230251642536255, -0.4373449933535234}, {-1.5, 
       0.5}, {-1.4049427443329972`, -0.4049427443329971}}], 
      PolygonBox[{{-1.5, -0.5}, {-1.5, 
       0.5}, {-1.230251642536255, -0.4373449933535234}, {-1.5, -0.5}}], 
      PolygonBox[{{-1.230251642536255, -0.4373449933535234}, \
{-1.0842925895560642`, -0.4374999810329408}, {-1.5, -0.5}, \
{-1.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{-1.205909005566828, -0.5}, {-1.5, -0.5}, \
{-1.0842925895560642`, -0.4374999810329408}, {-1.205909005566828, -0.5}}], 
      PolygonBox[{{-1.0842925895560642`, -0.4374999810329408}, \
{-0.999865158168957, -0.4375}, {-1.205909005566828, -0.5}, \
{-1.0842925895560642`, -0.4374999810329408}}], 
      PolygonBox[{{-0.9176761295989384, -0.5}, {-1.205909005566828, -0.5}, \
{-0.999865158168957, -0.4375}, {-0.9176761295989384, -0.5}}], 
      PolygonBox[{{-0.999865158168957, -0.4375}, {-0.9157074104439469, \
-0.4374999810329408}, {-0.9176761295989384, -0.5}, {-0.999865158168957, \
-0.4375}}], 
      PolygonBox[{{-0.7940909946396026, -0.5}, {-0.9176761295989384, -0.5}, \
{-0.9157074104439469, -0.4374999810329408}, {-0.7940909946396026, -0.5}}], 
      PolygonBox[{{-0.9157074104439469, -0.4374999810329408}, \
{-0.7697483574637453, -0.4373449933535234}, {-0.7940909946396026, -0.5}, \
{-0.9157074104439469, -0.4374999810329408}}], 
      PolygonBox[{{-0.642337217350629, -0.5}, {-0.7940909946396026, -0.5}, \
{-0.7697483574637453, -0.4373449933535234}, {-0.642337217350629, -0.5}}], 
      PolygonBox[{{-0.7697483574637453, -0.4373449933535234}, \
{-0.5950572556670028, -0.40494274433299715`}, {-0.642337217350629, -0.5}, \
{-0.7697483574637453, -0.4373449933535234}}], 
      PolygonBox[{{-0.5, -0.5}, {-0.642337217350629, -0.5}, \
{-0.5950572556670028, -0.40494274433299715`}, {-0.5, -0.5}}], 
      PolygonBox[{{-0.5950572556670028, -0.40494274433299715`}, \
{-0.5950572556670028, -0.4049427443329971}, {-0.5, -0.5}, \
{-0.5950572556670028, -0.40494274433299715`}}], 
      PolygonBox[{{-0.5, -0.5}, {-0.5, -0.5}, {-0.5950572556670028, \
-0.4049427443329971}, {-0.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, 1.}, {-1.4791666666666667`, 1.}, {-1.4583333333333333`, 
       1.}, {-1.4375, 1.}, {-1.4166666666666667`, 1.}, {-1.3958333333333335`, 
       1.}, {-1.375, 1.}, {-1.375, 1.}, {-1.3958333333333333`, 
       1.}, {-1.4166666666666667`, 1.}, {-1.4375, 1.}, {-1.4583333333333333`, 
       1.}, {-1.4791666666666665`, 1.}, {-1.5, 1.}, {-1.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, 1.}, {-0.6041666666666667, 1.}, {-0.5833333333333333, 
       1.}, {-0.5625, 1.}, {-0.5416666666666667, 1.}, {-0.5208333333333334, 
       1.}, {-0.5, 1.}, {-0.5, 1.}, {-0.5208333333333333, 
       1.}, {-0.5416666666666667, 1.}, {-0.5625, 1.}, {-0.5833333333333333, 
       1.}, {-0.6041666666666666, 1.}, {-0.625, 1.}, {-0.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 0.5}, {-1., 0.5208333333333333}, {-1., 
       0.5416666666666667}, {-1., 0.5625}, {-1., 0.5833333333333333}, {-1., 
       0.6041666666666666}, {-1., 0.625}, {-1., 0.625}, {-1., 
       0.6041666666666667}, {-1., 0.5833333333333333}, {-1., 0.5625}, {-1., 
       0.5416666666666667}, {-1., 0.5208333333333334}, {-1., 0.5}, {-1., 
       0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 1.375}, {-1., 1.3958333333333333`}, {-1., 
       1.4166666666666667`}, {-1., 1.4375}, {-1., 1.4583333333333333`}, {-1., 
       1.4791666666666665`}, {-1., 1.5}, {-1., 1.5}, {-1., 
       1.4791666666666667`}, {-1., 1.4583333333333333`}, {-1., 1.4375}, {-1., 
       1.4166666666666667`}, {-1., 1.3958333333333335`}, {-1., 1.375}, {-1., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, 1.}, {-1.25, 1.}, {-1.125, 1.}, {-1., 1.}, {-0.875, 
       1.}, {-0.75, 1.}, {-0.625, 1.}, {-0.625, 1.}, {-0.75, 1.}, {-0.875, 
       1.}, {-1., 1.}, {-1.125, 1.}, {-1.25, 1.}, {-1.375, 1.}, {-1.375, 
       1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 0.625}, {-1., 0.75}, {-1., 0.875}, {-1., 1.}, {-1., 
       1.125}, {-1., 1.25}, {-1., 1.375}, {-1., 1.375}, {-1., 1.25}, {-1., 
       1.125}, {-1., 1.}, {-1., 0.875}, {-1., 0.75}, {-1., 0.625}, {-1., 
       0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kPoD/YRO1xY12Y82T/vhOqp7t6P9g6P772Y
OPspVP6z/WTPCTOPND/fb3bbfLOs3Rd7iPir/Ql9E7jNjb7aH8nbkv3iyZv9
VxbH1q48/RUq/wGq/5v9XIi5aPKf4fqh5sLNh4rD7Yfqg7sPai7c/TD5YxB3
wPUzQtxpbw41fwrEH/aMUPsdIf60nw91XyQkHNDc/8Qeau5+aDjZM0H9bw/V
DzV3PzSc7KHm7v/3HwRe2kPN3X8I6j5Y+IOl/7+3BwByT7qS
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kPoH/ahYPAUzl8FBq/gfAj9AU3+E5r+r2jq
fxDkh0H0wfmrIeaiqf+AJv8KTf9TNPUPMPhhKO57YL8axf0P0PwHk3+Fpv8p
mvoHBPmhKO57sH8VivsfoPkPJv8JTf9XNPU/7AEUrYEy
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, 
       0.7348349570550448}, {-0.6752404735808355, 
       0.8125}, {-0.5950572556670028, 
       0.5950572556670028}, {-0.7348349570550446, 0.7348349570550448}}], 
      PolygonBox[{{-0.5626550066464766, 
       0.7697483574637448}, {-0.5950572556670028, 
       0.5950572556670028}, {-0.6752404735808355, 
       0.8125}, {-0.5626550066464766, 0.7697483574637448}}], 
      PolygonBox[{{-0.6752404735808355, 0.8125}, {-0.6377778151415994, 
       0.9029428580865547}, {-0.5626550066464766, 
       0.7697483574637448}, {-0.6752404735808355, 0.8125}}], 
      PolygonBox[{{-0.5625000189670593, 
       0.9157074104439382}, {-0.5626550066464766, 
       0.7697483574637448}, {-0.6377778151415994, 
       0.9029428580865547}, {-0.5625000189670593, 0.9157074104439382}}], 
      PolygonBox[{{-0.6377778151415994, 0.9029428580865547}, {-0.625, 
       1.}, {-0.5625000189670593, 0.9157074104439382}, {-0.6377778151415994, 
       0.9029428580865547}}], 
      PolygonBox[{{-0.5625, 1.}, {-0.5625000189670593, 
       0.9157074104439382}, {-0.625, 1.}, {-0.5625, 1.}}], 
      PolygonBox[{{-0.625, 1.}, {-0.6377778151415994, 
       1.0970571419134452`}, {-0.5625, 1.}, {-0.625, 1.}}], 
      PolygonBox[{{-0.5625000189670593, 1.0842925895560618`}, {-0.5625, 
       1.}, {-0.6377778151415994, 1.0970571419134452`}, {-0.5625000189670593, 
       1.0842925895560618`}}], 
      PolygonBox[{{-0.6377778151415994, 
       1.0970571419134452`}, {-0.6752404735808355, 
       1.1875}, {-0.5625000189670593, 
       1.0842925895560618`}, {-0.6377778151415994, 1.0970571419134452`}}], 
      PolygonBox[{{-0.5626550066464766, 
       1.230251642536255}, {-0.5625000189670593, 
       1.0842925895560618`}, {-0.6752404735808355, 
       1.1875}, {-0.5626550066464766, 1.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, 1.1875}, {-0.7348349570550446, 
       1.2651650429449552`}, {-0.5626550066464766, 
       1.230251642536255}, {-0.6752404735808355, 1.1875}}], 
      PolygonBox[{{-0.5950572556670028, 
       1.4049427443329972`}, {-0.5626550066464766, 
       1.230251642536255}, {-0.7348349570550446, 
       1.2651650429449552`}, {-0.5950572556670028, 1.4049427443329972`}}], 
      PolygonBox[{{-0.7348349570550446, 1.2651650429449552`}, {-0.8125, 
       1.3247595264191645`}, {-0.5950572556670028, 
       1.4049427443329972`}, {-0.7348349570550446, 1.2651650429449552`}}], 
      PolygonBox[{{-0.7697483574637448, 
       1.4373449933535234`}, {-0.5950572556670028, 
       1.4049427443329972`}, {-0.8125, 
       1.3247595264191645`}, {-0.7697483574637448, 1.4373449933535234`}}], 
      PolygonBox[{{-0.8125, 1.3247595264191645`}, {-0.9029428580865546, 
       1.3622221848584006`}, {-0.7697483574637448, 
       1.4373449933535234`}, {-0.8125, 1.3247595264191645`}}], 
      PolygonBox[{{-0.9157074104439394, 
       1.4374999810329407`}, {-0.7697483574637448, 
       1.4373449933535234`}, {-0.9029428580865546, 
       1.3622221848584006`}, {-0.9157074104439394, 1.4374999810329407`}}], 
      PolygonBox[{{-0.9029428580865546, 1.3622221848584006`}, {-1., 
       1.375}, {-0.9157074104439394, 
       1.4374999810329407`}, {-0.9029428580865546, 1.3622221848584006`}}], 
      PolygonBox[{{-0.9998944727795123, 1.4375}, {-0.9157074104439394, 
       1.4374999810329407`}, {-1., 1.375}, {-0.9998944727795123, 1.4375}}], 
      PolygonBox[{{-1., 1.375}, {-1.0970571419134452`, 
       1.3622221848584006`}, {-0.9998944727795123, 1.4375}, {-1., 1.375}}], 
      PolygonBox[{{-1.084292589556057, 
       1.4374999810329407`}, {-0.9998944727795123, 
       1.4375}, {-1.0970571419134452`, 
       1.3622221848584006`}, {-1.084292589556057, 1.4374999810329407`}}], 
      PolygonBox[{{-1.0970571419134452`, 1.3622221848584006`}, {-1.1875, 
       1.3247595264191645`}, {-1.084292589556057, 
       1.4374999810329407`}, {-1.0970571419134452`, 1.3622221848584006`}}], 
      PolygonBox[{{-1.230251642536255, 
       1.4373449933535234`}, {-1.084292589556057, 
       1.4374999810329407`}, {-1.1875, 
       1.3247595264191645`}, {-1.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{-1.1875, 1.3247595264191645`}, {-1.2651650429449552`, 
       1.2651650429449552`}, {-1.230251642536255, 
       1.4373449933535234`}, {-1.1875, 1.3247595264191645`}}], 
      PolygonBox[{{-1.4049427443329972`, 
       1.4049427443329972`}, {-1.230251642536255, 
       1.4373449933535234`}, {-1.2651650429449552`, 
       1.2651650429449552`}, {-1.4049427443329972`, 1.4049427443329972`}}], 
      PolygonBox[{{-1.2651650429449552`, 
       1.2651650429449552`}, {-1.3247595264191645`, 
       1.1875}, {-1.4049427443329972`, 
       1.4049427443329972`}, {-1.2651650429449552`, 1.2651650429449552`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       1.2302516425362553`}, {-1.4049427443329972`, 
       1.4049427443329972`}, {-1.3247595264191645`, 
       1.1875}, {-1.4373449933535234`, 1.2302516425362553`}}], 
      PolygonBox[{{-1.3247595264191645`, 1.1875}, {-1.3622221848584006`, 
       1.0970571419134454`}, {-1.4373449933535234`, 
       1.2302516425362553`}, {-1.3247595264191645`, 1.1875}}], 
      PolygonBox[{{-1.4374999810329407`, 
       1.0842925895560624`}, {-1.4373449933535234`, 
       1.2302516425362553`}, {-1.3622221848584006`, 
       1.0970571419134454`}, {-1.4374999810329407`, 1.0842925895560624`}}], 
      PolygonBox[{{-1.3622221848584006`, 1.0970571419134454`}, {-1.375, 
       1.0000000000000002`}, {-1.4374999810329407`, 
       1.0842925895560624`}, {-1.3622221848584006`, 1.0970571419134454`}}], 
      PolygonBox[{{-1.4375, 1.0001231780629953`}, {-1.4374999810329407`, 
       1.0842925895560624`}, {-1.375, 1.0000000000000002`}, {-1.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-1.375, 1.0000000000000002`}, {-1.3622221848584006`, 
       0.9029428580865548}, {-1.4375, 1.0001231780629953`}, {-1.375, 
       1.0000000000000002`}}], 
      PolygonBox[{{-1.4374999810329407`, 0.915707410443945}, {-1.4375, 
       1.0001231780629953`}, {-1.3622221848584006`, 
       0.9029428580865548}, {-1.4374999810329407`, 0.915707410443945}}], 
      PolygonBox[{{-1.3622221848584006`, 
       0.9029428580865548}, {-1.3247595264191645`, 
       0.8125000000000002}, {-1.4374999810329407`, 
       0.915707410443945}, {-1.3622221848584006`, 0.9029428580865548}}], 
      PolygonBox[{{-1.4373449933535234`, 
       0.7697483574637453}, {-1.4374999810329407`, 
       0.915707410443945}, {-1.3247595264191645`, 
       0.8125000000000002}, {-1.4373449933535234`, 0.7697483574637453}}], 
      PolygonBox[{{-1.3247595264191645`, 
       0.8125000000000002}, {-1.2651650429449552`, 
       0.7348349570550448}, {-1.4373449933535234`, 
       0.7697483574637453}, {-1.3247595264191645`, 0.8125000000000002}}], 
      PolygonBox[{{-1.4049427443329972`, 
       0.5950572556670028}, {-1.4373449933535234`, 
       0.7697483574637453}, {-1.2651650429449552`, 
       0.7348349570550448}, {-1.4049427443329972`, 0.5950572556670028}}], 
      PolygonBox[{{-1.2651650429449552`, 
       0.7348349570550448}, {-1.1875000000000002`, 
       0.6752404735808356}, {-1.4049427443329972`, 
       0.5950572556670028}, {-1.2651650429449552`, 0.7348349570550448}}], 
      PolygonBox[{{-1.230251642536255, 
       0.5626550066464766}, {-1.4049427443329972`, 
       0.5950572556670028}, {-1.1875000000000002`, 
       0.6752404735808356}, {-1.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-1.1875000000000002`, 
       0.6752404735808356}, {-1.0970571419134456`, 
       0.6377778151415995}, {-1.230251642536255, 
       0.5626550066464766}, {-1.1875000000000002`, 0.6752404735808356}}], 
      PolygonBox[{{-1.0842925895560642`, 
       0.5625000189670593}, {-1.230251642536255, 
       0.5626550066464766}, {-1.0970571419134456`, 
       0.6377778151415995}, {-1.0842925895560642`, 0.5625000189670593}}], 
      PolygonBox[{{-1.0970571419134456`, 
       0.6377778151415995}, {-0.9999999999999999, 
       0.625}, {-1.0842925895560642`, 
       0.5625000189670593}, {-1.0970571419134456`, 0.6377778151415995}}], 
      PolygonBox[{{-0.999865158168957, 0.5625}, {-1.0842925895560642`, 
       0.5625000189670593}, {-0.9999999999999999, 0.625}, {-0.999865158168957,
        0.5625}}], 
      PolygonBox[{{-0.9999999999999999, 0.625}, {-0.9029428580865548, 
       0.6377778151415994}, {-0.999865158168957, 
       0.5625}, {-0.9999999999999999, 0.625}}], 
      PolygonBox[{{-0.9157074104439469, 
       0.5625000189670593}, {-0.999865158168957, 
       0.5625}, {-0.9029428580865548, 
       0.6377778151415994}, {-0.9157074104439469, 0.5625000189670593}}], 
      PolygonBox[{{-0.9029428580865548, 
       0.6377778151415994}, {-0.8125000000000002, 
       0.6752404735808354}, {-0.9157074104439469, 
       0.5625000189670593}, {-0.9029428580865548, 0.6377778151415994}}], 
      PolygonBox[{{-0.7697483574637453, 
       0.5626550066464766}, {-0.9157074104439469, 
       0.5625000189670593}, {-0.8125000000000002, 
       0.6752404735808354}, {-0.7697483574637453, 0.5626550066464766}}], 
      PolygonBox[{{-0.8125000000000002, 
       0.6752404735808354}, {-0.7348349570550448, 
       0.7348349570550446}, {-0.7697483574637453, 
       0.5626550066464766}, {-0.8125000000000002, 0.6752404735808354}}], 
      PolygonBox[{{-0.5950572556670028, 
       0.5950572556670028}, {-0.7697483574637453, 
       0.5626550066464766}, {-0.7348349570550448, 
       0.7348349570550446}, {-0.5950572556670028, 0.5950572556670028}}], 
      PolygonBox[{{-0.7348349570550448, 
       0.7348349570550446}, {-0.7348349570550446, 
       0.7348349570550448}, {-0.5950572556670028, 
       0.5950572556670028}, {-0.7348349570550448, 0.7348349570550446}}], 
      PolygonBox[{{-0.5950572556670028, 
       0.5950572556670028}, {-0.5950572556670028, 
       0.5950572556670028}, {-0.7348349570550446, 
       0.7348349570550448}, {-0.5950572556670028, 0.5950572556670028}}], 
      PolygonBox[{{-0.5950572556670028, 
       0.5950572556670028}, {-0.5626550066464766, 0.7697483574637448}, {-0.5, 
       0.5}, {-0.5950572556670028, 0.5950572556670028}}], 
      PolygonBox[{{-0.5, 0.6423372173506323}, {-0.5, 
       0.5}, {-0.5626550066464766, 0.7697483574637448}, {-0.5, 
       0.6423372173506323}}], 
      PolygonBox[{{-0.5626550066464766, 
       0.7697483574637448}, {-0.5625000189670593, 0.9157074104439382}, {-0.5, 
       0.6423372173506323}, {-0.5626550066464766, 0.7697483574637448}}], 
      PolygonBox[{{-0.5, 0.79409099469826}, {-0.5, 
       0.6423372173506323}, {-0.5625000189670593, 0.9157074104439382}, {-0.5, 
       0.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, 0.9157074104439382}, {-0.5625, 
       1.}, {-0.5, 0.79409099469826}, {-0.5625000189670593, 
       0.9157074104439382}}], 
      PolygonBox[{{-0.5, 1.}, {-0.5, 0.79409099469826}, {-0.5625, 1.}, {-0.5, 
       1.}}], PolygonBox[{{-0.5625, 1.}, {-0.5625000189670593, 
       1.0842925895560618`}, {-0.5, 1.}, {-0.5625, 1.}}], 
      PolygonBox[{{-0.5, 1.2059090053017398`}, {-0.5, 
       1.}, {-0.5625000189670593, 1.0842925895560618`}, {-0.5, 
       1.2059090053017398`}}], 
      PolygonBox[{{-0.5625000189670593, 
       1.0842925895560618`}, {-0.5626550066464766, 1.230251642536255}, {-0.5, 
       1.2059090053017398`}, {-0.5625000189670593, 1.0842925895560618`}}], 
      PolygonBox[{{-0.5, 1.3576627826493675`}, {-0.5, 
       1.2059090053017398`}, {-0.5626550066464766, 1.230251642536255}, {-0.5, 
       1.3576627826493675`}}], 
      PolygonBox[{{-0.5626550066464766, 
       1.230251642536255}, {-0.5950572556670028, 1.4049427443329972`}, {-0.5, 
       1.3576627826493675`}, {-0.5626550066464766, 1.230251642536255}}], 
      PolygonBox[{{-0.508553435038814, 1.491446564961186}, {-0.5, 
       1.3576627826493675`}, {-0.5950572556670028, 
       1.4049427443329972`}, {-0.508553435038814, 1.491446564961186}}], 
      PolygonBox[{{-0.5950572556670028, 
       1.4049427443329972`}, {-0.7697483574637448, 
       1.4373449933535234`}, {-0.508553435038814, 
       1.491446564961186}, {-0.5950572556670028, 1.4049427443329972`}}], 
      PolygonBox[{{-0.6423372173506319, 1.5}, {-0.508553435038814, 
       1.491446564961186}, {-0.7697483574637448, 
       1.4373449933535234`}, {-0.6423372173506319, 1.5}}], 
      PolygonBox[{{-0.7697483574637448, 
       1.4373449933535234`}, {-0.9157074104439394, 
       1.4374999810329407`}, {-0.6423372173506319, 1.5}, {-0.7697483574637448,
        1.4373449933535234`}}], 
      PolygonBox[{{-0.7940909946267442, 1.5}, {-0.6423372173506319, 
       1.5}, {-0.9157074104439394, 1.4374999810329407`}, {-0.7940909946267442,
        1.5}}], 
      PolygonBox[{{-0.9157074104439394, 
       1.4374999810329407`}, {-0.9998944727795123, 
       1.4375}, {-0.7940909946267442, 1.5}, {-0.9157074104439394, 
       1.4374999810329407`}}], 
      PolygonBox[{{-0.9220580419731099, 1.5}, {-0.7940909946267442, 
       1.5}, {-0.9998944727795123, 1.4375}, {-0.9220580419731099, 1.5}}], 
      PolygonBox[{{-0.9998944727795123, 1.4375}, {-1.084292589556057, 
       1.4374999810329407`}, {-0.9220580419731099, 1.5}, {-0.9998944727795123,
        1.4375}}], 
      PolygonBox[{{-1.2059090053044457`, 1.5}, {-0.9220580419731099, 
       1.5}, {-1.084292589556057, 1.4374999810329407`}, {-1.2059090053044457`,
        1.5}}], 
      PolygonBox[{{-1.084292589556057, 
       1.4374999810329407`}, {-1.230251642536255, 
       1.4373449933535234`}, {-1.2059090053044457`, 1.5}, {-1.084292589556057,
        1.4374999810329407`}}], 
      PolygonBox[{{-1.3576627826493661`, 1.5}, {-1.2059090053044457`, 
       1.5}, {-1.230251642536255, 1.4373449933535234`}, {-1.3576627826493661`,
        1.5}}], 
      PolygonBox[{{-1.230251642536255, 
       1.4373449933535234`}, {-1.4049427443329972`, 
       1.4049427443329972`}, {-1.3576627826493661`, 1.5}, {-1.230251642536255,
        1.4373449933535234`}}], 
      PolygonBox[{{-0.5, 1.5}, {-1.3576627826493661`, 
       1.5}, {-1.4049427443329972`, 1.4049427443329972`}, {-0.5, 1.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       1.4049427443329972`}, {-1.4373449933535234`, 
       1.2302516425362553`}, {-0.5, 1.5}, {-1.4049427443329972`, 
       1.4049427443329972`}}], 
      PolygonBox[{{-1.5, 1.357662782649369}, {-0.5, 
       1.5}, {-1.4373449933535234`, 1.2302516425362553`}, {-1.5, 
       1.357662782649369}}], 
      PolygonBox[{{-1.4373449933535234`, 
       1.2302516425362553`}, {-1.4374999810329407`, 
       1.0842925895560624`}, {-1.5, 1.357662782649369}, {-1.4373449933535234`,
        1.2302516425362553`}}], 
      PolygonBox[{{-1.5, 1.205909005282899}, {-1.5, 
       1.357662782649369}, {-1.4374999810329407`, 1.0842925895560624`}, {-1.5,
        1.205909005282899}}], 
      PolygonBox[{{-1.4374999810329407`, 1.0842925895560624`}, {-1.4375, 
       1.0001231780629953`}, {-1.5, 1.205909005282899}, {-1.4374999810329407`,
        1.0842925895560624`}}], 
      PolygonBox[{{-1.5, 1.0806786667587003`}, {-1.5, 
       1.205909005282899}, {-1.4375, 1.0001231780629953`}, {-1.5, 
       1.0806786667587003`}}], 
      PolygonBox[{{-1.4375, 1.0001231780629953`}, {-1.4374999810329407`, 
       0.915707410443945}, {-1.5, 1.0806786667587003`}, {-1.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-1.5, 0.7940909948547215}, {-1.5, 
       1.0806786667587003`}, {-1.4374999810329407`, 0.915707410443945}, {-1.5,
        0.7940909948547215}}], 
      PolygonBox[{{-1.4374999810329407`, 
       0.915707410443945}, {-1.4373449933535234`, 0.7697483574637453}, {-1.5, 
       0.7940909948547215}, {-1.4374999810329407`, 0.915707410443945}}], 
      PolygonBox[{{-1.5, 0.6423372173506346}, {-1.5, 
       0.7940909948547215}, {-1.4373449933535234`, 0.7697483574637453}, {-1.5,
        0.6423372173506346}}], 
      PolygonBox[{{-1.4373449933535234`, 
       0.7697483574637453}, {-1.4049427443329972`, 0.5950572556670028}, {-1.5,
        0.6423372173506346}, {-1.4373449933535234`, 0.7697483574637453}}], 
      PolygonBox[{{-1.5, 1.5}, {-1.5, 
       0.6423372173506346}, {-1.4049427443329972`, 0.5950572556670028}, {-1.5,
        1.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       0.5950572556670028}, {-1.230251642536255, 0.5626550066464766}, {-1.5, 
       1.5}, {-1.4049427443329972`, 0.5950572556670028}}], 
      PolygonBox[{{-1.5, 0.5}, {-1.5, 1.5}, {-1.230251642536255, 
       0.5626550066464766}, {-1.5, 0.5}}], 
      PolygonBox[{{-1.230251642536255, 
       0.5626550066464766}, {-1.0842925895560642`, 0.5625000189670593}, {-1.5,
        0.5}, {-1.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{-1.205909005566828, 0.5}, {-1.5, 
       0.5}, {-1.0842925895560642`, 0.5625000189670593}, {-1.205909005566828, 
       0.5}}], PolygonBox[{{-1.0842925895560642`, 
       0.5625000189670593}, {-0.999865158168957, 0.5625}, {-1.205909005566828,
        0.5}, {-1.0842925895560642`, 0.5625000189670593}}], 
      PolygonBox[{{-0.9176761295989384, 0.5}, {-1.205909005566828, 
       0.5}, {-0.999865158168957, 0.5625}, {-0.9176761295989384, 0.5}}], 
      PolygonBox[{{-0.999865158168957, 0.5625}, {-0.9157074104439469, 
       0.5625000189670593}, {-0.9176761295989384, 0.5}, {-0.999865158168957, 
       0.5625}}], 
      PolygonBox[{{-0.7940909946396026, 0.5}, {-0.9176761295989384, 
       0.5}, {-0.9157074104439469, 0.5625000189670593}, {-0.7940909946396026, 
       0.5}}], PolygonBox[{{-0.9157074104439469, 
       0.5625000189670593}, {-0.7697483574637453, 
       0.5626550066464766}, {-0.7940909946396026, 0.5}, {-0.9157074104439469, 
       0.5625000189670593}}], 
      PolygonBox[{{-0.642337217350629, 0.5}, {-0.7940909946396026, 
       0.5}, {-0.7697483574637453, 0.5626550066464766}, {-0.642337217350629, 
       0.5}}], PolygonBox[{{-0.7697483574637453, 
       0.5626550066464766}, {-0.5950572556670028, 
       0.5950572556670028}, {-0.642337217350629, 0.5}, {-0.7697483574637453, 
       0.5626550066464766}}], 
      PolygonBox[{{-0.5, 0.5}, {-0.642337217350629, 
       0.5}, {-0.5950572556670028, 0.5950572556670028}, {-0.5, 0.5}}], 
      PolygonBox[{{-0.5950572556670028, 
       0.5950572556670028}, {-0.5950572556670028, 0.5950572556670028}, {-0.5, 
       0.5}, {-0.5950572556670028, 0.5950572556670028}}], 
      PolygonBox[{{-0.5, 0.5}, {-0.5, 0.5}, {-0.5950572556670028, 
       0.5950572556670028}, {-0.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, 2.}, {-1.4791666666666667`, 2.}, {-1.4583333333333333`, 
       2.}, {-1.4375, 2.}, {-1.4166666666666667`, 2.}, {-1.3958333333333335`, 
       2.}, {-1.375, 2.}, {-1.375, 2.}, {-1.3958333333333333`, 
       2.}, {-1.4166666666666667`, 2.}, {-1.4375, 2.}, {-1.4583333333333333`, 
       2.}, {-1.4791666666666665`, 2.}, {-1.5, 2.}, {-1.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, 2.}, {-0.6041666666666667, 2.}, {-0.5833333333333333, 
       2.}, {-0.5625, 2.}, {-0.5416666666666667, 2.}, {-0.5208333333333334, 
       2.}, {-0.5, 2.}, {-0.5, 2.}, {-0.5208333333333333, 
       2.}, {-0.5416666666666667, 2.}, {-0.5625, 2.}, {-0.5833333333333333, 
       2.}, {-0.6041666666666666, 2.}, {-0.625, 2.}, {-0.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 1.5}, {-1., 1.5208333333333333`}, {-1., 
       1.5416666666666667`}, {-1., 1.5625}, {-1., 1.5833333333333333`}, {-1., 
       1.6041666666666665`}, {-1., 1.625}, {-1., 1.625}, {-1., 
       1.6041666666666667`}, {-1., 1.5833333333333333`}, {-1., 1.5625}, {-1., 
       1.5416666666666667`}, {-1., 1.5208333333333335`}, {-1., 1.5}, {-1., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 2.375}, {-1., 2.3958333333333335`}, {-1., 
       2.4166666666666665`}, {-1., 2.4375}, {-1., 2.4583333333333335`}, {-1., 
       2.4791666666666665`}, {-1., 2.5}, {-1., 2.5}, {-1., 
       2.4791666666666665`}, {-1., 2.4583333333333335`}, {-1., 2.4375}, {-1., 
       2.4166666666666665`}, {-1., 2.3958333333333335`}, {-1., 2.375}, {-1., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, 2.}, {-1.25, 2.}, {-1.125, 2.}, {-1., 2.}, {-0.875, 
       2.}, {-0.75, 2.}, {-0.625, 2.}, {-0.625, 2.}, {-0.75, 2.}, {-0.875, 
       2.}, {-1., 2.}, {-1.125, 2.}, {-1.25, 2.}, {-1.375, 2.}, {-1.375, 
       2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 1.625}, {-1., 1.75}, {-1., 1.875}, {-1., 2.}, {-1., 
       2.125}, {-1., 2.25}, {-1., 2.375}, {-1., 2.375}, {-1., 2.25}, {-1., 
       2.125}, {-1., 2.}, {-1., 1.875}, {-1., 1.75}, {-1., 1.625}, {-1., 
       1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kMZDhE7XFjXZjzZ7/9E6OnRYwwODo/vvZg4
+ylEvoHRYbLnhJlHmp/vn/129k0+eSYHiLZX+w3cT7RKz2RyOJK3JfvFkzf7
X11ct+/KU5j8B6j5zA5zT6ie6u79iCb/Ga7f7Lb5Zlm7L3DzE/omcJsbfYXb
f2VxbO3K01/h7oPo/wZ3P0w+2fyWaUnRP3sU/Qx/7c2h5p9SOeHz6OBve0ao
/QsK87+cOPvLfj7UfToxi5rCTH7Zo7r/l/0xqP9g8kxQ/8P0T4GGD8x8R2j4
/QeDP/aR0PBNhLoPPfwB/bKrzg==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNoFodQMHgK568Cg1dwPoT+gCb/CU3/VzT1
PwjyV4PNYYLzIeYwoqlngPPDwPJ/7VH1/7JHVf8Dgx+G4r4f9qtR3A9T/wFN
/hWa/qdo6h8Q5K9Ccd8DqP/+oqmH+e8Bmv9h+pkcUNWzOAAABRp0LA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, 
       1.7348349570550448`}, {-0.6752404735808355, 
       1.8125}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.7348349570550446, 1.7348349570550448`}}], 
      PolygonBox[{{-0.5626550066464766, 
       1.769748357463745}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.6752404735808355, 
       1.8125}, {-0.5626550066464766, 1.769748357463745}}], 
      PolygonBox[{{-0.6752404735808355, 1.8125}, {-0.6377778151415994, 
       1.9029428580865546`}, {-0.5626550066464766, 
       1.769748357463745}, {-0.6752404735808355, 1.8125}}], 
      PolygonBox[{{-0.5625000189670593, 
       1.9157074104439382`}, {-0.5626550066464766, 
       1.769748357463745}, {-0.6377778151415994, 
       1.9029428580865546`}, {-0.5625000189670593, 1.9157074104439382`}}], 
      PolygonBox[{{-0.6377778151415994, 1.9029428580865546`}, {-0.625, 
       2.}, {-0.5625000189670593, 1.9157074104439382`}, {-0.6377778151415994, 
       1.9029428580865546`}}], 
      PolygonBox[{{-0.5625, 2.}, {-0.5625000189670593, 
       1.9157074104439382`}, {-0.625, 2.}, {-0.5625, 2.}}], 
      PolygonBox[{{-0.625, 2.}, {-0.6377778151415994, 
       2.0970571419134454`}, {-0.5625, 2.}, {-0.625, 2.}}], 
      PolygonBox[{{-0.5625000189670593, 2.084292589556062}, {-0.5625, 
       2.}, {-0.6377778151415994, 2.0970571419134454`}, {-0.5625000189670593, 
       2.084292589556062}}], 
      PolygonBox[{{-0.6377778151415994, 
       2.0970571419134454`}, {-0.6752404735808355, 
       2.1875}, {-0.5625000189670593, 
       2.084292589556062}, {-0.6377778151415994, 2.0970571419134454`}}], 
      PolygonBox[{{-0.5626550066464766, 
       2.230251642536255}, {-0.5625000189670593, 
       2.084292589556062}, {-0.6752404735808355, 
       2.1875}, {-0.5626550066464766, 2.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, 2.1875}, {-0.7348349570550446, 
       2.2651650429449552`}, {-0.5626550066464766, 
       2.230251642536255}, {-0.6752404735808355, 2.1875}}], 
      PolygonBox[{{-0.5950572556670028, 
       2.404942744332997}, {-0.5626550066464766, 
       2.230251642536255}, {-0.7348349570550446, 
       2.2651650429449552`}, {-0.5950572556670028, 2.404942744332997}}], 
      PolygonBox[{{-0.7348349570550446, 2.2651650429449552`}, {-0.8125, 
       2.3247595264191645`}, {-0.5950572556670028, 
       2.404942744332997}, {-0.7348349570550446, 2.2651650429449552`}}], 
      PolygonBox[{{-0.7697483574637448, 
       2.4373449933535234`}, {-0.5950572556670028, 
       2.404942744332997}, {-0.8125, 
       2.3247595264191645`}, {-0.7697483574637448, 2.4373449933535234`}}], 
      PolygonBox[{{-0.8125, 2.3247595264191645`}, {-0.9029428580865546, 
       2.3622221848584006`}, {-0.7697483574637448, 
       2.4373449933535234`}, {-0.8125, 2.3247595264191645`}}], 
      PolygonBox[{{-0.9157074104439394, 
       2.437499981032941}, {-0.7697483574637448, 
       2.4373449933535234`}, {-0.9029428580865546, 
       2.3622221848584006`}, {-0.9157074104439394, 2.437499981032941}}], 
      PolygonBox[{{-0.9029428580865546, 2.3622221848584006`}, {-1., 
       2.375}, {-0.9157074104439394, 2.437499981032941}, {-0.9029428580865546,
        2.3622221848584006`}}], 
      PolygonBox[{{-0.9998944727795123, 2.4375}, {-0.9157074104439394, 
       2.437499981032941}, {-1., 2.375}, {-0.9998944727795123, 2.4375}}], 
      PolygonBox[{{-1., 2.375}, {-1.0970571419134452`, 
       2.3622221848584006`}, {-0.9998944727795123, 2.4375}, {-1., 2.375}}], 
      PolygonBox[{{-1.084292589556057, 
       2.437499981032941}, {-0.9998944727795123, 
       2.4375}, {-1.0970571419134452`, 
       2.3622221848584006`}, {-1.084292589556057, 2.437499981032941}}], 
      PolygonBox[{{-1.0970571419134452`, 2.3622221848584006`}, {-1.1875, 
       2.3247595264191645`}, {-1.084292589556057, 
       2.437499981032941}, {-1.0970571419134452`, 2.3622221848584006`}}], 
      PolygonBox[{{-1.230251642536255, 
       2.4373449933535234`}, {-1.084292589556057, 
       2.437499981032941}, {-1.1875, 
       2.3247595264191645`}, {-1.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{-1.1875, 2.3247595264191645`}, {-1.2651650429449552`, 
       2.2651650429449552`}, {-1.230251642536255, 
       2.4373449933535234`}, {-1.1875, 2.3247595264191645`}}], 
      PolygonBox[{{-1.4049427443329972`, 
       2.404942744332997}, {-1.230251642536255, 
       2.4373449933535234`}, {-1.2651650429449552`, 
       2.2651650429449552`}, {-1.4049427443329972`, 2.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, 
       2.2651650429449552`}, {-1.3247595264191645`, 
       2.1875}, {-1.4049427443329972`, 
       2.404942744332997}, {-1.2651650429449552`, 2.2651650429449552`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       2.2302516425362553`}, {-1.4049427443329972`, 
       2.404942744332997}, {-1.3247595264191645`, 
       2.1875}, {-1.4373449933535234`, 2.2302516425362553`}}], 
      PolygonBox[{{-1.3247595264191645`, 2.1875}, {-1.3622221848584006`, 
       2.0970571419134454`}, {-1.4373449933535234`, 
       2.2302516425362553`}, {-1.3247595264191645`, 2.1875}}], 
      PolygonBox[{{-1.4374999810329407`, 
       2.0842925895560622`}, {-1.4373449933535234`, 
       2.2302516425362553`}, {-1.3622221848584006`, 
       2.0970571419134454`}, {-1.4374999810329407`, 2.0842925895560622`}}], 
      PolygonBox[{{-1.3622221848584006`, 2.0970571419134454`}, {-1.375, 
       2.}, {-1.4374999810329407`, 
       2.0842925895560622`}, {-1.3622221848584006`, 2.0970571419134454`}}], 
      PolygonBox[{{-1.4375, 2.0001231780629953`}, {-1.4374999810329407`, 
       2.0842925895560622`}, {-1.375, 2.}, {-1.4375, 2.0001231780629953`}}], 
      PolygonBox[{{-1.375, 2.}, {-1.3622221848584006`, 
       1.9029428580865548`}, {-1.4375, 2.0001231780629953`}, {-1.375, 2.}}], 
      PolygonBox[{{-1.4374999810329407`, 1.915707410443945}, {-1.4375, 
       2.0001231780629953`}, {-1.3622221848584006`, 
       1.9029428580865548`}, {-1.4374999810329407`, 1.915707410443945}}], 
      PolygonBox[{{-1.3622221848584006`, 
       1.9029428580865548`}, {-1.3247595264191645`, 
       1.8125000000000002`}, {-1.4374999810329407`, 
       1.915707410443945}, {-1.3622221848584006`, 1.9029428580865548`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       1.7697483574637451`}, {-1.4374999810329407`, 
       1.915707410443945}, {-1.3247595264191645`, 
       1.8125000000000002`}, {-1.4373449933535234`, 1.7697483574637451`}}], 
      PolygonBox[{{-1.3247595264191645`, 
       1.8125000000000002`}, {-1.2651650429449552`, 
       1.7348349570550448`}, {-1.4373449933535234`, 
       1.7697483574637451`}, {-1.3247595264191645`, 1.8125000000000002`}}], 
      PolygonBox[{{-1.4049427443329972`, 
       1.5950572556670028`}, {-1.4373449933535234`, 
       1.7697483574637451`}, {-1.2651650429449552`, 
       1.7348349570550448`}, {-1.4049427443329972`, 1.5950572556670028`}}], 
      PolygonBox[{{-1.2651650429449552`, 
       1.7348349570550448`}, {-1.1875000000000002`, 
       1.6752404735808355`}, {-1.4049427443329972`, 
       1.5950572556670028`}, {-1.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{-1.230251642536255, 
       1.5626550066464766`}, {-1.4049427443329972`, 
       1.5950572556670028`}, {-1.1875000000000002`, 
       1.6752404735808355`}, {-1.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{-1.1875000000000002`, 
       1.6752404735808355`}, {-1.0970571419134456`, 
       1.6377778151415994`}, {-1.230251642536255, 
       1.5626550066464766`}, {-1.1875000000000002`, 1.6752404735808355`}}], 
      PolygonBox[{{-1.0842925895560642`, 
       1.5625000189670593`}, {-1.230251642536255, 
       1.5626550066464766`}, {-1.0970571419134456`, 
       1.6377778151415994`}, {-1.0842925895560642`, 1.5625000189670593`}}], 
      PolygonBox[{{-1.0970571419134456`, 
       1.6377778151415994`}, {-0.9999999999999999, 
       1.625}, {-1.0842925895560642`, 
       1.5625000189670593`}, {-1.0970571419134456`, 1.6377778151415994`}}], 
      PolygonBox[{{-0.999865158168957, 1.5625}, {-1.0842925895560642`, 
       1.5625000189670593`}, {-0.9999999999999999, 
       1.625}, {-0.999865158168957, 1.5625}}], 
      PolygonBox[{{-0.9999999999999999, 1.625}, {-0.9029428580865548, 
       1.6377778151415994`}, {-0.999865158168957, 
       1.5625}, {-0.9999999999999999, 1.625}}], 
      PolygonBox[{{-0.9157074104439469, 
       1.5625000189670593`}, {-0.999865158168957, 
       1.5625}, {-0.9029428580865548, 
       1.6377778151415994`}, {-0.9157074104439469, 1.5625000189670593`}}], 
      PolygonBox[{{-0.9029428580865548, 
       1.6377778151415994`}, {-0.8125000000000002, 
       1.6752404735808355`}, {-0.9157074104439469, 
       1.5625000189670593`}, {-0.9029428580865548, 1.6377778151415994`}}], 
      PolygonBox[{{-0.7697483574637453, 
       1.5626550066464766`}, {-0.9157074104439469, 
       1.5625000189670593`}, {-0.8125000000000002, 
       1.6752404735808355`}, {-0.7697483574637453, 1.5626550066464766`}}], 
      PolygonBox[{{-0.8125000000000002, 
       1.6752404735808355`}, {-0.7348349570550448, 
       1.7348349570550448`}, {-0.7697483574637453, 
       1.5626550066464766`}, {-0.8125000000000002, 1.6752404735808355`}}], 
      PolygonBox[{{-0.5950572556670028, 
       1.5950572556670028`}, {-0.7697483574637453, 
       1.5626550066464766`}, {-0.7348349570550448, 
       1.7348349570550448`}, {-0.5950572556670028, 1.5950572556670028`}}], 
      PolygonBox[{{-0.7348349570550448, 
       1.7348349570550448`}, {-0.7348349570550446, 
       1.7348349570550448`}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.7348349570550448, 1.7348349570550448`}}], 
      PolygonBox[{{-0.5950572556670028, 
       1.5950572556670028`}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.7348349570550446, 
       1.7348349570550448`}, {-0.5950572556670028, 1.5950572556670028`}}], 
      PolygonBox[{{-0.5950572556670028, 
       1.5950572556670028`}, {-0.5626550066464766, 1.769748357463745}, {-0.5, 
       1.5}, {-0.5950572556670028, 1.5950572556670028`}}], 
      PolygonBox[{{-0.5, 1.6423372173506323`}, {-0.5, 
       1.5}, {-0.5626550066464766, 1.769748357463745}, {-0.5, 
       1.6423372173506323`}}], 
      PolygonBox[{{-0.5626550066464766, 
       1.769748357463745}, {-0.5625000189670593, 1.9157074104439382`}, {-0.5, 
       1.6423372173506323`}, {-0.5626550066464766, 1.769748357463745}}], 
      PolygonBox[{{-0.5, 1.79409099469826}, {-0.5, 
       1.6423372173506323`}, {-0.5625000189670593, 
       1.9157074104439382`}, {-0.5, 1.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, 1.9157074104439382`}, {-0.5625, 
       2.}, {-0.5, 1.79409099469826}, {-0.5625000189670593, 
       1.9157074104439382`}}], 
      PolygonBox[{{-0.5, 2.}, {-0.5, 1.79409099469826}, {-0.5625, 2.}, {-0.5, 
       2.}}], PolygonBox[{{-0.5625, 2.}, {-0.5625000189670593, 
       2.084292589556062}, {-0.5, 2.}, {-0.5625, 2.}}], 
      PolygonBox[{{-0.5, 2.20590900530174}, {-0.5, 2.}, {-0.5625000189670593, 
       2.084292589556062}, {-0.5, 2.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, 
       2.084292589556062}, {-0.5626550066464766, 2.230251642536255}, {-0.5, 
       2.20590900530174}, {-0.5625000189670593, 2.084292589556062}}], 
      PolygonBox[{{-0.5, 2.3576627826493675`}, {-0.5, 
       2.20590900530174}, {-0.5626550066464766, 2.230251642536255}, {-0.5, 
       2.3576627826493675`}}], 
      PolygonBox[{{-0.5626550066464766, 
       2.230251642536255}, {-0.5950572556670028, 2.404942744332997}, {-0.5, 
       2.3576627826493675`}, {-0.5626550066464766, 2.230251642536255}}], 
      PolygonBox[{{-0.508553435038814, 2.491446564961186}, {-0.5, 
       2.3576627826493675`}, {-0.5950572556670028, 
       2.404942744332997}, {-0.508553435038814, 2.491446564961186}}], 
      PolygonBox[{{-0.5950572556670028, 
       2.404942744332997}, {-0.7697483574637448, 
       2.4373449933535234`}, {-0.508553435038814, 
       2.491446564961186}, {-0.5950572556670028, 2.404942744332997}}], 
      PolygonBox[{{-0.6423372173506319, 2.5}, {-0.508553435038814, 
       2.491446564961186}, {-0.7697483574637448, 
       2.4373449933535234`}, {-0.6423372173506319, 2.5}}], 
      PolygonBox[{{-0.7697483574637448, 
       2.4373449933535234`}, {-0.9157074104439394, 
       2.437499981032941}, {-0.6423372173506319, 2.5}, {-0.7697483574637448, 
       2.4373449933535234`}}], 
      PolygonBox[{{-0.7940909946267442, 2.5}, {-0.6423372173506319, 
       2.5}, {-0.9157074104439394, 2.437499981032941}, {-0.7940909946267442, 
       2.5}}], PolygonBox[{{-0.9157074104439394, 
       2.437499981032941}, {-0.9998944727795123, 
       2.4375}, {-0.7940909946267442, 2.5}, {-0.9157074104439394, 
       2.437499981032941}}], 
      PolygonBox[{{-0.9220580419731099, 2.5}, {-0.7940909946267442, 
       2.5}, {-0.9998944727795123, 2.4375}, {-0.9220580419731099, 2.5}}], 
      PolygonBox[{{-0.9998944727795123, 2.4375}, {-1.084292589556057, 
       2.437499981032941}, {-0.9220580419731099, 2.5}, {-0.9998944727795123, 
       2.4375}}], 
      PolygonBox[{{-1.2059090053044457`, 2.5}, {-0.9220580419731099, 
       2.5}, {-1.084292589556057, 2.437499981032941}, {-1.2059090053044457`, 
       2.5}}], PolygonBox[{{-1.084292589556057, 
       2.437499981032941}, {-1.230251642536255, 
       2.4373449933535234`}, {-1.2059090053044457`, 2.5}, {-1.084292589556057,
        2.437499981032941}}], 
      PolygonBox[{{-1.3576627826493661`, 2.5}, {-1.2059090053044457`, 
       2.5}, {-1.230251642536255, 2.4373449933535234`}, {-1.3576627826493661`,
        2.5}}], 
      PolygonBox[{{-1.230251642536255, 
       2.4373449933535234`}, {-1.4049427443329972`, 
       2.404942744332997}, {-1.3576627826493661`, 2.5}, {-1.230251642536255, 
       2.4373449933535234`}}], 
      PolygonBox[{{-0.5, 2.5}, {-1.3576627826493661`, 
       2.5}, {-1.4049427443329972`, 2.404942744332997}, {-0.5, 2.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       2.404942744332997}, {-1.4373449933535234`, 2.2302516425362553`}, {-0.5,
        2.5}, {-1.4049427443329972`, 2.404942744332997}}], 
      PolygonBox[{{-1.5, 2.357662782649369}, {-0.5, 
       2.5}, {-1.4373449933535234`, 2.2302516425362553`}, {-1.5, 
       2.357662782649369}}], 
      PolygonBox[{{-1.4373449933535234`, 
       2.2302516425362553`}, {-1.4374999810329407`, 
       2.0842925895560622`}, {-1.5, 2.357662782649369}, {-1.4373449933535234`,
        2.2302516425362553`}}], 
      PolygonBox[{{-1.5, 2.205909005282899}, {-1.5, 
       2.357662782649369}, {-1.4374999810329407`, 2.0842925895560622`}, {-1.5,
        2.205909005282899}}], 
      PolygonBox[{{-1.4374999810329407`, 2.0842925895560622`}, {-1.4375, 
       2.0001231780629953`}, {-1.5, 2.205909005282899}, {-1.4374999810329407`,
        2.0842925895560622`}}], 
      PolygonBox[{{-1.5, 2.0806786667587}, {-1.5, 
       2.205909005282899}, {-1.4375, 2.0001231780629953`}, {-1.5, 
       2.0806786667587}}], 
      PolygonBox[{{-1.4375, 2.0001231780629953`}, {-1.4374999810329407`, 
       1.915707410443945}, {-1.5, 2.0806786667587}, {-1.4375, 
       2.0001231780629953`}}], 
      PolygonBox[{{-1.5, 1.7940909948547215`}, {-1.5, 
       2.0806786667587}, {-1.4374999810329407`, 1.915707410443945}, {-1.5, 
       1.7940909948547215`}}], 
      PolygonBox[{{-1.4374999810329407`, 
       1.915707410443945}, {-1.4373449933535234`, 1.7697483574637451`}, {-1.5,
        1.7940909948547215`}, {-1.4374999810329407`, 1.915707410443945}}], 
      PolygonBox[{{-1.5, 1.6423372173506348`}, {-1.5, 
       1.7940909948547215`}, {-1.4373449933535234`, 
       1.7697483574637451`}, {-1.5, 1.6423372173506348`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       1.7697483574637451`}, {-1.4049427443329972`, 
       1.5950572556670028`}, {-1.5, 
       1.6423372173506348`}, {-1.4373449933535234`, 1.7697483574637451`}}], 
      PolygonBox[{{-1.5, 2.5}, {-1.5, 
       1.6423372173506348`}, {-1.4049427443329972`, 
       1.5950572556670028`}, {-1.5, 2.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       1.5950572556670028`}, {-1.230251642536255, 1.5626550066464766`}, {-1.5,
        2.5}, {-1.4049427443329972`, 1.5950572556670028`}}], 
      PolygonBox[{{-1.5, 1.5}, {-1.5, 2.5}, {-1.230251642536255, 
       1.5626550066464766`}, {-1.5, 1.5}}], 
      PolygonBox[{{-1.230251642536255, 
       1.5626550066464766`}, {-1.0842925895560642`, 
       1.5625000189670593`}, {-1.5, 1.5}, {-1.230251642536255, 
       1.5626550066464766`}}], 
      PolygonBox[{{-1.205909005566828, 1.5}, {-1.5, 
       1.5}, {-1.0842925895560642`, 1.5625000189670593`}, {-1.205909005566828,
        1.5}}], 
      PolygonBox[{{-1.0842925895560642`, 
       1.5625000189670593`}, {-0.999865158168957, 
       1.5625}, {-1.205909005566828, 1.5}, {-1.0842925895560642`, 
       1.5625000189670593`}}], 
      PolygonBox[{{-0.9176761295989384, 1.5}, {-1.205909005566828, 
       1.5}, {-0.999865158168957, 1.5625}, {-0.9176761295989384, 1.5}}], 
      PolygonBox[{{-0.999865158168957, 1.5625}, {-0.9157074104439469, 
       1.5625000189670593`}, {-0.9176761295989384, 1.5}, {-0.999865158168957, 
       1.5625}}], 
      PolygonBox[{{-0.7940909946396026, 1.5}, {-0.9176761295989384, 
       1.5}, {-0.9157074104439469, 1.5625000189670593`}, {-0.7940909946396026,
        1.5}}], 
      PolygonBox[{{-0.9157074104439469, 
       1.5625000189670593`}, {-0.7697483574637453, 
       1.5626550066464766`}, {-0.7940909946396026, 1.5}, {-0.9157074104439469,
        1.5625000189670593`}}], 
      PolygonBox[{{-0.642337217350629, 1.5}, {-0.7940909946396026, 
       1.5}, {-0.7697483574637453, 1.5626550066464766`}, {-0.642337217350629, 
       1.5}}], PolygonBox[{{-0.7697483574637453, 
       1.5626550066464766`}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.642337217350629, 1.5}, {-0.7697483574637453, 
       1.5626550066464766`}}], 
      PolygonBox[{{-0.5, 1.5}, {-0.642337217350629, 
       1.5}, {-0.5950572556670028, 1.5950572556670028`}, {-0.5, 1.5}}], 
      PolygonBox[{{-0.5950572556670028, 
       1.5950572556670028`}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.5, 1.5}, {-0.5950572556670028, 
       1.5950572556670028`}}], 
      PolygonBox[{{-0.5, 1.5}, {-0.5, 1.5}, {-0.5950572556670028, 
       1.5950572556670028`}, {-0.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, 3.}, {-1.4791666666666667`, 3.}, {-1.4583333333333333`, 
       3.}, {-1.4375, 3.}, {-1.4166666666666667`, 3.}, {-1.3958333333333335`, 
       3.}, {-1.375, 3.}, {-1.375, 3.}, {-1.3958333333333333`, 
       3.}, {-1.4166666666666667`, 3.}, {-1.4375, 3.}, {-1.4583333333333333`, 
       3.}, {-1.4791666666666665`, 3.}, {-1.5, 3.}, {-1.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, 3.}, {-0.6041666666666667, 3.}, {-0.5833333333333333, 
       3.}, {-0.5625, 3.}, {-0.5416666666666667, 3.}, {-0.5208333333333334, 
       3.}, {-0.5, 3.}, {-0.5, 3.}, {-0.5208333333333333, 
       3.}, {-0.5416666666666667, 3.}, {-0.5625, 3.}, {-0.5833333333333333, 
       3.}, {-0.6041666666666666, 3.}, {-0.625, 3.}, {-0.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 2.5}, {-1., 2.5208333333333335`}, {-1., 
       2.5416666666666665`}, {-1., 2.5625}, {-1., 2.5833333333333335`}, {-1., 
       2.6041666666666665`}, {-1., 2.625}, {-1., 2.625}, {-1., 
       2.6041666666666665`}, {-1., 2.5833333333333335`}, {-1., 2.5625}, {-1., 
       2.5416666666666665`}, {-1., 2.5208333333333335`}, {-1., 2.5}, {-1., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 3.375}, {-1., 3.3958333333333335`}, {-1., 
       3.4166666666666665`}, {-1., 3.4375}, {-1., 3.4583333333333335`}, {-1., 
       3.4791666666666665`}, {-1., 3.5}, {-1., 3.5}, {-1., 
       3.4791666666666665`}, {-1., 3.4583333333333335`}, {-1., 3.4375}, {-1., 
       3.4166666666666665`}, {-1., 3.3958333333333335`}, {-1., 3.375}, {-1., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, 3.}, {-1.25, 3.}, {-1.125, 3.}, {-1., 3.}, {-0.875, 
       3.}, {-0.75, 3.}, {-0.625, 3.}, {-0.625, 3.}, {-0.75, 3.}, {-0.875, 
       3.}, {-1., 3.}, {-1.125, 3.}, {-1.25, 3.}, {-1.375, 3.}, {-1.375, 
       3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 2.625}, {-1., 2.75}, {-1., 2.875}, {-1., 3.}, {-1., 
       3.125}, {-1., 3.25}, {-1., 3.375}, {-1., 3.375}, {-1., 3.25}, {-1., 
       3.125}, {-1., 3.}, {-1., 2.875}, {-1., 2.75}, {-1., 2.625}, {-1., 
       2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kNoDoeIHS6sazOe7Pd/IvT06DEOB4fH915M
nP0UIt/A6TDZc8LMI83P989+O/smnzyXA0Tfq/0G7idapWdyORzJ25L94smb
/a8urtt35SlM/gPUfG6HuSdUT3X3fkST/wzXb3bbfLOs3Re4+Ql9E7jNjb7C
7b+yOLZ25emvcPdB9H+Dux8mv0n6rZSVJTuafjYHc6j5qUIpah8fsDowQu2/
sMO86kkaq8N8qPvE9AIdtaVY0dzP6nAM6j+YPBPU/zD9U6DhAzPfESX82Bwi
oeG7Eeo+9PAHAMeUl0g=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNoHodQMHgK568Cg1dwPoT+gCb/CU3/VzT1
PwjyV4PN4YLzIeZwoqnnQFPPBueHgdWzoqlnweCHobiPxWE1ivth6j+gyb9C
0/8UTf0DgvxQFPc9QHP/AzT/PUDz/4P9q1DCBxFfAK2vaEY=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, 
       2.7348349570550448`}, {-0.6752404735808355, 
       2.8125}, {-0.5950572556670028, 
       2.595057255667003}, {-0.7348349570550446, 2.7348349570550448`}}], 
      PolygonBox[{{-0.5626550066464766, 
       2.7697483574637447`}, {-0.5950572556670028, 
       2.595057255667003}, {-0.6752404735808355, 
       2.8125}, {-0.5626550066464766, 2.7697483574637447`}}], 
      PolygonBox[{{-0.6752404735808355, 2.8125}, {-0.6377778151415994, 
       2.9029428580865546`}, {-0.5626550066464766, 
       2.7697483574637447`}, {-0.6752404735808355, 2.8125}}], 
      PolygonBox[{{-0.5625000189670593, 
       2.915707410443938}, {-0.5626550066464766, 
       2.7697483574637447`}, {-0.6377778151415994, 
       2.9029428580865546`}, {-0.5625000189670593, 2.915707410443938}}], 
      PolygonBox[{{-0.6377778151415994, 2.9029428580865546`}, {-0.625, 
       3.}, {-0.5625000189670593, 2.915707410443938}, {-0.6377778151415994, 
       2.9029428580865546`}}], 
      PolygonBox[{{-0.5625, 3.}, {-0.5625000189670593, 
       2.915707410443938}, {-0.625, 3.}, {-0.5625, 3.}}], 
      PolygonBox[{{-0.625, 3.}, {-0.6377778151415994, 
       3.0970571419134454`}, {-0.5625, 3.}, {-0.625, 3.}}], 
      PolygonBox[{{-0.5625000189670593, 3.084292589556062}, {-0.5625, 
       3.}, {-0.6377778151415994, 3.0970571419134454`}, {-0.5625000189670593, 
       3.084292589556062}}], 
      PolygonBox[{{-0.6377778151415994, 
       3.0970571419134454`}, {-0.6752404735808355, 
       3.1875}, {-0.5625000189670593, 
       3.084292589556062}, {-0.6377778151415994, 3.0970571419134454`}}], 
      PolygonBox[{{-0.5626550066464766, 
       3.230251642536255}, {-0.5625000189670593, 
       3.084292589556062}, {-0.6752404735808355, 
       3.1875}, {-0.5626550066464766, 3.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, 3.1875}, {-0.7348349570550446, 
       3.2651650429449552`}, {-0.5626550066464766, 
       3.230251642536255}, {-0.6752404735808355, 3.1875}}], 
      PolygonBox[{{-0.5950572556670028, 
       3.404942744332997}, {-0.5626550066464766, 
       3.230251642536255}, {-0.7348349570550446, 
       3.2651650429449552`}, {-0.5950572556670028, 3.404942744332997}}], 
      PolygonBox[{{-0.7348349570550446, 3.2651650429449552`}, {-0.8125, 
       3.3247595264191645`}, {-0.5950572556670028, 
       3.404942744332997}, {-0.7348349570550446, 3.2651650429449552`}}], 
      PolygonBox[{{-0.7697483574637448, 
       3.4373449933535234`}, {-0.5950572556670028, 
       3.404942744332997}, {-0.8125, 
       3.3247595264191645`}, {-0.7697483574637448, 3.4373449933535234`}}], 
      PolygonBox[{{-0.8125, 3.3247595264191645`}, {-0.9029428580865546, 
       3.3622221848584006`}, {-0.7697483574637448, 
       3.4373449933535234`}, {-0.8125, 3.3247595264191645`}}], 
      PolygonBox[{{-0.9157074104439394, 
       3.437499981032941}, {-0.7697483574637448, 
       3.4373449933535234`}, {-0.9029428580865546, 
       3.3622221848584006`}, {-0.9157074104439394, 3.437499981032941}}], 
      PolygonBox[{{-0.9029428580865546, 3.3622221848584006`}, {-1., 
       3.375}, {-0.9157074104439394, 3.437499981032941}, {-0.9029428580865546,
        3.3622221848584006`}}], 
      PolygonBox[{{-0.9998944727795123, 3.4375}, {-0.9157074104439394, 
       3.437499981032941}, {-1., 3.375}, {-0.9998944727795123, 3.4375}}], 
      PolygonBox[{{-1., 3.375}, {-1.0970571419134452`, 
       3.3622221848584006`}, {-0.9998944727795123, 3.4375}, {-1., 3.375}}], 
      PolygonBox[{{-1.084292589556057, 
       3.437499981032941}, {-0.9998944727795123, 
       3.4375}, {-1.0970571419134452`, 
       3.3622221848584006`}, {-1.084292589556057, 3.437499981032941}}], 
      PolygonBox[{{-1.0970571419134452`, 3.3622221848584006`}, {-1.1875, 
       3.3247595264191645`}, {-1.084292589556057, 
       3.437499981032941}, {-1.0970571419134452`, 3.3622221848584006`}}], 
      PolygonBox[{{-1.230251642536255, 
       3.4373449933535234`}, {-1.084292589556057, 
       3.437499981032941}, {-1.1875, 
       3.3247595264191645`}, {-1.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{-1.1875, 3.3247595264191645`}, {-1.2651650429449552`, 
       3.2651650429449552`}, {-1.230251642536255, 
       3.4373449933535234`}, {-1.1875, 3.3247595264191645`}}], 
      PolygonBox[{{-1.4049427443329972`, 
       3.404942744332997}, {-1.230251642536255, 
       3.4373449933535234`}, {-1.2651650429449552`, 
       3.2651650429449552`}, {-1.4049427443329972`, 3.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, 
       3.2651650429449552`}, {-1.3247595264191645`, 
       3.1875}, {-1.4049427443329972`, 
       3.404942744332997}, {-1.2651650429449552`, 3.2651650429449552`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       3.2302516425362553`}, {-1.4049427443329972`, 
       3.404942744332997}, {-1.3247595264191645`, 
       3.1875}, {-1.4373449933535234`, 3.2302516425362553`}}], 
      PolygonBox[{{-1.3247595264191645`, 3.1875}, {-1.3622221848584006`, 
       3.0970571419134454`}, {-1.4373449933535234`, 
       3.2302516425362553`}, {-1.3247595264191645`, 3.1875}}], 
      PolygonBox[{{-1.4374999810329407`, 
       3.0842925895560622`}, {-1.4373449933535234`, 
       3.2302516425362553`}, {-1.3622221848584006`, 
       3.0970571419134454`}, {-1.4374999810329407`, 3.0842925895560622`}}], 
      PolygonBox[{{-1.3622221848584006`, 3.0970571419134454`}, {-1.375, 
       3.}, {-1.4374999810329407`, 
       3.0842925895560622`}, {-1.3622221848584006`, 3.0970571419134454`}}], 
      PolygonBox[{{-1.4375, 3.0001231780629953`}, {-1.4374999810329407`, 
       3.0842925895560622`}, {-1.375, 3.}, {-1.4375, 3.0001231780629953`}}], 
      PolygonBox[{{-1.375, 3.}, {-1.3622221848584006`, 
       2.902942858086555}, {-1.4375, 3.0001231780629953`}, {-1.375, 3.}}], 
      PolygonBox[{{-1.4374999810329407`, 2.915707410443945}, {-1.4375, 
       3.0001231780629953`}, {-1.3622221848584006`, 
       2.902942858086555}, {-1.4374999810329407`, 2.915707410443945}}], 
      PolygonBox[{{-1.3622221848584006`, 
       2.902942858086555}, {-1.3247595264191645`, 
       2.8125}, {-1.4374999810329407`, 
       2.915707410443945}, {-1.3622221848584006`, 2.902942858086555}}], 
      PolygonBox[{{-1.4373449933535234`, 
       2.769748357463745}, {-1.4374999810329407`, 
       2.915707410443945}, {-1.3247595264191645`, 
       2.8125}, {-1.4373449933535234`, 2.769748357463745}}], 
      PolygonBox[{{-1.3247595264191645`, 2.8125}, {-1.2651650429449552`, 
       2.7348349570550448`}, {-1.4373449933535234`, 
       2.769748357463745}, {-1.3247595264191645`, 2.8125}}], 
      PolygonBox[{{-1.4049427443329972`, 
       2.595057255667003}, {-1.4373449933535234`, 
       2.769748357463745}, {-1.2651650429449552`, 
       2.7348349570550448`}, {-1.4049427443329972`, 2.595057255667003}}], 
      PolygonBox[{{-1.2651650429449552`, 
       2.7348349570550448`}, {-1.1875000000000002`, 
       2.6752404735808355`}, {-1.4049427443329972`, 
       2.595057255667003}, {-1.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{-1.230251642536255, 
       2.5626550066464766`}, {-1.4049427443329972`, 
       2.595057255667003}, {-1.1875000000000002`, 
       2.6752404735808355`}, {-1.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-1.1875000000000002`, 
       2.6752404735808355`}, {-1.0970571419134456`, 
       2.6377778151415994`}, {-1.230251642536255, 
       2.5626550066464766`}, {-1.1875000000000002`, 2.6752404735808355`}}], 
      PolygonBox[{{-1.0842925895560642`, 
       2.562500018967059}, {-1.230251642536255, 
       2.5626550066464766`}, {-1.0970571419134456`, 
       2.6377778151415994`}, {-1.0842925895560642`, 2.562500018967059}}], 
      PolygonBox[{{-1.0970571419134456`, 
       2.6377778151415994`}, {-0.9999999999999999, 
       2.625}, {-1.0842925895560642`, 
       2.562500018967059}, {-1.0970571419134456`, 2.6377778151415994`}}], 
      PolygonBox[{{-0.999865158168957, 2.5625}, {-1.0842925895560642`, 
       2.562500018967059}, {-0.9999999999999999, 2.625}, {-0.999865158168957, 
       2.5625}}], 
      PolygonBox[{{-0.9999999999999999, 2.625}, {-0.9029428580865548, 
       2.6377778151415994`}, {-0.999865158168957, 
       2.5625}, {-0.9999999999999999, 2.625}}], 
      PolygonBox[{{-0.9157074104439469, 
       2.562500018967059}, {-0.999865158168957, 2.5625}, {-0.9029428580865548,
        2.6377778151415994`}, {-0.9157074104439469, 2.562500018967059}}], 
      PolygonBox[{{-0.9029428580865548, 
       2.6377778151415994`}, {-0.8125000000000002, 
       2.6752404735808355`}, {-0.9157074104439469, 
       2.562500018967059}, {-0.9029428580865548, 2.6377778151415994`}}], 
      PolygonBox[{{-0.7697483574637453, 
       2.5626550066464766`}, {-0.9157074104439469, 
       2.562500018967059}, {-0.8125000000000002, 
       2.6752404735808355`}, {-0.7697483574637453, 2.5626550066464766`}}], 
      PolygonBox[{{-0.8125000000000002, 
       2.6752404735808355`}, {-0.7348349570550448, 
       2.7348349570550448`}, {-0.7697483574637453, 
       2.5626550066464766`}, {-0.8125000000000002, 2.6752404735808355`}}], 
      PolygonBox[{{-0.5950572556670028, 
       2.595057255667003}, {-0.7697483574637453, 
       2.5626550066464766`}, {-0.7348349570550448, 
       2.7348349570550448`}, {-0.5950572556670028, 2.595057255667003}}], 
      PolygonBox[{{-0.7348349570550448, 
       2.7348349570550448`}, {-0.7348349570550446, 
       2.7348349570550448`}, {-0.5950572556670028, 
       2.595057255667003}, {-0.7348349570550448, 2.7348349570550448`}}], 
      PolygonBox[{{-0.5950572556670028, 
       2.595057255667003}, {-0.5950572556670028, 
       2.595057255667003}, {-0.7348349570550446, 
       2.7348349570550448`}, {-0.5950572556670028, 2.595057255667003}}], 
      PolygonBox[{{-0.5950572556670028, 
       2.595057255667003}, {-0.5626550066464766, 2.7697483574637447`}, {-0.5, 
       2.5}, {-0.5950572556670028, 2.595057255667003}}], 
      PolygonBox[{{-0.5, 2.642337217350632}, {-0.5, 
       2.5}, {-0.5626550066464766, 2.7697483574637447`}, {-0.5, 
       2.642337217350632}}], 
      PolygonBox[{{-0.5626550066464766, 
       2.7697483574637447`}, {-0.5625000189670593, 2.915707410443938}, {-0.5, 
       2.642337217350632}, {-0.5626550066464766, 2.7697483574637447`}}], 
      PolygonBox[{{-0.5, 2.79409099469826}, {-0.5, 
       2.642337217350632}, {-0.5625000189670593, 2.915707410443938}, {-0.5, 
       2.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, 2.915707410443938}, {-0.5625, 
       3.}, {-0.5, 2.79409099469826}, {-0.5625000189670593, 
       2.915707410443938}}], 
      PolygonBox[{{-0.5, 3.}, {-0.5, 2.79409099469826}, {-0.5625, 3.}, {-0.5, 
       3.}}], PolygonBox[{{-0.5625, 3.}, {-0.5625000189670593, 
       3.084292589556062}, {-0.5, 3.}, {-0.5625, 3.}}], 
      PolygonBox[{{-0.5, 3.20590900530174}, {-0.5, 3.}, {-0.5625000189670593, 
       3.084292589556062}, {-0.5, 3.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, 
       3.084292589556062}, {-0.5626550066464766, 3.230251642536255}, {-0.5, 
       3.20590900530174}, {-0.5625000189670593, 3.084292589556062}}], 
      PolygonBox[{{-0.5, 3.3576627826493675`}, {-0.5, 
       3.20590900530174}, {-0.5626550066464766, 3.230251642536255}, {-0.5, 
       3.3576627826493675`}}], 
      PolygonBox[{{-0.5626550066464766, 
       3.230251642536255}, {-0.5950572556670028, 3.404942744332997}, {-0.5, 
       3.3576627826493675`}, {-0.5626550066464766, 3.230251642536255}}], 
      PolygonBox[{{-0.508553435038814, 3.491446564961186}, {-0.5, 
       3.3576627826493675`}, {-0.5950572556670028, 
       3.404942744332997}, {-0.508553435038814, 3.491446564961186}}], 
      PolygonBox[{{-0.5950572556670028, 
       3.404942744332997}, {-0.7697483574637448, 
       3.4373449933535234`}, {-0.508553435038814, 
       3.491446564961186}, {-0.5950572556670028, 3.404942744332997}}], 
      PolygonBox[{{-0.6423372173506319, 3.5}, {-0.508553435038814, 
       3.491446564961186}, {-0.7697483574637448, 
       3.4373449933535234`}, {-0.6423372173506319, 3.5}}], 
      PolygonBox[{{-0.7697483574637448, 
       3.4373449933535234`}, {-0.9157074104439394, 
       3.437499981032941}, {-0.6423372173506319, 3.5}, {-0.7697483574637448, 
       3.4373449933535234`}}], 
      PolygonBox[{{-0.7940909946267442, 3.5}, {-0.6423372173506319, 
       3.5}, {-0.9157074104439394, 3.437499981032941}, {-0.7940909946267442, 
       3.5}}], PolygonBox[{{-0.9157074104439394, 
       3.437499981032941}, {-0.9998944727795123, 
       3.4375}, {-0.7940909946267442, 3.5}, {-0.9157074104439394, 
       3.437499981032941}}], 
      PolygonBox[{{-0.9220580419731099, 3.5}, {-0.7940909946267442, 
       3.5}, {-0.9998944727795123, 3.4375}, {-0.9220580419731099, 3.5}}], 
      PolygonBox[{{-0.9998944727795123, 3.4375}, {-1.084292589556057, 
       3.437499981032941}, {-0.9220580419731099, 3.5}, {-0.9998944727795123, 
       3.4375}}], 
      PolygonBox[{{-1.2059090053044457`, 3.5}, {-0.9220580419731099, 
       3.5}, {-1.084292589556057, 3.437499981032941}, {-1.2059090053044457`, 
       3.5}}], PolygonBox[{{-1.084292589556057, 
       3.437499981032941}, {-1.230251642536255, 
       3.4373449933535234`}, {-1.2059090053044457`, 3.5}, {-1.084292589556057,
        3.437499981032941}}], 
      PolygonBox[{{-1.3576627826493661`, 3.5}, {-1.2059090053044457`, 
       3.5}, {-1.230251642536255, 3.4373449933535234`}, {-1.3576627826493661`,
        3.5}}], 
      PolygonBox[{{-1.230251642536255, 
       3.4373449933535234`}, {-1.4049427443329972`, 
       3.404942744332997}, {-1.3576627826493661`, 3.5}, {-1.230251642536255, 
       3.4373449933535234`}}], 
      PolygonBox[{{-0.5, 3.5}, {-1.3576627826493661`, 
       3.5}, {-1.4049427443329972`, 3.404942744332997}, {-0.5, 3.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       3.404942744332997}, {-1.4373449933535234`, 3.2302516425362553`}, {-0.5,
        3.5}, {-1.4049427443329972`, 3.404942744332997}}], 
      PolygonBox[{{-1.5, 3.357662782649369}, {-0.5, 
       3.5}, {-1.4373449933535234`, 3.2302516425362553`}, {-1.5, 
       3.357662782649369}}], 
      PolygonBox[{{-1.4373449933535234`, 
       3.2302516425362553`}, {-1.4374999810329407`, 
       3.0842925895560622`}, {-1.5, 3.357662782649369}, {-1.4373449933535234`,
        3.2302516425362553`}}], 
      PolygonBox[{{-1.5, 3.205909005282899}, {-1.5, 
       3.357662782649369}, {-1.4374999810329407`, 3.0842925895560622`}, {-1.5,
        3.205909005282899}}], 
      PolygonBox[{{-1.4374999810329407`, 3.0842925895560622`}, {-1.4375, 
       3.0001231780629953`}, {-1.5, 3.205909005282899}, {-1.4374999810329407`,
        3.0842925895560622`}}], 
      PolygonBox[{{-1.5, 3.0806786667587}, {-1.5, 
       3.205909005282899}, {-1.4375, 3.0001231780629953`}, {-1.5, 
       3.0806786667587}}], 
      PolygonBox[{{-1.4375, 3.0001231780629953`}, {-1.4374999810329407`, 
       2.915707410443945}, {-1.5, 3.0806786667587}, {-1.4375, 
       3.0001231780629953`}}], 
      PolygonBox[{{-1.5, 2.7940909948547215`}, {-1.5, 
       3.0806786667587}, {-1.4374999810329407`, 2.915707410443945}, {-1.5, 
       2.7940909948547215`}}], 
      PolygonBox[{{-1.4374999810329407`, 
       2.915707410443945}, {-1.4373449933535234`, 2.769748357463745}, {-1.5, 
       2.7940909948547215`}, {-1.4374999810329407`, 2.915707410443945}}], 
      PolygonBox[{{-1.5, 2.6423372173506348`}, {-1.5, 
       2.7940909948547215`}, {-1.4373449933535234`, 2.769748357463745}, {-1.5,
        2.6423372173506348`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       2.769748357463745}, {-1.4049427443329972`, 2.595057255667003}, {-1.5, 
       2.6423372173506348`}, {-1.4373449933535234`, 2.769748357463745}}], 
      PolygonBox[{{-1.5, 3.5}, {-1.5, 
       2.6423372173506348`}, {-1.4049427443329972`, 2.595057255667003}, {-1.5,
        3.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       2.595057255667003}, {-1.230251642536255, 2.5626550066464766`}, {-1.5, 
       3.5}, {-1.4049427443329972`, 2.595057255667003}}], 
      PolygonBox[{{-1.5, 2.5}, {-1.5, 3.5}, {-1.230251642536255, 
       2.5626550066464766`}, {-1.5, 2.5}}], 
      PolygonBox[{{-1.230251642536255, 
       2.5626550066464766`}, {-1.0842925895560642`, 2.562500018967059}, {-1.5,
        2.5}, {-1.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{-1.205909005566828, 2.5}, {-1.5, 
       2.5}, {-1.0842925895560642`, 2.562500018967059}, {-1.205909005566828, 
       2.5}}], PolygonBox[{{-1.0842925895560642`, 
       2.562500018967059}, {-0.999865158168957, 2.5625}, {-1.205909005566828, 
       2.5}, {-1.0842925895560642`, 2.562500018967059}}], 
      PolygonBox[{{-0.9176761295989384, 2.5}, {-1.205909005566828, 
       2.5}, {-0.999865158168957, 2.5625}, {-0.9176761295989384, 2.5}}], 
      PolygonBox[{{-0.999865158168957, 2.5625}, {-0.9157074104439469, 
       2.562500018967059}, {-0.9176761295989384, 2.5}, {-0.999865158168957, 
       2.5625}}], 
      PolygonBox[{{-0.7940909946396026, 2.5}, {-0.9176761295989384, 
       2.5}, {-0.9157074104439469, 2.562500018967059}, {-0.7940909946396026, 
       2.5}}], PolygonBox[{{-0.9157074104439469, 
       2.562500018967059}, {-0.7697483574637453, 
       2.5626550066464766`}, {-0.7940909946396026, 2.5}, {-0.9157074104439469,
        2.562500018967059}}], 
      PolygonBox[{{-0.642337217350629, 2.5}, {-0.7940909946396026, 
       2.5}, {-0.7697483574637453, 2.5626550066464766`}, {-0.642337217350629, 
       2.5}}], PolygonBox[{{-0.7697483574637453, 
       2.5626550066464766`}, {-0.5950572556670028, 
       2.595057255667003}, {-0.642337217350629, 2.5}, {-0.7697483574637453, 
       2.5626550066464766`}}], 
      PolygonBox[{{-0.5, 2.5}, {-0.642337217350629, 
       2.5}, {-0.5950572556670028, 2.595057255667003}, {-0.5, 2.5}}], 
      PolygonBox[{{-0.5950572556670028, 
       2.595057255667003}, {-0.5950572556670028, 2.595057255667003}, {-0.5, 
       2.5}, {-0.5950572556670028, 2.595057255667003}}], 
      PolygonBox[{{-0.5, 2.5}, {-0.5, 2.5}, {-0.5950572556670028, 
       2.595057255667003}, {-0.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, 4.}, {-1.4791666666666667`, 4.}, {-1.4583333333333333`, 
       4.}, {-1.4375, 4.}, {-1.4166666666666667`, 4.}, {-1.3958333333333335`, 
       4.}, {-1.375, 4.}, {-1.375, 4.}, {-1.3958333333333333`, 
       4.}, {-1.4166666666666667`, 4.}, {-1.4375, 4.}, {-1.4583333333333333`, 
       4.}, {-1.4791666666666665`, 4.}, {-1.5, 4.}, {-1.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, 4.}, {-0.6041666666666667, 4.}, {-0.5833333333333333, 
       4.}, {-0.5625, 4.}, {-0.5416666666666667, 4.}, {-0.5208333333333334, 
       4.}, {-0.5, 4.}, {-0.5, 4.}, {-0.5208333333333333, 
       4.}, {-0.5416666666666667, 4.}, {-0.5625, 4.}, {-0.5833333333333333, 
       4.}, {-0.6041666666666666, 4.}, {-0.625, 4.}, {-0.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 3.5}, {-1., 3.5208333333333335`}, {-1., 
       3.5416666666666665`}, {-1., 3.5625}, {-1., 3.5833333333333335`}, {-1., 
       3.6041666666666665`}, {-1., 3.625}, {-1., 3.625}, {-1., 
       3.6041666666666665`}, {-1., 3.5833333333333335`}, {-1., 3.5625}, {-1., 
       3.5416666666666665`}, {-1., 3.5208333333333335`}, {-1., 3.5}, {-1., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 4.375}, {-1., 4.395833333333333}, {-1., 
       4.416666666666667}, {-1., 4.4375}, {-1., 4.458333333333333}, {-1., 
       4.479166666666667}, {-1., 4.5}, {-1., 4.5}, {-1., 
       4.479166666666667}, {-1., 4.458333333333333}, {-1., 4.4375}, {-1., 
       4.416666666666667}, {-1., 4.395833333333333}, {-1., 4.375}, {-1., 
       4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, 4.}, {-1.25, 4.}, {-1.125, 4.}, {-1., 4.}, {-0.875, 
       4.}, {-0.75, 4.}, {-0.625, 4.}, {-0.625, 4.}, {-0.75, 4.}, {-0.875, 
       4.}, {-1., 4.}, {-1.125, 4.}, {-1.25, 4.}, {-1.375, 4.}, {-1.375, 
       4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 3.625}, {-1., 3.75}, {-1., 3.875}, {-1., 4.}, {-1., 
       4.125}, {-1., 4.25}, {-1., 4.375}, {-1., 4.375}, {-1., 4.25}, {-1., 
       4.125}, {-1., 4.}, {-1., 3.875}, {-1., 3.75}, {-1., 3.625}, {-1., 
       3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kNoAYeIHS6sazOe7Fcv6vyUlCzg4PD43ouJ
s59C5A8IOEz2nDDzSPPz/ee+nc1p5xd0gOh7tX+G8pNDvT6CDkfytmS/ePJm
/9eM8PhXRTD5DxD9DYIOc0+onuru/Ygm/xmu3+y2+WZZuy9w8xP6JnCbG32F
239lcWztytNf92tA3QfR/w3ufpj8Jum3UlaW/Kj6G/gczKHmpwqlqH18wOvA
CLX/wg7zqidpvA7zoe4T0wt01JbiRXU/A6/DMaj/YPJMUP/D9E+Bhg/MfEfk
8APaHwkN341Q96GHPwDll5bF
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNoIYdQMHgK568Cg1dwPoT+gCb/CU3/VzT1
PwjyIfoE4fzVYHMF0NQLoMnzwflhYP28aOp5MPhhKO7jcViN4n6Y+g9o8q/Q
9D9FU/+AID8UxX0P0Nz/AM1/D9D8/wAtfBDxBQBSamkR
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, 
       3.7348349570550448`}, {-0.6752404735808355, 
       3.8125}, {-0.5950572556670028, 
       3.595057255667003}, {-0.7348349570550446, 3.7348349570550448`}}], 
      PolygonBox[{{-0.5626550066464766, 
       3.7697483574637447`}, {-0.5950572556670028, 
       3.595057255667003}, {-0.6752404735808355, 
       3.8125}, {-0.5626550066464766, 3.7697483574637447`}}], 
      PolygonBox[{{-0.6752404735808355, 3.8125}, {-0.6377778151415994, 
       3.9029428580865546`}, {-0.5626550066464766, 
       3.7697483574637447`}, {-0.6752404735808355, 3.8125}}], 
      PolygonBox[{{-0.5625000189670593, 
       3.915707410443938}, {-0.5626550066464766, 
       3.7697483574637447`}, {-0.6377778151415994, 
       3.9029428580865546`}, {-0.5625000189670593, 3.915707410443938}}], 
      PolygonBox[{{-0.6377778151415994, 3.9029428580865546`}, {-0.625, 
       4.}, {-0.5625000189670593, 3.915707410443938}, {-0.6377778151415994, 
       3.9029428580865546`}}], 
      PolygonBox[{{-0.5625, 4.}, {-0.5625000189670593, 
       3.915707410443938}, {-0.625, 4.}, {-0.5625, 4.}}], 
      PolygonBox[{{-0.625, 4.}, {-0.6377778151415994, 
       4.097057141913445}, {-0.5625, 4.}, {-0.625, 4.}}], 
      PolygonBox[{{-0.5625000189670593, 4.084292589556061}, {-0.5625, 
       4.}, {-0.6377778151415994, 4.097057141913445}, {-0.5625000189670593, 
       4.084292589556061}}], 
      PolygonBox[{{-0.6377778151415994, 
       4.097057141913445}, {-0.6752404735808355, 
       4.1875}, {-0.5625000189670593, 
       4.084292589556061}, {-0.6377778151415994, 4.097057141913445}}], 
      PolygonBox[{{-0.5626550066464766, 
       4.230251642536255}, {-0.5625000189670593, 
       4.084292589556061}, {-0.6752404735808355, 
       4.1875}, {-0.5626550066464766, 4.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, 4.1875}, {-0.7348349570550446, 
       4.265165042944956}, {-0.5626550066464766, 
       4.230251642536255}, {-0.6752404735808355, 4.1875}}], 
      PolygonBox[{{-0.5950572556670028, 
       4.404942744332997}, {-0.5626550066464766, 
       4.230251642536255}, {-0.7348349570550446, 
       4.265165042944956}, {-0.5950572556670028, 4.404942744332997}}], 
      PolygonBox[{{-0.7348349570550446, 4.265165042944956}, {-0.8125, 
       4.3247595264191645`}, {-0.5950572556670028, 
       4.404942744332997}, {-0.7348349570550446, 4.265165042944956}}], 
      PolygonBox[{{-0.7697483574637448, 
       4.437344993353523}, {-0.5950572556670028, 4.404942744332997}, {-0.8125,
        4.3247595264191645`}, {-0.7697483574637448, 4.437344993353523}}], 
      PolygonBox[{{-0.8125, 4.3247595264191645`}, {-0.9029428580865546, 
       4.362222184858401}, {-0.7697483574637448, 4.437344993353523}, {-0.8125,
        4.3247595264191645`}}], 
      PolygonBox[{{-0.9157074104439394, 
       4.437499981032941}, {-0.7697483574637448, 
       4.437344993353523}, {-0.9029428580865546, 
       4.362222184858401}, {-0.9157074104439394, 4.437499981032941}}], 
      PolygonBox[{{-0.9029428580865546, 4.362222184858401}, {-1., 
       4.375}, {-0.9157074104439394, 4.437499981032941}, {-0.9029428580865546,
        4.362222184858401}}], 
      PolygonBox[{{-0.9998944727795123, 4.4375}, {-0.9157074104439394, 
       4.437499981032941}, {-1., 4.375}, {-0.9998944727795123, 4.4375}}], 
      PolygonBox[{{-1., 4.375}, {-1.0970571419134452`, 
       4.362222184858401}, {-0.9998944727795123, 4.4375}, {-1., 4.375}}], 
      PolygonBox[{{-1.084292589556057, 
       4.437499981032941}, {-0.9998944727795123, 
       4.4375}, {-1.0970571419134452`, 
       4.362222184858401}, {-1.084292589556057, 4.437499981032941}}], 
      PolygonBox[{{-1.0970571419134452`, 4.362222184858401}, {-1.1875, 
       4.3247595264191645`}, {-1.084292589556057, 
       4.437499981032941}, {-1.0970571419134452`, 4.362222184858401}}], 
      PolygonBox[{{-1.230251642536255, 
       4.437344993353523}, {-1.084292589556057, 4.437499981032941}, {-1.1875, 
       4.3247595264191645`}, {-1.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{-1.1875, 4.3247595264191645`}, {-1.2651650429449552`, 
       4.265165042944956}, {-1.230251642536255, 4.437344993353523}, {-1.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{-1.4049427443329972`, 
       4.404942744332997}, {-1.230251642536255, 
       4.437344993353523}, {-1.2651650429449552`, 
       4.265165042944956}, {-1.4049427443329972`, 4.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, 
       4.265165042944956}, {-1.3247595264191645`, 
       4.1875}, {-1.4049427443329972`, 
       4.404942744332997}, {-1.2651650429449552`, 4.265165042944956}}], 
      PolygonBox[{{-1.4373449933535234`, 
       4.230251642536255}, {-1.4049427443329972`, 
       4.404942744332997}, {-1.3247595264191645`, 
       4.1875}, {-1.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{-1.3247595264191645`, 4.1875}, {-1.3622221848584006`, 
       4.097057141913446}, {-1.4373449933535234`, 
       4.230251642536255}, {-1.3247595264191645`, 4.1875}}], 
      PolygonBox[{{-1.4374999810329407`, 
       4.084292589556062}, {-1.4373449933535234`, 
       4.230251642536255}, {-1.3622221848584006`, 
       4.097057141913446}, {-1.4374999810329407`, 4.084292589556062}}], 
      PolygonBox[{{-1.3622221848584006`, 4.097057141913446}, {-1.375, 
       4.}, {-1.4374999810329407`, 4.084292589556062}, {-1.3622221848584006`, 
       4.097057141913446}}], 
      PolygonBox[{{-1.4375, 4.000123178062996}, {-1.4374999810329407`, 
       4.084292589556062}, {-1.375, 4.}, {-1.4375, 4.000123178062996}}], 
      PolygonBox[{{-1.375, 4.}, {-1.3622221848584006`, 
       3.902942858086555}, {-1.4375, 4.000123178062996}, {-1.375, 4.}}], 
      PolygonBox[{{-1.4374999810329407`, 3.915707410443945}, {-1.4375, 
       4.000123178062996}, {-1.3622221848584006`, 
       3.902942858086555}, {-1.4374999810329407`, 3.915707410443945}}], 
      PolygonBox[{{-1.3622221848584006`, 
       3.902942858086555}, {-1.3247595264191645`, 
       3.8125}, {-1.4374999810329407`, 
       3.915707410443945}, {-1.3622221848584006`, 3.902942858086555}}], 
      PolygonBox[{{-1.4373449933535234`, 
       3.769748357463745}, {-1.4374999810329407`, 
       3.915707410443945}, {-1.3247595264191645`, 
       3.8125}, {-1.4373449933535234`, 3.769748357463745}}], 
      PolygonBox[{{-1.3247595264191645`, 3.8125}, {-1.2651650429449552`, 
       3.7348349570550448`}, {-1.4373449933535234`, 
       3.769748357463745}, {-1.3247595264191645`, 3.8125}}], 
      PolygonBox[{{-1.4049427443329972`, 
       3.595057255667003}, {-1.4373449933535234`, 
       3.769748357463745}, {-1.2651650429449552`, 
       3.7348349570550448`}, {-1.4049427443329972`, 3.595057255667003}}], 
      PolygonBox[{{-1.2651650429449552`, 
       3.7348349570550448`}, {-1.1875000000000002`, 
       3.6752404735808355`}, {-1.4049427443329972`, 
       3.595057255667003}, {-1.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{-1.230251642536255, 
       3.5626550066464766`}, {-1.4049427443329972`, 
       3.595057255667003}, {-1.1875000000000002`, 
       3.6752404735808355`}, {-1.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-1.1875000000000002`, 
       3.6752404735808355`}, {-1.0970571419134456`, 
       3.6377778151415994`}, {-1.230251642536255, 
       3.5626550066464766`}, {-1.1875000000000002`, 3.6752404735808355`}}], 
      PolygonBox[{{-1.0842925895560642`, 
       3.562500018967059}, {-1.230251642536255, 
       3.5626550066464766`}, {-1.0970571419134456`, 
       3.6377778151415994`}, {-1.0842925895560642`, 3.562500018967059}}], 
      PolygonBox[{{-1.0970571419134456`, 
       3.6377778151415994`}, {-0.9999999999999999, 
       3.625}, {-1.0842925895560642`, 
       3.562500018967059}, {-1.0970571419134456`, 3.6377778151415994`}}], 
      PolygonBox[{{-0.999865158168957, 3.5625}, {-1.0842925895560642`, 
       3.562500018967059}, {-0.9999999999999999, 3.625}, {-0.999865158168957, 
       3.5625}}], 
      PolygonBox[{{-0.9999999999999999, 3.625}, {-0.9029428580865548, 
       3.6377778151415994`}, {-0.999865158168957, 
       3.5625}, {-0.9999999999999999, 3.625}}], 
      PolygonBox[{{-0.9157074104439469, 
       3.562500018967059}, {-0.999865158168957, 3.5625}, {-0.9029428580865548,
        3.6377778151415994`}, {-0.9157074104439469, 3.562500018967059}}], 
      PolygonBox[{{-0.9029428580865548, 
       3.6377778151415994`}, {-0.8125000000000002, 
       3.6752404735808355`}, {-0.9157074104439469, 
       3.562500018967059}, {-0.9029428580865548, 3.6377778151415994`}}], 
      PolygonBox[{{-0.7697483574637453, 
       3.5626550066464766`}, {-0.9157074104439469, 
       3.562500018967059}, {-0.8125000000000002, 
       3.6752404735808355`}, {-0.7697483574637453, 3.5626550066464766`}}], 
      PolygonBox[{{-0.8125000000000002, 
       3.6752404735808355`}, {-0.7348349570550448, 
       3.7348349570550448`}, {-0.7697483574637453, 
       3.5626550066464766`}, {-0.8125000000000002, 3.6752404735808355`}}], 
      PolygonBox[{{-0.5950572556670028, 
       3.595057255667003}, {-0.7697483574637453, 
       3.5626550066464766`}, {-0.7348349570550448, 
       3.7348349570550448`}, {-0.5950572556670028, 3.595057255667003}}], 
      PolygonBox[{{-0.7348349570550448, 
       3.7348349570550448`}, {-0.7348349570550446, 
       3.7348349570550448`}, {-0.5950572556670028, 
       3.595057255667003}, {-0.7348349570550448, 3.7348349570550448`}}], 
      PolygonBox[{{-0.5950572556670028, 
       3.595057255667003}, {-0.5950572556670028, 
       3.595057255667003}, {-0.7348349570550446, 
       3.7348349570550448`}, {-0.5950572556670028, 3.595057255667003}}], 
      PolygonBox[{{-0.5950572556670028, 
       3.595057255667003}, {-0.5626550066464766, 3.7697483574637447`}, {-0.5, 
       3.5}, {-0.5950572556670028, 3.595057255667003}}], 
      PolygonBox[{{-0.5, 3.642337217350632}, {-0.5, 
       3.5}, {-0.5626550066464766, 3.7697483574637447`}, {-0.5, 
       3.642337217350632}}], 
      PolygonBox[{{-0.5626550066464766, 
       3.7697483574637447`}, {-0.5625000189670593, 3.915707410443938}, {-0.5, 
       3.642337217350632}, {-0.5626550066464766, 3.7697483574637447`}}], 
      PolygonBox[{{-0.5, 3.79409099469826}, {-0.5, 
       3.642337217350632}, {-0.5625000189670593, 3.915707410443938}, {-0.5, 
       3.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, 3.915707410443938}, {-0.5625, 
       4.}, {-0.5, 3.79409099469826}, {-0.5625000189670593, 
       3.915707410443938}}], 
      PolygonBox[{{-0.5, 4.}, {-0.5, 3.79409099469826}, {-0.5625, 4.}, {-0.5, 
       4.}}], PolygonBox[{{-0.5625, 4.}, {-0.5625000189670593, 
       4.084292589556061}, {-0.5, 4.}, {-0.5625, 4.}}], 
      PolygonBox[{{-0.5, 4.20590900530174}, {-0.5, 4.}, {-0.5625000189670593, 
       4.084292589556061}, {-0.5, 4.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, 
       4.084292589556061}, {-0.5626550066464766, 4.230251642536255}, {-0.5, 
       4.20590900530174}, {-0.5625000189670593, 4.084292589556061}}], 
      PolygonBox[{{-0.5, 4.357662782649368}, {-0.5, 
       4.20590900530174}, {-0.5626550066464766, 4.230251642536255}, {-0.5, 
       4.357662782649368}}], 
      PolygonBox[{{-0.5626550066464766, 
       4.230251642536255}, {-0.5950572556670028, 4.404942744332997}, {-0.5, 
       4.357662782649368}, {-0.5626550066464766, 4.230251642536255}}], 
      PolygonBox[{{-0.508553435038814, 4.491446564961186}, {-0.5, 
       4.357662782649368}, {-0.5950572556670028, 
       4.404942744332997}, {-0.508553435038814, 4.491446564961186}}], 
      PolygonBox[{{-0.5950572556670028, 
       4.404942744332997}, {-0.7697483574637448, 
       4.437344993353523}, {-0.508553435038814, 
       4.491446564961186}, {-0.5950572556670028, 4.404942744332997}}], 
      PolygonBox[{{-0.6423372173506319, 4.5}, {-0.508553435038814, 
       4.491446564961186}, {-0.7697483574637448, 
       4.437344993353523}, {-0.6423372173506319, 4.5}}], 
      PolygonBox[{{-0.7697483574637448, 
       4.437344993353523}, {-0.9157074104439394, 
       4.437499981032941}, {-0.6423372173506319, 4.5}, {-0.7697483574637448, 
       4.437344993353523}}], 
      PolygonBox[{{-0.7940909946267442, 4.5}, {-0.6423372173506319, 
       4.5}, {-0.9157074104439394, 4.437499981032941}, {-0.7940909946267442, 
       4.5}}], PolygonBox[{{-0.9157074104439394, 
       4.437499981032941}, {-0.9998944727795123, 
       4.4375}, {-0.7940909946267442, 4.5}, {-0.9157074104439394, 
       4.437499981032941}}], 
      PolygonBox[{{-0.9220580419731099, 4.5}, {-0.7940909946267442, 
       4.5}, {-0.9998944727795123, 4.4375}, {-0.9220580419731099, 4.5}}], 
      PolygonBox[{{-0.9998944727795123, 4.4375}, {-1.084292589556057, 
       4.437499981032941}, {-0.9220580419731099, 4.5}, {-0.9998944727795123, 
       4.4375}}], 
      PolygonBox[{{-1.2059090053044457`, 4.5}, {-0.9220580419731099, 
       4.5}, {-1.084292589556057, 4.437499981032941}, {-1.2059090053044457`, 
       4.5}}], PolygonBox[{{-1.084292589556057, 
       4.437499981032941}, {-1.230251642536255, 
       4.437344993353523}, {-1.2059090053044457`, 4.5}, {-1.084292589556057, 
       4.437499981032941}}], 
      PolygonBox[{{-1.3576627826493661`, 4.5}, {-1.2059090053044457`, 
       4.5}, {-1.230251642536255, 4.437344993353523}, {-1.3576627826493661`, 
       4.5}}], PolygonBox[{{-1.230251642536255, 
       4.437344993353523}, {-1.4049427443329972`, 
       4.404942744332997}, {-1.3576627826493661`, 4.5}, {-1.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{-0.5, 4.5}, {-1.3576627826493661`, 
       4.5}, {-1.4049427443329972`, 4.404942744332997}, {-0.5, 4.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       4.404942744332997}, {-1.4373449933535234`, 4.230251642536255}, {-0.5, 
       4.5}, {-1.4049427443329972`, 4.404942744332997}}], 
      PolygonBox[{{-1.5, 4.357662782649369}, {-0.5, 
       4.5}, {-1.4373449933535234`, 4.230251642536255}, {-1.5, 
       4.357662782649369}}], 
      PolygonBox[{{-1.4373449933535234`, 
       4.230251642536255}, {-1.4374999810329407`, 4.084292589556062}, {-1.5, 
       4.357662782649369}, {-1.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{-1.5, 4.205909005282899}, {-1.5, 
       4.357662782649369}, {-1.4374999810329407`, 4.084292589556062}, {-1.5, 
       4.205909005282899}}], 
      PolygonBox[{{-1.4374999810329407`, 4.084292589556062}, {-1.4375, 
       4.000123178062996}, {-1.5, 4.205909005282899}, {-1.4374999810329407`, 
       4.084292589556062}}], 
      PolygonBox[{{-1.5, 4.0806786667587005`}, {-1.5, 
       4.205909005282899}, {-1.4375, 4.000123178062996}, {-1.5, 
       4.0806786667587005`}}], 
      PolygonBox[{{-1.4375, 4.000123178062996}, {-1.4374999810329407`, 
       3.915707410443945}, {-1.5, 4.0806786667587005`}, {-1.4375, 
       4.000123178062996}}], 
      PolygonBox[{{-1.5, 3.7940909948547215`}, {-1.5, 
       4.0806786667587005`}, {-1.4374999810329407`, 3.915707410443945}, {-1.5,
        3.7940909948547215`}}], 
      PolygonBox[{{-1.4374999810329407`, 
       3.915707410443945}, {-1.4373449933535234`, 3.769748357463745}, {-1.5, 
       3.7940909948547215`}, {-1.4374999810329407`, 3.915707410443945}}], 
      PolygonBox[{{-1.5, 3.6423372173506348`}, {-1.5, 
       3.7940909948547215`}, {-1.4373449933535234`, 3.769748357463745}, {-1.5,
        3.6423372173506348`}}], 
      PolygonBox[{{-1.4373449933535234`, 
       3.769748357463745}, {-1.4049427443329972`, 3.595057255667003}, {-1.5, 
       3.6423372173506348`}, {-1.4373449933535234`, 3.769748357463745}}], 
      PolygonBox[{{-1.5, 4.5}, {-1.5, 
       3.6423372173506348`}, {-1.4049427443329972`, 3.595057255667003}, {-1.5,
        4.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       3.595057255667003}, {-1.230251642536255, 3.5626550066464766`}, {-1.5, 
       4.5}, {-1.4049427443329972`, 3.595057255667003}}], 
      PolygonBox[{{-1.5, 3.5}, {-1.5, 4.5}, {-1.230251642536255, 
       3.5626550066464766`}, {-1.5, 3.5}}], 
      PolygonBox[{{-1.230251642536255, 
       3.5626550066464766`}, {-1.0842925895560642`, 3.562500018967059}, {-1.5,
        3.5}, {-1.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{-1.205909005566828, 3.5}, {-1.5, 
       3.5}, {-1.0842925895560642`, 3.562500018967059}, {-1.205909005566828, 
       3.5}}], PolygonBox[{{-1.0842925895560642`, 
       3.562500018967059}, {-0.999865158168957, 3.5625}, {-1.205909005566828, 
       3.5}, {-1.0842925895560642`, 3.562500018967059}}], 
      PolygonBox[{{-0.9176761295989384, 3.5}, {-1.205909005566828, 
       3.5}, {-0.999865158168957, 3.5625}, {-0.9176761295989384, 3.5}}], 
      PolygonBox[{{-0.999865158168957, 3.5625}, {-0.9157074104439469, 
       3.562500018967059}, {-0.9176761295989384, 3.5}, {-0.999865158168957, 
       3.5625}}], 
      PolygonBox[{{-0.7940909946396026, 3.5}, {-0.9176761295989384, 
       3.5}, {-0.9157074104439469, 3.562500018967059}, {-0.7940909946396026, 
       3.5}}], PolygonBox[{{-0.9157074104439469, 
       3.562500018967059}, {-0.7697483574637453, 
       3.5626550066464766`}, {-0.7940909946396026, 3.5}, {-0.9157074104439469,
        3.562500018967059}}], 
      PolygonBox[{{-0.642337217350629, 3.5}, {-0.7940909946396026, 
       3.5}, {-0.7697483574637453, 3.5626550066464766`}, {-0.642337217350629, 
       3.5}}], PolygonBox[{{-0.7697483574637453, 
       3.5626550066464766`}, {-0.5950572556670028, 
       3.595057255667003}, {-0.642337217350629, 3.5}, {-0.7697483574637453, 
       3.5626550066464766`}}], 
      PolygonBox[{{-0.5, 3.5}, {-0.642337217350629, 
       3.5}, {-0.5950572556670028, 3.595057255667003}, {-0.5, 3.5}}], 
      PolygonBox[{{-0.5950572556670028, 
       3.595057255667003}, {-0.5950572556670028, 3.595057255667003}, {-0.5, 
       3.5}, {-0.5950572556670028, 3.595057255667003}}], 
      PolygonBox[{{-0.5, 3.5}, {-0.5, 3.5}, {-0.5950572556670028, 
       3.595057255667003}, {-0.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5, 5.}, {-1.4791666666666667`, 5.}, {-1.4583333333333333`, 
       5.}, {-1.4375, 5.}, {-1.4166666666666667`, 5.}, {-1.3958333333333335`, 
       5.}, {-1.375, 5.}, {-1.375, 5.}, {-1.3958333333333333`, 
       5.}, {-1.4166666666666667`, 5.}, {-1.4375, 5.}, {-1.4583333333333333`, 
       5.}, {-1.4791666666666665`, 5.}, {-1.5, 5.}, {-1.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.625, 5.}, {-0.6041666666666667, 5.}, {-0.5833333333333333, 
       5.}, {-0.5625, 5.}, {-0.5416666666666667, 5.}, {-0.5208333333333334, 
       5.}, {-0.5, 5.}, {-0.5, 5.}, {-0.5208333333333333, 
       5.}, {-0.5416666666666667, 5.}, {-0.5625, 5.}, {-0.5833333333333333, 
       5.}, {-0.6041666666666666, 5.}, {-0.625, 5.}, {-0.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 4.5}, {-1., 4.520833333333333}, {-1., 
       4.541666666666667}, {-1., 4.5625}, {-1., 4.583333333333333}, {-1., 
       4.604166666666667}, {-1., 4.625}, {-1., 4.625}, {-1., 
       4.604166666666667}, {-1., 4.583333333333333}, {-1., 4.5625}, {-1., 
       4.541666666666667}, {-1., 4.520833333333333}, {-1., 4.5}, {-1., 
       4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 5.375}, {-1., 5.395833333333333}, {-1., 
       5.416666666666667}, {-1., 5.4375}, {-1., 5.458333333333333}, {-1., 
       5.479166666666667}, {-1., 5.5}, {-1., 5.5}, {-1., 
       5.479166666666667}, {-1., 5.458333333333333}, {-1., 5.4375}, {-1., 
       5.416666666666667}, {-1., 5.395833333333333}, {-1., 5.375}, {-1., 
       5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.375, 5.}, {-1.25, 5.}, {-1.125, 5.}, {-1., 5.}, {-0.875, 
       5.}, {-0.75, 5.}, {-0.625, 5.}, {-0.625, 5.}, {-0.75, 5.}, {-0.875, 
       5.}, {-1., 5.}, {-1.125, 5.}, {-1.25, 5.}, {-1.375, 5.}, {-1.375, 
       5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., 4.625}, {-1., 4.75}, {-1., 4.875}, {-1., 5.}, {-1., 
       5.125}, {-1., 5.25}, {-1., 5.375}, {-1., 5.375}, {-1., 5.25}, {-1., 
       5.125}, {-1., 5.}, {-1., 4.875}, {-1., 4.75}, {-1., 4.625}, {-1., 
       4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQFP9kNoEYeIHS6sazOe7Fcv6vyUlCzi4PD43ouJ
s59C5A+IOEz2nDDzSPPz/ee+nc1p5xd1gOh7tX+G8pNDvT6iDkfytmS/ePJm
/9eM8PhXRTD5DxD9DaIOc0+onuru/Ygm/xmu3+y2+WZZuy9w8xP6JnCbG32F
239lcWztytNf92tA3QfR/w3ufpj8zd4y3rlzhFH1Owg7mEPNN+Y0mlzxQciB
EWp/xh1p26LNQg7zoe7jnr5igWivEJr7hRyOQf0Hk2eC+h+mfwo0fIyg5jsi
hx/Q/kho+N6Aug89/AEVOZlz
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP9kNoMYdQMHgK568Cg1dwPoT+gCb/CU3/VzT1
PwjyIfpE4fzVYHNF0NSLoKkXRlMvhKYekx+G4j4hh9Uo7oep/4Am/wpN/1M0
9Q8I8lHd9wDN/Q/Q/PcAzf8P0MIHEV8Avr5plg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{-0.7348349570550446, 
       4.734834957055044}, {-0.6752404735808355, 
       4.8125}, {-0.5950572556670028, 
       4.595057255667003}, {-0.7348349570550446, 4.734834957055044}}], 
      PolygonBox[{{-0.5626550066464766, 
       4.769748357463745}, {-0.5950572556670028, 
       4.595057255667003}, {-0.6752404735808355, 
       4.8125}, {-0.5626550066464766, 4.769748357463745}}], 
      PolygonBox[{{-0.6752404735808355, 4.8125}, {-0.6377778151415994, 
       4.902942858086555}, {-0.5626550066464766, 
       4.769748357463745}, {-0.6752404735808355, 4.8125}}], 
      PolygonBox[{{-0.5625000189670593, 
       4.915707410443938}, {-0.5626550066464766, 
       4.769748357463745}, {-0.6377778151415994, 
       4.902942858086555}, {-0.5625000189670593, 4.915707410443938}}], 
      PolygonBox[{{-0.6377778151415994, 4.902942858086555}, {-0.625, 
       5.}, {-0.5625000189670593, 4.915707410443938}, {-0.6377778151415994, 
       4.902942858086555}}], 
      PolygonBox[{{-0.5625, 5.}, {-0.5625000189670593, 
       4.915707410443938}, {-0.625, 5.}, {-0.5625, 5.}}], 
      PolygonBox[{{-0.625, 5.}, {-0.6377778151415994, 
       5.097057141913445}, {-0.5625, 5.}, {-0.625, 5.}}], 
      PolygonBox[{{-0.5625000189670593, 5.084292589556061}, {-0.5625, 
       5.}, {-0.6377778151415994, 5.097057141913445}, {-0.5625000189670593, 
       5.084292589556061}}], 
      PolygonBox[{{-0.6377778151415994, 
       5.097057141913445}, {-0.6752404735808355, 
       5.1875}, {-0.5625000189670593, 
       5.084292589556061}, {-0.6377778151415994, 5.097057141913445}}], 
      PolygonBox[{{-0.5626550066464766, 
       5.230251642536255}, {-0.5625000189670593, 
       5.084292589556061}, {-0.6752404735808355, 
       5.1875}, {-0.5626550066464766, 5.230251642536255}}], 
      PolygonBox[{{-0.6752404735808355, 5.1875}, {-0.7348349570550446, 
       5.265165042944956}, {-0.5626550066464766, 
       5.230251642536255}, {-0.6752404735808355, 5.1875}}], 
      PolygonBox[{{-0.5950572556670028, 
       5.404942744332997}, {-0.5626550066464766, 
       5.230251642536255}, {-0.7348349570550446, 
       5.265165042944956}, {-0.5950572556670028, 5.404942744332997}}], 
      PolygonBox[{{-0.7348349570550446, 5.265165042944956}, {-0.8125, 
       5.3247595264191645`}, {-0.5950572556670028, 
       5.404942744332997}, {-0.7348349570550446, 5.265165042944956}}], 
      PolygonBox[{{-0.7697483574637448, 
       5.437344993353523}, {-0.5950572556670028, 5.404942744332997}, {-0.8125,
        5.3247595264191645`}, {-0.7697483574637448, 5.437344993353523}}], 
      PolygonBox[{{-0.8125, 5.3247595264191645`}, {-0.9029428580865546, 
       5.362222184858401}, {-0.7697483574637448, 5.437344993353523}, {-0.8125,
        5.3247595264191645`}}], 
      PolygonBox[{{-0.9157074104439394, 
       5.437499981032941}, {-0.7697483574637448, 
       5.437344993353523}, {-0.9029428580865546, 
       5.362222184858401}, {-0.9157074104439394, 5.437499981032941}}], 
      PolygonBox[{{-0.9029428580865546, 5.362222184858401}, {-1., 
       5.375}, {-0.9157074104439394, 5.437499981032941}, {-0.9029428580865546,
        5.362222184858401}}], 
      PolygonBox[{{-0.9998944727795123, 5.4375}, {-0.9157074104439394, 
       5.437499981032941}, {-1., 5.375}, {-0.9998944727795123, 5.4375}}], 
      PolygonBox[{{-1., 5.375}, {-1.0970571419134452`, 
       5.362222184858401}, {-0.9998944727795123, 5.4375}, {-1., 5.375}}], 
      PolygonBox[{{-1.084292589556057, 
       5.437499981032941}, {-0.9998944727795123, 
       5.4375}, {-1.0970571419134452`, 
       5.362222184858401}, {-1.084292589556057, 5.437499981032941}}], 
      PolygonBox[{{-1.0970571419134452`, 5.362222184858401}, {-1.1875, 
       5.3247595264191645`}, {-1.084292589556057, 
       5.437499981032941}, {-1.0970571419134452`, 5.362222184858401}}], 
      PolygonBox[{{-1.230251642536255, 
       5.437344993353523}, {-1.084292589556057, 5.437499981032941}, {-1.1875, 
       5.3247595264191645`}, {-1.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{-1.1875, 5.3247595264191645`}, {-1.2651650429449552`, 
       5.265165042944956}, {-1.230251642536255, 5.437344993353523}, {-1.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{-1.4049427443329972`, 
       5.404942744332997}, {-1.230251642536255, 
       5.437344993353523}, {-1.2651650429449552`, 
       5.265165042944956}, {-1.4049427443329972`, 5.404942744332997}}], 
      PolygonBox[{{-1.2651650429449552`, 
       5.265165042944956}, {-1.3247595264191645`, 
       5.1875}, {-1.4049427443329972`, 
       5.404942744332997}, {-1.2651650429449552`, 5.265165042944956}}], 
      PolygonBox[{{-1.4373449933535234`, 
       5.230251642536255}, {-1.4049427443329972`, 
       5.404942744332997}, {-1.3247595264191645`, 
       5.1875}, {-1.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{-1.3247595264191645`, 5.1875}, {-1.3622221848584006`, 
       5.097057141913446}, {-1.4373449933535234`, 
       5.230251642536255}, {-1.3247595264191645`, 5.1875}}], 
      PolygonBox[{{-1.4374999810329407`, 
       5.084292589556062}, {-1.4373449933535234`, 
       5.230251642536255}, {-1.3622221848584006`, 
       5.097057141913446}, {-1.4374999810329407`, 5.084292589556062}}], 
      PolygonBox[{{-1.3622221848584006`, 5.097057141913446}, {-1.375, 
       5.}, {-1.4374999810329407`, 5.084292589556062}, {-1.3622221848584006`, 
       5.097057141913446}}], 
      PolygonBox[{{-1.4375, 5.000123178062996}, {-1.4374999810329407`, 
       5.084292589556062}, {-1.375, 5.}, {-1.4375, 5.000123178062996}}], 
      PolygonBox[{{-1.375, 5.}, {-1.3622221848584006`, 
       4.902942858086555}, {-1.4375, 5.000123178062996}, {-1.375, 5.}}], 
      PolygonBox[{{-1.4374999810329407`, 4.915707410443945}, {-1.4375, 
       5.000123178062996}, {-1.3622221848584006`, 
       4.902942858086555}, {-1.4374999810329407`, 4.915707410443945}}], 
      PolygonBox[{{-1.3622221848584006`, 
       4.902942858086555}, {-1.3247595264191645`, 
       4.8125}, {-1.4374999810329407`, 
       4.915707410443945}, {-1.3622221848584006`, 4.902942858086555}}], 
      PolygonBox[{{-1.4373449933535234`, 
       4.769748357463746}, {-1.4374999810329407`, 
       4.915707410443945}, {-1.3247595264191645`, 
       4.8125}, {-1.4373449933535234`, 4.769748357463746}}], 
      PolygonBox[{{-1.3247595264191645`, 4.8125}, {-1.2651650429449552`, 
       4.734834957055044}, {-1.4373449933535234`, 
       4.769748357463746}, {-1.3247595264191645`, 4.8125}}], 
      PolygonBox[{{-1.4049427443329972`, 
       4.595057255667003}, {-1.4373449933535234`, 
       4.769748357463746}, {-1.2651650429449552`, 
       4.734834957055044}, {-1.4049427443329972`, 4.595057255667003}}], 
      PolygonBox[{{-1.2651650429449552`, 
       4.734834957055044}, {-1.1875000000000002`, 
       4.6752404735808355`}, {-1.4049427443329972`, 
       4.595057255667003}, {-1.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{-1.230251642536255, 
       4.562655006646477}, {-1.4049427443329972`, 
       4.595057255667003}, {-1.1875000000000002`, 
       4.6752404735808355`}, {-1.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-1.1875000000000002`, 
       4.6752404735808355`}, {-1.0970571419134456`, 
       4.637777815141599}, {-1.230251642536255, 
       4.562655006646477}, {-1.1875000000000002`, 4.6752404735808355`}}], 
      PolygonBox[{{-1.0842925895560642`, 
       4.562500018967059}, {-1.230251642536255, 
       4.562655006646477}, {-1.0970571419134456`, 
       4.637777815141599}, {-1.0842925895560642`, 4.562500018967059}}], 
      PolygonBox[{{-1.0970571419134456`, 
       4.637777815141599}, {-0.9999999999999999, 
       4.625}, {-1.0842925895560642`, 
       4.562500018967059}, {-1.0970571419134456`, 4.637777815141599}}], 
      PolygonBox[{{-0.999865158168957, 4.5625}, {-1.0842925895560642`, 
       4.562500018967059}, {-0.9999999999999999, 4.625}, {-0.999865158168957, 
       4.5625}}], 
      PolygonBox[{{-0.9999999999999999, 4.625}, {-0.9029428580865548, 
       4.637777815141599}, {-0.999865158168957, 4.5625}, {-0.9999999999999999,
        4.625}}], 
      PolygonBox[{{-0.9157074104439469, 
       4.562500018967059}, {-0.999865158168957, 4.5625}, {-0.9029428580865548,
        4.637777815141599}, {-0.9157074104439469, 4.562500018967059}}], 
      PolygonBox[{{-0.9029428580865548, 
       4.637777815141599}, {-0.8125000000000002, 
       4.6752404735808355`}, {-0.9157074104439469, 
       4.562500018967059}, {-0.9029428580865548, 4.637777815141599}}], 
      PolygonBox[{{-0.7697483574637453, 
       4.562655006646477}, {-0.9157074104439469, 
       4.562500018967059}, {-0.8125000000000002, 
       4.6752404735808355`}, {-0.7697483574637453, 4.562655006646477}}], 
      PolygonBox[{{-0.8125000000000002, 
       4.6752404735808355`}, {-0.7348349570550448, 
       4.734834957055044}, {-0.7697483574637453, 
       4.562655006646477}, {-0.8125000000000002, 4.6752404735808355`}}], 
      PolygonBox[{{-0.5950572556670028, 
       4.595057255667003}, {-0.7697483574637453, 
       4.562655006646477}, {-0.7348349570550448, 
       4.734834957055044}, {-0.5950572556670028, 4.595057255667003}}], 
      PolygonBox[{{-0.7348349570550448, 
       4.734834957055044}, {-0.7348349570550446, 
       4.734834957055044}, {-0.5950572556670028, 
       4.595057255667003}, {-0.7348349570550448, 4.734834957055044}}], 
      PolygonBox[{{-0.5950572556670028, 
       4.595057255667003}, {-0.5950572556670028, 
       4.595057255667003}, {-0.7348349570550446, 
       4.734834957055044}, {-0.5950572556670028, 4.595057255667003}}], 
      PolygonBox[{{-0.5950572556670028, 
       4.595057255667003}, {-0.5626550066464766, 4.769748357463745}, {-0.5, 
       4.5}, {-0.5950572556670028, 4.595057255667003}}], 
      PolygonBox[{{-0.5, 4.642337217350632}, {-0.5, 
       4.5}, {-0.5626550066464766, 4.769748357463745}, {-0.5, 
       4.642337217350632}}], 
      PolygonBox[{{-0.5626550066464766, 
       4.769748357463745}, {-0.5625000189670593, 4.915707410443938}, {-0.5, 
       4.642337217350632}, {-0.5626550066464766, 4.769748357463745}}], 
      PolygonBox[{{-0.5, 4.79409099469826}, {-0.5, 
       4.642337217350632}, {-0.5625000189670593, 4.915707410443938}, {-0.5, 
       4.79409099469826}}], 
      PolygonBox[{{-0.5625000189670593, 4.915707410443938}, {-0.5625, 
       5.}, {-0.5, 4.79409099469826}, {-0.5625000189670593, 
       4.915707410443938}}], 
      PolygonBox[{{-0.5, 5.}, {-0.5, 4.79409099469826}, {-0.5625, 5.}, {-0.5, 
       5.}}], 
      PolygonBox[{{-0.5625, 5.}, {-0.5625000189670593, 
       5.084292589556061}, {-0.5, 5.}, {-0.5625, 5.}}], 
      PolygonBox[{{-0.5, 5.20590900530174}, {-0.5, 5.}, {-0.5625000189670593, 
       5.084292589556061}, {-0.5, 5.20590900530174}}], 
      PolygonBox[{{-0.5625000189670593, 
       5.084292589556061}, {-0.5626550066464766, 5.230251642536255}, {-0.5, 
       5.20590900530174}, {-0.5625000189670593, 5.084292589556061}}], 
      PolygonBox[{{-0.5, 5.357662782649368}, {-0.5, 
       5.20590900530174}, {-0.5626550066464766, 5.230251642536255}, {-0.5, 
       5.357662782649368}}], 
      PolygonBox[{{-0.5626550066464766, 
       5.230251642536255}, {-0.5950572556670028, 5.404942744332997}, {-0.5, 
       5.357662782649368}, {-0.5626550066464766, 5.230251642536255}}], 
      PolygonBox[{{-0.508553435038814, 5.491446564961186}, {-0.5, 
       5.357662782649368}, {-0.5950572556670028, 
       5.404942744332997}, {-0.508553435038814, 5.491446564961186}}], 
      PolygonBox[{{-0.5950572556670028, 
       5.404942744332997}, {-0.7697483574637448, 
       5.437344993353523}, {-0.508553435038814, 
       5.491446564961186}, {-0.5950572556670028, 5.404942744332997}}], 
      PolygonBox[{{-0.6423372173506319, 5.5}, {-0.508553435038814, 
       5.491446564961186}, {-0.7697483574637448, 
       5.437344993353523}, {-0.6423372173506319, 5.5}}], 
      PolygonBox[{{-0.7697483574637448, 
       5.437344993353523}, {-0.9157074104439394, 
       5.437499981032941}, {-0.6423372173506319, 5.5}, {-0.7697483574637448, 
       5.437344993353523}}], 
      PolygonBox[{{-0.7940909946267442, 5.5}, {-0.6423372173506319, 
       5.5}, {-0.9157074104439394, 5.437499981032941}, {-0.7940909946267442, 
       5.5}}], PolygonBox[{{-0.9157074104439394, 
       5.437499981032941}, {-0.9998944727795123, 
       5.4375}, {-0.7940909946267442, 5.5}, {-0.9157074104439394, 
       5.437499981032941}}], 
      PolygonBox[{{-0.9220580419731099, 5.5}, {-0.7940909946267442, 
       5.5}, {-0.9998944727795123, 5.4375}, {-0.9220580419731099, 5.5}}], 
      PolygonBox[{{-0.9998944727795123, 5.4375}, {-1.084292589556057, 
       5.437499981032941}, {-0.9220580419731099, 5.5}, {-0.9998944727795123, 
       5.4375}}], 
      PolygonBox[{{-1.2059090053044457`, 5.5}, {-0.9220580419731099, 
       5.5}, {-1.084292589556057, 5.437499981032941}, {-1.2059090053044457`, 
       5.5}}], PolygonBox[{{-1.084292589556057, 
       5.437499981032941}, {-1.230251642536255, 
       5.437344993353523}, {-1.2059090053044457`, 5.5}, {-1.084292589556057, 
       5.437499981032941}}], 
      PolygonBox[{{-1.3576627826493661`, 5.5}, {-1.2059090053044457`, 
       5.5}, {-1.230251642536255, 5.437344993353523}, {-1.3576627826493661`, 
       5.5}}], PolygonBox[{{-1.230251642536255, 
       5.437344993353523}, {-1.4049427443329972`, 
       5.404942744332997}, {-1.3576627826493661`, 5.5}, {-1.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{-0.5, 5.5}, {-1.3576627826493661`, 
       5.5}, {-1.4049427443329972`, 5.404942744332997}, {-0.5, 5.5}}], 
      PolygonBox[{{-1.4049427443329972`, 
       5.404942744332997}, {-1.4373449933535234`, 5.230251642536255}, {-0.5, 
       5.5}, {-1.4049427443329972`, 5.404942744332997}}], 
      PolygonBox[{{-1.5, 5.357662782649369}, {-0.5, 
       5.5}, {-1.4373449933535234`, 5.230251642536255}, {-1.5, 
       5.357662782649369}}], 
      PolygonBox[{{-1.4373449933535234`, 
       5.230251642536255}, {-1.4374999810329407`, 5.084292589556062}, {-1.5, 
       5.357662782649369}, {-1.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{-1.5, 5.205909005282899}, {-1.5, 
       5.357662782649369}, {-1.4374999810329407`, 5.084292589556062}, {-1.5, 
       5.205909005282899}}], 
      PolygonBox[{{-1.4374999810329407`, 5.084292589556062}, {-1.4375, 
       5.000123178062996}, {-1.5, 5.205909005282899}, {-1.4374999810329407`, 
       5.084292589556062}}], 
      PolygonBox[{{-1.5, 5.0806786667587005`}, {-1.5, 
       5.205909005282899}, {-1.4375, 5.000123178062996}, {-1.5, 
       5.0806786667587005`}}], 
      PolygonBox[{{-1.4375, 5.000123178062996}, {-1.4374999810329407`, 
       4.915707410443945}, {-1.5, 5.0806786667587005`}, {-1.4375, 
       5.000123178062996}}], 
      PolygonBox[{{-1.5, 4.794090994854722}, {-1.5, 
       5.0806786667587005`}, {-1.4374999810329407`, 4.915707410443945}, {-1.5,
        4.794090994854722}}], 
      PolygonBox[{{-1.4374999810329407`, 
       4.915707410443945}, {-1.4373449933535234`, 4.769748357463746}, {-1.5, 
       4.794090994854722}, {-1.4374999810329407`, 4.915707410443945}}], 
      PolygonBox[{{-1.5, 4.642337217350635}, {-1.5, 
       4.794090994854722}, {-1.4373449933535234`, 4.769748357463746}, {-1.5, 
       4.642337217350635}}], 
      PolygonBox[{{-1.4373449933535234`, 
       4.769748357463746}, {-1.4049427443329972`, 4.595057255667003}, {-1.5, 
       4.642337217350635}, {-1.4373449933535234`, 4.769748357463746}}], 
      PolygonBox[{{-1.5, 5.5}, {-1.5, 
       4.642337217350635}, {-1.4049427443329972`, 4.595057255667003}, {-1.5, 
       5.5}}], PolygonBox[{{-1.4049427443329972`, 
       4.595057255667003}, {-1.230251642536255, 4.562655006646477}, {-1.5, 
       5.5}, {-1.4049427443329972`, 4.595057255667003}}], 
      PolygonBox[{{-1.5, 4.5}, {-1.5, 5.5}, {-1.230251642536255, 
       4.562655006646477}, {-1.5, 4.5}}], 
      PolygonBox[{{-1.230251642536255, 
       4.562655006646477}, {-1.0842925895560642`, 4.562500018967059}, {-1.5, 
       4.5}, {-1.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{-1.205909005566828, 4.5}, {-1.5, 
       4.5}, {-1.0842925895560642`, 4.562500018967059}, {-1.205909005566828, 
       4.5}}], PolygonBox[{{-1.0842925895560642`, 
       4.562500018967059}, {-0.999865158168957, 4.5625}, {-1.205909005566828, 
       4.5}, {-1.0842925895560642`, 4.562500018967059}}], 
      PolygonBox[{{-0.9176761295989384, 4.5}, {-1.205909005566828, 
       4.5}, {-0.999865158168957, 4.5625}, {-0.9176761295989384, 4.5}}], 
      PolygonBox[{{-0.999865158168957, 4.5625}, {-0.9157074104439469, 
       4.562500018967059}, {-0.9176761295989384, 4.5}, {-0.999865158168957, 
       4.5625}}], 
      PolygonBox[{{-0.7940909946396026, 4.5}, {-0.9176761295989384, 
       4.5}, {-0.9157074104439469, 4.562500018967059}, {-0.7940909946396026, 
       4.5}}], PolygonBox[{{-0.9157074104439469, 
       4.562500018967059}, {-0.7697483574637453, 
       4.562655006646477}, {-0.7940909946396026, 4.5}, {-0.9157074104439469, 
       4.562500018967059}}], 
      PolygonBox[{{-0.642337217350629, 4.5}, {-0.7940909946396026, 
       4.5}, {-0.7697483574637453, 4.562655006646477}, {-0.642337217350629, 
       4.5}}], PolygonBox[{{-0.7697483574637453, 
       4.562655006646477}, {-0.5950572556670028, 
       4.595057255667003}, {-0.642337217350629, 4.5}, {-0.7697483574637453, 
       4.562655006646477}}], 
      PolygonBox[{{-0.5, 4.5}, {-0.642337217350629, 
       4.5}, {-0.5950572556670028, 4.595057255667003}, {-0.5, 4.5}}], 
      PolygonBox[{{-0.5950572556670028, 
       4.595057255667003}, {-0.5950572556670028, 4.595057255667003}, {-0.5, 
       4.5}, {-0.5950572556670028, 4.595057255667003}}], 
      PolygonBox[{{-0.5, 4.5}, {-0.5, 4.5}, {-0.5950572556670028, 
       4.595057255667003}, {-0.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, -5.}, {-0.4791666666666667, -5.}, {-0.4583333333333333, \
-5.}, {-0.4375, -5.}, {-0.4166666666666667, -5.}, {-0.39583333333333337`, \
-5.}, {-0.375, -5.}, {-0.375, -5.}, {-0.3958333333333333, -5.}, \
{-0.4166666666666667, -5.}, {-0.4375, -5.}, {-0.4583333333333333, -5.}, \
{-0.47916666666666663`, -5.}, {-0.5, -5.}, {-0.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, -5.}, {0.3958333333333333, -5.}, {
       0.4166666666666667, -5.}, {0.4375, -5.}, {0.4583333333333333, -5.}, {
       0.47916666666666663`, -5.}, {0.5, -5.}, {0.5, -5.}, {
       0.4791666666666667, -5.}, {0.4583333333333333, -5.}, {0.4375, -5.}, {
       0.4166666666666667, -5.}, {0.39583333333333337`, -5.}, {0.375, -5.}, {
       0.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -5.5}, {0., -5.479166666666667}, {
       0., -5.458333333333333}, {0., -5.4375}, {0., -5.416666666666667}, {
       0., -5.395833333333333}, {0., -5.375}, {0., -5.375}, {
       0., -5.395833333333333}, {0., -5.416666666666667}, {0., -5.4375}, {
       0., -5.458333333333333}, {0., -5.479166666666667}, {0., -5.5}, {
       0., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -4.625}, {0., -4.604166666666667}, {
       0., -4.583333333333333}, {0., -4.5625}, {0., -4.541666666666667}, {
       0., -4.520833333333333}, {0., -4.5}, {0., -4.5}, {
       0., -4.520833333333333}, {0., -4.541666666666667}, {0., -4.5625}, {
       0., -4.583333333333333}, {0., -4.604166666666667}, {0., -4.625}, {
       0., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, -5.}, {-0.25, -5.}, {-0.125, -5.}, {0., -5.}, {
       0.125, -5.}, {0.25, -5.}, {0.375, -5.}, {0.375, -5.}, {0.25, -5.}, {
       0.125, -5.}, {
       0., -5.}, {-0.125, -5.}, {-0.25, -5.}, {-0.375, -5.}, {-0.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -5.375}, {0., -5.25}, {0., -5.125}, {0., -5.}, {
       0., -4.875}, {0., -4.75}, {0., -4.625}, {0., -4.625}, {0., -4.75}, {
       0., -4.875}, {0., -5.}, {0., -5.125}, {0., -5.25}, {0., -5.375}, {
       0., -5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CG0yIGA/rKvS/Wu29/sLeOdO0f4QIOlk96d
E1cg8g7CB27l3D9T9uOCvRGn0eSKD0IHIGacsM+4I21btFnowL3OmEV7buyw
556+YoFor9ABrq55PpaVVTZgZQ1CB65C5PfD5P/+B4Hj+2H6b0LM3w8zvx5i
/36Y/f4Q9+2/AXUf1P370dy/X72o81NSssiBRmT9B0QO3IGaf/bb2Zx2ftED
bBD375+h/ORQr4/ogbdQ933NCI9/VSR6oON52c9Xtybvgbhf9MAZqP9g8t8h
7reH6b8BDZ9zUPPrkMMPaL8fNHw1oO5DD38AoWq0oQ==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CG00IGwUBC4isY/CuczoAChAyEQ+f2o/Kv7
UdU/IMhfvQoEEHywMaHCaOpF0NSLoKkXRVMvhsEPQ3EfjH8UTT0MiMH8Z4/K
v2qPqv4BQT6a++zR3G+P5j97NP/bo4UPPD4Ay9tj4A==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, -5.265165042944956}, {
       0.3247595264191645, -5.1875}, {
       0.40494274433299715`, -5.404942744332997}, {
       0.26516504294495535`, -5.265165042944956}}], 
      PolygonBox[{{0.4373449933535234, -5.230251642536255}, {
       0.40494274433299715`, -5.404942744332997}, {
       0.3247595264191645, -5.1875}, {
       0.4373449933535234, -5.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, -5.1875}, {
       0.36222218485840063`, -5.097057141913445}, {
       0.4373449933535234, -5.230251642536255}, {
       0.3247595264191645, -5.1875}}], 
      PolygonBox[{{0.4374999810329408, -5.084292589556062}, {
       0.4373449933535234, -5.230251642536255}, {
       0.36222218485840063`, -5.097057141913445}, {
       0.4374999810329408, -5.084292589556062}}], 
      PolygonBox[{{0.36222218485840063`, -5.097057141913445}, {0.375, -5.}, {
       0.4374999810329408, -5.084292589556062}, {
       0.36222218485840063`, -5.097057141913445}}], 
      PolygonBox[{{0.4375, -5.}, {0.4374999810329408, -5.084292589556062}, {
       0.375, -5.}, {0.4375, -5.}}], 
      PolygonBox[{{0.375, -5.}, {0.36222218485840063`, -4.902942858086555}, {
       0.4375, -5.}, {0.375, -5.}}], 
      PolygonBox[{{0.4374999810329408, -4.915707410443939}, {0.4375, -5.}, {
       0.36222218485840063`, -4.902942858086555}, {
       0.4374999810329408, -4.915707410443939}}], 
      PolygonBox[{{0.36222218485840063`, -4.902942858086555}, {
       0.3247595264191645, -4.8125}, {
       0.4374999810329408, -4.915707410443939}, {
       0.36222218485840063`, -4.902942858086555}}], 
      PolygonBox[{{0.4373449933535234, -4.769748357463745}, {
       0.4374999810329408, -4.915707410443939}, {
       0.3247595264191645, -4.8125}, {
       0.4373449933535234, -4.769748357463745}}], 
      PolygonBox[{{0.3247595264191645, -4.8125}, {
       0.26516504294495535`, -4.734834957055044}, {
       0.4373449933535234, -4.769748357463745}, {
       0.3247595264191645, -4.8125}}], 
      PolygonBox[{{0.4049427443329971, -4.595057255667003}, {
       0.4373449933535234, -4.769748357463745}, {
       0.26516504294495535`, -4.734834957055044}, {
       0.4049427443329971, -4.595057255667003}}], 
      PolygonBox[{{0.26516504294495535`, -4.734834957055044}, {
       0.18750000000000006`, -4.6752404735808355`}, {
       0.4049427443329971, -4.595057255667003}, {
       0.26516504294495535`, -4.734834957055044}}], 
      PolygonBox[{{0.23025164253625516`, -4.562655006646477}, {
       0.4049427443329971, -4.595057255667003}, {
       0.18750000000000006`, -4.6752404735808355`}, {
       0.23025164253625516`, -4.562655006646477}}], 
      PolygonBox[{{0.18750000000000006`, -4.6752404735808355`}, {
       0.09705714191344536, -4.637777815141599}, {
       0.23025164253625516`, -4.562655006646477}, {
       0.18750000000000006`, -4.6752404735808355`}}], 
      PolygonBox[{{0.08429258955606053, -4.562500018967059}, {
       0.23025164253625516`, -4.562655006646477}, {
       0.09705714191344536, -4.637777815141599}, {
       0.08429258955606053, -4.562500018967059}}], 
      PolygonBox[{{0.09705714191344536, -4.637777815141599}, {
       2.296212748401287*^-17, -4.625}, {
       0.08429258955606053, -4.562500018967059}, {
       0.09705714191344536, -4.637777815141599}}], 
      PolygonBox[{{0.0001055272204876927, -4.5625}, {
       0.08429258955606053, -4.562500018967059}, {
       2.296212748401287*^-17, -4.625}, {0.0001055272204876927, -4.5625}}], 
      PolygonBox[{{
       2.296212748401287*^-17, -4.625}, {-0.09705714191344515, \
-4.637777815141599}, {0.0001055272204876927, -4.5625}, {
       2.296212748401287*^-17, -4.625}}], 
      PolygonBox[{{-0.08429258955605684, -4.562500018967059}, {
       0.0001055272204876927, -4.5625}, {-0.09705714191344515, \
-4.637777815141599}, {-0.08429258955605684, -4.562500018967059}}], 
      PolygonBox[{{-0.09705714191344515, -4.637777815141599}, \
{-0.18749999999999992`, -4.6752404735808355`}, {-0.08429258955605684, \
-4.562500018967059}, {-0.09705714191344515, -4.637777815141599}}], 
      PolygonBox[{{-0.23025164253625502`, -4.562655006646477}, \
{-0.08429258955605684, -4.562500018967059}, {-0.18749999999999992`, \
-4.6752404735808355`}, {-0.23025164253625502`, -4.562655006646477}}], 
      PolygonBox[{{-0.18749999999999992`, -4.6752404735808355`}, \
{-0.2651650429449553, -4.734834957055044}, {-0.23025164253625502`, \
-4.562655006646477}, {-0.18749999999999992`, -4.6752404735808355`}}], 
      PolygonBox[{{-0.4049427443329971, -4.595057255667003}, \
{-0.23025164253625502`, -4.562655006646477}, {-0.2651650429449553, \
-4.734834957055044}, {-0.4049427443329971, -4.595057255667003}}], 
      PolygonBox[{{-0.2651650429449553, -4.734834957055044}, \
{-0.32475952641916445`, -4.8125}, {-0.4049427443329971, -4.595057255667003}, \
{-0.2651650429449553, -4.734834957055044}}], 
      PolygonBox[{{-0.4373449933535234, -4.769748357463745}, \
{-0.4049427443329971, -4.595057255667003}, {-0.32475952641916445`, -4.8125}, \
{-0.4373449933535234, -4.769748357463745}}], 
      PolygonBox[{{-0.32475952641916445`, -4.8125}, {-0.3622221848584006, \
-4.902942858086554}, {-0.4373449933535234, -4.769748357463745}, \
{-0.32475952641916445`, -4.8125}}], 
      PolygonBox[{{-0.4374999810329408, -4.915707410443938}, \
{-0.4373449933535234, -4.769748357463745}, {-0.3622221848584006, \
-4.902942858086554}, {-0.4374999810329408, -4.915707410443938}}], 
      PolygonBox[{{-0.3622221848584006, -4.902942858086554}, {-0.375, -5.}, \
{-0.4374999810329408, -4.915707410443938}, {-0.3622221848584006, \
-4.902942858086554}}], 
      PolygonBox[{{-0.4375, -4.999876821937004}, {-0.4374999810329408, \
-4.915707410443938}, {-0.375, -5.}, {-0.4375, -4.999876821937004}}], 
      PolygonBox[{{-0.375, -5.}, {-0.36222218485840063`, -5.097057141913445}, \
{-0.4375, -4.999876821937004}, {-0.375, -5.}}], 
      PolygonBox[{{-0.4374999810329408, -5.084292589556055}, {-0.4375, \
-4.999876821937004}, {-0.36222218485840063`, -5.097057141913445}, \
{-0.4374999810329408, -5.084292589556055}}], 
      PolygonBox[{{-0.36222218485840063`, -5.097057141913445}, \
{-0.3247595264191646, -5.1875}, {-0.4374999810329408, -5.084292589556055}, \
{-0.36222218485840063`, -5.097057141913445}}], 
      PolygonBox[{{-0.4373449933535234, -5.230251642536254}, \
{-0.4374999810329408, -5.084292589556055}, {-0.3247595264191646, -5.1875}, \
{-0.4373449933535234, -5.230251642536254}}], 
      PolygonBox[{{-0.3247595264191646, -5.1875}, {-0.26516504294495535`, \
-5.265165042944956}, {-0.4373449933535234, -5.230251642536254}, \
{-0.3247595264191646, -5.1875}}], 
      PolygonBox[{{-0.40494274433299715`, -5.404942744332997}, \
{-0.4373449933535234, -5.230251642536254}, {-0.26516504294495535`, \
-5.265165042944956}, {-0.40494274433299715`, -5.404942744332997}}], 
      PolygonBox[{{-0.26516504294495535`, -5.265165042944956}, \
{-0.18750000000000017`, -5.3247595264191645`}, {-0.40494274433299715`, \
-5.404942744332997}, {-0.26516504294495535`, -5.265165042944956}}], 
      PolygonBox[{{-0.23025164253625505`, -5.437344993353523}, \
{-0.40494274433299715`, -5.404942744332997}, {-0.18750000000000017`, \
-5.3247595264191645`}, {-0.23025164253625505`, -5.437344993353523}}], 
      PolygonBox[{{-0.18750000000000017`, -5.3247595264191645`}, \
{-0.09705714191344557, -5.362222184858401}, {-0.23025164253625505`, \
-5.437344993353523}, {-0.18750000000000017`, -5.3247595264191645`}}], 
      PolygonBox[{{-0.08429258955606422, -5.437499981032941}, \
{-0.23025164253625505`, -5.437344993353523}, {-0.09705714191344557, \
-5.362222184858401}, {-0.08429258955606422, -5.437499981032941}}], 
      PolygonBox[{{-0.09705714191344557, -5.362222184858401}, {
       6.888638245203862*^-17, -5.375}, {-0.08429258955606422, \
-5.437499981032941}, {-0.09705714191344557, -5.362222184858401}}], 
      PolygonBox[{{
       0.0001348418310429853, -5.4375}, {-0.08429258955606422, \
-5.437499981032941}, {6.888638245203862*^-17, -5.375}, {
       0.0001348418310429853, -5.4375}}], 
      PolygonBox[{{6.888638245203862*^-17, -5.375}, {
       0.09705714191344511, -5.362222184858401}, {
       0.0001348418310429853, -5.4375}, {6.888638245203862*^-17, -5.375}}], 
      PolygonBox[{{0.08429258955605314, -5.437499981032941}, {
       0.0001348418310429853, -5.4375}, {
       0.09705714191344511, -5.362222184858401}, {
       0.08429258955605314, -5.437499981032941}}], 
      PolygonBox[{{0.09705714191344511, -5.362222184858401}, {
       0.18749999999999975`, -5.3247595264191645`}, {
       0.08429258955605314, -5.437499981032941}, {
       0.09705714191344511, -5.362222184858401}}], 
      PolygonBox[{{0.2302516425362547, -5.437344993353523}, {
       0.08429258955605314, -5.437499981032941}, {
       0.18749999999999975`, -5.3247595264191645`}, {
       0.2302516425362547, -5.437344993353523}}], 
      PolygonBox[{{0.18749999999999975`, -5.3247595264191645`}, {
       0.26516504294495524`, -5.265165042944956}, {
       0.2302516425362547, -5.437344993353523}, {
       0.18749999999999975`, -5.3247595264191645`}}], 
      PolygonBox[{{0.4049427443329971, -5.404942744332997}, {
       0.2302516425362547, -5.437344993353523}, {
       0.26516504294495524`, -5.265165042944956}, {
       0.4049427443329971, -5.404942744332997}}], 
      PolygonBox[{{0.26516504294495524`, -5.265165042944956}, {
       0.26516504294495535`, -5.265165042944956}, {
       0.4049427443329971, -5.404942744332997}, {
       0.26516504294495524`, -5.265165042944956}}], 
      PolygonBox[{{0.40494274433299715`, -5.404942744332997}, {
       0.4049427443329971, -5.404942744332997}, {
       0.26516504294495535`, -5.265165042944956}, {
       0.40494274433299715`, -5.404942744332997}}], 
      PolygonBox[{{0.40494274433299715`, -5.404942744332997}, {
       0.4373449933535234, -5.230251642536255}, {0.5, -5.5}, {
       0.40494274433299715`, -5.404942744332997}}], 
      PolygonBox[{{0.5, -5.357662782649368}, {0.5, -5.5}, {
       0.4373449933535234, -5.230251642536255}, {0.5, -5.357662782649368}}], 
      PolygonBox[{{0.4373449933535234, -5.230251642536255}, {
       0.4374999810329408, -5.084292589556062}, {0.5, -5.357662782649368}, {
       0.4373449933535234, -5.230251642536255}}], 
      PolygonBox[{{0.5, -5.20590900530174}, {0.5, -5.357662782649368}, {
       0.4374999810329408, -5.084292589556062}, {0.5, -5.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, -5.084292589556062}, {0.4375, -5.}, {
       0.5, -5.20590900530174}, {0.4374999810329408, -5.084292589556062}}], 
      PolygonBox[{{0.5, -5.}, {0.5, -5.20590900530174}, {0.4375, -5.}, {
       0.5, -5.}}], 
      PolygonBox[{{0.4375, -5.}, {0.4374999810329408, -4.915707410443939}, {
       0.5, -5.}, {0.4375, -5.}}], 
      PolygonBox[{{0.5, -4.79409099469826}, {0.5, -5.}, {
       0.4374999810329408, -4.915707410443939}, {0.5, -4.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, -4.915707410443939}, {
       0.4373449933535234, -4.769748357463745}, {0.5, -4.79409099469826}, {
       0.4374999810329408, -4.915707410443939}}], 
      PolygonBox[{{0.5, -4.642337217350632}, {0.5, -4.79409099469826}, {
       0.4373449933535234, -4.769748357463745}, {0.5, -4.642337217350632}}], 
      PolygonBox[{{0.4373449933535234, -4.769748357463745}, {
       0.4049427443329971, -4.595057255667003}, {0.5, -4.642337217350632}, {
       0.4373449933535234, -4.769748357463745}}], 
      PolygonBox[{{0.491446564961186, -4.508553435038814}, {
       0.5, -4.642337217350632}, {0.4049427443329971, -4.595057255667003}, {
       0.491446564961186, -4.508553435038814}}], 
      PolygonBox[{{0.4049427443329971, -4.595057255667003}, {
       0.23025164253625516`, -4.562655006646477}, {
       0.491446564961186, -4.508553435038814}, {
       0.4049427443329971, -4.595057255667003}}], 
      PolygonBox[{{0.35766278264936807`, -4.5}, {
       0.491446564961186, -4.508553435038814}, {
       0.23025164253625516`, -4.562655006646477}, {
       0.35766278264936807`, -4.5}}], 
      PolygonBox[{{0.23025164253625516`, -4.562655006646477}, {
       0.08429258955606053, -4.562500018967059}, {
       0.35766278264936807`, -4.5}, {
       0.23025164253625516`, -4.562655006646477}}], 
      PolygonBox[{{0.20590900537325585`, -4.5}, {
       0.35766278264936807`, -4.5}, {
       0.08429258955606053, -4.562500018967059}, {
       0.20590900537325585`, -4.5}}], 
      PolygonBox[{{0.08429258955606053, -4.562500018967059}, {
       0.0001055272204876927, -4.5625}, {0.20590900537325585`, -4.5}, {
       0.08429258955606053, -4.562500018967059}}], 
      PolygonBox[{{0.07794195802689004, -4.5}, {0.20590900537325585`, -4.5}, {
       0.0001055272204876927, -4.5625}, {0.07794195802689004, -4.5}}], 
      PolygonBox[{{
       0.0001055272204876927, -4.5625}, {-0.08429258955605684, \
-4.562500018967059}, {0.07794195802689004, -4.5}, {
       0.0001055272204876927, -4.5625}}], 
      PolygonBox[{{-0.20590900530444564`, -4.5}, {
       0.07794195802689004, -4.5}, {-0.08429258955605684, \
-4.562500018967059}, {-0.20590900530444564`, -4.5}}], 
      PolygonBox[{{-0.08429258955605684, -4.562500018967059}, \
{-0.23025164253625502`, -4.562655006646477}, {-0.20590900530444564`, -4.5}, \
{-0.08429258955605684, -4.562500018967059}}], 
      PolygonBox[{{-0.35766278264936624`, -4.5}, {-0.20590900530444564`, \
-4.5}, {-0.23025164253625502`, -4.562655006646477}, {-0.35766278264936624`, \
-4.5}}], PolygonBox[{{-0.23025164253625502`, -4.562655006646477}, \
{-0.4049427443329971, -4.595057255667003}, {-0.35766278264936624`, -4.5}, \
{-0.23025164253625502`, -4.562655006646477}}], 
      PolygonBox[{{
       0.5, -4.5}, {-0.35766278264936624`, -4.5}, {-0.4049427443329971, \
-4.595057255667003}, {0.5, -4.5}}], 
      PolygonBox[{{-0.4049427443329971, -4.595057255667003}, \
{-0.4373449933535234, -4.769748357463745}, {
       0.5, -4.5}, {-0.4049427443329971, -4.595057255667003}}], 
      PolygonBox[{{-0.5, -4.642337217350631}, {
       0.5, -4.5}, {-0.4373449933535234, -4.769748357463745}, {-0.5, \
-4.642337217350631}}], 
      PolygonBox[{{-0.4373449933535234, -4.769748357463745}, \
{-0.4374999810329408, -4.915707410443938}, {-0.5, -4.642337217350631}, \
{-0.4373449933535234, -4.769748357463745}}], 
      PolygonBox[{{-0.5, -4.794090994717101}, {-0.5, -4.642337217350631}, \
{-0.4374999810329408, -4.915707410443938}, {-0.5, -4.794090994717101}}], 
      PolygonBox[{{-0.4374999810329408, -4.915707410443938}, {-0.4375, \
-4.999876821937004}, {-0.5, -4.794090994717101}, {-0.4374999810329408, \
-4.915707410443938}}], 
      PolygonBox[{{-0.5, -4.9193213332412995`}, {-0.5, -4.794090994717101}, \
{-0.4375, -4.999876821937004}, {-0.5, -4.9193213332412995`}}], 
      PolygonBox[{{-0.4375, -4.999876821937004}, {-0.4374999810329408, \
-5.084292589556055}, {-0.5, -4.9193213332412995`}, {-0.4375, \
-4.999876821937004}}], 
      PolygonBox[{{-0.5, -5.205909005145278}, {-0.5, -4.9193213332412995`}, \
{-0.4374999810329408, -5.084292589556055}, {-0.5, -5.205909005145278}}], 
      PolygonBox[{{-0.4374999810329408, -5.084292589556055}, \
{-0.4373449933535234, -5.230251642536254}, {-0.5, -5.205909005145278}, \
{-0.4374999810329408, -5.084292589556055}}], 
      PolygonBox[{{-0.5, -5.357662782649365}, {-0.5, -5.205909005145278}, \
{-0.4373449933535234, -5.230251642536254}, {-0.5, -5.357662782649365}}], 
      PolygonBox[{{-0.4373449933535234, -5.230251642536254}, \
{-0.40494274433299715`, -5.404942744332997}, {-0.5, -5.357662782649365}, \
{-0.4373449933535234, -5.230251642536254}}], 
      PolygonBox[{{-0.5, -4.5}, {-0.5, -5.357662782649365}, \
{-0.40494274433299715`, -5.404942744332997}, {-0.5, -4.5}}], 
      PolygonBox[{{-0.40494274433299715`, -5.404942744332997}, \
{-0.23025164253625505`, -5.437344993353523}, {-0.5, -4.5}, \
{-0.40494274433299715`, -5.404942744332997}}], 
      PolygonBox[{{-0.5, -5.5}, {-0.5, -4.5}, {-0.23025164253625505`, \
-5.437344993353523}, {-0.5, -5.5}}], 
      PolygonBox[{{-0.23025164253625505`, -5.437344993353523}, \
{-0.08429258955606422, -5.437499981032941}, {-0.5, -5.5}, \
{-0.23025164253625505`, -5.437344993353523}}], 
      PolygonBox[{{-0.20590900556682806`, -5.5}, {-0.5, -5.5}, \
{-0.08429258955606422, -5.437499981032941}, {-0.20590900556682806`, -5.5}}], 
      PolygonBox[{{-0.08429258955606422, -5.437499981032941}, {
       0.0001348418310429853, -5.4375}, {-0.20590900556682806`, -5.5}, \
{-0.08429258955606422, -5.437499981032941}}], 
      PolygonBox[{{0.0823238704010616, -5.5}, {-0.20590900556682806`, -5.5}, {
       0.0001348418310429853, -5.4375}, {0.0823238704010616, -5.5}}], 
      PolygonBox[{{0.0001348418310429853, -5.4375}, {
       0.08429258955605314, -5.437499981032941}, {0.0823238704010616, -5.5}, {
       0.0001348418310429853, -5.4375}}], 
      PolygonBox[{{0.2059090053603974, -5.5}, {0.0823238704010616, -5.5}, {
       0.08429258955605314, -5.437499981032941}, {0.2059090053603974, -5.5}}],
       PolygonBox[{{0.08429258955605314, -5.437499981032941}, {
       0.2302516425362547, -5.437344993353523}, {0.2059090053603974, -5.5}, {
       0.08429258955605314, -5.437499981032941}}], 
      PolygonBox[{{0.35766278264937107`, -5.5}, {0.2059090053603974, -5.5}, {
       0.2302516425362547, -5.437344993353523}, {
       0.35766278264937107`, -5.5}}], 
      PolygonBox[{{0.2302516425362547, -5.437344993353523}, {
       0.4049427443329971, -5.404942744332997}, {
       0.35766278264937107`, -5.5}, {
       0.2302516425362547, -5.437344993353523}}], 
      PolygonBox[{{0.5, -5.5}, {0.35766278264937107`, -5.5}, {
       0.4049427443329971, -5.404942744332997}, {0.5, -5.5}}], 
      PolygonBox[{{0.4049427443329971, -5.404942744332997}, {
       0.40494274433299715`, -5.404942744332997}, {0.5, -5.5}, {
       0.4049427443329971, -5.404942744332997}}], 
      PolygonBox[{{0.5, -5.5}, {0.5, -5.5}, {
       0.40494274433299715`, -5.404942744332997}, {
       0.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, -4.}, {-0.4791666666666667, -4.}, {-0.4583333333333333, \
-4.}, {-0.4375, -4.}, {-0.4166666666666667, -4.}, {-0.39583333333333337`, \
-4.}, {-0.375, -4.}, {-0.375, -4.}, {-0.3958333333333333, -4.}, \
{-0.4166666666666667, -4.}, {-0.4375, -4.}, {-0.4583333333333333, -4.}, \
{-0.47916666666666663`, -4.}, {-0.5, -4.}, {-0.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, -4.}, {0.3958333333333333, -4.}, {
       0.4166666666666667, -4.}, {0.4375, -4.}, {0.4583333333333333, -4.}, {
       0.47916666666666663`, -4.}, {0.5, -4.}, {0.5, -4.}, {
       0.4791666666666667, -4.}, {0.4583333333333333, -4.}, {0.4375, -4.}, {
       0.4166666666666667, -4.}, {0.39583333333333337`, -4.}, {0.375, -4.}, {
       0.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -4.5}, {0., -4.479166666666667}, {
       0., -4.458333333333333}, {0., -4.4375}, {0., -4.416666666666667}, {
       0., -4.395833333333333}, {0., -4.375}, {0., -4.375}, {
       0., -4.395833333333333}, {0., -4.416666666666667}, {0., -4.4375}, {0.,
        -4.458333333333333}, {0., -4.479166666666667}, {0., -4.5}, {
       0., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -3.625}, {0., -3.6041666666666665`}, {
       0., -3.5833333333333335`}, {0., -3.5625}, {0., -3.5416666666666665`}, {
       0., -3.5208333333333335`}, {0., -3.5}, {0., -3.5}, {
       0., -3.5208333333333335`}, {0., -3.5416666666666665`}, {0., -3.5625}, {
       0., -3.5833333333333335`}, {0., -3.6041666666666665`}, {0., -3.625}, {
       0., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, -4.}, {-0.25, -4.}, {-0.125, -4.}, {0., -4.}, {
       0.125, -4.}, {0.25, -4.}, {0.375, -4.}, {0.375, -4.}, {0.25, -4.}, {
       0.125, -4.}, {
       0., -4.}, {-0.125, -4.}, {-0.25, -4.}, {-0.375, -4.}, {-0.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -4.375}, {0., -4.25}, {0., -4.125}, {0., -4.}, {
       0., -3.875}, {0., -3.75}, {0., -3.625}, {0., -3.625}, {0., -3.75}, {
       0., -3.875}, {0., -4.}, {0., -4.125}, {0., -4.25}, {0., -4.375}, {
       0., -4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CG0wIGA/rKvS/Wu22+UfitlZcl/oMHSSe/O
iSsQ+Qa+A7dy7p8p+3HBPlUoRe3jA94DEDNO2F/YYV71JI33wL3OmEV7buyw
F9MLdNSW4j3A1TXPx7KyygZiPu+BqxD5/TD5v/9B4Ph+mP6bEPP3w8yvh9i/
H2a/P8R9+2Hug7p/P5r796sXdX5KShY40Iis/4DAgTtQ889+O5vTzi94gA3i
/v0zlJ8c6vURPPAW6r6vGeHxr4oED3Q8L/v56tbkPRD7BQ+cgfoPJv8d4n57
mP4b0PA5BzW/Djn8gPb7QcNXA+o+9PAHALoZsfM=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CE0z4GwUBC4isY/CuczoACeAyEQ+f2o/Kv7
UdU/IMgHawvlhfNXrwIBPjT1AmjyAmj6BdHUC2Hww1DcB+MfRVMPA0Iw/9mj
8q/ao6p/QJCP5j57NPfbo/nPHs3/9mGo4QOPDwBSZ2Nb
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, -4.265165042944956}, {
       0.3247595264191645, -4.1875}, {
       0.40494274433299715`, -4.404942744332997}, {
       0.26516504294495535`, -4.265165042944956}}], 
      PolygonBox[{{0.4373449933535234, -4.230251642536255}, {
       0.40494274433299715`, -4.404942744332997}, {
       0.3247595264191645, -4.1875}, {
       0.4373449933535234, -4.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, -4.1875}, {
       0.36222218485840063`, -4.097057141913445}, {
       0.4373449933535234, -4.230251642536255}, {
       0.3247595264191645, -4.1875}}], 
      PolygonBox[{{0.4374999810329408, -4.084292589556062}, {
       0.4373449933535234, -4.230251642536255}, {
       0.36222218485840063`, -4.097057141913445}, {
       0.4374999810329408, -4.084292589556062}}], 
      PolygonBox[{{0.36222218485840063`, -4.097057141913445}, {0.375, -4.}, {
       0.4374999810329408, -4.084292589556062}, {
       0.36222218485840063`, -4.097057141913445}}], 
      PolygonBox[{{0.4375, -4.}, {0.4374999810329408, -4.084292589556062}, {
       0.375, -4.}, {0.4375, -4.}}], 
      PolygonBox[{{0.375, -4.}, {
       0.36222218485840063`, -3.9029428580865546`}, {0.4375, -4.}, {
       0.375, -4.}}], 
      PolygonBox[{{0.4374999810329408, -3.915707410443938}, {0.4375, -4.}, {
       0.36222218485840063`, -3.9029428580865546`}, {
       0.4374999810329408, -3.915707410443938}}], 
      PolygonBox[{{0.36222218485840063`, -3.9029428580865546`}, {
       0.3247595264191645, -3.8125}, {
       0.4374999810329408, -3.915707410443938}, {
       0.36222218485840063`, -3.9029428580865546`}}], 
      PolygonBox[{{0.4373449933535234, -3.769748357463745}, {
       0.4374999810329408, -3.915707410443938}, {
       0.3247595264191645, -3.8125}, {
       0.4373449933535234, -3.769748357463745}}], 
      PolygonBox[{{0.3247595264191645, -3.8125}, {
       0.26516504294495535`, -3.7348349570550448`}, {
       0.4373449933535234, -3.769748357463745}, {
       0.3247595264191645, -3.8125}}], 
      PolygonBox[{{0.4049427443329971, -3.595057255667003}, {
       0.4373449933535234, -3.769748357463745}, {
       0.26516504294495535`, -3.7348349570550448`}, {
       0.4049427443329971, -3.595057255667003}}], 
      PolygonBox[{{0.26516504294495535`, -3.7348349570550448`}, {
       0.18750000000000006`, -3.6752404735808355`}, {
       0.4049427443329971, -3.595057255667003}, {
       0.26516504294495535`, -3.7348349570550448`}}], 
      PolygonBox[{{0.23025164253625516`, -3.5626550066464766`}, {
       0.4049427443329971, -3.595057255667003}, {
       0.18750000000000006`, -3.6752404735808355`}, {
       0.23025164253625516`, -3.5626550066464766`}}], 
      PolygonBox[{{0.18750000000000006`, -3.6752404735808355`}, {
       0.09705714191344536, -3.6377778151415994`}, {
       0.23025164253625516`, -3.5626550066464766`}, {
       0.18750000000000006`, -3.6752404735808355`}}], 
      PolygonBox[{{0.08429258955606053, -3.562500018967059}, {
       0.23025164253625516`, -3.5626550066464766`}, {
       0.09705714191344536, -3.6377778151415994`}, {
       0.08429258955606053, -3.562500018967059}}], 
      PolygonBox[{{0.09705714191344536, -3.6377778151415994`}, {
       2.296212748401287*^-17, -3.625}, {
       0.08429258955606053, -3.562500018967059}, {
       0.09705714191344536, -3.6377778151415994`}}], 
      PolygonBox[{{0.0001055272204876927, -3.5625}, {
       0.08429258955606053, -3.562500018967059}, {
       2.296212748401287*^-17, -3.625}, {0.0001055272204876927, -3.5625}}], 
      PolygonBox[{{
       2.296212748401287*^-17, -3.625}, {-0.09705714191344515, \
-3.6377778151415994`}, {0.0001055272204876927, -3.5625}, {
       2.296212748401287*^-17, -3.625}}], 
      PolygonBox[{{-0.08429258955605684, -3.562500018967059}, {
       0.0001055272204876927, -3.5625}, {-0.09705714191344515, \
-3.6377778151415994`}, {-0.08429258955605684, -3.562500018967059}}], 
      PolygonBox[{{-0.09705714191344515, -3.6377778151415994`}, \
{-0.18749999999999992`, -3.6752404735808355`}, {-0.08429258955605684, \
-3.562500018967059}, {-0.09705714191344515, -3.6377778151415994`}}], 
      PolygonBox[{{-0.23025164253625502`, -3.5626550066464766`}, \
{-0.08429258955605684, -3.562500018967059}, {-0.18749999999999992`, \
-3.6752404735808355`}, {-0.23025164253625502`, -3.5626550066464766`}}], 
      PolygonBox[{{-0.18749999999999992`, -3.6752404735808355`}, \
{-0.2651650429449553, -3.7348349570550448`}, {-0.23025164253625502`, \
-3.5626550066464766`}, {-0.18749999999999992`, -3.6752404735808355`}}], 
      PolygonBox[{{-0.4049427443329971, -3.595057255667003}, \
{-0.23025164253625502`, -3.5626550066464766`}, {-0.2651650429449553, \
-3.7348349570550448`}, {-0.4049427443329971, -3.595057255667003}}], 
      PolygonBox[{{-0.2651650429449553, -3.7348349570550448`}, \
{-0.32475952641916445`, -3.8125}, {-0.4049427443329971, -3.595057255667003}, \
{-0.2651650429449553, -3.7348349570550448`}}], 
      PolygonBox[{{-0.4373449933535234, -3.7697483574637447`}, \
{-0.4049427443329971, -3.595057255667003}, {-0.32475952641916445`, -3.8125}, \
{-0.4373449933535234, -3.7697483574637447`}}], 
      PolygonBox[{{-0.32475952641916445`, -3.8125}, {-0.3622221848584006, \
-3.9029428580865546`}, {-0.4373449933535234, -3.7697483574637447`}, \
{-0.32475952641916445`, -3.8125}}], 
      PolygonBox[{{-0.4374999810329408, -3.9157074104439378`}, \
{-0.4373449933535234, -3.7697483574637447`}, {-0.3622221848584006, \
-3.9029428580865546`}, {-0.4374999810329408, -3.9157074104439378`}}], 
      PolygonBox[{{-0.3622221848584006, -3.9029428580865546`}, {-0.375, -4.}, \
{-0.4374999810329408, -3.9157074104439378`}, {-0.3622221848584006, \
-3.9029428580865546`}}], 
      PolygonBox[{{-0.4375, -3.9998768219370047`}, {-0.4374999810329408, \
-3.9157074104439378`}, {-0.375, -4.}, {-0.4375, -3.9998768219370047`}}], 
      PolygonBox[{{-0.375, -4.}, {-0.36222218485840063`, -4.097057141913445}, \
{-0.4375, -3.9998768219370047`}, {-0.375, -4.}}], 
      PolygonBox[{{-0.4374999810329408, -4.084292589556055}, {-0.4375, \
-3.9998768219370047`}, {-0.36222218485840063`, -4.097057141913445}, \
{-0.4374999810329408, -4.084292589556055}}], 
      PolygonBox[{{-0.36222218485840063`, -4.097057141913445}, \
{-0.3247595264191646, -4.1875}, {-0.4374999810329408, -4.084292589556055}, \
{-0.36222218485840063`, -4.097057141913445}}], 
      PolygonBox[{{-0.4373449933535234, -4.230251642536254}, \
{-0.4374999810329408, -4.084292589556055}, {-0.3247595264191646, -4.1875}, \
{-0.4373449933535234, -4.230251642536254}}], 
      PolygonBox[{{-0.3247595264191646, -4.1875}, {-0.26516504294495535`, \
-4.265165042944956}, {-0.4373449933535234, -4.230251642536254}, \
{-0.3247595264191646, -4.1875}}], 
      PolygonBox[{{-0.40494274433299715`, -4.404942744332997}, \
{-0.4373449933535234, -4.230251642536254}, {-0.26516504294495535`, \
-4.265165042944956}, {-0.40494274433299715`, -4.404942744332997}}], 
      PolygonBox[{{-0.26516504294495535`, -4.265165042944956}, \
{-0.18750000000000017`, -4.3247595264191645`}, {-0.40494274433299715`, \
-4.404942744332997}, {-0.26516504294495535`, -4.265165042944956}}], 
      PolygonBox[{{-0.23025164253625505`, -4.437344993353523}, \
{-0.40494274433299715`, -4.404942744332997}, {-0.18750000000000017`, \
-4.3247595264191645`}, {-0.23025164253625505`, -4.437344993353523}}], 
      PolygonBox[{{-0.18750000000000017`, -4.3247595264191645`}, \
{-0.09705714191344557, -4.362222184858401}, {-0.23025164253625505`, \
-4.437344993353523}, {-0.18750000000000017`, -4.3247595264191645`}}], 
      PolygonBox[{{-0.08429258955606422, -4.437499981032941}, \
{-0.23025164253625505`, -4.437344993353523}, {-0.09705714191344557, \
-4.362222184858401}, {-0.08429258955606422, -4.437499981032941}}], 
      PolygonBox[{{-0.09705714191344557, -4.362222184858401}, {
       6.888638245203862*^-17, -4.375}, {-0.08429258955606422, \
-4.437499981032941}, {-0.09705714191344557, -4.362222184858401}}], 
      PolygonBox[{{
       0.0001348418310429853, -4.4375}, {-0.08429258955606422, \
-4.437499981032941}, {6.888638245203862*^-17, -4.375}, {
       0.0001348418310429853, -4.4375}}], 
      PolygonBox[{{6.888638245203862*^-17, -4.375}, {
       0.09705714191344511, -4.362222184858401}, {
       0.0001348418310429853, -4.4375}, {6.888638245203862*^-17, -4.375}}], 
      PolygonBox[{{0.08429258955605314, -4.437499981032941}, {
       0.0001348418310429853, -4.4375}, {
       0.09705714191344511, -4.362222184858401}, {
       0.08429258955605314, -4.437499981032941}}], 
      PolygonBox[{{0.09705714191344511, -4.362222184858401}, {
       0.18749999999999975`, -4.3247595264191645`}, {
       0.08429258955605314, -4.437499981032941}, {
       0.09705714191344511, -4.362222184858401}}], 
      PolygonBox[{{0.2302516425362547, -4.437344993353523}, {
       0.08429258955605314, -4.437499981032941}, {
       0.18749999999999975`, -4.3247595264191645`}, {
       0.2302516425362547, -4.437344993353523}}], 
      PolygonBox[{{0.18749999999999975`, -4.3247595264191645`}, {
       0.26516504294495524`, -4.265165042944956}, {
       0.2302516425362547, -4.437344993353523}, {
       0.18749999999999975`, -4.3247595264191645`}}], 
      PolygonBox[{{0.4049427443329971, -4.404942744332997}, {
       0.2302516425362547, -4.437344993353523}, {
       0.26516504294495524`, -4.265165042944956}, {
       0.4049427443329971, -4.404942744332997}}], 
      PolygonBox[{{0.26516504294495524`, -4.265165042944956}, {
       0.26516504294495535`, -4.265165042944956}, {
       0.4049427443329971, -4.404942744332997}, {
       0.26516504294495524`, -4.265165042944956}}], 
      PolygonBox[{{0.40494274433299715`, -4.404942744332997}, {
       0.4049427443329971, -4.404942744332997}, {
       0.26516504294495535`, -4.265165042944956}, {
       0.40494274433299715`, -4.404942744332997}}], 
      PolygonBox[{{0.40494274433299715`, -4.404942744332997}, {
       0.4373449933535234, -4.230251642536255}, {0.5, -4.5}, {
       0.40494274433299715`, -4.404942744332997}}], 
      PolygonBox[{{0.5, -4.357662782649368}, {0.5, -4.5}, {
       0.4373449933535234, -4.230251642536255}, {0.5, -4.357662782649368}}], 
      PolygonBox[{{0.4373449933535234, -4.230251642536255}, {
       0.4374999810329408, -4.084292589556062}, {0.5, -4.357662782649368}, {
       0.4373449933535234, -4.230251642536255}}], 
      PolygonBox[{{0.5, -4.20590900530174}, {0.5, -4.357662782649368}, {
       0.4374999810329408, -4.084292589556062}, {0.5, -4.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, -4.084292589556062}, {0.4375, -4.}, {
       0.5, -4.20590900530174}, {0.4374999810329408, -4.084292589556062}}], 
      PolygonBox[{{0.5, -4.}, {0.5, -4.20590900530174}, {0.4375, -4.}, {
       0.5, -4.}}], 
      PolygonBox[{{0.4375, -4.}, {0.4374999810329408, -3.915707410443938}, {
       0.5, -4.}, {0.4375, -4.}}], 
      PolygonBox[{{0.5, -3.79409099469826}, {0.5, -4.}, {
       0.4374999810329408, -3.915707410443938}, {0.5, -3.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, -3.915707410443938}, {
       0.4373449933535234, -3.769748357463745}, {0.5, -3.79409099469826}, {
       0.4374999810329408, -3.915707410443938}}], 
      PolygonBox[{{0.5, -3.6423372173506325`}, {0.5, -3.79409099469826}, {
       0.4373449933535234, -3.769748357463745}, {0.5, -3.6423372173506325`}}],
       PolygonBox[{{0.4373449933535234, -3.769748357463745}, {
       0.4049427443329971, -3.595057255667003}, {0.5, -3.6423372173506325`}, {
       0.4373449933535234, -3.769748357463745}}], 
      PolygonBox[{{0.491446564961186, -3.508553435038814}, {
       0.5, -3.6423372173506325`}, {0.4049427443329971, -3.595057255667003}, {
       0.491446564961186, -3.508553435038814}}], 
      PolygonBox[{{0.4049427443329971, -3.595057255667003}, {
       0.23025164253625516`, -3.5626550066464766`}, {
       0.491446564961186, -3.508553435038814}, {
       0.4049427443329971, -3.595057255667003}}], 
      PolygonBox[{{0.35766278264936807`, -3.5}, {
       0.491446564961186, -3.508553435038814}, {
       0.23025164253625516`, -3.5626550066464766`}, {
       0.35766278264936807`, -3.5}}], 
      PolygonBox[{{0.23025164253625516`, -3.5626550066464766`}, {
       0.08429258955606053, -3.562500018967059}, {
       0.35766278264936807`, -3.5}, {
       0.23025164253625516`, -3.5626550066464766`}}], 
      PolygonBox[{{0.20590900537325585`, -3.5}, {
       0.35766278264936807`, -3.5}, {
       0.08429258955606053, -3.562500018967059}, {
       0.20590900537325585`, -3.5}}], 
      PolygonBox[{{0.08429258955606053, -3.562500018967059}, {
       0.0001055272204876927, -3.5625}, {0.20590900537325585`, -3.5}, {
       0.08429258955606053, -3.562500018967059}}], 
      PolygonBox[{{0.07794195802689004, -3.5}, {0.20590900537325585`, -3.5}, {
       0.0001055272204876927, -3.5625}, {0.07794195802689004, -3.5}}], 
      PolygonBox[{{
       0.0001055272204876927, -3.5625}, {-0.08429258955605684, \
-3.562500018967059}, {0.07794195802689004, -3.5}, {
       0.0001055272204876927, -3.5625}}], 
      PolygonBox[{{-0.20590900530444564`, -3.5}, {
       0.07794195802689004, -3.5}, {-0.08429258955605684, \
-3.562500018967059}, {-0.20590900530444564`, -3.5}}], 
      PolygonBox[{{-0.08429258955605684, -3.562500018967059}, \
{-0.23025164253625502`, -3.5626550066464766`}, {-0.20590900530444564`, -3.5}, \
{-0.08429258955605684, -3.562500018967059}}], 
      PolygonBox[{{-0.35766278264936624`, -3.5}, {-0.20590900530444564`, \
-3.5}, {-0.23025164253625502`, -3.5626550066464766`}, {-0.35766278264936624`, \
-3.5}}], PolygonBox[{{-0.23025164253625502`, -3.5626550066464766`}, \
{-0.4049427443329971, -3.595057255667003}, {-0.35766278264936624`, -3.5}, \
{-0.23025164253625502`, -3.5626550066464766`}}], 
      PolygonBox[{{
       0.5, -3.5}, {-0.35766278264936624`, -3.5}, {-0.4049427443329971, \
-3.595057255667003}, {0.5, -3.5}}], 
      PolygonBox[{{-0.4049427443329971, -3.595057255667003}, \
{-0.4373449933535234, -3.7697483574637447`}, {
       0.5, -3.5}, {-0.4049427443329971, -3.595057255667003}}], 
      PolygonBox[{{-0.5, -3.642337217350631}, {
       0.5, -3.5}, {-0.4373449933535234, -3.7697483574637447`}, {-0.5, \
-3.642337217350631}}], 
      PolygonBox[{{-0.4373449933535234, -3.7697483574637447`}, \
{-0.4374999810329408, -3.9157074104439378`}, {-0.5, -3.642337217350631}, \
{-0.4373449933535234, -3.7697483574637447`}}], 
      PolygonBox[{{-0.5, -3.794090994717101}, {-0.5, -3.642337217350631}, \
{-0.4374999810329408, -3.9157074104439378`}, {-0.5, -3.794090994717101}}], 
      PolygonBox[{{-0.4374999810329408, -3.9157074104439378`}, {-0.4375, \
-3.9998768219370047`}, {-0.5, -3.794090994717101}, {-0.4374999810329408, \
-3.9157074104439378`}}], 
      PolygonBox[{{-0.5, -3.9193213332413}, {-0.5, -3.794090994717101}, \
{-0.4375, -3.9998768219370047`}, {-0.5, -3.9193213332413}}], 
      PolygonBox[{{-0.4375, -3.9998768219370047`}, {-0.4374999810329408, \
-4.084292589556055}, {-0.5, -3.9193213332413}, {-0.4375, \
-3.9998768219370047`}}], 
      PolygonBox[{{-0.5, -4.205909005145278}, {-0.5, -3.9193213332413}, \
{-0.4374999810329408, -4.084292589556055}, {-0.5, -4.205909005145278}}], 
      PolygonBox[{{-0.4374999810329408, -4.084292589556055}, \
{-0.4373449933535234, -4.230251642536254}, {-0.5, -4.205909005145278}, \
{-0.4374999810329408, -4.084292589556055}}], 
      PolygonBox[{{-0.5, -4.357662782649365}, {-0.5, -4.205909005145278}, \
{-0.4373449933535234, -4.230251642536254}, {-0.5, -4.357662782649365}}], 
      PolygonBox[{{-0.4373449933535234, -4.230251642536254}, \
{-0.40494274433299715`, -4.404942744332997}, {-0.5, -4.357662782649365}, \
{-0.4373449933535234, -4.230251642536254}}], 
      PolygonBox[{{-0.5, -3.5}, {-0.5, -4.357662782649365}, \
{-0.40494274433299715`, -4.404942744332997}, {-0.5, -3.5}}], 
      PolygonBox[{{-0.40494274433299715`, -4.404942744332997}, \
{-0.23025164253625505`, -4.437344993353523}, {-0.5, -3.5}, \
{-0.40494274433299715`, -4.404942744332997}}], 
      PolygonBox[{{-0.5, -4.5}, {-0.5, -3.5}, {-0.23025164253625505`, \
-4.437344993353523}, {-0.5, -4.5}}], 
      PolygonBox[{{-0.23025164253625505`, -4.437344993353523}, \
{-0.08429258955606422, -4.437499981032941}, {-0.5, -4.5}, \
{-0.23025164253625505`, -4.437344993353523}}], 
      PolygonBox[{{-0.20590900556682806`, -4.5}, {-0.5, -4.5}, \
{-0.08429258955606422, -4.437499981032941}, {-0.20590900556682806`, -4.5}}], 
      PolygonBox[{{-0.08429258955606422, -4.437499981032941}, {
       0.0001348418310429853, -4.4375}, {-0.20590900556682806`, -4.5}, \
{-0.08429258955606422, -4.437499981032941}}], 
      PolygonBox[{{0.0823238704010616, -4.5}, {-0.20590900556682806`, -4.5}, {
       0.0001348418310429853, -4.4375}, {0.0823238704010616, -4.5}}], 
      PolygonBox[{{0.0001348418310429853, -4.4375}, {
       0.08429258955605314, -4.437499981032941}, {0.0823238704010616, -4.5}, {
       0.0001348418310429853, -4.4375}}], 
      PolygonBox[{{0.2059090053603974, -4.5}, {0.0823238704010616, -4.5}, {
       0.08429258955605314, -4.437499981032941}, {0.2059090053603974, -4.5}}],
       PolygonBox[{{0.08429258955605314, -4.437499981032941}, {
       0.2302516425362547, -4.437344993353523}, {0.2059090053603974, -4.5}, {
       0.08429258955605314, -4.437499981032941}}], 
      PolygonBox[{{0.35766278264937107`, -4.5}, {0.2059090053603974, -4.5}, {
       0.2302516425362547, -4.437344993353523}, {
       0.35766278264937107`, -4.5}}], 
      PolygonBox[{{0.2302516425362547, -4.437344993353523}, {
       0.4049427443329971, -4.404942744332997}, {
       0.35766278264937107`, -4.5}, {
       0.2302516425362547, -4.437344993353523}}], 
      PolygonBox[{{0.5, -4.5}, {0.35766278264937107`, -4.5}, {
       0.4049427443329971, -4.404942744332997}, {0.5, -4.5}}], 
      PolygonBox[{{0.4049427443329971, -4.404942744332997}, {
       0.40494274433299715`, -4.404942744332997}, {0.5, -4.5}, {
       0.4049427443329971, -4.404942744332997}}], 
      PolygonBox[{{0.5, -4.5}, {0.5, -4.5}, {
       0.40494274433299715`, -4.404942744332997}, {
       0.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, -3.}, {-0.4791666666666667, -3.}, {-0.4583333333333333, \
-3.}, {-0.4375, -3.}, {-0.4166666666666667, -3.}, {-0.39583333333333337`, \
-3.}, {-0.375, -3.}, {-0.375, -3.}, {-0.3958333333333333, -3.}, \
{-0.4166666666666667, -3.}, {-0.4375, -3.}, {-0.4583333333333333, -3.}, \
{-0.47916666666666663`, -3.}, {-0.5, -3.}, {-0.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, -3.}, {0.3958333333333333, -3.}, {
       0.4166666666666667, -3.}, {0.4375, -3.}, {0.4583333333333333, -3.}, {
       0.47916666666666663`, -3.}, {0.5, -3.}, {0.5, -3.}, {
       0.4791666666666667, -3.}, {0.4583333333333333, -3.}, {0.4375, -3.}, {
       0.4166666666666667, -3.}, {0.39583333333333337`, -3.}, {0.375, -3.}, {
       0.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -3.5}, {0., -3.4791666666666665`}, {
       0., -3.4583333333333335`}, {0., -3.4375}, {0., -3.4166666666666665`}, {
       0., -3.3958333333333335`}, {0., -3.375}, {0., -3.375}, {
       0., -3.3958333333333335`}, {0., -3.4166666666666665`}, {0., -3.4375}, {
       0., -3.4583333333333335`}, {0., -3.4791666666666665`}, {0., -3.5}, {
       0., -3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -2.625}, {0., -2.6041666666666665`}, {
       0., -2.5833333333333335`}, {0., -2.5625}, {0., -2.5416666666666665`}, {
       0., -2.5208333333333335`}, {0., -2.5}, {0., -2.5}, {
       0., -2.5208333333333335`}, {0., -2.5416666666666665`}, {0., -2.5625}, {
       0., -2.5833333333333335`}, {0., -2.6041666666666665`}, {0., -2.625}, {
       0., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, -3.}, {-0.25, -3.}, {-0.125, -3.}, {0., -3.}, {
       0.125, -3.}, {0.25, -3.}, {0.375, -3.}, {0.375, -3.}, {0.25, -3.}, {
       0.125, -3.}, {
       0., -3.}, {-0.125, -3.}, {-0.25, -3.}, {-0.375, -3.}, {-0.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -3.375}, {0., -3.25}, {0., -3.125}, {0., -3.}, {
       0., -2.875}, {0., -2.75}, {0., -2.625}, {0., -2.625}, {0., -2.75}, {
       0., -2.875}, {0., -3.}, {0., -3.125}, {0., -3.25}, {0., -3.375}, {
       0., -3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CE0x4GA/rKvS/Wu22+UfitlZcl+oMHSSe/O
iSsQ+Qa2A7dy7p8p+3HBPlUoRe3jA9YDEDNO2F/YYV71JI31wL3OmEV7buyw
F9MLdNSWYj3A1TXPx7KyygZiPuuBqxD5/TD5v/9B4Ph+mP6bEPP3w8yvh9i/
H2a/P8R9+2Hug7p/P5r79/s9EXp69BjHgUYU/ZwH7kDNn/129k0+ea4DbBD3
7zdwP9EqPZPrwFuo+15dXLfvylOuAx3Py36+ujV5D8R87gNnoP6DyX+HuN8e
pv8GNHxg5tehhB/nAT9o+PpD3Yce/gCjp7J2
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CE0y4GwUBC4isY/CuczoACWAyEQ+f2o/Kv7
UdU/IMgHawtlhfNXrwIBNjT1HGjqOeF8sPJVXGjqeTD4YSjug/GPoqmHAR6Y
/+xR+VftUdU/IMhfjeo+ezT326P5zx7N//ZhqOEDjw8AoIxikA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, -3.2651650429449552`}, {
       0.3247595264191645, -3.1875}, {
       0.40494274433299715`, -3.404942744332997}, {
       0.26516504294495535`, -3.2651650429449552`}}], 
      PolygonBox[{{0.4373449933535234, -3.2302516425362553`}, {
       0.40494274433299715`, -3.404942744332997}, {
       0.3247595264191645, -3.1875}, {
       0.4373449933535234, -3.2302516425362553`}}], 
      PolygonBox[{{0.3247595264191645, -3.1875}, {
       0.36222218485840063`, -3.0970571419134454`}, {
       0.4373449933535234, -3.2302516425362553`}, {
       0.3247595264191645, -3.1875}}], 
      PolygonBox[{{0.4374999810329408, -3.084292589556062}, {
       0.4373449933535234, -3.2302516425362553`}, {
       0.36222218485840063`, -3.0970571419134454`}, {
       0.4374999810329408, -3.084292589556062}}], 
      PolygonBox[{{0.36222218485840063`, -3.0970571419134454`}, {
       0.375, -3.}, {0.4374999810329408, -3.084292589556062}, {
       0.36222218485840063`, -3.0970571419134454`}}], 
      PolygonBox[{{0.4375, -3.}, {0.4374999810329408, -3.084292589556062}, {
       0.375, -3.}, {0.4375, -3.}}], 
      PolygonBox[{{0.375, -3.}, {
       0.36222218485840063`, -2.9029428580865546`}, {0.4375, -3.}, {
       0.375, -3.}}], 
      PolygonBox[{{0.4374999810329408, -2.915707410443938}, {0.4375, -3.}, {
       0.36222218485840063`, -2.9029428580865546`}, {
       0.4374999810329408, -2.915707410443938}}], 
      PolygonBox[{{0.36222218485840063`, -2.9029428580865546`}, {
       0.3247595264191645, -2.8125}, {
       0.4374999810329408, -2.915707410443938}, {
       0.36222218485840063`, -2.9029428580865546`}}], 
      PolygonBox[{{0.4373449933535234, -2.769748357463745}, {
       0.4374999810329408, -2.915707410443938}, {
       0.3247595264191645, -2.8125}, {
       0.4373449933535234, -2.769748357463745}}], 
      PolygonBox[{{0.3247595264191645, -2.8125}, {
       0.26516504294495535`, -2.7348349570550448`}, {
       0.4373449933535234, -2.769748357463745}, {
       0.3247595264191645, -2.8125}}], 
      PolygonBox[{{0.4049427443329971, -2.595057255667003}, {
       0.4373449933535234, -2.769748357463745}, {
       0.26516504294495535`, -2.7348349570550448`}, {
       0.4049427443329971, -2.595057255667003}}], 
      PolygonBox[{{0.26516504294495535`, -2.7348349570550448`}, {
       0.18750000000000006`, -2.6752404735808355`}, {
       0.4049427443329971, -2.595057255667003}, {
       0.26516504294495535`, -2.7348349570550448`}}], 
      PolygonBox[{{0.23025164253625516`, -2.5626550066464766`}, {
       0.4049427443329971, -2.595057255667003}, {
       0.18750000000000006`, -2.6752404735808355`}, {
       0.23025164253625516`, -2.5626550066464766`}}], 
      PolygonBox[{{0.18750000000000006`, -2.6752404735808355`}, {
       0.09705714191344536, -2.6377778151415994`}, {
       0.23025164253625516`, -2.5626550066464766`}, {
       0.18750000000000006`, -2.6752404735808355`}}], 
      PolygonBox[{{0.08429258955606053, -2.562500018967059}, {
       0.23025164253625516`, -2.5626550066464766`}, {
       0.09705714191344536, -2.6377778151415994`}, {
       0.08429258955606053, -2.562500018967059}}], 
      PolygonBox[{{0.09705714191344536, -2.6377778151415994`}, {
       2.296212748401287*^-17, -2.625}, {
       0.08429258955606053, -2.562500018967059}, {
       0.09705714191344536, -2.6377778151415994`}}], 
      PolygonBox[{{0.0001055272204876927, -2.5625}, {
       0.08429258955606053, -2.562500018967059}, {
       2.296212748401287*^-17, -2.625}, {0.0001055272204876927, -2.5625}}], 
      PolygonBox[{{
       2.296212748401287*^-17, -2.625}, {-0.09705714191344515, \
-2.6377778151415994`}, {0.0001055272204876927, -2.5625}, {
       2.296212748401287*^-17, -2.625}}], 
      PolygonBox[{{-0.08429258955605684, -2.562500018967059}, {
       0.0001055272204876927, -2.5625}, {-0.09705714191344515, \
-2.6377778151415994`}, {-0.08429258955605684, -2.562500018967059}}], 
      PolygonBox[{{-0.09705714191344515, -2.6377778151415994`}, \
{-0.18749999999999992`, -2.6752404735808355`}, {-0.08429258955605684, \
-2.562500018967059}, {-0.09705714191344515, -2.6377778151415994`}}], 
      PolygonBox[{{-0.23025164253625502`, -2.5626550066464766`}, \
{-0.08429258955605684, -2.562500018967059}, {-0.18749999999999992`, \
-2.6752404735808355`}, {-0.23025164253625502`, -2.5626550066464766`}}], 
      PolygonBox[{{-0.18749999999999992`, -2.6752404735808355`}, \
{-0.2651650429449553, -2.7348349570550448`}, {-0.23025164253625502`, \
-2.5626550066464766`}, {-0.18749999999999992`, -2.6752404735808355`}}], 
      PolygonBox[{{-0.4049427443329971, -2.595057255667003}, \
{-0.23025164253625502`, -2.5626550066464766`}, {-0.2651650429449553, \
-2.7348349570550448`}, {-0.4049427443329971, -2.595057255667003}}], 
      PolygonBox[{{-0.2651650429449553, -2.7348349570550448`}, \
{-0.32475952641916445`, -2.8125}, {-0.4049427443329971, -2.595057255667003}, \
{-0.2651650429449553, -2.7348349570550448`}}], 
      PolygonBox[{{-0.4373449933535234, -2.7697483574637447`}, \
{-0.4049427443329971, -2.595057255667003}, {-0.32475952641916445`, -2.8125}, \
{-0.4373449933535234, -2.7697483574637447`}}], 
      PolygonBox[{{-0.32475952641916445`, -2.8125}, {-0.3622221848584006, \
-2.9029428580865546`}, {-0.4373449933535234, -2.7697483574637447`}, \
{-0.32475952641916445`, -2.8125}}], 
      PolygonBox[{{-0.4374999810329408, -2.9157074104439378`}, \
{-0.4373449933535234, -2.7697483574637447`}, {-0.3622221848584006, \
-2.9029428580865546`}, {-0.4374999810329408, -2.9157074104439378`}}], 
      PolygonBox[{{-0.3622221848584006, -2.9029428580865546`}, {-0.375, -3.}, \
{-0.4374999810329408, -2.9157074104439378`}, {-0.3622221848584006, \
-2.9029428580865546`}}], 
      PolygonBox[{{-0.4375, -2.9998768219370047`}, {-0.4374999810329408, \
-2.9157074104439378`}, {-0.375, -3.}, {-0.4375, -2.9998768219370047`}}], 
      PolygonBox[{{-0.375, -3.}, {-0.36222218485840063`, -3.097057141913445}, \
{-0.4375, -2.9998768219370047`}, {-0.375, -3.}}], 
      PolygonBox[{{-0.4374999810329408, -3.084292589556055}, {-0.4375, \
-2.9998768219370047`}, {-0.36222218485840063`, -3.097057141913445}, \
{-0.4374999810329408, -3.084292589556055}}], 
      PolygonBox[{{-0.36222218485840063`, -3.097057141913445}, \
{-0.3247595264191646, -3.1875}, {-0.4374999810329408, -3.084292589556055}, \
{-0.36222218485840063`, -3.097057141913445}}], 
      PolygonBox[{{-0.4373449933535234, -3.230251642536255}, \
{-0.4374999810329408, -3.084292589556055}, {-0.3247595264191646, -3.1875}, \
{-0.4373449933535234, -3.230251642536255}}], 
      PolygonBox[{{-0.3247595264191646, -3.1875}, {-0.26516504294495535`, \
-3.2651650429449552`}, {-0.4373449933535234, -3.230251642536255}, \
{-0.3247595264191646, -3.1875}}], 
      PolygonBox[{{-0.40494274433299715`, -3.404942744332997}, \
{-0.4373449933535234, -3.230251642536255}, {-0.26516504294495535`, \
-3.2651650429449552`}, {-0.40494274433299715`, -3.404942744332997}}], 
      PolygonBox[{{-0.26516504294495535`, -3.2651650429449552`}, \
{-0.18750000000000017`, -3.3247595264191645`}, {-0.40494274433299715`, \
-3.404942744332997}, {-0.26516504294495535`, -3.2651650429449552`}}], 
      PolygonBox[{{-0.23025164253625505`, -3.4373449933535234`}, \
{-0.40494274433299715`, -3.404942744332997}, {-0.18750000000000017`, \
-3.3247595264191645`}, {-0.23025164253625505`, -3.4373449933535234`}}], 
      PolygonBox[{{-0.18750000000000017`, -3.3247595264191645`}, \
{-0.09705714191344557, -3.3622221848584006`}, {-0.23025164253625505`, \
-3.4373449933535234`}, {-0.18750000000000017`, -3.3247595264191645`}}], 
      PolygonBox[{{-0.08429258955606422, -3.437499981032941}, \
{-0.23025164253625505`, -3.4373449933535234`}, {-0.09705714191344557, \
-3.3622221848584006`}, {-0.08429258955606422, -3.437499981032941}}], 
      PolygonBox[{{-0.09705714191344557, -3.3622221848584006`}, {
       6.888638245203862*^-17, -3.375}, {-0.08429258955606422, \
-3.437499981032941}, {-0.09705714191344557, -3.3622221848584006`}}], 
      PolygonBox[{{
       0.0001348418310429853, -3.4375}, {-0.08429258955606422, \
-3.437499981032941}, {6.888638245203862*^-17, -3.375}, {
       0.0001348418310429853, -3.4375}}], 
      PolygonBox[{{6.888638245203862*^-17, -3.375}, {
       0.09705714191344511, -3.3622221848584006`}, {
       0.0001348418310429853, -3.4375}, {6.888638245203862*^-17, -3.375}}], 
      PolygonBox[{{0.08429258955605314, -3.437499981032941}, {
       0.0001348418310429853, -3.4375}, {
       0.09705714191344511, -3.3622221848584006`}, {
       0.08429258955605314, -3.437499981032941}}], 
      PolygonBox[{{0.09705714191344511, -3.3622221848584006`}, {
       0.18749999999999975`, -3.3247595264191645`}, {
       0.08429258955605314, -3.437499981032941}, {
       0.09705714191344511, -3.3622221848584006`}}], 
      PolygonBox[{{0.2302516425362547, -3.4373449933535234`}, {
       0.08429258955605314, -3.437499981032941}, {
       0.18749999999999975`, -3.3247595264191645`}, {
       0.2302516425362547, -3.4373449933535234`}}], 
      PolygonBox[{{0.18749999999999975`, -3.3247595264191645`}, {
       0.26516504294495524`, -3.2651650429449552`}, {
       0.2302516425362547, -3.4373449933535234`}, {
       0.18749999999999975`, -3.3247595264191645`}}], 
      PolygonBox[{{0.4049427443329971, -3.404942744332997}, {
       0.2302516425362547, -3.4373449933535234`}, {
       0.26516504294495524`, -3.2651650429449552`}, {
       0.4049427443329971, -3.404942744332997}}], 
      PolygonBox[{{0.26516504294495524`, -3.2651650429449552`}, {
       0.26516504294495535`, -3.2651650429449552`}, {
       0.4049427443329971, -3.404942744332997}, {
       0.26516504294495524`, -3.2651650429449552`}}], 
      PolygonBox[{{0.40494274433299715`, -3.404942744332997}, {
       0.4049427443329971, -3.404942744332997}, {
       0.26516504294495535`, -3.2651650429449552`}, {
       0.40494274433299715`, -3.404942744332997}}], 
      PolygonBox[{{0.40494274433299715`, -3.404942744332997}, {
       0.4373449933535234, -3.2302516425362553`}, {0.5, -3.5}, {
       0.40494274433299715`, -3.404942744332997}}], 
      PolygonBox[{{0.5, -3.357662782649368}, {0.5, -3.5}, {
       0.4373449933535234, -3.2302516425362553`}, {0.5, -3.357662782649368}}],
       PolygonBox[{{0.4373449933535234, -3.2302516425362553`}, {
       0.4374999810329408, -3.084292589556062}, {0.5, -3.357662782649368}, {
       0.4373449933535234, -3.2302516425362553`}}], 
      PolygonBox[{{0.5, -3.20590900530174}, {0.5, -3.357662782649368}, {
       0.4374999810329408, -3.084292589556062}, {0.5, -3.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, -3.084292589556062}, {0.4375, -3.}, {
       0.5, -3.20590900530174}, {0.4374999810329408, -3.084292589556062}}], 
      PolygonBox[{{0.5, -3.}, {0.5, -3.20590900530174}, {0.4375, -3.}, {
       0.5, -3.}}], 
      PolygonBox[{{0.4375, -3.}, {0.4374999810329408, -2.915707410443938}, {
       0.5, -3.}, {0.4375, -3.}}], 
      PolygonBox[{{0.5, -2.79409099469826}, {0.5, -3.}, {
       0.4374999810329408, -2.915707410443938}, {0.5, -2.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, -2.915707410443938}, {
       0.4373449933535234, -2.769748357463745}, {0.5, -2.79409099469826}, {
       0.4374999810329408, -2.915707410443938}}], 
      PolygonBox[{{0.5, -2.6423372173506325`}, {0.5, -2.79409099469826}, {
       0.4373449933535234, -2.769748357463745}, {0.5, -2.6423372173506325`}}],
       PolygonBox[{{0.4373449933535234, -2.769748357463745}, {
       0.4049427443329971, -2.595057255667003}, {0.5, -2.6423372173506325`}, {
       0.4373449933535234, -2.769748357463745}}], 
      PolygonBox[{{0.491446564961186, -2.508553435038814}, {
       0.5, -2.6423372173506325`}, {0.4049427443329971, -2.595057255667003}, {
       0.491446564961186, -2.508553435038814}}], 
      PolygonBox[{{0.4049427443329971, -2.595057255667003}, {
       0.23025164253625516`, -2.5626550066464766`}, {
       0.491446564961186, -2.508553435038814}, {
       0.4049427443329971, -2.595057255667003}}], 
      PolygonBox[{{0.35766278264936807`, -2.5}, {
       0.491446564961186, -2.508553435038814}, {
       0.23025164253625516`, -2.5626550066464766`}, {
       0.35766278264936807`, -2.5}}], 
      PolygonBox[{{0.23025164253625516`, -2.5626550066464766`}, {
       0.08429258955606053, -2.562500018967059}, {
       0.35766278264936807`, -2.5}, {
       0.23025164253625516`, -2.5626550066464766`}}], 
      PolygonBox[{{0.20590900537325585`, -2.5}, {
       0.35766278264936807`, -2.5}, {
       0.08429258955606053, -2.562500018967059}, {
       0.20590900537325585`, -2.5}}], 
      PolygonBox[{{0.08429258955606053, -2.562500018967059}, {
       0.0001055272204876927, -2.5625}, {0.20590900537325585`, -2.5}, {
       0.08429258955606053, -2.562500018967059}}], 
      PolygonBox[{{0.07794195802689004, -2.5}, {0.20590900537325585`, -2.5}, {
       0.0001055272204876927, -2.5625}, {0.07794195802689004, -2.5}}], 
      PolygonBox[{{
       0.0001055272204876927, -2.5625}, {-0.08429258955605684, \
-2.562500018967059}, {0.07794195802689004, -2.5}, {
       0.0001055272204876927, -2.5625}}], 
      PolygonBox[{{-0.20590900530444564`, -2.5}, {
       0.07794195802689004, -2.5}, {-0.08429258955605684, \
-2.562500018967059}, {-0.20590900530444564`, -2.5}}], 
      PolygonBox[{{-0.08429258955605684, -2.562500018967059}, \
{-0.23025164253625502`, -2.5626550066464766`}, {-0.20590900530444564`, -2.5}, \
{-0.08429258955605684, -2.562500018967059}}], 
      PolygonBox[{{-0.35766278264936624`, -2.5}, {-0.20590900530444564`, \
-2.5}, {-0.23025164253625502`, -2.5626550066464766`}, {-0.35766278264936624`, \
-2.5}}], PolygonBox[{{-0.23025164253625502`, -2.5626550066464766`}, \
{-0.4049427443329971, -2.595057255667003}, {-0.35766278264936624`, -2.5}, \
{-0.23025164253625502`, -2.5626550066464766`}}], 
      PolygonBox[{{
       0.5, -2.5}, {-0.35766278264936624`, -2.5}, {-0.4049427443329971, \
-2.595057255667003}, {0.5, -2.5}}], 
      PolygonBox[{{-0.4049427443329971, -2.595057255667003}, \
{-0.4373449933535234, -2.7697483574637447`}, {
       0.5, -2.5}, {-0.4049427443329971, -2.595057255667003}}], 
      PolygonBox[{{-0.5, -2.642337217350631}, {
       0.5, -2.5}, {-0.4373449933535234, -2.7697483574637447`}, {-0.5, \
-2.642337217350631}}], 
      PolygonBox[{{-0.4373449933535234, -2.7697483574637447`}, \
{-0.4374999810329408, -2.9157074104439378`}, {-0.5, -2.642337217350631}, \
{-0.4373449933535234, -2.7697483574637447`}}], 
      PolygonBox[{{-0.5, -2.794090994717101}, {-0.5, -2.642337217350631}, \
{-0.4374999810329408, -2.9157074104439378`}, {-0.5, -2.794090994717101}}], 
      PolygonBox[{{-0.4374999810329408, -2.9157074104439378`}, {-0.4375, \
-2.9998768219370047`}, {-0.5, -2.794090994717101}, {-0.4374999810329408, \
-2.9157074104439378`}}], 
      PolygonBox[{{-0.5, -2.9193213332413}, {-0.5, -2.794090994717101}, \
{-0.4375, -2.9998768219370047`}, {-0.5, -2.9193213332413}}], 
      PolygonBox[{{-0.4375, -2.9998768219370047`}, {-0.4374999810329408, \
-3.084292589556055}, {-0.5, -2.9193213332413}, {-0.4375, \
-2.9998768219370047`}}], 
      PolygonBox[{{-0.5, -3.2059090051452785`}, {-0.5, -2.9193213332413}, \
{-0.4374999810329408, -3.084292589556055}, {-0.5, -3.2059090051452785`}}], 
      PolygonBox[{{-0.4374999810329408, -3.084292589556055}, \
{-0.4373449933535234, -3.230251642536255}, {-0.5, -3.2059090051452785`}, \
{-0.4374999810329408, -3.084292589556055}}], 
      PolygonBox[{{-0.5, -3.3576627826493652`}, {-0.5, -3.2059090051452785`}, \
{-0.4373449933535234, -3.230251642536255}, {-0.5, -3.3576627826493652`}}], 
      PolygonBox[{{-0.4373449933535234, -3.230251642536255}, \
{-0.40494274433299715`, -3.404942744332997}, {-0.5, -3.3576627826493652`}, \
{-0.4373449933535234, -3.230251642536255}}], 
      PolygonBox[{{-0.5, -2.5}, {-0.5, -3.3576627826493652`}, \
{-0.40494274433299715`, -3.404942744332997}, {-0.5, -2.5}}], 
      PolygonBox[{{-0.40494274433299715`, -3.404942744332997}, \
{-0.23025164253625505`, -3.4373449933535234`}, {-0.5, -2.5}, \
{-0.40494274433299715`, -3.404942744332997}}], 
      PolygonBox[{{-0.5, -3.5}, {-0.5, -2.5}, {-0.23025164253625505`, \
-3.4373449933535234`}, {-0.5, -3.5}}], 
      PolygonBox[{{-0.23025164253625505`, -3.4373449933535234`}, \
{-0.08429258955606422, -3.437499981032941}, {-0.5, -3.5}, \
{-0.23025164253625505`, -3.4373449933535234`}}], 
      PolygonBox[{{-0.20590900556682806`, -3.5}, {-0.5, -3.5}, \
{-0.08429258955606422, -3.437499981032941}, {-0.20590900556682806`, -3.5}}], 
      PolygonBox[{{-0.08429258955606422, -3.437499981032941}, {
       0.0001348418310429853, -3.4375}, {-0.20590900556682806`, -3.5}, \
{-0.08429258955606422, -3.437499981032941}}], 
      PolygonBox[{{0.0823238704010616, -3.5}, {-0.20590900556682806`, -3.5}, {
       0.0001348418310429853, -3.4375}, {0.0823238704010616, -3.5}}], 
      PolygonBox[{{0.0001348418310429853, -3.4375}, {
       0.08429258955605314, -3.437499981032941}, {0.0823238704010616, -3.5}, {
       0.0001348418310429853, -3.4375}}], 
      PolygonBox[{{0.2059090053603974, -3.5}, {0.0823238704010616, -3.5}, {
       0.08429258955605314, -3.437499981032941}, {0.2059090053603974, -3.5}}],
       PolygonBox[{{0.08429258955605314, -3.437499981032941}, {
       0.2302516425362547, -3.4373449933535234`}, {
       0.2059090053603974, -3.5}, {0.08429258955605314, -3.437499981032941}}],
       PolygonBox[{{0.35766278264937107`, -3.5}, {0.2059090053603974, -3.5}, {
       0.2302516425362547, -3.4373449933535234`}, {
       0.35766278264937107`, -3.5}}], 
      PolygonBox[{{0.2302516425362547, -3.4373449933535234`}, {
       0.4049427443329971, -3.404942744332997}, {
       0.35766278264937107`, -3.5}, {
       0.2302516425362547, -3.4373449933535234`}}], 
      PolygonBox[{{0.5, -3.5}, {0.35766278264937107`, -3.5}, {
       0.4049427443329971, -3.404942744332997}, {0.5, -3.5}}], 
      PolygonBox[{{0.4049427443329971, -3.404942744332997}, {
       0.40494274433299715`, -3.404942744332997}, {0.5, -3.5}, {
       0.4049427443329971, -3.404942744332997}}], 
      PolygonBox[{{0.5, -3.5}, {0.5, -3.5}, {
       0.40494274433299715`, -3.404942744332997}, {
       0.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, -2.}, {-0.4791666666666667, -2.}, {-0.4583333333333333, \
-2.}, {-0.4375, -2.}, {-0.4166666666666667, -2.}, {-0.39583333333333337`, \
-2.}, {-0.375, -2.}, {-0.375, -2.}, {-0.3958333333333333, -2.}, \
{-0.4166666666666667, -2.}, {-0.4375, -2.}, {-0.4583333333333333, -2.}, \
{-0.47916666666666663`, -2.}, {-0.5, -2.}, {-0.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, -2.}, {0.3958333333333333, -2.}, {
       0.4166666666666667, -2.}, {0.4375, -2.}, {0.4583333333333333, -2.}, {
       0.47916666666666663`, -2.}, {0.5, -2.}, {0.5, -2.}, {
       0.4791666666666667, -2.}, {0.4583333333333333, -2.}, {0.4375, -2.}, {
       0.4166666666666667, -2.}, {0.39583333333333337`, -2.}, {0.375, -2.}, {
       0.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -2.5}, {0., -2.4791666666666665`}, {
       0., -2.4583333333333335`}, {0., -2.4375}, {0., -2.4166666666666665`}, {
       0., -2.3958333333333335`}, {0., -2.375}, {0., -2.375}, {
       0., -2.3958333333333335`}, {0., -2.4166666666666665`}, {0., -2.4375}, {
       0., -2.4583333333333335`}, {0., -2.4791666666666665`}, {0., -2.5}, {
       0., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -1.625}, {0., -1.6041666666666667`}, {
       0., -1.5833333333333333`}, {0., -1.5625}, {0., -1.5416666666666667`}, {
       0., -1.5208333333333335`}, {0., -1.5}, {0., -1.5}, {
       0., -1.5208333333333333`}, {0., -1.5416666666666667`}, {0., -1.5625}, {
       0., -1.5833333333333333`}, {0., -1.6041666666666665`}, {0., -1.625}, {
       0., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, -2.}, {-0.25, -2.}, {-0.125, -2.}, {0., -2.}, {
       0.125, -2.}, {0.25, -2.}, {0.375, -2.}, {0.375, -2.}, {0.25, -2.}, {
       0.125, -2.}, {
       0., -2.}, {-0.125, -2.}, {-0.25, -2.}, {-0.375, -2.}, {-0.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -2.375}, {0., -2.25}, {0., -2.125}, {0., -2.}, {
       0., -1.875}, {0., -1.75}, {0., -1.625}, {0., -1.625}, {0., -1.75}, {
       0., -1.875}, {0., -2.}, {0., -2.125}, {0., -2.25}, {0., -2.375}, {
       0., -2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37KGMAwH9ZV+X6l23TzK/ZVpS9G9/g6WT3p0T
V6Dyf/ffyrl/puzHBftTKid8Hh38vR9ixgn7BYX5X06c/bX/XmfMoj03dtjr
xCxqCjP5tZ+ra56PZWWVDUT/r/1XIfL7YfJ//4PA8f0w/Tch5u+HmV8PsX8/
zH5/iPv2w9wHdf9+NPfv93si9PToMYYDjcj6GxgP3IGaP/vt7Jt88kwH2CDu
32/gfqJVeibTgbdQ9726uG7fladMBzqel/18dWvyHojxzAfOQP0Hk/8Ocb89
TP8NaPjAzK9DDj+g/X7Q8PWHug89/AF7BcEE
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CH0j/1hoSBwFY1/FM5nQAE/9odA5Pej8q/u
R1X/gCB/FRj8gvPBxoT+RVPPcABVnvEAqn6mA6jqWTD4YSjug/GPoqmHAZYD
ISj+h/Gv2qOqf0CQvxrVffZo7rdH8599GKr/ofrh4QOPDwD4wm52
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, -2.2651650429449552`}, {
       0.3247595264191645, -2.1875}, {
       0.40494274433299715`, -2.404942744332997}, {
       0.26516504294495535`, -2.2651650429449552`}}], 
      PolygonBox[{{0.4373449933535234, -2.2302516425362553`}, {
       0.40494274433299715`, -2.404942744332997}, {
       0.3247595264191645, -2.1875}, {
       0.4373449933535234, -2.2302516425362553`}}], 
      PolygonBox[{{0.3247595264191645, -2.1875}, {
       0.36222218485840063`, -2.0970571419134454`}, {
       0.4373449933535234, -2.2302516425362553`}, {
       0.3247595264191645, -2.1875}}], 
      PolygonBox[{{0.4374999810329408, -2.084292589556062}, {
       0.4373449933535234, -2.2302516425362553`}, {
       0.36222218485840063`, -2.0970571419134454`}, {
       0.4374999810329408, -2.084292589556062}}], 
      PolygonBox[{{0.36222218485840063`, -2.0970571419134454`}, {
       0.375, -2.}, {0.4374999810329408, -2.084292589556062}, {
       0.36222218485840063`, -2.0970571419134454`}}], 
      PolygonBox[{{0.4375, -2.}, {0.4374999810329408, -2.084292589556062}, {
       0.375, -2.}, {0.4375, -2.}}], 
      PolygonBox[{{0.375, -2.}, {
       0.36222218485840063`, -1.9029428580865548`}, {0.4375, -2.}, {
       0.375, -2.}}], 
      PolygonBox[{{0.4374999810329408, -1.9157074104439382`}, {0.4375, -2.}, {
       0.36222218485840063`, -1.9029428580865548`}, {
       0.4374999810329408, -1.9157074104439382`}}], 
      PolygonBox[{{0.36222218485840063`, -1.9029428580865548`}, {
       0.3247595264191645, -1.8125}, {
       0.4374999810329408, -1.9157074104439382`}, {
       0.36222218485840063`, -1.9029428580865548`}}], 
      PolygonBox[{{0.4373449933535234, -1.769748357463745}, {
       0.4374999810329408, -1.9157074104439382`}, {
       0.3247595264191645, -1.8125}, {
       0.4373449933535234, -1.769748357463745}}], 
      PolygonBox[{{0.3247595264191645, -1.8125}, {
       0.26516504294495535`, -1.7348349570550448`}, {
       0.4373449933535234, -1.769748357463745}, {
       0.3247595264191645, -1.8125}}], 
      PolygonBox[{{0.4049427443329971, -1.5950572556670028`}, {
       0.4373449933535234, -1.769748357463745}, {
       0.26516504294495535`, -1.7348349570550448`}, {
       0.4049427443329971, -1.5950572556670028`}}], 
      PolygonBox[{{0.26516504294495535`, -1.7348349570550448`}, {
       0.18750000000000006`, -1.6752404735808355`}, {
       0.4049427443329971, -1.5950572556670028`}, {
       0.26516504294495535`, -1.7348349570550448`}}], 
      PolygonBox[{{0.23025164253625516`, -1.5626550066464766`}, {
       0.4049427443329971, -1.5950572556670028`}, {
       0.18750000000000006`, -1.6752404735808355`}, {
       0.23025164253625516`, -1.5626550066464766`}}], 
      PolygonBox[{{0.18750000000000006`, -1.6752404735808355`}, {
       0.09705714191344536, -1.6377778151415994`}, {
       0.23025164253625516`, -1.5626550066464766`}, {
       0.18750000000000006`, -1.6752404735808355`}}], 
      PolygonBox[{{0.08429258955606053, -1.5625000189670593`}, {
       0.23025164253625516`, -1.5626550066464766`}, {
       0.09705714191344536, -1.6377778151415994`}, {
       0.08429258955606053, -1.5625000189670593`}}], 
      PolygonBox[{{0.09705714191344536, -1.6377778151415994`}, {
       2.296212748401287*^-17, -1.625}, {
       0.08429258955606053, -1.5625000189670593`}, {
       0.09705714191344536, -1.6377778151415994`}}], 
      PolygonBox[{{0.0001055272204876927, -1.5625}, {
       0.08429258955606053, -1.5625000189670593`}, {
       2.296212748401287*^-17, -1.625}, {0.0001055272204876927, -1.5625}}], 
      PolygonBox[{{
       2.296212748401287*^-17, -1.625}, {-0.09705714191344515, \
-1.6377778151415994`}, {0.0001055272204876927, -1.5625}, {
       2.296212748401287*^-17, -1.625}}], 
      PolygonBox[{{-0.08429258955605684, -1.5625000189670593`}, {
       0.0001055272204876927, -1.5625}, {-0.09705714191344515, \
-1.6377778151415994`}, {-0.08429258955605684, -1.5625000189670593`}}], 
      PolygonBox[{{-0.09705714191344515, -1.6377778151415994`}, \
{-0.18749999999999992`, -1.6752404735808355`}, {-0.08429258955605684, \
-1.5625000189670593`}, {-0.09705714191344515, -1.6377778151415994`}}], 
      PolygonBox[{{-0.23025164253625502`, -1.5626550066464766`}, \
{-0.08429258955605684, -1.5625000189670593`}, {-0.18749999999999992`, \
-1.6752404735808355`}, {-0.23025164253625502`, -1.5626550066464766`}}], 
      PolygonBox[{{-0.18749999999999992`, -1.6752404735808355`}, \
{-0.2651650429449553, -1.7348349570550448`}, {-0.23025164253625502`, \
-1.5626550066464766`}, {-0.18749999999999992`, -1.6752404735808355`}}], 
      PolygonBox[{{-0.4049427443329971, -1.5950572556670028`}, \
{-0.23025164253625502`, -1.5626550066464766`}, {-0.2651650429449553, \
-1.7348349570550448`}, {-0.4049427443329971, -1.5950572556670028`}}], 
      PolygonBox[{{-0.2651650429449553, -1.7348349570550448`}, \
{-0.32475952641916445`, -1.8125}, {-0.4049427443329971, \
-1.5950572556670028`}, {-0.2651650429449553, -1.7348349570550448`}}], 
      PolygonBox[{{-0.4373449933535234, -1.7697483574637447`}, \
{-0.4049427443329971, -1.5950572556670028`}, {-0.32475952641916445`, \
-1.8125}, {-0.4373449933535234, -1.7697483574637447`}}], 
      PolygonBox[{{-0.32475952641916445`, -1.8125}, {-0.3622221848584006, \
-1.9029428580865546`}, {-0.4373449933535234, -1.7697483574637447`}, \
{-0.32475952641916445`, -1.8125}}], 
      PolygonBox[{{-0.4374999810329408, -1.9157074104439376`}, \
{-0.4373449933535234, -1.7697483574637447`}, {-0.3622221848584006, \
-1.9029428580865546`}, {-0.4374999810329408, -1.9157074104439376`}}], 
      PolygonBox[{{-0.3622221848584006, -1.9029428580865546`}, {-0.375, \
-1.9999999999999998`}, {-0.4374999810329408, -1.9157074104439376`}, \
{-0.3622221848584006, -1.9029428580865546`}}], 
      PolygonBox[{{-0.4375, -1.9998768219370047`}, {-0.4374999810329408, \
-1.9157074104439376`}, {-0.375, -1.9999999999999998`}, {-0.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-0.375, -1.9999999999999998`}, {-0.36222218485840063`, \
-2.097057141913445}, {-0.4375, -1.9998768219370047`}, {-0.375, \
-1.9999999999999998`}}], 
      PolygonBox[{{-0.4374999810329408, -2.084292589556055}, {-0.4375, \
-1.9998768219370047`}, {-0.36222218485840063`, -2.097057141913445}, \
{-0.4374999810329408, -2.084292589556055}}], 
      PolygonBox[{{-0.36222218485840063`, -2.097057141913445}, \
{-0.3247595264191646, -2.1875}, {-0.4374999810329408, -2.084292589556055}, \
{-0.36222218485840063`, -2.097057141913445}}], 
      PolygonBox[{{-0.4373449933535234, -2.230251642536255}, \
{-0.4374999810329408, -2.084292589556055}, {-0.3247595264191646, -2.1875}, \
{-0.4373449933535234, -2.230251642536255}}], 
      PolygonBox[{{-0.3247595264191646, -2.1875}, {-0.26516504294495535`, \
-2.2651650429449552`}, {-0.4373449933535234, -2.230251642536255}, \
{-0.3247595264191646, -2.1875}}], 
      PolygonBox[{{-0.40494274433299715`, -2.404942744332997}, \
{-0.4373449933535234, -2.230251642536255}, {-0.26516504294495535`, \
-2.2651650429449552`}, {-0.40494274433299715`, -2.404942744332997}}], 
      PolygonBox[{{-0.26516504294495535`, -2.2651650429449552`}, \
{-0.18750000000000017`, -2.3247595264191645`}, {-0.40494274433299715`, \
-2.404942744332997}, {-0.26516504294495535`, -2.2651650429449552`}}], 
      PolygonBox[{{-0.23025164253625505`, -2.4373449933535234`}, \
{-0.40494274433299715`, -2.404942744332997}, {-0.18750000000000017`, \
-2.3247595264191645`}, {-0.23025164253625505`, -2.4373449933535234`}}], 
      PolygonBox[{{-0.18750000000000017`, -2.3247595264191645`}, \
{-0.09705714191344557, -2.3622221848584006`}, {-0.23025164253625505`, \
-2.4373449933535234`}, {-0.18750000000000017`, -2.3247595264191645`}}], 
      PolygonBox[{{-0.08429258955606422, -2.437499981032941}, \
{-0.23025164253625505`, -2.4373449933535234`}, {-0.09705714191344557, \
-2.3622221848584006`}, {-0.08429258955606422, -2.437499981032941}}], 
      PolygonBox[{{-0.09705714191344557, -2.3622221848584006`}, {
       6.888638245203862*^-17, -2.375}, {-0.08429258955606422, \
-2.437499981032941}, {-0.09705714191344557, -2.3622221848584006`}}], 
      PolygonBox[{{
       0.0001348418310429853, -2.4375}, {-0.08429258955606422, \
-2.437499981032941}, {6.888638245203862*^-17, -2.375}, {
       0.0001348418310429853, -2.4375}}], 
      PolygonBox[{{6.888638245203862*^-17, -2.375}, {
       0.09705714191344511, -2.3622221848584006`}, {
       0.0001348418310429853, -2.4375}, {6.888638245203862*^-17, -2.375}}], 
      PolygonBox[{{0.08429258955605314, -2.437499981032941}, {
       0.0001348418310429853, -2.4375}, {
       0.09705714191344511, -2.3622221848584006`}, {
       0.08429258955605314, -2.437499981032941}}], 
      PolygonBox[{{0.09705714191344511, -2.3622221848584006`}, {
       0.18749999999999975`, -2.3247595264191645`}, {
       0.08429258955605314, -2.437499981032941}, {
       0.09705714191344511, -2.3622221848584006`}}], 
      PolygonBox[{{0.2302516425362547, -2.4373449933535234`}, {
       0.08429258955605314, -2.437499981032941}, {
       0.18749999999999975`, -2.3247595264191645`}, {
       0.2302516425362547, -2.4373449933535234`}}], 
      PolygonBox[{{0.18749999999999975`, -2.3247595264191645`}, {
       0.26516504294495524`, -2.2651650429449552`}, {
       0.2302516425362547, -2.4373449933535234`}, {
       0.18749999999999975`, -2.3247595264191645`}}], 
      PolygonBox[{{0.4049427443329971, -2.404942744332997}, {
       0.2302516425362547, -2.4373449933535234`}, {
       0.26516504294495524`, -2.2651650429449552`}, {
       0.4049427443329971, -2.404942744332997}}], 
      PolygonBox[{{0.26516504294495524`, -2.2651650429449552`}, {
       0.26516504294495535`, -2.2651650429449552`}, {
       0.4049427443329971, -2.404942744332997}, {
       0.26516504294495524`, -2.2651650429449552`}}], 
      PolygonBox[{{0.40494274433299715`, -2.404942744332997}, {
       0.4049427443329971, -2.404942744332997}, {
       0.26516504294495535`, -2.2651650429449552`}, {
       0.40494274433299715`, -2.404942744332997}}], 
      PolygonBox[{{0.40494274433299715`, -2.404942744332997}, {
       0.4373449933535234, -2.2302516425362553`}, {0.5, -2.5}, {
       0.40494274433299715`, -2.404942744332997}}], 
      PolygonBox[{{0.5, -2.357662782649368}, {0.5, -2.5}, {
       0.4373449933535234, -2.2302516425362553`}, {0.5, -2.357662782649368}}],
       PolygonBox[{{0.4373449933535234, -2.2302516425362553`}, {
       0.4374999810329408, -2.084292589556062}, {0.5, -2.357662782649368}, {
       0.4373449933535234, -2.2302516425362553`}}], 
      PolygonBox[{{0.5, -2.20590900530174}, {0.5, -2.357662782649368}, {
       0.4374999810329408, -2.084292589556062}, {0.5, -2.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, -2.084292589556062}, {0.4375, -2.}, {
       0.5, -2.20590900530174}, {0.4374999810329408, -2.084292589556062}}], 
      PolygonBox[{{0.5, -2.}, {0.5, -2.20590900530174}, {0.4375, -2.}, {
       0.5, -2.}}], 
      PolygonBox[{{0.4375, -2.}, {0.4374999810329408, -1.9157074104439382`}, {
       0.5, -2.}, {0.4375, -2.}}], 
      PolygonBox[{{0.5, -1.7940909946982602`}, {0.5, -2.}, {
       0.4374999810329408, -1.9157074104439382`}, {
       0.5, -1.7940909946982602`}}], 
      PolygonBox[{{0.4374999810329408, -1.9157074104439382`}, {
       0.4373449933535234, -1.769748357463745}, {0.5, -1.7940909946982602`}, {
       0.4374999810329408, -1.9157074104439382`}}], 
      PolygonBox[{{0.5, -1.6423372173506325`}, {0.5, -1.7940909946982602`}, {
       0.4373449933535234, -1.769748357463745}, {0.5, -1.6423372173506325`}}],
       PolygonBox[{{0.4373449933535234, -1.769748357463745}, {
       0.4049427443329971, -1.5950572556670028`}, {
       0.5, -1.6423372173506325`}, {0.4373449933535234, -1.769748357463745}}],
       PolygonBox[{{0.491446564961186, -1.508553435038814}, {
       0.5, -1.6423372173506325`}, {
       0.4049427443329971, -1.5950572556670028`}, {
       0.491446564961186, -1.508553435038814}}], 
      PolygonBox[{{0.4049427443329971, -1.5950572556670028`}, {
       0.23025164253625516`, -1.5626550066464766`}, {
       0.491446564961186, -1.508553435038814}, {
       0.4049427443329971, -1.5950572556670028`}}], 
      PolygonBox[{{0.35766278264936807`, -1.5}, {
       0.491446564961186, -1.508553435038814}, {
       0.23025164253625516`, -1.5626550066464766`}, {
       0.35766278264936807`, -1.5}}], 
      PolygonBox[{{0.23025164253625516`, -1.5626550066464766`}, {
       0.08429258955606053, -1.5625000189670593`}, {
       0.35766278264936807`, -1.5}, {
       0.23025164253625516`, -1.5626550066464766`}}], 
      PolygonBox[{{0.20590900537325585`, -1.5}, {
       0.35766278264936807`, -1.5}, {
       0.08429258955606053, -1.5625000189670593`}, {
       0.20590900537325585`, -1.5}}], 
      PolygonBox[{{0.08429258955606053, -1.5625000189670593`}, {
       0.0001055272204876927, -1.5625}, {0.20590900537325585`, -1.5}, {
       0.08429258955606053, -1.5625000189670593`}}], 
      PolygonBox[{{0.07794195802689004, -1.5}, {0.20590900537325585`, -1.5}, {
       0.0001055272204876927, -1.5625}, {0.07794195802689004, -1.5}}], 
      PolygonBox[{{
       0.0001055272204876927, -1.5625}, {-0.08429258955605684, \
-1.5625000189670593`}, {0.07794195802689004, -1.5}, {
       0.0001055272204876927, -1.5625}}], 
      PolygonBox[{{-0.20590900530444564`, -1.5}, {
       0.07794195802689004, -1.5}, {-0.08429258955605684, \
-1.5625000189670593`}, {-0.20590900530444564`, -1.5}}], 
      PolygonBox[{{-0.08429258955605684, -1.5625000189670593`}, \
{-0.23025164253625502`, -1.5626550066464766`}, {-0.20590900530444564`, -1.5}, \
{-0.08429258955605684, -1.5625000189670593`}}], 
      PolygonBox[{{-0.35766278264936624`, -1.5}, {-0.20590900530444564`, \
-1.5}, {-0.23025164253625502`, -1.5626550066464766`}, {-0.35766278264936624`, \
-1.5}}], PolygonBox[{{-0.23025164253625502`, -1.5626550066464766`}, \
{-0.4049427443329971, -1.5950572556670028`}, {-0.35766278264936624`, -1.5}, \
{-0.23025164253625502`, -1.5626550066464766`}}], 
      PolygonBox[{{
       0.5, -1.5}, {-0.35766278264936624`, -1.5}, {-0.4049427443329971, \
-1.5950572556670028`}, {0.5, -1.5}}], 
      PolygonBox[{{-0.4049427443329971, -1.5950572556670028`}, \
{-0.4373449933535234, -1.7697483574637447`}, {
       0.5, -1.5}, {-0.4049427443329971, -1.5950572556670028`}}], 
      PolygonBox[{{-0.5, -1.642337217350631}, {
       0.5, -1.5}, {-0.4373449933535234, -1.7697483574637447`}, {-0.5, \
-1.642337217350631}}], 
      PolygonBox[{{-0.4373449933535234, -1.7697483574637447`}, \
{-0.4374999810329408, -1.9157074104439376`}, {-0.5, -1.642337217350631}, \
{-0.4373449933535234, -1.7697483574637447`}}], 
      PolygonBox[{{-0.5, -1.794090994717101}, {-0.5, -1.642337217350631}, \
{-0.4374999810329408, -1.9157074104439376`}, {-0.5, -1.794090994717101}}], 
      PolygonBox[{{-0.4374999810329408, -1.9157074104439376`}, {-0.4375, \
-1.9998768219370047`}, {-0.5, -1.794090994717101}, {-0.4374999810329408, \
-1.9157074104439376`}}], 
      PolygonBox[{{-0.5, -1.9193213332412997`}, {-0.5, -1.794090994717101}, \
{-0.4375, -1.9998768219370047`}, {-0.5, -1.9193213332412997`}}], 
      PolygonBox[{{-0.4375, -1.9998768219370047`}, {-0.4374999810329408, \
-2.084292589556055}, {-0.5, -1.9193213332412997`}, {-0.4375, \
-1.9998768219370047`}}], 
      PolygonBox[{{-0.5, -2.2059090051452785`}, {-0.5, -1.9193213332412997`}, \
{-0.4374999810329408, -2.084292589556055}, {-0.5, -2.2059090051452785`}}], 
      PolygonBox[{{-0.4374999810329408, -2.084292589556055}, \
{-0.4373449933535234, -2.230251642536255}, {-0.5, -2.2059090051452785`}, \
{-0.4374999810329408, -2.084292589556055}}], 
      PolygonBox[{{-0.5, -2.3576627826493652`}, {-0.5, -2.2059090051452785`}, \
{-0.4373449933535234, -2.230251642536255}, {-0.5, -2.3576627826493652`}}], 
      PolygonBox[{{-0.4373449933535234, -2.230251642536255}, \
{-0.40494274433299715`, -2.404942744332997}, {-0.5, -2.3576627826493652`}, \
{-0.4373449933535234, -2.230251642536255}}], 
      PolygonBox[{{-0.5, -1.5}, {-0.5, -2.3576627826493652`}, \
{-0.40494274433299715`, -2.404942744332997}, {-0.5, -1.5}}], 
      PolygonBox[{{-0.40494274433299715`, -2.404942744332997}, \
{-0.23025164253625505`, -2.4373449933535234`}, {-0.5, -1.5}, \
{-0.40494274433299715`, -2.404942744332997}}], 
      PolygonBox[{{-0.5, -2.5}, {-0.5, -1.5}, {-0.23025164253625505`, \
-2.4373449933535234`}, {-0.5, -2.5}}], 
      PolygonBox[{{-0.23025164253625505`, -2.4373449933535234`}, \
{-0.08429258955606422, -2.437499981032941}, {-0.5, -2.5}, \
{-0.23025164253625505`, -2.4373449933535234`}}], 
      PolygonBox[{{-0.20590900556682806`, -2.5}, {-0.5, -2.5}, \
{-0.08429258955606422, -2.437499981032941}, {-0.20590900556682806`, -2.5}}], 
      PolygonBox[{{-0.08429258955606422, -2.437499981032941}, {
       0.0001348418310429853, -2.4375}, {-0.20590900556682806`, -2.5}, \
{-0.08429258955606422, -2.437499981032941}}], 
      PolygonBox[{{0.0823238704010616, -2.5}, {-0.20590900556682806`, -2.5}, {
       0.0001348418310429853, -2.4375}, {0.0823238704010616, -2.5}}], 
      PolygonBox[{{0.0001348418310429853, -2.4375}, {
       0.08429258955605314, -2.437499981032941}, {0.0823238704010616, -2.5}, {
       0.0001348418310429853, -2.4375}}], 
      PolygonBox[{{0.2059090053603974, -2.5}, {0.0823238704010616, -2.5}, {
       0.08429258955605314, -2.437499981032941}, {0.2059090053603974, -2.5}}],
       PolygonBox[{{0.08429258955605314, -2.437499981032941}, {
       0.2302516425362547, -2.4373449933535234`}, {
       0.2059090053603974, -2.5}, {0.08429258955605314, -2.437499981032941}}],
       PolygonBox[{{0.35766278264937107`, -2.5}, {0.2059090053603974, -2.5}, {
       0.2302516425362547, -2.4373449933535234`}, {
       0.35766278264937107`, -2.5}}], 
      PolygonBox[{{0.2302516425362547, -2.4373449933535234`}, {
       0.4049427443329971, -2.404942744332997}, {
       0.35766278264937107`, -2.5}, {
       0.2302516425362547, -2.4373449933535234`}}], 
      PolygonBox[{{0.5, -2.5}, {0.35766278264937107`, -2.5}, {
       0.4049427443329971, -2.404942744332997}, {0.5, -2.5}}], 
      PolygonBox[{{0.4049427443329971, -2.404942744332997}, {
       0.40494274433299715`, -2.404942744332997}, {0.5, -2.5}, {
       0.4049427443329971, -2.404942744332997}}], 
      PolygonBox[{{0.5, -2.5}, {0.5, -2.5}, {
       0.40494274433299715`, -2.404942744332997}, {
       0.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, -1.}, {-0.4791666666666667, -1.}, {-0.4583333333333333, \
-1.}, {-0.4375, -1.}, {-0.4166666666666667, -1.}, {-0.39583333333333337`, \
-1.}, {-0.375, -1.}, {-0.375, -1.}, {-0.3958333333333333, -1.}, \
{-0.4166666666666667, -1.}, {-0.4375, -1.}, {-0.4583333333333333, -1.}, \
{-0.47916666666666663`, -1.}, {-0.5, -1.}, {-0.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, -1.}, {0.3958333333333333, -1.}, {
       0.4166666666666667, -1.}, {0.4375, -1.}, {0.4583333333333333, -1.}, {
       0.47916666666666663`, -1.}, {0.5, -1.}, {0.5, -1.}, {
       0.4791666666666667, -1.}, {0.4583333333333333, -1.}, {0.4375, -1.}, {
       0.4166666666666667, -1.}, {0.39583333333333337`, -1.}, {0.375, -1.}, {
       0.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -1.5}, {0., -1.4791666666666667`}, {
       0., -1.4583333333333333`}, {0., -1.4375}, {0., -1.4166666666666667`}, {
       0., -1.3958333333333335`}, {0., -1.375}, {0., -1.375}, {
       0., -1.3958333333333333`}, {0., -1.4166666666666667`}, {0., -1.4375}, {
       0., -1.4583333333333333`}, {0., -1.4791666666666665`}, {0., -1.5}, {
       0., -1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -0.625}, {0., -0.6041666666666667}, {
       0., -0.5833333333333333}, {0., -0.5625}, {0., -0.5416666666666667}, {
       0., -0.5208333333333334}, {0., -0.5}, {0., -0.5}, {
       0., -0.5208333333333333}, {0., -0.5416666666666667}, {0., -0.5625}, {
       0., -0.5833333333333333}, {0., -0.6041666666666666}, {0., -0.625}, {
       0., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, -1.}, {-0.25, -1.}, {-0.125, -1.}, {0., -1.}, {
       0.125, -1.}, {0.25, -1.}, {0.375, -1.}, {0.375, -1.}, {0.25, -1.}, {
       0.125, -1.}, {
       0., -1.}, {-0.125, -1.}, {-0.25, -1.}, {-0.375, -1.}, {-0.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -1.375}, {0., -1.25}, {0., -1.125}, {0., -1.}, {
       0., -0.875}, {0., -0.75}, {0., -0.625}, {0., -0.625}, {0., -0.75}, {
       0., -0.875}, {0., -1.}, {0., -1.125}, {0., -1.25}, {0., -1.375}, {
       0., -1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CH0h/0B/WVfl+pdtz+atyX7xZM3+xssnfTu
nLgClX+1/1bO/TNlPy7YT/GcMPNI8/P9EDNO2Ds8vvdi4uyn++91xizac2OH
fcQOF9a1GU/2c3XN87GsrLKB6H+y/ypEfj9M/u9/EDi+H6b/JsT8/ZOh5tdD
7N8PVvb/5X5/iPv2H4G6D+r+/Wju3z/3hOqp7t6P+xuh+iHyn/ffgZpvdtt8
s6zdl/1sEPfvT+ibwG1u9HX/W6j7riyOrV15+uv+judlP1/dmrwHov/b/jNQ
/8Hkv0Pcbw/TfwMaPjDz66Dhxwi13w8avvOh7kMPfwDOT8/K
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7KH0/rBQELiKxj8K5zOggAf7QyDy+1H5V/ej
qidMg7WFPoXzV4HBKzR1H9DkP6Hp/4qm/gcGPwzFfTD+UTT1MPAD5j97VP5V
e1T1Dwjyw1DdZ78a1f32aP6Dyr9C0/8UTf2D/QCju3t8
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, -1.2651650429449552`}, {
       0.3247595264191645, -1.1875}, {
       0.40494274433299715`, -1.4049427443329972`}, {
       0.26516504294495535`, -1.2651650429449552`}}], 
      PolygonBox[{{0.4373449933535234, -1.230251642536255}, {
       0.40494274433299715`, -1.4049427443329972`}, {
       0.3247595264191645, -1.1875}, {
       0.4373449933535234, -1.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, -1.1875}, {
       0.36222218485840063`, -1.0970571419134454`}, {
       0.4373449933535234, -1.230251642536255}, {
       0.3247595264191645, -1.1875}}], 
      PolygonBox[{{0.4374999810329408, -1.0842925895560618`}, {
       0.4373449933535234, -1.230251642536255}, {
       0.36222218485840063`, -1.0970571419134454`}, {
       0.4374999810329408, -1.0842925895560618`}}], 
      PolygonBox[{{0.36222218485840063`, -1.0970571419134454`}, {
       0.375, -1.}, {0.4374999810329408, -1.0842925895560618`}, {
       0.36222218485840063`, -1.0970571419134454`}}], 
      PolygonBox[{{0.4375, -1.}, {0.4374999810329408, -1.0842925895560618`}, {
       0.375, -1.}, {0.4375, -1.}}], 
      PolygonBox[{{0.375, -1.}, {0.36222218485840063`, -0.9029428580865547}, {
       0.4375, -1.}, {0.375, -1.}}], 
      PolygonBox[{{0.4374999810329408, -0.9157074104439382}, {0.4375, -1.}, {
       0.36222218485840063`, -0.9029428580865547}, {
       0.4374999810329408, -0.9157074104439382}}], 
      PolygonBox[{{0.36222218485840063`, -0.9029428580865547}, {
       0.3247595264191645, -0.8125}, {
       0.4374999810329408, -0.9157074104439382}, {
       0.36222218485840063`, -0.9029428580865547}}], 
      PolygonBox[{{0.4373449933535234, -0.7697483574637449}, {
       0.4374999810329408, -0.9157074104439382}, {
       0.3247595264191645, -0.8125}, {
       0.4373449933535234, -0.7697483574637449}}], 
      PolygonBox[{{0.3247595264191645, -0.8125}, {
       0.26516504294495535`, -0.7348349570550448}, {
       0.4373449933535234, -0.7697483574637449}, {
       0.3247595264191645, -0.8125}}], 
      PolygonBox[{{0.4049427443329971, -0.5950572556670028}, {
       0.4373449933535234, -0.7697483574637449}, {
       0.26516504294495535`, -0.7348349570550448}, {
       0.4049427443329971, -0.5950572556670028}}], 
      PolygonBox[{{0.26516504294495535`, -0.7348349570550448}, {
       0.18750000000000006`, -0.6752404735808355}, {
       0.4049427443329971, -0.5950572556670028}, {
       0.26516504294495535`, -0.7348349570550448}}], 
      PolygonBox[{{0.23025164253625516`, -0.5626550066464766}, {
       0.4049427443329971, -0.5950572556670028}, {
       0.18750000000000006`, -0.6752404735808355}, {
       0.23025164253625516`, -0.5626550066464766}}], 
      PolygonBox[{{0.18750000000000006`, -0.6752404735808355}, {
       0.09705714191344536, -0.6377778151415994}, {
       0.23025164253625516`, -0.5626550066464766}, {
       0.18750000000000006`, -0.6752404735808355}}], 
      PolygonBox[{{0.08429258955606053, -0.5625000189670593}, {
       0.23025164253625516`, -0.5626550066464766}, {
       0.09705714191344536, -0.6377778151415994}, {
       0.08429258955606053, -0.5625000189670593}}], 
      PolygonBox[{{0.09705714191344536, -0.6377778151415994}, {
       2.296212748401287*^-17, -0.625}, {
       0.08429258955606053, -0.5625000189670593}, {
       0.09705714191344536, -0.6377778151415994}}], 
      PolygonBox[{{0.0001055272204876927, -0.5625}, {
       0.08429258955606053, -0.5625000189670593}, {
       2.296212748401287*^-17, -0.625}, {0.0001055272204876927, -0.5625}}], 
      PolygonBox[{{
       2.296212748401287*^-17, -0.625}, {-0.09705714191344515, \
-0.6377778151415994}, {0.0001055272204876927, -0.5625}, {
       2.296212748401287*^-17, -0.625}}], 
      PolygonBox[{{-0.08429258955605684, -0.5625000189670593}, {
       0.0001055272204876927, -0.5625}, {-0.09705714191344515, \
-0.6377778151415994}, {-0.08429258955605684, -0.5625000189670593}}], 
      PolygonBox[{{-0.09705714191344515, -0.6377778151415994}, \
{-0.18749999999999992`, -0.6752404735808355}, {-0.08429258955605684, \
-0.5625000189670593}, {-0.09705714191344515, -0.6377778151415994}}], 
      PolygonBox[{{-0.23025164253625502`, -0.5626550066464766}, \
{-0.08429258955605684, -0.5625000189670593}, {-0.18749999999999992`, \
-0.6752404735808355}, {-0.23025164253625502`, -0.5626550066464766}}], 
      PolygonBox[{{-0.18749999999999992`, -0.6752404735808355}, \
{-0.2651650429449553, -0.7348349570550446}, {-0.23025164253625502`, \
-0.5626550066464766}, {-0.18749999999999992`, -0.6752404735808355}}], 
      PolygonBox[{{-0.4049427443329971, -0.5950572556670028}, \
{-0.23025164253625502`, -0.5626550066464766}, {-0.2651650429449553, \
-0.7348349570550446}, {-0.4049427443329971, -0.5950572556670028}}], 
      PolygonBox[{{-0.2651650429449553, -0.7348349570550446}, \
{-0.32475952641916445`, -0.8124999999999999}, {-0.4049427443329971, \
-0.5950572556670028}, {-0.2651650429449553, -0.7348349570550446}}], 
      PolygonBox[{{-0.4373449933535234, -0.7697483574637446}, \
{-0.4049427443329971, -0.5950572556670028}, {-0.32475952641916445`, \
-0.8124999999999999}, {-0.4373449933535234, -0.7697483574637446}}], 
      PolygonBox[{{-0.32475952641916445`, -0.8124999999999999}, \
{-0.3622221848584006, -0.9029428580865546}, {-0.4373449933535234, \
-0.7697483574637446}, {-0.32475952641916445`, -0.8124999999999999}}], 
      PolygonBox[{{-0.4374999810329408, -0.9157074104439377}, \
{-0.4373449933535234, -0.7697483574637446}, {-0.3622221848584006, \
-0.9029428580865546}, {-0.4374999810329408, -0.9157074104439377}}], 
      PolygonBox[{{-0.3622221848584006, -0.9029428580865546}, {-0.375, \
-0.9999999999999998}, {-0.4374999810329408, -0.9157074104439377}, \
{-0.3622221848584006, -0.9029428580865546}}], 
      PolygonBox[{{-0.4375, -0.9998768219370047}, {-0.4374999810329408, \
-0.9157074104439377}, {-0.375, -0.9999999999999998}, {-0.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-0.375, -0.9999999999999998}, {-0.36222218485840063`, \
-1.0970571419134452`}, {-0.4375, -0.9998768219370047}, {-0.375, \
-0.9999999999999998}}], 
      PolygonBox[{{-0.4374999810329408, -1.084292589556055}, {-0.4375, \
-0.9998768219370047}, {-0.36222218485840063`, -1.0970571419134452`}, \
{-0.4374999810329408, -1.084292589556055}}], 
      PolygonBox[{{-0.36222218485840063`, -1.0970571419134452`}, \
{-0.3247595264191646, -1.1874999999999998`}, {-0.4374999810329408, \
-1.084292589556055}, {-0.36222218485840063`, -1.0970571419134452`}}], 
      PolygonBox[{{-0.4373449933535234, -1.2302516425362549`}, \
{-0.4374999810329408, -1.084292589556055}, {-0.3247595264191646, \
-1.1874999999999998`}, {-0.4373449933535234, -1.2302516425362549`}}], 
      PolygonBox[{{-0.3247595264191646, -1.1874999999999998`}, \
{-0.26516504294495535`, -1.2651650429449552`}, {-0.4373449933535234, \
-1.2302516425362549`}, {-0.3247595264191646, -1.1874999999999998`}}], 
      PolygonBox[{{-0.40494274433299715`, -1.4049427443329972`}, \
{-0.4373449933535234, -1.2302516425362549`}, {-0.26516504294495535`, \
-1.2651650429449552`}, {-0.40494274433299715`, -1.4049427443329972`}}], 
      PolygonBox[{{-0.26516504294495535`, -1.2651650429449552`}, \
{-0.18750000000000017`, -1.3247595264191645`}, {-0.40494274433299715`, \
-1.4049427443329972`}, {-0.26516504294495535`, -1.2651650429449552`}}], 
      PolygonBox[{{-0.23025164253625505`, -1.4373449933535234`}, \
{-0.40494274433299715`, -1.4049427443329972`}, {-0.18750000000000017`, \
-1.3247595264191645`}, {-0.23025164253625505`, -1.4373449933535234`}}], 
      PolygonBox[{{-0.18750000000000017`, -1.3247595264191645`}, \
{-0.09705714191344557, -1.3622221848584006`}, {-0.23025164253625505`, \
-1.4373449933535234`}, {-0.18750000000000017`, -1.3247595264191645`}}], 
      PolygonBox[{{-0.08429258955606422, -1.4374999810329407`}, \
{-0.23025164253625505`, -1.4373449933535234`}, {-0.09705714191344557, \
-1.3622221848584006`}, {-0.08429258955606422, -1.4374999810329407`}}], 
      PolygonBox[{{-0.09705714191344557, -1.3622221848584006`}, {
       6.888638245203862*^-17, -1.375}, {-0.08429258955606422, \
-1.4374999810329407`}, {-0.09705714191344557, -1.3622221848584006`}}], 
      PolygonBox[{{
       0.0001348418310429853, -1.4375}, {-0.08429258955606422, \
-1.4374999810329407`}, {6.888638245203862*^-17, -1.375}, {
       0.0001348418310429853, -1.4375}}], 
      PolygonBox[{{6.888638245203862*^-17, -1.375}, {
       0.09705714191344511, -1.3622221848584006`}, {
       0.0001348418310429853, -1.4375}, {6.888638245203862*^-17, -1.375}}], 
      PolygonBox[{{0.08429258955605314, -1.4374999810329407`}, {
       0.0001348418310429853, -1.4375}, {
       0.09705714191344511, -1.3622221848584006`}, {
       0.08429258955605314, -1.4374999810329407`}}], 
      PolygonBox[{{0.09705714191344511, -1.3622221848584006`}, {
       0.18749999999999975`, -1.3247595264191645`}, {
       0.08429258955605314, -1.4374999810329407`}, {
       0.09705714191344511, -1.3622221848584006`}}], 
      PolygonBox[{{0.2302516425362547, -1.4373449933535234`}, {
       0.08429258955605314, -1.4374999810329407`}, {
       0.18749999999999975`, -1.3247595264191645`}, {
       0.2302516425362547, -1.4373449933535234`}}], 
      PolygonBox[{{0.18749999999999975`, -1.3247595264191645`}, {
       0.26516504294495524`, -1.2651650429449552`}, {
       0.2302516425362547, -1.4373449933535234`}, {
       0.18749999999999975`, -1.3247595264191645`}}], 
      PolygonBox[{{0.4049427443329971, -1.4049427443329972`}, {
       0.2302516425362547, -1.4373449933535234`}, {
       0.26516504294495524`, -1.2651650429449552`}, {
       0.4049427443329971, -1.4049427443329972`}}], 
      PolygonBox[{{0.26516504294495524`, -1.2651650429449552`}, {
       0.26516504294495535`, -1.2651650429449552`}, {
       0.4049427443329971, -1.4049427443329972`}, {
       0.26516504294495524`, -1.2651650429449552`}}], 
      PolygonBox[{{0.40494274433299715`, -1.4049427443329972`}, {
       0.4049427443329971, -1.4049427443329972`}, {
       0.26516504294495535`, -1.2651650429449552`}, {
       0.40494274433299715`, -1.4049427443329972`}}], 
      PolygonBox[{{0.40494274433299715`, -1.4049427443329972`}, {
       0.4373449933535234, -1.230251642536255}, {0.5, -1.5}, {
       0.40494274433299715`, -1.4049427443329972`}}], 
      PolygonBox[{{0.5, -1.3576627826493677`}, {0.5, -1.5}, {
       0.4373449933535234, -1.230251642536255}, {0.5, -1.3576627826493677`}}],
       PolygonBox[{{0.4373449933535234, -1.230251642536255}, {
       0.4374999810329408, -1.0842925895560618`}, {
       0.5, -1.3576627826493677`}, {0.4373449933535234, -1.230251642536255}}],
       PolygonBox[{{0.5, -1.20590900530174}, {0.5, -1.3576627826493677`}, {
       0.4374999810329408, -1.0842925895560618`}, {0.5, -1.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, -1.0842925895560618`}, {0.4375, -1.}, {
       0.5, -1.20590900530174}, {0.4374999810329408, -1.0842925895560618`}}], 
      PolygonBox[{{0.5, -1.}, {0.5, -1.20590900530174}, {0.4375, -1.}, {
       0.5, -1.}}], 
      PolygonBox[{{0.4375, -1.}, {0.4374999810329408, -0.9157074104439382}, {
       0.5, -1.}, {0.4375, -1.}}], 
      PolygonBox[{{0.5, -0.79409099469826}, {0.5, -1.}, {
       0.4374999810329408, -0.9157074104439382}, {0.5, -0.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, -0.9157074104439382}, {
       0.4373449933535234, -0.7697483574637449}, {0.5, -0.79409099469826}, {
       0.4374999810329408, -0.9157074104439382}}], 
      PolygonBox[{{0.5, -0.6423372173506324}, {0.5, -0.79409099469826}, {
       0.4373449933535234, -0.7697483574637449}, {0.5, -0.6423372173506324}}],
       PolygonBox[{{0.4373449933535234, -0.7697483574637449}, {
       0.4049427443329971, -0.5950572556670028}, {0.5, -0.6423372173506324}, {
       0.4373449933535234, -0.7697483574637449}}], 
      PolygonBox[{{0.491446564961186, -0.508553435038814}, {
       0.5, -0.6423372173506324}, {0.4049427443329971, -0.5950572556670028}, {
       0.491446564961186, -0.508553435038814}}], 
      PolygonBox[{{0.4049427443329971, -0.5950572556670028}, {
       0.23025164253625516`, -0.5626550066464766}, {
       0.491446564961186, -0.508553435038814}, {
       0.4049427443329971, -0.5950572556670028}}], 
      PolygonBox[{{0.35766278264936807`, -0.5}, {
       0.491446564961186, -0.508553435038814}, {
       0.23025164253625516`, -0.5626550066464766}, {
       0.35766278264936807`, -0.5}}], 
      PolygonBox[{{0.23025164253625516`, -0.5626550066464766}, {
       0.08429258955606053, -0.5625000189670593}, {
       0.35766278264936807`, -0.5}, {
       0.23025164253625516`, -0.5626550066464766}}], 
      PolygonBox[{{0.20590900537325585`, -0.5}, {
       0.35766278264936807`, -0.5}, {
       0.08429258955606053, -0.5625000189670593}, {
       0.20590900537325585`, -0.5}}], 
      PolygonBox[{{0.08429258955606053, -0.5625000189670593}, {
       0.0001055272204876927, -0.5625}, {0.20590900537325585`, -0.5}, {
       0.08429258955606053, -0.5625000189670593}}], 
      PolygonBox[{{0.07794195802689004, -0.5}, {0.20590900537325585`, -0.5}, {
       0.0001055272204876927, -0.5625}, {0.07794195802689004, -0.5}}], 
      PolygonBox[{{
       0.0001055272204876927, -0.5625}, {-0.08429258955605684, \
-0.5625000189670593}, {0.07794195802689004, -0.5}, {
       0.0001055272204876927, -0.5625}}], 
      PolygonBox[{{-0.20590900530444564`, -0.5}, {
       0.07794195802689004, -0.5}, {-0.08429258955605684, \
-0.5625000189670593}, {-0.20590900530444564`, -0.5}}], 
      PolygonBox[{{-0.08429258955605684, -0.5625000189670593}, \
{-0.23025164253625502`, -0.5626550066464766}, {-0.20590900530444564`, -0.5}, \
{-0.08429258955605684, -0.5625000189670593}}], 
      PolygonBox[{{-0.35766278264936624`, -0.5}, {-0.20590900530444564`, \
-0.5}, {-0.23025164253625502`, -0.5626550066464766}, {-0.35766278264936624`, \
-0.5}}], PolygonBox[{{-0.23025164253625502`, -0.5626550066464766}, \
{-0.4049427443329971, -0.5950572556670028}, {-0.35766278264936624`, -0.5}, \
{-0.23025164253625502`, -0.5626550066464766}}], 
      PolygonBox[{{
       0.5, -0.5}, {-0.35766278264936624`, -0.5}, {-0.4049427443329971, \
-0.5950572556670028}, {0.5, -0.5}}], 
      PolygonBox[{{-0.4049427443329971, -0.5950572556670028}, \
{-0.4373449933535234, -0.7697483574637446}, {
       0.5, -0.5}, {-0.4049427443329971, -0.5950572556670028}}], 
      PolygonBox[{{-0.5, -0.642337217350631}, {
       0.5, -0.5}, {-0.4373449933535234, -0.7697483574637446}, {-0.5, \
-0.642337217350631}}], 
      PolygonBox[{{-0.4373449933535234, -0.7697483574637446}, \
{-0.4374999810329408, -0.9157074104439377}, {-0.5, -0.642337217350631}, \
{-0.4373449933535234, -0.7697483574637446}}], 
      PolygonBox[{{-0.5, -0.7940909947171011}, {-0.5, -0.642337217350631}, \
{-0.4374999810329408, -0.9157074104439377}, {-0.5, -0.7940909947171011}}], 
      PolygonBox[{{-0.4374999810329408, -0.9157074104439377}, {-0.4375, \
-0.9998768219370047}, {-0.5, -0.7940909947171011}, {-0.4374999810329408, \
-0.9157074104439377}}], 
      PolygonBox[{{-0.5, -0.9193213332412997}, {-0.5, -0.7940909947171011}, \
{-0.4375, -0.9998768219370047}, {-0.5, -0.9193213332412997}}], 
      PolygonBox[{{-0.4375, -0.9998768219370047}, {-0.4374999810329408, \
-1.084292589556055}, {-0.5, -0.9193213332412997}, {-0.4375, \
-0.9998768219370047}}], 
      PolygonBox[{{-0.5, -1.2059090051452785`}, {-0.5, -0.9193213332412997}, \
{-0.4374999810329408, -1.084292589556055}, {-0.5, -1.2059090051452785`}}], 
      PolygonBox[{{-0.4374999810329408, -1.084292589556055}, \
{-0.4373449933535234, -1.2302516425362549`}, {-0.5, -1.2059090051452785`}, \
{-0.4374999810329408, -1.084292589556055}}], 
      PolygonBox[{{-0.5, -1.3576627826493652`}, {-0.5, -1.2059090051452785`}, \
{-0.4373449933535234, -1.2302516425362549`}, {-0.5, -1.3576627826493652`}}], 
      PolygonBox[{{-0.4373449933535234, -1.2302516425362549`}, \
{-0.40494274433299715`, -1.4049427443329972`}, {-0.5, -1.3576627826493652`}, \
{-0.4373449933535234, -1.2302516425362549`}}], 
      PolygonBox[{{-0.5, -0.5}, {-0.5, -1.3576627826493652`}, \
{-0.40494274433299715`, -1.4049427443329972`}, {-0.5, -0.5}}], 
      PolygonBox[{{-0.40494274433299715`, -1.4049427443329972`}, \
{-0.23025164253625505`, -1.4373449933535234`}, {-0.5, -0.5}, \
{-0.40494274433299715`, -1.4049427443329972`}}], 
      PolygonBox[{{-0.5, -1.5}, {-0.5, -0.5}, {-0.23025164253625505`, \
-1.4373449933535234`}, {-0.5, -1.5}}], 
      PolygonBox[{{-0.23025164253625505`, -1.4373449933535234`}, \
{-0.08429258955606422, -1.4374999810329407`}, {-0.5, -1.5}, \
{-0.23025164253625505`, -1.4373449933535234`}}], 
      PolygonBox[{{-0.20590900556682806`, -1.5}, {-0.5, -1.5}, \
{-0.08429258955606422, -1.4374999810329407`}, {-0.20590900556682806`, -1.5}}],
       PolygonBox[{{-0.08429258955606422, -1.4374999810329407`}, {
       0.0001348418310429853, -1.4375}, {-0.20590900556682806`, -1.5}, \
{-0.08429258955606422, -1.4374999810329407`}}], 
      PolygonBox[{{0.0823238704010616, -1.5}, {-0.20590900556682806`, -1.5}, {
       0.0001348418310429853, -1.4375}, {0.0823238704010616, -1.5}}], 
      PolygonBox[{{0.0001348418310429853, -1.4375}, {
       0.08429258955605314, -1.4374999810329407`}, {
       0.0823238704010616, -1.5}, {0.0001348418310429853, -1.4375}}], 
      PolygonBox[{{0.2059090053603974, -1.5}, {0.0823238704010616, -1.5}, {
       0.08429258955605314, -1.4374999810329407`}, {
       0.2059090053603974, -1.5}}], 
      PolygonBox[{{0.08429258955605314, -1.4374999810329407`}, {
       0.2302516425362547, -1.4373449933535234`}, {
       0.2059090053603974, -1.5}, {
       0.08429258955605314, -1.4374999810329407`}}], 
      PolygonBox[{{0.35766278264937107`, -1.5}, {0.2059090053603974, -1.5}, {
       0.2302516425362547, -1.4373449933535234`}, {
       0.35766278264937107`, -1.5}}], 
      PolygonBox[{{0.2302516425362547, -1.4373449933535234`}, {
       0.4049427443329971, -1.4049427443329972`}, {
       0.35766278264937107`, -1.5}, {
       0.2302516425362547, -1.4373449933535234`}}], 
      PolygonBox[{{0.5, -1.5}, {0.35766278264937107`, -1.5}, {
       0.4049427443329971, -1.4049427443329972`}, {0.5, -1.5}}], 
      PolygonBox[{{0.4049427443329971, -1.4049427443329972`}, {
       0.40494274433299715`, -1.4049427443329972`}, {0.5, -1.5}, {
       0.4049427443329971, -1.4049427443329972`}}], 
      PolygonBox[{{0.5, -1.5}, {0.5, -1.5}, {
       0.40494274433299715`, -1.4049427443329972`}, {
       0.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 0.}, {-0.4791666666666667, 0.}, {-0.4583333333333333, 
       0.}, {-0.4375, 0.}, {-0.4166666666666667, 0.}, {-0.39583333333333337`, 
       0.}, {-0.375, 0.}, {-0.375, 0.}, {-0.3958333333333333, 
       0.}, {-0.4166666666666667, 0.}, {-0.4375, 0.}, {-0.4583333333333333, 
       0.}, {-0.47916666666666663`, 0.}, {-0.5, 0.}, {-0.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, 0.}, {0.3958333333333333, 0.}, {0.4166666666666667, 
       0.}, {0.4375, 0.}, {0.4583333333333333, 0.}, {0.47916666666666663`, 
       0.}, {0.5, 0.}, {0.5, 0.}, {0.4791666666666667, 0.}, {
       0.4583333333333333, 0.}, {0.4375, 0.}, {0.4166666666666667, 0.}, {
       0.39583333333333337`, 0.}, {0.375, 0.}, {0.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -0.5}, {0., -0.4791666666666667}, {
       0., -0.4583333333333333}, {0., -0.4375}, {0., -0.4166666666666667}, {
       0., -0.39583333333333337`}, {0., -0.375}, {0., -0.375}, {
       0., -0.3958333333333333}, {0., -0.4166666666666667}, {0., -0.4375}, {
       0., -0.4583333333333333}, {0., -0.47916666666666663`}, {0., -0.5}, {
       0., -0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 0.375}, {0., 0.3958333333333333}, {0., 
       0.4166666666666667}, {0., 0.4375}, {0., 0.4583333333333333}, {0., 
       0.47916666666666663`}, {0., 0.5}, {0., 0.5}, {0., 
       0.4791666666666667}, {0., 0.4583333333333333}, {0., 0.4375}, {0., 
       0.4166666666666667}, {0., 0.39583333333333337`}, {0., 0.375}, {0., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, 0.}, {-0.25, 0.}, {-0.125, 0.}, {0., 0.}, {0.125, 
       0.}, {0.25, 0.}, {0.375, 0.}, {0.375, 0.}, {0.25, 0.}, {0.125, 0.}, {
       0., 0.}, {-0.125, 0.}, {-0.25, 0.}, {-0.375, 0.}, {-0.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -0.375}, {0., -0.25}, {0., -0.125}, {0., 0.}, {0., 
       0.125}, {0., 0.25}, {0., 0.375}, {0., 0.375}, {0., 0.25}, {0., 
       0.125}, {0., 0.}, {0., -0.125}, {0., -0.25}, {0., -0.375}, {
       0., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37GGsgP6yr0v1rtvf6IxZtOfGDvsGSye9Oyeu
2P8Hg+P2t3Lunyn7ccH+JpSGmHECru4eVJ8/1Byurnk+lpVVNjB7rkLk98Ps
+Qsxdz9MP9Tc/TB76iHi+1mg9kDN3f8Aag/U3P0Qe7psoObuPwe1pxGq/w/U
njtQ869DaTaIufvroOreQvX5Qc3peF7289WtyXtg9pyB2guz5zs0XJqg+m9A
3Q11P8xce5g9UHPt30HtgYULxP2z9gAA38XVGQ==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7GF0WCgIXEXjH7VHVYfQFwKR34/Kv7ofzVyC
fDR796PZux/N3v1o9u5HsxcnHYamLgzNHBz22KPyrxLtLxgfzV57NHtxhas9
Kv8qWjw8sAcACDBnxg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, -0.2651650429449553}, {
       0.3247595264191645, -0.1875}, {
       0.40494274433299715`, -0.4049427443329971}, {
       0.26516504294495535`, -0.2651650429449553}}], 
      PolygonBox[{{0.4373449933535234, -0.23025164253625516`}, {
       0.40494274433299715`, -0.4049427443329971}, {
       0.3247595264191645, -0.1875}, {
       0.4373449933535234, -0.23025164253625516`}}], 
      PolygonBox[{{0.3247595264191645, -0.1875}, {
       0.36222218485840063`, -0.0970571419134453}, {
       0.4373449933535234, -0.23025164253625516`}, {
       0.3247595264191645, -0.1875}}], 
      PolygonBox[{{0.4374999810329408, -0.08429258955606181}, {
       0.4373449933535234, -0.23025164253625516`}, {
       0.36222218485840063`, -0.0970571419134453}, {
       0.4374999810329408, -0.08429258955606181}}], 
      PolygonBox[{{0.36222218485840063`, -0.0970571419134453}, {0.375, 0.}, {
       0.4374999810329408, -0.08429258955606181}, {
       0.36222218485840063`, -0.0970571419134453}}], 
      PolygonBox[{{0.4375, 0.}, {0.4374999810329408, -0.08429258955606181}, {
       0.375, 0.}, {0.4375, 0.}}], 
      PolygonBox[{{0.375, 0.}, {0.36222218485840063`, 0.09705714191344525}, {
       0.4375, 0.}, {0.375, 0.}}], 
      PolygonBox[{{0.4374999810329408, 0.08429258955606177}, {0.4375, 0.}, {
       0.36222218485840063`, 0.09705714191344525}, {0.4374999810329408, 
       0.08429258955606177}}], 
      PolygonBox[{{0.36222218485840063`, 0.09705714191344525}, {
       0.3247595264191645, 0.18749999999999994`}, {0.4374999810329408, 
       0.08429258955606177}, {0.36222218485840063`, 0.09705714191344525}}], 
      PolygonBox[{{0.4373449933535234, 0.23025164253625502`}, {
       0.4374999810329408, 0.08429258955606177}, {0.3247595264191645, 
       0.18749999999999994`}, {0.4373449933535234, 0.23025164253625502`}}], 
      PolygonBox[{{0.3247595264191645, 0.18749999999999994`}, {
       0.26516504294495535`, 0.2651650429449553}, {0.4373449933535234, 
       0.23025164253625502`}, {0.3247595264191645, 0.18749999999999994`}}], 
      PolygonBox[{{0.4049427443329971, 0.40494274433299715`}, {
       0.4373449933535234, 0.23025164253625502`}, {0.26516504294495535`, 
       0.2651650429449553}, {0.4049427443329971, 0.40494274433299715`}}], 
      PolygonBox[{{0.26516504294495535`, 0.2651650429449553}, {
       0.18750000000000006`, 0.3247595264191645}, {0.4049427443329971, 
       0.40494274433299715`}, {0.26516504294495535`, 0.2651650429449553}}], 
      PolygonBox[{{0.23025164253625516`, 0.4373449933535234}, {
       0.4049427443329971, 0.40494274433299715`}, {0.18750000000000006`, 
       0.3247595264191645}, {0.23025164253625516`, 0.4373449933535234}}], 
      PolygonBox[{{0.18750000000000006`, 0.3247595264191645}, {
       0.09705714191344536, 0.3622221848584006}, {0.23025164253625516`, 
       0.4373449933535234}, {0.18750000000000006`, 0.3247595264191645}}], 
      PolygonBox[{{0.08429258955606053, 0.4374999810329408}, {
       0.23025164253625516`, 0.4373449933535234}, {0.09705714191344536, 
       0.3622221848584006}, {0.08429258955606053, 0.4374999810329408}}], 
      PolygonBox[{{0.09705714191344536, 0.3622221848584006}, {
       2.296212748401287*^-17, 0.375}, {0.08429258955606053, 
       0.4374999810329408}, {0.09705714191344536, 0.3622221848584006}}], 
      PolygonBox[{{0.0001055272204876927, 0.4375}, {0.08429258955606053, 
       0.4374999810329408}, {2.296212748401287*^-17, 0.375}, {
       0.0001055272204876927, 0.4375}}], 
      PolygonBox[{{2.296212748401287*^-17, 0.375}, {-0.09705714191344515, 
       0.36222218485840063`}, {0.0001055272204876927, 0.4375}, {
       2.296212748401287*^-17, 0.375}}], 
      PolygonBox[{{-0.08429258955605684, 0.4374999810329408}, {
       0.0001055272204876927, 0.4375}, {-0.09705714191344515, 
       0.36222218485840063`}, {-0.08429258955605684, 0.4374999810329408}}], 
      PolygonBox[{{-0.09705714191344515, 
       0.36222218485840063`}, {-0.18749999999999992`, 
       0.3247595264191645}, {-0.08429258955605684, 
       0.4374999810329408}, {-0.09705714191344515, 0.36222218485840063`}}], 
      PolygonBox[{{-0.23025164253625502`, 
       0.4373449933535234}, {-0.08429258955605684, 
       0.4374999810329408}, {-0.18749999999999992`, 
       0.3247595264191645}, {-0.23025164253625502`, 0.4373449933535234}}], 
      PolygonBox[{{-0.18749999999999992`, 
       0.3247595264191645}, {-0.2651650429449553, 
       0.26516504294495535`}, {-0.23025164253625502`, 
       0.4373449933535234}, {-0.18749999999999992`, 0.3247595264191645}}], 
      PolygonBox[{{-0.4049427443329971, 
       0.40494274433299715`}, {-0.23025164253625502`, 
       0.4373449933535234}, {-0.2651650429449553, 
       0.26516504294495535`}, {-0.4049427443329971, 0.40494274433299715`}}], 
      PolygonBox[{{-0.2651650429449553, 
       0.26516504294495535`}, {-0.32475952641916445`, 
       0.1875000000000001}, {-0.4049427443329971, 
       0.40494274433299715`}, {-0.2651650429449553, 0.26516504294495535`}}], 
      PolygonBox[{{-0.4373449933535234, 
       0.2302516425362554}, {-0.4049427443329971, 
       0.40494274433299715`}, {-0.32475952641916445`, 
       0.1875000000000001}, {-0.4373449933535234, 0.2302516425362554}}], 
      PolygonBox[{{-0.32475952641916445`, 
       0.1875000000000001}, {-0.3622221848584006, 
       0.09705714191344539}, {-0.4373449933535234, 
       0.2302516425362554}, {-0.32475952641916445`, 0.1875000000000001}}], 
      PolygonBox[{{-0.4374999810329408, 
       0.08429258955606238}, {-0.4373449933535234, 
       0.2302516425362554}, {-0.3622221848584006, 
       0.09705714191344539}, {-0.4374999810329408, 0.08429258955606238}}], 
      PolygonBox[{{-0.3622221848584006, 0.09705714191344539}, {-0.375, 
       2.1245770866179924`*^-16}, {-0.4374999810329408, 
       0.08429258955606238}, {-0.3622221848584006, 0.09705714191344539}}], 
      PolygonBox[{{-0.4375, 0.00012317806299537147`}, {-0.4374999810329408, 
       0.08429258955606238}, {-0.375, 2.1245770866179924`*^-16}, {-0.4375, 
       0.00012317806299537147`}}], 
      PolygonBox[{{-0.375, 
       2.1245770866179924`*^-16}, {-0.36222218485840063`, \
-0.09705714191344514}, {-0.4375, 0.00012317806299537147`}, {-0.375, 
       2.1245770866179924`*^-16}}], 
      PolygonBox[{{-0.4374999810329408, -0.084292589556055}, {-0.4375, 
       0.00012317806299537147`}, {-0.36222218485840063`, \
-0.09705714191344514}, {-0.4374999810329408, -0.084292589556055}}], 
      PolygonBox[{{-0.36222218485840063`, -0.09705714191344514}, \
{-0.3247595264191646, -0.18749999999999978`}, {-0.4374999810329408, \
-0.084292589556055}, {-0.36222218485840063`, -0.09705714191344514}}], 
      PolygonBox[{{-0.4373449933535234, -0.23025164253625477`}, \
{-0.4374999810329408, -0.084292589556055}, {-0.3247595264191646, \
-0.18749999999999978`}, {-0.4373449933535234, -0.23025164253625477`}}], 
      PolygonBox[{{-0.3247595264191646, -0.18749999999999978`}, \
{-0.26516504294495535`, -0.2651650429449553}, {-0.4373449933535234, \
-0.23025164253625477`}, {-0.3247595264191646, -0.18749999999999978`}}], 
      PolygonBox[{{-0.40494274433299715`, -0.4049427443329971}, \
{-0.4373449933535234, -0.23025164253625477`}, {-0.26516504294495535`, \
-0.2651650429449553}, {-0.40494274433299715`, -0.4049427443329971}}], 
      PolygonBox[{{-0.26516504294495535`, -0.2651650429449553}, \
{-0.18750000000000017`, -0.3247595264191644}, {-0.40494274433299715`, \
-0.4049427443329971}, {-0.26516504294495535`, -0.2651650429449553}}], 
      PolygonBox[{{-0.23025164253625505`, -0.4373449933535234}, \
{-0.40494274433299715`, -0.4049427443329971}, {-0.18750000000000017`, \
-0.3247595264191644}, {-0.23025164253625505`, -0.4373449933535234}}], 
      PolygonBox[{{-0.18750000000000017`, -0.3247595264191644}, \
{-0.09705714191344557, -0.3622221848584005}, {-0.23025164253625505`, \
-0.4373449933535234}, {-0.18750000000000017`, -0.3247595264191644}}], 
      PolygonBox[{{-0.08429258955606422, -0.4374999810329408}, \
{-0.23025164253625505`, -0.4373449933535234}, {-0.09705714191344557, \
-0.3622221848584005}, {-0.08429258955606422, -0.4374999810329408}}], 
      PolygonBox[{{-0.09705714191344557, -0.3622221848584005}, {
       6.888638245203862*^-17, -0.375}, {-0.08429258955606422, \
-0.4374999810329408}, {-0.09705714191344557, -0.3622221848584005}}], 
      PolygonBox[{{
       0.0001348418310429853, -0.4375}, {-0.08429258955606422, \
-0.4374999810329408}, {6.888638245203862*^-17, -0.375}, {
       0.0001348418310429853, -0.4375}}], 
      PolygonBox[{{6.888638245203862*^-17, -0.375}, {
       0.09705714191344511, -0.36222218485840063`}, {
       0.0001348418310429853, -0.4375}, {6.888638245203862*^-17, -0.375}}], 
      PolygonBox[{{0.08429258955605314, -0.4374999810329408}, {
       0.0001348418310429853, -0.4375}, {
       0.09705714191344511, -0.36222218485840063`}, {
       0.08429258955605314, -0.4374999810329408}}], 
      PolygonBox[{{0.09705714191344511, -0.36222218485840063`}, {
       0.18749999999999975`, -0.3247595264191646}, {
       0.08429258955605314, -0.4374999810329408}, {
       0.09705714191344511, -0.36222218485840063`}}], 
      PolygonBox[{{0.2302516425362547, -0.4373449933535234}, {
       0.08429258955605314, -0.4374999810329408}, {
       0.18749999999999975`, -0.3247595264191646}, {
       0.2302516425362547, -0.4373449933535234}}], 
      PolygonBox[{{0.18749999999999975`, -0.3247595264191646}, {
       0.26516504294495524`, -0.26516504294495535`}, {
       0.2302516425362547, -0.4373449933535234}, {
       0.18749999999999975`, -0.3247595264191646}}], 
      PolygonBox[{{0.4049427443329971, -0.40494274433299715`}, {
       0.2302516425362547, -0.4373449933535234}, {
       0.26516504294495524`, -0.26516504294495535`}, {
       0.4049427443329971, -0.40494274433299715`}}], 
      PolygonBox[{{0.26516504294495524`, -0.26516504294495535`}, {
       0.26516504294495535`, -0.2651650429449553}, {
       0.4049427443329971, -0.40494274433299715`}, {
       0.26516504294495524`, -0.26516504294495535`}}], 
      PolygonBox[{{0.40494274433299715`, -0.4049427443329971}, {
       0.4049427443329971, -0.40494274433299715`}, {
       0.26516504294495535`, -0.2651650429449553}, {
       0.40494274433299715`, -0.4049427443329971}}], 
      PolygonBox[{{0.40494274433299715`, -0.4049427443329971}, {
       0.4373449933535234, -0.23025164253625516`}, {0.5, -0.5}, {
       0.40494274433299715`, -0.4049427443329971}}], 
      PolygonBox[{{0.5, -0.3576627826493677}, {0.5, -0.5}, {
       0.4373449933535234, -0.23025164253625516`}, {
       0.5, -0.3576627826493677}}], 
      PolygonBox[{{0.4373449933535234, -0.23025164253625516`}, {
       0.4374999810329408, -0.08429258955606181}, {
       0.5, -0.3576627826493677}, {
       0.4373449933535234, -0.23025164253625516`}}], 
      PolygonBox[{{0.5, -0.20590900530173997`}, {0.5, -0.3576627826493677}, {
       0.4374999810329408, -0.08429258955606181}, {
       0.5, -0.20590900530173997`}}], 
      PolygonBox[{{0.4374999810329408, -0.08429258955606181}, {0.4375, 0.}, {
       0.5, -0.20590900530173997`}, {
       0.4374999810329408, -0.08429258955606181}}], 
      PolygonBox[{{0.5, 0.}, {0.5, -0.20590900530173997`}, {0.4375, 0.}, {0.5,
        0.}}], PolygonBox[{{0.4375, 0.}, {0.4374999810329408, 
       0.08429258955606177}, {0.5, 0.}, {0.4375, 0.}}], 
      PolygonBox[{{0.5, 0.20590900530173992`}, {0.5, 0.}, {0.4374999810329408,
        0.08429258955606177}, {0.5, 0.20590900530173992`}}], 
      PolygonBox[{{0.4374999810329408, 0.08429258955606177}, {
       0.4373449933535234, 0.23025164253625502`}, {0.5, 
       0.20590900530173992`}, {0.4374999810329408, 0.08429258955606177}}], 
      PolygonBox[{{0.5, 0.35766278264936757`}, {0.5, 0.20590900530173992`}, {
       0.4373449933535234, 0.23025164253625502`}, {0.5, 
       0.35766278264936757`}}], 
      PolygonBox[{{0.4373449933535234, 0.23025164253625502`}, {
       0.4049427443329971, 0.40494274433299715`}, {0.5, 
       0.35766278264936757`}, {0.4373449933535234, 0.23025164253625502`}}], 
      PolygonBox[{{0.491446564961186, 0.491446564961186}, {0.5, 
       0.35766278264936757`}, {0.4049427443329971, 0.40494274433299715`}, {
       0.491446564961186, 0.491446564961186}}], 
      PolygonBox[{{0.4049427443329971, 0.40494274433299715`}, {
       0.23025164253625516`, 0.4373449933535234}, {0.491446564961186, 
       0.491446564961186}, {0.4049427443329971, 0.40494274433299715`}}], 
      PolygonBox[{{0.35766278264936807`, 0.5}, {0.491446564961186, 
       0.491446564961186}, {0.23025164253625516`, 0.4373449933535234}, {
       0.35766278264936807`, 0.5}}], 
      PolygonBox[{{0.23025164253625516`, 0.4373449933535234}, {
       0.08429258955606053, 0.4374999810329408}, {0.35766278264936807`, 
       0.5}, {0.23025164253625516`, 0.4373449933535234}}], 
      PolygonBox[{{0.20590900537325585`, 0.5}, {0.35766278264936807`, 0.5}, {
       0.08429258955606053, 0.4374999810329408}, {0.20590900537325585`, 
       0.5}}], PolygonBox[{{0.08429258955606053, 0.4374999810329408}, {
       0.0001055272204876927, 0.4375}, {0.20590900537325585`, 0.5}, {
       0.08429258955606053, 0.4374999810329408}}], 
      PolygonBox[{{0.07794195802689004, 0.5}, {0.20590900537325585`, 0.5}, {
       0.0001055272204876927, 0.4375}, {0.07794195802689004, 0.5}}], 
      PolygonBox[{{0.0001055272204876927, 0.4375}, {-0.08429258955605684, 
       0.4374999810329408}, {0.07794195802689004, 0.5}, {
       0.0001055272204876927, 0.4375}}], 
      PolygonBox[{{-0.20590900530444564`, 0.5}, {0.07794195802689004, 
       0.5}, {-0.08429258955605684, 
       0.4374999810329408}, {-0.20590900530444564`, 0.5}}], 
      PolygonBox[{{-0.08429258955605684, 
       0.4374999810329408}, {-0.23025164253625502`, 
       0.4373449933535234}, {-0.20590900530444564`, 
       0.5}, {-0.08429258955605684, 0.4374999810329408}}], 
      PolygonBox[{{-0.35766278264936624`, 0.5}, {-0.20590900530444564`, 
       0.5}, {-0.23025164253625502`, 
       0.4373449933535234}, {-0.35766278264936624`, 0.5}}], 
      PolygonBox[{{-0.23025164253625502`, 
       0.4373449933535234}, {-0.4049427443329971, 
       0.40494274433299715`}, {-0.35766278264936624`, 
       0.5}, {-0.23025164253625502`, 0.4373449933535234}}], 
      PolygonBox[{{0.5, 0.5}, {-0.35766278264936624`, 
       0.5}, {-0.4049427443329971, 0.40494274433299715`}, {0.5, 0.5}}], 
      PolygonBox[{{-0.4049427443329971, 
       0.40494274433299715`}, {-0.4373449933535234, 0.2302516425362554}, {0.5,
        0.5}, {-0.4049427443329971, 0.40494274433299715`}}], 
      PolygonBox[{{-0.5, 0.357662782649369}, {0.5, 0.5}, {-0.4373449933535234,
        0.2302516425362554}, {-0.5, 0.357662782649369}}], 
      PolygonBox[{{-0.4373449933535234, 
       0.2302516425362554}, {-0.4374999810329408, 0.08429258955606238}, {-0.5,
        0.357662782649369}, {-0.4373449933535234, 0.2302516425362554}}], 
      PolygonBox[{{-0.5, 0.20590900528289896`}, {-0.5, 
       0.357662782649369}, {-0.4374999810329408, 0.08429258955606238}, {-0.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{-0.4374999810329408, 0.08429258955606238}, {-0.4375, 
       0.00012317806299537147`}, {-0.5, 
       0.20590900528289896`}, {-0.4374999810329408, 0.08429258955606238}}], 
      PolygonBox[{{-0.5, 0.08067866675870025}, {-0.5, 
       0.20590900528289896`}, {-0.4375, 0.00012317806299537147`}, {-0.5, 
       0.08067866675870025}}], 
      PolygonBox[{{-0.4375, 
       0.00012317806299537147`}, {-0.4374999810329408, -0.084292589556055}, \
{-0.5, 0.08067866675870025}, {-0.4375, 0.00012317806299537147`}}], 
      PolygonBox[{{-0.5, -0.20590900514527852`}, {-0.5, 
       0.08067866675870025}, {-0.4374999810329408, -0.084292589556055}, \
{-0.5, -0.20590900514527852`}}], 
      PolygonBox[{{-0.4374999810329408, -0.084292589556055}, \
{-0.4373449933535234, -0.23025164253625477`}, {-0.5, -0.20590900514527852`}, \
{-0.4374999810329408, -0.084292589556055}}], 
      PolygonBox[{{-0.5, -0.35766278264936535`}, {-0.5, \
-0.20590900514527852`}, {-0.4373449933535234, -0.23025164253625477`}, {-0.5, \
-0.35766278264936535`}}], 
      PolygonBox[{{-0.4373449933535234, -0.23025164253625477`}, \
{-0.40494274433299715`, -0.4049427443329971}, {-0.5, -0.35766278264936535`}, \
{-0.4373449933535234, -0.23025164253625477`}}], 
      PolygonBox[{{-0.5, 
       0.5}, {-0.5, -0.35766278264936535`}, {-0.40494274433299715`, \
-0.4049427443329971}, {-0.5, 0.5}}], 
      PolygonBox[{{-0.40494274433299715`, -0.4049427443329971}, \
{-0.23025164253625505`, -0.4373449933535234}, {-0.5, 
       0.5}, {-0.40494274433299715`, -0.4049427443329971}}], 
      PolygonBox[{{-0.5, -0.5}, {-0.5, 
       0.5}, {-0.23025164253625505`, -0.4373449933535234}, {-0.5, -0.5}}], 
      PolygonBox[{{-0.23025164253625505`, -0.4373449933535234}, \
{-0.08429258955606422, -0.4374999810329408}, {-0.5, -0.5}, \
{-0.23025164253625505`, -0.4373449933535234}}], 
      PolygonBox[{{-0.20590900556682806`, -0.5}, {-0.5, -0.5}, \
{-0.08429258955606422, -0.4374999810329408}, {-0.20590900556682806`, -0.5}}], 
      PolygonBox[{{-0.08429258955606422, -0.4374999810329408}, {
       0.0001348418310429853, -0.4375}, {-0.20590900556682806`, -0.5}, \
{-0.08429258955606422, -0.4374999810329408}}], 
      PolygonBox[{{0.0823238704010616, -0.5}, {-0.20590900556682806`, -0.5}, {
       0.0001348418310429853, -0.4375}, {0.0823238704010616, -0.5}}], 
      PolygonBox[{{0.0001348418310429853, -0.4375}, {
       0.08429258955605314, -0.4374999810329408}, {
       0.0823238704010616, -0.5}, {0.0001348418310429853, -0.4375}}], 
      PolygonBox[{{0.2059090053603974, -0.5}, {0.0823238704010616, -0.5}, {
       0.08429258955605314, -0.4374999810329408}, {
       0.2059090053603974, -0.5}}], 
      PolygonBox[{{0.08429258955605314, -0.4374999810329408}, {
       0.2302516425362547, -0.4373449933535234}, {0.2059090053603974, -0.5}, {
       0.08429258955605314, -0.4374999810329408}}], 
      PolygonBox[{{0.35766278264937107`, -0.5}, {0.2059090053603974, -0.5}, {
       0.2302516425362547, -0.4373449933535234}, {
       0.35766278264937107`, -0.5}}], 
      PolygonBox[{{0.2302516425362547, -0.4373449933535234}, {
       0.4049427443329971, -0.40494274433299715`}, {
       0.35766278264937107`, -0.5}, {
       0.2302516425362547, -0.4373449933535234}}], 
      PolygonBox[{{0.5, -0.5}, {0.35766278264937107`, -0.5}, {
       0.4049427443329971, -0.40494274433299715`}, {0.5, -0.5}}], 
      PolygonBox[{{0.4049427443329971, -0.40494274433299715`}, {
       0.40494274433299715`, -0.4049427443329971}, {0.5, -0.5}, {
       0.4049427443329971, -0.40494274433299715`}}], 
      PolygonBox[{{0.5, -0.5}, {0.5, -0.5}, {
       0.40494274433299715`, -0.4049427443329971}, {
       0.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 1.}, {-0.4791666666666667, 1.}, {-0.4583333333333333, 
       1.}, {-0.4375, 1.}, {-0.4166666666666667, 1.}, {-0.39583333333333337`, 
       1.}, {-0.375, 1.}, {-0.375, 1.}, {-0.3958333333333333, 
       1.}, {-0.4166666666666667, 1.}, {-0.4375, 1.}, {-0.4583333333333333, 
       1.}, {-0.47916666666666663`, 1.}, {-0.5, 1.}, {-0.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, 1.}, {0.3958333333333333, 1.}, {0.4166666666666667, 
       1.}, {0.4375, 1.}, {0.4583333333333333, 1.}, {0.47916666666666663`, 
       1.}, {0.5, 1.}, {0.5, 1.}, {0.4791666666666667, 1.}, {
       0.4583333333333333, 1.}, {0.4375, 1.}, {0.4166666666666667, 1.}, {
       0.39583333333333337`, 1.}, {0.375, 1.}, {0.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 0.5}, {0., 0.5208333333333333}, {0., 
       0.5416666666666667}, {0., 0.5625}, {0., 0.5833333333333333}, {0., 
       0.6041666666666666}, {0., 0.625}, {0., 0.625}, {0., 
       0.6041666666666667}, {0., 0.5833333333333333}, {0., 0.5625}, {0., 
       0.5416666666666667}, {0., 0.5208333333333334}, {0., 0.5}, {0., 0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 1.375}, {0., 1.3958333333333333`}, {0., 
       1.4166666666666667`}, {0., 1.4375}, {0., 1.4583333333333333`}, {0., 
       1.4791666666666665`}, {0., 1.5}, {0., 1.5}, {0., 
       1.4791666666666667`}, {0., 1.4583333333333333`}, {0., 1.4375}, {0., 
       1.4166666666666667`}, {0., 1.3958333333333335`}, {0., 1.375}, {0., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, 1.}, {-0.25, 1.}, {-0.125, 1.}, {0., 1.}, {0.125, 
       1.}, {0.25, 1.}, {0.375, 1.}, {0.375, 1.}, {0.25, 1.}, {0.125, 1.}, {
       0., 1.}, {-0.125, 1.}, {-0.25, 1.}, {-0.375, 1.}, {-0.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 0.625}, {0., 0.75}, {0., 0.875}, {0., 1.}, {0., 1.125}, {
       0., 1.25}, {0., 1.375}, {0., 1.375}, {0., 1.25}, {0., 1.125}, {0., 
       1.}, {0., 0.875}, {0., 0.75}, {0., 0.625}, {0., 0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CH0B/uA/rKvS/Wu2887oXqqu/ejfYOlk96d
E1eg8p/tb+XcP1P244K92W3zzbJ2X+whZpywT+ibwG1u9NX+XmfMoj03dthf
WRxbu/L0V3uurnk+lpVVNhD93+yvQuT3w+T//geB4/th+m9CzN8PM78eYv9+
mP3+EPfth7kP6v79aO7ffyxvS/aLJ2/sG6H6GcHyr+zvQM2f4jlh5pHm5/Zs
EPfvd3x878XE2U/t30LdF7nDhXVtxhP7judlP1/dmrwHYv4T+zNQ/0VA5b9D
3G9vD9V/Axo+k6Hm10HD7x9Y3Ut7P2j4HoK6Dxb+YOn/7+0BxCXJQg==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CH0D/uwUBC4isY/CuczoIAf9iEQ+f2o/Kv7
UdU/IMiH2PMVzl+9CgQ+oan/gCb/Ck3/UzT1DzD4YSjug/GPoqlHhEsIiv9h
/Kv2qOoJ06Go7rNfhep+ezT/QeU/oen/iqb+hz0AW5ZtfA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, 0.7348349570550448}, {
       0.3247595264191645, 0.8125}, {0.40494274433299715`, 
       0.5950572556670028}, {0.26516504294495535`, 0.7348349570550448}}], 
      PolygonBox[{{0.4373449933535234, 0.7697483574637448}, {
       0.40494274433299715`, 0.5950572556670028}, {0.3247595264191645, 
       0.8125}, {0.4373449933535234, 0.7697483574637448}}], 
      PolygonBox[{{0.3247595264191645, 0.8125}, {0.36222218485840063`, 
       0.9029428580865547}, {0.4373449933535234, 0.7697483574637448}, {
       0.3247595264191645, 0.8125}}], 
      PolygonBox[{{0.4374999810329408, 0.9157074104439382}, {
       0.4373449933535234, 0.7697483574637448}, {0.36222218485840063`, 
       0.9029428580865547}, {0.4374999810329408, 0.9157074104439382}}], 
      PolygonBox[{{0.36222218485840063`, 0.9029428580865547}, {0.375, 1.}, {
       0.4374999810329408, 0.9157074104439382}, {0.36222218485840063`, 
       0.9029428580865547}}], 
      PolygonBox[{{0.4375, 1.}, {0.4374999810329408, 0.9157074104439382}, {
       0.375, 1.}, {0.4375, 1.}}], 
      PolygonBox[{{0.375, 1.}, {0.36222218485840063`, 1.0970571419134452`}, {
       0.4375, 1.}, {0.375, 1.}}], 
      PolygonBox[{{0.4374999810329408, 1.0842925895560618`}, {0.4375, 1.}, {
       0.36222218485840063`, 1.0970571419134452`}, {0.4374999810329408, 
       1.0842925895560618`}}], 
      PolygonBox[{{0.36222218485840063`, 1.0970571419134452`}, {
       0.3247595264191645, 1.1875}, {0.4374999810329408, 
       1.0842925895560618`}, {0.36222218485840063`, 1.0970571419134452`}}], 
      PolygonBox[{{0.4373449933535234, 1.230251642536255}, {
       0.4374999810329408, 1.0842925895560618`}, {0.3247595264191645, 
       1.1875}, {0.4373449933535234, 1.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, 1.1875}, {0.26516504294495535`, 
       1.2651650429449552`}, {0.4373449933535234, 1.230251642536255}, {
       0.3247595264191645, 1.1875}}], 
      PolygonBox[{{0.4049427443329971, 1.4049427443329972`}, {
       0.4373449933535234, 1.230251642536255}, {0.26516504294495535`, 
       1.2651650429449552`}, {0.4049427443329971, 1.4049427443329972`}}], 
      PolygonBox[{{0.26516504294495535`, 1.2651650429449552`}, {
       0.18750000000000006`, 1.3247595264191645`}, {0.4049427443329971, 
       1.4049427443329972`}, {0.26516504294495535`, 1.2651650429449552`}}], 
      PolygonBox[{{0.23025164253625516`, 1.4373449933535234`}, {
       0.4049427443329971, 1.4049427443329972`}, {0.18750000000000006`, 
       1.3247595264191645`}, {0.23025164253625516`, 1.4373449933535234`}}], 
      PolygonBox[{{0.18750000000000006`, 1.3247595264191645`}, {
       0.09705714191344536, 1.3622221848584006`}, {0.23025164253625516`, 
       1.4373449933535234`}, {0.18750000000000006`, 1.3247595264191645`}}], 
      PolygonBox[{{0.08429258955606053, 1.4374999810329407`}, {
       0.23025164253625516`, 1.4373449933535234`}, {0.09705714191344536, 
       1.3622221848584006`}, {0.08429258955606053, 1.4374999810329407`}}], 
      PolygonBox[{{0.09705714191344536, 1.3622221848584006`}, {
       2.296212748401287*^-17, 1.375}, {0.08429258955606053, 
       1.4374999810329407`}, {0.09705714191344536, 1.3622221848584006`}}], 
      PolygonBox[{{0.0001055272204876927, 1.4375}, {0.08429258955606053, 
       1.4374999810329407`}, {2.296212748401287*^-17, 1.375}, {
       0.0001055272204876927, 1.4375}}], 
      PolygonBox[{{2.296212748401287*^-17, 1.375}, {-0.09705714191344515, 
       1.3622221848584006`}, {0.0001055272204876927, 1.4375}, {
       2.296212748401287*^-17, 1.375}}], 
      PolygonBox[{{-0.08429258955605684, 1.4374999810329407`}, {
       0.0001055272204876927, 1.4375}, {-0.09705714191344515, 
       1.3622221848584006`}, {-0.08429258955605684, 1.4374999810329407`}}], 
      PolygonBox[{{-0.09705714191344515, 
       1.3622221848584006`}, {-0.18749999999999992`, 
       1.3247595264191645`}, {-0.08429258955605684, 
       1.4374999810329407`}, {-0.09705714191344515, 1.3622221848584006`}}], 
      PolygonBox[{{-0.23025164253625502`, 
       1.4373449933535234`}, {-0.08429258955605684, 
       1.4374999810329407`}, {-0.18749999999999992`, 
       1.3247595264191645`}, {-0.23025164253625502`, 1.4373449933535234`}}], 
      PolygonBox[{{-0.18749999999999992`, 
       1.3247595264191645`}, {-0.2651650429449553, 
       1.2651650429449552`}, {-0.23025164253625502`, 
       1.4373449933535234`}, {-0.18749999999999992`, 1.3247595264191645`}}], 
      PolygonBox[{{-0.4049427443329971, 
       1.4049427443329972`}, {-0.23025164253625502`, 
       1.4373449933535234`}, {-0.2651650429449553, 
       1.2651650429449552`}, {-0.4049427443329971, 1.4049427443329972`}}], 
      PolygonBox[{{-0.2651650429449553, 
       1.2651650429449552`}, {-0.32475952641916445`, 
       1.1875}, {-0.4049427443329971, 
       1.4049427443329972`}, {-0.2651650429449553, 1.2651650429449552`}}], 
      PolygonBox[{{-0.4373449933535234, 
       1.2302516425362553`}, {-0.4049427443329971, 
       1.4049427443329972`}, {-0.32475952641916445`, 
       1.1875}, {-0.4373449933535234, 1.2302516425362553`}}], 
      PolygonBox[{{-0.32475952641916445`, 1.1875}, {-0.3622221848584006, 
       1.0970571419134454`}, {-0.4373449933535234, 
       1.2302516425362553`}, {-0.32475952641916445`, 1.1875}}], 
      PolygonBox[{{-0.4374999810329408, 
       1.0842925895560624`}, {-0.4373449933535234, 
       1.2302516425362553`}, {-0.3622221848584006, 
       1.0970571419134454`}, {-0.4374999810329408, 1.0842925895560624`}}], 
      PolygonBox[{{-0.3622221848584006, 1.0970571419134454`}, {-0.375, 
       1.0000000000000002`}, {-0.4374999810329408, 
       1.0842925895560624`}, {-0.3622221848584006, 1.0970571419134454`}}], 
      PolygonBox[{{-0.4375, 1.0001231780629953`}, {-0.4374999810329408, 
       1.0842925895560624`}, {-0.375, 1.0000000000000002`}, {-0.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-0.375, 1.0000000000000002`}, {-0.36222218485840063`, 
       0.9029428580865548}, {-0.4375, 1.0001231780629953`}, {-0.375, 
       1.0000000000000002`}}], 
      PolygonBox[{{-0.4374999810329408, 0.915707410443945}, {-0.4375, 
       1.0001231780629953`}, {-0.36222218485840063`, 
       0.9029428580865548}, {-0.4374999810329408, 0.915707410443945}}], 
      PolygonBox[{{-0.36222218485840063`, 
       0.9029428580865548}, {-0.3247595264191646, 
       0.8125000000000002}, {-0.4374999810329408, 
       0.915707410443945}, {-0.36222218485840063`, 0.9029428580865548}}], 
      PolygonBox[{{-0.4373449933535234, 
       0.7697483574637453}, {-0.4374999810329408, 
       0.915707410443945}, {-0.3247595264191646, 
       0.8125000000000002}, {-0.4373449933535234, 0.7697483574637453}}], 
      PolygonBox[{{-0.3247595264191646, 
       0.8125000000000002}, {-0.26516504294495535`, 
       0.7348349570550448}, {-0.4373449933535234, 
       0.7697483574637453}, {-0.3247595264191646, 0.8125000000000002}}], 
      PolygonBox[{{-0.40494274433299715`, 
       0.5950572556670028}, {-0.4373449933535234, 
       0.7697483574637453}, {-0.26516504294495535`, 
       0.7348349570550448}, {-0.40494274433299715`, 0.5950572556670028}}], 
      PolygonBox[{{-0.26516504294495535`, 
       0.7348349570550448}, {-0.18750000000000017`, 
       0.6752404735808356}, {-0.40494274433299715`, 
       0.5950572556670028}, {-0.26516504294495535`, 0.7348349570550448}}], 
      PolygonBox[{{-0.23025164253625505`, 
       0.5626550066464766}, {-0.40494274433299715`, 
       0.5950572556670028}, {-0.18750000000000017`, 
       0.6752404735808356}, {-0.23025164253625505`, 0.5626550066464766}}], 
      PolygonBox[{{-0.18750000000000017`, 
       0.6752404735808356}, {-0.09705714191344557, 
       0.6377778151415995}, {-0.23025164253625505`, 
       0.5626550066464766}, {-0.18750000000000017`, 0.6752404735808356}}], 
      PolygonBox[{{-0.08429258955606422, 
       0.5625000189670593}, {-0.23025164253625505`, 
       0.5626550066464766}, {-0.09705714191344557, 
       0.6377778151415995}, {-0.08429258955606422, 0.5625000189670593}}], 
      PolygonBox[{{-0.09705714191344557, 0.6377778151415995}, {
       6.888638245203862*^-17, 0.625}, {-0.08429258955606422, 
       0.5625000189670593}, {-0.09705714191344557, 0.6377778151415995}}], 
      PolygonBox[{{0.0001348418310429853, 0.5625}, {-0.08429258955606422, 
       0.5625000189670593}, {6.888638245203862*^-17, 0.625}, {
       0.0001348418310429853, 0.5625}}], 
      PolygonBox[{{6.888638245203862*^-17, 0.625}, {0.09705714191344511, 
       0.6377778151415994}, {0.0001348418310429853, 0.5625}, {
       6.888638245203862*^-17, 0.625}}], 
      PolygonBox[{{0.08429258955605314, 0.5625000189670593}, {
       0.0001348418310429853, 0.5625}, {0.09705714191344511, 
       0.6377778151415994}, {0.08429258955605314, 0.5625000189670593}}], 
      PolygonBox[{{0.09705714191344511, 0.6377778151415994}, {
       0.18749999999999975`, 0.6752404735808354}, {0.08429258955605314, 
       0.5625000189670593}, {0.09705714191344511, 0.6377778151415994}}], 
      PolygonBox[{{0.2302516425362547, 0.5626550066464766}, {
       0.08429258955605314, 0.5625000189670593}, {0.18749999999999975`, 
       0.6752404735808354}, {0.2302516425362547, 0.5626550066464766}}], 
      PolygonBox[{{0.18749999999999975`, 0.6752404735808354}, {
       0.26516504294495524`, 0.7348349570550446}, {0.2302516425362547, 
       0.5626550066464766}, {0.18749999999999975`, 0.6752404735808354}}], 
      PolygonBox[{{0.4049427443329971, 0.5950572556670028}, {
       0.2302516425362547, 0.5626550066464766}, {0.26516504294495524`, 
       0.7348349570550446}, {0.4049427443329971, 0.5950572556670028}}], 
      PolygonBox[{{0.26516504294495524`, 0.7348349570550446}, {
       0.26516504294495535`, 0.7348349570550448}, {0.4049427443329971, 
       0.5950572556670028}, {0.26516504294495524`, 0.7348349570550446}}], 
      PolygonBox[{{0.40494274433299715`, 0.5950572556670028}, {
       0.4049427443329971, 0.5950572556670028}, {0.26516504294495535`, 
       0.7348349570550448}, {0.40494274433299715`, 0.5950572556670028}}], 
      PolygonBox[{{0.40494274433299715`, 0.5950572556670028}, {
       0.4373449933535234, 0.7697483574637448}, {0.5, 0.5}, {
       0.40494274433299715`, 0.5950572556670028}}], 
      PolygonBox[{{0.5, 0.6423372173506323}, {0.5, 0.5}, {0.4373449933535234, 
       0.7697483574637448}, {0.5, 0.6423372173506323}}], 
      PolygonBox[{{0.4373449933535234, 0.7697483574637448}, {
       0.4374999810329408, 0.9157074104439382}, {0.5, 0.6423372173506323}, {
       0.4373449933535234, 0.7697483574637448}}], 
      PolygonBox[{{0.5, 0.79409099469826}, {0.5, 0.6423372173506323}, {
       0.4374999810329408, 0.9157074104439382}, {0.5, 0.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, 0.9157074104439382}, {0.4375, 1.}, {
       0.5, 0.79409099469826}, {0.4374999810329408, 0.9157074104439382}}], 
      PolygonBox[{{0.5, 1.}, {0.5, 0.79409099469826}, {0.4375, 1.}, {0.5, 
       1.}}], PolygonBox[{{0.4375, 1.}, {0.4374999810329408, 
       1.0842925895560618`}, {0.5, 1.}, {0.4375, 1.}}], 
      PolygonBox[{{0.5, 1.2059090053017398`}, {0.5, 1.}, {0.4374999810329408, 
       1.0842925895560618`}, {0.5, 1.2059090053017398`}}], 
      PolygonBox[{{0.4374999810329408, 1.0842925895560618`}, {
       0.4373449933535234, 1.230251642536255}, {0.5, 1.2059090053017398`}, {
       0.4374999810329408, 1.0842925895560618`}}], 
      PolygonBox[{{0.5, 1.3576627826493675`}, {0.5, 1.2059090053017398`}, {
       0.4373449933535234, 1.230251642536255}, {0.5, 1.3576627826493675`}}], 
      PolygonBox[{{0.4373449933535234, 1.230251642536255}, {
       0.4049427443329971, 1.4049427443329972`}, {0.5, 1.3576627826493675`}, {
       0.4373449933535234, 1.230251642536255}}], 
      PolygonBox[{{0.491446564961186, 1.491446564961186}, {0.5, 
       1.3576627826493675`}, {0.4049427443329971, 1.4049427443329972`}, {
       0.491446564961186, 1.491446564961186}}], 
      PolygonBox[{{0.4049427443329971, 1.4049427443329972`}, {
       0.23025164253625516`, 1.4373449933535234`}, {0.491446564961186, 
       1.491446564961186}, {0.4049427443329971, 1.4049427443329972`}}], 
      PolygonBox[{{0.35766278264936807`, 1.5}, {0.491446564961186, 
       1.491446564961186}, {0.23025164253625516`, 1.4373449933535234`}, {
       0.35766278264936807`, 1.5}}], 
      PolygonBox[{{0.23025164253625516`, 1.4373449933535234`}, {
       0.08429258955606053, 1.4374999810329407`}, {0.35766278264936807`, 
       1.5}, {0.23025164253625516`, 1.4373449933535234`}}], 
      PolygonBox[{{0.20590900537325585`, 1.5}, {0.35766278264936807`, 1.5}, {
       0.08429258955606053, 1.4374999810329407`}, {0.20590900537325585`, 
       1.5}}], PolygonBox[{{0.08429258955606053, 1.4374999810329407`}, {
       0.0001055272204876927, 1.4375}, {0.20590900537325585`, 1.5}, {
       0.08429258955606053, 1.4374999810329407`}}], 
      PolygonBox[{{0.07794195802689004, 1.5}, {0.20590900537325585`, 1.5}, {
       0.0001055272204876927, 1.4375}, {0.07794195802689004, 1.5}}], 
      PolygonBox[{{0.0001055272204876927, 1.4375}, {-0.08429258955605684, 
       1.4374999810329407`}, {0.07794195802689004, 1.5}, {
       0.0001055272204876927, 1.4375}}], 
      PolygonBox[{{-0.20590900530444564`, 1.5}, {0.07794195802689004, 
       1.5}, {-0.08429258955605684, 
       1.4374999810329407`}, {-0.20590900530444564`, 1.5}}], 
      PolygonBox[{{-0.08429258955605684, 
       1.4374999810329407`}, {-0.23025164253625502`, 
       1.4373449933535234`}, {-0.20590900530444564`, 
       1.5}, {-0.08429258955605684, 1.4374999810329407`}}], 
      PolygonBox[{{-0.35766278264936624`, 1.5}, {-0.20590900530444564`, 
       1.5}, {-0.23025164253625502`, 
       1.4373449933535234`}, {-0.35766278264936624`, 1.5}}], 
      PolygonBox[{{-0.23025164253625502`, 
       1.4373449933535234`}, {-0.4049427443329971, 
       1.4049427443329972`}, {-0.35766278264936624`, 
       1.5}, {-0.23025164253625502`, 1.4373449933535234`}}], 
      PolygonBox[{{0.5, 1.5}, {-0.35766278264936624`, 
       1.5}, {-0.4049427443329971, 1.4049427443329972`}, {0.5, 1.5}}], 
      PolygonBox[{{-0.4049427443329971, 
       1.4049427443329972`}, {-0.4373449933535234, 1.2302516425362553`}, {0.5,
        1.5}, {-0.4049427443329971, 1.4049427443329972`}}], 
      PolygonBox[{{-0.5, 1.357662782649369}, {0.5, 1.5}, {-0.4373449933535234,
        1.2302516425362553`}, {-0.5, 1.357662782649369}}], 
      PolygonBox[{{-0.4373449933535234, 
       1.2302516425362553`}, {-0.4374999810329408, 
       1.0842925895560624`}, {-0.5, 1.357662782649369}, {-0.4373449933535234, 
       1.2302516425362553`}}], 
      PolygonBox[{{-0.5, 1.205909005282899}, {-0.5, 
       1.357662782649369}, {-0.4374999810329408, 1.0842925895560624`}, {-0.5, 
       1.205909005282899}}], 
      PolygonBox[{{-0.4374999810329408, 1.0842925895560624`}, {-0.4375, 
       1.0001231780629953`}, {-0.5, 1.205909005282899}, {-0.4374999810329408, 
       1.0842925895560624`}}], 
      PolygonBox[{{-0.5, 1.0806786667587003`}, {-0.5, 
       1.205909005282899}, {-0.4375, 1.0001231780629953`}, {-0.5, 
       1.0806786667587003`}}], 
      PolygonBox[{{-0.4375, 1.0001231780629953`}, {-0.4374999810329408, 
       0.915707410443945}, {-0.5, 1.0806786667587003`}, {-0.4375, 
       1.0001231780629953`}}], 
      PolygonBox[{{-0.5, 0.7940909948547215}, {-0.5, 
       1.0806786667587003`}, {-0.4374999810329408, 0.915707410443945}, {-0.5, 
       0.7940909948547215}}], 
      PolygonBox[{{-0.4374999810329408, 
       0.915707410443945}, {-0.4373449933535234, 0.7697483574637453}, {-0.5, 
       0.7940909948547215}, {-0.4374999810329408, 0.915707410443945}}], 
      PolygonBox[{{-0.5, 0.6423372173506346}, {-0.5, 
       0.7940909948547215}, {-0.4373449933535234, 0.7697483574637453}, {-0.5, 
       0.6423372173506346}}], 
      PolygonBox[{{-0.4373449933535234, 
       0.7697483574637453}, {-0.40494274433299715`, 
       0.5950572556670028}, {-0.5, 0.6423372173506346}, {-0.4373449933535234, 
       0.7697483574637453}}], 
      PolygonBox[{{-0.5, 1.5}, {-0.5, 
       0.6423372173506346}, {-0.40494274433299715`, 
       0.5950572556670028}, {-0.5, 1.5}}], 
      PolygonBox[{{-0.40494274433299715`, 
       0.5950572556670028}, {-0.23025164253625505`, 
       0.5626550066464766}, {-0.5, 1.5}, {-0.40494274433299715`, 
       0.5950572556670028}}], 
      PolygonBox[{{-0.5, 0.5}, {-0.5, 1.5}, {-0.23025164253625505`, 
       0.5626550066464766}, {-0.5, 0.5}}], 
      PolygonBox[{{-0.23025164253625505`, 
       0.5626550066464766}, {-0.08429258955606422, 0.5625000189670593}, {-0.5,
        0.5}, {-0.23025164253625505`, 0.5626550066464766}}], 
      PolygonBox[{{-0.20590900556682806`, 0.5}, {-0.5, 
       0.5}, {-0.08429258955606422, 
       0.5625000189670593}, {-0.20590900556682806`, 0.5}}], 
      PolygonBox[{{-0.08429258955606422, 0.5625000189670593}, {
       0.0001348418310429853, 0.5625}, {-0.20590900556682806`, 
       0.5}, {-0.08429258955606422, 0.5625000189670593}}], 
      PolygonBox[{{0.0823238704010616, 0.5}, {-0.20590900556682806`, 0.5}, {
       0.0001348418310429853, 0.5625}, {0.0823238704010616, 0.5}}], 
      PolygonBox[{{0.0001348418310429853, 0.5625}, {0.08429258955605314, 
       0.5625000189670593}, {0.0823238704010616, 0.5}, {0.0001348418310429853,
        0.5625}}], 
      PolygonBox[{{0.2059090053603974, 0.5}, {0.0823238704010616, 0.5}, {
       0.08429258955605314, 0.5625000189670593}, {0.2059090053603974, 0.5}}], 
      PolygonBox[{{0.08429258955605314, 0.5625000189670593}, {
       0.2302516425362547, 0.5626550066464766}, {0.2059090053603974, 0.5}, {
       0.08429258955605314, 0.5625000189670593}}], 
      PolygonBox[{{0.35766278264937107`, 0.5}, {0.2059090053603974, 0.5}, {
       0.2302516425362547, 0.5626550066464766}, {0.35766278264937107`, 0.5}}],
       PolygonBox[{{0.2302516425362547, 0.5626550066464766}, {
       0.4049427443329971, 0.5950572556670028}, {0.35766278264937107`, 0.5}, {
       0.2302516425362547, 0.5626550066464766}}], 
      PolygonBox[{{0.5, 0.5}, {0.35766278264937107`, 0.5}, {
       0.4049427443329971, 0.5950572556670028}, {0.5, 0.5}}], 
      PolygonBox[{{0.4049427443329971, 0.5950572556670028}, {
       0.40494274433299715`, 0.5950572556670028}, {0.5, 0.5}, {
       0.4049427443329971, 0.5950572556670028}}], 
      PolygonBox[{{0.5, 0.5}, {0.5, 0.5}, {0.40494274433299715`, 
       0.5950572556670028}, {0.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 2.}, {-0.4791666666666667, 2.}, {-0.4583333333333333, 
       2.}, {-0.4375, 2.}, {-0.4166666666666667, 2.}, {-0.39583333333333337`, 
       2.}, {-0.375, 2.}, {-0.375, 2.}, {-0.3958333333333333, 
       2.}, {-0.4166666666666667, 2.}, {-0.4375, 2.}, {-0.4583333333333333, 
       2.}, {-0.47916666666666663`, 2.}, {-0.5, 2.}, {-0.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, 2.}, {0.3958333333333333, 2.}, {0.4166666666666667, 
       2.}, {0.4375, 2.}, {0.4583333333333333, 2.}, {0.47916666666666663`, 
       2.}, {0.5, 2.}, {0.5, 2.}, {0.4791666666666667, 2.}, {
       0.4583333333333333, 2.}, {0.4375, 2.}, {0.4166666666666667, 2.}, {
       0.39583333333333337`, 2.}, {0.375, 2.}, {0.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 1.5}, {0., 1.5208333333333333`}, {0., 
       1.5416666666666667`}, {0., 1.5625}, {0., 1.5833333333333333`}, {0., 
       1.6041666666666665`}, {0., 1.625}, {0., 1.625}, {0., 
       1.6041666666666667`}, {0., 1.5833333333333333`}, {0., 1.5625}, {0., 
       1.5416666666666667`}, {0., 1.5208333333333335`}, {0., 1.5}, {0., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 2.375}, {0., 2.3958333333333335`}, {0., 
       2.4166666666666665`}, {0., 2.4375}, {0., 2.4583333333333335`}, {0., 
       2.4791666666666665`}, {0., 2.5}, {0., 2.5}, {0., 
       2.4791666666666665`}, {0., 2.4583333333333335`}, {0., 2.4375}, {0., 
       2.4166666666666665`}, {0., 2.3958333333333335`}, {0., 2.375}, {0., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, 2.}, {-0.25, 2.}, {-0.125, 2.}, {0., 2.}, {0.125, 
       2.}, {0.25, 2.}, {0.375, 2.}, {0.375, 2.}, {0.25, 2.}, {0.125, 2.}, {
       0., 2.}, {-0.125, 2.}, {-0.25, 2.}, {-0.375, 2.}, {-0.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 1.625}, {0., 1.75}, {0., 1.875}, {0., 2.}, {0., 2.125}, {
       0., 2.25}, {0., 2.375}, {0., 2.375}, {0., 2.25}, {0., 2.125}, {0., 
       2.}, {0., 1.875}, {0., 1.75}, {0., 1.625}, {0., 1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37KEMh4D+sq9L9a7b+z8Renr0GINDg6WT3p0T
VyDyDYwOt3Lunyn7ccF+9tvZN/nkmRwgZpywN3A/0So9k8nhXmfMoj03dti/
urhu35WnTA5cXfN8LCurbCDGMztchcjvh8n//Q8Cx/fD9N+EmL8fZn49xP79
MPv9Ie7bD3Mf1P370dy/P9n8lmlJ0T/7RmT9DH/t70DNP6VywufRwd/2bBD3
719QmP/lxNlf9m+h7tOJWdQUZvLLvuN52c9Xtybvgej/ZX8G6j+Y/HeI++1h
+m9Awwdmfh00/MDK/v+x94OGbyLUfejhDwBPl7p+
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CE0i0NYKAhcReMfhfMZUACLQwhEfj8q/+p+
VPUPCPJXrwIBJjgfbEwoI5p6Bjgf4q6/9qj6f9mjqv+BwQ9DcR+MfxRNPQz8
sA9B8T+Mf9UeVf0DgvxVqO6zD0V1P8xeB1R5uP+h+uHhA48PAEwDYHY=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, 1.7348349570550448`}, {
       0.3247595264191645, 1.8125}, {0.40494274433299715`, 
       1.5950572556670028`}, {0.26516504294495535`, 1.7348349570550448`}}], 
      PolygonBox[{{0.4373449933535234, 1.769748357463745}, {
       0.40494274433299715`, 1.5950572556670028`}, {0.3247595264191645, 
       1.8125}, {0.4373449933535234, 1.769748357463745}}], 
      PolygonBox[{{0.3247595264191645, 1.8125}, {0.36222218485840063`, 
       1.9029428580865546`}, {0.4373449933535234, 1.769748357463745}, {
       0.3247595264191645, 1.8125}}], 
      PolygonBox[{{0.4374999810329408, 1.9157074104439382`}, {
       0.4373449933535234, 1.769748357463745}, {0.36222218485840063`, 
       1.9029428580865546`}, {0.4374999810329408, 1.9157074104439382`}}], 
      PolygonBox[{{0.36222218485840063`, 1.9029428580865546`}, {0.375, 2.}, {
       0.4374999810329408, 1.9157074104439382`}, {0.36222218485840063`, 
       1.9029428580865546`}}], 
      PolygonBox[{{0.4375, 2.}, {0.4374999810329408, 1.9157074104439382`}, {
       0.375, 2.}, {0.4375, 2.}}], 
      PolygonBox[{{0.375, 2.}, {0.36222218485840063`, 2.0970571419134454`}, {
       0.4375, 2.}, {0.375, 2.}}], 
      PolygonBox[{{0.4374999810329408, 2.084292589556062}, {0.4375, 2.}, {
       0.36222218485840063`, 2.0970571419134454`}, {0.4374999810329408, 
       2.084292589556062}}], 
      PolygonBox[{{0.36222218485840063`, 2.0970571419134454`}, {
       0.3247595264191645, 2.1875}, {0.4374999810329408, 2.084292589556062}, {
       0.36222218485840063`, 2.0970571419134454`}}], 
      PolygonBox[{{0.4373449933535234, 2.230251642536255}, {
       0.4374999810329408, 2.084292589556062}, {0.3247595264191645, 2.1875}, {
       0.4373449933535234, 2.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, 2.1875}, {0.26516504294495535`, 
       2.2651650429449552`}, {0.4373449933535234, 2.230251642536255}, {
       0.3247595264191645, 2.1875}}], 
      PolygonBox[{{0.4049427443329971, 2.404942744332997}, {
       0.4373449933535234, 2.230251642536255}, {0.26516504294495535`, 
       2.2651650429449552`}, {0.4049427443329971, 2.404942744332997}}], 
      PolygonBox[{{0.26516504294495535`, 2.2651650429449552`}, {
       0.18750000000000006`, 2.3247595264191645`}, {0.4049427443329971, 
       2.404942744332997}, {0.26516504294495535`, 2.2651650429449552`}}], 
      PolygonBox[{{0.23025164253625516`, 2.4373449933535234`}, {
       0.4049427443329971, 2.404942744332997}, {0.18750000000000006`, 
       2.3247595264191645`}, {0.23025164253625516`, 2.4373449933535234`}}], 
      PolygonBox[{{0.18750000000000006`, 2.3247595264191645`}, {
       0.09705714191344536, 2.3622221848584006`}, {0.23025164253625516`, 
       2.4373449933535234`}, {0.18750000000000006`, 2.3247595264191645`}}], 
      PolygonBox[{{0.08429258955606053, 2.437499981032941}, {
       0.23025164253625516`, 2.4373449933535234`}, {0.09705714191344536, 
       2.3622221848584006`}, {0.08429258955606053, 2.437499981032941}}], 
      PolygonBox[{{0.09705714191344536, 2.3622221848584006`}, {
       2.296212748401287*^-17, 2.375}, {0.08429258955606053, 
       2.437499981032941}, {0.09705714191344536, 2.3622221848584006`}}], 
      PolygonBox[{{0.0001055272204876927, 2.4375}, {0.08429258955606053, 
       2.437499981032941}, {2.296212748401287*^-17, 2.375}, {
       0.0001055272204876927, 2.4375}}], 
      PolygonBox[{{2.296212748401287*^-17, 2.375}, {-0.09705714191344515, 
       2.3622221848584006`}, {0.0001055272204876927, 2.4375}, {
       2.296212748401287*^-17, 2.375}}], 
      PolygonBox[{{-0.08429258955605684, 2.437499981032941}, {
       0.0001055272204876927, 2.4375}, {-0.09705714191344515, 
       2.3622221848584006`}, {-0.08429258955605684, 2.437499981032941}}], 
      PolygonBox[{{-0.09705714191344515, 
       2.3622221848584006`}, {-0.18749999999999992`, 
       2.3247595264191645`}, {-0.08429258955605684, 
       2.437499981032941}, {-0.09705714191344515, 2.3622221848584006`}}], 
      PolygonBox[{{-0.23025164253625502`, 
       2.4373449933535234`}, {-0.08429258955605684, 
       2.437499981032941}, {-0.18749999999999992`, 
       2.3247595264191645`}, {-0.23025164253625502`, 2.4373449933535234`}}], 
      PolygonBox[{{-0.18749999999999992`, 
       2.3247595264191645`}, {-0.2651650429449553, 
       2.2651650429449552`}, {-0.23025164253625502`, 
       2.4373449933535234`}, {-0.18749999999999992`, 2.3247595264191645`}}], 
      PolygonBox[{{-0.4049427443329971, 
       2.404942744332997}, {-0.23025164253625502`, 
       2.4373449933535234`}, {-0.2651650429449553, 
       2.2651650429449552`}, {-0.4049427443329971, 2.404942744332997}}], 
      PolygonBox[{{-0.2651650429449553, 
       2.2651650429449552`}, {-0.32475952641916445`, 
       2.1875}, {-0.4049427443329971, 
       2.404942744332997}, {-0.2651650429449553, 2.2651650429449552`}}], 
      PolygonBox[{{-0.4373449933535234, 
       2.2302516425362553`}, {-0.4049427443329971, 
       2.404942744332997}, {-0.32475952641916445`, 
       2.1875}, {-0.4373449933535234, 2.2302516425362553`}}], 
      PolygonBox[{{-0.32475952641916445`, 2.1875}, {-0.3622221848584006, 
       2.0970571419134454`}, {-0.4373449933535234, 
       2.2302516425362553`}, {-0.32475952641916445`, 2.1875}}], 
      PolygonBox[{{-0.4374999810329408, 
       2.0842925895560622`}, {-0.4373449933535234, 
       2.2302516425362553`}, {-0.3622221848584006, 
       2.0970571419134454`}, {-0.4374999810329408, 2.0842925895560622`}}], 
      PolygonBox[{{-0.3622221848584006, 2.0970571419134454`}, {-0.375, 
       2.}, {-0.4374999810329408, 2.0842925895560622`}, {-0.3622221848584006, 
       2.0970571419134454`}}], 
      PolygonBox[{{-0.4375, 2.0001231780629953`}, {-0.4374999810329408, 
       2.0842925895560622`}, {-0.375, 2.}, {-0.4375, 2.0001231780629953`}}], 
      PolygonBox[{{-0.375, 2.}, {-0.36222218485840063`, 
       1.9029428580865548`}, {-0.4375, 2.0001231780629953`}, {-0.375, 2.}}], 
      PolygonBox[{{-0.4374999810329408, 1.915707410443945}, {-0.4375, 
       2.0001231780629953`}, {-0.36222218485840063`, 
       1.9029428580865548`}, {-0.4374999810329408, 1.915707410443945}}], 
      PolygonBox[{{-0.36222218485840063`, 
       1.9029428580865548`}, {-0.3247595264191646, 
       1.8125000000000002`}, {-0.4374999810329408, 
       1.915707410443945}, {-0.36222218485840063`, 1.9029428580865548`}}], 
      PolygonBox[{{-0.4373449933535234, 
       1.7697483574637451`}, {-0.4374999810329408, 
       1.915707410443945}, {-0.3247595264191646, 
       1.8125000000000002`}, {-0.4373449933535234, 1.7697483574637451`}}], 
      PolygonBox[{{-0.3247595264191646, 
       1.8125000000000002`}, {-0.26516504294495535`, 
       1.7348349570550448`}, {-0.4373449933535234, 
       1.7697483574637451`}, {-0.3247595264191646, 1.8125000000000002`}}], 
      PolygonBox[{{-0.40494274433299715`, 
       1.5950572556670028`}, {-0.4373449933535234, 
       1.7697483574637451`}, {-0.26516504294495535`, 
       1.7348349570550448`}, {-0.40494274433299715`, 1.5950572556670028`}}], 
      PolygonBox[{{-0.26516504294495535`, 
       1.7348349570550448`}, {-0.18750000000000017`, 
       1.6752404735808355`}, {-0.40494274433299715`, 
       1.5950572556670028`}, {-0.26516504294495535`, 1.7348349570550448`}}], 
      PolygonBox[{{-0.23025164253625505`, 
       1.5626550066464766`}, {-0.40494274433299715`, 
       1.5950572556670028`}, {-0.18750000000000017`, 
       1.6752404735808355`}, {-0.23025164253625505`, 1.5626550066464766`}}], 
      PolygonBox[{{-0.18750000000000017`, 
       1.6752404735808355`}, {-0.09705714191344557, 
       1.6377778151415994`}, {-0.23025164253625505`, 
       1.5626550066464766`}, {-0.18750000000000017`, 1.6752404735808355`}}], 
      PolygonBox[{{-0.08429258955606422, 
       1.5625000189670593`}, {-0.23025164253625505`, 
       1.5626550066464766`}, {-0.09705714191344557, 
       1.6377778151415994`}, {-0.08429258955606422, 1.5625000189670593`}}], 
      PolygonBox[{{-0.09705714191344557, 1.6377778151415994`}, {
       6.888638245203862*^-17, 1.625}, {-0.08429258955606422, 
       1.5625000189670593`}, {-0.09705714191344557, 1.6377778151415994`}}], 
      PolygonBox[{{0.0001348418310429853, 1.5625}, {-0.08429258955606422, 
       1.5625000189670593`}, {6.888638245203862*^-17, 1.625}, {
       0.0001348418310429853, 1.5625}}], 
      PolygonBox[{{6.888638245203862*^-17, 1.625}, {0.09705714191344511, 
       1.6377778151415994`}, {0.0001348418310429853, 1.5625}, {
       6.888638245203862*^-17, 1.625}}], 
      PolygonBox[{{0.08429258955605314, 1.5625000189670593`}, {
       0.0001348418310429853, 1.5625}, {0.09705714191344511, 
       1.6377778151415994`}, {0.08429258955605314, 1.5625000189670593`}}], 
      PolygonBox[{{0.09705714191344511, 1.6377778151415994`}, {
       0.18749999999999975`, 1.6752404735808355`}, {0.08429258955605314, 
       1.5625000189670593`}, {0.09705714191344511, 1.6377778151415994`}}], 
      PolygonBox[{{0.2302516425362547, 1.5626550066464766`}, {
       0.08429258955605314, 1.5625000189670593`}, {0.18749999999999975`, 
       1.6752404735808355`}, {0.2302516425362547, 1.5626550066464766`}}], 
      PolygonBox[{{0.18749999999999975`, 1.6752404735808355`}, {
       0.26516504294495524`, 1.7348349570550448`}, {0.2302516425362547, 
       1.5626550066464766`}, {0.18749999999999975`, 1.6752404735808355`}}], 
      PolygonBox[{{0.4049427443329971, 1.5950572556670028`}, {
       0.2302516425362547, 1.5626550066464766`}, {0.26516504294495524`, 
       1.7348349570550448`}, {0.4049427443329971, 1.5950572556670028`}}], 
      PolygonBox[{{0.26516504294495524`, 1.7348349570550448`}, {
       0.26516504294495535`, 1.7348349570550448`}, {0.4049427443329971, 
       1.5950572556670028`}, {0.26516504294495524`, 1.7348349570550448`}}], 
      PolygonBox[{{0.40494274433299715`, 1.5950572556670028`}, {
       0.4049427443329971, 1.5950572556670028`}, {0.26516504294495535`, 
       1.7348349570550448`}, {0.40494274433299715`, 1.5950572556670028`}}], 
      PolygonBox[{{0.40494274433299715`, 1.5950572556670028`}, {
       0.4373449933535234, 1.769748357463745}, {0.5, 1.5}, {
       0.40494274433299715`, 1.5950572556670028`}}], 
      PolygonBox[{{0.5, 1.6423372173506323`}, {0.5, 1.5}, {0.4373449933535234,
        1.769748357463745}, {0.5, 1.6423372173506323`}}], 
      PolygonBox[{{0.4373449933535234, 1.769748357463745}, {
       0.4374999810329408, 1.9157074104439382`}, {0.5, 1.6423372173506323`}, {
       0.4373449933535234, 1.769748357463745}}], 
      PolygonBox[{{0.5, 1.79409099469826}, {0.5, 1.6423372173506323`}, {
       0.4374999810329408, 1.9157074104439382`}, {0.5, 1.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, 1.9157074104439382`}, {0.4375, 2.}, {
       0.5, 1.79409099469826}, {0.4374999810329408, 1.9157074104439382`}}], 
      PolygonBox[{{0.5, 2.}, {0.5, 1.79409099469826}, {0.4375, 2.}, {0.5, 
       2.}}], PolygonBox[{{0.4375, 2.}, {0.4374999810329408, 
       2.084292589556062}, {0.5, 2.}, {0.4375, 2.}}], 
      PolygonBox[{{0.5, 2.20590900530174}, {0.5, 2.}, {0.4374999810329408, 
       2.084292589556062}, {0.5, 2.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, 2.084292589556062}, {
       0.4373449933535234, 2.230251642536255}, {0.5, 2.20590900530174}, {
       0.4374999810329408, 2.084292589556062}}], 
      PolygonBox[{{0.5, 2.3576627826493675`}, {0.5, 2.20590900530174}, {
       0.4373449933535234, 2.230251642536255}, {0.5, 2.3576627826493675`}}], 
      PolygonBox[{{0.4373449933535234, 2.230251642536255}, {
       0.4049427443329971, 2.404942744332997}, {0.5, 2.3576627826493675`}, {
       0.4373449933535234, 2.230251642536255}}], 
      PolygonBox[{{0.491446564961186, 2.491446564961186}, {0.5, 
       2.3576627826493675`}, {0.4049427443329971, 2.404942744332997}, {
       0.491446564961186, 2.491446564961186}}], 
      PolygonBox[{{0.4049427443329971, 2.404942744332997}, {
       0.23025164253625516`, 2.4373449933535234`}, {0.491446564961186, 
       2.491446564961186}, {0.4049427443329971, 2.404942744332997}}], 
      PolygonBox[{{0.35766278264936807`, 2.5}, {0.491446564961186, 
       2.491446564961186}, {0.23025164253625516`, 2.4373449933535234`}, {
       0.35766278264936807`, 2.5}}], 
      PolygonBox[{{0.23025164253625516`, 2.4373449933535234`}, {
       0.08429258955606053, 2.437499981032941}, {0.35766278264936807`, 2.5}, {
       0.23025164253625516`, 2.4373449933535234`}}], 
      PolygonBox[{{0.20590900537325585`, 2.5}, {0.35766278264936807`, 2.5}, {
       0.08429258955606053, 2.437499981032941}, {0.20590900537325585`, 2.5}}],
       PolygonBox[{{0.08429258955606053, 2.437499981032941}, {
       0.0001055272204876927, 2.4375}, {0.20590900537325585`, 2.5}, {
       0.08429258955606053, 2.437499981032941}}], 
      PolygonBox[{{0.07794195802689004, 2.5}, {0.20590900537325585`, 2.5}, {
       0.0001055272204876927, 2.4375}, {0.07794195802689004, 2.5}}], 
      PolygonBox[{{0.0001055272204876927, 2.4375}, {-0.08429258955605684, 
       2.437499981032941}, {0.07794195802689004, 2.5}, {0.0001055272204876927,
        2.4375}}], 
      PolygonBox[{{-0.20590900530444564`, 2.5}, {0.07794195802689004, 
       2.5}, {-0.08429258955605684, 
       2.437499981032941}, {-0.20590900530444564`, 2.5}}], 
      PolygonBox[{{-0.08429258955605684, 
       2.437499981032941}, {-0.23025164253625502`, 
       2.4373449933535234`}, {-0.20590900530444564`, 
       2.5}, {-0.08429258955605684, 2.437499981032941}}], 
      PolygonBox[{{-0.35766278264936624`, 2.5}, {-0.20590900530444564`, 
       2.5}, {-0.23025164253625502`, 
       2.4373449933535234`}, {-0.35766278264936624`, 2.5}}], 
      PolygonBox[{{-0.23025164253625502`, 
       2.4373449933535234`}, {-0.4049427443329971, 
       2.404942744332997}, {-0.35766278264936624`, 
       2.5}, {-0.23025164253625502`, 2.4373449933535234`}}], 
      PolygonBox[{{0.5, 2.5}, {-0.35766278264936624`, 
       2.5}, {-0.4049427443329971, 2.404942744332997}, {0.5, 2.5}}], 
      PolygonBox[{{-0.4049427443329971, 
       2.404942744332997}, {-0.4373449933535234, 2.2302516425362553`}, {0.5, 
       2.5}, {-0.4049427443329971, 2.404942744332997}}], 
      PolygonBox[{{-0.5, 2.357662782649369}, {0.5, 2.5}, {-0.4373449933535234,
        2.2302516425362553`}, {-0.5, 2.357662782649369}}], 
      PolygonBox[{{-0.4373449933535234, 
       2.2302516425362553`}, {-0.4374999810329408, 
       2.0842925895560622`}, {-0.5, 2.357662782649369}, {-0.4373449933535234, 
       2.2302516425362553`}}], 
      PolygonBox[{{-0.5, 2.205909005282899}, {-0.5, 
       2.357662782649369}, {-0.4374999810329408, 2.0842925895560622`}, {-0.5, 
       2.205909005282899}}], 
      PolygonBox[{{-0.4374999810329408, 2.0842925895560622`}, {-0.4375, 
       2.0001231780629953`}, {-0.5, 2.205909005282899}, {-0.4374999810329408, 
       2.0842925895560622`}}], 
      PolygonBox[{{-0.5, 2.0806786667587}, {-0.5, 
       2.205909005282899}, {-0.4375, 2.0001231780629953`}, {-0.5, 
       2.0806786667587}}], 
      PolygonBox[{{-0.4375, 2.0001231780629953`}, {-0.4374999810329408, 
       1.915707410443945}, {-0.5, 2.0806786667587}, {-0.4375, 
       2.0001231780629953`}}], 
      PolygonBox[{{-0.5, 1.7940909948547215`}, {-0.5, 
       2.0806786667587}, {-0.4374999810329408, 1.915707410443945}, {-0.5, 
       1.7940909948547215`}}], 
      PolygonBox[{{-0.4374999810329408, 
       1.915707410443945}, {-0.4373449933535234, 1.7697483574637451`}, {-0.5, 
       1.7940909948547215`}, {-0.4374999810329408, 1.915707410443945}}], 
      PolygonBox[{{-0.5, 1.6423372173506348`}, {-0.5, 
       1.7940909948547215`}, {-0.4373449933535234, 
       1.7697483574637451`}, {-0.5, 1.6423372173506348`}}], 
      PolygonBox[{{-0.4373449933535234, 
       1.7697483574637451`}, {-0.40494274433299715`, 
       1.5950572556670028`}, {-0.5, 
       1.6423372173506348`}, {-0.4373449933535234, 1.7697483574637451`}}], 
      PolygonBox[{{-0.5, 2.5}, {-0.5, 
       1.6423372173506348`}, {-0.40494274433299715`, 
       1.5950572556670028`}, {-0.5, 2.5}}], 
      PolygonBox[{{-0.40494274433299715`, 
       1.5950572556670028`}, {-0.23025164253625505`, 
       1.5626550066464766`}, {-0.5, 2.5}, {-0.40494274433299715`, 
       1.5950572556670028`}}], 
      PolygonBox[{{-0.5, 1.5}, {-0.5, 2.5}, {-0.23025164253625505`, 
       1.5626550066464766`}, {-0.5, 1.5}}], 
      PolygonBox[{{-0.23025164253625505`, 
       1.5626550066464766`}, {-0.08429258955606422, 
       1.5625000189670593`}, {-0.5, 1.5}, {-0.23025164253625505`, 
       1.5626550066464766`}}], 
      PolygonBox[{{-0.20590900556682806`, 1.5}, {-0.5, 
       1.5}, {-0.08429258955606422, 
       1.5625000189670593`}, {-0.20590900556682806`, 1.5}}], 
      PolygonBox[{{-0.08429258955606422, 1.5625000189670593`}, {
       0.0001348418310429853, 1.5625}, {-0.20590900556682806`, 
       1.5}, {-0.08429258955606422, 1.5625000189670593`}}], 
      PolygonBox[{{0.0823238704010616, 1.5}, {-0.20590900556682806`, 1.5}, {
       0.0001348418310429853, 1.5625}, {0.0823238704010616, 1.5}}], 
      PolygonBox[{{0.0001348418310429853, 1.5625}, {0.08429258955605314, 
       1.5625000189670593`}, {0.0823238704010616, 1.5}, {
       0.0001348418310429853, 1.5625}}], 
      PolygonBox[{{0.2059090053603974, 1.5}, {0.0823238704010616, 1.5}, {
       0.08429258955605314, 1.5625000189670593`}, {0.2059090053603974, 1.5}}],
       PolygonBox[{{0.08429258955605314, 1.5625000189670593`}, {
       0.2302516425362547, 1.5626550066464766`}, {0.2059090053603974, 1.5}, {
       0.08429258955605314, 1.5625000189670593`}}], 
      PolygonBox[{{0.35766278264937107`, 1.5}, {0.2059090053603974, 1.5}, {
       0.2302516425362547, 1.5626550066464766`}, {0.35766278264937107`, 
       1.5}}], PolygonBox[{{0.2302516425362547, 1.5626550066464766`}, {
       0.4049427443329971, 1.5950572556670028`}, {0.35766278264937107`, 
       1.5}, {0.2302516425362547, 1.5626550066464766`}}], 
      PolygonBox[{{0.5, 1.5}, {0.35766278264937107`, 1.5}, {
       0.4049427443329971, 1.5950572556670028`}, {0.5, 1.5}}], 
      PolygonBox[{{0.4049427443329971, 1.5950572556670028`}, {
       0.40494274433299715`, 1.5950572556670028`}, {0.5, 1.5}, {
       0.4049427443329971, 1.5950572556670028`}}], 
      PolygonBox[{{0.5, 1.5}, {0.5, 1.5}, {0.40494274433299715`, 
       1.5950572556670028`}, {0.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 3.}, {-0.4791666666666667, 3.}, {-0.4583333333333333, 
       3.}, {-0.4375, 3.}, {-0.4166666666666667, 3.}, {-0.39583333333333337`, 
       3.}, {-0.375, 3.}, {-0.375, 3.}, {-0.3958333333333333, 
       3.}, {-0.4166666666666667, 3.}, {-0.4375, 3.}, {-0.4583333333333333, 
       3.}, {-0.47916666666666663`, 3.}, {-0.5, 3.}, {-0.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, 3.}, {0.3958333333333333, 3.}, {0.4166666666666667, 
       3.}, {0.4375, 3.}, {0.4583333333333333, 3.}, {0.47916666666666663`, 
       3.}, {0.5, 3.}, {0.5, 3.}, {0.4791666666666667, 3.}, {
       0.4583333333333333, 3.}, {0.4375, 3.}, {0.4166666666666667, 3.}, {
       0.39583333333333337`, 3.}, {0.375, 3.}, {0.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 2.5}, {0., 2.5208333333333335`}, {0., 
       2.5416666666666665`}, {0., 2.5625}, {0., 2.5833333333333335`}, {0., 
       2.6041666666666665`}, {0., 2.625}, {0., 2.625}, {0., 
       2.6041666666666665`}, {0., 2.5833333333333335`}, {0., 2.5625}, {0., 
       2.5416666666666665`}, {0., 2.5208333333333335`}, {0., 2.5}, {0., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 3.375}, {0., 3.3958333333333335`}, {0., 
       3.4166666666666665`}, {0., 3.4375}, {0., 3.4583333333333335`}, {0., 
       3.4791666666666665`}, {0., 3.5}, {0., 3.5}, {0., 
       3.4791666666666665`}, {0., 3.4583333333333335`}, {0., 3.4375}, {0., 
       3.4166666666666665`}, {0., 3.3958333333333335`}, {0., 3.375}, {0., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, 3.}, {-0.25, 3.}, {-0.125, 3.}, {0., 3.}, {0.125, 
       3.}, {0.25, 3.}, {0.375, 3.}, {0.375, 3.}, {0.25, 3.}, {0.125, 3.}, {
       0., 3.}, {-0.125, 3.}, {-0.25, 3.}, {-0.375, 3.}, {-0.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 2.625}, {0., 2.75}, {0., 2.875}, {0., 3.}, {0., 3.125}, {
       0., 3.25}, {0., 3.375}, {0., 3.375}, {0., 3.25}, {0., 3.125}, {0., 
       3.}, {0., 2.875}, {0., 2.75}, {0., 2.625}, {0., 2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CE0h0NAf9nXpXrX7f2fCD09eozDocHSSe/O
iSsQ+QZOh1s598+U/bhgP/vt7Jt88lwOEDNO2Bu4n2iVnsnlcK8zZtGeGzvs
X11ct+/KUy4Hrq55PpaVVTYQ87kdrkLk98Pk//4HgeP7YfpvQszfDzO/HmL/
fpj9/hD37Ye5D+r+/Wju379J+q2UlSW7QyOKfjaHO1DzU4VS1D4+YHVgg7h/
/4Ud5lVP0lgd3kLdJ6YX6KgtxerQ8bzs56tbk/dAzGd1OAP1H0z+O8T99jD9
N6DhAzO/DiX82Bz8oOG7Eeo+9PAHABl5pfg=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CE0j0NYKAhcReMfhfMZUACPQwhEfj8q/+p+
VPUPCPJXrwIBLjgfbEwoJ5p6DjT1bHA+xJ2saOpZMPhhKO6D8Y+iqYcBFpj/
7FH5V+1R1T8gyA9FdZ89mvvt0fxnj+Z/+1Wo4QOPDwD0mFSQ
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, 2.7348349570550448`}, {
       0.3247595264191645, 2.8125}, {0.40494274433299715`, 
       2.595057255667003}, {0.26516504294495535`, 2.7348349570550448`}}], 
      PolygonBox[{{0.4373449933535234, 2.7697483574637447`}, {
       0.40494274433299715`, 2.595057255667003}, {0.3247595264191645, 
       2.8125}, {0.4373449933535234, 2.7697483574637447`}}], 
      PolygonBox[{{0.3247595264191645, 2.8125}, {0.36222218485840063`, 
       2.9029428580865546`}, {0.4373449933535234, 2.7697483574637447`}, {
       0.3247595264191645, 2.8125}}], 
      PolygonBox[{{0.4374999810329408, 2.915707410443938}, {
       0.4373449933535234, 2.7697483574637447`}, {0.36222218485840063`, 
       2.9029428580865546`}, {0.4374999810329408, 2.915707410443938}}], 
      PolygonBox[{{0.36222218485840063`, 2.9029428580865546`}, {0.375, 3.}, {
       0.4374999810329408, 2.915707410443938}, {0.36222218485840063`, 
       2.9029428580865546`}}], 
      PolygonBox[{{0.4375, 3.}, {0.4374999810329408, 2.915707410443938}, {
       0.375, 3.}, {0.4375, 3.}}], 
      PolygonBox[{{0.375, 3.}, {0.36222218485840063`, 3.0970571419134454`}, {
       0.4375, 3.}, {0.375, 3.}}], 
      PolygonBox[{{0.4374999810329408, 3.084292589556062}, {0.4375, 3.}, {
       0.36222218485840063`, 3.0970571419134454`}, {0.4374999810329408, 
       3.084292589556062}}], 
      PolygonBox[{{0.36222218485840063`, 3.0970571419134454`}, {
       0.3247595264191645, 3.1875}, {0.4374999810329408, 3.084292589556062}, {
       0.36222218485840063`, 3.0970571419134454`}}], 
      PolygonBox[{{0.4373449933535234, 3.230251642536255}, {
       0.4374999810329408, 3.084292589556062}, {0.3247595264191645, 3.1875}, {
       0.4373449933535234, 3.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, 3.1875}, {0.26516504294495535`, 
       3.2651650429449552`}, {0.4373449933535234, 3.230251642536255}, {
       0.3247595264191645, 3.1875}}], 
      PolygonBox[{{0.4049427443329971, 3.404942744332997}, {
       0.4373449933535234, 3.230251642536255}, {0.26516504294495535`, 
       3.2651650429449552`}, {0.4049427443329971, 3.404942744332997}}], 
      PolygonBox[{{0.26516504294495535`, 3.2651650429449552`}, {
       0.18750000000000006`, 3.3247595264191645`}, {0.4049427443329971, 
       3.404942744332997}, {0.26516504294495535`, 3.2651650429449552`}}], 
      PolygonBox[{{0.23025164253625516`, 3.4373449933535234`}, {
       0.4049427443329971, 3.404942744332997}, {0.18750000000000006`, 
       3.3247595264191645`}, {0.23025164253625516`, 3.4373449933535234`}}], 
      PolygonBox[{{0.18750000000000006`, 3.3247595264191645`}, {
       0.09705714191344536, 3.3622221848584006`}, {0.23025164253625516`, 
       3.4373449933535234`}, {0.18750000000000006`, 3.3247595264191645`}}], 
      PolygonBox[{{0.08429258955606053, 3.437499981032941}, {
       0.23025164253625516`, 3.4373449933535234`}, {0.09705714191344536, 
       3.3622221848584006`}, {0.08429258955606053, 3.437499981032941}}], 
      PolygonBox[{{0.09705714191344536, 3.3622221848584006`}, {
       2.296212748401287*^-17, 3.375}, {0.08429258955606053, 
       3.437499981032941}, {0.09705714191344536, 3.3622221848584006`}}], 
      PolygonBox[{{0.0001055272204876927, 3.4375}, {0.08429258955606053, 
       3.437499981032941}, {2.296212748401287*^-17, 3.375}, {
       0.0001055272204876927, 3.4375}}], 
      PolygonBox[{{2.296212748401287*^-17, 3.375}, {-0.09705714191344515, 
       3.3622221848584006`}, {0.0001055272204876927, 3.4375}, {
       2.296212748401287*^-17, 3.375}}], 
      PolygonBox[{{-0.08429258955605684, 3.437499981032941}, {
       0.0001055272204876927, 3.4375}, {-0.09705714191344515, 
       3.3622221848584006`}, {-0.08429258955605684, 3.437499981032941}}], 
      PolygonBox[{{-0.09705714191344515, 
       3.3622221848584006`}, {-0.18749999999999992`, 
       3.3247595264191645`}, {-0.08429258955605684, 
       3.437499981032941}, {-0.09705714191344515, 3.3622221848584006`}}], 
      PolygonBox[{{-0.23025164253625502`, 
       3.4373449933535234`}, {-0.08429258955605684, 
       3.437499981032941}, {-0.18749999999999992`, 
       3.3247595264191645`}, {-0.23025164253625502`, 3.4373449933535234`}}], 
      PolygonBox[{{-0.18749999999999992`, 
       3.3247595264191645`}, {-0.2651650429449553, 
       3.2651650429449552`}, {-0.23025164253625502`, 
       3.4373449933535234`}, {-0.18749999999999992`, 3.3247595264191645`}}], 
      PolygonBox[{{-0.4049427443329971, 
       3.404942744332997}, {-0.23025164253625502`, 
       3.4373449933535234`}, {-0.2651650429449553, 
       3.2651650429449552`}, {-0.4049427443329971, 3.404942744332997}}], 
      PolygonBox[{{-0.2651650429449553, 
       3.2651650429449552`}, {-0.32475952641916445`, 
       3.1875}, {-0.4049427443329971, 
       3.404942744332997}, {-0.2651650429449553, 3.2651650429449552`}}], 
      PolygonBox[{{-0.4373449933535234, 
       3.2302516425362553`}, {-0.4049427443329971, 
       3.404942744332997}, {-0.32475952641916445`, 
       3.1875}, {-0.4373449933535234, 3.2302516425362553`}}], 
      PolygonBox[{{-0.32475952641916445`, 3.1875}, {-0.3622221848584006, 
       3.0970571419134454`}, {-0.4373449933535234, 
       3.2302516425362553`}, {-0.32475952641916445`, 3.1875}}], 
      PolygonBox[{{-0.4374999810329408, 
       3.0842925895560622`}, {-0.4373449933535234, 
       3.2302516425362553`}, {-0.3622221848584006, 
       3.0970571419134454`}, {-0.4374999810329408, 3.0842925895560622`}}], 
      PolygonBox[{{-0.3622221848584006, 3.0970571419134454`}, {-0.375, 
       3.}, {-0.4374999810329408, 3.0842925895560622`}, {-0.3622221848584006, 
       3.0970571419134454`}}], 
      PolygonBox[{{-0.4375, 3.0001231780629953`}, {-0.4374999810329408, 
       3.0842925895560622`}, {-0.375, 3.}, {-0.4375, 3.0001231780629953`}}], 
      PolygonBox[{{-0.375, 3.}, {-0.36222218485840063`, 
       2.902942858086555}, {-0.4375, 3.0001231780629953`}, {-0.375, 3.}}], 
      PolygonBox[{{-0.4374999810329408, 2.915707410443945}, {-0.4375, 
       3.0001231780629953`}, {-0.36222218485840063`, 
       2.902942858086555}, {-0.4374999810329408, 2.915707410443945}}], 
      PolygonBox[{{-0.36222218485840063`, 
       2.902942858086555}, {-0.3247595264191646, 
       2.8125}, {-0.4374999810329408, 
       2.915707410443945}, {-0.36222218485840063`, 2.902942858086555}}], 
      PolygonBox[{{-0.4373449933535234, 
       2.769748357463745}, {-0.4374999810329408, 
       2.915707410443945}, {-0.3247595264191646, 
       2.8125}, {-0.4373449933535234, 2.769748357463745}}], 
      PolygonBox[{{-0.3247595264191646, 2.8125}, {-0.26516504294495535`, 
       2.7348349570550448`}, {-0.4373449933535234, 
       2.769748357463745}, {-0.3247595264191646, 2.8125}}], 
      PolygonBox[{{-0.40494274433299715`, 
       2.595057255667003}, {-0.4373449933535234, 
       2.769748357463745}, {-0.26516504294495535`, 
       2.7348349570550448`}, {-0.40494274433299715`, 2.595057255667003}}], 
      PolygonBox[{{-0.26516504294495535`, 
       2.7348349570550448`}, {-0.18750000000000017`, 
       2.6752404735808355`}, {-0.40494274433299715`, 
       2.595057255667003}, {-0.26516504294495535`, 2.7348349570550448`}}], 
      PolygonBox[{{-0.23025164253625505`, 
       2.5626550066464766`}, {-0.40494274433299715`, 
       2.595057255667003}, {-0.18750000000000017`, 
       2.6752404735808355`}, {-0.23025164253625505`, 2.5626550066464766`}}], 
      PolygonBox[{{-0.18750000000000017`, 
       2.6752404735808355`}, {-0.09705714191344557, 
       2.6377778151415994`}, {-0.23025164253625505`, 
       2.5626550066464766`}, {-0.18750000000000017`, 2.6752404735808355`}}], 
      PolygonBox[{{-0.08429258955606422, 
       2.562500018967059}, {-0.23025164253625505`, 
       2.5626550066464766`}, {-0.09705714191344557, 
       2.6377778151415994`}, {-0.08429258955606422, 2.562500018967059}}], 
      PolygonBox[{{-0.09705714191344557, 2.6377778151415994`}, {
       6.888638245203862*^-17, 2.625}, {-0.08429258955606422, 
       2.562500018967059}, {-0.09705714191344557, 2.6377778151415994`}}], 
      PolygonBox[{{0.0001348418310429853, 2.5625}, {-0.08429258955606422, 
       2.562500018967059}, {6.888638245203862*^-17, 2.625}, {
       0.0001348418310429853, 2.5625}}], 
      PolygonBox[{{6.888638245203862*^-17, 2.625}, {0.09705714191344511, 
       2.6377778151415994`}, {0.0001348418310429853, 2.5625}, {
       6.888638245203862*^-17, 2.625}}], 
      PolygonBox[{{0.08429258955605314, 2.562500018967059}, {
       0.0001348418310429853, 2.5625}, {0.09705714191344511, 
       2.6377778151415994`}, {0.08429258955605314, 2.562500018967059}}], 
      PolygonBox[{{0.09705714191344511, 2.6377778151415994`}, {
       0.18749999999999975`, 2.6752404735808355`}, {0.08429258955605314, 
       2.562500018967059}, {0.09705714191344511, 2.6377778151415994`}}], 
      PolygonBox[{{0.2302516425362547, 2.5626550066464766`}, {
       0.08429258955605314, 2.562500018967059}, {0.18749999999999975`, 
       2.6752404735808355`}, {0.2302516425362547, 2.5626550066464766`}}], 
      PolygonBox[{{0.18749999999999975`, 2.6752404735808355`}, {
       0.26516504294495524`, 2.7348349570550448`}, {0.2302516425362547, 
       2.5626550066464766`}, {0.18749999999999975`, 2.6752404735808355`}}], 
      PolygonBox[{{0.4049427443329971, 2.595057255667003}, {
       0.2302516425362547, 2.5626550066464766`}, {0.26516504294495524`, 
       2.7348349570550448`}, {0.4049427443329971, 2.595057255667003}}], 
      PolygonBox[{{0.26516504294495524`, 2.7348349570550448`}, {
       0.26516504294495535`, 2.7348349570550448`}, {0.4049427443329971, 
       2.595057255667003}, {0.26516504294495524`, 2.7348349570550448`}}], 
      PolygonBox[{{0.40494274433299715`, 2.595057255667003}, {
       0.4049427443329971, 2.595057255667003}, {0.26516504294495535`, 
       2.7348349570550448`}, {0.40494274433299715`, 2.595057255667003}}], 
      PolygonBox[{{0.40494274433299715`, 2.595057255667003}, {
       0.4373449933535234, 2.7697483574637447`}, {0.5, 2.5}, {
       0.40494274433299715`, 2.595057255667003}}], 
      PolygonBox[{{0.5, 2.642337217350632}, {0.5, 2.5}, {0.4373449933535234, 
       2.7697483574637447`}, {0.5, 2.642337217350632}}], 
      PolygonBox[{{0.4373449933535234, 2.7697483574637447`}, {
       0.4374999810329408, 2.915707410443938}, {0.5, 2.642337217350632}, {
       0.4373449933535234, 2.7697483574637447`}}], 
      PolygonBox[{{0.5, 2.79409099469826}, {0.5, 2.642337217350632}, {
       0.4374999810329408, 2.915707410443938}, {0.5, 2.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, 2.915707410443938}, {0.4375, 3.}, {0.5,
        2.79409099469826}, {0.4374999810329408, 2.915707410443938}}], 
      PolygonBox[{{0.5, 3.}, {0.5, 2.79409099469826}, {0.4375, 3.}, {0.5, 
       3.}}], PolygonBox[{{0.4375, 3.}, {0.4374999810329408, 
       3.084292589556062}, {0.5, 3.}, {0.4375, 3.}}], 
      PolygonBox[{{0.5, 3.20590900530174}, {0.5, 3.}, {0.4374999810329408, 
       3.084292589556062}, {0.5, 3.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, 3.084292589556062}, {
       0.4373449933535234, 3.230251642536255}, {0.5, 3.20590900530174}, {
       0.4374999810329408, 3.084292589556062}}], 
      PolygonBox[{{0.5, 3.3576627826493675`}, {0.5, 3.20590900530174}, {
       0.4373449933535234, 3.230251642536255}, {0.5, 3.3576627826493675`}}], 
      PolygonBox[{{0.4373449933535234, 3.230251642536255}, {
       0.4049427443329971, 3.404942744332997}, {0.5, 3.3576627826493675`}, {
       0.4373449933535234, 3.230251642536255}}], 
      PolygonBox[{{0.491446564961186, 3.491446564961186}, {0.5, 
       3.3576627826493675`}, {0.4049427443329971, 3.404942744332997}, {
       0.491446564961186, 3.491446564961186}}], 
      PolygonBox[{{0.4049427443329971, 3.404942744332997}, {
       0.23025164253625516`, 3.4373449933535234`}, {0.491446564961186, 
       3.491446564961186}, {0.4049427443329971, 3.404942744332997}}], 
      PolygonBox[{{0.35766278264936807`, 3.5}, {0.491446564961186, 
       3.491446564961186}, {0.23025164253625516`, 3.4373449933535234`}, {
       0.35766278264936807`, 3.5}}], 
      PolygonBox[{{0.23025164253625516`, 3.4373449933535234`}, {
       0.08429258955606053, 3.437499981032941}, {0.35766278264936807`, 3.5}, {
       0.23025164253625516`, 3.4373449933535234`}}], 
      PolygonBox[{{0.20590900537325585`, 3.5}, {0.35766278264936807`, 3.5}, {
       0.08429258955606053, 3.437499981032941}, {0.20590900537325585`, 3.5}}],
       PolygonBox[{{0.08429258955606053, 3.437499981032941}, {
       0.0001055272204876927, 3.4375}, {0.20590900537325585`, 3.5}, {
       0.08429258955606053, 3.437499981032941}}], 
      PolygonBox[{{0.07794195802689004, 3.5}, {0.20590900537325585`, 3.5}, {
       0.0001055272204876927, 3.4375}, {0.07794195802689004, 3.5}}], 
      PolygonBox[{{0.0001055272204876927, 3.4375}, {-0.08429258955605684, 
       3.437499981032941}, {0.07794195802689004, 3.5}, {0.0001055272204876927,
        3.4375}}], 
      PolygonBox[{{-0.20590900530444564`, 3.5}, {0.07794195802689004, 
       3.5}, {-0.08429258955605684, 
       3.437499981032941}, {-0.20590900530444564`, 3.5}}], 
      PolygonBox[{{-0.08429258955605684, 
       3.437499981032941}, {-0.23025164253625502`, 
       3.4373449933535234`}, {-0.20590900530444564`, 
       3.5}, {-0.08429258955605684, 3.437499981032941}}], 
      PolygonBox[{{-0.35766278264936624`, 3.5}, {-0.20590900530444564`, 
       3.5}, {-0.23025164253625502`, 
       3.4373449933535234`}, {-0.35766278264936624`, 3.5}}], 
      PolygonBox[{{-0.23025164253625502`, 
       3.4373449933535234`}, {-0.4049427443329971, 
       3.404942744332997}, {-0.35766278264936624`, 
       3.5}, {-0.23025164253625502`, 3.4373449933535234`}}], 
      PolygonBox[{{0.5, 3.5}, {-0.35766278264936624`, 
       3.5}, {-0.4049427443329971, 3.404942744332997}, {0.5, 3.5}}], 
      PolygonBox[{{-0.4049427443329971, 
       3.404942744332997}, {-0.4373449933535234, 3.2302516425362553`}, {0.5, 
       3.5}, {-0.4049427443329971, 3.404942744332997}}], 
      PolygonBox[{{-0.5, 3.357662782649369}, {0.5, 3.5}, {-0.4373449933535234,
        3.2302516425362553`}, {-0.5, 3.357662782649369}}], 
      PolygonBox[{{-0.4373449933535234, 
       3.2302516425362553`}, {-0.4374999810329408, 
       3.0842925895560622`}, {-0.5, 3.357662782649369}, {-0.4373449933535234, 
       3.2302516425362553`}}], 
      PolygonBox[{{-0.5, 3.205909005282899}, {-0.5, 
       3.357662782649369}, {-0.4374999810329408, 3.0842925895560622`}, {-0.5, 
       3.205909005282899}}], 
      PolygonBox[{{-0.4374999810329408, 3.0842925895560622`}, {-0.4375, 
       3.0001231780629953`}, {-0.5, 3.205909005282899}, {-0.4374999810329408, 
       3.0842925895560622`}}], 
      PolygonBox[{{-0.5, 3.0806786667587}, {-0.5, 
       3.205909005282899}, {-0.4375, 3.0001231780629953`}, {-0.5, 
       3.0806786667587}}], 
      PolygonBox[{{-0.4375, 3.0001231780629953`}, {-0.4374999810329408, 
       2.915707410443945}, {-0.5, 3.0806786667587}, {-0.4375, 
       3.0001231780629953`}}], 
      PolygonBox[{{-0.5, 2.7940909948547215`}, {-0.5, 
       3.0806786667587}, {-0.4374999810329408, 2.915707410443945}, {-0.5, 
       2.7940909948547215`}}], 
      PolygonBox[{{-0.4374999810329408, 
       2.915707410443945}, {-0.4373449933535234, 2.769748357463745}, {-0.5, 
       2.7940909948547215`}, {-0.4374999810329408, 2.915707410443945}}], 
      PolygonBox[{{-0.5, 2.6423372173506348`}, {-0.5, 
       2.7940909948547215`}, {-0.4373449933535234, 2.769748357463745}, {-0.5, 
       2.6423372173506348`}}], 
      PolygonBox[{{-0.4373449933535234, 
       2.769748357463745}, {-0.40494274433299715`, 2.595057255667003}, {-0.5, 
       2.6423372173506348`}, {-0.4373449933535234, 2.769748357463745}}], 
      PolygonBox[{{-0.5, 3.5}, {-0.5, 
       2.6423372173506348`}, {-0.40494274433299715`, 
       2.595057255667003}, {-0.5, 3.5}}], 
      PolygonBox[{{-0.40494274433299715`, 
       2.595057255667003}, {-0.23025164253625505`, 
       2.5626550066464766`}, {-0.5, 3.5}, {-0.40494274433299715`, 
       2.595057255667003}}], 
      PolygonBox[{{-0.5, 2.5}, {-0.5, 3.5}, {-0.23025164253625505`, 
       2.5626550066464766`}, {-0.5, 2.5}}], 
      PolygonBox[{{-0.23025164253625505`, 
       2.5626550066464766`}, {-0.08429258955606422, 2.562500018967059}, {-0.5,
        2.5}, {-0.23025164253625505`, 2.5626550066464766`}}], 
      PolygonBox[{{-0.20590900556682806`, 2.5}, {-0.5, 
       2.5}, {-0.08429258955606422, 
       2.562500018967059}, {-0.20590900556682806`, 2.5}}], 
      PolygonBox[{{-0.08429258955606422, 2.562500018967059}, {
       0.0001348418310429853, 2.5625}, {-0.20590900556682806`, 
       2.5}, {-0.08429258955606422, 2.562500018967059}}], 
      PolygonBox[{{0.0823238704010616, 2.5}, {-0.20590900556682806`, 2.5}, {
       0.0001348418310429853, 2.5625}, {0.0823238704010616, 2.5}}], 
      PolygonBox[{{0.0001348418310429853, 2.5625}, {0.08429258955605314, 
       2.562500018967059}, {0.0823238704010616, 2.5}, {0.0001348418310429853, 
       2.5625}}], 
      PolygonBox[{{0.2059090053603974, 2.5}, {0.0823238704010616, 2.5}, {
       0.08429258955605314, 2.562500018967059}, {0.2059090053603974, 2.5}}], 
      PolygonBox[{{0.08429258955605314, 2.562500018967059}, {
       0.2302516425362547, 2.5626550066464766`}, {0.2059090053603974, 2.5}, {
       0.08429258955605314, 2.562500018967059}}], 
      PolygonBox[{{0.35766278264937107`, 2.5}, {0.2059090053603974, 2.5}, {
       0.2302516425362547, 2.5626550066464766`}, {0.35766278264937107`, 
       2.5}}], 
      PolygonBox[{{0.2302516425362547, 2.5626550066464766`}, {
       0.4049427443329971, 2.595057255667003}, {0.35766278264937107`, 2.5}, {
       0.2302516425362547, 2.5626550066464766`}}], 
      PolygonBox[{{0.5, 2.5}, {0.35766278264937107`, 2.5}, {
       0.4049427443329971, 2.595057255667003}, {0.5, 2.5}}], 
      PolygonBox[{{0.4049427443329971, 2.595057255667003}, {
       0.40494274433299715`, 2.595057255667003}, {0.5, 2.5}, {
       0.4049427443329971, 2.595057255667003}}], 
      PolygonBox[{{0.5, 2.5}, {0.5, 2.5}, {0.40494274433299715`, 
       2.595057255667003}, {0.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 4.}, {-0.4791666666666667, 4.}, {-0.4583333333333333, 
       4.}, {-0.4375, 4.}, {-0.4166666666666667, 4.}, {-0.39583333333333337`, 
       4.}, {-0.375, 4.}, {-0.375, 4.}, {-0.3958333333333333, 
       4.}, {-0.4166666666666667, 4.}, {-0.4375, 4.}, {-0.4583333333333333, 
       4.}, {-0.47916666666666663`, 4.}, {-0.5, 4.}, {-0.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, 4.}, {0.3958333333333333, 4.}, {0.4166666666666667, 
       4.}, {0.4375, 4.}, {0.4583333333333333, 4.}, {0.47916666666666663`, 
       4.}, {0.5, 4.}, {0.5, 4.}, {0.4791666666666667, 4.}, {
       0.4583333333333333, 4.}, {0.4375, 4.}, {0.4166666666666667, 4.}, {
       0.39583333333333337`, 4.}, {0.375, 4.}, {0.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 3.5}, {0., 3.5208333333333335`}, {0., 
       3.5416666666666665`}, {0., 3.5625}, {0., 3.5833333333333335`}, {0., 
       3.6041666666666665`}, {0., 3.625}, {0., 3.625}, {0., 
       3.6041666666666665`}, {0., 3.5833333333333335`}, {0., 3.5625}, {0., 
       3.5416666666666665`}, {0., 3.5208333333333335`}, {0., 3.5}, {0., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 4.375}, {0., 4.395833333333333}, {0., 
       4.416666666666667}, {0., 4.4375}, {0., 4.458333333333333}, {0., 
       4.479166666666667}, {0., 4.5}, {0., 4.5}, {0., 4.479166666666667}, {0.,
        4.458333333333333}, {0., 4.4375}, {0., 4.416666666666667}, {0., 
       4.395833333333333}, {0., 4.375}, {0., 4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, 4.}, {-0.25, 4.}, {-0.125, 4.}, {0., 4.}, {0.125, 
       4.}, {0.25, 4.}, {0.375, 4.}, {0.375, 4.}, {0.25, 4.}, {0.125, 4.}, {
       0., 4.}, {-0.125, 4.}, {-0.25, 4.}, {-0.375, 4.}, {-0.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 3.625}, {0., 3.75}, {0., 3.875}, {0., 4.}, {0., 4.125}, {
       0., 4.25}, {0., 4.375}, {0., 4.375}, {0., 4.25}, {0., 4.125}, {0., 
       4.}, {0., 3.875}, {0., 3.75}, {0., 3.625}, {0., 3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CG0gENAf9nXpXrX7dWLOj8lJQs4NFg66d05
cQUif0DA4VbO/TNlPy7Yn/t2NqedX9ABYsYJ+xnKTw71+gg63OuMWbTnxg77
rxnh8a+KBB24uub5WFZW2YCVNQg6XIXI74fJ//0PAsf3w/TfhJi/H2Z+PcT+
/TD7/SHu268BdR/U/fvR3L9/k/RbKStLfodGZP0NfA53oOanCqWofXzA68AG
cf/+CzvMq56k8Tq8hbpPTC/QUVuK16HjednPV7cm74GYz+twBuo/mPx3iPvt
YfpvQMMHZn4dcvgB7feDhu9GqPvQwx8AN3yldQ==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CG0kENYKAhcReMfhfMZUICQQwhEfj8q/+p+
VPUPCPLB2kIF4fzVq0BAAE29AJo8H5wPcScvmnoeDH4Yivtg/KNo6mGAB+Y/
e1T+VXtU9Q8I8kNR3WeP5n57NP/Zo/nfHi184PEBAJlTVVs=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, 3.7348349570550448`}, {
       0.3247595264191645, 3.8125}, {0.40494274433299715`, 
       3.595057255667003}, {0.26516504294495535`, 3.7348349570550448`}}], 
      PolygonBox[{{0.4373449933535234, 3.7697483574637447`}, {
       0.40494274433299715`, 3.595057255667003}, {0.3247595264191645, 
       3.8125}, {0.4373449933535234, 3.7697483574637447`}}], 
      PolygonBox[{{0.3247595264191645, 3.8125}, {0.36222218485840063`, 
       3.9029428580865546`}, {0.4373449933535234, 3.7697483574637447`}, {
       0.3247595264191645, 3.8125}}], 
      PolygonBox[{{0.4374999810329408, 3.915707410443938}, {
       0.4373449933535234, 3.7697483574637447`}, {0.36222218485840063`, 
       3.9029428580865546`}, {0.4374999810329408, 3.915707410443938}}], 
      PolygonBox[{{0.36222218485840063`, 3.9029428580865546`}, {0.375, 4.}, {
       0.4374999810329408, 3.915707410443938}, {0.36222218485840063`, 
       3.9029428580865546`}}], 
      PolygonBox[{{0.4375, 4.}, {0.4374999810329408, 3.915707410443938}, {
       0.375, 4.}, {0.4375, 4.}}], 
      PolygonBox[{{0.375, 4.}, {0.36222218485840063`, 4.097057141913445}, {
       0.4375, 4.}, {0.375, 4.}}], 
      PolygonBox[{{0.4374999810329408, 4.084292589556061}, {0.4375, 4.}, {
       0.36222218485840063`, 4.097057141913445}, {0.4374999810329408, 
       4.084292589556061}}], 
      PolygonBox[{{0.36222218485840063`, 4.097057141913445}, {
       0.3247595264191645, 4.1875}, {0.4374999810329408, 4.084292589556061}, {
       0.36222218485840063`, 4.097057141913445}}], 
      PolygonBox[{{0.4373449933535234, 4.230251642536255}, {
       0.4374999810329408, 4.084292589556061}, {0.3247595264191645, 4.1875}, {
       0.4373449933535234, 4.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, 4.1875}, {0.26516504294495535`, 
       4.265165042944956}, {0.4373449933535234, 4.230251642536255}, {
       0.3247595264191645, 4.1875}}], 
      PolygonBox[{{0.4049427443329971, 4.404942744332997}, {
       0.4373449933535234, 4.230251642536255}, {0.26516504294495535`, 
       4.265165042944956}, {0.4049427443329971, 4.404942744332997}}], 
      PolygonBox[{{0.26516504294495535`, 4.265165042944956}, {
       0.18750000000000006`, 4.3247595264191645`}, {0.4049427443329971, 
       4.404942744332997}, {0.26516504294495535`, 4.265165042944956}}], 
      PolygonBox[{{0.23025164253625516`, 4.437344993353523}, {
       0.4049427443329971, 4.404942744332997}, {0.18750000000000006`, 
       4.3247595264191645`}, {0.23025164253625516`, 4.437344993353523}}], 
      PolygonBox[{{0.18750000000000006`, 4.3247595264191645`}, {
       0.09705714191344536, 4.362222184858401}, {0.23025164253625516`, 
       4.437344993353523}, {0.18750000000000006`, 4.3247595264191645`}}], 
      PolygonBox[{{0.08429258955606053, 4.437499981032941}, {
       0.23025164253625516`, 4.437344993353523}, {0.09705714191344536, 
       4.362222184858401}, {0.08429258955606053, 4.437499981032941}}], 
      PolygonBox[{{0.09705714191344536, 4.362222184858401}, {
       2.296212748401287*^-17, 4.375}, {0.08429258955606053, 
       4.437499981032941}, {0.09705714191344536, 4.362222184858401}}], 
      PolygonBox[{{0.0001055272204876927, 4.4375}, {0.08429258955606053, 
       4.437499981032941}, {2.296212748401287*^-17, 4.375}, {
       0.0001055272204876927, 4.4375}}], 
      PolygonBox[{{2.296212748401287*^-17, 4.375}, {-0.09705714191344515, 
       4.362222184858401}, {0.0001055272204876927, 4.4375}, {
       2.296212748401287*^-17, 4.375}}], 
      PolygonBox[{{-0.08429258955605684, 4.437499981032941}, {
       0.0001055272204876927, 4.4375}, {-0.09705714191344515, 
       4.362222184858401}, {-0.08429258955605684, 4.437499981032941}}], 
      PolygonBox[{{-0.09705714191344515, 
       4.362222184858401}, {-0.18749999999999992`, 
       4.3247595264191645`}, {-0.08429258955605684, 
       4.437499981032941}, {-0.09705714191344515, 4.362222184858401}}], 
      PolygonBox[{{-0.23025164253625502`, 
       4.437344993353523}, {-0.08429258955605684, 
       4.437499981032941}, {-0.18749999999999992`, 
       4.3247595264191645`}, {-0.23025164253625502`, 4.437344993353523}}], 
      PolygonBox[{{-0.18749999999999992`, 
       4.3247595264191645`}, {-0.2651650429449553, 
       4.265165042944956}, {-0.23025164253625502`, 
       4.437344993353523}, {-0.18749999999999992`, 4.3247595264191645`}}], 
      PolygonBox[{{-0.4049427443329971, 
       4.404942744332997}, {-0.23025164253625502`, 
       4.437344993353523}, {-0.2651650429449553, 
       4.265165042944956}, {-0.4049427443329971, 4.404942744332997}}], 
      PolygonBox[{{-0.2651650429449553, 
       4.265165042944956}, {-0.32475952641916445`, 
       4.1875}, {-0.4049427443329971, 
       4.404942744332997}, {-0.2651650429449553, 4.265165042944956}}], 
      PolygonBox[{{-0.4373449933535234, 
       4.230251642536255}, {-0.4049427443329971, 
       4.404942744332997}, {-0.32475952641916445`, 
       4.1875}, {-0.4373449933535234, 4.230251642536255}}], 
      PolygonBox[{{-0.32475952641916445`, 4.1875}, {-0.3622221848584006, 
       4.097057141913446}, {-0.4373449933535234, 
       4.230251642536255}, {-0.32475952641916445`, 4.1875}}], 
      PolygonBox[{{-0.4374999810329408, 
       4.084292589556062}, {-0.4373449933535234, 
       4.230251642536255}, {-0.3622221848584006, 
       4.097057141913446}, {-0.4374999810329408, 4.084292589556062}}], 
      PolygonBox[{{-0.3622221848584006, 4.097057141913446}, {-0.375, 
       4.}, {-0.4374999810329408, 4.084292589556062}, {-0.3622221848584006, 
       4.097057141913446}}], 
      PolygonBox[{{-0.4375, 4.000123178062996}, {-0.4374999810329408, 
       4.084292589556062}, {-0.375, 4.}, {-0.4375, 4.000123178062996}}], 
      PolygonBox[{{-0.375, 4.}, {-0.36222218485840063`, 
       3.902942858086555}, {-0.4375, 4.000123178062996}, {-0.375, 4.}}], 
      PolygonBox[{{-0.4374999810329408, 3.915707410443945}, {-0.4375, 
       4.000123178062996}, {-0.36222218485840063`, 
       3.902942858086555}, {-0.4374999810329408, 3.915707410443945}}], 
      PolygonBox[{{-0.36222218485840063`, 
       3.902942858086555}, {-0.3247595264191646, 
       3.8125}, {-0.4374999810329408, 
       3.915707410443945}, {-0.36222218485840063`, 3.902942858086555}}], 
      PolygonBox[{{-0.4373449933535234, 
       3.769748357463745}, {-0.4374999810329408, 
       3.915707410443945}, {-0.3247595264191646, 
       3.8125}, {-0.4373449933535234, 3.769748357463745}}], 
      PolygonBox[{{-0.3247595264191646, 3.8125}, {-0.26516504294495535`, 
       3.7348349570550448`}, {-0.4373449933535234, 
       3.769748357463745}, {-0.3247595264191646, 3.8125}}], 
      PolygonBox[{{-0.40494274433299715`, 
       3.595057255667003}, {-0.4373449933535234, 
       3.769748357463745}, {-0.26516504294495535`, 
       3.7348349570550448`}, {-0.40494274433299715`, 3.595057255667003}}], 
      PolygonBox[{{-0.26516504294495535`, 
       3.7348349570550448`}, {-0.18750000000000017`, 
       3.6752404735808355`}, {-0.40494274433299715`, 
       3.595057255667003}, {-0.26516504294495535`, 3.7348349570550448`}}], 
      PolygonBox[{{-0.23025164253625505`, 
       3.5626550066464766`}, {-0.40494274433299715`, 
       3.595057255667003}, {-0.18750000000000017`, 
       3.6752404735808355`}, {-0.23025164253625505`, 3.5626550066464766`}}], 
      PolygonBox[{{-0.18750000000000017`, 
       3.6752404735808355`}, {-0.09705714191344557, 
       3.6377778151415994`}, {-0.23025164253625505`, 
       3.5626550066464766`}, {-0.18750000000000017`, 3.6752404735808355`}}], 
      PolygonBox[{{-0.08429258955606422, 
       3.562500018967059}, {-0.23025164253625505`, 
       3.5626550066464766`}, {-0.09705714191344557, 
       3.6377778151415994`}, {-0.08429258955606422, 3.562500018967059}}], 
      PolygonBox[{{-0.09705714191344557, 3.6377778151415994`}, {
       6.888638245203862*^-17, 3.625}, {-0.08429258955606422, 
       3.562500018967059}, {-0.09705714191344557, 3.6377778151415994`}}], 
      PolygonBox[{{0.0001348418310429853, 3.5625}, {-0.08429258955606422, 
       3.562500018967059}, {6.888638245203862*^-17, 3.625}, {
       0.0001348418310429853, 3.5625}}], 
      PolygonBox[{{6.888638245203862*^-17, 3.625}, {0.09705714191344511, 
       3.6377778151415994`}, {0.0001348418310429853, 3.5625}, {
       6.888638245203862*^-17, 3.625}}], 
      PolygonBox[{{0.08429258955605314, 3.562500018967059}, {
       0.0001348418310429853, 3.5625}, {0.09705714191344511, 
       3.6377778151415994`}, {0.08429258955605314, 3.562500018967059}}], 
      PolygonBox[{{0.09705714191344511, 3.6377778151415994`}, {
       0.18749999999999975`, 3.6752404735808355`}, {0.08429258955605314, 
       3.562500018967059}, {0.09705714191344511, 3.6377778151415994`}}], 
      PolygonBox[{{0.2302516425362547, 3.5626550066464766`}, {
       0.08429258955605314, 3.562500018967059}, {0.18749999999999975`, 
       3.6752404735808355`}, {0.2302516425362547, 3.5626550066464766`}}], 
      PolygonBox[{{0.18749999999999975`, 3.6752404735808355`}, {
       0.26516504294495524`, 3.7348349570550448`}, {0.2302516425362547, 
       3.5626550066464766`}, {0.18749999999999975`, 3.6752404735808355`}}], 
      PolygonBox[{{0.4049427443329971, 3.595057255667003}, {
       0.2302516425362547, 3.5626550066464766`}, {0.26516504294495524`, 
       3.7348349570550448`}, {0.4049427443329971, 3.595057255667003}}], 
      PolygonBox[{{0.26516504294495524`, 3.7348349570550448`}, {
       0.26516504294495535`, 3.7348349570550448`}, {0.4049427443329971, 
       3.595057255667003}, {0.26516504294495524`, 3.7348349570550448`}}], 
      PolygonBox[{{0.40494274433299715`, 3.595057255667003}, {
       0.4049427443329971, 3.595057255667003}, {0.26516504294495535`, 
       3.7348349570550448`}, {0.40494274433299715`, 3.595057255667003}}], 
      PolygonBox[{{0.40494274433299715`, 3.595057255667003}, {
       0.4373449933535234, 3.7697483574637447`}, {0.5, 3.5}, {
       0.40494274433299715`, 3.595057255667003}}], 
      PolygonBox[{{0.5, 3.642337217350632}, {0.5, 3.5}, {0.4373449933535234, 
       3.7697483574637447`}, {0.5, 3.642337217350632}}], 
      PolygonBox[{{0.4373449933535234, 3.7697483574637447`}, {
       0.4374999810329408, 3.915707410443938}, {0.5, 3.642337217350632}, {
       0.4373449933535234, 3.7697483574637447`}}], 
      PolygonBox[{{0.5, 3.79409099469826}, {0.5, 3.642337217350632}, {
       0.4374999810329408, 3.915707410443938}, {0.5, 3.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, 3.915707410443938}, {0.4375, 4.}, {0.5,
        3.79409099469826}, {0.4374999810329408, 3.915707410443938}}], 
      PolygonBox[{{0.5, 4.}, {0.5, 3.79409099469826}, {0.4375, 4.}, {0.5, 
       4.}}], PolygonBox[{{0.4375, 4.}, {0.4374999810329408, 
       4.084292589556061}, {0.5, 4.}, {0.4375, 4.}}], 
      PolygonBox[{{0.5, 4.20590900530174}, {0.5, 4.}, {0.4374999810329408, 
       4.084292589556061}, {0.5, 4.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, 4.084292589556061}, {
       0.4373449933535234, 4.230251642536255}, {0.5, 4.20590900530174}, {
       0.4374999810329408, 4.084292589556061}}], 
      PolygonBox[{{0.5, 4.357662782649368}, {0.5, 4.20590900530174}, {
       0.4373449933535234, 4.230251642536255}, {0.5, 4.357662782649368}}], 
      PolygonBox[{{0.4373449933535234, 4.230251642536255}, {
       0.4049427443329971, 4.404942744332997}, {0.5, 4.357662782649368}, {
       0.4373449933535234, 4.230251642536255}}], 
      PolygonBox[{{0.491446564961186, 4.491446564961186}, {0.5, 
       4.357662782649368}, {0.4049427443329971, 4.404942744332997}, {
       0.491446564961186, 4.491446564961186}}], 
      PolygonBox[{{0.4049427443329971, 4.404942744332997}, {
       0.23025164253625516`, 4.437344993353523}, {0.491446564961186, 
       4.491446564961186}, {0.4049427443329971, 4.404942744332997}}], 
      PolygonBox[{{0.35766278264936807`, 4.5}, {0.491446564961186, 
       4.491446564961186}, {0.23025164253625516`, 4.437344993353523}, {
       0.35766278264936807`, 4.5}}], 
      PolygonBox[{{0.23025164253625516`, 4.437344993353523}, {
       0.08429258955606053, 4.437499981032941}, {0.35766278264936807`, 4.5}, {
       0.23025164253625516`, 4.437344993353523}}], 
      PolygonBox[{{0.20590900537325585`, 4.5}, {0.35766278264936807`, 4.5}, {
       0.08429258955606053, 4.437499981032941}, {0.20590900537325585`, 4.5}}],
       PolygonBox[{{0.08429258955606053, 4.437499981032941}, {
       0.0001055272204876927, 4.4375}, {0.20590900537325585`, 4.5}, {
       0.08429258955606053, 4.437499981032941}}], 
      PolygonBox[{{0.07794195802689004, 4.5}, {0.20590900537325585`, 4.5}, {
       0.0001055272204876927, 4.4375}, {0.07794195802689004, 4.5}}], 
      PolygonBox[{{0.0001055272204876927, 4.4375}, {-0.08429258955605684, 
       4.437499981032941}, {0.07794195802689004, 4.5}, {0.0001055272204876927,
        4.4375}}], 
      PolygonBox[{{-0.20590900530444564`, 4.5}, {0.07794195802689004, 
       4.5}, {-0.08429258955605684, 
       4.437499981032941}, {-0.20590900530444564`, 4.5}}], 
      PolygonBox[{{-0.08429258955605684, 
       4.437499981032941}, {-0.23025164253625502`, 
       4.437344993353523}, {-0.20590900530444564`, 
       4.5}, {-0.08429258955605684, 4.437499981032941}}], 
      PolygonBox[{{-0.35766278264936624`, 4.5}, {-0.20590900530444564`, 
       4.5}, {-0.23025164253625502`, 
       4.437344993353523}, {-0.35766278264936624`, 4.5}}], 
      PolygonBox[{{-0.23025164253625502`, 
       4.437344993353523}, {-0.4049427443329971, 
       4.404942744332997}, {-0.35766278264936624`, 
       4.5}, {-0.23025164253625502`, 4.437344993353523}}], 
      PolygonBox[{{0.5, 4.5}, {-0.35766278264936624`, 
       4.5}, {-0.4049427443329971, 4.404942744332997}, {0.5, 4.5}}], 
      PolygonBox[{{-0.4049427443329971, 
       4.404942744332997}, {-0.4373449933535234, 4.230251642536255}, {0.5, 
       4.5}, {-0.4049427443329971, 4.404942744332997}}], 
      PolygonBox[{{-0.5, 4.357662782649369}, {0.5, 4.5}, {-0.4373449933535234,
        4.230251642536255}, {-0.5, 4.357662782649369}}], 
      PolygonBox[{{-0.4373449933535234, 
       4.230251642536255}, {-0.4374999810329408, 4.084292589556062}, {-0.5, 
       4.357662782649369}, {-0.4373449933535234, 4.230251642536255}}], 
      PolygonBox[{{-0.5, 4.205909005282899}, {-0.5, 
       4.357662782649369}, {-0.4374999810329408, 4.084292589556062}, {-0.5, 
       4.205909005282899}}], 
      PolygonBox[{{-0.4374999810329408, 4.084292589556062}, {-0.4375, 
       4.000123178062996}, {-0.5, 4.205909005282899}, {-0.4374999810329408, 
       4.084292589556062}}], 
      PolygonBox[{{-0.5, 4.0806786667587005`}, {-0.5, 
       4.205909005282899}, {-0.4375, 4.000123178062996}, {-0.5, 
       4.0806786667587005`}}], 
      PolygonBox[{{-0.4375, 4.000123178062996}, {-0.4374999810329408, 
       3.915707410443945}, {-0.5, 4.0806786667587005`}, {-0.4375, 
       4.000123178062996}}], 
      PolygonBox[{{-0.5, 3.7940909948547215`}, {-0.5, 
       4.0806786667587005`}, {-0.4374999810329408, 3.915707410443945}, {-0.5, 
       3.7940909948547215`}}], 
      PolygonBox[{{-0.4374999810329408, 
       3.915707410443945}, {-0.4373449933535234, 3.769748357463745}, {-0.5, 
       3.7940909948547215`}, {-0.4374999810329408, 3.915707410443945}}], 
      PolygonBox[{{-0.5, 3.6423372173506348`}, {-0.5, 
       3.7940909948547215`}, {-0.4373449933535234, 3.769748357463745}, {-0.5, 
       3.6423372173506348`}}], 
      PolygonBox[{{-0.4373449933535234, 
       3.769748357463745}, {-0.40494274433299715`, 3.595057255667003}, {-0.5, 
       3.6423372173506348`}, {-0.4373449933535234, 3.769748357463745}}], 
      PolygonBox[{{-0.5, 4.5}, {-0.5, 
       3.6423372173506348`}, {-0.40494274433299715`, 
       3.595057255667003}, {-0.5, 4.5}}], 
      PolygonBox[{{-0.40494274433299715`, 
       3.595057255667003}, {-0.23025164253625505`, 
       3.5626550066464766`}, {-0.5, 4.5}, {-0.40494274433299715`, 
       3.595057255667003}}], 
      PolygonBox[{{-0.5, 3.5}, {-0.5, 4.5}, {-0.23025164253625505`, 
       3.5626550066464766`}, {-0.5, 3.5}}], 
      PolygonBox[{{-0.23025164253625505`, 
       3.5626550066464766`}, {-0.08429258955606422, 3.562500018967059}, {-0.5,
        3.5}, {-0.23025164253625505`, 3.5626550066464766`}}], 
      PolygonBox[{{-0.20590900556682806`, 3.5}, {-0.5, 
       3.5}, {-0.08429258955606422, 
       3.562500018967059}, {-0.20590900556682806`, 3.5}}], 
      PolygonBox[{{-0.08429258955606422, 3.562500018967059}, {
       0.0001348418310429853, 3.5625}, {-0.20590900556682806`, 
       3.5}, {-0.08429258955606422, 3.562500018967059}}], 
      PolygonBox[{{0.0823238704010616, 3.5}, {-0.20590900556682806`, 3.5}, {
       0.0001348418310429853, 3.5625}, {0.0823238704010616, 3.5}}], 
      PolygonBox[{{0.0001348418310429853, 3.5625}, {0.08429258955605314, 
       3.562500018967059}, {0.0823238704010616, 3.5}, {0.0001348418310429853, 
       3.5625}}], 
      PolygonBox[{{0.2059090053603974, 3.5}, {0.0823238704010616, 3.5}, {
       0.08429258955605314, 3.562500018967059}, {0.2059090053603974, 3.5}}], 
      PolygonBox[{{0.08429258955605314, 3.562500018967059}, {
       0.2302516425362547, 3.5626550066464766`}, {0.2059090053603974, 3.5}, {
       0.08429258955605314, 3.562500018967059}}], 
      PolygonBox[{{0.35766278264937107`, 3.5}, {0.2059090053603974, 3.5}, {
       0.2302516425362547, 3.5626550066464766`}, {0.35766278264937107`, 
       3.5}}], PolygonBox[{{0.2302516425362547, 3.5626550066464766`}, {
       0.4049427443329971, 3.595057255667003}, {0.35766278264937107`, 3.5}, {
       0.2302516425362547, 3.5626550066464766`}}], 
      PolygonBox[{{0.5, 3.5}, {0.35766278264937107`, 3.5}, {
       0.4049427443329971, 3.595057255667003}, {0.5, 3.5}}], 
      PolygonBox[{{0.4049427443329971, 3.595057255667003}, {
       0.40494274433299715`, 3.595057255667003}, {0.5, 3.5}, {
       0.4049427443329971, 3.595057255667003}}], 
      PolygonBox[{{0.5, 3.5}, {0.5, 3.5}, {0.40494274433299715`, 
       3.595057255667003}, {0.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 5.}, {-0.4791666666666667, 5.}, {-0.4583333333333333, 
       5.}, {-0.4375, 5.}, {-0.4166666666666667, 5.}, {-0.39583333333333337`, 
       5.}, {-0.375, 5.}, {-0.375, 5.}, {-0.3958333333333333, 
       5.}, {-0.4166666666666667, 5.}, {-0.4375, 5.}, {-0.4583333333333333, 
       5.}, {-0.47916666666666663`, 5.}, {-0.5, 5.}, {-0.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.375, 5.}, {0.3958333333333333, 5.}, {0.4166666666666667, 
       5.}, {0.4375, 5.}, {0.4583333333333333, 5.}, {0.47916666666666663`, 
       5.}, {0.5, 5.}, {0.5, 5.}, {0.4791666666666667, 5.}, {
       0.4583333333333333, 5.}, {0.4375, 5.}, {0.4166666666666667, 5.}, {
       0.39583333333333337`, 5.}, {0.375, 5.}, {0.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 4.5}, {0., 4.520833333333333}, {0., 4.541666666666667}, {
       0., 4.5625}, {0., 4.583333333333333}, {0., 4.604166666666667}, {0., 
       4.625}, {0., 4.625}, {0., 4.604166666666667}, {0., 
       4.583333333333333}, {0., 4.5625}, {0., 4.541666666666667}, {0., 
       4.520833333333333}, {0., 4.5}, {0., 4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 5.375}, {0., 5.395833333333333}, {0., 
       5.416666666666667}, {0., 5.4375}, {0., 5.458333333333333}, {0., 
       5.479166666666667}, {0., 5.5}, {0., 5.5}, {0., 5.479166666666667}, {0.,
        5.458333333333333}, {0., 5.4375}, {0., 5.416666666666667}, {0., 
       5.395833333333333}, {0., 5.375}, {0., 5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.375, 5.}, {-0.25, 5.}, {-0.125, 5.}, {0., 5.}, {0.125, 
       5.}, {0.25, 5.}, {0.375, 5.}, {0.375, 5.}, {0.25, 5.}, {0.125, 5.}, {
       0., 5.}, {-0.125, 5.}, {-0.25, 5.}, {-0.375, 5.}, {-0.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 4.625}, {0., 4.75}, {0., 4.875}, {0., 5.}, {0., 5.125}, {
       0., 5.25}, {0., 5.375}, {0., 5.375}, {0., 5.25}, {0., 5.125}, {0., 
       5.}, {0., 4.875}, {0., 4.75}, {0., 4.625}, {0., 4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQE37CG0iENAf9nXpXrX7dWLOj8lJYs4NFg66d05
cQUif0DE4VbO/TNlPy7Yn/t2NqedX9QBYsYJ+xnKTw71+og63OuMWbTnxg77
rxnh8a+KRB24uub5WFZW2YCVNYg6XIXI74fJ//0PAsf3w/TfhJi/H2Z+PcT+
/TD7/SHu268BdR/U/fvR3L//Zm8Z79w5wg6NyPodhB3uQM035jSaXPFByIEN
4v79GXekbYs2Czm8hbqPe/qKBaK9Qg4dz8t+vro1eQ/E/UIOZ6D+g8l/h7jf
Hqb/BjR8jKDm1yGHH9B+P2j43oC6Dz38AWcPqCM=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEP7CG0mENYKAhcReMfhfMZUICYQwhEfj8q/+p+
VPUPCPLB2kJF4fzVq0BABE29CJp6YTT1QmjqMflhKO6D8Y+iqYcBIZj/7FH5
V+1R1T8gyEdznz2a++3R/GeP5n97tPCBxwcABbZV4A==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{0.26516504294495535`, 4.734834957055044}, {
       0.3247595264191645, 4.8125}, {0.40494274433299715`, 
       4.595057255667003}, {0.26516504294495535`, 4.734834957055044}}], 
      PolygonBox[{{0.4373449933535234, 4.769748357463745}, {
       0.40494274433299715`, 4.595057255667003}, {0.3247595264191645, 
       4.8125}, {0.4373449933535234, 4.769748357463745}}], 
      PolygonBox[{{0.3247595264191645, 4.8125}, {0.36222218485840063`, 
       4.902942858086555}, {0.4373449933535234, 4.769748357463745}, {
       0.3247595264191645, 4.8125}}], 
      PolygonBox[{{0.4374999810329408, 4.915707410443938}, {
       0.4373449933535234, 4.769748357463745}, {0.36222218485840063`, 
       4.902942858086555}, {0.4374999810329408, 4.915707410443938}}], 
      PolygonBox[{{0.36222218485840063`, 4.902942858086555}, {0.375, 5.}, {
       0.4374999810329408, 4.915707410443938}, {0.36222218485840063`, 
       4.902942858086555}}], 
      PolygonBox[{{0.4375, 5.}, {0.4374999810329408, 4.915707410443938}, {
       0.375, 5.}, {0.4375, 5.}}], 
      PolygonBox[{{0.375, 5.}, {0.36222218485840063`, 5.097057141913445}, {
       0.4375, 5.}, {0.375, 5.}}], 
      PolygonBox[{{0.4374999810329408, 5.084292589556061}, {0.4375, 5.}, {
       0.36222218485840063`, 5.097057141913445}, {0.4374999810329408, 
       5.084292589556061}}], 
      PolygonBox[{{0.36222218485840063`, 5.097057141913445}, {
       0.3247595264191645, 5.1875}, {0.4374999810329408, 5.084292589556061}, {
       0.36222218485840063`, 5.097057141913445}}], 
      PolygonBox[{{0.4373449933535234, 5.230251642536255}, {
       0.4374999810329408, 5.084292589556061}, {0.3247595264191645, 5.1875}, {
       0.4373449933535234, 5.230251642536255}}], 
      PolygonBox[{{0.3247595264191645, 5.1875}, {0.26516504294495535`, 
       5.265165042944956}, {0.4373449933535234, 5.230251642536255}, {
       0.3247595264191645, 5.1875}}], 
      PolygonBox[{{0.4049427443329971, 5.404942744332997}, {
       0.4373449933535234, 5.230251642536255}, {0.26516504294495535`, 
       5.265165042944956}, {0.4049427443329971, 5.404942744332997}}], 
      PolygonBox[{{0.26516504294495535`, 5.265165042944956}, {
       0.18750000000000006`, 5.3247595264191645`}, {0.4049427443329971, 
       5.404942744332997}, {0.26516504294495535`, 5.265165042944956}}], 
      PolygonBox[{{0.23025164253625516`, 5.437344993353523}, {
       0.4049427443329971, 5.404942744332997}, {0.18750000000000006`, 
       5.3247595264191645`}, {0.23025164253625516`, 5.437344993353523}}], 
      PolygonBox[{{0.18750000000000006`, 5.3247595264191645`}, {
       0.09705714191344536, 5.362222184858401}, {0.23025164253625516`, 
       5.437344993353523}, {0.18750000000000006`, 5.3247595264191645`}}], 
      PolygonBox[{{0.08429258955606053, 5.437499981032941}, {
       0.23025164253625516`, 5.437344993353523}, {0.09705714191344536, 
       5.362222184858401}, {0.08429258955606053, 5.437499981032941}}], 
      PolygonBox[{{0.09705714191344536, 5.362222184858401}, {
       2.296212748401287*^-17, 5.375}, {0.08429258955606053, 
       5.437499981032941}, {0.09705714191344536, 5.362222184858401}}], 
      PolygonBox[{{0.0001055272204876927, 5.4375}, {0.08429258955606053, 
       5.437499981032941}, {2.296212748401287*^-17, 5.375}, {
       0.0001055272204876927, 5.4375}}], 
      PolygonBox[{{2.296212748401287*^-17, 5.375}, {-0.09705714191344515, 
       5.362222184858401}, {0.0001055272204876927, 5.4375}, {
       2.296212748401287*^-17, 5.375}}], 
      PolygonBox[{{-0.08429258955605684, 5.437499981032941}, {
       0.0001055272204876927, 5.4375}, {-0.09705714191344515, 
       5.362222184858401}, {-0.08429258955605684, 5.437499981032941}}], 
      PolygonBox[{{-0.09705714191344515, 
       5.362222184858401}, {-0.18749999999999992`, 
       5.3247595264191645`}, {-0.08429258955605684, 
       5.437499981032941}, {-0.09705714191344515, 5.362222184858401}}], 
      PolygonBox[{{-0.23025164253625502`, 
       5.437344993353523}, {-0.08429258955605684, 
       5.437499981032941}, {-0.18749999999999992`, 
       5.3247595264191645`}, {-0.23025164253625502`, 5.437344993353523}}], 
      PolygonBox[{{-0.18749999999999992`, 
       5.3247595264191645`}, {-0.2651650429449553, 
       5.265165042944956}, {-0.23025164253625502`, 
       5.437344993353523}, {-0.18749999999999992`, 5.3247595264191645`}}], 
      PolygonBox[{{-0.4049427443329971, 
       5.404942744332997}, {-0.23025164253625502`, 
       5.437344993353523}, {-0.2651650429449553, 
       5.265165042944956}, {-0.4049427443329971, 5.404942744332997}}], 
      PolygonBox[{{-0.2651650429449553, 
       5.265165042944956}, {-0.32475952641916445`, 
       5.1875}, {-0.4049427443329971, 
       5.404942744332997}, {-0.2651650429449553, 5.265165042944956}}], 
      PolygonBox[{{-0.4373449933535234, 
       5.230251642536255}, {-0.4049427443329971, 
       5.404942744332997}, {-0.32475952641916445`, 
       5.1875}, {-0.4373449933535234, 5.230251642536255}}], 
      PolygonBox[{{-0.32475952641916445`, 5.1875}, {-0.3622221848584006, 
       5.097057141913446}, {-0.4373449933535234, 
       5.230251642536255}, {-0.32475952641916445`, 5.1875}}], 
      PolygonBox[{{-0.4374999810329408, 
       5.084292589556062}, {-0.4373449933535234, 
       5.230251642536255}, {-0.3622221848584006, 
       5.097057141913446}, {-0.4374999810329408, 5.084292589556062}}], 
      PolygonBox[{{-0.3622221848584006, 5.097057141913446}, {-0.375, 
       5.}, {-0.4374999810329408, 5.084292589556062}, {-0.3622221848584006, 
       5.097057141913446}}], 
      PolygonBox[{{-0.4375, 5.000123178062996}, {-0.4374999810329408, 
       5.084292589556062}, {-0.375, 5.}, {-0.4375, 5.000123178062996}}], 
      PolygonBox[{{-0.375, 5.}, {-0.36222218485840063`, 
       4.902942858086555}, {-0.4375, 5.000123178062996}, {-0.375, 5.}}], 
      PolygonBox[{{-0.4374999810329408, 4.915707410443945}, {-0.4375, 
       5.000123178062996}, {-0.36222218485840063`, 
       4.902942858086555}, {-0.4374999810329408, 4.915707410443945}}], 
      PolygonBox[{{-0.36222218485840063`, 
       4.902942858086555}, {-0.3247595264191646, 
       4.8125}, {-0.4374999810329408, 
       4.915707410443945}, {-0.36222218485840063`, 4.902942858086555}}], 
      PolygonBox[{{-0.4373449933535234, 
       4.769748357463746}, {-0.4374999810329408, 
       4.915707410443945}, {-0.3247595264191646, 
       4.8125}, {-0.4373449933535234, 4.769748357463746}}], 
      PolygonBox[{{-0.3247595264191646, 4.8125}, {-0.26516504294495535`, 
       4.734834957055044}, {-0.4373449933535234, 
       4.769748357463746}, {-0.3247595264191646, 4.8125}}], 
      PolygonBox[{{-0.40494274433299715`, 
       4.595057255667003}, {-0.4373449933535234, 
       4.769748357463746}, {-0.26516504294495535`, 
       4.734834957055044}, {-0.40494274433299715`, 4.595057255667003}}], 
      PolygonBox[{{-0.26516504294495535`, 
       4.734834957055044}, {-0.18750000000000017`, 
       4.6752404735808355`}, {-0.40494274433299715`, 
       4.595057255667003}, {-0.26516504294495535`, 4.734834957055044}}], 
      PolygonBox[{{-0.23025164253625505`, 
       4.562655006646477}, {-0.40494274433299715`, 
       4.595057255667003}, {-0.18750000000000017`, 
       4.6752404735808355`}, {-0.23025164253625505`, 4.562655006646477}}], 
      PolygonBox[{{-0.18750000000000017`, 
       4.6752404735808355`}, {-0.09705714191344557, 
       4.637777815141599}, {-0.23025164253625505`, 
       4.562655006646477}, {-0.18750000000000017`, 4.6752404735808355`}}], 
      PolygonBox[{{-0.08429258955606422, 
       4.562500018967059}, {-0.23025164253625505`, 
       4.562655006646477}, {-0.09705714191344557, 
       4.637777815141599}, {-0.08429258955606422, 4.562500018967059}}], 
      PolygonBox[{{-0.09705714191344557, 4.637777815141599}, {
       6.888638245203862*^-17, 4.625}, {-0.08429258955606422, 
       4.562500018967059}, {-0.09705714191344557, 4.637777815141599}}], 
      PolygonBox[{{0.0001348418310429853, 4.5625}, {-0.08429258955606422, 
       4.562500018967059}, {6.888638245203862*^-17, 4.625}, {
       0.0001348418310429853, 4.5625}}], 
      PolygonBox[{{6.888638245203862*^-17, 4.625}, {0.09705714191344511, 
       4.637777815141599}, {0.0001348418310429853, 4.5625}, {
       6.888638245203862*^-17, 4.625}}], 
      PolygonBox[{{0.08429258955605314, 4.562500018967059}, {
       0.0001348418310429853, 4.5625}, {0.09705714191344511, 
       4.637777815141599}, {0.08429258955605314, 4.562500018967059}}], 
      PolygonBox[{{0.09705714191344511, 4.637777815141599}, {
       0.18749999999999975`, 4.6752404735808355`}, {0.08429258955605314, 
       4.562500018967059}, {0.09705714191344511, 4.637777815141599}}], 
      PolygonBox[{{0.2302516425362547, 4.562655006646477}, {
       0.08429258955605314, 4.562500018967059}, {0.18749999999999975`, 
       4.6752404735808355`}, {0.2302516425362547, 4.562655006646477}}], 
      PolygonBox[{{0.18749999999999975`, 4.6752404735808355`}, {
       0.26516504294495524`, 4.734834957055044}, {0.2302516425362547, 
       4.562655006646477}, {0.18749999999999975`, 4.6752404735808355`}}], 
      PolygonBox[{{0.4049427443329971, 4.595057255667003}, {
       0.2302516425362547, 4.562655006646477}, {0.26516504294495524`, 
       4.734834957055044}, {0.4049427443329971, 4.595057255667003}}], 
      PolygonBox[{{0.26516504294495524`, 4.734834957055044}, {
       0.26516504294495535`, 4.734834957055044}, {0.4049427443329971, 
       4.595057255667003}, {0.26516504294495524`, 4.734834957055044}}], 
      PolygonBox[{{0.40494274433299715`, 4.595057255667003}, {
       0.4049427443329971, 4.595057255667003}, {0.26516504294495535`, 
       4.734834957055044}, {0.40494274433299715`, 4.595057255667003}}], 
      PolygonBox[{{0.40494274433299715`, 4.595057255667003}, {
       0.4373449933535234, 4.769748357463745}, {0.5, 4.5}, {
       0.40494274433299715`, 4.595057255667003}}], 
      PolygonBox[{{0.5, 4.642337217350632}, {0.5, 4.5}, {0.4373449933535234, 
       4.769748357463745}, {0.5, 4.642337217350632}}], 
      PolygonBox[{{0.4373449933535234, 4.769748357463745}, {
       0.4374999810329408, 4.915707410443938}, {0.5, 4.642337217350632}, {
       0.4373449933535234, 4.769748357463745}}], 
      PolygonBox[{{0.5, 4.79409099469826}, {0.5, 4.642337217350632}, {
       0.4374999810329408, 4.915707410443938}, {0.5, 4.79409099469826}}], 
      PolygonBox[{{0.4374999810329408, 4.915707410443938}, {0.4375, 5.}, {0.5,
        4.79409099469826}, {0.4374999810329408, 4.915707410443938}}], 
      PolygonBox[{{0.5, 5.}, {0.5, 4.79409099469826}, {0.4375, 5.}, {0.5, 
       5.}}], PolygonBox[{{0.4375, 5.}, {0.4374999810329408, 
       5.084292589556061}, {0.5, 5.}, {0.4375, 5.}}], 
      PolygonBox[{{0.5, 5.20590900530174}, {0.5, 5.}, {0.4374999810329408, 
       5.084292589556061}, {0.5, 5.20590900530174}}], 
      PolygonBox[{{0.4374999810329408, 5.084292589556061}, {
       0.4373449933535234, 5.230251642536255}, {0.5, 5.20590900530174}, {
       0.4374999810329408, 5.084292589556061}}], 
      PolygonBox[{{0.5, 5.357662782649368}, {0.5, 5.20590900530174}, {
       0.4373449933535234, 5.230251642536255}, {0.5, 5.357662782649368}}], 
      PolygonBox[{{0.4373449933535234, 5.230251642536255}, {
       0.4049427443329971, 5.404942744332997}, {0.5, 5.357662782649368}, {
       0.4373449933535234, 5.230251642536255}}], 
      PolygonBox[{{0.491446564961186, 5.491446564961186}, {0.5, 
       5.357662782649368}, {0.4049427443329971, 5.404942744332997}, {
       0.491446564961186, 5.491446564961186}}], 
      PolygonBox[{{0.4049427443329971, 5.404942744332997}, {
       0.23025164253625516`, 5.437344993353523}, {0.491446564961186, 
       5.491446564961186}, {0.4049427443329971, 5.404942744332997}}], 
      PolygonBox[{{0.35766278264936807`, 5.5}, {0.491446564961186, 
       5.491446564961186}, {0.23025164253625516`, 5.437344993353523}, {
       0.35766278264936807`, 5.5}}], 
      PolygonBox[{{0.23025164253625516`, 5.437344993353523}, {
       0.08429258955606053, 5.437499981032941}, {0.35766278264936807`, 5.5}, {
       0.23025164253625516`, 5.437344993353523}}], 
      PolygonBox[{{0.20590900537325585`, 5.5}, {0.35766278264936807`, 5.5}, {
       0.08429258955606053, 5.437499981032941}, {0.20590900537325585`, 5.5}}],
       PolygonBox[{{0.08429258955606053, 5.437499981032941}, {
       0.0001055272204876927, 5.4375}, {0.20590900537325585`, 5.5}, {
       0.08429258955606053, 5.437499981032941}}], 
      PolygonBox[{{0.07794195802689004, 5.5}, {0.20590900537325585`, 5.5}, {
       0.0001055272204876927, 5.4375}, {0.07794195802689004, 5.5}}], 
      PolygonBox[{{0.0001055272204876927, 5.4375}, {-0.08429258955605684, 
       5.437499981032941}, {0.07794195802689004, 5.5}, {0.0001055272204876927,
        5.4375}}], 
      PolygonBox[{{-0.20590900530444564`, 5.5}, {0.07794195802689004, 
       5.5}, {-0.08429258955605684, 
       5.437499981032941}, {-0.20590900530444564`, 5.5}}], 
      PolygonBox[{{-0.08429258955605684, 
       5.437499981032941}, {-0.23025164253625502`, 
       5.437344993353523}, {-0.20590900530444564`, 
       5.5}, {-0.08429258955605684, 5.437499981032941}}], 
      PolygonBox[{{-0.35766278264936624`, 5.5}, {-0.20590900530444564`, 
       5.5}, {-0.23025164253625502`, 
       5.437344993353523}, {-0.35766278264936624`, 5.5}}], 
      PolygonBox[{{-0.23025164253625502`, 
       5.437344993353523}, {-0.4049427443329971, 
       5.404942744332997}, {-0.35766278264936624`, 
       5.5}, {-0.23025164253625502`, 5.437344993353523}}], 
      PolygonBox[{{0.5, 5.5}, {-0.35766278264936624`, 
       5.5}, {-0.4049427443329971, 5.404942744332997}, {0.5, 5.5}}], 
      PolygonBox[{{-0.4049427443329971, 
       5.404942744332997}, {-0.4373449933535234, 5.230251642536255}, {0.5, 
       5.5}, {-0.4049427443329971, 5.404942744332997}}], 
      PolygonBox[{{-0.5, 5.357662782649369}, {0.5, 5.5}, {-0.4373449933535234,
        5.230251642536255}, {-0.5, 5.357662782649369}}], 
      PolygonBox[{{-0.4373449933535234, 
       5.230251642536255}, {-0.4374999810329408, 5.084292589556062}, {-0.5, 
       5.357662782649369}, {-0.4373449933535234, 5.230251642536255}}], 
      PolygonBox[{{-0.5, 5.205909005282899}, {-0.5, 
       5.357662782649369}, {-0.4374999810329408, 5.084292589556062}, {-0.5, 
       5.205909005282899}}], 
      PolygonBox[{{-0.4374999810329408, 5.084292589556062}, {-0.4375, 
       5.000123178062996}, {-0.5, 5.205909005282899}, {-0.4374999810329408, 
       5.084292589556062}}], 
      PolygonBox[{{-0.5, 5.0806786667587005`}, {-0.5, 
       5.205909005282899}, {-0.4375, 5.000123178062996}, {-0.5, 
       5.0806786667587005`}}], 
      PolygonBox[{{-0.4375, 5.000123178062996}, {-0.4374999810329408, 
       4.915707410443945}, {-0.5, 5.0806786667587005`}, {-0.4375, 
       5.000123178062996}}], 
      PolygonBox[{{-0.5, 4.794090994854722}, {-0.5, 
       5.0806786667587005`}, {-0.4374999810329408, 4.915707410443945}, {-0.5, 
       4.794090994854722}}], 
      PolygonBox[{{-0.4374999810329408, 
       4.915707410443945}, {-0.4373449933535234, 4.769748357463746}, {-0.5, 
       4.794090994854722}, {-0.4374999810329408, 4.915707410443945}}], 
      PolygonBox[{{-0.5, 4.642337217350635}, {-0.5, 
       4.794090994854722}, {-0.4373449933535234, 4.769748357463746}, {-0.5, 
       4.642337217350635}}], 
      PolygonBox[{{-0.4373449933535234, 
       4.769748357463746}, {-0.40494274433299715`, 4.595057255667003}, {-0.5, 
       4.642337217350635}, {-0.4373449933535234, 4.769748357463746}}], 
      PolygonBox[{{-0.5, 5.5}, {-0.5, 
       4.642337217350635}, {-0.40494274433299715`, 4.595057255667003}, {-0.5, 
       5.5}}], PolygonBox[{{-0.40494274433299715`, 
       4.595057255667003}, {-0.23025164253625505`, 4.562655006646477}, {-0.5, 
       5.5}, {-0.40494274433299715`, 4.595057255667003}}], 
      PolygonBox[{{-0.5, 4.5}, {-0.5, 5.5}, {-0.23025164253625505`, 
       4.562655006646477}, {-0.5, 4.5}}], 
      PolygonBox[{{-0.23025164253625505`, 
       4.562655006646477}, {-0.08429258955606422, 4.562500018967059}, {-0.5, 
       4.5}, {-0.23025164253625505`, 4.562655006646477}}], 
      PolygonBox[{{-0.20590900556682806`, 4.5}, {-0.5, 
       4.5}, {-0.08429258955606422, 
       4.562500018967059}, {-0.20590900556682806`, 4.5}}], 
      PolygonBox[{{-0.08429258955606422, 4.562500018967059}, {
       0.0001348418310429853, 4.5625}, {-0.20590900556682806`, 
       4.5}, {-0.08429258955606422, 4.562500018967059}}], 
      PolygonBox[{{0.0823238704010616, 4.5}, {-0.20590900556682806`, 4.5}, {
       0.0001348418310429853, 4.5625}, {0.0823238704010616, 4.5}}], 
      PolygonBox[{{0.0001348418310429853, 4.5625}, {0.08429258955605314, 
       4.562500018967059}, {0.0823238704010616, 4.5}, {0.0001348418310429853, 
       4.5625}}], 
      PolygonBox[{{0.2059090053603974, 4.5}, {0.0823238704010616, 4.5}, {
       0.08429258955605314, 4.562500018967059}, {0.2059090053603974, 4.5}}], 
      PolygonBox[{{0.08429258955605314, 4.562500018967059}, {
       0.2302516425362547, 4.562655006646477}, {0.2059090053603974, 4.5}, {
       0.08429258955605314, 4.562500018967059}}], 
      PolygonBox[{{0.35766278264937107`, 4.5}, {0.2059090053603974, 4.5}, {
       0.2302516425362547, 4.562655006646477}, {0.35766278264937107`, 4.5}}], 
      PolygonBox[{{0.2302516425362547, 4.562655006646477}, {
       0.4049427443329971, 4.595057255667003}, {0.35766278264937107`, 4.5}, {
       0.2302516425362547, 4.562655006646477}}], 
      PolygonBox[{{0.5, 4.5}, {0.35766278264937107`, 4.5}, {
       0.4049427443329971, 4.595057255667003}, {0.5, 4.5}}], 
      PolygonBox[{{0.4049427443329971, 4.595057255667003}, {
       0.40494274433299715`, 4.595057255667003}, {0.5, 4.5}, {
       0.4049427443329971, 4.595057255667003}}], 
      PolygonBox[{{0.5, 4.5}, {0.5, 4.5}, {0.40494274433299715`, 
       4.595057255667003}, {0.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -5.}, {0.5208333333333333, -5.}, {
       0.5416666666666667, -5.}, {0.5625, -5.}, {0.5833333333333333, -5.}, {
       0.6041666666666666, -5.}, {0.625, -5.}, {0.625, -5.}, {
       0.6041666666666667, -5.}, {0.5833333333333333, -5.}, {0.5625, -5.}, {
       0.5416666666666667, -5.}, {0.5208333333333334, -5.}, {0.5, -5.}, {
       0.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, -5.}, {1.3958333333333333`, -5.}, {
       1.4166666666666667`, -5.}, {1.4375, -5.}, {1.4583333333333333`, -5.}, {
       1.4791666666666665`, -5.}, {1.5, -5.}, {1.5, -5.}, {
       1.4791666666666667`, -5.}, {1.4583333333333333`, -5.}, {1.4375, -5.}, {
       1.4166666666666667`, -5.}, {1.3958333333333335`, -5.}, {1.375, -5.}, {
       1.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -5.5}, {1., -5.479166666666667}, {
       1., -5.458333333333333}, {1., -5.4375}, {1., -5.416666666666667}, {
       1., -5.395833333333333}, {1., -5.375}, {1., -5.375}, {
       1., -5.395833333333333}, {1., -5.416666666666667}, {1., -5.4375}, {
       1., -5.458333333333333}, {1., -5.479166666666667}, {1., -5.5}, {
       1., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -4.625}, {1., -4.604166666666667}, {
       1., -4.583333333333333}, {1., -4.5625}, {1., -4.541666666666667}, {
       1., -4.520833333333333}, {1., -4.5}, {1., -4.5}, {
       1., -4.520833333333333}, {1., -4.541666666666667}, {1., -4.5625}, {
       1., -4.583333333333333}, {1., -4.604166666666667}, {1., -4.625}, {
       1., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, -5.}, {0.75, -5.}, {0.875, -5.}, {1., -5.}, {
       1.125, -5.}, {1.25, -5.}, {1.375, -5.}, {1.375, -5.}, {1.25, -5.}, {
       1.125, -5.}, {1., -5.}, {0.875, -5.}, {0.75, -5.}, {0.625, -5.}, {
       0.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -5.375}, {1., -5.25}, {1., -5.125}, {1., -5.}, {
       1., -4.875}, {1., -4.75}, {1., -4.625}, {1., -4.625}, {1., -4.75}, {
       1., -4.875}, {1., -5.}, {1., -5.125}, {1., -5.25}, {1., -5.375}, {
       1., -5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CG0yIEri2NrV57+an+zt4x37hzhAwl9E7jN
jb5C5B2ED5jdNt8sa/fF3ojTaHLFB6EDEH2f7TPuSNsWbRY6MO+E6qnu3o/2
3NNXLBDthcl/gOhvEDpwNG9L9osnb+DyjGCJV3D9UzwnzDzS/BxuvsPjey8m
zn4Ktz9ihwvr2own9jeg7oOY/wTufpi8elHnp6RkEVT9B0QOTIKaf/bb2Zx2
ftED//6DwEv7GcpPDvX6iB44BHXf14zw+FdFogfA0v/fQ90vemAu1H+o8p/g
+mHhcw5qPkr4HUCErwbUfejhDwA1Watj
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CG00IGwUBD4CuevXgUCn+B8CP0BTf4Vmv6n
aOofEORDzEHwwcaECqOpF0FTL4KmXhRNvRgGPxTFfWIHVqG4H6b+A5r8JzT9
X9HU/yDIR3XfDzT3/0Dz3w80//9ACx9EfAEApq9plg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, -5.265165042944956}, {
       1.3247595264191645`, -5.1875}, {
       1.4049427443329972`, -5.404942744332997}, {
       1.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{1.4373449933535234`, -5.230251642536255}, {
       1.4049427443329972`, -5.404942744332997}, {
       1.3247595264191645`, -5.1875}, {
       1.4373449933535234`, -5.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, -5.1875}, {
       1.3622221848584006`, -5.097057141913445}, {
       1.4373449933535234`, -5.230251642536255}, {
       1.3247595264191645`, -5.1875}}], 
      PolygonBox[{{1.4374999810329407`, -5.084292589556062}, {
       1.4373449933535234`, -5.230251642536255}, {
       1.3622221848584006`, -5.097057141913445}, {
       1.4374999810329407`, -5.084292589556062}}], 
      PolygonBox[{{1.3622221848584006`, -5.097057141913445}, {1.375, -5.}, {
       1.4374999810329407`, -5.084292589556062}, {
       1.3622221848584006`, -5.097057141913445}}], 
      PolygonBox[{{1.4375, -5.}, {1.4374999810329407`, -5.084292589556062}, {
       1.375, -5.}, {1.4375, -5.}}], 
      PolygonBox[{{1.375, -5.}, {1.3622221848584006`, -4.902942858086555}, {
       1.4375, -5.}, {1.375, -5.}}], 
      PolygonBox[{{1.4374999810329407`, -4.915707410443939}, {1.4375, -5.}, {
       1.3622221848584006`, -4.902942858086555}, {
       1.4374999810329407`, -4.915707410443939}}], 
      PolygonBox[{{1.3622221848584006`, -4.902942858086555}, {
       1.3247595264191645`, -4.8125}, {
       1.4374999810329407`, -4.915707410443939}, {
       1.3622221848584006`, -4.902942858086555}}], 
      PolygonBox[{{1.4373449933535234`, -4.769748357463745}, {
       1.4374999810329407`, -4.915707410443939}, {
       1.3247595264191645`, -4.8125}, {
       1.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{1.3247595264191645`, -4.8125}, {
       1.2651650429449552`, -4.734834957055044}, {
       1.4373449933535234`, -4.769748357463745}, {
       1.3247595264191645`, -4.8125}}], 
      PolygonBox[{{1.4049427443329972`, -4.595057255667003}, {
       1.4373449933535234`, -4.769748357463745}, {
       1.2651650429449552`, -4.734834957055044}, {
       1.4049427443329972`, -4.595057255667003}}], 
      PolygonBox[{{1.2651650429449552`, -4.734834957055044}, {
       1.1875, -4.6752404735808355`}, {
       1.4049427443329972`, -4.595057255667003}, {
       1.2651650429449552`, -4.734834957055044}}], 
      PolygonBox[{{1.230251642536255, -4.562655006646477}, {
       1.4049427443329972`, -4.595057255667003}, {
       1.1875, -4.6752404735808355`}, {
       1.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{1.1875, -4.6752404735808355`}, {
       1.0970571419134454`, -4.637777815141599}, {
       1.230251642536255, -4.562655006646477}, {
       1.1875, -4.6752404735808355`}}], 
      PolygonBox[{{1.0842925895560604`, -4.562500018967059}, {
       1.230251642536255, -4.562655006646477}, {
       1.0970571419134454`, -4.637777815141599}, {
       1.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{1.0970571419134454`, -4.637777815141599}, {1., -4.625}, {
       1.0842925895560604`, -4.562500018967059}, {
       1.0970571419134454`, -4.637777815141599}}], 
      PolygonBox[{{1.0001055272204877`, -4.5625}, {
       1.0842925895560604`, -4.562500018967059}, {1., -4.625}, {
       1.0001055272204877`, -4.5625}}], 
      PolygonBox[{{1., -4.625}, {0.9029428580865548, -4.637777815141599}, {
       1.0001055272204877`, -4.5625}, {1., -4.625}}], 
      PolygonBox[{{0.9157074104439431, -4.562500018967059}, {
       1.0001055272204877`, -4.5625}, {
       0.9029428580865548, -4.637777815141599}, {
       0.9157074104439431, -4.562500018967059}}], 
      PolygonBox[{{0.9029428580865548, -4.637777815141599}, {
       0.8125000000000001, -4.6752404735808355`}, {
       0.9157074104439431, -4.562500018967059}, {
       0.9029428580865548, -4.637777815141599}}], 
      PolygonBox[{{0.7697483574637449, -4.562655006646477}, {
       0.9157074104439431, -4.562500018967059}, {
       0.8125000000000001, -4.6752404735808355`}, {
       0.7697483574637449, -4.562655006646477}}], 
      PolygonBox[{{0.8125000000000001, -4.6752404735808355`}, {
       0.7348349570550448, -4.734834957055044}, {
       0.7697483574637449, -4.562655006646477}, {
       0.8125000000000001, -4.6752404735808355`}}], 
      PolygonBox[{{0.5950572556670028, -4.595057255667003}, {
       0.7697483574637449, -4.562655006646477}, {
       0.7348349570550448, -4.734834957055044}, {
       0.5950572556670028, -4.595057255667003}}], 
      PolygonBox[{{0.7348349570550448, -4.734834957055044}, {
       0.6752404735808355, -4.8125}, {
       0.5950572556670028, -4.595057255667003}, {
       0.7348349570550448, -4.734834957055044}}], 
      PolygonBox[{{0.5626550066464766, -4.769748357463745}, {
       0.5950572556670028, -4.595057255667003}, {
       0.6752404735808355, -4.8125}, {
       0.5626550066464766, -4.769748357463745}}], 
      PolygonBox[{{0.6752404735808355, -4.8125}, {
       0.6377778151415994, -4.902942858086554}, {
       0.5626550066464766, -4.769748357463745}, {
       0.6752404735808355, -4.8125}}], 
      PolygonBox[{{0.5625000189670593, -4.915707410443938}, {
       0.5626550066464766, -4.769748357463745}, {
       0.6377778151415994, -4.902942858086554}, {
       0.5625000189670593, -4.915707410443938}}], 
      PolygonBox[{{0.6377778151415994, -4.902942858086554}, {0.625, -5.}, {
       0.5625000189670593, -4.915707410443938}, {
       0.6377778151415994, -4.902942858086554}}], 
      PolygonBox[{{0.5625, -4.999876821937004}, {
       0.5625000189670593, -4.915707410443938}, {0.625, -5.}, {
       0.5625, -4.999876821937004}}], 
      PolygonBox[{{0.625, -5.}, {0.6377778151415994, -5.097057141913445}, {
       0.5625, -4.999876821937004}, {0.625, -5.}}], 
      PolygonBox[{{0.5625000189670593, -5.084292589556055}, {
       0.5625, -4.999876821937004}, {
       0.6377778151415994, -5.097057141913445}, {
       0.5625000189670593, -5.084292589556055}}], 
      PolygonBox[{{0.6377778151415994, -5.097057141913445}, {
       0.6752404735808354, -5.1875}, {
       0.5625000189670593, -5.084292589556055}, {
       0.6377778151415994, -5.097057141913445}}], 
      PolygonBox[{{0.5626550066464766, -5.230251642536254}, {
       0.5625000189670593, -5.084292589556055}, {
       0.6752404735808354, -5.1875}, {
       0.5626550066464766, -5.230251642536254}}], 
      PolygonBox[{{0.6752404735808354, -5.1875}, {
       0.7348349570550446, -5.265165042944956}, {
       0.5626550066464766, -5.230251642536254}, {
       0.6752404735808354, -5.1875}}], 
      PolygonBox[{{0.5950572556670028, -5.404942744332997}, {
       0.5626550066464766, -5.230251642536254}, {
       0.7348349570550446, -5.265165042944956}, {
       0.5950572556670028, -5.404942744332997}}], 
      PolygonBox[{{0.7348349570550446, -5.265165042944956}, {
       0.8124999999999998, -5.3247595264191645`}, {
       0.5950572556670028, -5.404942744332997}, {
       0.7348349570550446, -5.265165042944956}}], 
      PolygonBox[{{0.7697483574637449, -5.437344993353523}, {
       0.5950572556670028, -5.404942744332997}, {
       0.8124999999999998, -5.3247595264191645`}, {
       0.7697483574637449, -5.437344993353523}}], 
      PolygonBox[{{0.8124999999999998, -5.3247595264191645`}, {
       0.9029428580865544, -5.362222184858401}, {
       0.7697483574637449, -5.437344993353523}, {
       0.8124999999999998, -5.3247595264191645`}}], 
      PolygonBox[{{0.9157074104439358, -5.437499981032941}, {
       0.7697483574637449, -5.437344993353523}, {
       0.9029428580865544, -5.362222184858401}, {
       0.9157074104439358, -5.437499981032941}}], 
      PolygonBox[{{0.9029428580865544, -5.362222184858401}, {1., -5.375}, {
       0.9157074104439358, -5.437499981032941}, {
       0.9029428580865544, -5.362222184858401}}], 
      PolygonBox[{{1.000134841831043, -5.4375}, {
       0.9157074104439358, -5.437499981032941}, {1., -5.375}, {
       1.000134841831043, -5.4375}}], 
      PolygonBox[{{1., -5.375}, {1.0970571419134452`, -5.362222184858401}, {
       1.000134841831043, -5.4375}, {1., -5.375}}], 
      PolygonBox[{{1.0842925895560531`, -5.437499981032941}, {
       1.000134841831043, -5.4375}, {
       1.0970571419134452`, -5.362222184858401}, {
       1.0842925895560531`, -5.437499981032941}}], 
      PolygonBox[{{1.0970571419134452`, -5.362222184858401}, {
       1.1874999999999998`, -5.3247595264191645`}, {
       1.0842925895560531`, -5.437499981032941}, {
       1.0970571419134452`, -5.362222184858401}}], 
      PolygonBox[{{1.2302516425362546`, -5.437344993353523}, {
       1.0842925895560531`, -5.437499981032941}, {
       1.1874999999999998`, -5.3247595264191645`}, {
       1.2302516425362546`, -5.437344993353523}}], 
      PolygonBox[{{1.1874999999999998`, -5.3247595264191645`}, {
       1.2651650429449552`, -5.265165042944956}, {
       1.2302516425362546`, -5.437344993353523}, {
       1.1874999999999998`, -5.3247595264191645`}}], 
      PolygonBox[{{1.4049427443329972`, -5.404942744332997}, {
       1.2302516425362546`, -5.437344993353523}, {
       1.2651650429449552`, -5.265165042944956}, {
       1.4049427443329972`, -5.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, -5.265165042944956}, {
       1.2651650429449552`, -5.265165042944956}, {
       1.4049427443329972`, -5.404942744332997}, {
       1.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{1.4049427443329972`, -5.404942744332997}, {
       1.4049427443329972`, -5.404942744332997}, {
       1.2651650429449552`, -5.265165042944956}, {
       1.4049427443329972`, -5.404942744332997}}], 
      PolygonBox[{{1.4049427443329972`, -5.404942744332997}, {
       1.4373449933535234`, -5.230251642536255}, {1.5, -5.5}, {
       1.4049427443329972`, -5.404942744332997}}], 
      PolygonBox[{{1.5, -5.357662782649368}, {1.5, -5.5}, {
       1.4373449933535234`, -5.230251642536255}, {1.5, -5.357662782649368}}], 
      PolygonBox[{{1.4373449933535234`, -5.230251642536255}, {
       1.4374999810329407`, -5.084292589556062}, {1.5, -5.357662782649368}, {
       1.4373449933535234`, -5.230251642536255}}], 
      PolygonBox[{{1.5, -5.20590900530174}, {1.5, -5.357662782649368}, {
       1.4374999810329407`, -5.084292589556062}, {1.5, -5.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, -5.084292589556062}, {1.4375, -5.}, {
       1.5, -5.20590900530174}, {1.4374999810329407`, -5.084292589556062}}], 
      PolygonBox[{{1.5, -5.}, {1.5, -5.20590900530174}, {1.4375, -5.}, {
       1.5, -5.}}], 
      PolygonBox[{{1.4375, -5.}, {1.4374999810329407`, -4.915707410443939}, {
       1.5, -5.}, {1.4375, -5.}}], 
      PolygonBox[{{1.5, -4.79409099469826}, {1.5, -5.}, {
       1.4374999810329407`, -4.915707410443939}, {1.5, -4.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, -4.915707410443939}, {
       1.4373449933535234`, -4.769748357463745}, {1.5, -4.79409099469826}, {
       1.4374999810329407`, -4.915707410443939}}], 
      PolygonBox[{{1.5, -4.642337217350632}, {1.5, -4.79409099469826}, {
       1.4373449933535234`, -4.769748357463745}, {1.5, -4.642337217350632}}], 
      PolygonBox[{{1.4373449933535234`, -4.769748357463745}, {
       1.4049427443329972`, -4.595057255667003}, {1.5, -4.642337217350632}, {
       1.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{1.491446564961186, -4.508553435038814}, {
       1.5, -4.642337217350632}, {1.4049427443329972`, -4.595057255667003}, {
       1.491446564961186, -4.508553435038814}}], 
      PolygonBox[{{1.4049427443329972`, -4.595057255667003}, {
       1.230251642536255, -4.562655006646477}, {
       1.491446564961186, -4.508553435038814}, {
       1.4049427443329972`, -4.595057255667003}}], 
      PolygonBox[{{1.3576627826493681`, -4.5}, {
       1.491446564961186, -4.508553435038814}, {
       1.230251642536255, -4.562655006646477}, {1.3576627826493681`, -4.5}}], 
      PolygonBox[{{1.230251642536255, -4.562655006646477}, {
       1.0842925895560604`, -4.562500018967059}, {
       1.3576627826493681`, -4.5}, {1.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{1.2059090053732557`, -4.5}, {1.3576627826493681`, -4.5}, {
       1.0842925895560604`, -4.562500018967059}, {
       1.2059090053732557`, -4.5}}], 
      PolygonBox[{{1.0842925895560604`, -4.562500018967059}, {
       1.0001055272204877`, -4.5625}, {1.2059090053732557`, -4.5}, {
       1.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{1.07794195802689, -4.5}, {1.2059090053732557`, -4.5}, {
       1.0001055272204877`, -4.5625}, {1.07794195802689, -4.5}}], 
      PolygonBox[{{1.0001055272204877`, -4.5625}, {
       0.9157074104439431, -4.562500018967059}, {1.07794195802689, -4.5}, {
       1.0001055272204877`, -4.5625}}], 
      PolygonBox[{{0.7940909946955543, -4.5}, {1.07794195802689, -4.5}, {
       0.9157074104439431, -4.562500018967059}, {0.7940909946955543, -4.5}}], 
      PolygonBox[{{0.9157074104439431, -4.562500018967059}, {
       0.7697483574637449, -4.562655006646477}, {0.7940909946955543, -4.5}, {
       0.9157074104439431, -4.562500018967059}}], 
      PolygonBox[{{0.6423372173506338, -4.5}, {0.7940909946955543, -4.5}, {
       0.7697483574637449, -4.562655006646477}, {0.6423372173506338, -4.5}}], 
      PolygonBox[{{0.7697483574637449, -4.562655006646477}, {
       0.5950572556670028, -4.595057255667003}, {0.6423372173506338, -4.5}, {
       0.7697483574637449, -4.562655006646477}}], 
      PolygonBox[{{1.5, -4.5}, {0.6423372173506338, -4.5}, {
       0.5950572556670028, -4.595057255667003}, {1.5, -4.5}}], 
      PolygonBox[{{0.5950572556670028, -4.595057255667003}, {
       0.5626550066464766, -4.769748357463745}, {1.5, -4.5}, {
       0.5950572556670028, -4.595057255667003}}], 
      PolygonBox[{{0.5, -4.642337217350631}, {1.5, -4.5}, {
       0.5626550066464766, -4.769748357463745}, {0.5, -4.642337217350631}}], 
      PolygonBox[{{0.5626550066464766, -4.769748357463745}, {
       0.5625000189670593, -4.915707410443938}, {0.5, -4.642337217350631}, {
       0.5626550066464766, -4.769748357463745}}], 
      PolygonBox[{{0.5, -4.794090994717101}, {0.5, -4.642337217350631}, {
       0.5625000189670593, -4.915707410443938}, {0.5, -4.794090994717101}}], 
      PolygonBox[{{0.5625000189670593, -4.915707410443938}, {
       0.5625, -4.999876821937004}, {0.5, -4.794090994717101}, {
       0.5625000189670593, -4.915707410443938}}], 
      PolygonBox[{{0.5, -4.9193213332412995`}, {0.5, -4.794090994717101}, {
       0.5625, -4.999876821937004}, {0.5, -4.9193213332412995`}}], 
      PolygonBox[{{0.5625, -4.999876821937004}, {
       0.5625000189670593, -5.084292589556055}, {0.5, -4.9193213332412995`}, {
       0.5625, -4.999876821937004}}], 
      PolygonBox[{{0.5, -5.205909005145278}, {0.5, -4.9193213332412995`}, {
       0.5625000189670593, -5.084292589556055}, {0.5, -5.205909005145278}}], 
      PolygonBox[{{0.5625000189670593, -5.084292589556055}, {
       0.5626550066464766, -5.230251642536254}, {0.5, -5.205909005145278}, {
       0.5625000189670593, -5.084292589556055}}], 
      PolygonBox[{{0.5, -5.357662782649365}, {0.5, -5.205909005145278}, {
       0.5626550066464766, -5.230251642536254}, {0.5, -5.357662782649365}}], 
      PolygonBox[{{0.5626550066464766, -5.230251642536254}, {
       0.5950572556670028, -5.404942744332997}, {0.5, -5.357662782649365}, {
       0.5626550066464766, -5.230251642536254}}], 
      PolygonBox[{{0.5, -4.5}, {0.5, -5.357662782649365}, {
       0.5950572556670028, -5.404942744332997}, {0.5, -4.5}}], 
      PolygonBox[{{0.5950572556670028, -5.404942744332997}, {
       0.7697483574637449, -5.437344993353523}, {0.5, -4.5}, {
       0.5950572556670028, -5.404942744332997}}], 
      PolygonBox[{{0.5, -5.5}, {0.5, -4.5}, {
       0.7697483574637449, -5.437344993353523}, {0.5, -5.5}}], 
      PolygonBox[{{0.7697483574637449, -5.437344993353523}, {
       0.9157074104439358, -5.437499981032941}, {0.5, -5.5}, {
       0.7697483574637449, -5.437344993353523}}], 
      PolygonBox[{{0.794090994433172, -5.5}, {0.5, -5.5}, {
       0.9157074104439358, -5.437499981032941}, {0.794090994433172, -5.5}}], 
      PolygonBox[{{0.9157074104439358, -5.437499981032941}, {
       1.000134841831043, -5.4375}, {0.794090994433172, -5.5}, {
       0.9157074104439358, -5.437499981032941}}], 
      PolygonBox[{{1.0823238704010616`, -5.5}, {0.794090994433172, -5.5}, {
       1.000134841831043, -5.4375}, {1.0823238704010616`, -5.5}}], 
      PolygonBox[{{1.000134841831043, -5.4375}, {
       1.0842925895560531`, -5.437499981032941}, {
       1.0823238704010616`, -5.5}, {1.000134841831043, -5.4375}}], 
      PolygonBox[{{1.2059090053603974`, -5.5}, {1.0823238704010616`, -5.5}, {
       1.0842925895560531`, -5.437499981032941}, {
       1.2059090053603974`, -5.5}}], 
      PolygonBox[{{1.0842925895560531`, -5.437499981032941}, {
       1.2302516425362546`, -5.437344993353523}, {
       1.2059090053603974`, -5.5}, {
       1.0842925895560531`, -5.437499981032941}}], 
      PolygonBox[{{1.357662782649371, -5.5}, {1.2059090053603974`, -5.5}, {
       1.2302516425362546`, -5.437344993353523}, {1.357662782649371, -5.5}}], 
      PolygonBox[{{1.2302516425362546`, -5.437344993353523}, {
       1.4049427443329972`, -5.404942744332997}, {1.357662782649371, -5.5}, {
       1.2302516425362546`, -5.437344993353523}}], 
      PolygonBox[{{1.5, -5.5}, {1.357662782649371, -5.5}, {
       1.4049427443329972`, -5.404942744332997}, {1.5, -5.5}}], 
      PolygonBox[{{1.4049427443329972`, -5.404942744332997}, {
       1.4049427443329972`, -5.404942744332997}, {1.5, -5.5}, {
       1.4049427443329972`, -5.404942744332997}}], 
      PolygonBox[{{1.5, -5.5}, {1.5, -5.5}, {
       1.4049427443329972`, -5.404942744332997}, {1.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -4.}, {0.5208333333333333, -4.}, {
       0.5416666666666667, -4.}, {0.5625, -4.}, {0.5833333333333333, -4.}, {
       0.6041666666666666, -4.}, {0.625, -4.}, {0.625, -4.}, {
       0.6041666666666667, -4.}, {0.5833333333333333, -4.}, {0.5625, -4.}, {
       0.5416666666666667, -4.}, {0.5208333333333334, -4.}, {0.5, -4.}, {
       0.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, -4.}, {1.3958333333333333`, -4.}, {
       1.4166666666666667`, -4.}, {1.4375, -4.}, {1.4583333333333333`, -4.}, {
       1.4791666666666665`, -4.}, {1.5, -4.}, {1.5, -4.}, {
       1.4791666666666667`, -4.}, {1.4583333333333333`, -4.}, {1.4375, -4.}, {
       1.4166666666666667`, -4.}, {1.3958333333333335`, -4.}, {1.375, -4.}, {
       1.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -4.5}, {1., -4.479166666666667}, {
       1., -4.458333333333333}, {1., -4.4375}, {1., -4.416666666666667}, {
       1., -4.395833333333333}, {1., -4.375}, {1., -4.375}, {
       1., -4.395833333333333}, {1., -4.416666666666667}, {1., -4.4375}, {
       1., -4.458333333333333}, {1., -4.479166666666667}, {1., -4.5}, {
       1., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -3.625}, {1., -3.6041666666666665`}, {
       1., -3.5833333333333335`}, {1., -3.5625}, {1., -3.5416666666666665`}, {
       1., -3.5208333333333335`}, {1., -3.5}, {1., -3.5}, {
       1., -3.5208333333333335`}, {1., -3.5416666666666665`}, {1., -3.5625}, {
       1., -3.5833333333333335`}, {1., -3.6041666666666665`}, {1., -3.625}, {
       1., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, -4.}, {0.75, -4.}, {0.875, -4.}, {1., -4.}, {
       1.125, -4.}, {1.25, -4.}, {1.375, -4.}, {1.375, -4.}, {1.25, -4.}, {
       1.125, -4.}, {1., -4.}, {0.875, -4.}, {0.75, -4.}, {0.625, -4.}, {
       0.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -4.375}, {1., -4.25}, {1., -4.125}, {1., -4.}, {
       1., -3.875}, {1., -3.75}, {1., -3.625}, {1., -3.625}, {1., -3.75}, {
       1., -3.875}, {1., -4.}, {1., -4.125}, {1., -4.25}, {1., -4.375}, {
       1., -4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CG0wIEri2NrV57+ar9R+q2UlSX/gYS+Cdzm
Rl8h8g18B8xum2+WtftinyqUovbxAe8BiL7P9hd2mFc9SeM9MO+E6qnu3o/2
YnqBjtpSMPkPUPN5DxzN25L94skbuDwjWPwVXP8UzwkzjzQ/h5vv8Pjei4mz
n8Ltj9jhwro24wncfRBzn8DdD5NXL+r8lJQsgKr/gMCBSVDzz347m9POL3jg
338QeGk/Q/nJoV4fwQOHoO77mhEe/6pI8ABY+v97qP2CB+ZC/Ycq/wmuHxY+
56Dmo4TfAUT4akDdhx7+AE4IqLU=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CE0z4GwUBD4CuevXgUCn+B8CP0BTf4Vmv6n
aOofEOSDtYXywvkQc/nQ1AugyQug6RdEUy+EwQ9FcZ/QgVUo7oep/4Am/wlN
/1c09T8I8lHd9wPN/T/Q/PcDzf8/7MNQwgcRXwAtO2kR
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, -4.265165042944956}, {
       1.3247595264191645`, -4.1875}, {
       1.4049427443329972`, -4.404942744332997}, {
       1.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{1.4373449933535234`, -4.230251642536255}, {
       1.4049427443329972`, -4.404942744332997}, {
       1.3247595264191645`, -4.1875}, {
       1.4373449933535234`, -4.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, -4.1875}, {
       1.3622221848584006`, -4.097057141913445}, {
       1.4373449933535234`, -4.230251642536255}, {
       1.3247595264191645`, -4.1875}}], 
      PolygonBox[{{1.4374999810329407`, -4.084292589556062}, {
       1.4373449933535234`, -4.230251642536255}, {
       1.3622221848584006`, -4.097057141913445}, {
       1.4374999810329407`, -4.084292589556062}}], 
      PolygonBox[{{1.3622221848584006`, -4.097057141913445}, {1.375, -4.}, {
       1.4374999810329407`, -4.084292589556062}, {
       1.3622221848584006`, -4.097057141913445}}], 
      PolygonBox[{{1.4375, -4.}, {1.4374999810329407`, -4.084292589556062}, {
       1.375, -4.}, {1.4375, -4.}}], 
      PolygonBox[{{1.375, -4.}, {1.3622221848584006`, -3.9029428580865546`}, {
       1.4375, -4.}, {1.375, -4.}}], 
      PolygonBox[{{1.4374999810329407`, -3.915707410443938}, {1.4375, -4.}, {
       1.3622221848584006`, -3.9029428580865546`}, {
       1.4374999810329407`, -3.915707410443938}}], 
      PolygonBox[{{1.3622221848584006`, -3.9029428580865546`}, {
       1.3247595264191645`, -3.8125}, {
       1.4374999810329407`, -3.915707410443938}, {
       1.3622221848584006`, -3.9029428580865546`}}], 
      PolygonBox[{{1.4373449933535234`, -3.769748357463745}, {
       1.4374999810329407`, -3.915707410443938}, {
       1.3247595264191645`, -3.8125}, {
       1.4373449933535234`, -3.769748357463745}}], 
      PolygonBox[{{1.3247595264191645`, -3.8125}, {
       1.2651650429449552`, -3.7348349570550448`}, {
       1.4373449933535234`, -3.769748357463745}, {
       1.3247595264191645`, -3.8125}}], 
      PolygonBox[{{1.4049427443329972`, -3.595057255667003}, {
       1.4373449933535234`, -3.769748357463745}, {
       1.2651650429449552`, -3.7348349570550448`}, {
       1.4049427443329972`, -3.595057255667003}}], 
      PolygonBox[{{1.2651650429449552`, -3.7348349570550448`}, {
       1.1875, -3.6752404735808355`}, {
       1.4049427443329972`, -3.595057255667003}, {
       1.2651650429449552`, -3.7348349570550448`}}], 
      PolygonBox[{{1.230251642536255, -3.5626550066464766`}, {
       1.4049427443329972`, -3.595057255667003}, {
       1.1875, -3.6752404735808355`}, {
       1.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{1.1875, -3.6752404735808355`}, {
       1.0970571419134454`, -3.6377778151415994`}, {
       1.230251642536255, -3.5626550066464766`}, {
       1.1875, -3.6752404735808355`}}], 
      PolygonBox[{{1.0842925895560604`, -3.562500018967059}, {
       1.230251642536255, -3.5626550066464766`}, {
       1.0970571419134454`, -3.6377778151415994`}, {
       1.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{1.0970571419134454`, -3.6377778151415994`}, {1., -3.625}, {
       1.0842925895560604`, -3.562500018967059}, {
       1.0970571419134454`, -3.6377778151415994`}}], 
      PolygonBox[{{1.0001055272204877`, -3.5625}, {
       1.0842925895560604`, -3.562500018967059}, {1., -3.625}, {
       1.0001055272204877`, -3.5625}}], 
      PolygonBox[{{1., -3.625}, {0.9029428580865548, -3.6377778151415994`}, {
       1.0001055272204877`, -3.5625}, {1., -3.625}}], 
      PolygonBox[{{0.9157074104439431, -3.562500018967059}, {
       1.0001055272204877`, -3.5625}, {
       0.9029428580865548, -3.6377778151415994`}, {
       0.9157074104439431, -3.562500018967059}}], 
      PolygonBox[{{0.9029428580865548, -3.6377778151415994`}, {
       0.8125000000000001, -3.6752404735808355`}, {
       0.9157074104439431, -3.562500018967059}, {
       0.9029428580865548, -3.6377778151415994`}}], 
      PolygonBox[{{0.7697483574637449, -3.5626550066464766`}, {
       0.9157074104439431, -3.562500018967059}, {
       0.8125000000000001, -3.6752404735808355`}, {
       0.7697483574637449, -3.5626550066464766`}}], 
      PolygonBox[{{0.8125000000000001, -3.6752404735808355`}, {
       0.7348349570550448, -3.7348349570550448`}, {
       0.7697483574637449, -3.5626550066464766`}, {
       0.8125000000000001, -3.6752404735808355`}}], 
      PolygonBox[{{0.5950572556670028, -3.595057255667003}, {
       0.7697483574637449, -3.5626550066464766`}, {
       0.7348349570550448, -3.7348349570550448`}, {
       0.5950572556670028, -3.595057255667003}}], 
      PolygonBox[{{0.7348349570550448, -3.7348349570550448`}, {
       0.6752404735808355, -3.8125}, {
       0.5950572556670028, -3.595057255667003}, {
       0.7348349570550448, -3.7348349570550448`}}], 
      PolygonBox[{{0.5626550066464766, -3.7697483574637447`}, {
       0.5950572556670028, -3.595057255667003}, {
       0.6752404735808355, -3.8125}, {
       0.5626550066464766, -3.7697483574637447`}}], 
      PolygonBox[{{0.6752404735808355, -3.8125}, {
       0.6377778151415994, -3.9029428580865546`}, {
       0.5626550066464766, -3.7697483574637447`}, {
       0.6752404735808355, -3.8125}}], 
      PolygonBox[{{0.5625000189670593, -3.9157074104439378`}, {
       0.5626550066464766, -3.7697483574637447`}, {
       0.6377778151415994, -3.9029428580865546`}, {
       0.5625000189670593, -3.9157074104439378`}}], 
      PolygonBox[{{0.6377778151415994, -3.9029428580865546`}, {0.625, -4.}, {
       0.5625000189670593, -3.9157074104439378`}, {
       0.6377778151415994, -3.9029428580865546`}}], 
      PolygonBox[{{0.5625, -3.9998768219370047`}, {
       0.5625000189670593, -3.9157074104439378`}, {0.625, -4.}, {
       0.5625, -3.9998768219370047`}}], 
      PolygonBox[{{0.625, -4.}, {0.6377778151415994, -4.097057141913445}, {
       0.5625, -3.9998768219370047`}, {0.625, -4.}}], 
      PolygonBox[{{0.5625000189670593, -4.084292589556055}, {
       0.5625, -3.9998768219370047`}, {
       0.6377778151415994, -4.097057141913445}, {
       0.5625000189670593, -4.084292589556055}}], 
      PolygonBox[{{0.6377778151415994, -4.097057141913445}, {
       0.6752404735808354, -4.1875}, {
       0.5625000189670593, -4.084292589556055}, {
       0.6377778151415994, -4.097057141913445}}], 
      PolygonBox[{{0.5626550066464766, -4.230251642536254}, {
       0.5625000189670593, -4.084292589556055}, {
       0.6752404735808354, -4.1875}, {
       0.5626550066464766, -4.230251642536254}}], 
      PolygonBox[{{0.6752404735808354, -4.1875}, {
       0.7348349570550446, -4.265165042944956}, {
       0.5626550066464766, -4.230251642536254}, {
       0.6752404735808354, -4.1875}}], 
      PolygonBox[{{0.5950572556670028, -4.404942744332997}, {
       0.5626550066464766, -4.230251642536254}, {
       0.7348349570550446, -4.265165042944956}, {
       0.5950572556670028, -4.404942744332997}}], 
      PolygonBox[{{0.7348349570550446, -4.265165042944956}, {
       0.8124999999999998, -4.3247595264191645`}, {
       0.5950572556670028, -4.404942744332997}, {
       0.7348349570550446, -4.265165042944956}}], 
      PolygonBox[{{0.7697483574637449, -4.437344993353523}, {
       0.5950572556670028, -4.404942744332997}, {
       0.8124999999999998, -4.3247595264191645`}, {
       0.7697483574637449, -4.437344993353523}}], 
      PolygonBox[{{0.8124999999999998, -4.3247595264191645`}, {
       0.9029428580865544, -4.362222184858401}, {
       0.7697483574637449, -4.437344993353523}, {
       0.8124999999999998, -4.3247595264191645`}}], 
      PolygonBox[{{0.9157074104439358, -4.437499981032941}, {
       0.7697483574637449, -4.437344993353523}, {
       0.9029428580865544, -4.362222184858401}, {
       0.9157074104439358, -4.437499981032941}}], 
      PolygonBox[{{0.9029428580865544, -4.362222184858401}, {1., -4.375}, {
       0.9157074104439358, -4.437499981032941}, {
       0.9029428580865544, -4.362222184858401}}], 
      PolygonBox[{{1.000134841831043, -4.4375}, {
       0.9157074104439358, -4.437499981032941}, {1., -4.375}, {
       1.000134841831043, -4.4375}}], 
      PolygonBox[{{1., -4.375}, {1.0970571419134452`, -4.362222184858401}, {
       1.000134841831043, -4.4375}, {1., -4.375}}], 
      PolygonBox[{{1.0842925895560531`, -4.437499981032941}, {
       1.000134841831043, -4.4375}, {
       1.0970571419134452`, -4.362222184858401}, {
       1.0842925895560531`, -4.437499981032941}}], 
      PolygonBox[{{1.0970571419134452`, -4.362222184858401}, {
       1.1874999999999998`, -4.3247595264191645`}, {
       1.0842925895560531`, -4.437499981032941}, {
       1.0970571419134452`, -4.362222184858401}}], 
      PolygonBox[{{1.2302516425362546`, -4.437344993353523}, {
       1.0842925895560531`, -4.437499981032941}, {
       1.1874999999999998`, -4.3247595264191645`}, {
       1.2302516425362546`, -4.437344993353523}}], 
      PolygonBox[{{1.1874999999999998`, -4.3247595264191645`}, {
       1.2651650429449552`, -4.265165042944956}, {
       1.2302516425362546`, -4.437344993353523}, {
       1.1874999999999998`, -4.3247595264191645`}}], 
      PolygonBox[{{1.4049427443329972`, -4.404942744332997}, {
       1.2302516425362546`, -4.437344993353523}, {
       1.2651650429449552`, -4.265165042944956}, {
       1.4049427443329972`, -4.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, -4.265165042944956}, {
       1.2651650429449552`, -4.265165042944956}, {
       1.4049427443329972`, -4.404942744332997}, {
       1.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{1.4049427443329972`, -4.404942744332997}, {
       1.4049427443329972`, -4.404942744332997}, {
       1.2651650429449552`, -4.265165042944956}, {
       1.4049427443329972`, -4.404942744332997}}], 
      PolygonBox[{{1.4049427443329972`, -4.404942744332997}, {
       1.4373449933535234`, -4.230251642536255}, {1.5, -4.5}, {
       1.4049427443329972`, -4.404942744332997}}], 
      PolygonBox[{{1.5, -4.357662782649368}, {1.5, -4.5}, {
       1.4373449933535234`, -4.230251642536255}, {1.5, -4.357662782649368}}], 
      PolygonBox[{{1.4373449933535234`, -4.230251642536255}, {
       1.4374999810329407`, -4.084292589556062}, {1.5, -4.357662782649368}, {
       1.4373449933535234`, -4.230251642536255}}], 
      PolygonBox[{{1.5, -4.20590900530174}, {1.5, -4.357662782649368}, {
       1.4374999810329407`, -4.084292589556062}, {1.5, -4.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, -4.084292589556062}, {1.4375, -4.}, {
       1.5, -4.20590900530174}, {1.4374999810329407`, -4.084292589556062}}], 
      PolygonBox[{{1.5, -4.}, {1.5, -4.20590900530174}, {1.4375, -4.}, {
       1.5, -4.}}], 
      PolygonBox[{{1.4375, -4.}, {1.4374999810329407`, -3.915707410443938}, {
       1.5, -4.}, {1.4375, -4.}}], 
      PolygonBox[{{1.5, -3.79409099469826}, {1.5, -4.}, {
       1.4374999810329407`, -3.915707410443938}, {1.5, -3.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, -3.915707410443938}, {
       1.4373449933535234`, -3.769748357463745}, {1.5, -3.79409099469826}, {
       1.4374999810329407`, -3.915707410443938}}], 
      PolygonBox[{{1.5, -3.6423372173506325`}, {1.5, -3.79409099469826}, {
       1.4373449933535234`, -3.769748357463745}, {
       1.5, -3.6423372173506325`}}], 
      PolygonBox[{{1.4373449933535234`, -3.769748357463745}, {
       1.4049427443329972`, -3.595057255667003}, {
       1.5, -3.6423372173506325`}, {
       1.4373449933535234`, -3.769748357463745}}], 
      PolygonBox[{{1.491446564961186, -3.508553435038814}, {
       1.5, -3.6423372173506325`}, {
       1.4049427443329972`, -3.595057255667003}, {
       1.491446564961186, -3.508553435038814}}], 
      PolygonBox[{{1.4049427443329972`, -3.595057255667003}, {
       1.230251642536255, -3.5626550066464766`}, {
       1.491446564961186, -3.508553435038814}, {
       1.4049427443329972`, -3.595057255667003}}], 
      PolygonBox[{{1.3576627826493681`, -3.5}, {
       1.491446564961186, -3.508553435038814}, {
       1.230251642536255, -3.5626550066464766`}, {
       1.3576627826493681`, -3.5}}], 
      PolygonBox[{{1.230251642536255, -3.5626550066464766`}, {
       1.0842925895560604`, -3.562500018967059}, {
       1.3576627826493681`, -3.5}, {
       1.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{1.2059090053732557`, -3.5}, {1.3576627826493681`, -3.5}, {
       1.0842925895560604`, -3.562500018967059}, {
       1.2059090053732557`, -3.5}}], 
      PolygonBox[{{1.0842925895560604`, -3.562500018967059}, {
       1.0001055272204877`, -3.5625}, {1.2059090053732557`, -3.5}, {
       1.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{1.07794195802689, -3.5}, {1.2059090053732557`, -3.5}, {
       1.0001055272204877`, -3.5625}, {1.07794195802689, -3.5}}], 
      PolygonBox[{{1.0001055272204877`, -3.5625}, {
       0.9157074104439431, -3.562500018967059}, {1.07794195802689, -3.5}, {
       1.0001055272204877`, -3.5625}}], 
      PolygonBox[{{0.7940909946955543, -3.5}, {1.07794195802689, -3.5}, {
       0.9157074104439431, -3.562500018967059}, {0.7940909946955543, -3.5}}], 
      PolygonBox[{{0.9157074104439431, -3.562500018967059}, {
       0.7697483574637449, -3.5626550066464766`}, {
       0.7940909946955543, -3.5}, {0.9157074104439431, -3.562500018967059}}], 
      PolygonBox[{{0.6423372173506338, -3.5}, {0.7940909946955543, -3.5}, {
       0.7697483574637449, -3.5626550066464766`}, {
       0.6423372173506338, -3.5}}], 
      PolygonBox[{{0.7697483574637449, -3.5626550066464766`}, {
       0.5950572556670028, -3.595057255667003}, {0.6423372173506338, -3.5}, {
       0.7697483574637449, -3.5626550066464766`}}], 
      PolygonBox[{{1.5, -3.5}, {0.6423372173506338, -3.5}, {
       0.5950572556670028, -3.595057255667003}, {1.5, -3.5}}], 
      PolygonBox[{{0.5950572556670028, -3.595057255667003}, {
       0.5626550066464766, -3.7697483574637447`}, {1.5, -3.5}, {
       0.5950572556670028, -3.595057255667003}}], 
      PolygonBox[{{0.5, -3.642337217350631}, {1.5, -3.5}, {
       0.5626550066464766, -3.7697483574637447`}, {0.5, -3.642337217350631}}],
       PolygonBox[{{0.5626550066464766, -3.7697483574637447`}, {
       0.5625000189670593, -3.9157074104439378`}, {0.5, -3.642337217350631}, {
       0.5626550066464766, -3.7697483574637447`}}], 
      PolygonBox[{{0.5, -3.794090994717101}, {0.5, -3.642337217350631}, {
       0.5625000189670593, -3.9157074104439378`}, {0.5, -3.794090994717101}}],
       PolygonBox[{{0.5625000189670593, -3.9157074104439378`}, {
       0.5625, -3.9998768219370047`}, {0.5, -3.794090994717101}, {
       0.5625000189670593, -3.9157074104439378`}}], 
      PolygonBox[{{0.5, -3.9193213332413}, {0.5, -3.794090994717101}, {
       0.5625, -3.9998768219370047`}, {0.5, -3.9193213332413}}], 
      PolygonBox[{{0.5625, -3.9998768219370047`}, {
       0.5625000189670593, -4.084292589556055}, {0.5, -3.9193213332413}, {
       0.5625, -3.9998768219370047`}}], 
      PolygonBox[{{0.5, -4.205909005145278}, {0.5, -3.9193213332413}, {
       0.5625000189670593, -4.084292589556055}, {0.5, -4.205909005145278}}], 
      PolygonBox[{{0.5625000189670593, -4.084292589556055}, {
       0.5626550066464766, -4.230251642536254}, {0.5, -4.205909005145278}, {
       0.5625000189670593, -4.084292589556055}}], 
      PolygonBox[{{0.5, -4.357662782649365}, {0.5, -4.205909005145278}, {
       0.5626550066464766, -4.230251642536254}, {0.5, -4.357662782649365}}], 
      PolygonBox[{{0.5626550066464766, -4.230251642536254}, {
       0.5950572556670028, -4.404942744332997}, {0.5, -4.357662782649365}, {
       0.5626550066464766, -4.230251642536254}}], 
      PolygonBox[{{0.5, -3.5}, {0.5, -4.357662782649365}, {
       0.5950572556670028, -4.404942744332997}, {0.5, -3.5}}], 
      PolygonBox[{{0.5950572556670028, -4.404942744332997}, {
       0.7697483574637449, -4.437344993353523}, {0.5, -3.5}, {
       0.5950572556670028, -4.404942744332997}}], 
      PolygonBox[{{0.5, -4.5}, {0.5, -3.5}, {
       0.7697483574637449, -4.437344993353523}, {0.5, -4.5}}], 
      PolygonBox[{{0.7697483574637449, -4.437344993353523}, {
       0.9157074104439358, -4.437499981032941}, {0.5, -4.5}, {
       0.7697483574637449, -4.437344993353523}}], 
      PolygonBox[{{0.794090994433172, -4.5}, {0.5, -4.5}, {
       0.9157074104439358, -4.437499981032941}, {0.794090994433172, -4.5}}], 
      PolygonBox[{{0.9157074104439358, -4.437499981032941}, {
       1.000134841831043, -4.4375}, {0.794090994433172, -4.5}, {
       0.9157074104439358, -4.437499981032941}}], 
      PolygonBox[{{1.0823238704010616`, -4.5}, {0.794090994433172, -4.5}, {
       1.000134841831043, -4.4375}, {1.0823238704010616`, -4.5}}], 
      PolygonBox[{{1.000134841831043, -4.4375}, {
       1.0842925895560531`, -4.437499981032941}, {
       1.0823238704010616`, -4.5}, {1.000134841831043, -4.4375}}], 
      PolygonBox[{{1.2059090053603974`, -4.5}, {1.0823238704010616`, -4.5}, {
       1.0842925895560531`, -4.437499981032941}, {
       1.2059090053603974`, -4.5}}], 
      PolygonBox[{{1.0842925895560531`, -4.437499981032941}, {
       1.2302516425362546`, -4.437344993353523}, {
       1.2059090053603974`, -4.5}, {
       1.0842925895560531`, -4.437499981032941}}], 
      PolygonBox[{{1.357662782649371, -4.5}, {1.2059090053603974`, -4.5}, {
       1.2302516425362546`, -4.437344993353523}, {1.357662782649371, -4.5}}], 
      PolygonBox[{{1.2302516425362546`, -4.437344993353523}, {
       1.4049427443329972`, -4.404942744332997}, {1.357662782649371, -4.5}, {
       1.2302516425362546`, -4.437344993353523}}], 
      PolygonBox[{{1.5, -4.5}, {1.357662782649371, -4.5}, {
       1.4049427443329972`, -4.404942744332997}, {1.5, -4.5}}], 
      PolygonBox[{{1.4049427443329972`, -4.404942744332997}, {
       1.4049427443329972`, -4.404942744332997}, {1.5, -4.5}, {
       1.4049427443329972`, -4.404942744332997}}], 
      PolygonBox[{{1.5, -4.5}, {1.5, -4.5}, {
       1.4049427443329972`, -4.404942744332997}, {1.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -3.}, {0.5208333333333333, -3.}, {
       0.5416666666666667, -3.}, {0.5625, -3.}, {0.5833333333333333, -3.}, {
       0.6041666666666666, -3.}, {0.625, -3.}, {0.625, -3.}, {
       0.6041666666666667, -3.}, {0.5833333333333333, -3.}, {0.5625, -3.}, {
       0.5416666666666667, -3.}, {0.5208333333333334, -3.}, {0.5, -3.}, {
       0.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, -3.}, {1.3958333333333333`, -3.}, {
       1.4166666666666667`, -3.}, {1.4375, -3.}, {1.4583333333333333`, -3.}, {
       1.4791666666666665`, -3.}, {1.5, -3.}, {1.5, -3.}, {
       1.4791666666666667`, -3.}, {1.4583333333333333`, -3.}, {1.4375, -3.}, {
       1.4166666666666667`, -3.}, {1.3958333333333335`, -3.}, {1.375, -3.}, {
       1.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -3.5}, {1., -3.4791666666666665`}, {
       1., -3.4583333333333335`}, {1., -3.4375}, {1., -3.4166666666666665`}, {
       1., -3.3958333333333335`}, {1., -3.375}, {1., -3.375}, {
       1., -3.3958333333333335`}, {1., -3.4166666666666665`}, {1., -3.4375}, {
       1., -3.4583333333333335`}, {1., -3.4791666666666665`}, {1., -3.5}, {
       1., -3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -2.625}, {1., -2.6041666666666665`}, {
       1., -2.5833333333333335`}, {1., -2.5625}, {1., -2.5416666666666665`}, {
       1., -2.5208333333333335`}, {1., -2.5}, {1., -2.5}, {
       1., -2.5208333333333335`}, {1., -2.5416666666666665`}, {1., -2.5625}, {
       1., -2.5833333333333335`}, {1., -2.6041666666666665`}, {1., -2.625}, {
       1., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, -3.}, {0.75, -3.}, {0.875, -3.}, {1., -3.}, {
       1.125, -3.}, {1.25, -3.}, {1.375, -3.}, {1.375, -3.}, {1.25, -3.}, {
       1.125, -3.}, {1., -3.}, {0.875, -3.}, {0.75, -3.}, {0.625, -3.}, {
       0.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -3.375}, {1., -3.25}, {1., -3.125}, {1., -3.}, {
       1., -2.875}, {1., -2.75}, {1., -2.625}, {1., -2.625}, {1., -2.75}, {
       1., -2.875}, {1., -3.}, {1., -3.125}, {1., -3.25}, {1., -3.375}, {
       1., -3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CE0x4Eri2NrV57+ar9R+q2UlSX7gYS+Cdzm
Rl8h8g1sB8xum2+WtftinyqUovbxAesBiL7P9hd2mFc9SWM9MO+E6qnu3o/2
YnqBjtpSMPkPUPNZDxzN25L94skbuDwjWPwVXP8UzwkzjzQ/h5vv8Pjei4mz
n8Ltj9jhwro24wncfRBzn8DdD5P3eyL09OgxDjT9nAcmQc2f/Xb2TT55rgP/
/oPAS3sD9xOt0jO5DhyCuu/VxXX7rjzlOgCW/v8eaj73gblQ/6HKf4Lrh4UP
zHzU8OOEh68/1H3o4Q8AN5apOA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CE0y4GwUBD4CuevXgUCn+B8CP0BTf4Vmv6n
aOofEOSDtYWywvkQc9nQ1HOgqeeE88HKV3GhqefB4IeiuI/nwCoU98PUf0CT
/4Sm/yua+h8E+atR3PcDzf0/0Pz3A83/P+zDUMIHEV8Ae2BoRg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, -3.2651650429449552`}, {
       1.3247595264191645`, -3.1875}, {
       1.4049427443329972`, -3.404942744332997}, {
       1.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{1.4373449933535234`, -3.2302516425362553`}, {
       1.4049427443329972`, -3.404942744332997}, {
       1.3247595264191645`, -3.1875}, {
       1.4373449933535234`, -3.2302516425362553`}}], 
      PolygonBox[{{1.3247595264191645`, -3.1875}, {
       1.3622221848584006`, -3.0970571419134454`}, {
       1.4373449933535234`, -3.2302516425362553`}, {
       1.3247595264191645`, -3.1875}}], 
      PolygonBox[{{1.4374999810329407`, -3.084292589556062}, {
       1.4373449933535234`, -3.2302516425362553`}, {
       1.3622221848584006`, -3.0970571419134454`}, {
       1.4374999810329407`, -3.084292589556062}}], 
      PolygonBox[{{1.3622221848584006`, -3.0970571419134454`}, {1.375, -3.}, {
       1.4374999810329407`, -3.084292589556062}, {
       1.3622221848584006`, -3.0970571419134454`}}], 
      PolygonBox[{{1.4375, -3.}, {1.4374999810329407`, -3.084292589556062}, {
       1.375, -3.}, {1.4375, -3.}}], 
      PolygonBox[{{1.375, -3.}, {1.3622221848584006`, -2.9029428580865546`}, {
       1.4375, -3.}, {1.375, -3.}}], 
      PolygonBox[{{1.4374999810329407`, -2.915707410443938}, {1.4375, -3.}, {
       1.3622221848584006`, -2.9029428580865546`}, {
       1.4374999810329407`, -2.915707410443938}}], 
      PolygonBox[{{1.3622221848584006`, -2.9029428580865546`}, {
       1.3247595264191645`, -2.8125}, {
       1.4374999810329407`, -2.915707410443938}, {
       1.3622221848584006`, -2.9029428580865546`}}], 
      PolygonBox[{{1.4373449933535234`, -2.769748357463745}, {
       1.4374999810329407`, -2.915707410443938}, {
       1.3247595264191645`, -2.8125}, {
       1.4373449933535234`, -2.769748357463745}}], 
      PolygonBox[{{1.3247595264191645`, -2.8125}, {
       1.2651650429449552`, -2.7348349570550448`}, {
       1.4373449933535234`, -2.769748357463745}, {
       1.3247595264191645`, -2.8125}}], 
      PolygonBox[{{1.4049427443329972`, -2.595057255667003}, {
       1.4373449933535234`, -2.769748357463745}, {
       1.2651650429449552`, -2.7348349570550448`}, {
       1.4049427443329972`, -2.595057255667003}}], 
      PolygonBox[{{1.2651650429449552`, -2.7348349570550448`}, {
       1.1875, -2.6752404735808355`}, {
       1.4049427443329972`, -2.595057255667003}, {
       1.2651650429449552`, -2.7348349570550448`}}], 
      PolygonBox[{{1.230251642536255, -2.5626550066464766`}, {
       1.4049427443329972`, -2.595057255667003}, {
       1.1875, -2.6752404735808355`}, {
       1.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{1.1875, -2.6752404735808355`}, {
       1.0970571419134454`, -2.6377778151415994`}, {
       1.230251642536255, -2.5626550066464766`}, {
       1.1875, -2.6752404735808355`}}], 
      PolygonBox[{{1.0842925895560604`, -2.562500018967059}, {
       1.230251642536255, -2.5626550066464766`}, {
       1.0970571419134454`, -2.6377778151415994`}, {
       1.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{1.0970571419134454`, -2.6377778151415994`}, {1., -2.625}, {
       1.0842925895560604`, -2.562500018967059}, {
       1.0970571419134454`, -2.6377778151415994`}}], 
      PolygonBox[{{1.0001055272204877`, -2.5625}, {
       1.0842925895560604`, -2.562500018967059}, {1., -2.625}, {
       1.0001055272204877`, -2.5625}}], 
      PolygonBox[{{1., -2.625}, {0.9029428580865548, -2.6377778151415994`}, {
       1.0001055272204877`, -2.5625}, {1., -2.625}}], 
      PolygonBox[{{0.9157074104439431, -2.562500018967059}, {
       1.0001055272204877`, -2.5625}, {
       0.9029428580865548, -2.6377778151415994`}, {
       0.9157074104439431, -2.562500018967059}}], 
      PolygonBox[{{0.9029428580865548, -2.6377778151415994`}, {
       0.8125000000000001, -2.6752404735808355`}, {
       0.9157074104439431, -2.562500018967059}, {
       0.9029428580865548, -2.6377778151415994`}}], 
      PolygonBox[{{0.7697483574637449, -2.5626550066464766`}, {
       0.9157074104439431, -2.562500018967059}, {
       0.8125000000000001, -2.6752404735808355`}, {
       0.7697483574637449, -2.5626550066464766`}}], 
      PolygonBox[{{0.8125000000000001, -2.6752404735808355`}, {
       0.7348349570550448, -2.7348349570550448`}, {
       0.7697483574637449, -2.5626550066464766`}, {
       0.8125000000000001, -2.6752404735808355`}}], 
      PolygonBox[{{0.5950572556670028, -2.595057255667003}, {
       0.7697483574637449, -2.5626550066464766`}, {
       0.7348349570550448, -2.7348349570550448`}, {
       0.5950572556670028, -2.595057255667003}}], 
      PolygonBox[{{0.7348349570550448, -2.7348349570550448`}, {
       0.6752404735808355, -2.8125}, {
       0.5950572556670028, -2.595057255667003}, {
       0.7348349570550448, -2.7348349570550448`}}], 
      PolygonBox[{{0.5626550066464766, -2.7697483574637447`}, {
       0.5950572556670028, -2.595057255667003}, {
       0.6752404735808355, -2.8125}, {
       0.5626550066464766, -2.7697483574637447`}}], 
      PolygonBox[{{0.6752404735808355, -2.8125}, {
       0.6377778151415994, -2.9029428580865546`}, {
       0.5626550066464766, -2.7697483574637447`}, {
       0.6752404735808355, -2.8125}}], 
      PolygonBox[{{0.5625000189670593, -2.9157074104439378`}, {
       0.5626550066464766, -2.7697483574637447`}, {
       0.6377778151415994, -2.9029428580865546`}, {
       0.5625000189670593, -2.9157074104439378`}}], 
      PolygonBox[{{0.6377778151415994, -2.9029428580865546`}, {0.625, -3.}, {
       0.5625000189670593, -2.9157074104439378`}, {
       0.6377778151415994, -2.9029428580865546`}}], 
      PolygonBox[{{0.5625, -2.9998768219370047`}, {
       0.5625000189670593, -2.9157074104439378`}, {0.625, -3.}, {
       0.5625, -2.9998768219370047`}}], 
      PolygonBox[{{0.625, -3.}, {0.6377778151415994, -3.097057141913445}, {
       0.5625, -2.9998768219370047`}, {0.625, -3.}}], 
      PolygonBox[{{0.5625000189670593, -3.084292589556055}, {
       0.5625, -2.9998768219370047`}, {
       0.6377778151415994, -3.097057141913445}, {
       0.5625000189670593, -3.084292589556055}}], 
      PolygonBox[{{0.6377778151415994, -3.097057141913445}, {
       0.6752404735808354, -3.1875}, {
       0.5625000189670593, -3.084292589556055}, {
       0.6377778151415994, -3.097057141913445}}], 
      PolygonBox[{{0.5626550066464766, -3.230251642536255}, {
       0.5625000189670593, -3.084292589556055}, {
       0.6752404735808354, -3.1875}, {
       0.5626550066464766, -3.230251642536255}}], 
      PolygonBox[{{0.6752404735808354, -3.1875}, {
       0.7348349570550446, -3.2651650429449552`}, {
       0.5626550066464766, -3.230251642536255}, {
       0.6752404735808354, -3.1875}}], 
      PolygonBox[{{0.5950572556670028, -3.404942744332997}, {
       0.5626550066464766, -3.230251642536255}, {
       0.7348349570550446, -3.2651650429449552`}, {
       0.5950572556670028, -3.404942744332997}}], 
      PolygonBox[{{0.7348349570550446, -3.2651650429449552`}, {
       0.8124999999999998, -3.3247595264191645`}, {
       0.5950572556670028, -3.404942744332997}, {
       0.7348349570550446, -3.2651650429449552`}}], 
      PolygonBox[{{0.7697483574637449, -3.4373449933535234`}, {
       0.5950572556670028, -3.404942744332997}, {
       0.8124999999999998, -3.3247595264191645`}, {
       0.7697483574637449, -3.4373449933535234`}}], 
      PolygonBox[{{0.8124999999999998, -3.3247595264191645`}, {
       0.9029428580865544, -3.3622221848584006`}, {
       0.7697483574637449, -3.4373449933535234`}, {
       0.8124999999999998, -3.3247595264191645`}}], 
      PolygonBox[{{0.9157074104439358, -3.437499981032941}, {
       0.7697483574637449, -3.4373449933535234`}, {
       0.9029428580865544, -3.3622221848584006`}, {
       0.9157074104439358, -3.437499981032941}}], 
      PolygonBox[{{0.9029428580865544, -3.3622221848584006`}, {1., -3.375}, {
       0.9157074104439358, -3.437499981032941}, {
       0.9029428580865544, -3.3622221848584006`}}], 
      PolygonBox[{{1.000134841831043, -3.4375}, {
       0.9157074104439358, -3.437499981032941}, {1., -3.375}, {
       1.000134841831043, -3.4375}}], 
      PolygonBox[{{1., -3.375}, {1.0970571419134452`, -3.3622221848584006`}, {
       1.000134841831043, -3.4375}, {1., -3.375}}], 
      PolygonBox[{{1.0842925895560531`, -3.437499981032941}, {
       1.000134841831043, -3.4375}, {
       1.0970571419134452`, -3.3622221848584006`}, {
       1.0842925895560531`, -3.437499981032941}}], 
      PolygonBox[{{1.0970571419134452`, -3.3622221848584006`}, {
       1.1874999999999998`, -3.3247595264191645`}, {
       1.0842925895560531`, -3.437499981032941}, {
       1.0970571419134452`, -3.3622221848584006`}}], 
      PolygonBox[{{1.2302516425362546`, -3.4373449933535234`}, {
       1.0842925895560531`, -3.437499981032941}, {
       1.1874999999999998`, -3.3247595264191645`}, {
       1.2302516425362546`, -3.4373449933535234`}}], 
      PolygonBox[{{1.1874999999999998`, -3.3247595264191645`}, {
       1.2651650429449552`, -3.2651650429449552`}, {
       1.2302516425362546`, -3.4373449933535234`}, {
       1.1874999999999998`, -3.3247595264191645`}}], 
      PolygonBox[{{1.4049427443329972`, -3.404942744332997}, {
       1.2302516425362546`, -3.4373449933535234`}, {
       1.2651650429449552`, -3.2651650429449552`}, {
       1.4049427443329972`, -3.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, -3.2651650429449552`}, {
       1.2651650429449552`, -3.2651650429449552`}, {
       1.4049427443329972`, -3.404942744332997}, {
       1.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{1.4049427443329972`, -3.404942744332997}, {
       1.4049427443329972`, -3.404942744332997}, {
       1.2651650429449552`, -3.2651650429449552`}, {
       1.4049427443329972`, -3.404942744332997}}], 
      PolygonBox[{{1.4049427443329972`, -3.404942744332997}, {
       1.4373449933535234`, -3.2302516425362553`}, {1.5, -3.5}, {
       1.4049427443329972`, -3.404942744332997}}], 
      PolygonBox[{{1.5, -3.357662782649368}, {1.5, -3.5}, {
       1.4373449933535234`, -3.2302516425362553`}, {
       1.5, -3.357662782649368}}], 
      PolygonBox[{{1.4373449933535234`, -3.2302516425362553`}, {
       1.4374999810329407`, -3.084292589556062}, {1.5, -3.357662782649368}, {
       1.4373449933535234`, -3.2302516425362553`}}], 
      PolygonBox[{{1.5, -3.20590900530174}, {1.5, -3.357662782649368}, {
       1.4374999810329407`, -3.084292589556062}, {1.5, -3.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, -3.084292589556062}, {1.4375, -3.}, {
       1.5, -3.20590900530174}, {1.4374999810329407`, -3.084292589556062}}], 
      PolygonBox[{{1.5, -3.}, {1.5, -3.20590900530174}, {1.4375, -3.}, {
       1.5, -3.}}], 
      PolygonBox[{{1.4375, -3.}, {1.4374999810329407`, -2.915707410443938}, {
       1.5, -3.}, {1.4375, -3.}}], 
      PolygonBox[{{1.5, -2.79409099469826}, {1.5, -3.}, {
       1.4374999810329407`, -2.915707410443938}, {1.5, -2.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, -2.915707410443938}, {
       1.4373449933535234`, -2.769748357463745}, {1.5, -2.79409099469826}, {
       1.4374999810329407`, -2.915707410443938}}], 
      PolygonBox[{{1.5, -2.6423372173506325`}, {1.5, -2.79409099469826}, {
       1.4373449933535234`, -2.769748357463745}, {
       1.5, -2.6423372173506325`}}], 
      PolygonBox[{{1.4373449933535234`, -2.769748357463745}, {
       1.4049427443329972`, -2.595057255667003}, {
       1.5, -2.6423372173506325`}, {
       1.4373449933535234`, -2.769748357463745}}], 
      PolygonBox[{{1.491446564961186, -2.508553435038814}, {
       1.5, -2.6423372173506325`}, {
       1.4049427443329972`, -2.595057255667003}, {
       1.491446564961186, -2.508553435038814}}], 
      PolygonBox[{{1.4049427443329972`, -2.595057255667003}, {
       1.230251642536255, -2.5626550066464766`}, {
       1.491446564961186, -2.508553435038814}, {
       1.4049427443329972`, -2.595057255667003}}], 
      PolygonBox[{{1.3576627826493681`, -2.5}, {
       1.491446564961186, -2.508553435038814}, {
       1.230251642536255, -2.5626550066464766`}, {
       1.3576627826493681`, -2.5}}], 
      PolygonBox[{{1.230251642536255, -2.5626550066464766`}, {
       1.0842925895560604`, -2.562500018967059}, {
       1.3576627826493681`, -2.5}, {
       1.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{1.2059090053732557`, -2.5}, {1.3576627826493681`, -2.5}, {
       1.0842925895560604`, -2.562500018967059}, {
       1.2059090053732557`, -2.5}}], 
      PolygonBox[{{1.0842925895560604`, -2.562500018967059}, {
       1.0001055272204877`, -2.5625}, {1.2059090053732557`, -2.5}, {
       1.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{1.07794195802689, -2.5}, {1.2059090053732557`, -2.5}, {
       1.0001055272204877`, -2.5625}, {1.07794195802689, -2.5}}], 
      PolygonBox[{{1.0001055272204877`, -2.5625}, {
       0.9157074104439431, -2.562500018967059}, {1.07794195802689, -2.5}, {
       1.0001055272204877`, -2.5625}}], 
      PolygonBox[{{0.7940909946955543, -2.5}, {1.07794195802689, -2.5}, {
       0.9157074104439431, -2.562500018967059}, {0.7940909946955543, -2.5}}], 
      PolygonBox[{{0.9157074104439431, -2.562500018967059}, {
       0.7697483574637449, -2.5626550066464766`}, {
       0.7940909946955543, -2.5}, {0.9157074104439431, -2.562500018967059}}], 
      PolygonBox[{{0.6423372173506338, -2.5}, {0.7940909946955543, -2.5}, {
       0.7697483574637449, -2.5626550066464766`}, {
       0.6423372173506338, -2.5}}], 
      PolygonBox[{{0.7697483574637449, -2.5626550066464766`}, {
       0.5950572556670028, -2.595057255667003}, {0.6423372173506338, -2.5}, {
       0.7697483574637449, -2.5626550066464766`}}], 
      PolygonBox[{{1.5, -2.5}, {0.6423372173506338, -2.5}, {
       0.5950572556670028, -2.595057255667003}, {1.5, -2.5}}], 
      PolygonBox[{{0.5950572556670028, -2.595057255667003}, {
       0.5626550066464766, -2.7697483574637447`}, {1.5, -2.5}, {
       0.5950572556670028, -2.595057255667003}}], 
      PolygonBox[{{0.5, -2.642337217350631}, {1.5, -2.5}, {
       0.5626550066464766, -2.7697483574637447`}, {0.5, -2.642337217350631}}],
       PolygonBox[{{0.5626550066464766, -2.7697483574637447`}, {
       0.5625000189670593, -2.9157074104439378`}, {0.5, -2.642337217350631}, {
       0.5626550066464766, -2.7697483574637447`}}], 
      PolygonBox[{{0.5, -2.794090994717101}, {0.5, -2.642337217350631}, {
       0.5625000189670593, -2.9157074104439378`}, {0.5, -2.794090994717101}}],
       PolygonBox[{{0.5625000189670593, -2.9157074104439378`}, {
       0.5625, -2.9998768219370047`}, {0.5, -2.794090994717101}, {
       0.5625000189670593, -2.9157074104439378`}}], 
      PolygonBox[{{0.5, -2.9193213332413}, {0.5, -2.794090994717101}, {
       0.5625, -2.9998768219370047`}, {0.5, -2.9193213332413}}], 
      PolygonBox[{{0.5625, -2.9998768219370047`}, {
       0.5625000189670593, -3.084292589556055}, {0.5, -2.9193213332413}, {
       0.5625, -2.9998768219370047`}}], 
      PolygonBox[{{0.5, -3.2059090051452785`}, {0.5, -2.9193213332413}, {
       0.5625000189670593, -3.084292589556055}, {0.5, -3.2059090051452785`}}],
       PolygonBox[{{0.5625000189670593, -3.084292589556055}, {
       0.5626550066464766, -3.230251642536255}, {0.5, -3.2059090051452785`}, {
       0.5625000189670593, -3.084292589556055}}], 
      PolygonBox[{{0.5, -3.3576627826493652`}, {0.5, -3.2059090051452785`}, {
       0.5626550066464766, -3.230251642536255}, {0.5, -3.3576627826493652`}}],
       PolygonBox[{{0.5626550066464766, -3.230251642536255}, {
       0.5950572556670028, -3.404942744332997}, {0.5, -3.3576627826493652`}, {
       0.5626550066464766, -3.230251642536255}}], 
      PolygonBox[{{0.5, -2.5}, {0.5, -3.3576627826493652`}, {
       0.5950572556670028, -3.404942744332997}, {0.5, -2.5}}], 
      PolygonBox[{{0.5950572556670028, -3.404942744332997}, {
       0.7697483574637449, -3.4373449933535234`}, {0.5, -2.5}, {
       0.5950572556670028, -3.404942744332997}}], 
      PolygonBox[{{0.5, -3.5}, {0.5, -2.5}, {
       0.7697483574637449, -3.4373449933535234`}, {0.5, -3.5}}], 
      PolygonBox[{{0.7697483574637449, -3.4373449933535234`}, {
       0.9157074104439358, -3.437499981032941}, {0.5, -3.5}, {
       0.7697483574637449, -3.4373449933535234`}}], 
      PolygonBox[{{0.794090994433172, -3.5}, {0.5, -3.5}, {
       0.9157074104439358, -3.437499981032941}, {0.794090994433172, -3.5}}], 
      PolygonBox[{{0.9157074104439358, -3.437499981032941}, {
       1.000134841831043, -3.4375}, {0.794090994433172, -3.5}, {
       0.9157074104439358, -3.437499981032941}}], 
      PolygonBox[{{1.0823238704010616`, -3.5}, {0.794090994433172, -3.5}, {
       1.000134841831043, -3.4375}, {1.0823238704010616`, -3.5}}], 
      PolygonBox[{{1.000134841831043, -3.4375}, {
       1.0842925895560531`, -3.437499981032941}, {
       1.0823238704010616`, -3.5}, {1.000134841831043, -3.4375}}], 
      PolygonBox[{{1.2059090053603974`, -3.5}, {1.0823238704010616`, -3.5}, {
       1.0842925895560531`, -3.437499981032941}, {
       1.2059090053603974`, -3.5}}], 
      PolygonBox[{{1.0842925895560531`, -3.437499981032941}, {
       1.2302516425362546`, -3.4373449933535234`}, {
       1.2059090053603974`, -3.5}, {
       1.0842925895560531`, -3.437499981032941}}], 
      PolygonBox[{{1.357662782649371, -3.5}, {1.2059090053603974`, -3.5}, {
       1.2302516425362546`, -3.4373449933535234`}, {
       1.357662782649371, -3.5}}], 
      PolygonBox[{{1.2302516425362546`, -3.4373449933535234`}, {
       1.4049427443329972`, -3.404942744332997}, {1.357662782649371, -3.5}, {
       1.2302516425362546`, -3.4373449933535234`}}], 
      PolygonBox[{{1.5, -3.5}, {1.357662782649371, -3.5}, {
       1.4049427443329972`, -3.404942744332997}, {1.5, -3.5}}], 
      PolygonBox[{{1.4049427443329972`, -3.404942744332997}, {
       1.4049427443329972`, -3.404942744332997}, {1.5, -3.5}, {
       1.4049427443329972`, -3.404942744332997}}], 
      PolygonBox[{{1.5, -3.5}, {1.5, -3.5}, {
       1.4049427443329972`, -3.404942744332997}, {1.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -2.}, {0.5208333333333333, -2.}, {
       0.5416666666666667, -2.}, {0.5625, -2.}, {0.5833333333333333, -2.}, {
       0.6041666666666666, -2.}, {0.625, -2.}, {0.625, -2.}, {
       0.6041666666666667, -2.}, {0.5833333333333333, -2.}, {0.5625, -2.}, {
       0.5416666666666667, -2.}, {0.5208333333333334, -2.}, {0.5, -2.}, {
       0.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, -2.}, {1.3958333333333333`, -2.}, {
       1.4166666666666667`, -2.}, {1.4375, -2.}, {1.4583333333333333`, -2.}, {
       1.4791666666666665`, -2.}, {1.5, -2.}, {1.5, -2.}, {
       1.4791666666666667`, -2.}, {1.4583333333333333`, -2.}, {1.4375, -2.}, {
       1.4166666666666667`, -2.}, {1.3958333333333335`, -2.}, {1.375, -2.}, {
       1.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -2.5}, {1., -2.4791666666666665`}, {
       1., -2.4583333333333335`}, {1., -2.4375}, {1., -2.4166666666666665`}, {
       1., -2.3958333333333335`}, {1., -2.375}, {1., -2.375}, {
       1., -2.3958333333333335`}, {1., -2.4166666666666665`}, {1., -2.4375}, {
       1., -2.4583333333333335`}, {1., -2.4791666666666665`}, {1., -2.5}, {
       1., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -1.625}, {1., -1.6041666666666667`}, {
       1., -1.5833333333333333`}, {1., -1.5625}, {1., -1.5416666666666667`}, {
       1., -1.5208333333333335`}, {1., -1.5}, {1., -1.5}, {
       1., -1.5208333333333333`}, {1., -1.5416666666666667`}, {1., -1.5625}, {
       1., -1.5833333333333333`}, {1., -1.6041666666666665`}, {1., -1.625}, {
       1., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, -2.}, {0.75, -2.}, {0.875, -2.}, {1., -2.}, {
       1.125, -2.}, {1.25, -2.}, {1.375, -2.}, {1.375, -2.}, {1.25, -2.}, {
       1.125, -2.}, {1., -2.}, {0.875, -2.}, {0.75, -2.}, {0.625, -2.}, {
       0.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -2.375}, {1., -2.25}, {1., -2.125}, {1., -2.}, {
       1., -1.875}, {1., -1.75}, {1., -1.625}, {1., -1.625}, {1., -1.75}, {
       1., -1.875}, {1., -2.}, {1., -2.125}, {1., -2.25}, {1., -2.375}, {
       1., -2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7KGMA1cWx9auPP3VPsn8lmlJ0b/9CX0TuM2N
vkLl/+43u22+Wdbui/0plRM+jw7+3g8R/2y/oDD/y4mzv/bPO6F6qrv3o71O
zKKmMJNfUPkPUP2/9h/N25L94skbuDwjWPwVXP8UzwkzjzQ/h5vv8Pjei4mz
n8Ltj9jhwro24wncfRDxJ3D3w+T9ngg9PXqM4QCK/gbGA5Og5s9+O/smnzzT
gX//QeClvYH7iVbpmUwHDkHd9+riun1XnjIdAEv/fw81n/nAXKj/UOU/wfXD
wgdmPkr4Ae2Hha8/1H3o4Q8ADvS3xg==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7KH0/rBQEPgK569eBQKf4HwI/QFN/hWa/qdo
6h8Q5IONWfULzgcbE/oXTT3DAVR5xgOo+pkOoKpnweCHoriP5cAqFPfD1H9A
k/+Epv8rmvofBPmrUdz3A839P9D898M+DMX/MP2/9qOq/7EfANOWdCw=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, -2.2651650429449552`}, {
       1.3247595264191645`, -2.1875}, {
       1.4049427443329972`, -2.404942744332997}, {
       1.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{1.4373449933535234`, -2.2302516425362553`}, {
       1.4049427443329972`, -2.404942744332997}, {
       1.3247595264191645`, -2.1875}, {
       1.4373449933535234`, -2.2302516425362553`}}], 
      PolygonBox[{{1.3247595264191645`, -2.1875}, {
       1.3622221848584006`, -2.0970571419134454`}, {
       1.4373449933535234`, -2.2302516425362553`}, {
       1.3247595264191645`, -2.1875}}], 
      PolygonBox[{{1.4374999810329407`, -2.084292589556062}, {
       1.4373449933535234`, -2.2302516425362553`}, {
       1.3622221848584006`, -2.0970571419134454`}, {
       1.4374999810329407`, -2.084292589556062}}], 
      PolygonBox[{{1.3622221848584006`, -2.0970571419134454`}, {1.375, -2.}, {
       1.4374999810329407`, -2.084292589556062}, {
       1.3622221848584006`, -2.0970571419134454`}}], 
      PolygonBox[{{1.4375, -2.}, {1.4374999810329407`, -2.084292589556062}, {
       1.375, -2.}, {1.4375, -2.}}], 
      PolygonBox[{{1.375, -2.}, {1.3622221848584006`, -1.9029428580865548`}, {
       1.4375, -2.}, {1.375, -2.}}], 
      PolygonBox[{{1.4374999810329407`, -1.9157074104439382`}, {
       1.4375, -2.}, {1.3622221848584006`, -1.9029428580865548`}, {
       1.4374999810329407`, -1.9157074104439382`}}], 
      PolygonBox[{{1.3622221848584006`, -1.9029428580865548`}, {
       1.3247595264191645`, -1.8125}, {
       1.4374999810329407`, -1.9157074104439382`}, {
       1.3622221848584006`, -1.9029428580865548`}}], 
      PolygonBox[{{1.4373449933535234`, -1.769748357463745}, {
       1.4374999810329407`, -1.9157074104439382`}, {
       1.3247595264191645`, -1.8125}, {
       1.4373449933535234`, -1.769748357463745}}], 
      PolygonBox[{{1.3247595264191645`, -1.8125}, {
       1.2651650429449552`, -1.7348349570550448`}, {
       1.4373449933535234`, -1.769748357463745}, {
       1.3247595264191645`, -1.8125}}], 
      PolygonBox[{{1.4049427443329972`, -1.5950572556670028`}, {
       1.4373449933535234`, -1.769748357463745}, {
       1.2651650429449552`, -1.7348349570550448`}, {
       1.4049427443329972`, -1.5950572556670028`}}], 
      PolygonBox[{{1.2651650429449552`, -1.7348349570550448`}, {
       1.1875, -1.6752404735808355`}, {
       1.4049427443329972`, -1.5950572556670028`}, {
       1.2651650429449552`, -1.7348349570550448`}}], 
      PolygonBox[{{1.230251642536255, -1.5626550066464766`}, {
       1.4049427443329972`, -1.5950572556670028`}, {
       1.1875, -1.6752404735808355`}, {
       1.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{1.1875, -1.6752404735808355`}, {
       1.0970571419134454`, -1.6377778151415994`}, {
       1.230251642536255, -1.5626550066464766`}, {
       1.1875, -1.6752404735808355`}}], 
      PolygonBox[{{1.0842925895560604`, -1.5625000189670593`}, {
       1.230251642536255, -1.5626550066464766`}, {
       1.0970571419134454`, -1.6377778151415994`}, {
       1.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{1.0970571419134454`, -1.6377778151415994`}, {1., -1.625}, {
       1.0842925895560604`, -1.5625000189670593`}, {
       1.0970571419134454`, -1.6377778151415994`}}], 
      PolygonBox[{{1.0001055272204877`, -1.5625}, {
       1.0842925895560604`, -1.5625000189670593`}, {1., -1.625}, {
       1.0001055272204877`, -1.5625}}], 
      PolygonBox[{{1., -1.625}, {0.9029428580865548, -1.6377778151415994`}, {
       1.0001055272204877`, -1.5625}, {1., -1.625}}], 
      PolygonBox[{{0.9157074104439431, -1.5625000189670593`}, {
       1.0001055272204877`, -1.5625}, {
       0.9029428580865548, -1.6377778151415994`}, {
       0.9157074104439431, -1.5625000189670593`}}], 
      PolygonBox[{{0.9029428580865548, -1.6377778151415994`}, {
       0.8125000000000001, -1.6752404735808355`}, {
       0.9157074104439431, -1.5625000189670593`}, {
       0.9029428580865548, -1.6377778151415994`}}], 
      PolygonBox[{{0.7697483574637449, -1.5626550066464766`}, {
       0.9157074104439431, -1.5625000189670593`}, {
       0.8125000000000001, -1.6752404735808355`}, {
       0.7697483574637449, -1.5626550066464766`}}], 
      PolygonBox[{{0.8125000000000001, -1.6752404735808355`}, {
       0.7348349570550448, -1.7348349570550448`}, {
       0.7697483574637449, -1.5626550066464766`}, {
       0.8125000000000001, -1.6752404735808355`}}], 
      PolygonBox[{{0.5950572556670028, -1.5950572556670028`}, {
       0.7697483574637449, -1.5626550066464766`}, {
       0.7348349570550448, -1.7348349570550448`}, {
       0.5950572556670028, -1.5950572556670028`}}], 
      PolygonBox[{{0.7348349570550448, -1.7348349570550448`}, {
       0.6752404735808355, -1.8125}, {
       0.5950572556670028, -1.5950572556670028`}, {
       0.7348349570550448, -1.7348349570550448`}}], 
      PolygonBox[{{0.5626550066464766, -1.7697483574637447`}, {
       0.5950572556670028, -1.5950572556670028`}, {
       0.6752404735808355, -1.8125}, {
       0.5626550066464766, -1.7697483574637447`}}], 
      PolygonBox[{{0.6752404735808355, -1.8125}, {
       0.6377778151415994, -1.9029428580865546`}, {
       0.5626550066464766, -1.7697483574637447`}, {
       0.6752404735808355, -1.8125}}], 
      PolygonBox[{{0.5625000189670593, -1.9157074104439376`}, {
       0.5626550066464766, -1.7697483574637447`}, {
       0.6377778151415994, -1.9029428580865546`}, {
       0.5625000189670593, -1.9157074104439376`}}], 
      PolygonBox[{{0.6377778151415994, -1.9029428580865546`}, {
       0.625, -1.9999999999999998`}, {
       0.5625000189670593, -1.9157074104439376`}, {
       0.6377778151415994, -1.9029428580865546`}}], 
      PolygonBox[{{0.5625, -1.9998768219370047`}, {
       0.5625000189670593, -1.9157074104439376`}, {
       0.625, -1.9999999999999998`}, {0.5625, -1.9998768219370047`}}], 
      PolygonBox[{{0.625, -1.9999999999999998`}, {
       0.6377778151415994, -2.097057141913445}, {
       0.5625, -1.9998768219370047`}, {0.625, -1.9999999999999998`}}], 
      PolygonBox[{{0.5625000189670593, -2.084292589556055}, {
       0.5625, -1.9998768219370047`}, {
       0.6377778151415994, -2.097057141913445}, {
       0.5625000189670593, -2.084292589556055}}], 
      PolygonBox[{{0.6377778151415994, -2.097057141913445}, {
       0.6752404735808354, -2.1875}, {
       0.5625000189670593, -2.084292589556055}, {
       0.6377778151415994, -2.097057141913445}}], 
      PolygonBox[{{0.5626550066464766, -2.230251642536255}, {
       0.5625000189670593, -2.084292589556055}, {
       0.6752404735808354, -2.1875}, {
       0.5626550066464766, -2.230251642536255}}], 
      PolygonBox[{{0.6752404735808354, -2.1875}, {
       0.7348349570550446, -2.2651650429449552`}, {
       0.5626550066464766, -2.230251642536255}, {
       0.6752404735808354, -2.1875}}], 
      PolygonBox[{{0.5950572556670028, -2.404942744332997}, {
       0.5626550066464766, -2.230251642536255}, {
       0.7348349570550446, -2.2651650429449552`}, {
       0.5950572556670028, -2.404942744332997}}], 
      PolygonBox[{{0.7348349570550446, -2.2651650429449552`}, {
       0.8124999999999998, -2.3247595264191645`}, {
       0.5950572556670028, -2.404942744332997}, {
       0.7348349570550446, -2.2651650429449552`}}], 
      PolygonBox[{{0.7697483574637449, -2.4373449933535234`}, {
       0.5950572556670028, -2.404942744332997}, {
       0.8124999999999998, -2.3247595264191645`}, {
       0.7697483574637449, -2.4373449933535234`}}], 
      PolygonBox[{{0.8124999999999998, -2.3247595264191645`}, {
       0.9029428580865544, -2.3622221848584006`}, {
       0.7697483574637449, -2.4373449933535234`}, {
       0.8124999999999998, -2.3247595264191645`}}], 
      PolygonBox[{{0.9157074104439358, -2.437499981032941}, {
       0.7697483574637449, -2.4373449933535234`}, {
       0.9029428580865544, -2.3622221848584006`}, {
       0.9157074104439358, -2.437499981032941}}], 
      PolygonBox[{{0.9029428580865544, -2.3622221848584006`}, {1., -2.375}, {
       0.9157074104439358, -2.437499981032941}, {
       0.9029428580865544, -2.3622221848584006`}}], 
      PolygonBox[{{1.000134841831043, -2.4375}, {
       0.9157074104439358, -2.437499981032941}, {1., -2.375}, {
       1.000134841831043, -2.4375}}], 
      PolygonBox[{{1., -2.375}, {1.0970571419134452`, -2.3622221848584006`}, {
       1.000134841831043, -2.4375}, {1., -2.375}}], 
      PolygonBox[{{1.0842925895560531`, -2.437499981032941}, {
       1.000134841831043, -2.4375}, {
       1.0970571419134452`, -2.3622221848584006`}, {
       1.0842925895560531`, -2.437499981032941}}], 
      PolygonBox[{{1.0970571419134452`, -2.3622221848584006`}, {
       1.1874999999999998`, -2.3247595264191645`}, {
       1.0842925895560531`, -2.437499981032941}, {
       1.0970571419134452`, -2.3622221848584006`}}], 
      PolygonBox[{{1.2302516425362546`, -2.4373449933535234`}, {
       1.0842925895560531`, -2.437499981032941}, {
       1.1874999999999998`, -2.3247595264191645`}, {
       1.2302516425362546`, -2.4373449933535234`}}], 
      PolygonBox[{{1.1874999999999998`, -2.3247595264191645`}, {
       1.2651650429449552`, -2.2651650429449552`}, {
       1.2302516425362546`, -2.4373449933535234`}, {
       1.1874999999999998`, -2.3247595264191645`}}], 
      PolygonBox[{{1.4049427443329972`, -2.404942744332997}, {
       1.2302516425362546`, -2.4373449933535234`}, {
       1.2651650429449552`, -2.2651650429449552`}, {
       1.4049427443329972`, -2.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, -2.2651650429449552`}, {
       1.2651650429449552`, -2.2651650429449552`}, {
       1.4049427443329972`, -2.404942744332997}, {
       1.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{1.4049427443329972`, -2.404942744332997}, {
       1.4049427443329972`, -2.404942744332997}, {
       1.2651650429449552`, -2.2651650429449552`}, {
       1.4049427443329972`, -2.404942744332997}}], 
      PolygonBox[{{1.4049427443329972`, -2.404942744332997}, {
       1.4373449933535234`, -2.2302516425362553`}, {1.5, -2.5}, {
       1.4049427443329972`, -2.404942744332997}}], 
      PolygonBox[{{1.5, -2.357662782649368}, {1.5, -2.5}, {
       1.4373449933535234`, -2.2302516425362553`}, {
       1.5, -2.357662782649368}}], 
      PolygonBox[{{1.4373449933535234`, -2.2302516425362553`}, {
       1.4374999810329407`, -2.084292589556062}, {1.5, -2.357662782649368}, {
       1.4373449933535234`, -2.2302516425362553`}}], 
      PolygonBox[{{1.5, -2.20590900530174}, {1.5, -2.357662782649368}, {
       1.4374999810329407`, -2.084292589556062}, {1.5, -2.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, -2.084292589556062}, {1.4375, -2.}, {
       1.5, -2.20590900530174}, {1.4374999810329407`, -2.084292589556062}}], 
      PolygonBox[{{1.5, -2.}, {1.5, -2.20590900530174}, {1.4375, -2.}, {
       1.5, -2.}}], 
      PolygonBox[{{1.4375, -2.}, {
       1.4374999810329407`, -1.9157074104439382`}, {1.5, -2.}, {
       1.4375, -2.}}], 
      PolygonBox[{{1.5, -1.7940909946982602`}, {1.5, -2.}, {
       1.4374999810329407`, -1.9157074104439382`}, {
       1.5, -1.7940909946982602`}}], 
      PolygonBox[{{1.4374999810329407`, -1.9157074104439382`}, {
       1.4373449933535234`, -1.769748357463745}, {
       1.5, -1.7940909946982602`}, {
       1.4374999810329407`, -1.9157074104439382`}}], 
      PolygonBox[{{1.5, -1.6423372173506325`}, {1.5, -1.7940909946982602`}, {
       1.4373449933535234`, -1.769748357463745}, {
       1.5, -1.6423372173506325`}}], 
      PolygonBox[{{1.4373449933535234`, -1.769748357463745}, {
       1.4049427443329972`, -1.5950572556670028`}, {
       1.5, -1.6423372173506325`}, {
       1.4373449933535234`, -1.769748357463745}}], 
      PolygonBox[{{1.491446564961186, -1.508553435038814}, {
       1.5, -1.6423372173506325`}, {
       1.4049427443329972`, -1.5950572556670028`}, {
       1.491446564961186, -1.508553435038814}}], 
      PolygonBox[{{1.4049427443329972`, -1.5950572556670028`}, {
       1.230251642536255, -1.5626550066464766`}, {
       1.491446564961186, -1.508553435038814}, {
       1.4049427443329972`, -1.5950572556670028`}}], 
      PolygonBox[{{1.3576627826493681`, -1.5}, {
       1.491446564961186, -1.508553435038814}, {
       1.230251642536255, -1.5626550066464766`}, {
       1.3576627826493681`, -1.5}}], 
      PolygonBox[{{1.230251642536255, -1.5626550066464766`}, {
       1.0842925895560604`, -1.5625000189670593`}, {
       1.3576627826493681`, -1.5}, {
       1.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{1.2059090053732557`, -1.5}, {1.3576627826493681`, -1.5}, {
       1.0842925895560604`, -1.5625000189670593`}, {
       1.2059090053732557`, -1.5}}], 
      PolygonBox[{{1.0842925895560604`, -1.5625000189670593`}, {
       1.0001055272204877`, -1.5625}, {1.2059090053732557`, -1.5}, {
       1.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{1.07794195802689, -1.5}, {1.2059090053732557`, -1.5}, {
       1.0001055272204877`, -1.5625}, {1.07794195802689, -1.5}}], 
      PolygonBox[{{1.0001055272204877`, -1.5625}, {
       0.9157074104439431, -1.5625000189670593`}, {1.07794195802689, -1.5}, {
       1.0001055272204877`, -1.5625}}], 
      PolygonBox[{{0.7940909946955543, -1.5}, {1.07794195802689, -1.5}, {
       0.9157074104439431, -1.5625000189670593`}, {
       0.7940909946955543, -1.5}}], 
      PolygonBox[{{0.9157074104439431, -1.5625000189670593`}, {
       0.7697483574637449, -1.5626550066464766`}, {
       0.7940909946955543, -1.5}, {
       0.9157074104439431, -1.5625000189670593`}}], 
      PolygonBox[{{0.6423372173506338, -1.5}, {0.7940909946955543, -1.5}, {
       0.7697483574637449, -1.5626550066464766`}, {
       0.6423372173506338, -1.5}}], 
      PolygonBox[{{0.7697483574637449, -1.5626550066464766`}, {
       0.5950572556670028, -1.5950572556670028`}, {
       0.6423372173506338, -1.5}, {
       0.7697483574637449, -1.5626550066464766`}}], 
      PolygonBox[{{1.5, -1.5}, {0.6423372173506338, -1.5}, {
       0.5950572556670028, -1.5950572556670028`}, {1.5, -1.5}}], 
      PolygonBox[{{0.5950572556670028, -1.5950572556670028`}, {
       0.5626550066464766, -1.7697483574637447`}, {1.5, -1.5}, {
       0.5950572556670028, -1.5950572556670028`}}], 
      PolygonBox[{{0.5, -1.642337217350631}, {1.5, -1.5}, {
       0.5626550066464766, -1.7697483574637447`}, {0.5, -1.642337217350631}}],
       PolygonBox[{{0.5626550066464766, -1.7697483574637447`}, {
       0.5625000189670593, -1.9157074104439376`}, {0.5, -1.642337217350631}, {
       0.5626550066464766, -1.7697483574637447`}}], 
      PolygonBox[{{0.5, -1.794090994717101}, {0.5, -1.642337217350631}, {
       0.5625000189670593, -1.9157074104439376`}, {0.5, -1.794090994717101}}],
       PolygonBox[{{0.5625000189670593, -1.9157074104439376`}, {
       0.5625, -1.9998768219370047`}, {0.5, -1.794090994717101}, {
       0.5625000189670593, -1.9157074104439376`}}], 
      PolygonBox[{{0.5, -1.9193213332412997`}, {0.5, -1.794090994717101}, {
       0.5625, -1.9998768219370047`}, {0.5, -1.9193213332412997`}}], 
      PolygonBox[{{0.5625, -1.9998768219370047`}, {
       0.5625000189670593, -2.084292589556055}, {0.5, -1.9193213332412997`}, {
       0.5625, -1.9998768219370047`}}], 
      PolygonBox[{{0.5, -2.2059090051452785`}, {0.5, -1.9193213332412997`}, {
       0.5625000189670593, -2.084292589556055}, {0.5, -2.2059090051452785`}}],
       PolygonBox[{{0.5625000189670593, -2.084292589556055}, {
       0.5626550066464766, -2.230251642536255}, {0.5, -2.2059090051452785`}, {
       0.5625000189670593, -2.084292589556055}}], 
      PolygonBox[{{0.5, -2.3576627826493652`}, {0.5, -2.2059090051452785`}, {
       0.5626550066464766, -2.230251642536255}, {0.5, -2.3576627826493652`}}],
       PolygonBox[{{0.5626550066464766, -2.230251642536255}, {
       0.5950572556670028, -2.404942744332997}, {0.5, -2.3576627826493652`}, {
       0.5626550066464766, -2.230251642536255}}], 
      PolygonBox[{{0.5, -1.5}, {0.5, -2.3576627826493652`}, {
       0.5950572556670028, -2.404942744332997}, {0.5, -1.5}}], 
      PolygonBox[{{0.5950572556670028, -2.404942744332997}, {
       0.7697483574637449, -2.4373449933535234`}, {0.5, -1.5}, {
       0.5950572556670028, -2.404942744332997}}], 
      PolygonBox[{{0.5, -2.5}, {0.5, -1.5}, {
       0.7697483574637449, -2.4373449933535234`}, {0.5, -2.5}}], 
      PolygonBox[{{0.7697483574637449, -2.4373449933535234`}, {
       0.9157074104439358, -2.437499981032941}, {0.5, -2.5}, {
       0.7697483574637449, -2.4373449933535234`}}], 
      PolygonBox[{{0.794090994433172, -2.5}, {0.5, -2.5}, {
       0.9157074104439358, -2.437499981032941}, {0.794090994433172, -2.5}}], 
      PolygonBox[{{0.9157074104439358, -2.437499981032941}, {
       1.000134841831043, -2.4375}, {0.794090994433172, -2.5}, {
       0.9157074104439358, -2.437499981032941}}], 
      PolygonBox[{{1.0823238704010616`, -2.5}, {0.794090994433172, -2.5}, {
       1.000134841831043, -2.4375}, {1.0823238704010616`, -2.5}}], 
      PolygonBox[{{1.000134841831043, -2.4375}, {
       1.0842925895560531`, -2.437499981032941}, {
       1.0823238704010616`, -2.5}, {1.000134841831043, -2.4375}}], 
      PolygonBox[{{1.2059090053603974`, -2.5}, {1.0823238704010616`, -2.5}, {
       1.0842925895560531`, -2.437499981032941}, {
       1.2059090053603974`, -2.5}}], 
      PolygonBox[{{1.0842925895560531`, -2.437499981032941}, {
       1.2302516425362546`, -2.4373449933535234`}, {
       1.2059090053603974`, -2.5}, {
       1.0842925895560531`, -2.437499981032941}}], 
      PolygonBox[{{1.357662782649371, -2.5}, {1.2059090053603974`, -2.5}, {
       1.2302516425362546`, -2.4373449933535234`}, {
       1.357662782649371, -2.5}}], 
      PolygonBox[{{1.2302516425362546`, -2.4373449933535234`}, {
       1.4049427443329972`, -2.404942744332997}, {1.357662782649371, -2.5}, {
       1.2302516425362546`, -2.4373449933535234`}}], 
      PolygonBox[{{1.5, -2.5}, {1.357662782649371, -2.5}, {
       1.4049427443329972`, -2.404942744332997}, {1.5, -2.5}}], 
      PolygonBox[{{1.4049427443329972`, -2.404942744332997}, {
       1.4049427443329972`, -2.404942744332997}, {1.5, -2.5}, {
       1.4049427443329972`, -2.404942744332997}}], 
      PolygonBox[{{1.5, -2.5}, {1.5, -2.5}, {
       1.4049427443329972`, -2.404942744332997}, {1.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -1.}, {0.5208333333333333, -1.}, {
       0.5416666666666667, -1.}, {0.5625, -1.}, {0.5833333333333333, -1.}, {
       0.6041666666666666, -1.}, {0.625, -1.}, {0.625, -1.}, {
       0.6041666666666667, -1.}, {0.5833333333333333, -1.}, {0.5625, -1.}, {
       0.5416666666666667, -1.}, {0.5208333333333334, -1.}, {0.5, -1.}, {
       0.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, -1.}, {1.3958333333333333`, -1.}, {
       1.4166666666666667`, -1.}, {1.4375, -1.}, {1.4583333333333333`, -1.}, {
       1.4791666666666665`, -1.}, {1.5, -1.}, {1.5, -1.}, {
       1.4791666666666667`, -1.}, {1.4583333333333333`, -1.}, {1.4375, -1.}, {
       1.4166666666666667`, -1.}, {1.3958333333333335`, -1.}, {1.375, -1.}, {
       1.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -1.5}, {1., -1.4791666666666667`}, {
       1., -1.4583333333333333`}, {1., -1.4375}, {1., -1.4166666666666667`}, {
       1., -1.3958333333333335`}, {1., -1.375}, {1., -1.375}, {
       1., -1.3958333333333333`}, {1., -1.4166666666666667`}, {1., -1.4375}, {
       1., -1.4583333333333333`}, {1., -1.4791666666666665`}, {1., -1.5}, {
       1., -1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -0.625}, {1., -0.6041666666666667}, {
       1., -0.5833333333333333}, {1., -0.5625}, {1., -0.5416666666666667}, {
       1., -0.5208333333333334}, {1., -0.5}, {1., -0.5}, {
       1., -0.5208333333333333}, {1., -0.5416666666666667}, {1., -0.5625}, {
       1., -0.5833333333333333}, {1., -0.6041666666666666}, {1., -0.625}, {
       1., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, -1.}, {0.75, -1.}, {0.875, -1.}, {1., -1.}, {
       1.125, -1.}, {1.25, -1.}, {1.375, -1.}, {1.375, -1.}, {1.25, -1.}, {
       1.125, -1.}, {1., -1.}, {0.875, -1.}, {0.75, -1.}, {0.625, -1.}, {
       0.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -1.375}, {1., -1.25}, {1., -1.125}, {1., -1.}, {
       1., -0.875}, {1., -0.75}, {1., -0.625}, {1., -0.625}, {1., -0.75}, {
       1., -0.875}, {1., -1.}, {1., -1.125}, {1., -1.25}, {1., -1.375}, {
       1., -1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CH0h/1XFsfWrjz91f5o3pbsF0/e7E/om8Bt
bvQVKv9qv9lt882ydl/sp3hOmHmk+fl+iPhne4fH915MnP10/7wTqqe6ez/a
R+xwYV2b8QQq/wGq/8l+qLlweUaIuXD9UHPtJ0PNh4rb/weDl/uh+uyPQN0H
NRfufpj8XIg74Pqh7tw/CWo+1B/7/0HMtYf6c/8hqPug4bAfYu97qP5v+6Hm
osl/guuHhQ/MfFj4MULth4XvfKj70MMfAGI+xow=
      "]], LineBox[CompressedData["
1:eJyFTzEKwCAQk76jS1/iHwr6gELn/ksf4VdcXJxEEG5s5VC4dDAgISSR3HE9
570ppfbvdWaQZo7Bmo42tXcddWrmAn6GfoJ8XGrDvakd/wv5An6FfoM8/bQR
+yg4sZ/gvuFX6DfI01JbsY+0F/sJ7ht+hn6CfAwvfo+BMg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, -1.2651650429449552`}, {
       1.3247595264191645`, -1.1875}, {
       1.4049427443329972`, -1.4049427443329972`}, {
       1.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{1.4373449933535234`, -1.230251642536255}, {
       1.4049427443329972`, -1.4049427443329972`}, {
       1.3247595264191645`, -1.1875}, {
       1.4373449933535234`, -1.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, -1.1875}, {
       1.3622221848584006`, -1.0970571419134454`}, {
       1.4373449933535234`, -1.230251642536255}, {
       1.3247595264191645`, -1.1875}}], 
      PolygonBox[{{1.4374999810329407`, -1.0842925895560618`}, {
       1.4373449933535234`, -1.230251642536255}, {
       1.3622221848584006`, -1.0970571419134454`}, {
       1.4374999810329407`, -1.0842925895560618`}}], 
      PolygonBox[{{1.3622221848584006`, -1.0970571419134454`}, {1.375, -1.}, {
       1.4374999810329407`, -1.0842925895560618`}, {
       1.3622221848584006`, -1.0970571419134454`}}], 
      PolygonBox[{{1.4375, -1.}, {
       1.4374999810329407`, -1.0842925895560618`}, {1.375, -1.}, {
       1.4375, -1.}}], 
      PolygonBox[{{1.375, -1.}, {1.3622221848584006`, -0.9029428580865547}, {
       1.4375, -1.}, {1.375, -1.}}], 
      PolygonBox[{{1.4374999810329407`, -0.9157074104439382}, {1.4375, -1.}, {
       1.3622221848584006`, -0.9029428580865547}, {
       1.4374999810329407`, -0.9157074104439382}}], 
      PolygonBox[{{1.3622221848584006`, -0.9029428580865547}, {
       1.3247595264191645`, -0.8125}, {
       1.4374999810329407`, -0.9157074104439382}, {
       1.3622221848584006`, -0.9029428580865547}}], 
      PolygonBox[{{1.4373449933535234`, -0.7697483574637449}, {
       1.4374999810329407`, -0.9157074104439382}, {
       1.3247595264191645`, -0.8125}, {
       1.4373449933535234`, -0.7697483574637449}}], 
      PolygonBox[{{1.3247595264191645`, -0.8125}, {
       1.2651650429449552`, -0.7348349570550448}, {
       1.4373449933535234`, -0.7697483574637449}, {
       1.3247595264191645`, -0.8125}}], 
      PolygonBox[{{1.4049427443329972`, -0.5950572556670028}, {
       1.4373449933535234`, -0.7697483574637449}, {
       1.2651650429449552`, -0.7348349570550448}, {
       1.4049427443329972`, -0.5950572556670028}}], 
      PolygonBox[{{1.2651650429449552`, -0.7348349570550448}, {
       1.1875, -0.6752404735808355}, {
       1.4049427443329972`, -0.5950572556670028}, {
       1.2651650429449552`, -0.7348349570550448}}], 
      PolygonBox[{{1.230251642536255, -0.5626550066464766}, {
       1.4049427443329972`, -0.5950572556670028}, {
       1.1875, -0.6752404735808355}, {
       1.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{1.1875, -0.6752404735808355}, {
       1.0970571419134454`, -0.6377778151415994}, {
       1.230251642536255, -0.5626550066464766}, {
       1.1875, -0.6752404735808355}}], 
      PolygonBox[{{1.0842925895560604`, -0.5625000189670593}, {
       1.230251642536255, -0.5626550066464766}, {
       1.0970571419134454`, -0.6377778151415994}, {
       1.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{1.0970571419134454`, -0.6377778151415994}, {1., -0.625}, {
       1.0842925895560604`, -0.5625000189670593}, {
       1.0970571419134454`, -0.6377778151415994}}], 
      PolygonBox[{{1.0001055272204877`, -0.5625}, {
       1.0842925895560604`, -0.5625000189670593}, {1., -0.625}, {
       1.0001055272204877`, -0.5625}}], 
      PolygonBox[{{1., -0.625}, {0.9029428580865548, -0.6377778151415994}, {
       1.0001055272204877`, -0.5625}, {1., -0.625}}], 
      PolygonBox[{{0.9157074104439431, -0.5625000189670593}, {
       1.0001055272204877`, -0.5625}, {
       0.9029428580865548, -0.6377778151415994}, {
       0.9157074104439431, -0.5625000189670593}}], 
      PolygonBox[{{0.9029428580865548, -0.6377778151415994}, {
       0.8125000000000001, -0.6752404735808355}, {
       0.9157074104439431, -0.5625000189670593}, {
       0.9029428580865548, -0.6377778151415994}}], 
      PolygonBox[{{0.7697483574637449, -0.5626550066464766}, {
       0.9157074104439431, -0.5625000189670593}, {
       0.8125000000000001, -0.6752404735808355}, {
       0.7697483574637449, -0.5626550066464766}}], 
      PolygonBox[{{0.8125000000000001, -0.6752404735808355}, {
       0.7348349570550448, -0.7348349570550446}, {
       0.7697483574637449, -0.5626550066464766}, {
       0.8125000000000001, -0.6752404735808355}}], 
      PolygonBox[{{0.5950572556670028, -0.5950572556670028}, {
       0.7697483574637449, -0.5626550066464766}, {
       0.7348349570550448, -0.7348349570550446}, {
       0.5950572556670028, -0.5950572556670028}}], 
      PolygonBox[{{0.7348349570550448, -0.7348349570550446}, {
       0.6752404735808355, -0.8124999999999999}, {
       0.5950572556670028, -0.5950572556670028}, {
       0.7348349570550448, -0.7348349570550446}}], 
      PolygonBox[{{0.5626550066464766, -0.7697483574637446}, {
       0.5950572556670028, -0.5950572556670028}, {
       0.6752404735808355, -0.8124999999999999}, {
       0.5626550066464766, -0.7697483574637446}}], 
      PolygonBox[{{0.6752404735808355, -0.8124999999999999}, {
       0.6377778151415994, -0.9029428580865546}, {
       0.5626550066464766, -0.7697483574637446}, {
       0.6752404735808355, -0.8124999999999999}}], 
      PolygonBox[{{0.5625000189670593, -0.9157074104439377}, {
       0.5626550066464766, -0.7697483574637446}, {
       0.6377778151415994, -0.9029428580865546}, {
       0.5625000189670593, -0.9157074104439377}}], 
      PolygonBox[{{0.6377778151415994, -0.9029428580865546}, {
       0.625, -0.9999999999999998}, {
       0.5625000189670593, -0.9157074104439377}, {
       0.6377778151415994, -0.9029428580865546}}], 
      PolygonBox[{{0.5625, -0.9998768219370047}, {
       0.5625000189670593, -0.9157074104439377}, {
       0.625, -0.9999999999999998}, {0.5625, -0.9998768219370047}}], 
      PolygonBox[{{0.625, -0.9999999999999998}, {
       0.6377778151415994, -1.0970571419134452`}, {
       0.5625, -0.9998768219370047}, {0.625, -0.9999999999999998}}], 
      PolygonBox[{{0.5625000189670593, -1.084292589556055}, {
       0.5625, -0.9998768219370047}, {
       0.6377778151415994, -1.0970571419134452`}, {
       0.5625000189670593, -1.084292589556055}}], 
      PolygonBox[{{0.6377778151415994, -1.0970571419134452`}, {
       0.6752404735808354, -1.1874999999999998`}, {
       0.5625000189670593, -1.084292589556055}, {
       0.6377778151415994, -1.0970571419134452`}}], 
      PolygonBox[{{0.5626550066464766, -1.2302516425362549`}, {
       0.5625000189670593, -1.084292589556055}, {
       0.6752404735808354, -1.1874999999999998`}, {
       0.5626550066464766, -1.2302516425362549`}}], 
      PolygonBox[{{0.6752404735808354, -1.1874999999999998`}, {
       0.7348349570550446, -1.2651650429449552`}, {
       0.5626550066464766, -1.2302516425362549`}, {
       0.6752404735808354, -1.1874999999999998`}}], 
      PolygonBox[{{0.5950572556670028, -1.4049427443329972`}, {
       0.5626550066464766, -1.2302516425362549`}, {
       0.7348349570550446, -1.2651650429449552`}, {
       0.5950572556670028, -1.4049427443329972`}}], 
      PolygonBox[{{0.7348349570550446, -1.2651650429449552`}, {
       0.8124999999999998, -1.3247595264191645`}, {
       0.5950572556670028, -1.4049427443329972`}, {
       0.7348349570550446, -1.2651650429449552`}}], 
      PolygonBox[{{0.7697483574637449, -1.4373449933535234`}, {
       0.5950572556670028, -1.4049427443329972`}, {
       0.8124999999999998, -1.3247595264191645`}, {
       0.7697483574637449, -1.4373449933535234`}}], 
      PolygonBox[{{0.8124999999999998, -1.3247595264191645`}, {
       0.9029428580865544, -1.3622221848584006`}, {
       0.7697483574637449, -1.4373449933535234`}, {
       0.8124999999999998, -1.3247595264191645`}}], 
      PolygonBox[{{0.9157074104439358, -1.4374999810329407`}, {
       0.7697483574637449, -1.4373449933535234`}, {
       0.9029428580865544, -1.3622221848584006`}, {
       0.9157074104439358, -1.4374999810329407`}}], 
      PolygonBox[{{0.9029428580865544, -1.3622221848584006`}, {1., -1.375}, {
       0.9157074104439358, -1.4374999810329407`}, {
       0.9029428580865544, -1.3622221848584006`}}], 
      PolygonBox[{{1.000134841831043, -1.4375}, {
       0.9157074104439358, -1.4374999810329407`}, {1., -1.375}, {
       1.000134841831043, -1.4375}}], 
      PolygonBox[{{1., -1.375}, {1.0970571419134452`, -1.3622221848584006`}, {
       1.000134841831043, -1.4375}, {1., -1.375}}], 
      PolygonBox[{{1.0842925895560531`, -1.4374999810329407`}, {
       1.000134841831043, -1.4375}, {
       1.0970571419134452`, -1.3622221848584006`}, {
       1.0842925895560531`, -1.4374999810329407`}}], 
      PolygonBox[{{1.0970571419134452`, -1.3622221848584006`}, {
       1.1874999999999998`, -1.3247595264191645`}, {
       1.0842925895560531`, -1.4374999810329407`}, {
       1.0970571419134452`, -1.3622221848584006`}}], 
      PolygonBox[{{1.2302516425362546`, -1.4373449933535234`}, {
       1.0842925895560531`, -1.4374999810329407`}, {
       1.1874999999999998`, -1.3247595264191645`}, {
       1.2302516425362546`, -1.4373449933535234`}}], 
      PolygonBox[{{1.1874999999999998`, -1.3247595264191645`}, {
       1.2651650429449552`, -1.2651650429449552`}, {
       1.2302516425362546`, -1.4373449933535234`}, {
       1.1874999999999998`, -1.3247595264191645`}}], 
      PolygonBox[{{1.4049427443329972`, -1.4049427443329972`}, {
       1.2302516425362546`, -1.4373449933535234`}, {
       1.2651650429449552`, -1.2651650429449552`}, {
       1.4049427443329972`, -1.4049427443329972`}}], 
      PolygonBox[{{1.2651650429449552`, -1.2651650429449552`}, {
       1.2651650429449552`, -1.2651650429449552`}, {
       1.4049427443329972`, -1.4049427443329972`}, {
       1.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{1.4049427443329972`, -1.4049427443329972`}, {
       1.4049427443329972`, -1.4049427443329972`}, {
       1.2651650429449552`, -1.2651650429449552`}, {
       1.4049427443329972`, -1.4049427443329972`}}], 
      PolygonBox[{{1.4049427443329972`, -1.4049427443329972`}, {
       1.4373449933535234`, -1.230251642536255}, {1.5, -1.5}, {
       1.4049427443329972`, -1.4049427443329972`}}], 
      PolygonBox[{{1.5, -1.3576627826493677`}, {1.5, -1.5}, {
       1.4373449933535234`, -1.230251642536255}, {
       1.5, -1.3576627826493677`}}], 
      PolygonBox[{{1.4373449933535234`, -1.230251642536255}, {
       1.4374999810329407`, -1.0842925895560618`}, {
       1.5, -1.3576627826493677`}, {
       1.4373449933535234`, -1.230251642536255}}], 
      PolygonBox[{{1.5, -1.20590900530174}, {1.5, -1.3576627826493677`}, {
       1.4374999810329407`, -1.0842925895560618`}, {1.5, -1.20590900530174}}],
       PolygonBox[{{1.4374999810329407`, -1.0842925895560618`}, {
       1.4375, -1.}, {1.5, -1.20590900530174}, {
       1.4374999810329407`, -1.0842925895560618`}}], 
      PolygonBox[{{1.5, -1.}, {1.5, -1.20590900530174}, {1.4375, -1.}, {
       1.5, -1.}}], 
      PolygonBox[{{1.4375, -1.}, {1.4374999810329407`, -0.9157074104439382}, {
       1.5, -1.}, {1.4375, -1.}}], 
      PolygonBox[{{1.5, -0.79409099469826}, {1.5, -1.}, {
       1.4374999810329407`, -0.9157074104439382}, {1.5, -0.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, -0.9157074104439382}, {
       1.4373449933535234`, -0.7697483574637449}, {1.5, -0.79409099469826}, {
       1.4374999810329407`, -0.9157074104439382}}], 
      PolygonBox[{{1.5, -0.6423372173506324}, {1.5, -0.79409099469826}, {
       1.4373449933535234`, -0.7697483574637449}, {
       1.5, -0.6423372173506324}}], 
      PolygonBox[{{1.4373449933535234`, -0.7697483574637449}, {
       1.4049427443329972`, -0.5950572556670028}, {
       1.5, -0.6423372173506324}, {
       1.4373449933535234`, -0.7697483574637449}}], 
      PolygonBox[{{1.491446564961186, -0.508553435038814}, {
       1.5, -0.6423372173506324}, {
       1.4049427443329972`, -0.5950572556670028}, {
       1.491446564961186, -0.508553435038814}}], 
      PolygonBox[{{1.4049427443329972`, -0.5950572556670028}, {
       1.230251642536255, -0.5626550066464766}, {
       1.491446564961186, -0.508553435038814}, {
       1.4049427443329972`, -0.5950572556670028}}], 
      PolygonBox[{{1.3576627826493681`, -0.5}, {
       1.491446564961186, -0.508553435038814}, {
       1.230251642536255, -0.5626550066464766}, {1.3576627826493681`, -0.5}}],
       PolygonBox[{{1.230251642536255, -0.5626550066464766}, {
       1.0842925895560604`, -0.5625000189670593}, {
       1.3576627826493681`, -0.5}, {1.230251642536255, -0.5626550066464766}}],
       PolygonBox[{{1.2059090053732557`, -0.5}, {1.3576627826493681`, -0.5}, {
       1.0842925895560604`, -0.5625000189670593}, {
       1.2059090053732557`, -0.5}}], 
      PolygonBox[{{1.0842925895560604`, -0.5625000189670593}, {
       1.0001055272204877`, -0.5625}, {1.2059090053732557`, -0.5}, {
       1.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{1.07794195802689, -0.5}, {1.2059090053732557`, -0.5}, {
       1.0001055272204877`, -0.5625}, {1.07794195802689, -0.5}}], 
      PolygonBox[{{1.0001055272204877`, -0.5625}, {
       0.9157074104439431, -0.5625000189670593}, {1.07794195802689, -0.5}, {
       1.0001055272204877`, -0.5625}}], 
      PolygonBox[{{0.7940909946955543, -0.5}, {1.07794195802689, -0.5}, {
       0.9157074104439431, -0.5625000189670593}, {0.7940909946955543, -0.5}}],
       PolygonBox[{{0.9157074104439431, -0.5625000189670593}, {
       0.7697483574637449, -0.5626550066464766}, {0.7940909946955543, -0.5}, {
       0.9157074104439431, -0.5625000189670593}}], 
      PolygonBox[{{0.6423372173506338, -0.5}, {0.7940909946955543, -0.5}, {
       0.7697483574637449, -0.5626550066464766}, {0.6423372173506338, -0.5}}],
       PolygonBox[{{0.7697483574637449, -0.5626550066464766}, {
       0.5950572556670028, -0.5950572556670028}, {0.6423372173506338, -0.5}, {
       0.7697483574637449, -0.5626550066464766}}], 
      PolygonBox[{{1.5, -0.5}, {0.6423372173506338, -0.5}, {
       0.5950572556670028, -0.5950572556670028}, {1.5, -0.5}}], 
      PolygonBox[{{0.5950572556670028, -0.5950572556670028}, {
       0.5626550066464766, -0.7697483574637446}, {1.5, -0.5}, {
       0.5950572556670028, -0.5950572556670028}}], 
      PolygonBox[{{0.5, -0.642337217350631}, {1.5, -0.5}, {
       0.5626550066464766, -0.7697483574637446}, {0.5, -0.642337217350631}}], 
      PolygonBox[{{0.5626550066464766, -0.7697483574637446}, {
       0.5625000189670593, -0.9157074104439377}, {0.5, -0.642337217350631}, {
       0.5626550066464766, -0.7697483574637446}}], 
      PolygonBox[{{0.5, -0.7940909947171011}, {0.5, -0.642337217350631}, {
       0.5625000189670593, -0.9157074104439377}, {0.5, -0.7940909947171011}}],
       PolygonBox[{{0.5625000189670593, -0.9157074104439377}, {
       0.5625, -0.9998768219370047}, {0.5, -0.7940909947171011}, {
       0.5625000189670593, -0.9157074104439377}}], 
      PolygonBox[{{0.5, -0.9193213332412997}, {0.5, -0.7940909947171011}, {
       0.5625, -0.9998768219370047}, {0.5, -0.9193213332412997}}], 
      PolygonBox[{{0.5625, -0.9998768219370047}, {
       0.5625000189670593, -1.084292589556055}, {0.5, -0.9193213332412997}, {
       0.5625, -0.9998768219370047}}], 
      PolygonBox[{{0.5, -1.2059090051452785`}, {0.5, -0.9193213332412997}, {
       0.5625000189670593, -1.084292589556055}, {0.5, -1.2059090051452785`}}],
       PolygonBox[{{0.5625000189670593, -1.084292589556055}, {
       0.5626550066464766, -1.2302516425362549`}, {
       0.5, -1.2059090051452785`}, {0.5625000189670593, -1.084292589556055}}],
       PolygonBox[{{0.5, -1.3576627826493652`}, {0.5, -1.2059090051452785`}, {
       0.5626550066464766, -1.2302516425362549`}, {
       0.5, -1.3576627826493652`}}], 
      PolygonBox[{{0.5626550066464766, -1.2302516425362549`}, {
       0.5950572556670028, -1.4049427443329972`}, {
       0.5, -1.3576627826493652`}, {
       0.5626550066464766, -1.2302516425362549`}}], 
      PolygonBox[{{0.5, -0.5}, {0.5, -1.3576627826493652`}, {
       0.5950572556670028, -1.4049427443329972`}, {0.5, -0.5}}], 
      PolygonBox[{{0.5950572556670028, -1.4049427443329972`}, {
       0.7697483574637449, -1.4373449933535234`}, {0.5, -0.5}, {
       0.5950572556670028, -1.4049427443329972`}}], 
      PolygonBox[{{0.5, -1.5}, {0.5, -0.5}, {
       0.7697483574637449, -1.4373449933535234`}, {0.5, -1.5}}], 
      PolygonBox[{{0.7697483574637449, -1.4373449933535234`}, {
       0.9157074104439358, -1.4374999810329407`}, {0.5, -1.5}, {
       0.7697483574637449, -1.4373449933535234`}}], 
      PolygonBox[{{0.794090994433172, -1.5}, {0.5, -1.5}, {
       0.9157074104439358, -1.4374999810329407`}, {0.794090994433172, -1.5}}],
       PolygonBox[{{0.9157074104439358, -1.4374999810329407`}, {
       1.000134841831043, -1.4375}, {0.794090994433172, -1.5}, {
       0.9157074104439358, -1.4374999810329407`}}], 
      PolygonBox[{{1.0823238704010616`, -1.5}, {0.794090994433172, -1.5}, {
       1.000134841831043, -1.4375}, {1.0823238704010616`, -1.5}}], 
      PolygonBox[{{1.000134841831043, -1.4375}, {
       1.0842925895560531`, -1.4374999810329407`}, {
       1.0823238704010616`, -1.5}, {1.000134841831043, -1.4375}}], 
      PolygonBox[{{1.2059090053603974`, -1.5}, {1.0823238704010616`, -1.5}, {
       1.0842925895560531`, -1.4374999810329407`}, {
       1.2059090053603974`, -1.5}}], 
      PolygonBox[{{1.0842925895560531`, -1.4374999810329407`}, {
       1.2302516425362546`, -1.4373449933535234`}, {
       1.2059090053603974`, -1.5}, {
       1.0842925895560531`, -1.4374999810329407`}}], 
      PolygonBox[{{1.357662782649371, -1.5}, {1.2059090053603974`, -1.5}, {
       1.2302516425362546`, -1.4373449933535234`}, {
       1.357662782649371, -1.5}}], 
      PolygonBox[{{1.2302516425362546`, -1.4373449933535234`}, {
       1.4049427443329972`, -1.4049427443329972`}, {
       1.357662782649371, -1.5}, {
       1.2302516425362546`, -1.4373449933535234`}}], 
      PolygonBox[{{1.5, -1.5}, {1.357662782649371, -1.5}, {
       1.4049427443329972`, -1.4049427443329972`}, {1.5, -1.5}}], 
      PolygonBox[{{1.4049427443329972`, -1.4049427443329972`}, {
       1.4049427443329972`, -1.4049427443329972`}, {1.5, -1.5}, {
       1.4049427443329972`, -1.4049427443329972`}}], 
      PolygonBox[{{1.5, -1.5}, {1.5, -1.5}, {
       1.4049427443329972`, -1.4049427443329972`}, {
       1.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, 0.}, {0.5208333333333333, 0.}, {0.5416666666666667, 
       0.}, {0.5625, 0.}, {0.5833333333333333, 0.}, {0.6041666666666666, 
       0.}, {0.625, 0.}, {0.625, 0.}, {0.6041666666666667, 0.}, {
       0.5833333333333333, 0.}, {0.5625, 0.}, {0.5416666666666667, 0.}, {
       0.5208333333333334, 0.}, {0.5, 0.}, {0.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, 0.}, {1.3958333333333333`, 0.}, {1.4166666666666667`, 
       0.}, {1.4375, 0.}, {1.4583333333333333`, 0.}, {1.4791666666666665`, 
       0.}, {1.5, 0.}, {1.5, 0.}, {1.4791666666666667`, 0.}, {
       1.4583333333333333`, 0.}, {1.4375, 0.}, {1.4166666666666667`, 0.}, {
       1.3958333333333335`, 0.}, {1.375, 0.}, {1.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -0.5}, {1., -0.4791666666666667}, {
       1., -0.4583333333333333}, {1., -0.4375}, {1., -0.4166666666666667}, {
       1., -0.39583333333333337`}, {1., -0.375}, {1., -0.375}, {
       1., -0.3958333333333333}, {1., -0.4166666666666667}, {1., -0.4375}, {
       1., -0.4583333333333333}, {1., -0.47916666666666663`}, {1., -0.5}, {
       1., -0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 0.375}, {1., 0.3958333333333333}, {1., 
       0.4166666666666667}, {1., 0.4375}, {1., 0.4583333333333333}, {1., 
       0.47916666666666663`}, {1., 0.5}, {1., 0.5}, {1., 
       0.4791666666666667}, {1., 0.4583333333333333}, {1., 0.4375}, {1., 
       0.4166666666666667}, {1., 0.39583333333333337`}, {1., 0.375}, {1., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, 0.}, {0.75, 0.}, {0.875, 0.}, {1., 0.}, {1.125, 0.}, {
       1.25, 0.}, {1.375, 0.}, {1.375, 0.}, {1.25, 0.}, {1.125, 0.}, {1., 
       0.}, {0.875, 0.}, {0.75, 0.}, {0.625, 0.}, {0.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -0.375}, {1., -0.25}, {1., -0.125}, {1., 0.}, {1., 
       0.125}, {1., 0.25}, {1., 0.375}, {1., 0.375}, {1., 0.25}, {1., 
       0.125}, {1., 0.}, {1., -0.125}, {1., -0.25}, {1., -0.375}, {
       1., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7GGsK4tja1ee/mp/ozNm0Z4bO+wT+iZwmxt9
tf8PBsftzW6bb5a1+2J/M+f+mbIfF6D6Pts3WDrp3TlxxX7eCdVT3b0f7f37
y74u1bsOlf8ApW/YH83bkv3iyRv7AKg8I1j8FVz/FM8JM480P7e/BTXf4fG9
FxNnP7VnAas7YR+xw4V1bcYT+wdQ90HMfWLP1TXPx7KyywYmfw4ivx+m/w/E
/fsnQc2/DjF//z+w+Ev7Ooj9+w9B3ecHcd9+iL/fw9y/fy7UfwEo8p/sm6D6
YeEDdf9+WPixQdy/Hxa+76Dug4U/xP2z9gAAc7TL2w==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CH0A/uwUBD4CuevXgUCn+B8CP0BTf4Vmv6n
aOoJ0xB9V9H4R9HUwcAD+xCI/H5U/tX9aOZi8ENR3bd/Far796P5Dyr/CU3/
VzT1Pwjyw1DcB+MfRVMPAz9g/rNH5V+1R1X/wB4A4vVtfA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, -0.2651650429449553}, {
       1.3247595264191645`, -0.1875}, {
       1.4049427443329972`, -0.4049427443329971}, {
       1.2651650429449552`, -0.2651650429449553}}], 
      PolygonBox[{{1.4373449933535234`, -0.23025164253625516`}, {
       1.4049427443329972`, -0.4049427443329971}, {
       1.3247595264191645`, -0.1875}, {
       1.4373449933535234`, -0.23025164253625516`}}], 
      PolygonBox[{{1.3247595264191645`, -0.1875}, {
       1.3622221848584006`, -0.0970571419134453}, {
       1.4373449933535234`, -0.23025164253625516`}, {
       1.3247595264191645`, -0.1875}}], 
      PolygonBox[{{1.4374999810329407`, -0.08429258955606181}, {
       1.4373449933535234`, -0.23025164253625516`}, {
       1.3622221848584006`, -0.0970571419134453}, {
       1.4374999810329407`, -0.08429258955606181}}], 
      PolygonBox[{{1.3622221848584006`, -0.0970571419134453}, {1.375, 0.}, {
       1.4374999810329407`, -0.08429258955606181}, {
       1.3622221848584006`, -0.0970571419134453}}], 
      PolygonBox[{{1.4375, 0.}, {1.4374999810329407`, -0.08429258955606181}, {
       1.375, 0.}, {1.4375, 0.}}], 
      PolygonBox[{{1.375, 0.}, {1.3622221848584006`, 0.09705714191344525}, {
       1.4375, 0.}, {1.375, 0.}}], 
      PolygonBox[{{1.4374999810329407`, 0.08429258955606177}, {1.4375, 0.}, {
       1.3622221848584006`, 0.09705714191344525}, {1.4374999810329407`, 
       0.08429258955606177}}], 
      PolygonBox[{{1.3622221848584006`, 0.09705714191344525}, {
       1.3247595264191645`, 0.18749999999999994`}, {1.4374999810329407`, 
       0.08429258955606177}, {1.3622221848584006`, 0.09705714191344525}}], 
      PolygonBox[{{1.4373449933535234`, 0.23025164253625502`}, {
       1.4374999810329407`, 0.08429258955606177}, {1.3247595264191645`, 
       0.18749999999999994`}, {1.4373449933535234`, 0.23025164253625502`}}], 
      PolygonBox[{{1.3247595264191645`, 0.18749999999999994`}, {
       1.2651650429449552`, 0.2651650429449553}, {1.4373449933535234`, 
       0.23025164253625502`}, {1.3247595264191645`, 0.18749999999999994`}}], 
      PolygonBox[{{1.4049427443329972`, 0.40494274433299715`}, {
       1.4373449933535234`, 0.23025164253625502`}, {1.2651650429449552`, 
       0.2651650429449553}, {1.4049427443329972`, 0.40494274433299715`}}], 
      PolygonBox[{{1.2651650429449552`, 0.2651650429449553}, {1.1875, 
       0.3247595264191645}, {1.4049427443329972`, 0.40494274433299715`}, {
       1.2651650429449552`, 0.2651650429449553}}], 
      PolygonBox[{{1.230251642536255, 0.4373449933535234}, {
       1.4049427443329972`, 0.40494274433299715`}, {1.1875, 
       0.3247595264191645}, {1.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{1.1875, 0.3247595264191645}, {1.0970571419134454`, 
       0.3622221848584006}, {1.230251642536255, 0.4373449933535234}, {1.1875, 
       0.3247595264191645}}], 
      PolygonBox[{{1.0842925895560604`, 0.4374999810329408}, {
       1.230251642536255, 0.4373449933535234}, {1.0970571419134454`, 
       0.3622221848584006}, {1.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{1.0970571419134454`, 0.3622221848584006}, {1., 0.375}, {
       1.0842925895560604`, 0.4374999810329408}, {1.0970571419134454`, 
       0.3622221848584006}}], 
      PolygonBox[{{1.0001055272204877`, 0.4375}, {1.0842925895560604`, 
       0.4374999810329408}, {1., 0.375}, {1.0001055272204877`, 0.4375}}], 
      PolygonBox[{{1., 0.375}, {0.9029428580865548, 0.36222218485840063`}, {
       1.0001055272204877`, 0.4375}, {1., 0.375}}], 
      PolygonBox[{{0.9157074104439431, 0.4374999810329408}, {
       1.0001055272204877`, 0.4375}, {0.9029428580865548, 
       0.36222218485840063`}, {0.9157074104439431, 0.4374999810329408}}], 
      PolygonBox[{{0.9029428580865548, 0.36222218485840063`}, {
       0.8125000000000001, 0.3247595264191645}, {0.9157074104439431, 
       0.4374999810329408}, {0.9029428580865548, 0.36222218485840063`}}], 
      PolygonBox[{{0.7697483574637449, 0.4373449933535234}, {
       0.9157074104439431, 0.4374999810329408}, {0.8125000000000001, 
       0.3247595264191645}, {0.7697483574637449, 0.4373449933535234}}], 
      PolygonBox[{{0.8125000000000001, 0.3247595264191645}, {
       0.7348349570550448, 0.26516504294495535`}, {0.7697483574637449, 
       0.4373449933535234}, {0.8125000000000001, 0.3247595264191645}}], 
      PolygonBox[{{0.5950572556670028, 0.40494274433299715`}, {
       0.7697483574637449, 0.4373449933535234}, {0.7348349570550448, 
       0.26516504294495535`}, {0.5950572556670028, 0.40494274433299715`}}], 
      PolygonBox[{{0.7348349570550448, 0.26516504294495535`}, {
       0.6752404735808355, 0.1875000000000001}, {0.5950572556670028, 
       0.40494274433299715`}, {0.7348349570550448, 0.26516504294495535`}}], 
      PolygonBox[{{0.5626550066464766, 0.2302516425362554}, {
       0.5950572556670028, 0.40494274433299715`}, {0.6752404735808355, 
       0.1875000000000001}, {0.5626550066464766, 0.2302516425362554}}], 
      PolygonBox[{{0.6752404735808355, 0.1875000000000001}, {
       0.6377778151415994, 0.09705714191344539}, {0.5626550066464766, 
       0.2302516425362554}, {0.6752404735808355, 0.1875000000000001}}], 
      PolygonBox[{{0.5625000189670593, 0.08429258955606238}, {
       0.5626550066464766, 0.2302516425362554}, {0.6377778151415994, 
       0.09705714191344539}, {0.5625000189670593, 0.08429258955606238}}], 
      PolygonBox[{{0.6377778151415994, 0.09705714191344539}, {0.625, 
       2.1245770866179924`*^-16}, {0.5625000189670593, 0.08429258955606238}, {
       0.6377778151415994, 0.09705714191344539}}], 
      PolygonBox[{{0.5625, 0.00012317806299537147`}, {0.5625000189670593, 
       0.08429258955606238}, {0.625, 2.1245770866179924`*^-16}, {0.5625, 
       0.00012317806299537147`}}], 
      PolygonBox[{{0.625, 2.1245770866179924`*^-16}, {
       0.6377778151415994, -0.09705714191344514}, {0.5625, 
       0.00012317806299537147`}, {0.625, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{0.5625000189670593, -0.084292589556055}, {0.5625, 
       0.00012317806299537147`}, {0.6377778151415994, -0.09705714191344514}, {
       0.5625000189670593, -0.084292589556055}}], 
      PolygonBox[{{0.6377778151415994, -0.09705714191344514}, {
       0.6752404735808354, -0.18749999999999978`}, {
       0.5625000189670593, -0.084292589556055}, {
       0.6377778151415994, -0.09705714191344514}}], 
      PolygonBox[{{0.5626550066464766, -0.23025164253625477`}, {
       0.5625000189670593, -0.084292589556055}, {
       0.6752404735808354, -0.18749999999999978`}, {
       0.5626550066464766, -0.23025164253625477`}}], 
      PolygonBox[{{0.6752404735808354, -0.18749999999999978`}, {
       0.7348349570550446, -0.2651650429449553}, {
       0.5626550066464766, -0.23025164253625477`}, {
       0.6752404735808354, -0.18749999999999978`}}], 
      PolygonBox[{{0.5950572556670028, -0.4049427443329971}, {
       0.5626550066464766, -0.23025164253625477`}, {
       0.7348349570550446, -0.2651650429449553}, {
       0.5950572556670028, -0.4049427443329971}}], 
      PolygonBox[{{0.7348349570550446, -0.2651650429449553}, {
       0.8124999999999998, -0.3247595264191644}, {
       0.5950572556670028, -0.4049427443329971}, {
       0.7348349570550446, -0.2651650429449553}}], 
      PolygonBox[{{0.7697483574637449, -0.4373449933535234}, {
       0.5950572556670028, -0.4049427443329971}, {
       0.8124999999999998, -0.3247595264191644}, {
       0.7697483574637449, -0.4373449933535234}}], 
      PolygonBox[{{0.8124999999999998, -0.3247595264191644}, {
       0.9029428580865544, -0.3622221848584005}, {
       0.7697483574637449, -0.4373449933535234}, {
       0.8124999999999998, -0.3247595264191644}}], 
      PolygonBox[{{0.9157074104439358, -0.4374999810329408}, {
       0.7697483574637449, -0.4373449933535234}, {
       0.9029428580865544, -0.3622221848584005}, {
       0.9157074104439358, -0.4374999810329408}}], 
      PolygonBox[{{0.9029428580865544, -0.3622221848584005}, {1., -0.375}, {
       0.9157074104439358, -0.4374999810329408}, {
       0.9029428580865544, -0.3622221848584005}}], 
      PolygonBox[{{1.000134841831043, -0.4375}, {
       0.9157074104439358, -0.4374999810329408}, {1., -0.375}, {
       1.000134841831043, -0.4375}}], 
      PolygonBox[{{1., -0.375}, {
       1.0970571419134452`, -0.36222218485840063`}, {
       1.000134841831043, -0.4375}, {1., -0.375}}], 
      PolygonBox[{{1.0842925895560531`, -0.4374999810329408}, {
       1.000134841831043, -0.4375}, {
       1.0970571419134452`, -0.36222218485840063`}, {
       1.0842925895560531`, -0.4374999810329408}}], 
      PolygonBox[{{1.0970571419134452`, -0.36222218485840063`}, {
       1.1874999999999998`, -0.3247595264191646}, {
       1.0842925895560531`, -0.4374999810329408}, {
       1.0970571419134452`, -0.36222218485840063`}}], 
      PolygonBox[{{1.2302516425362546`, -0.4373449933535234}, {
       1.0842925895560531`, -0.4374999810329408}, {
       1.1874999999999998`, -0.3247595264191646}, {
       1.2302516425362546`, -0.4373449933535234}}], 
      PolygonBox[{{1.1874999999999998`, -0.3247595264191646}, {
       1.2651650429449552`, -0.26516504294495535`}, {
       1.2302516425362546`, -0.4373449933535234}, {
       1.1874999999999998`, -0.3247595264191646}}], 
      PolygonBox[{{1.4049427443329972`, -0.40494274433299715`}, {
       1.2302516425362546`, -0.4373449933535234}, {
       1.2651650429449552`, -0.26516504294495535`}, {
       1.4049427443329972`, -0.40494274433299715`}}], 
      PolygonBox[{{1.2651650429449552`, -0.26516504294495535`}, {
       1.2651650429449552`, -0.2651650429449553}, {
       1.4049427443329972`, -0.40494274433299715`}, {
       1.2651650429449552`, -0.26516504294495535`}}], 
      PolygonBox[{{1.4049427443329972`, -0.4049427443329971}, {
       1.4049427443329972`, -0.40494274433299715`}, {
       1.2651650429449552`, -0.2651650429449553}, {
       1.4049427443329972`, -0.4049427443329971}}], 
      PolygonBox[{{1.4049427443329972`, -0.4049427443329971}, {
       1.4373449933535234`, -0.23025164253625516`}, {1.5, -0.5}, {
       1.4049427443329972`, -0.4049427443329971}}], 
      PolygonBox[{{1.5, -0.3576627826493677}, {1.5, -0.5}, {
       1.4373449933535234`, -0.23025164253625516`}, {
       1.5, -0.3576627826493677}}], 
      PolygonBox[{{1.4373449933535234`, -0.23025164253625516`}, {
       1.4374999810329407`, -0.08429258955606181}, {
       1.5, -0.3576627826493677}, {
       1.4373449933535234`, -0.23025164253625516`}}], 
      PolygonBox[{{1.5, -0.20590900530173997`}, {1.5, -0.3576627826493677}, {
       1.4374999810329407`, -0.08429258955606181}, {
       1.5, -0.20590900530173997`}}], 
      PolygonBox[{{1.4374999810329407`, -0.08429258955606181}, {1.4375, 0.}, {
       1.5, -0.20590900530173997`}, {
       1.4374999810329407`, -0.08429258955606181}}], 
      PolygonBox[{{1.5, 0.}, {1.5, -0.20590900530173997`}, {1.4375, 0.}, {1.5,
        0.}}], PolygonBox[{{1.4375, 0.}, {1.4374999810329407`, 
       0.08429258955606177}, {1.5, 0.}, {1.4375, 0.}}], 
      PolygonBox[{{1.5, 0.20590900530173992`}, {1.5, 0.}, {
       1.4374999810329407`, 0.08429258955606177}, {1.5, 
       0.20590900530173992`}}], 
      PolygonBox[{{1.4374999810329407`, 0.08429258955606177}, {
       1.4373449933535234`, 0.23025164253625502`}, {1.5, 
       0.20590900530173992`}, {1.4374999810329407`, 0.08429258955606177}}], 
      PolygonBox[{{1.5, 0.35766278264936757`}, {1.5, 0.20590900530173992`}, {
       1.4373449933535234`, 0.23025164253625502`}, {1.5, 
       0.35766278264936757`}}], 
      PolygonBox[{{1.4373449933535234`, 0.23025164253625502`}, {
       1.4049427443329972`, 0.40494274433299715`}, {1.5, 
       0.35766278264936757`}, {1.4373449933535234`, 0.23025164253625502`}}], 
      PolygonBox[{{1.491446564961186, 0.491446564961186}, {1.5, 
       0.35766278264936757`}, {1.4049427443329972`, 0.40494274433299715`}, {
       1.491446564961186, 0.491446564961186}}], 
      PolygonBox[{{1.4049427443329972`, 0.40494274433299715`}, {
       1.230251642536255, 0.4373449933535234}, {1.491446564961186, 
       0.491446564961186}, {1.4049427443329972`, 0.40494274433299715`}}], 
      PolygonBox[{{1.3576627826493681`, 0.5}, {1.491446564961186, 
       0.491446564961186}, {1.230251642536255, 0.4373449933535234}, {
       1.3576627826493681`, 0.5}}], 
      PolygonBox[{{1.230251642536255, 0.4373449933535234}, {
       1.0842925895560604`, 0.4374999810329408}, {1.3576627826493681`, 0.5}, {
       1.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{1.2059090053732557`, 0.5}, {1.3576627826493681`, 0.5}, {
       1.0842925895560604`, 0.4374999810329408}, {1.2059090053732557`, 0.5}}],
       PolygonBox[{{1.0842925895560604`, 0.4374999810329408}, {
       1.0001055272204877`, 0.4375}, {1.2059090053732557`, 0.5}, {
       1.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{1.07794195802689, 0.5}, {1.2059090053732557`, 0.5}, {
       1.0001055272204877`, 0.4375}, {1.07794195802689, 0.5}}], 
      PolygonBox[{{1.0001055272204877`, 0.4375}, {0.9157074104439431, 
       0.4374999810329408}, {1.07794195802689, 0.5}, {1.0001055272204877`, 
       0.4375}}], 
      PolygonBox[{{0.7940909946955543, 0.5}, {1.07794195802689, 0.5}, {
       0.9157074104439431, 0.4374999810329408}, {0.7940909946955543, 0.5}}], 
      PolygonBox[{{0.9157074104439431, 0.4374999810329408}, {
       0.7697483574637449, 0.4373449933535234}, {0.7940909946955543, 0.5}, {
       0.9157074104439431, 0.4374999810329408}}], 
      PolygonBox[{{0.6423372173506338, 0.5}, {0.7940909946955543, 0.5}, {
       0.7697483574637449, 0.4373449933535234}, {0.6423372173506338, 0.5}}], 
      PolygonBox[{{0.7697483574637449, 0.4373449933535234}, {
       0.5950572556670028, 0.40494274433299715`}, {0.6423372173506338, 0.5}, {
       0.7697483574637449, 0.4373449933535234}}], 
      PolygonBox[{{1.5, 0.5}, {0.6423372173506338, 0.5}, {0.5950572556670028, 
       0.40494274433299715`}, {1.5, 0.5}}], 
      PolygonBox[{{0.5950572556670028, 0.40494274433299715`}, {
       0.5626550066464766, 0.2302516425362554}, {1.5, 0.5}, {
       0.5950572556670028, 0.40494274433299715`}}], 
      PolygonBox[{{0.5, 0.357662782649369}, {1.5, 0.5}, {0.5626550066464766, 
       0.2302516425362554}, {0.5, 0.357662782649369}}], 
      PolygonBox[{{0.5626550066464766, 0.2302516425362554}, {
       0.5625000189670593, 0.08429258955606238}, {0.5, 0.357662782649369}, {
       0.5626550066464766, 0.2302516425362554}}], 
      PolygonBox[{{0.5, 0.20590900528289896`}, {0.5, 0.357662782649369}, {
       0.5625000189670593, 0.08429258955606238}, {0.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{0.5625000189670593, 0.08429258955606238}, {0.5625, 
       0.00012317806299537147`}, {0.5, 0.20590900528289896`}, {
       0.5625000189670593, 0.08429258955606238}}], 
      PolygonBox[{{0.5, 0.08067866675870025}, {0.5, 0.20590900528289896`}, {
       0.5625, 0.00012317806299537147`}, {0.5, 0.08067866675870025}}], 
      PolygonBox[{{0.5625, 0.00012317806299537147`}, {
       0.5625000189670593, -0.084292589556055}, {0.5, 0.08067866675870025}, {
       0.5625, 0.00012317806299537147`}}], 
      PolygonBox[{{0.5, -0.20590900514527852`}, {0.5, 0.08067866675870025}, {
       0.5625000189670593, -0.084292589556055}, {
       0.5, -0.20590900514527852`}}], 
      PolygonBox[{{0.5625000189670593, -0.084292589556055}, {
       0.5626550066464766, -0.23025164253625477`}, {
       0.5, -0.20590900514527852`}, {
       0.5625000189670593, -0.084292589556055}}], 
      PolygonBox[{{0.5, -0.35766278264936535`}, {
       0.5, -0.20590900514527852`}, {
       0.5626550066464766, -0.23025164253625477`}, {
       0.5, -0.35766278264936535`}}], 
      PolygonBox[{{0.5626550066464766, -0.23025164253625477`}, {
       0.5950572556670028, -0.4049427443329971}, {
       0.5, -0.35766278264936535`}, {
       0.5626550066464766, -0.23025164253625477`}}], 
      PolygonBox[{{0.5, 0.5}, {0.5, -0.35766278264936535`}, {
       0.5950572556670028, -0.4049427443329971}, {0.5, 0.5}}], 
      PolygonBox[{{0.5950572556670028, -0.4049427443329971}, {
       0.7697483574637449, -0.4373449933535234}, {0.5, 0.5}, {
       0.5950572556670028, -0.4049427443329971}}], 
      PolygonBox[{{0.5, -0.5}, {0.5, 0.5}, {
       0.7697483574637449, -0.4373449933535234}, {0.5, -0.5}}], 
      PolygonBox[{{0.7697483574637449, -0.4373449933535234}, {
       0.9157074104439358, -0.4374999810329408}, {0.5, -0.5}, {
       0.7697483574637449, -0.4373449933535234}}], 
      PolygonBox[{{0.794090994433172, -0.5}, {0.5, -0.5}, {
       0.9157074104439358, -0.4374999810329408}, {0.794090994433172, -0.5}}], 
      PolygonBox[{{0.9157074104439358, -0.4374999810329408}, {
       1.000134841831043, -0.4375}, {0.794090994433172, -0.5}, {
       0.9157074104439358, -0.4374999810329408}}], 
      PolygonBox[{{1.0823238704010616`, -0.5}, {0.794090994433172, -0.5}, {
       1.000134841831043, -0.4375}, {1.0823238704010616`, -0.5}}], 
      PolygonBox[{{1.000134841831043, -0.4375}, {
       1.0842925895560531`, -0.4374999810329408}, {
       1.0823238704010616`, -0.5}, {1.000134841831043, -0.4375}}], 
      PolygonBox[{{1.2059090053603974`, -0.5}, {1.0823238704010616`, -0.5}, {
       1.0842925895560531`, -0.4374999810329408}, {
       1.2059090053603974`, -0.5}}], 
      PolygonBox[{{1.0842925895560531`, -0.4374999810329408}, {
       1.2302516425362546`, -0.4373449933535234}, {
       1.2059090053603974`, -0.5}, {
       1.0842925895560531`, -0.4374999810329408}}], 
      PolygonBox[{{1.357662782649371, -0.5}, {1.2059090053603974`, -0.5}, {
       1.2302516425362546`, -0.4373449933535234}, {1.357662782649371, -0.5}}],
       PolygonBox[{{1.2302516425362546`, -0.4373449933535234}, {
       1.4049427443329972`, -0.40494274433299715`}, {
       1.357662782649371, -0.5}, {1.2302516425362546`, -0.4373449933535234}}],
       PolygonBox[{{1.5, -0.5}, {1.357662782649371, -0.5}, {
       1.4049427443329972`, -0.40494274433299715`}, {1.5, -0.5}}], 
      PolygonBox[{{1.4049427443329972`, -0.40494274433299715`}, {
       1.4049427443329972`, -0.4049427443329971}, {1.5, -0.5}, {
       1.4049427443329972`, -0.40494274433299715`}}], 
      PolygonBox[{{1.5, -0.5}, {1.5, -0.5}, {
       1.4049427443329972`, -0.4049427443329971}, {
       1.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, 1.}, {0.5208333333333333, 1.}, {0.5416666666666667, 
       1.}, {0.5625, 1.}, {0.5833333333333333, 1.}, {0.6041666666666666, 
       1.}, {0.625, 1.}, {0.625, 1.}, {0.6041666666666667, 1.}, {
       0.5833333333333333, 1.}, {0.5625, 1.}, {0.5416666666666667, 1.}, {
       0.5208333333333334, 1.}, {0.5, 1.}, {0.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, 1.}, {1.3958333333333333`, 1.}, {1.4166666666666667`, 
       1.}, {1.4375, 1.}, {1.4583333333333333`, 1.}, {1.4791666666666665`, 
       1.}, {1.5, 1.}, {1.5, 1.}, {1.4791666666666667`, 1.}, {
       1.4583333333333333`, 1.}, {1.4375, 1.}, {1.4166666666666667`, 1.}, {
       1.3958333333333335`, 1.}, {1.375, 1.}, {1.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 0.5}, {1., 0.5208333333333333}, {1., 
       0.5416666666666667}, {1., 0.5625}, {1., 0.5833333333333333}, {1., 
       0.6041666666666666}, {1., 0.625}, {1., 0.625}, {1., 
       0.6041666666666667}, {1., 0.5833333333333333}, {1., 0.5625}, {1., 
       0.5416666666666667}, {1., 0.5208333333333334}, {1., 0.5}, {1., 0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 1.375}, {1., 1.3958333333333333`}, {1., 
       1.4166666666666667`}, {1., 1.4375}, {1., 1.4583333333333333`}, {1., 
       1.4791666666666665`}, {1., 1.5}, {1., 1.5}, {1., 
       1.4791666666666667`}, {1., 1.4583333333333333`}, {1., 1.4375}, {1., 
       1.4166666666666667`}, {1., 1.3958333333333335`}, {1., 1.375}, {1., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, 1.}, {0.75, 1.}, {0.875, 1.}, {1., 1.}, {1.125, 1.}, {
       1.25, 1.}, {1.375, 1.}, {1.375, 1.}, {1.25, 1.}, {1.125, 1.}, {1., 
       1.}, {0.875, 1.}, {0.75, 1.}, {0.625, 1.}, {0.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 0.625}, {1., 0.75}, {1., 0.875}, {1., 1.}, {1., 1.125}, {
       1., 1.25}, {1., 1.375}, {1., 1.375}, {1., 1.25}, {1., 1.125}, {1., 
       1.}, {1., 0.875}, {1., 0.75}, {1., 0.625}, {1., 0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CH0B/sri2NrV57+aj/vhOqp7t6P9gl9E7jN
jb5C5T/bm9023yxr9wVOw8Rh6mD6YObAzIXZczRvS/aLJ2/g8oxg8Vdw/VM8
J8w80vwcbr7D43svJs5+CrcnYocL69qMJ3B7IOJP4PbA5I9B7YHph9kzCWo+
zJ5//0Hgpb0jVN0hqL5IqDlg6f/v4fbMhdobgSL/yd4eqh/m7slQ82H+gtkD
8zfMHli4wOwBAFgUwAQ=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7GF0WCgIfIXzV68CgU/2qOo+oMm/QtP/FE39
A4J8VHsfoNn7AM3eB2j2PkCz9wFOOhRN3So0c9DtWYXmjlA0dxLrz1C0cFmF
Fm7o4boKLdxD0eIFRgMANmpzMg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, 0.7348349570550448}, {
       1.3247595264191645`, 0.8125}, {1.4049427443329972`, 
       0.5950572556670028}, {1.2651650429449552`, 0.7348349570550448}}], 
      PolygonBox[{{1.4373449933535234`, 0.7697483574637448}, {
       1.4049427443329972`, 0.5950572556670028}, {1.3247595264191645`, 
       0.8125}, {1.4373449933535234`, 0.7697483574637448}}], 
      PolygonBox[{{1.3247595264191645`, 0.8125}, {1.3622221848584006`, 
       0.9029428580865547}, {1.4373449933535234`, 0.7697483574637448}, {
       1.3247595264191645`, 0.8125}}], 
      PolygonBox[{{1.4374999810329407`, 0.9157074104439382}, {
       1.4373449933535234`, 0.7697483574637448}, {1.3622221848584006`, 
       0.9029428580865547}, {1.4374999810329407`, 0.9157074104439382}}], 
      PolygonBox[{{1.3622221848584006`, 0.9029428580865547}, {1.375, 1.}, {
       1.4374999810329407`, 0.9157074104439382}, {1.3622221848584006`, 
       0.9029428580865547}}], 
      PolygonBox[{{1.4375, 1.}, {1.4374999810329407`, 0.9157074104439382}, {
       1.375, 1.}, {1.4375, 1.}}], 
      PolygonBox[{{1.375, 1.}, {1.3622221848584006`, 1.0970571419134452`}, {
       1.4375, 1.}, {1.375, 1.}}], 
      PolygonBox[{{1.4374999810329407`, 1.0842925895560618`}, {1.4375, 1.}, {
       1.3622221848584006`, 1.0970571419134452`}, {1.4374999810329407`, 
       1.0842925895560618`}}], 
      PolygonBox[{{1.3622221848584006`, 1.0970571419134452`}, {
       1.3247595264191645`, 1.1875}, {1.4374999810329407`, 
       1.0842925895560618`}, {1.3622221848584006`, 1.0970571419134452`}}], 
      PolygonBox[{{1.4373449933535234`, 1.230251642536255}, {
       1.4374999810329407`, 1.0842925895560618`}, {1.3247595264191645`, 
       1.1875}, {1.4373449933535234`, 1.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, 1.1875}, {1.2651650429449552`, 
       1.2651650429449552`}, {1.4373449933535234`, 1.230251642536255}, {
       1.3247595264191645`, 1.1875}}], 
      PolygonBox[{{1.4049427443329972`, 1.4049427443329972`}, {
       1.4373449933535234`, 1.230251642536255}, {1.2651650429449552`, 
       1.2651650429449552`}, {1.4049427443329972`, 1.4049427443329972`}}], 
      PolygonBox[{{1.2651650429449552`, 1.2651650429449552`}, {1.1875, 
       1.3247595264191645`}, {1.4049427443329972`, 1.4049427443329972`}, {
       1.2651650429449552`, 1.2651650429449552`}}], 
      PolygonBox[{{1.230251642536255, 1.4373449933535234`}, {
       1.4049427443329972`, 1.4049427443329972`}, {1.1875, 
       1.3247595264191645`}, {1.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{1.1875, 1.3247595264191645`}, {1.0970571419134454`, 
       1.3622221848584006`}, {1.230251642536255, 1.4373449933535234`}, {
       1.1875, 1.3247595264191645`}}], 
      PolygonBox[{{1.0842925895560604`, 1.4374999810329407`}, {
       1.230251642536255, 1.4373449933535234`}, {1.0970571419134454`, 
       1.3622221848584006`}, {1.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{1.0970571419134454`, 1.3622221848584006`}, {1., 1.375}, {
       1.0842925895560604`, 1.4374999810329407`}, {1.0970571419134454`, 
       1.3622221848584006`}}], 
      PolygonBox[{{1.0001055272204877`, 1.4375}, {1.0842925895560604`, 
       1.4374999810329407`}, {1., 1.375}, {1.0001055272204877`, 1.4375}}], 
      PolygonBox[{{1., 1.375}, {0.9029428580865548, 1.3622221848584006`}, {
       1.0001055272204877`, 1.4375}, {1., 1.375}}], 
      PolygonBox[{{0.9157074104439431, 1.4374999810329407`}, {
       1.0001055272204877`, 1.4375}, {0.9029428580865548, 
       1.3622221848584006`}, {0.9157074104439431, 1.4374999810329407`}}], 
      PolygonBox[{{0.9029428580865548, 1.3622221848584006`}, {
       0.8125000000000001, 1.3247595264191645`}, {0.9157074104439431, 
       1.4374999810329407`}, {0.9029428580865548, 1.3622221848584006`}}], 
      PolygonBox[{{0.7697483574637449, 1.4373449933535234`}, {
       0.9157074104439431, 1.4374999810329407`}, {0.8125000000000001, 
       1.3247595264191645`}, {0.7697483574637449, 1.4373449933535234`}}], 
      PolygonBox[{{0.8125000000000001, 1.3247595264191645`}, {
       0.7348349570550448, 1.2651650429449552`}, {0.7697483574637449, 
       1.4373449933535234`}, {0.8125000000000001, 1.3247595264191645`}}], 
      PolygonBox[{{0.5950572556670028, 1.4049427443329972`}, {
       0.7697483574637449, 1.4373449933535234`}, {0.7348349570550448, 
       1.2651650429449552`}, {0.5950572556670028, 1.4049427443329972`}}], 
      PolygonBox[{{0.7348349570550448, 1.2651650429449552`}, {
       0.6752404735808355, 1.1875}, {0.5950572556670028, 
       1.4049427443329972`}, {0.7348349570550448, 1.2651650429449552`}}], 
      PolygonBox[{{0.5626550066464766, 1.2302516425362553`}, {
       0.5950572556670028, 1.4049427443329972`}, {0.6752404735808355, 
       1.1875}, {0.5626550066464766, 1.2302516425362553`}}], 
      PolygonBox[{{0.6752404735808355, 1.1875}, {0.6377778151415994, 
       1.0970571419134454`}, {0.5626550066464766, 1.2302516425362553`}, {
       0.6752404735808355, 1.1875}}], 
      PolygonBox[{{0.5625000189670593, 1.0842925895560624`}, {
       0.5626550066464766, 1.2302516425362553`}, {0.6377778151415994, 
       1.0970571419134454`}, {0.5625000189670593, 1.0842925895560624`}}], 
      PolygonBox[{{0.6377778151415994, 1.0970571419134454`}, {0.625, 
       1.0000000000000002`}, {0.5625000189670593, 1.0842925895560624`}, {
       0.6377778151415994, 1.0970571419134454`}}], 
      PolygonBox[{{0.5625, 1.0001231780629953`}, {0.5625000189670593, 
       1.0842925895560624`}, {0.625, 1.0000000000000002`}, {0.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{0.625, 1.0000000000000002`}, {0.6377778151415994, 
       0.9029428580865548}, {0.5625, 1.0001231780629953`}, {0.625, 
       1.0000000000000002`}}], 
      PolygonBox[{{0.5625000189670593, 0.915707410443945}, {0.5625, 
       1.0001231780629953`}, {0.6377778151415994, 0.9029428580865548}, {
       0.5625000189670593, 0.915707410443945}}], 
      PolygonBox[{{0.6377778151415994, 0.9029428580865548}, {
       0.6752404735808354, 0.8125000000000002}, {0.5625000189670593, 
       0.915707410443945}, {0.6377778151415994, 0.9029428580865548}}], 
      PolygonBox[{{0.5626550066464766, 0.7697483574637453}, {
       0.5625000189670593, 0.915707410443945}, {0.6752404735808354, 
       0.8125000000000002}, {0.5626550066464766, 0.7697483574637453}}], 
      PolygonBox[{{0.6752404735808354, 0.8125000000000002}, {
       0.7348349570550446, 0.7348349570550448}, {0.5626550066464766, 
       0.7697483574637453}, {0.6752404735808354, 0.8125000000000002}}], 
      PolygonBox[{{0.5950572556670028, 0.5950572556670028}, {
       0.5626550066464766, 0.7697483574637453}, {0.7348349570550446, 
       0.7348349570550448}, {0.5950572556670028, 0.5950572556670028}}], 
      PolygonBox[{{0.7348349570550446, 0.7348349570550448}, {
       0.8124999999999998, 0.6752404735808356}, {0.5950572556670028, 
       0.5950572556670028}, {0.7348349570550446, 0.7348349570550448}}], 
      PolygonBox[{{0.7697483574637449, 0.5626550066464766}, {
       0.5950572556670028, 0.5950572556670028}, {0.8124999999999998, 
       0.6752404735808356}, {0.7697483574637449, 0.5626550066464766}}], 
      PolygonBox[{{0.8124999999999998, 0.6752404735808356}, {
       0.9029428580865544, 0.6377778151415995}, {0.7697483574637449, 
       0.5626550066464766}, {0.8124999999999998, 0.6752404735808356}}], 
      PolygonBox[{{0.9157074104439358, 0.5625000189670593}, {
       0.7697483574637449, 0.5626550066464766}, {0.9029428580865544, 
       0.6377778151415995}, {0.9157074104439358, 0.5625000189670593}}], 
      PolygonBox[{{0.9029428580865544, 0.6377778151415995}, {1., 0.625}, {
       0.9157074104439358, 0.5625000189670593}, {0.9029428580865544, 
       0.6377778151415995}}], 
      PolygonBox[{{1.000134841831043, 0.5625}, {0.9157074104439358, 
       0.5625000189670593}, {1., 0.625}, {1.000134841831043, 0.5625}}], 
      PolygonBox[{{1., 0.625}, {1.0970571419134452`, 0.6377778151415994}, {
       1.000134841831043, 0.5625}, {1., 0.625}}], 
      PolygonBox[{{1.0842925895560531`, 0.5625000189670593}, {
       1.000134841831043, 0.5625}, {1.0970571419134452`, 
       0.6377778151415994}, {1.0842925895560531`, 0.5625000189670593}}], 
      PolygonBox[{{1.0970571419134452`, 0.6377778151415994}, {
       1.1874999999999998`, 0.6752404735808354}, {1.0842925895560531`, 
       0.5625000189670593}, {1.0970571419134452`, 0.6377778151415994}}], 
      PolygonBox[{{1.2302516425362546`, 0.5626550066464766}, {
       1.0842925895560531`, 0.5625000189670593}, {1.1874999999999998`, 
       0.6752404735808354}, {1.2302516425362546`, 0.5626550066464766}}], 
      PolygonBox[{{1.1874999999999998`, 0.6752404735808354}, {
       1.2651650429449552`, 0.7348349570550446}, {1.2302516425362546`, 
       0.5626550066464766}, {1.1874999999999998`, 0.6752404735808354}}], 
      PolygonBox[{{1.4049427443329972`, 0.5950572556670028}, {
       1.2302516425362546`, 0.5626550066464766}, {1.2651650429449552`, 
       0.7348349570550446}, {1.4049427443329972`, 0.5950572556670028}}], 
      PolygonBox[{{1.2651650429449552`, 0.7348349570550446}, {
       1.2651650429449552`, 0.7348349570550448}, {1.4049427443329972`, 
       0.5950572556670028}, {1.2651650429449552`, 0.7348349570550446}}], 
      PolygonBox[{{1.4049427443329972`, 0.5950572556670028}, {
       1.4049427443329972`, 0.5950572556670028}, {1.2651650429449552`, 
       0.7348349570550448}, {1.4049427443329972`, 0.5950572556670028}}], 
      PolygonBox[{{1.4049427443329972`, 0.5950572556670028}, {
       1.4373449933535234`, 0.7697483574637448}, {1.5, 0.5}, {
       1.4049427443329972`, 0.5950572556670028}}], 
      PolygonBox[{{1.5, 0.6423372173506323}, {1.5, 0.5}, {1.4373449933535234`,
        0.7697483574637448}, {1.5, 0.6423372173506323}}], 
      PolygonBox[{{1.4373449933535234`, 0.7697483574637448}, {
       1.4374999810329407`, 0.9157074104439382}, {1.5, 0.6423372173506323}, {
       1.4373449933535234`, 0.7697483574637448}}], 
      PolygonBox[{{1.5, 0.79409099469826}, {1.5, 0.6423372173506323}, {
       1.4374999810329407`, 0.9157074104439382}, {1.5, 0.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, 0.9157074104439382}, {1.4375, 1.}, {
       1.5, 0.79409099469826}, {1.4374999810329407`, 0.9157074104439382}}], 
      PolygonBox[{{1.5, 1.}, {1.5, 0.79409099469826}, {1.4375, 1.}, {1.5, 
       1.}}], PolygonBox[{{1.4375, 1.}, {1.4374999810329407`, 
       1.0842925895560618`}, {1.5, 1.}, {1.4375, 1.}}], 
      PolygonBox[{{1.5, 1.2059090053017398`}, {1.5, 1.}, {1.4374999810329407`,
        1.0842925895560618`}, {1.5, 1.2059090053017398`}}], 
      PolygonBox[{{1.4374999810329407`, 1.0842925895560618`}, {
       1.4373449933535234`, 1.230251642536255}, {1.5, 1.2059090053017398`}, {
       1.4374999810329407`, 1.0842925895560618`}}], 
      PolygonBox[{{1.5, 1.3576627826493675`}, {1.5, 1.2059090053017398`}, {
       1.4373449933535234`, 1.230251642536255}, {1.5, 1.3576627826493675`}}], 
      PolygonBox[{{1.4373449933535234`, 1.230251642536255}, {
       1.4049427443329972`, 1.4049427443329972`}, {1.5, 
       1.3576627826493675`}, {1.4373449933535234`, 1.230251642536255}}], 
      PolygonBox[{{1.491446564961186, 1.491446564961186}, {1.5, 
       1.3576627826493675`}, {1.4049427443329972`, 1.4049427443329972`}, {
       1.491446564961186, 1.491446564961186}}], 
      PolygonBox[{{1.4049427443329972`, 1.4049427443329972`}, {
       1.230251642536255, 1.4373449933535234`}, {1.491446564961186, 
       1.491446564961186}, {1.4049427443329972`, 1.4049427443329972`}}], 
      PolygonBox[{{1.3576627826493681`, 1.5}, {1.491446564961186, 
       1.491446564961186}, {1.230251642536255, 1.4373449933535234`}, {
       1.3576627826493681`, 1.5}}], 
      PolygonBox[{{1.230251642536255, 1.4373449933535234`}, {
       1.0842925895560604`, 1.4374999810329407`}, {1.3576627826493681`, 
       1.5}, {1.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{1.2059090053732557`, 1.5}, {1.3576627826493681`, 1.5}, {
       1.0842925895560604`, 1.4374999810329407`}, {1.2059090053732557`, 
       1.5}}], 
      PolygonBox[{{1.0842925895560604`, 1.4374999810329407`}, {
       1.0001055272204877`, 1.4375}, {1.2059090053732557`, 1.5}, {
       1.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{1.07794195802689, 1.5}, {1.2059090053732557`, 1.5}, {
       1.0001055272204877`, 1.4375}, {1.07794195802689, 1.5}}], 
      PolygonBox[{{1.0001055272204877`, 1.4375}, {0.9157074104439431, 
       1.4374999810329407`}, {1.07794195802689, 1.5}, {1.0001055272204877`, 
       1.4375}}], 
      PolygonBox[{{0.7940909946955543, 1.5}, {1.07794195802689, 1.5}, {
       0.9157074104439431, 1.4374999810329407`}, {0.7940909946955543, 1.5}}], 
      PolygonBox[{{0.9157074104439431, 1.4374999810329407`}, {
       0.7697483574637449, 1.4373449933535234`}, {0.7940909946955543, 1.5}, {
       0.9157074104439431, 1.4374999810329407`}}], 
      PolygonBox[{{0.6423372173506338, 1.5}, {0.7940909946955543, 1.5}, {
       0.7697483574637449, 1.4373449933535234`}, {0.6423372173506338, 1.5}}], 
      PolygonBox[{{0.7697483574637449, 1.4373449933535234`}, {
       0.5950572556670028, 1.4049427443329972`}, {0.6423372173506338, 1.5}, {
       0.7697483574637449, 1.4373449933535234`}}], 
      PolygonBox[{{1.5, 1.5}, {0.6423372173506338, 1.5}, {0.5950572556670028, 
       1.4049427443329972`}, {1.5, 1.5}}], 
      PolygonBox[{{0.5950572556670028, 1.4049427443329972`}, {
       0.5626550066464766, 1.2302516425362553`}, {1.5, 1.5}, {
       0.5950572556670028, 1.4049427443329972`}}], 
      PolygonBox[{{0.5, 1.357662782649369}, {1.5, 1.5}, {0.5626550066464766, 
       1.2302516425362553`}, {0.5, 1.357662782649369}}], 
      PolygonBox[{{0.5626550066464766, 1.2302516425362553`}, {
       0.5625000189670593, 1.0842925895560624`}, {0.5, 1.357662782649369}, {
       0.5626550066464766, 1.2302516425362553`}}], 
      PolygonBox[{{0.5, 1.205909005282899}, {0.5, 1.357662782649369}, {
       0.5625000189670593, 1.0842925895560624`}, {0.5, 1.205909005282899}}], 
      PolygonBox[{{0.5625000189670593, 1.0842925895560624`}, {0.5625, 
       1.0001231780629953`}, {0.5, 1.205909005282899}, {0.5625000189670593, 
       1.0842925895560624`}}], 
      PolygonBox[{{0.5, 1.0806786667587003`}, {0.5, 1.205909005282899}, {
       0.5625, 1.0001231780629953`}, {0.5, 1.0806786667587003`}}], 
      PolygonBox[{{0.5625, 1.0001231780629953`}, {0.5625000189670593, 
       0.915707410443945}, {0.5, 1.0806786667587003`}, {0.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{0.5, 0.7940909948547215}, {0.5, 1.0806786667587003`}, {
       0.5625000189670593, 0.915707410443945}, {0.5, 0.7940909948547215}}], 
      PolygonBox[{{0.5625000189670593, 0.915707410443945}, {
       0.5626550066464766, 0.7697483574637453}, {0.5, 0.7940909948547215}, {
       0.5625000189670593, 0.915707410443945}}], 
      PolygonBox[{{0.5, 0.6423372173506346}, {0.5, 0.7940909948547215}, {
       0.5626550066464766, 0.7697483574637453}, {0.5, 0.6423372173506346}}], 
      PolygonBox[{{0.5626550066464766, 0.7697483574637453}, {
       0.5950572556670028, 0.5950572556670028}, {0.5, 0.6423372173506346}, {
       0.5626550066464766, 0.7697483574637453}}], 
      PolygonBox[{{0.5, 1.5}, {0.5, 0.6423372173506346}, {0.5950572556670028, 
       0.5950572556670028}, {0.5, 1.5}}], 
      PolygonBox[{{0.5950572556670028, 0.5950572556670028}, {
       0.7697483574637449, 0.5626550066464766}, {0.5, 1.5}, {
       0.5950572556670028, 0.5950572556670028}}], 
      PolygonBox[{{0.5, 0.5}, {0.5, 1.5}, {0.7697483574637449, 
       0.5626550066464766}, {0.5, 0.5}}], 
      PolygonBox[{{0.7697483574637449, 0.5626550066464766}, {
       0.9157074104439358, 0.5625000189670593}, {0.5, 0.5}, {
       0.7697483574637449, 0.5626550066464766}}], 
      PolygonBox[{{0.794090994433172, 0.5}, {0.5, 0.5}, {0.9157074104439358, 
       0.5625000189670593}, {0.794090994433172, 0.5}}], 
      PolygonBox[{{0.9157074104439358, 0.5625000189670593}, {
       1.000134841831043, 0.5625}, {0.794090994433172, 0.5}, {
       0.9157074104439358, 0.5625000189670593}}], 
      PolygonBox[{{1.0823238704010616`, 0.5}, {0.794090994433172, 0.5}, {
       1.000134841831043, 0.5625}, {1.0823238704010616`, 0.5}}], 
      PolygonBox[{{1.000134841831043, 0.5625}, {1.0842925895560531`, 
       0.5625000189670593}, {1.0823238704010616`, 0.5}, {1.000134841831043, 
       0.5625}}], 
      PolygonBox[{{1.2059090053603974`, 0.5}, {1.0823238704010616`, 0.5}, {
       1.0842925895560531`, 0.5625000189670593}, {1.2059090053603974`, 0.5}}],
       PolygonBox[{{1.0842925895560531`, 0.5625000189670593}, {
       1.2302516425362546`, 0.5626550066464766}, {1.2059090053603974`, 0.5}, {
       1.0842925895560531`, 0.5625000189670593}}], 
      PolygonBox[{{1.357662782649371, 0.5}, {1.2059090053603974`, 0.5}, {
       1.2302516425362546`, 0.5626550066464766}, {1.357662782649371, 0.5}}], 
      PolygonBox[{{1.2302516425362546`, 0.5626550066464766}, {
       1.4049427443329972`, 0.5950572556670028}, {1.357662782649371, 0.5}, {
       1.2302516425362546`, 0.5626550066464766}}], 
      PolygonBox[{{1.5, 0.5}, {1.357662782649371, 0.5}, {1.4049427443329972`, 
       0.5950572556670028}, {1.5, 0.5}}], 
      PolygonBox[{{1.4049427443329972`, 0.5950572556670028}, {
       1.4049427443329972`, 0.5950572556670028}, {1.5, 0.5}, {
       1.4049427443329972`, 0.5950572556670028}}], 
      PolygonBox[{{1.5, 0.5}, {1.5, 0.5}, {1.4049427443329972`, 
       0.5950572556670028}, {1.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, 2.}, {0.5208333333333333, 2.}, {0.5416666666666667, 
       2.}, {0.5625, 2.}, {0.5833333333333333, 2.}, {0.6041666666666666, 
       2.}, {0.625, 2.}, {0.625, 2.}, {0.6041666666666667, 2.}, {
       0.5833333333333333, 2.}, {0.5625, 2.}, {0.5416666666666667, 2.}, {
       0.5208333333333334, 2.}, {0.5, 2.}, {0.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, 2.}, {1.3958333333333333`, 2.}, {1.4166666666666667`, 
       2.}, {1.4375, 2.}, {1.4583333333333333`, 2.}, {1.4791666666666665`, 
       2.}, {1.5, 2.}, {1.5, 2.}, {1.4791666666666667`, 2.}, {
       1.4583333333333333`, 2.}, {1.4375, 2.}, {1.4166666666666667`, 2.}, {
       1.3958333333333335`, 2.}, {1.375, 2.}, {1.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 1.5}, {1., 1.5208333333333333`}, {1., 
       1.5416666666666667`}, {1., 1.5625}, {1., 1.5833333333333333`}, {1., 
       1.6041666666666665`}, {1., 1.625}, {1., 1.625}, {1., 
       1.6041666666666667`}, {1., 1.5833333333333333`}, {1., 1.5625}, {1., 
       1.5416666666666667`}, {1., 1.5208333333333335`}, {1., 1.5}, {1., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 2.375}, {1., 2.3958333333333335`}, {1., 
       2.4166666666666665`}, {1., 2.4375}, {1., 2.4583333333333335`}, {1., 
       2.4791666666666665`}, {1., 2.5}, {1., 2.5}, {1., 
       2.4791666666666665`}, {1., 2.4583333333333335`}, {1., 2.4375}, {1., 
       2.4166666666666665`}, {1., 2.3958333333333335`}, {1., 2.375}, {1., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, 2.}, {0.75, 2.}, {0.875, 2.}, {1., 2.}, {1.125, 2.}, {
       1.25, 2.}, {1.375, 2.}, {1.375, 2.}, {1.25, 2.}, {1.125, 2.}, {1., 
       2.}, {0.875, 2.}, {0.75, 2.}, {0.625, 2.}, {0.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 1.625}, {1., 1.75}, {1., 1.875}, {1., 2.}, {1., 2.125}, {
       1., 2.25}, {1., 2.375}, {1., 2.375}, {1., 2.25}, {1., 2.125}, {1., 
       2.}, {1., 1.875}, {1., 1.75}, {1., 1.625}, {1., 1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7KEMhyuLY2tXnv5q7/9E6OnRYwwOCX0TuM2N
vkLkGxgdzG6bb5a1+2I/++3sm3zyTA4QbZ/tDdxPtErPZHKYd0L1VHfvR/tX
F9ftu/IUJv8Baj6zw9G8LdkvnryByzOCxV/B9U/xnDDzSPNzuPkOj++9mDj7
Kdz+iB0urGsznsDdBzH3Cdz9MPlk81umJUX/7FH0M/y1nwQ1/5TKCZ9HB3/b
//sPAi/tFxTmfzlx9pf9Iaj7dGIWNYWZ/LIHS/9/D9X/y34u1H+o8p/g+mHh
AzMfFn4QdX/sYeGbCHUfevgDAON3sUA=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CE0i0NYKAh8hfNXrwKBT3A+hP6AJv8KTf9T
NPUPCPIh5jDB+WBjQhnR1DPA+RB7/tqj6v9lj6r+BwY/FMV9P+xXobgfpv4D
mvwnNP1f0dQTplehuA9mzl80dTD//UDzP0w/kwOqehYHACbXZiw=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, 1.7348349570550448`}, {
       1.3247595264191645`, 1.8125}, {1.4049427443329972`, 
       1.5950572556670028`}, {1.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{1.4373449933535234`, 1.769748357463745}, {
       1.4049427443329972`, 1.5950572556670028`}, {1.3247595264191645`, 
       1.8125}, {1.4373449933535234`, 1.769748357463745}}], 
      PolygonBox[{{1.3247595264191645`, 1.8125}, {1.3622221848584006`, 
       1.9029428580865546`}, {1.4373449933535234`, 1.769748357463745}, {
       1.3247595264191645`, 1.8125}}], 
      PolygonBox[{{1.4374999810329407`, 1.9157074104439382`}, {
       1.4373449933535234`, 1.769748357463745}, {1.3622221848584006`, 
       1.9029428580865546`}, {1.4374999810329407`, 1.9157074104439382`}}], 
      PolygonBox[{{1.3622221848584006`, 1.9029428580865546`}, {1.375, 2.}, {
       1.4374999810329407`, 1.9157074104439382`}, {1.3622221848584006`, 
       1.9029428580865546`}}], 
      PolygonBox[{{1.4375, 2.}, {1.4374999810329407`, 1.9157074104439382`}, {
       1.375, 2.}, {1.4375, 2.}}], 
      PolygonBox[{{1.375, 2.}, {1.3622221848584006`, 2.0970571419134454`}, {
       1.4375, 2.}, {1.375, 2.}}], 
      PolygonBox[{{1.4374999810329407`, 2.084292589556062}, {1.4375, 2.}, {
       1.3622221848584006`, 2.0970571419134454`}, {1.4374999810329407`, 
       2.084292589556062}}], 
      PolygonBox[{{1.3622221848584006`, 2.0970571419134454`}, {
       1.3247595264191645`, 2.1875}, {1.4374999810329407`, 
       2.084292589556062}, {1.3622221848584006`, 2.0970571419134454`}}], 
      PolygonBox[{{1.4373449933535234`, 2.230251642536255}, {
       1.4374999810329407`, 2.084292589556062}, {1.3247595264191645`, 
       2.1875}, {1.4373449933535234`, 2.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, 2.1875}, {1.2651650429449552`, 
       2.2651650429449552`}, {1.4373449933535234`, 2.230251642536255}, {
       1.3247595264191645`, 2.1875}}], 
      PolygonBox[{{1.4049427443329972`, 2.404942744332997}, {
       1.4373449933535234`, 2.230251642536255}, {1.2651650429449552`, 
       2.2651650429449552`}, {1.4049427443329972`, 2.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, 2.2651650429449552`}, {1.1875, 
       2.3247595264191645`}, {1.4049427443329972`, 2.404942744332997}, {
       1.2651650429449552`, 2.2651650429449552`}}], 
      PolygonBox[{{1.230251642536255, 2.4373449933535234`}, {
       1.4049427443329972`, 2.404942744332997}, {1.1875, 
       2.3247595264191645`}, {1.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{1.1875, 2.3247595264191645`}, {1.0970571419134454`, 
       2.3622221848584006`}, {1.230251642536255, 2.4373449933535234`}, {
       1.1875, 2.3247595264191645`}}], 
      PolygonBox[{{1.0842925895560604`, 2.437499981032941}, {
       1.230251642536255, 2.4373449933535234`}, {1.0970571419134454`, 
       2.3622221848584006`}, {1.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{1.0970571419134454`, 2.3622221848584006`}, {1., 2.375}, {
       1.0842925895560604`, 2.437499981032941}, {1.0970571419134454`, 
       2.3622221848584006`}}], 
      PolygonBox[{{1.0001055272204877`, 2.4375}, {1.0842925895560604`, 
       2.437499981032941}, {1., 2.375}, {1.0001055272204877`, 2.4375}}], 
      PolygonBox[{{1., 2.375}, {0.9029428580865548, 2.3622221848584006`}, {
       1.0001055272204877`, 2.4375}, {1., 2.375}}], 
      PolygonBox[{{0.9157074104439431, 2.437499981032941}, {
       1.0001055272204877`, 2.4375}, {0.9029428580865548, 
       2.3622221848584006`}, {0.9157074104439431, 2.437499981032941}}], 
      PolygonBox[{{0.9029428580865548, 2.3622221848584006`}, {
       0.8125000000000001, 2.3247595264191645`}, {0.9157074104439431, 
       2.437499981032941}, {0.9029428580865548, 2.3622221848584006`}}], 
      PolygonBox[{{0.7697483574637449, 2.4373449933535234`}, {
       0.9157074104439431, 2.437499981032941}, {0.8125000000000001, 
       2.3247595264191645`}, {0.7697483574637449, 2.4373449933535234`}}], 
      PolygonBox[{{0.8125000000000001, 2.3247595264191645`}, {
       0.7348349570550448, 2.2651650429449552`}, {0.7697483574637449, 
       2.4373449933535234`}, {0.8125000000000001, 2.3247595264191645`}}], 
      PolygonBox[{{0.5950572556670028, 2.404942744332997}, {
       0.7697483574637449, 2.4373449933535234`}, {0.7348349570550448, 
       2.2651650429449552`}, {0.5950572556670028, 2.404942744332997}}], 
      PolygonBox[{{0.7348349570550448, 2.2651650429449552`}, {
       0.6752404735808355, 2.1875}, {0.5950572556670028, 2.404942744332997}, {
       0.7348349570550448, 2.2651650429449552`}}], 
      PolygonBox[{{0.5626550066464766, 2.2302516425362553`}, {
       0.5950572556670028, 2.404942744332997}, {0.6752404735808355, 2.1875}, {
       0.5626550066464766, 2.2302516425362553`}}], 
      PolygonBox[{{0.6752404735808355, 2.1875}, {0.6377778151415994, 
       2.0970571419134454`}, {0.5626550066464766, 2.2302516425362553`}, {
       0.6752404735808355, 2.1875}}], 
      PolygonBox[{{0.5625000189670593, 2.0842925895560622`}, {
       0.5626550066464766, 2.2302516425362553`}, {0.6377778151415994, 
       2.0970571419134454`}, {0.5625000189670593, 2.0842925895560622`}}], 
      PolygonBox[{{0.6377778151415994, 2.0970571419134454`}, {0.625, 2.}, {
       0.5625000189670593, 2.0842925895560622`}, {0.6377778151415994, 
       2.0970571419134454`}}], 
      PolygonBox[{{0.5625, 2.0001231780629953`}, {0.5625000189670593, 
       2.0842925895560622`}, {0.625, 2.}, {0.5625, 2.0001231780629953`}}], 
      PolygonBox[{{0.625, 2.}, {0.6377778151415994, 1.9029428580865548`}, {
       0.5625, 2.0001231780629953`}, {0.625, 2.}}], 
      PolygonBox[{{0.5625000189670593, 1.915707410443945}, {0.5625, 
       2.0001231780629953`}, {0.6377778151415994, 1.9029428580865548`}, {
       0.5625000189670593, 1.915707410443945}}], 
      PolygonBox[{{0.6377778151415994, 1.9029428580865548`}, {
       0.6752404735808354, 1.8125000000000002`}, {0.5625000189670593, 
       1.915707410443945}, {0.6377778151415994, 1.9029428580865548`}}], 
      PolygonBox[{{0.5626550066464766, 1.7697483574637451`}, {
       0.5625000189670593, 1.915707410443945}, {0.6752404735808354, 
       1.8125000000000002`}, {0.5626550066464766, 1.7697483574637451`}}], 
      PolygonBox[{{0.6752404735808354, 1.8125000000000002`}, {
       0.7348349570550446, 1.7348349570550448`}, {0.5626550066464766, 
       1.7697483574637451`}, {0.6752404735808354, 1.8125000000000002`}}], 
      PolygonBox[{{0.5950572556670028, 1.5950572556670028`}, {
       0.5626550066464766, 1.7697483574637451`}, {0.7348349570550446, 
       1.7348349570550448`}, {0.5950572556670028, 1.5950572556670028`}}], 
      PolygonBox[{{0.7348349570550446, 1.7348349570550448`}, {
       0.8124999999999998, 1.6752404735808355`}, {0.5950572556670028, 
       1.5950572556670028`}, {0.7348349570550446, 1.7348349570550448`}}], 
      PolygonBox[{{0.7697483574637449, 1.5626550066464766`}, {
       0.5950572556670028, 1.5950572556670028`}, {0.8124999999999998, 
       1.6752404735808355`}, {0.7697483574637449, 1.5626550066464766`}}], 
      PolygonBox[{{0.8124999999999998, 1.6752404735808355`}, {
       0.9029428580865544, 1.6377778151415994`}, {0.7697483574637449, 
       1.5626550066464766`}, {0.8124999999999998, 1.6752404735808355`}}], 
      PolygonBox[{{0.9157074104439358, 1.5625000189670593`}, {
       0.7697483574637449, 1.5626550066464766`}, {0.9029428580865544, 
       1.6377778151415994`}, {0.9157074104439358, 1.5625000189670593`}}], 
      PolygonBox[{{0.9029428580865544, 1.6377778151415994`}, {1., 1.625}, {
       0.9157074104439358, 1.5625000189670593`}, {0.9029428580865544, 
       1.6377778151415994`}}], 
      PolygonBox[{{1.000134841831043, 1.5625}, {0.9157074104439358, 
       1.5625000189670593`}, {1., 1.625}, {1.000134841831043, 1.5625}}], 
      PolygonBox[{{1., 1.625}, {1.0970571419134452`, 1.6377778151415994`}, {
       1.000134841831043, 1.5625}, {1., 1.625}}], 
      PolygonBox[{{1.0842925895560531`, 1.5625000189670593`}, {
       1.000134841831043, 1.5625}, {1.0970571419134452`, 
       1.6377778151415994`}, {1.0842925895560531`, 1.5625000189670593`}}], 
      PolygonBox[{{1.0970571419134452`, 1.6377778151415994`}, {
       1.1874999999999998`, 1.6752404735808355`}, {1.0842925895560531`, 
       1.5625000189670593`}, {1.0970571419134452`, 1.6377778151415994`}}], 
      PolygonBox[{{1.2302516425362546`, 1.5626550066464766`}, {
       1.0842925895560531`, 1.5625000189670593`}, {1.1874999999999998`, 
       1.6752404735808355`}, {1.2302516425362546`, 1.5626550066464766`}}], 
      PolygonBox[{{1.1874999999999998`, 1.6752404735808355`}, {
       1.2651650429449552`, 1.7348349570550448`}, {1.2302516425362546`, 
       1.5626550066464766`}, {1.1874999999999998`, 1.6752404735808355`}}], 
      PolygonBox[{{1.4049427443329972`, 1.5950572556670028`}, {
       1.2302516425362546`, 1.5626550066464766`}, {1.2651650429449552`, 
       1.7348349570550448`}, {1.4049427443329972`, 1.5950572556670028`}}], 
      PolygonBox[{{1.2651650429449552`, 1.7348349570550448`}, {
       1.2651650429449552`, 1.7348349570550448`}, {1.4049427443329972`, 
       1.5950572556670028`}, {1.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{1.4049427443329972`, 1.5950572556670028`}, {
       1.4049427443329972`, 1.5950572556670028`}, {1.2651650429449552`, 
       1.7348349570550448`}, {1.4049427443329972`, 1.5950572556670028`}}], 
      PolygonBox[{{1.4049427443329972`, 1.5950572556670028`}, {
       1.4373449933535234`, 1.769748357463745}, {1.5, 1.5}, {
       1.4049427443329972`, 1.5950572556670028`}}], 
      PolygonBox[{{1.5, 1.6423372173506323`}, {1.5, 1.5}, {
       1.4373449933535234`, 1.769748357463745}, {1.5, 1.6423372173506323`}}], 
      PolygonBox[{{1.4373449933535234`, 1.769748357463745}, {
       1.4374999810329407`, 1.9157074104439382`}, {1.5, 
       1.6423372173506323`}, {1.4373449933535234`, 1.769748357463745}}], 
      PolygonBox[{{1.5, 1.79409099469826}, {1.5, 1.6423372173506323`}, {
       1.4374999810329407`, 1.9157074104439382`}, {1.5, 1.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, 1.9157074104439382`}, {1.4375, 2.}, {
       1.5, 1.79409099469826}, {1.4374999810329407`, 1.9157074104439382`}}], 
      PolygonBox[{{1.5, 2.}, {1.5, 1.79409099469826}, {1.4375, 2.}, {1.5, 
       2.}}], PolygonBox[{{1.4375, 2.}, {1.4374999810329407`, 
       2.084292589556062}, {1.5, 2.}, {1.4375, 2.}}], 
      PolygonBox[{{1.5, 2.20590900530174}, {1.5, 2.}, {1.4374999810329407`, 
       2.084292589556062}, {1.5, 2.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, 2.084292589556062}, {
       1.4373449933535234`, 2.230251642536255}, {1.5, 2.20590900530174}, {
       1.4374999810329407`, 2.084292589556062}}], 
      PolygonBox[{{1.5, 2.3576627826493675`}, {1.5, 2.20590900530174}, {
       1.4373449933535234`, 2.230251642536255}, {1.5, 2.3576627826493675`}}], 
      PolygonBox[{{1.4373449933535234`, 2.230251642536255}, {
       1.4049427443329972`, 2.404942744332997}, {1.5, 2.3576627826493675`}, {
       1.4373449933535234`, 2.230251642536255}}], 
      PolygonBox[{{1.491446564961186, 2.491446564961186}, {1.5, 
       2.3576627826493675`}, {1.4049427443329972`, 2.404942744332997}, {
       1.491446564961186, 2.491446564961186}}], 
      PolygonBox[{{1.4049427443329972`, 2.404942744332997}, {
       1.230251642536255, 2.4373449933535234`}, {1.491446564961186, 
       2.491446564961186}, {1.4049427443329972`, 2.404942744332997}}], 
      PolygonBox[{{1.3576627826493681`, 2.5}, {1.491446564961186, 
       2.491446564961186}, {1.230251642536255, 2.4373449933535234`}, {
       1.3576627826493681`, 2.5}}], 
      PolygonBox[{{1.230251642536255, 2.4373449933535234`}, {
       1.0842925895560604`, 2.437499981032941}, {1.3576627826493681`, 2.5}, {
       1.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{1.2059090053732557`, 2.5}, {1.3576627826493681`, 2.5}, {
       1.0842925895560604`, 2.437499981032941}, {1.2059090053732557`, 2.5}}], 
      PolygonBox[{{1.0842925895560604`, 2.437499981032941}, {
       1.0001055272204877`, 2.4375}, {1.2059090053732557`, 2.5}, {
       1.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{1.07794195802689, 2.5}, {1.2059090053732557`, 2.5}, {
       1.0001055272204877`, 2.4375}, {1.07794195802689, 2.5}}], 
      PolygonBox[{{1.0001055272204877`, 2.4375}, {0.9157074104439431, 
       2.437499981032941}, {1.07794195802689, 2.5}, {1.0001055272204877`, 
       2.4375}}], 
      PolygonBox[{{0.7940909946955543, 2.5}, {1.07794195802689, 2.5}, {
       0.9157074104439431, 2.437499981032941}, {0.7940909946955543, 2.5}}], 
      PolygonBox[{{0.9157074104439431, 2.437499981032941}, {
       0.7697483574637449, 2.4373449933535234`}, {0.7940909946955543, 2.5}, {
       0.9157074104439431, 2.437499981032941}}], 
      PolygonBox[{{0.6423372173506338, 2.5}, {0.7940909946955543, 2.5}, {
       0.7697483574637449, 2.4373449933535234`}, {0.6423372173506338, 2.5}}], 
      PolygonBox[{{0.7697483574637449, 2.4373449933535234`}, {
       0.5950572556670028, 2.404942744332997}, {0.6423372173506338, 2.5}, {
       0.7697483574637449, 2.4373449933535234`}}], 
      PolygonBox[{{1.5, 2.5}, {0.6423372173506338, 2.5}, {0.5950572556670028, 
       2.404942744332997}, {1.5, 2.5}}], 
      PolygonBox[{{0.5950572556670028, 2.404942744332997}, {
       0.5626550066464766, 2.2302516425362553`}, {1.5, 2.5}, {
       0.5950572556670028, 2.404942744332997}}], 
      PolygonBox[{{0.5, 2.357662782649369}, {1.5, 2.5}, {0.5626550066464766, 
       2.2302516425362553`}, {0.5, 2.357662782649369}}], 
      PolygonBox[{{0.5626550066464766, 2.2302516425362553`}, {
       0.5625000189670593, 2.0842925895560622`}, {0.5, 2.357662782649369}, {
       0.5626550066464766, 2.2302516425362553`}}], 
      PolygonBox[{{0.5, 2.205909005282899}, {0.5, 2.357662782649369}, {
       0.5625000189670593, 2.0842925895560622`}, {0.5, 2.205909005282899}}], 
      PolygonBox[{{0.5625000189670593, 2.0842925895560622`}, {0.5625, 
       2.0001231780629953`}, {0.5, 2.205909005282899}, {0.5625000189670593, 
       2.0842925895560622`}}], 
      PolygonBox[{{0.5, 2.0806786667587}, {0.5, 2.205909005282899}, {0.5625, 
       2.0001231780629953`}, {0.5, 2.0806786667587}}], 
      PolygonBox[{{0.5625, 2.0001231780629953`}, {0.5625000189670593, 
       1.915707410443945}, {0.5, 2.0806786667587}, {0.5625, 
       2.0001231780629953`}}], 
      PolygonBox[{{0.5, 1.7940909948547215`}, {0.5, 2.0806786667587}, {
       0.5625000189670593, 1.915707410443945}, {0.5, 1.7940909948547215`}}], 
      PolygonBox[{{0.5625000189670593, 1.915707410443945}, {
       0.5626550066464766, 1.7697483574637451`}, {0.5, 1.7940909948547215`}, {
       0.5625000189670593, 1.915707410443945}}], 
      PolygonBox[{{0.5, 1.6423372173506348`}, {0.5, 1.7940909948547215`}, {
       0.5626550066464766, 1.7697483574637451`}, {0.5, 1.6423372173506348`}}],
       PolygonBox[{{0.5626550066464766, 1.7697483574637451`}, {
       0.5950572556670028, 1.5950572556670028`}, {0.5, 1.6423372173506348`}, {
       0.5626550066464766, 1.7697483574637451`}}], 
      PolygonBox[{{0.5, 2.5}, {0.5, 1.6423372173506348`}, {0.5950572556670028,
        1.5950572556670028`}, {0.5, 2.5}}], 
      PolygonBox[{{0.5950572556670028, 1.5950572556670028`}, {
       0.7697483574637449, 1.5626550066464766`}, {0.5, 2.5}, {
       0.5950572556670028, 1.5950572556670028`}}], 
      PolygonBox[{{0.5, 1.5}, {0.5, 2.5}, {0.7697483574637449, 
       1.5626550066464766`}, {0.5, 1.5}}], 
      PolygonBox[{{0.7697483574637449, 1.5626550066464766`}, {
       0.9157074104439358, 1.5625000189670593`}, {0.5, 1.5}, {
       0.7697483574637449, 1.5626550066464766`}}], 
      PolygonBox[{{0.794090994433172, 1.5}, {0.5, 1.5}, {0.9157074104439358, 
       1.5625000189670593`}, {0.794090994433172, 1.5}}], 
      PolygonBox[{{0.9157074104439358, 1.5625000189670593`}, {
       1.000134841831043, 1.5625}, {0.794090994433172, 1.5}, {
       0.9157074104439358, 1.5625000189670593`}}], 
      PolygonBox[{{1.0823238704010616`, 1.5}, {0.794090994433172, 1.5}, {
       1.000134841831043, 1.5625}, {1.0823238704010616`, 1.5}}], 
      PolygonBox[{{1.000134841831043, 1.5625}, {1.0842925895560531`, 
       1.5625000189670593`}, {1.0823238704010616`, 1.5}, {1.000134841831043, 
       1.5625}}], 
      PolygonBox[{{1.2059090053603974`, 1.5}, {1.0823238704010616`, 1.5}, {
       1.0842925895560531`, 1.5625000189670593`}, {1.2059090053603974`, 
       1.5}}], PolygonBox[{{1.0842925895560531`, 1.5625000189670593`}, {
       1.2302516425362546`, 1.5626550066464766`}, {1.2059090053603974`, 
       1.5}, {1.0842925895560531`, 1.5625000189670593`}}], 
      PolygonBox[{{1.357662782649371, 1.5}, {1.2059090053603974`, 1.5}, {
       1.2302516425362546`, 1.5626550066464766`}, {1.357662782649371, 1.5}}], 
      PolygonBox[{{1.2302516425362546`, 1.5626550066464766`}, {
       1.4049427443329972`, 1.5950572556670028`}, {1.357662782649371, 1.5}, {
       1.2302516425362546`, 1.5626550066464766`}}], 
      PolygonBox[{{1.5, 1.5}, {1.357662782649371, 1.5}, {1.4049427443329972`, 
       1.5950572556670028`}, {1.5, 1.5}}], 
      PolygonBox[{{1.4049427443329972`, 1.5950572556670028`}, {
       1.4049427443329972`, 1.5950572556670028`}, {1.5, 1.5}, {
       1.4049427443329972`, 1.5950572556670028`}}], 
      PolygonBox[{{1.5, 1.5}, {1.5, 1.5}, {1.4049427443329972`, 
       1.5950572556670028`}, {1.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, 3.}, {0.5208333333333333, 3.}, {0.5416666666666667, 
       3.}, {0.5625, 3.}, {0.5833333333333333, 3.}, {0.6041666666666666, 
       3.}, {0.625, 3.}, {0.625, 3.}, {0.6041666666666667, 3.}, {
       0.5833333333333333, 3.}, {0.5625, 3.}, {0.5416666666666667, 3.}, {
       0.5208333333333334, 3.}, {0.5, 3.}, {0.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, 3.}, {1.3958333333333333`, 3.}, {1.4166666666666667`, 
       3.}, {1.4375, 3.}, {1.4583333333333333`, 3.}, {1.4791666666666665`, 
       3.}, {1.5, 3.}, {1.5, 3.}, {1.4791666666666667`, 3.}, {
       1.4583333333333333`, 3.}, {1.4375, 3.}, {1.4166666666666667`, 3.}, {
       1.3958333333333335`, 3.}, {1.375, 3.}, {1.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 2.5}, {1., 2.5208333333333335`}, {1., 
       2.5416666666666665`}, {1., 2.5625}, {1., 2.5833333333333335`}, {1., 
       2.6041666666666665`}, {1., 2.625}, {1., 2.625}, {1., 
       2.6041666666666665`}, {1., 2.5833333333333335`}, {1., 2.5625}, {1., 
       2.5416666666666665`}, {1., 2.5208333333333335`}, {1., 2.5}, {1., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 3.375}, {1., 3.3958333333333335`}, {1., 
       3.4166666666666665`}, {1., 3.4375}, {1., 3.4583333333333335`}, {1., 
       3.4791666666666665`}, {1., 3.5}, {1., 3.5}, {1., 
       3.4791666666666665`}, {1., 3.4583333333333335`}, {1., 3.4375}, {1., 
       3.4166666666666665`}, {1., 3.3958333333333335`}, {1., 3.375}, {1., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, 3.}, {0.75, 3.}, {0.875, 3.}, {1., 3.}, {1.125, 3.}, {
       1.25, 3.}, {1.375, 3.}, {1.375, 3.}, {1.25, 3.}, {1.125, 3.}, {1., 
       3.}, {0.875, 3.}, {0.75, 3.}, {0.625, 3.}, {0.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 2.625}, {1., 2.75}, {1., 2.875}, {1., 3.}, {1., 3.125}, {
       1., 3.25}, {1., 3.375}, {1., 3.375}, {1., 3.25}, {1., 3.125}, {1., 
       3.}, {1., 2.875}, {1., 2.75}, {1., 2.625}, {1., 2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CE0h8OVxbG1K09/tfd/IvT06DEOh4S+Cdzm
Rl8h8g2cDma3zTfL2n2xn/129k0+eS4HiL7P9gbuJ1qlZ3I5zDuheqq796P9
q4vr9l15CpP/ADWf2+Fo3pbsF0/ewOUZweKv4PqneE6YeaT5Odx8h8f3Xkyc
/RRuf8QOF9a1GU/g7oOY+wTufpj8Jum3UlaW7Gj62RwmQc1PFUpR+/iA1eHf
fxB4aX9hh3nVkzRWh0NQ94npBTpqS7E6gKX/v4eaz+owF+o/VPlPcP2w8IGZ
jxp+bPDw3Qh1H3r4AwCtWZy6
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CE0j0NYKAh8hfNXrwKBT3A+hP6AJv8KTf9T
NPUPCPIh5nDB+WBjQjnR1HOgqWeD8yH2sqKpZ8Hgh6K4j8VhFYr7Yeo/oMl/
QtP/FU39D4L8UBT3/UBz/w80//1A8/8P+1Uo4YOILwDPbFpG
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, 2.7348349570550448`}, {
       1.3247595264191645`, 2.8125}, {1.4049427443329972`, 
       2.595057255667003}, {1.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{1.4373449933535234`, 2.7697483574637447`}, {
       1.4049427443329972`, 2.595057255667003}, {1.3247595264191645`, 
       2.8125}, {1.4373449933535234`, 2.7697483574637447`}}], 
      PolygonBox[{{1.3247595264191645`, 2.8125}, {1.3622221848584006`, 
       2.9029428580865546`}, {1.4373449933535234`, 2.7697483574637447`}, {
       1.3247595264191645`, 2.8125}}], 
      PolygonBox[{{1.4374999810329407`, 2.915707410443938}, {
       1.4373449933535234`, 2.7697483574637447`}, {1.3622221848584006`, 
       2.9029428580865546`}, {1.4374999810329407`, 2.915707410443938}}], 
      PolygonBox[{{1.3622221848584006`, 2.9029428580865546`}, {1.375, 3.}, {
       1.4374999810329407`, 2.915707410443938}, {1.3622221848584006`, 
       2.9029428580865546`}}], 
      PolygonBox[{{1.4375, 3.}, {1.4374999810329407`, 2.915707410443938}, {
       1.375, 3.}, {1.4375, 3.}}], 
      PolygonBox[{{1.375, 3.}, {1.3622221848584006`, 3.0970571419134454`}, {
       1.4375, 3.}, {1.375, 3.}}], 
      PolygonBox[{{1.4374999810329407`, 3.084292589556062}, {1.4375, 3.}, {
       1.3622221848584006`, 3.0970571419134454`}, {1.4374999810329407`, 
       3.084292589556062}}], 
      PolygonBox[{{1.3622221848584006`, 3.0970571419134454`}, {
       1.3247595264191645`, 3.1875}, {1.4374999810329407`, 
       3.084292589556062}, {1.3622221848584006`, 3.0970571419134454`}}], 
      PolygonBox[{{1.4373449933535234`, 3.230251642536255}, {
       1.4374999810329407`, 3.084292589556062}, {1.3247595264191645`, 
       3.1875}, {1.4373449933535234`, 3.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, 3.1875}, {1.2651650429449552`, 
       3.2651650429449552`}, {1.4373449933535234`, 3.230251642536255}, {
       1.3247595264191645`, 3.1875}}], 
      PolygonBox[{{1.4049427443329972`, 3.404942744332997}, {
       1.4373449933535234`, 3.230251642536255}, {1.2651650429449552`, 
       3.2651650429449552`}, {1.4049427443329972`, 3.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, 3.2651650429449552`}, {1.1875, 
       3.3247595264191645`}, {1.4049427443329972`, 3.404942744332997}, {
       1.2651650429449552`, 3.2651650429449552`}}], 
      PolygonBox[{{1.230251642536255, 3.4373449933535234`}, {
       1.4049427443329972`, 3.404942744332997}, {1.1875, 
       3.3247595264191645`}, {1.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{1.1875, 3.3247595264191645`}, {1.0970571419134454`, 
       3.3622221848584006`}, {1.230251642536255, 3.4373449933535234`}, {
       1.1875, 3.3247595264191645`}}], 
      PolygonBox[{{1.0842925895560604`, 3.437499981032941}, {
       1.230251642536255, 3.4373449933535234`}, {1.0970571419134454`, 
       3.3622221848584006`}, {1.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{1.0970571419134454`, 3.3622221848584006`}, {1., 3.375}, {
       1.0842925895560604`, 3.437499981032941}, {1.0970571419134454`, 
       3.3622221848584006`}}], 
      PolygonBox[{{1.0001055272204877`, 3.4375}, {1.0842925895560604`, 
       3.437499981032941}, {1., 3.375}, {1.0001055272204877`, 3.4375}}], 
      PolygonBox[{{1., 3.375}, {0.9029428580865548, 3.3622221848584006`}, {
       1.0001055272204877`, 3.4375}, {1., 3.375}}], 
      PolygonBox[{{0.9157074104439431, 3.437499981032941}, {
       1.0001055272204877`, 3.4375}, {0.9029428580865548, 
       3.3622221848584006`}, {0.9157074104439431, 3.437499981032941}}], 
      PolygonBox[{{0.9029428580865548, 3.3622221848584006`}, {
       0.8125000000000001, 3.3247595264191645`}, {0.9157074104439431, 
       3.437499981032941}, {0.9029428580865548, 3.3622221848584006`}}], 
      PolygonBox[{{0.7697483574637449, 3.4373449933535234`}, {
       0.9157074104439431, 3.437499981032941}, {0.8125000000000001, 
       3.3247595264191645`}, {0.7697483574637449, 3.4373449933535234`}}], 
      PolygonBox[{{0.8125000000000001, 3.3247595264191645`}, {
       0.7348349570550448, 3.2651650429449552`}, {0.7697483574637449, 
       3.4373449933535234`}, {0.8125000000000001, 3.3247595264191645`}}], 
      PolygonBox[{{0.5950572556670028, 3.404942744332997}, {
       0.7697483574637449, 3.4373449933535234`}, {0.7348349570550448, 
       3.2651650429449552`}, {0.5950572556670028, 3.404942744332997}}], 
      PolygonBox[{{0.7348349570550448, 3.2651650429449552`}, {
       0.6752404735808355, 3.1875}, {0.5950572556670028, 3.404942744332997}, {
       0.7348349570550448, 3.2651650429449552`}}], 
      PolygonBox[{{0.5626550066464766, 3.2302516425362553`}, {
       0.5950572556670028, 3.404942744332997}, {0.6752404735808355, 3.1875}, {
       0.5626550066464766, 3.2302516425362553`}}], 
      PolygonBox[{{0.6752404735808355, 3.1875}, {0.6377778151415994, 
       3.0970571419134454`}, {0.5626550066464766, 3.2302516425362553`}, {
       0.6752404735808355, 3.1875}}], 
      PolygonBox[{{0.5625000189670593, 3.0842925895560622`}, {
       0.5626550066464766, 3.2302516425362553`}, {0.6377778151415994, 
       3.0970571419134454`}, {0.5625000189670593, 3.0842925895560622`}}], 
      PolygonBox[{{0.6377778151415994, 3.0970571419134454`}, {0.625, 3.}, {
       0.5625000189670593, 3.0842925895560622`}, {0.6377778151415994, 
       3.0970571419134454`}}], 
      PolygonBox[{{0.5625, 3.0001231780629953`}, {0.5625000189670593, 
       3.0842925895560622`}, {0.625, 3.}, {0.5625, 3.0001231780629953`}}], 
      PolygonBox[{{0.625, 3.}, {0.6377778151415994, 2.902942858086555}, {
       0.5625, 3.0001231780629953`}, {0.625, 3.}}], 
      PolygonBox[{{0.5625000189670593, 2.915707410443945}, {0.5625, 
       3.0001231780629953`}, {0.6377778151415994, 2.902942858086555}, {
       0.5625000189670593, 2.915707410443945}}], 
      PolygonBox[{{0.6377778151415994, 2.902942858086555}, {
       0.6752404735808354, 2.8125}, {0.5625000189670593, 2.915707410443945}, {
       0.6377778151415994, 2.902942858086555}}], 
      PolygonBox[{{0.5626550066464766, 2.769748357463745}, {
       0.5625000189670593, 2.915707410443945}, {0.6752404735808354, 2.8125}, {
       0.5626550066464766, 2.769748357463745}}], 
      PolygonBox[{{0.6752404735808354, 2.8125}, {0.7348349570550446, 
       2.7348349570550448`}, {0.5626550066464766, 2.769748357463745}, {
       0.6752404735808354, 2.8125}}], 
      PolygonBox[{{0.5950572556670028, 2.595057255667003}, {
       0.5626550066464766, 2.769748357463745}, {0.7348349570550446, 
       2.7348349570550448`}, {0.5950572556670028, 2.595057255667003}}], 
      PolygonBox[{{0.7348349570550446, 2.7348349570550448`}, {
       0.8124999999999998, 2.6752404735808355`}, {0.5950572556670028, 
       2.595057255667003}, {0.7348349570550446, 2.7348349570550448`}}], 
      PolygonBox[{{0.7697483574637449, 2.5626550066464766`}, {
       0.5950572556670028, 2.595057255667003}, {0.8124999999999998, 
       2.6752404735808355`}, {0.7697483574637449, 2.5626550066464766`}}], 
      PolygonBox[{{0.8124999999999998, 2.6752404735808355`}, {
       0.9029428580865544, 2.6377778151415994`}, {0.7697483574637449, 
       2.5626550066464766`}, {0.8124999999999998, 2.6752404735808355`}}], 
      PolygonBox[{{0.9157074104439358, 2.562500018967059}, {
       0.7697483574637449, 2.5626550066464766`}, {0.9029428580865544, 
       2.6377778151415994`}, {0.9157074104439358, 2.562500018967059}}], 
      PolygonBox[{{0.9029428580865544, 2.6377778151415994`}, {1., 2.625}, {
       0.9157074104439358, 2.562500018967059}, {0.9029428580865544, 
       2.6377778151415994`}}], 
      PolygonBox[{{1.000134841831043, 2.5625}, {0.9157074104439358, 
       2.562500018967059}, {1., 2.625}, {1.000134841831043, 2.5625}}], 
      PolygonBox[{{1., 2.625}, {1.0970571419134452`, 2.6377778151415994`}, {
       1.000134841831043, 2.5625}, {1., 2.625}}], 
      PolygonBox[{{1.0842925895560531`, 2.562500018967059}, {
       1.000134841831043, 2.5625}, {1.0970571419134452`, 
       2.6377778151415994`}, {1.0842925895560531`, 2.562500018967059}}], 
      PolygonBox[{{1.0970571419134452`, 2.6377778151415994`}, {
       1.1874999999999998`, 2.6752404735808355`}, {1.0842925895560531`, 
       2.562500018967059}, {1.0970571419134452`, 2.6377778151415994`}}], 
      PolygonBox[{{1.2302516425362546`, 2.5626550066464766`}, {
       1.0842925895560531`, 2.562500018967059}, {1.1874999999999998`, 
       2.6752404735808355`}, {1.2302516425362546`, 2.5626550066464766`}}], 
      PolygonBox[{{1.1874999999999998`, 2.6752404735808355`}, {
       1.2651650429449552`, 2.7348349570550448`}, {1.2302516425362546`, 
       2.5626550066464766`}, {1.1874999999999998`, 2.6752404735808355`}}], 
      PolygonBox[{{1.4049427443329972`, 2.595057255667003}, {
       1.2302516425362546`, 2.5626550066464766`}, {1.2651650429449552`, 
       2.7348349570550448`}, {1.4049427443329972`, 2.595057255667003}}], 
      PolygonBox[{{1.2651650429449552`, 2.7348349570550448`}, {
       1.2651650429449552`, 2.7348349570550448`}, {1.4049427443329972`, 
       2.595057255667003}, {1.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{1.4049427443329972`, 2.595057255667003}, {
       1.4049427443329972`, 2.595057255667003}, {1.2651650429449552`, 
       2.7348349570550448`}, {1.4049427443329972`, 2.595057255667003}}], 
      PolygonBox[{{1.4049427443329972`, 2.595057255667003}, {
       1.4373449933535234`, 2.7697483574637447`}, {1.5, 2.5}, {
       1.4049427443329972`, 2.595057255667003}}], 
      PolygonBox[{{1.5, 2.642337217350632}, {1.5, 2.5}, {1.4373449933535234`, 
       2.7697483574637447`}, {1.5, 2.642337217350632}}], 
      PolygonBox[{{1.4373449933535234`, 2.7697483574637447`}, {
       1.4374999810329407`, 2.915707410443938}, {1.5, 2.642337217350632}, {
       1.4373449933535234`, 2.7697483574637447`}}], 
      PolygonBox[{{1.5, 2.79409099469826}, {1.5, 2.642337217350632}, {
       1.4374999810329407`, 2.915707410443938}, {1.5, 2.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, 2.915707410443938}, {1.4375, 3.}, {
       1.5, 2.79409099469826}, {1.4374999810329407`, 2.915707410443938}}], 
      PolygonBox[{{1.5, 3.}, {1.5, 2.79409099469826}, {1.4375, 3.}, {1.5, 
       3.}}], PolygonBox[{{1.4375, 3.}, {1.4374999810329407`, 
       3.084292589556062}, {1.5, 3.}, {1.4375, 3.}}], 
      PolygonBox[{{1.5, 3.20590900530174}, {1.5, 3.}, {1.4374999810329407`, 
       3.084292589556062}, {1.5, 3.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, 3.084292589556062}, {
       1.4373449933535234`, 3.230251642536255}, {1.5, 3.20590900530174}, {
       1.4374999810329407`, 3.084292589556062}}], 
      PolygonBox[{{1.5, 3.3576627826493675`}, {1.5, 3.20590900530174}, {
       1.4373449933535234`, 3.230251642536255}, {1.5, 3.3576627826493675`}}], 
      PolygonBox[{{1.4373449933535234`, 3.230251642536255}, {
       1.4049427443329972`, 3.404942744332997}, {1.5, 3.3576627826493675`}, {
       1.4373449933535234`, 3.230251642536255}}], 
      PolygonBox[{{1.491446564961186, 3.491446564961186}, {1.5, 
       3.3576627826493675`}, {1.4049427443329972`, 3.404942744332997}, {
       1.491446564961186, 3.491446564961186}}], 
      PolygonBox[{{1.4049427443329972`, 3.404942744332997}, {
       1.230251642536255, 3.4373449933535234`}, {1.491446564961186, 
       3.491446564961186}, {1.4049427443329972`, 3.404942744332997}}], 
      PolygonBox[{{1.3576627826493681`, 3.5}, {1.491446564961186, 
       3.491446564961186}, {1.230251642536255, 3.4373449933535234`}, {
       1.3576627826493681`, 3.5}}], 
      PolygonBox[{{1.230251642536255, 3.4373449933535234`}, {
       1.0842925895560604`, 3.437499981032941}, {1.3576627826493681`, 3.5}, {
       1.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{1.2059090053732557`, 3.5}, {1.3576627826493681`, 3.5}, {
       1.0842925895560604`, 3.437499981032941}, {1.2059090053732557`, 3.5}}], 
      PolygonBox[{{1.0842925895560604`, 3.437499981032941}, {
       1.0001055272204877`, 3.4375}, {1.2059090053732557`, 3.5}, {
       1.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{1.07794195802689, 3.5}, {1.2059090053732557`, 3.5}, {
       1.0001055272204877`, 3.4375}, {1.07794195802689, 3.5}}], 
      PolygonBox[{{1.0001055272204877`, 3.4375}, {0.9157074104439431, 
       3.437499981032941}, {1.07794195802689, 3.5}, {1.0001055272204877`, 
       3.4375}}], 
      PolygonBox[{{0.7940909946955543, 3.5}, {1.07794195802689, 3.5}, {
       0.9157074104439431, 3.437499981032941}, {0.7940909946955543, 3.5}}], 
      PolygonBox[{{0.9157074104439431, 3.437499981032941}, {
       0.7697483574637449, 3.4373449933535234`}, {0.7940909946955543, 3.5}, {
       0.9157074104439431, 3.437499981032941}}], 
      PolygonBox[{{0.6423372173506338, 3.5}, {0.7940909946955543, 3.5}, {
       0.7697483574637449, 3.4373449933535234`}, {0.6423372173506338, 3.5}}], 
      PolygonBox[{{0.7697483574637449, 3.4373449933535234`}, {
       0.5950572556670028, 3.404942744332997}, {0.6423372173506338, 3.5}, {
       0.7697483574637449, 3.4373449933535234`}}], 
      PolygonBox[{{1.5, 3.5}, {0.6423372173506338, 3.5}, {0.5950572556670028, 
       3.404942744332997}, {1.5, 3.5}}], 
      PolygonBox[{{0.5950572556670028, 3.404942744332997}, {
       0.5626550066464766, 3.2302516425362553`}, {1.5, 3.5}, {
       0.5950572556670028, 3.404942744332997}}], 
      PolygonBox[{{0.5, 3.357662782649369}, {1.5, 3.5}, {0.5626550066464766, 
       3.2302516425362553`}, {0.5, 3.357662782649369}}], 
      PolygonBox[{{0.5626550066464766, 3.2302516425362553`}, {
       0.5625000189670593, 3.0842925895560622`}, {0.5, 3.357662782649369}, {
       0.5626550066464766, 3.2302516425362553`}}], 
      PolygonBox[{{0.5, 3.205909005282899}, {0.5, 3.357662782649369}, {
       0.5625000189670593, 3.0842925895560622`}, {0.5, 3.205909005282899}}], 
      PolygonBox[{{0.5625000189670593, 3.0842925895560622`}, {0.5625, 
       3.0001231780629953`}, {0.5, 3.205909005282899}, {0.5625000189670593, 
       3.0842925895560622`}}], 
      PolygonBox[{{0.5, 3.0806786667587}, {0.5, 3.205909005282899}, {0.5625, 
       3.0001231780629953`}, {0.5, 3.0806786667587}}], 
      PolygonBox[{{0.5625, 3.0001231780629953`}, {0.5625000189670593, 
       2.915707410443945}, {0.5, 3.0806786667587}, {0.5625, 
       3.0001231780629953`}}], 
      PolygonBox[{{0.5, 2.7940909948547215`}, {0.5, 3.0806786667587}, {
       0.5625000189670593, 2.915707410443945}, {0.5, 2.7940909948547215`}}], 
      PolygonBox[{{0.5625000189670593, 2.915707410443945}, {
       0.5626550066464766, 2.769748357463745}, {0.5, 2.7940909948547215`}, {
       0.5625000189670593, 2.915707410443945}}], 
      PolygonBox[{{0.5, 2.6423372173506348`}, {0.5, 2.7940909948547215`}, {
       0.5626550066464766, 2.769748357463745}, {0.5, 2.6423372173506348`}}], 
      PolygonBox[{{0.5626550066464766, 2.769748357463745}, {
       0.5950572556670028, 2.595057255667003}, {0.5, 2.6423372173506348`}, {
       0.5626550066464766, 2.769748357463745}}], 
      PolygonBox[{{0.5, 3.5}, {0.5, 2.6423372173506348`}, {0.5950572556670028,
        2.595057255667003}, {0.5, 3.5}}], 
      PolygonBox[{{0.5950572556670028, 2.595057255667003}, {
       0.7697483574637449, 2.5626550066464766`}, {0.5, 3.5}, {
       0.5950572556670028, 2.595057255667003}}], 
      PolygonBox[{{0.5, 2.5}, {0.5, 3.5}, {0.7697483574637449, 
       2.5626550066464766`}, {0.5, 2.5}}], 
      PolygonBox[{{0.7697483574637449, 2.5626550066464766`}, {
       0.9157074104439358, 2.562500018967059}, {0.5, 2.5}, {
       0.7697483574637449, 2.5626550066464766`}}], 
      PolygonBox[{{0.794090994433172, 2.5}, {0.5, 2.5}, {0.9157074104439358, 
       2.562500018967059}, {0.794090994433172, 2.5}}], 
      PolygonBox[{{0.9157074104439358, 2.562500018967059}, {1.000134841831043,
        2.5625}, {0.794090994433172, 2.5}, {0.9157074104439358, 
       2.562500018967059}}], 
      PolygonBox[{{1.0823238704010616`, 2.5}, {0.794090994433172, 2.5}, {
       1.000134841831043, 2.5625}, {1.0823238704010616`, 2.5}}], 
      PolygonBox[{{1.000134841831043, 2.5625}, {1.0842925895560531`, 
       2.562500018967059}, {1.0823238704010616`, 2.5}, {1.000134841831043, 
       2.5625}}], 
      PolygonBox[{{1.2059090053603974`, 2.5}, {1.0823238704010616`, 2.5}, {
       1.0842925895560531`, 2.562500018967059}, {1.2059090053603974`, 2.5}}], 
      PolygonBox[{{1.0842925895560531`, 2.562500018967059}, {
       1.2302516425362546`, 2.5626550066464766`}, {1.2059090053603974`, 
       2.5}, {1.0842925895560531`, 2.562500018967059}}], 
      PolygonBox[{{1.357662782649371, 2.5}, {1.2059090053603974`, 2.5}, {
       1.2302516425362546`, 2.5626550066464766`}, {1.357662782649371, 2.5}}], 
      PolygonBox[{{1.2302516425362546`, 2.5626550066464766`}, {
       1.4049427443329972`, 2.595057255667003}, {1.357662782649371, 2.5}, {
       1.2302516425362546`, 2.5626550066464766`}}], 
      PolygonBox[{{1.5, 2.5}, {1.357662782649371, 2.5}, {1.4049427443329972`, 
       2.595057255667003}, {1.5, 2.5}}], 
      PolygonBox[{{1.4049427443329972`, 2.595057255667003}, {
       1.4049427443329972`, 2.595057255667003}, {1.5, 2.5}, {
       1.4049427443329972`, 2.595057255667003}}], 
      PolygonBox[{{1.5, 2.5}, {1.5, 2.5}, {1.4049427443329972`, 
       2.595057255667003}, {1.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, 4.}, {0.5208333333333333, 4.}, {0.5416666666666667, 
       4.}, {0.5625, 4.}, {0.5833333333333333, 4.}, {0.6041666666666666, 
       4.}, {0.625, 4.}, {0.625, 4.}, {0.6041666666666667, 4.}, {
       0.5833333333333333, 4.}, {0.5625, 4.}, {0.5416666666666667, 4.}, {
       0.5208333333333334, 4.}, {0.5, 4.}, {0.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, 4.}, {1.3958333333333333`, 4.}, {1.4166666666666667`, 
       4.}, {1.4375, 4.}, {1.4583333333333333`, 4.}, {1.4791666666666665`, 
       4.}, {1.5, 4.}, {1.5, 4.}, {1.4791666666666667`, 4.}, {
       1.4583333333333333`, 4.}, {1.4375, 4.}, {1.4166666666666667`, 4.}, {
       1.3958333333333335`, 4.}, {1.375, 4.}, {1.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 3.5}, {1., 3.5208333333333335`}, {1., 
       3.5416666666666665`}, {1., 3.5625}, {1., 3.5833333333333335`}, {1., 
       3.6041666666666665`}, {1., 3.625}, {1., 3.625}, {1., 
       3.6041666666666665`}, {1., 3.5833333333333335`}, {1., 3.5625}, {1., 
       3.5416666666666665`}, {1., 3.5208333333333335`}, {1., 3.5}, {1., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 4.375}, {1., 4.395833333333333}, {1., 
       4.416666666666667}, {1., 4.4375}, {1., 4.458333333333333}, {1., 
       4.479166666666667}, {1., 4.5}, {1., 4.5}, {1., 4.479166666666667}, {1.,
        4.458333333333333}, {1., 4.4375}, {1., 4.416666666666667}, {1., 
       4.395833333333333}, {1., 4.375}, {1., 4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, 4.}, {0.75, 4.}, {0.875, 4.}, {1., 4.}, {1.125, 4.}, {
       1.25, 4.}, {1.375, 4.}, {1.375, 4.}, {1.25, 4.}, {1.125, 4.}, {1., 
       4.}, {0.875, 4.}, {0.75, 4.}, {0.625, 4.}, {0.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 3.625}, {1., 3.75}, {1., 3.875}, {1., 4.}, {1., 4.125}, {
       1., 4.25}, {1., 4.375}, {1., 4.375}, {1., 4.25}, {1., 4.125}, {1., 
       4.}, {1., 3.875}, {1., 3.75}, {1., 3.625}, {1., 3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CG0gMOVxbG1K09/tVcv6vyUlCzgkNA3gdvc
6CtE/oCAg9lt882ydl/sz307m9POL+gA0ffZfobyk0O9PoIO806onuru/Wj/
NSM8/lURTP4DRH+DoMPRvC3ZL568gcszgiVewfVP8Zww80jzc7j5Do/vvZg4
+ync/ogdLqxrM57Ya0DdBzH/Cdz9MPlN0m+lrCz5UfU38DlMgpqfKpSi9vEB
r8O//yDw0v7CDvOqJ2m8Doeg7hPTC3TUluJ1AEv/fw81n9dhLtR/qPKf4Pph
4QMzHyX8gPbDwncj1H3o4Q8Ay1ycNw==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CG0kENYKAh8hfNXrwKBT3A+hP6AJv8KTf9T
NPUPCPLB2kIF4XyIuQJo6gXQ5PngfIi9vGjqeTD4oSju43FYheJ+mPoPaPKf
0PR/RVP/gyA/FMV9P9Dc/wPNfz/Q/P8DLXwQ8QUAdCdbEQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, 3.7348349570550448`}, {
       1.3247595264191645`, 3.8125}, {1.4049427443329972`, 
       3.595057255667003}, {1.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{1.4373449933535234`, 3.7697483574637447`}, {
       1.4049427443329972`, 3.595057255667003}, {1.3247595264191645`, 
       3.8125}, {1.4373449933535234`, 3.7697483574637447`}}], 
      PolygonBox[{{1.3247595264191645`, 3.8125}, {1.3622221848584006`, 
       3.9029428580865546`}, {1.4373449933535234`, 3.7697483574637447`}, {
       1.3247595264191645`, 3.8125}}], 
      PolygonBox[{{1.4374999810329407`, 3.915707410443938}, {
       1.4373449933535234`, 3.7697483574637447`}, {1.3622221848584006`, 
       3.9029428580865546`}, {1.4374999810329407`, 3.915707410443938}}], 
      PolygonBox[{{1.3622221848584006`, 3.9029428580865546`}, {1.375, 4.}, {
       1.4374999810329407`, 3.915707410443938}, {1.3622221848584006`, 
       3.9029428580865546`}}], 
      PolygonBox[{{1.4375, 4.}, {1.4374999810329407`, 3.915707410443938}, {
       1.375, 4.}, {1.4375, 4.}}], 
      PolygonBox[{{1.375, 4.}, {1.3622221848584006`, 4.097057141913445}, {
       1.4375, 4.}, {1.375, 4.}}], 
      PolygonBox[{{1.4374999810329407`, 4.084292589556061}, {1.4375, 4.}, {
       1.3622221848584006`, 4.097057141913445}, {1.4374999810329407`, 
       4.084292589556061}}], 
      PolygonBox[{{1.3622221848584006`, 4.097057141913445}, {
       1.3247595264191645`, 4.1875}, {1.4374999810329407`, 
       4.084292589556061}, {1.3622221848584006`, 4.097057141913445}}], 
      PolygonBox[{{1.4373449933535234`, 4.230251642536255}, {
       1.4374999810329407`, 4.084292589556061}, {1.3247595264191645`, 
       4.1875}, {1.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, 4.1875}, {1.2651650429449552`, 
       4.265165042944956}, {1.4373449933535234`, 4.230251642536255}, {
       1.3247595264191645`, 4.1875}}], 
      PolygonBox[{{1.4049427443329972`, 4.404942744332997}, {
       1.4373449933535234`, 4.230251642536255}, {1.2651650429449552`, 
       4.265165042944956}, {1.4049427443329972`, 4.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, 4.265165042944956}, {1.1875, 
       4.3247595264191645`}, {1.4049427443329972`, 4.404942744332997}, {
       1.2651650429449552`, 4.265165042944956}}], 
      PolygonBox[{{1.230251642536255, 4.437344993353523}, {
       1.4049427443329972`, 4.404942744332997}, {1.1875, 
       4.3247595264191645`}, {1.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{1.1875, 4.3247595264191645`}, {1.0970571419134454`, 
       4.362222184858401}, {1.230251642536255, 4.437344993353523}, {1.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{1.0842925895560604`, 4.437499981032941}, {
       1.230251642536255, 4.437344993353523}, {1.0970571419134454`, 
       4.362222184858401}, {1.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{1.0970571419134454`, 4.362222184858401}, {1., 4.375}, {
       1.0842925895560604`, 4.437499981032941}, {1.0970571419134454`, 
       4.362222184858401}}], 
      PolygonBox[{{1.0001055272204877`, 4.4375}, {1.0842925895560604`, 
       4.437499981032941}, {1., 4.375}, {1.0001055272204877`, 4.4375}}], 
      PolygonBox[{{1., 4.375}, {0.9029428580865548, 4.362222184858401}, {
       1.0001055272204877`, 4.4375}, {1., 4.375}}], 
      PolygonBox[{{0.9157074104439431, 4.437499981032941}, {
       1.0001055272204877`, 4.4375}, {0.9029428580865548, 
       4.362222184858401}, {0.9157074104439431, 4.437499981032941}}], 
      PolygonBox[{{0.9029428580865548, 4.362222184858401}, {
       0.8125000000000001, 4.3247595264191645`}, {0.9157074104439431, 
       4.437499981032941}, {0.9029428580865548, 4.362222184858401}}], 
      PolygonBox[{{0.7697483574637449, 4.437344993353523}, {
       0.9157074104439431, 4.437499981032941}, {0.8125000000000001, 
       4.3247595264191645`}, {0.7697483574637449, 4.437344993353523}}], 
      PolygonBox[{{0.8125000000000001, 4.3247595264191645`}, {
       0.7348349570550448, 4.265165042944956}, {0.7697483574637449, 
       4.437344993353523}, {0.8125000000000001, 4.3247595264191645`}}], 
      PolygonBox[{{0.5950572556670028, 4.404942744332997}, {
       0.7697483574637449, 4.437344993353523}, {0.7348349570550448, 
       4.265165042944956}, {0.5950572556670028, 4.404942744332997}}], 
      PolygonBox[{{0.7348349570550448, 4.265165042944956}, {
       0.6752404735808355, 4.1875}, {0.5950572556670028, 4.404942744332997}, {
       0.7348349570550448, 4.265165042944956}}], 
      PolygonBox[{{0.5626550066464766, 4.230251642536255}, {
       0.5950572556670028, 4.404942744332997}, {0.6752404735808355, 4.1875}, {
       0.5626550066464766, 4.230251642536255}}], 
      PolygonBox[{{0.6752404735808355, 4.1875}, {0.6377778151415994, 
       4.097057141913446}, {0.5626550066464766, 4.230251642536255}, {
       0.6752404735808355, 4.1875}}], 
      PolygonBox[{{0.5625000189670593, 4.084292589556062}, {
       0.5626550066464766, 4.230251642536255}, {0.6377778151415994, 
       4.097057141913446}, {0.5625000189670593, 4.084292589556062}}], 
      PolygonBox[{{0.6377778151415994, 4.097057141913446}, {0.625, 4.}, {
       0.5625000189670593, 4.084292589556062}, {0.6377778151415994, 
       4.097057141913446}}], 
      PolygonBox[{{0.5625, 4.000123178062996}, {0.5625000189670593, 
       4.084292589556062}, {0.625, 4.}, {0.5625, 4.000123178062996}}], 
      PolygonBox[{{0.625, 4.}, {0.6377778151415994, 3.902942858086555}, {
       0.5625, 4.000123178062996}, {0.625, 4.}}], 
      PolygonBox[{{0.5625000189670593, 3.915707410443945}, {0.5625, 
       4.000123178062996}, {0.6377778151415994, 3.902942858086555}, {
       0.5625000189670593, 3.915707410443945}}], 
      PolygonBox[{{0.6377778151415994, 3.902942858086555}, {
       0.6752404735808354, 3.8125}, {0.5625000189670593, 3.915707410443945}, {
       0.6377778151415994, 3.902942858086555}}], 
      PolygonBox[{{0.5626550066464766, 3.769748357463745}, {
       0.5625000189670593, 3.915707410443945}, {0.6752404735808354, 3.8125}, {
       0.5626550066464766, 3.769748357463745}}], 
      PolygonBox[{{0.6752404735808354, 3.8125}, {0.7348349570550446, 
       3.7348349570550448`}, {0.5626550066464766, 3.769748357463745}, {
       0.6752404735808354, 3.8125}}], 
      PolygonBox[{{0.5950572556670028, 3.595057255667003}, {
       0.5626550066464766, 3.769748357463745}, {0.7348349570550446, 
       3.7348349570550448`}, {0.5950572556670028, 3.595057255667003}}], 
      PolygonBox[{{0.7348349570550446, 3.7348349570550448`}, {
       0.8124999999999998, 3.6752404735808355`}, {0.5950572556670028, 
       3.595057255667003}, {0.7348349570550446, 3.7348349570550448`}}], 
      PolygonBox[{{0.7697483574637449, 3.5626550066464766`}, {
       0.5950572556670028, 3.595057255667003}, {0.8124999999999998, 
       3.6752404735808355`}, {0.7697483574637449, 3.5626550066464766`}}], 
      PolygonBox[{{0.8124999999999998, 3.6752404735808355`}, {
       0.9029428580865544, 3.6377778151415994`}, {0.7697483574637449, 
       3.5626550066464766`}, {0.8124999999999998, 3.6752404735808355`}}], 
      PolygonBox[{{0.9157074104439358, 3.562500018967059}, {
       0.7697483574637449, 3.5626550066464766`}, {0.9029428580865544, 
       3.6377778151415994`}, {0.9157074104439358, 3.562500018967059}}], 
      PolygonBox[{{0.9029428580865544, 3.6377778151415994`}, {1., 3.625}, {
       0.9157074104439358, 3.562500018967059}, {0.9029428580865544, 
       3.6377778151415994`}}], 
      PolygonBox[{{1.000134841831043, 3.5625}, {0.9157074104439358, 
       3.562500018967059}, {1., 3.625}, {1.000134841831043, 3.5625}}], 
      PolygonBox[{{1., 3.625}, {1.0970571419134452`, 3.6377778151415994`}, {
       1.000134841831043, 3.5625}, {1., 3.625}}], 
      PolygonBox[{{1.0842925895560531`, 3.562500018967059}, {
       1.000134841831043, 3.5625}, {1.0970571419134452`, 
       3.6377778151415994`}, {1.0842925895560531`, 3.562500018967059}}], 
      PolygonBox[{{1.0970571419134452`, 3.6377778151415994`}, {
       1.1874999999999998`, 3.6752404735808355`}, {1.0842925895560531`, 
       3.562500018967059}, {1.0970571419134452`, 3.6377778151415994`}}], 
      PolygonBox[{{1.2302516425362546`, 3.5626550066464766`}, {
       1.0842925895560531`, 3.562500018967059}, {1.1874999999999998`, 
       3.6752404735808355`}, {1.2302516425362546`, 3.5626550066464766`}}], 
      PolygonBox[{{1.1874999999999998`, 3.6752404735808355`}, {
       1.2651650429449552`, 3.7348349570550448`}, {1.2302516425362546`, 
       3.5626550066464766`}, {1.1874999999999998`, 3.6752404735808355`}}], 
      PolygonBox[{{1.4049427443329972`, 3.595057255667003}, {
       1.2302516425362546`, 3.5626550066464766`}, {1.2651650429449552`, 
       3.7348349570550448`}, {1.4049427443329972`, 3.595057255667003}}], 
      PolygonBox[{{1.2651650429449552`, 3.7348349570550448`}, {
       1.2651650429449552`, 3.7348349570550448`}, {1.4049427443329972`, 
       3.595057255667003}, {1.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{1.4049427443329972`, 3.595057255667003}, {
       1.4049427443329972`, 3.595057255667003}, {1.2651650429449552`, 
       3.7348349570550448`}, {1.4049427443329972`, 3.595057255667003}}], 
      PolygonBox[{{1.4049427443329972`, 3.595057255667003}, {
       1.4373449933535234`, 3.7697483574637447`}, {1.5, 3.5}, {
       1.4049427443329972`, 3.595057255667003}}], 
      PolygonBox[{{1.5, 3.642337217350632}, {1.5, 3.5}, {1.4373449933535234`, 
       3.7697483574637447`}, {1.5, 3.642337217350632}}], 
      PolygonBox[{{1.4373449933535234`, 3.7697483574637447`}, {
       1.4374999810329407`, 3.915707410443938}, {1.5, 3.642337217350632}, {
       1.4373449933535234`, 3.7697483574637447`}}], 
      PolygonBox[{{1.5, 3.79409099469826}, {1.5, 3.642337217350632}, {
       1.4374999810329407`, 3.915707410443938}, {1.5, 3.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, 3.915707410443938}, {1.4375, 4.}, {
       1.5, 3.79409099469826}, {1.4374999810329407`, 3.915707410443938}}], 
      PolygonBox[{{1.5, 4.}, {1.5, 3.79409099469826}, {1.4375, 4.}, {1.5, 
       4.}}], PolygonBox[{{1.4375, 4.}, {1.4374999810329407`, 
       4.084292589556061}, {1.5, 4.}, {1.4375, 4.}}], 
      PolygonBox[{{1.5, 4.20590900530174}, {1.5, 4.}, {1.4374999810329407`, 
       4.084292589556061}, {1.5, 4.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, 4.084292589556061}, {
       1.4373449933535234`, 4.230251642536255}, {1.5, 4.20590900530174}, {
       1.4374999810329407`, 4.084292589556061}}], 
      PolygonBox[{{1.5, 4.357662782649368}, {1.5, 4.20590900530174}, {
       1.4373449933535234`, 4.230251642536255}, {1.5, 4.357662782649368}}], 
      PolygonBox[{{1.4373449933535234`, 4.230251642536255}, {
       1.4049427443329972`, 4.404942744332997}, {1.5, 4.357662782649368}, {
       1.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{1.491446564961186, 4.491446564961186}, {1.5, 
       4.357662782649368}, {1.4049427443329972`, 4.404942744332997}, {
       1.491446564961186, 4.491446564961186}}], 
      PolygonBox[{{1.4049427443329972`, 4.404942744332997}, {
       1.230251642536255, 4.437344993353523}, {1.491446564961186, 
       4.491446564961186}, {1.4049427443329972`, 4.404942744332997}}], 
      PolygonBox[{{1.3576627826493681`, 4.5}, {1.491446564961186, 
       4.491446564961186}, {1.230251642536255, 4.437344993353523}, {
       1.3576627826493681`, 4.5}}], 
      PolygonBox[{{1.230251642536255, 4.437344993353523}, {
       1.0842925895560604`, 4.437499981032941}, {1.3576627826493681`, 4.5}, {
       1.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{1.2059090053732557`, 4.5}, {1.3576627826493681`, 4.5}, {
       1.0842925895560604`, 4.437499981032941}, {1.2059090053732557`, 4.5}}], 
      PolygonBox[{{1.0842925895560604`, 4.437499981032941}, {
       1.0001055272204877`, 4.4375}, {1.2059090053732557`, 4.5}, {
       1.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{1.07794195802689, 4.5}, {1.2059090053732557`, 4.5}, {
       1.0001055272204877`, 4.4375}, {1.07794195802689, 4.5}}], 
      PolygonBox[{{1.0001055272204877`, 4.4375}, {0.9157074104439431, 
       4.437499981032941}, {1.07794195802689, 4.5}, {1.0001055272204877`, 
       4.4375}}], 
      PolygonBox[{{0.7940909946955543, 4.5}, {1.07794195802689, 4.5}, {
       0.9157074104439431, 4.437499981032941}, {0.7940909946955543, 4.5}}], 
      PolygonBox[{{0.9157074104439431, 4.437499981032941}, {
       0.7697483574637449, 4.437344993353523}, {0.7940909946955543, 4.5}, {
       0.9157074104439431, 4.437499981032941}}], 
      PolygonBox[{{0.6423372173506338, 4.5}, {0.7940909946955543, 4.5}, {
       0.7697483574637449, 4.437344993353523}, {0.6423372173506338, 4.5}}], 
      PolygonBox[{{0.7697483574637449, 4.437344993353523}, {
       0.5950572556670028, 4.404942744332997}, {0.6423372173506338, 4.5}, {
       0.7697483574637449, 4.437344993353523}}], 
      PolygonBox[{{1.5, 4.5}, {0.6423372173506338, 4.5}, {0.5950572556670028, 
       4.404942744332997}, {1.5, 4.5}}], 
      PolygonBox[{{0.5950572556670028, 4.404942744332997}, {
       0.5626550066464766, 4.230251642536255}, {1.5, 4.5}, {
       0.5950572556670028, 4.404942744332997}}], 
      PolygonBox[{{0.5, 4.357662782649369}, {1.5, 4.5}, {0.5626550066464766, 
       4.230251642536255}, {0.5, 4.357662782649369}}], 
      PolygonBox[{{0.5626550066464766, 4.230251642536255}, {
       0.5625000189670593, 4.084292589556062}, {0.5, 4.357662782649369}, {
       0.5626550066464766, 4.230251642536255}}], 
      PolygonBox[{{0.5, 4.205909005282899}, {0.5, 4.357662782649369}, {
       0.5625000189670593, 4.084292589556062}, {0.5, 4.205909005282899}}], 
      PolygonBox[{{0.5625000189670593, 4.084292589556062}, {0.5625, 
       4.000123178062996}, {0.5, 4.205909005282899}, {0.5625000189670593, 
       4.084292589556062}}], 
      PolygonBox[{{0.5, 4.0806786667587005`}, {0.5, 4.205909005282899}, {
       0.5625, 4.000123178062996}, {0.5, 4.0806786667587005`}}], 
      PolygonBox[{{0.5625, 4.000123178062996}, {0.5625000189670593, 
       3.915707410443945}, {0.5, 4.0806786667587005`}, {0.5625, 
       4.000123178062996}}], 
      PolygonBox[{{0.5, 3.7940909948547215`}, {0.5, 4.0806786667587005`}, {
       0.5625000189670593, 3.915707410443945}, {0.5, 3.7940909948547215`}}], 
      PolygonBox[{{0.5625000189670593, 3.915707410443945}, {
       0.5626550066464766, 3.769748357463745}, {0.5, 3.7940909948547215`}, {
       0.5625000189670593, 3.915707410443945}}], 
      PolygonBox[{{0.5, 3.6423372173506348`}, {0.5, 3.7940909948547215`}, {
       0.5626550066464766, 3.769748357463745}, {0.5, 3.6423372173506348`}}], 
      PolygonBox[{{0.5626550066464766, 3.769748357463745}, {
       0.5950572556670028, 3.595057255667003}, {0.5, 3.6423372173506348`}, {
       0.5626550066464766, 3.769748357463745}}], 
      PolygonBox[{{0.5, 4.5}, {0.5, 3.6423372173506348`}, {0.5950572556670028,
        3.595057255667003}, {0.5, 4.5}}], 
      PolygonBox[{{0.5950572556670028, 3.595057255667003}, {
       0.7697483574637449, 3.5626550066464766`}, {0.5, 4.5}, {
       0.5950572556670028, 3.595057255667003}}], 
      PolygonBox[{{0.5, 3.5}, {0.5, 4.5}, {0.7697483574637449, 
       3.5626550066464766`}, {0.5, 3.5}}], 
      PolygonBox[{{0.7697483574637449, 3.5626550066464766`}, {
       0.9157074104439358, 3.562500018967059}, {0.5, 3.5}, {
       0.7697483574637449, 3.5626550066464766`}}], 
      PolygonBox[{{0.794090994433172, 3.5}, {0.5, 3.5}, {0.9157074104439358, 
       3.562500018967059}, {0.794090994433172, 3.5}}], 
      PolygonBox[{{0.9157074104439358, 3.562500018967059}, {1.000134841831043,
        3.5625}, {0.794090994433172, 3.5}, {0.9157074104439358, 
       3.562500018967059}}], 
      PolygonBox[{{1.0823238704010616`, 3.5}, {0.794090994433172, 3.5}, {
       1.000134841831043, 3.5625}, {1.0823238704010616`, 3.5}}], 
      PolygonBox[{{1.000134841831043, 3.5625}, {1.0842925895560531`, 
       3.562500018967059}, {1.0823238704010616`, 3.5}, {1.000134841831043, 
       3.5625}}], 
      PolygonBox[{{1.2059090053603974`, 3.5}, {1.0823238704010616`, 3.5}, {
       1.0842925895560531`, 3.562500018967059}, {1.2059090053603974`, 3.5}}], 
      PolygonBox[{{1.0842925895560531`, 3.562500018967059}, {
       1.2302516425362546`, 3.5626550066464766`}, {1.2059090053603974`, 
       3.5}, {1.0842925895560531`, 3.562500018967059}}], 
      PolygonBox[{{1.357662782649371, 3.5}, {1.2059090053603974`, 3.5}, {
       1.2302516425362546`, 3.5626550066464766`}, {1.357662782649371, 3.5}}], 
      PolygonBox[{{1.2302516425362546`, 3.5626550066464766`}, {
       1.4049427443329972`, 3.595057255667003}, {1.357662782649371, 3.5}, {
       1.2302516425362546`, 3.5626550066464766`}}], 
      PolygonBox[{{1.5, 3.5}, {1.357662782649371, 3.5}, {1.4049427443329972`, 
       3.595057255667003}, {1.5, 3.5}}], 
      PolygonBox[{{1.4049427443329972`, 3.595057255667003}, {
       1.4049427443329972`, 3.595057255667003}, {1.5, 3.5}, {
       1.4049427443329972`, 3.595057255667003}}], 
      PolygonBox[{{1.5, 3.5}, {1.5, 3.5}, {1.4049427443329972`, 
       3.595057255667003}, {1.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, 5.}, {0.5208333333333333, 5.}, {0.5416666666666667, 
       5.}, {0.5625, 5.}, {0.5833333333333333, 5.}, {0.6041666666666666, 
       5.}, {0.625, 5.}, {0.625, 5.}, {0.6041666666666667, 5.}, {
       0.5833333333333333, 5.}, {0.5625, 5.}, {0.5416666666666667, 5.}, {
       0.5208333333333334, 5.}, {0.5, 5.}, {0.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.375, 5.}, {1.3958333333333333`, 5.}, {1.4166666666666667`, 
       5.}, {1.4375, 5.}, {1.4583333333333333`, 5.}, {1.4791666666666665`, 
       5.}, {1.5, 5.}, {1.5, 5.}, {1.4791666666666667`, 5.}, {
       1.4583333333333333`, 5.}, {1.4375, 5.}, {1.4166666666666667`, 5.}, {
       1.3958333333333335`, 5.}, {1.375, 5.}, {1.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 4.5}, {1., 4.520833333333333}, {1., 4.541666666666667}, {
       1., 4.5625}, {1., 4.583333333333333}, {1., 4.604166666666667}, {1., 
       4.625}, {1., 4.625}, {1., 4.604166666666667}, {1., 
       4.583333333333333}, {1., 4.5625}, {1., 4.541666666666667}, {1., 
       4.520833333333333}, {1., 4.5}, {1., 4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 5.375}, {1., 5.395833333333333}, {1., 
       5.416666666666667}, {1., 5.4375}, {1., 5.458333333333333}, {1., 
       5.479166666666667}, {1., 5.5}, {1., 5.5}, {1., 5.479166666666667}, {1.,
        5.458333333333333}, {1., 5.4375}, {1., 5.416666666666667}, {1., 
       5.395833333333333}, {1., 5.375}, {1., 5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.625, 5.}, {0.75, 5.}, {0.875, 5.}, {1., 5.}, {1.125, 5.}, {
       1.25, 5.}, {1.375, 5.}, {1.375, 5.}, {1.25, 5.}, {1.125, 5.}, {1., 
       5.}, {0.875, 5.}, {0.75, 5.}, {0.625, 5.}, {0.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., 4.625}, {1., 4.75}, {1., 4.875}, {1., 5.}, {1., 5.125}, {
       1., 5.25}, {1., 5.375}, {1., 5.375}, {1., 5.25}, {1., 5.125}, {1., 
       5.}, {1., 4.875}, {1., 4.75}, {1., 4.625}, {1., 4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHf7CG0iMOVxbG1K09/tVcv6vyUlCzikNA3gdvc
6CtE/oCIg9lt882ydl/sz307m9POL+oA0ffZfobyk0O9PqIO806onuru/Wj/
NSM8/lURTP4DRH+DqMPRvC3ZL568gcszgiVewfVP8Zww80jzc7j5Do/vvZg4
+ync/ogdLqxrM57Ya0DdBzH/Cdz9MPmbvWW8c+cIo+p3EHaYBDXfmNNocsUH
IYd//0HgpX3GHWnbos1CDoeg7uOevmKBaK+QA1j6/3uo+4Uc5kL9hyr/Ca4f
Fj5GUPNRwg9oPyx8b0Ddhx7+APrvnuU=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE/7CG0mENYKAh8hfNXrwKBT3A+hP6AJv8KTf9T
NPUPCPLB2kJF4XyIuSJo6kXQ1AujqRdCU4/JD0Vxn5DDKhT3w9R/QJP/hKb/
K5r6HwT5qO77geb+H2j++4Hm/x9o4YOILwDge1uW
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{1.2651650429449552`, 4.734834957055044}, {
       1.3247595264191645`, 4.8125}, {1.4049427443329972`, 
       4.595057255667003}, {1.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{1.4373449933535234`, 4.769748357463745}, {
       1.4049427443329972`, 4.595057255667003}, {1.3247595264191645`, 
       4.8125}, {1.4373449933535234`, 4.769748357463745}}], 
      PolygonBox[{{1.3247595264191645`, 4.8125}, {1.3622221848584006`, 
       4.902942858086555}, {1.4373449933535234`, 4.769748357463745}, {
       1.3247595264191645`, 4.8125}}], 
      PolygonBox[{{1.4374999810329407`, 4.915707410443938}, {
       1.4373449933535234`, 4.769748357463745}, {1.3622221848584006`, 
       4.902942858086555}, {1.4374999810329407`, 4.915707410443938}}], 
      PolygonBox[{{1.3622221848584006`, 4.902942858086555}, {1.375, 5.}, {
       1.4374999810329407`, 4.915707410443938}, {1.3622221848584006`, 
       4.902942858086555}}], 
      PolygonBox[{{1.4375, 5.}, {1.4374999810329407`, 4.915707410443938}, {
       1.375, 5.}, {1.4375, 5.}}], 
      PolygonBox[{{1.375, 5.}, {1.3622221848584006`, 5.097057141913445}, {
       1.4375, 5.}, {1.375, 5.}}], 
      PolygonBox[{{1.4374999810329407`, 5.084292589556061}, {1.4375, 5.}, {
       1.3622221848584006`, 5.097057141913445}, {1.4374999810329407`, 
       5.084292589556061}}], 
      PolygonBox[{{1.3622221848584006`, 5.097057141913445}, {
       1.3247595264191645`, 5.1875}, {1.4374999810329407`, 
       5.084292589556061}, {1.3622221848584006`, 5.097057141913445}}], 
      PolygonBox[{{1.4373449933535234`, 5.230251642536255}, {
       1.4374999810329407`, 5.084292589556061}, {1.3247595264191645`, 
       5.1875}, {1.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{1.3247595264191645`, 5.1875}, {1.2651650429449552`, 
       5.265165042944956}, {1.4373449933535234`, 5.230251642536255}, {
       1.3247595264191645`, 5.1875}}], 
      PolygonBox[{{1.4049427443329972`, 5.404942744332997}, {
       1.4373449933535234`, 5.230251642536255}, {1.2651650429449552`, 
       5.265165042944956}, {1.4049427443329972`, 5.404942744332997}}], 
      PolygonBox[{{1.2651650429449552`, 5.265165042944956}, {1.1875, 
       5.3247595264191645`}, {1.4049427443329972`, 5.404942744332997}, {
       1.2651650429449552`, 5.265165042944956}}], 
      PolygonBox[{{1.230251642536255, 5.437344993353523}, {
       1.4049427443329972`, 5.404942744332997}, {1.1875, 
       5.3247595264191645`}, {1.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{1.1875, 5.3247595264191645`}, {1.0970571419134454`, 
       5.362222184858401}, {1.230251642536255, 5.437344993353523}, {1.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{1.0842925895560604`, 5.437499981032941}, {
       1.230251642536255, 5.437344993353523}, {1.0970571419134454`, 
       5.362222184858401}, {1.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{1.0970571419134454`, 5.362222184858401}, {1., 5.375}, {
       1.0842925895560604`, 5.437499981032941}, {1.0970571419134454`, 
       5.362222184858401}}], 
      PolygonBox[{{1.0001055272204877`, 5.4375}, {1.0842925895560604`, 
       5.437499981032941}, {1., 5.375}, {1.0001055272204877`, 5.4375}}], 
      PolygonBox[{{1., 5.375}, {0.9029428580865548, 5.362222184858401}, {
       1.0001055272204877`, 5.4375}, {1., 5.375}}], 
      PolygonBox[{{0.9157074104439431, 5.437499981032941}, {
       1.0001055272204877`, 5.4375}, {0.9029428580865548, 
       5.362222184858401}, {0.9157074104439431, 5.437499981032941}}], 
      PolygonBox[{{0.9029428580865548, 5.362222184858401}, {
       0.8125000000000001, 5.3247595264191645`}, {0.9157074104439431, 
       5.437499981032941}, {0.9029428580865548, 5.362222184858401}}], 
      PolygonBox[{{0.7697483574637449, 5.437344993353523}, {
       0.9157074104439431, 5.437499981032941}, {0.8125000000000001, 
       5.3247595264191645`}, {0.7697483574637449, 5.437344993353523}}], 
      PolygonBox[{{0.8125000000000001, 5.3247595264191645`}, {
       0.7348349570550448, 5.265165042944956}, {0.7697483574637449, 
       5.437344993353523}, {0.8125000000000001, 5.3247595264191645`}}], 
      PolygonBox[{{0.5950572556670028, 5.404942744332997}, {
       0.7697483574637449, 5.437344993353523}, {0.7348349570550448, 
       5.265165042944956}, {0.5950572556670028, 5.404942744332997}}], 
      PolygonBox[{{0.7348349570550448, 5.265165042944956}, {
       0.6752404735808355, 5.1875}, {0.5950572556670028, 5.404942744332997}, {
       0.7348349570550448, 5.265165042944956}}], 
      PolygonBox[{{0.5626550066464766, 5.230251642536255}, {
       0.5950572556670028, 5.404942744332997}, {0.6752404735808355, 5.1875}, {
       0.5626550066464766, 5.230251642536255}}], 
      PolygonBox[{{0.6752404735808355, 5.1875}, {0.6377778151415994, 
       5.097057141913446}, {0.5626550066464766, 5.230251642536255}, {
       0.6752404735808355, 5.1875}}], 
      PolygonBox[{{0.5625000189670593, 5.084292589556062}, {
       0.5626550066464766, 5.230251642536255}, {0.6377778151415994, 
       5.097057141913446}, {0.5625000189670593, 5.084292589556062}}], 
      PolygonBox[{{0.6377778151415994, 5.097057141913446}, {0.625, 5.}, {
       0.5625000189670593, 5.084292589556062}, {0.6377778151415994, 
       5.097057141913446}}], 
      PolygonBox[{{0.5625, 5.000123178062996}, {0.5625000189670593, 
       5.084292589556062}, {0.625, 5.}, {0.5625, 5.000123178062996}}], 
      PolygonBox[{{0.625, 5.}, {0.6377778151415994, 4.902942858086555}, {
       0.5625, 5.000123178062996}, {0.625, 5.}}], 
      PolygonBox[{{0.5625000189670593, 4.915707410443945}, {0.5625, 
       5.000123178062996}, {0.6377778151415994, 4.902942858086555}, {
       0.5625000189670593, 4.915707410443945}}], 
      PolygonBox[{{0.6377778151415994, 4.902942858086555}, {
       0.6752404735808354, 4.8125}, {0.5625000189670593, 4.915707410443945}, {
       0.6377778151415994, 4.902942858086555}}], 
      PolygonBox[{{0.5626550066464766, 4.769748357463746}, {
       0.5625000189670593, 4.915707410443945}, {0.6752404735808354, 4.8125}, {
       0.5626550066464766, 4.769748357463746}}], 
      PolygonBox[{{0.6752404735808354, 4.8125}, {0.7348349570550446, 
       4.734834957055044}, {0.5626550066464766, 4.769748357463746}, {
       0.6752404735808354, 4.8125}}], 
      PolygonBox[{{0.5950572556670028, 4.595057255667003}, {
       0.5626550066464766, 4.769748357463746}, {0.7348349570550446, 
       4.734834957055044}, {0.5950572556670028, 4.595057255667003}}], 
      PolygonBox[{{0.7348349570550446, 4.734834957055044}, {
       0.8124999999999998, 4.6752404735808355`}, {0.5950572556670028, 
       4.595057255667003}, {0.7348349570550446, 4.734834957055044}}], 
      PolygonBox[{{0.7697483574637449, 4.562655006646477}, {
       0.5950572556670028, 4.595057255667003}, {0.8124999999999998, 
       4.6752404735808355`}, {0.7697483574637449, 4.562655006646477}}], 
      PolygonBox[{{0.8124999999999998, 4.6752404735808355`}, {
       0.9029428580865544, 4.637777815141599}, {0.7697483574637449, 
       4.562655006646477}, {0.8124999999999998, 4.6752404735808355`}}], 
      PolygonBox[{{0.9157074104439358, 4.562500018967059}, {
       0.7697483574637449, 4.562655006646477}, {0.9029428580865544, 
       4.637777815141599}, {0.9157074104439358, 4.562500018967059}}], 
      PolygonBox[{{0.9029428580865544, 4.637777815141599}, {1., 4.625}, {
       0.9157074104439358, 4.562500018967059}, {0.9029428580865544, 
       4.637777815141599}}], 
      PolygonBox[{{1.000134841831043, 4.5625}, {0.9157074104439358, 
       4.562500018967059}, {1., 4.625}, {1.000134841831043, 4.5625}}], 
      PolygonBox[{{1., 4.625}, {1.0970571419134452`, 4.637777815141599}, {
       1.000134841831043, 4.5625}, {1., 4.625}}], 
      PolygonBox[{{1.0842925895560531`, 4.562500018967059}, {
       1.000134841831043, 4.5625}, {1.0970571419134452`, 4.637777815141599}, {
       1.0842925895560531`, 4.562500018967059}}], 
      PolygonBox[{{1.0970571419134452`, 4.637777815141599}, {
       1.1874999999999998`, 4.6752404735808355`}, {1.0842925895560531`, 
       4.562500018967059}, {1.0970571419134452`, 4.637777815141599}}], 
      PolygonBox[{{1.2302516425362546`, 4.562655006646477}, {
       1.0842925895560531`, 4.562500018967059}, {1.1874999999999998`, 
       4.6752404735808355`}, {1.2302516425362546`, 4.562655006646477}}], 
      PolygonBox[{{1.1874999999999998`, 4.6752404735808355`}, {
       1.2651650429449552`, 4.734834957055044}, {1.2302516425362546`, 
       4.562655006646477}, {1.1874999999999998`, 4.6752404735808355`}}], 
      PolygonBox[{{1.4049427443329972`, 4.595057255667003}, {
       1.2302516425362546`, 4.562655006646477}, {1.2651650429449552`, 
       4.734834957055044}, {1.4049427443329972`, 4.595057255667003}}], 
      PolygonBox[{{1.2651650429449552`, 4.734834957055044}, {
       1.2651650429449552`, 4.734834957055044}, {1.4049427443329972`, 
       4.595057255667003}, {1.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{1.4049427443329972`, 4.595057255667003}, {
       1.4049427443329972`, 4.595057255667003}, {1.2651650429449552`, 
       4.734834957055044}, {1.4049427443329972`, 4.595057255667003}}], 
      PolygonBox[{{1.4049427443329972`, 4.595057255667003}, {
       1.4373449933535234`, 4.769748357463745}, {1.5, 4.5}, {
       1.4049427443329972`, 4.595057255667003}}], 
      PolygonBox[{{1.5, 4.642337217350632}, {1.5, 4.5}, {1.4373449933535234`, 
       4.769748357463745}, {1.5, 4.642337217350632}}], 
      PolygonBox[{{1.4373449933535234`, 4.769748357463745}, {
       1.4374999810329407`, 4.915707410443938}, {1.5, 4.642337217350632}, {
       1.4373449933535234`, 4.769748357463745}}], 
      PolygonBox[{{1.5, 4.79409099469826}, {1.5, 4.642337217350632}, {
       1.4374999810329407`, 4.915707410443938}, {1.5, 4.79409099469826}}], 
      PolygonBox[{{1.4374999810329407`, 4.915707410443938}, {1.4375, 5.}, {
       1.5, 4.79409099469826}, {1.4374999810329407`, 4.915707410443938}}], 
      PolygonBox[{{1.5, 5.}, {1.5, 4.79409099469826}, {1.4375, 5.}, {1.5, 
       5.}}], PolygonBox[{{1.4375, 5.}, {1.4374999810329407`, 
       5.084292589556061}, {1.5, 5.}, {1.4375, 5.}}], 
      PolygonBox[{{1.5, 5.20590900530174}, {1.5, 5.}, {1.4374999810329407`, 
       5.084292589556061}, {1.5, 5.20590900530174}}], 
      PolygonBox[{{1.4374999810329407`, 5.084292589556061}, {
       1.4373449933535234`, 5.230251642536255}, {1.5, 5.20590900530174}, {
       1.4374999810329407`, 5.084292589556061}}], 
      PolygonBox[{{1.5, 5.357662782649368}, {1.5, 5.20590900530174}, {
       1.4373449933535234`, 5.230251642536255}, {1.5, 5.357662782649368}}], 
      PolygonBox[{{1.4373449933535234`, 5.230251642536255}, {
       1.4049427443329972`, 5.404942744332997}, {1.5, 5.357662782649368}, {
       1.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{1.491446564961186, 5.491446564961186}, {1.5, 
       5.357662782649368}, {1.4049427443329972`, 5.404942744332997}, {
       1.491446564961186, 5.491446564961186}}], 
      PolygonBox[{{1.4049427443329972`, 5.404942744332997}, {
       1.230251642536255, 5.437344993353523}, {1.491446564961186, 
       5.491446564961186}, {1.4049427443329972`, 5.404942744332997}}], 
      PolygonBox[{{1.3576627826493681`, 5.5}, {1.491446564961186, 
       5.491446564961186}, {1.230251642536255, 5.437344993353523}, {
       1.3576627826493681`, 5.5}}], 
      PolygonBox[{{1.230251642536255, 5.437344993353523}, {
       1.0842925895560604`, 5.437499981032941}, {1.3576627826493681`, 5.5}, {
       1.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{1.2059090053732557`, 5.5}, {1.3576627826493681`, 5.5}, {
       1.0842925895560604`, 5.437499981032941}, {1.2059090053732557`, 5.5}}], 
      PolygonBox[{{1.0842925895560604`, 5.437499981032941}, {
       1.0001055272204877`, 5.4375}, {1.2059090053732557`, 5.5}, {
       1.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{1.07794195802689, 5.5}, {1.2059090053732557`, 5.5}, {
       1.0001055272204877`, 5.4375}, {1.07794195802689, 5.5}}], 
      PolygonBox[{{1.0001055272204877`, 5.4375}, {0.9157074104439431, 
       5.437499981032941}, {1.07794195802689, 5.5}, {1.0001055272204877`, 
       5.4375}}], 
      PolygonBox[{{0.7940909946955543, 5.5}, {1.07794195802689, 5.5}, {
       0.9157074104439431, 5.437499981032941}, {0.7940909946955543, 5.5}}], 
      PolygonBox[{{0.9157074104439431, 5.437499981032941}, {
       0.7697483574637449, 5.437344993353523}, {0.7940909946955543, 5.5}, {
       0.9157074104439431, 5.437499981032941}}], 
      PolygonBox[{{0.6423372173506338, 5.5}, {0.7940909946955543, 5.5}, {
       0.7697483574637449, 5.437344993353523}, {0.6423372173506338, 5.5}}], 
      PolygonBox[{{0.7697483574637449, 5.437344993353523}, {
       0.5950572556670028, 5.404942744332997}, {0.6423372173506338, 5.5}, {
       0.7697483574637449, 5.437344993353523}}], 
      PolygonBox[{{1.5, 5.5}, {0.6423372173506338, 5.5}, {0.5950572556670028, 
       5.404942744332997}, {1.5, 5.5}}], 
      PolygonBox[{{0.5950572556670028, 5.404942744332997}, {
       0.5626550066464766, 5.230251642536255}, {1.5, 5.5}, {
       0.5950572556670028, 5.404942744332997}}], 
      PolygonBox[{{0.5, 5.357662782649369}, {1.5, 5.5}, {0.5626550066464766, 
       5.230251642536255}, {0.5, 5.357662782649369}}], 
      PolygonBox[{{0.5626550066464766, 5.230251642536255}, {
       0.5625000189670593, 5.084292589556062}, {0.5, 5.357662782649369}, {
       0.5626550066464766, 5.230251642536255}}], 
      PolygonBox[{{0.5, 5.205909005282899}, {0.5, 5.357662782649369}, {
       0.5625000189670593, 5.084292589556062}, {0.5, 5.205909005282899}}], 
      PolygonBox[{{0.5625000189670593, 5.084292589556062}, {0.5625, 
       5.000123178062996}, {0.5, 5.205909005282899}, {0.5625000189670593, 
       5.084292589556062}}], 
      PolygonBox[{{0.5, 5.0806786667587005`}, {0.5, 5.205909005282899}, {
       0.5625, 5.000123178062996}, {0.5, 5.0806786667587005`}}], 
      PolygonBox[{{0.5625, 5.000123178062996}, {0.5625000189670593, 
       4.915707410443945}, {0.5, 5.0806786667587005`}, {0.5625, 
       5.000123178062996}}], 
      PolygonBox[{{0.5, 4.794090994854722}, {0.5, 5.0806786667587005`}, {
       0.5625000189670593, 4.915707410443945}, {0.5, 4.794090994854722}}], 
      PolygonBox[{{0.5625000189670593, 4.915707410443945}, {
       0.5626550066464766, 4.769748357463746}, {0.5, 4.794090994854722}, {
       0.5625000189670593, 4.915707410443945}}], 
      PolygonBox[{{0.5, 4.642337217350635}, {0.5, 4.794090994854722}, {
       0.5626550066464766, 4.769748357463746}, {0.5, 4.642337217350635}}], 
      PolygonBox[{{0.5626550066464766, 4.769748357463746}, {
       0.5950572556670028, 4.595057255667003}, {0.5, 4.642337217350635}, {
       0.5626550066464766, 4.769748357463746}}], 
      PolygonBox[{{0.5, 5.5}, {0.5, 4.642337217350635}, {0.5950572556670028, 
       4.595057255667003}, {0.5, 5.5}}], 
      PolygonBox[{{0.5950572556670028, 4.595057255667003}, {
       0.7697483574637449, 4.562655006646477}, {0.5, 5.5}, {
       0.5950572556670028, 4.595057255667003}}], 
      PolygonBox[{{0.5, 4.5}, {0.5, 5.5}, {0.7697483574637449, 
       4.562655006646477}, {0.5, 4.5}}], 
      PolygonBox[{{0.7697483574637449, 4.562655006646477}, {
       0.9157074104439358, 4.562500018967059}, {0.5, 4.5}, {
       0.7697483574637449, 4.562655006646477}}], 
      PolygonBox[{{0.794090994433172, 4.5}, {0.5, 4.5}, {0.9157074104439358, 
       4.562500018967059}, {0.794090994433172, 4.5}}], 
      PolygonBox[{{0.9157074104439358, 4.562500018967059}, {1.000134841831043,
        4.5625}, {0.794090994433172, 4.5}, {0.9157074104439358, 
       4.562500018967059}}], 
      PolygonBox[{{1.0823238704010616`, 4.5}, {0.794090994433172, 4.5}, {
       1.000134841831043, 4.5625}, {1.0823238704010616`, 4.5}}], 
      PolygonBox[{{1.000134841831043, 4.5625}, {1.0842925895560531`, 
       4.562500018967059}, {1.0823238704010616`, 4.5}, {1.000134841831043, 
       4.5625}}], 
      PolygonBox[{{1.2059090053603974`, 4.5}, {1.0823238704010616`, 4.5}, {
       1.0842925895560531`, 4.562500018967059}, {1.2059090053603974`, 4.5}}], 
      PolygonBox[{{1.0842925895560531`, 4.562500018967059}, {
       1.2302516425362546`, 4.562655006646477}, {1.2059090053603974`, 4.5}, {
       1.0842925895560531`, 4.562500018967059}}], 
      PolygonBox[{{1.357662782649371, 4.5}, {1.2059090053603974`, 4.5}, {
       1.2302516425362546`, 4.562655006646477}, {1.357662782649371, 4.5}}], 
      PolygonBox[{{1.2302516425362546`, 4.562655006646477}, {
       1.4049427443329972`, 4.595057255667003}, {1.357662782649371, 4.5}, {
       1.2302516425362546`, 4.562655006646477}}], 
      PolygonBox[{{1.5, 4.5}, {1.357662782649371, 4.5}, {1.4049427443329972`, 
       4.595057255667003}, {1.5, 4.5}}], 
      PolygonBox[{{1.4049427443329972`, 4.595057255667003}, {
       1.4049427443329972`, 4.595057255667003}, {1.5, 4.5}, {
       1.4049427443329972`, 4.595057255667003}}], 
      PolygonBox[{{1.5, 4.5}, {1.5, 4.5}, {1.4049427443329972`, 
       4.595057255667003}, {1.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, -5.}, {1.5208333333333333`, -5.}, {
       1.5416666666666667`, -5.}, {1.5625, -5.}, {1.5833333333333333`, -5.}, {
       1.6041666666666665`, -5.}, {1.625, -5.}, {1.625, -5.}, {
       1.6041666666666667`, -5.}, {1.5833333333333333`, -5.}, {1.5625, -5.}, {
       1.5416666666666667`, -5.}, {1.5208333333333335`, -5.}, {1.5, -5.}, {
       1.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, -5.}, {2.3958333333333335`, -5.}, {
       2.4166666666666665`, -5.}, {2.4375, -5.}, {2.4583333333333335`, -5.}, {
       2.4791666666666665`, -5.}, {2.5, -5.}, {2.5, -5.}, {
       2.4791666666666665`, -5.}, {2.4583333333333335`, -5.}, {2.4375, -5.}, {
       2.4166666666666665`, -5.}, {2.3958333333333335`, -5.}, {2.375, -5.}, {
       2.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -5.5}, {2., -5.479166666666667}, {
       2., -5.458333333333333}, {2., -5.4375}, {2., -5.416666666666667}, {
       2., -5.395833333333333}, {2., -5.375}, {2., -5.375}, {
       2., -5.395833333333333}, {2., -5.416666666666667}, {2., -5.4375}, {
       2., -5.458333333333333}, {2., -5.479166666666667}, {2., -5.5}, {
       2., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -4.625}, {2., -4.604166666666667}, {
       2., -4.583333333333333}, {2., -4.5625}, {2., -4.541666666666667}, {
       2., -4.520833333333333}, {2., -4.5}, {2., -4.5}, {
       2., -4.520833333333333}, {2., -4.541666666666667}, {2., -4.5625}, {
       2., -4.583333333333333}, {2., -4.604166666666667}, {2., -4.625}, {
       2., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, -5.}, {1.75, -5.}, {1.875, -5.}, {2., -5.}, {
       2.125, -5.}, {2.25, -5.}, {2.375, -5.}, {2.375, -5.}, {2.25, -5.}, {
       2.125, -5.}, {2., -5.}, {1.875, -5.}, {1.75, -5.}, {1.625, -5.}, {
       1.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -5.375}, {2., -5.25}, {2., -5.125}, {2., -5.}, {
       2., -4.875}, {2., -4.75}, {2., -4.625}, {2., -4.625}, {2., -4.75}, {
       2., -4.875}, {2., -5.}, {2., -5.125}, {2., -5.25}, {2., -5.375}, {
       2., -5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhBa5MCri+v2XXnK5HCzt4x37hzhAwbuJ1ql
ZzJB5B2ED8x+O/smnzyTgxGn0eSKD0IHwOINjA4Zd6RtizYLHfB/IvT06DEG
B+7pKxaI9kLlgToh6oQOJJvfMi0p+mePKv/XHqb/lMoJn0cHf9vDzF9QmP/l
xNlf9jD7dWIWNYWZ/LK/AXUfRD9UHuh+mLx6UeenpGQRVP0HRA6chJp/9tvZ
nHZ+0QP/weCP/QzlJ4d6fUQPJELd9zUjPP5VkSia+0UP+EH9B5MHa69ndIDp
h4XPOaj5KOF3ABG+GlD3oYc/AG+Km58=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhBa6MDqVSDABOeHggEjnA/VAOeHgeX/2qPq
/2WPqv4HQT5EH4IPsVcYTb0ImnoRNPWiaOrFMPirUNwnBvXfXzT1MP+Jofkf
pp/JAVU9C0E+qvtYHFDdD1MvgqZeGE29EJp6oQMAHWZckA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, -5.265165042944956}, {
       2.3247595264191645`, -5.1875}, {
       2.404942744332997, -5.404942744332997}, {
       2.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{2.4373449933535234`, -5.230251642536255}, {
       2.404942744332997, -5.404942744332997}, {
       2.3247595264191645`, -5.1875}, {
       2.4373449933535234`, -5.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, -5.1875}, {
       2.3622221848584006`, -5.097057141913445}, {
       2.4373449933535234`, -5.230251642536255}, {
       2.3247595264191645`, -5.1875}}], 
      PolygonBox[{{2.437499981032941, -5.084292589556062}, {
       2.4373449933535234`, -5.230251642536255}, {
       2.3622221848584006`, -5.097057141913445}, {
       2.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{2.3622221848584006`, -5.097057141913445}, {2.375, -5.}, {
       2.437499981032941, -5.084292589556062}, {
       2.3622221848584006`, -5.097057141913445}}], 
      PolygonBox[{{2.4375, -5.}, {2.437499981032941, -5.084292589556062}, {
       2.375, -5.}, {2.4375, -5.}}], 
      PolygonBox[{{2.375, -5.}, {2.3622221848584006`, -4.902942858086555}, {
       2.4375, -5.}, {2.375, -5.}}], 
      PolygonBox[{{2.437499981032941, -4.915707410443939}, {2.4375, -5.}, {
       2.3622221848584006`, -4.902942858086555}, {
       2.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{2.3622221848584006`, -4.902942858086555}, {
       2.3247595264191645`, -4.8125}, {
       2.437499981032941, -4.915707410443939}, {
       2.3622221848584006`, -4.902942858086555}}], 
      PolygonBox[{{2.4373449933535234`, -4.769748357463745}, {
       2.437499981032941, -4.915707410443939}, {
       2.3247595264191645`, -4.8125}, {
       2.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{2.3247595264191645`, -4.8125}, {
       2.2651650429449552`, -4.734834957055044}, {
       2.4373449933535234`, -4.769748357463745}, {
       2.3247595264191645`, -4.8125}}], 
      PolygonBox[{{2.404942744332997, -4.595057255667003}, {
       2.4373449933535234`, -4.769748357463745}, {
       2.2651650429449552`, -4.734834957055044}, {
       2.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{2.2651650429449552`, -4.734834957055044}, {
       2.1875, -4.6752404735808355`}, {
       2.404942744332997, -4.595057255667003}, {
       2.2651650429449552`, -4.734834957055044}}], 
      PolygonBox[{{2.2302516425362553`, -4.562655006646477}, {
       2.404942744332997, -4.595057255667003}, {
       2.1875, -4.6752404735808355`}, {
       2.2302516425362553`, -4.562655006646477}}], 
      PolygonBox[{{2.1875, -4.6752404735808355`}, {
       2.0970571419134454`, -4.637777815141599}, {
       2.2302516425362553`, -4.562655006646477}, {
       2.1875, -4.6752404735808355`}}], 
      PolygonBox[{{2.0842925895560604`, -4.562500018967059}, {
       2.2302516425362553`, -4.562655006646477}, {
       2.0970571419134454`, -4.637777815141599}, {
       2.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{2.0970571419134454`, -4.637777815141599}, {2., -4.625}, {
       2.0842925895560604`, -4.562500018967059}, {
       2.0970571419134454`, -4.637777815141599}}], 
      PolygonBox[{{2.0001055272204877`, -4.5625}, {
       2.0842925895560604`, -4.562500018967059}, {2., -4.625}, {
       2.0001055272204877`, -4.5625}}], 
      PolygonBox[{{2., -4.625}, {1.9029428580865548`, -4.637777815141599}, {
       2.0001055272204877`, -4.5625}, {2., -4.625}}], 
      PolygonBox[{{1.915707410443943, -4.562500018967059}, {
       2.0001055272204877`, -4.5625}, {
       1.9029428580865548`, -4.637777815141599}, {
       1.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{1.9029428580865548`, -4.637777815141599}, {
       1.8125, -4.6752404735808355`}, {
       1.915707410443943, -4.562500018967059}, {
       1.9029428580865548`, -4.637777815141599}}], 
      PolygonBox[{{1.769748357463745, -4.562655006646477}, {
       1.915707410443943, -4.562500018967059}, {
       1.8125, -4.6752404735808355`}, {
       1.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{1.8125, -4.6752404735808355`}, {
       1.7348349570550448`, -4.734834957055044}, {
       1.769748357463745, -4.562655006646477}, {
       1.8125, -4.6752404735808355`}}], 
      PolygonBox[{{1.5950572556670028`, -4.595057255667003}, {
       1.769748357463745, -4.562655006646477}, {
       1.7348349570550448`, -4.734834957055044}, {
       1.5950572556670028`, -4.595057255667003}}], 
      PolygonBox[{{1.7348349570550448`, -4.734834957055044}, {
       1.6752404735808355`, -4.8125}, {
       1.5950572556670028`, -4.595057255667003}, {
       1.7348349570550448`, -4.734834957055044}}], 
      PolygonBox[{{1.5626550066464766`, -4.769748357463745}, {
       1.5950572556670028`, -4.595057255667003}, {
       1.6752404735808355`, -4.8125}, {
       1.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{1.6752404735808355`, -4.8125}, {
       1.6377778151415994`, -4.902942858086554}, {
       1.5626550066464766`, -4.769748357463745}, {
       1.6752404735808355`, -4.8125}}], 
      PolygonBox[{{1.5625000189670593`, -4.915707410443938}, {
       1.5626550066464766`, -4.769748357463745}, {
       1.6377778151415994`, -4.902942858086554}, {
       1.5625000189670593`, -4.915707410443938}}], 
      PolygonBox[{{1.6377778151415994`, -4.902942858086554}, {1.625, -5.}, {
       1.5625000189670593`, -4.915707410443938}, {
       1.6377778151415994`, -4.902942858086554}}], 
      PolygonBox[{{1.5625, -4.999876821937004}, {
       1.5625000189670593`, -4.915707410443938}, {1.625, -5.}, {
       1.5625, -4.999876821937004}}], 
      PolygonBox[{{1.625, -5.}, {1.6377778151415994`, -5.097057141913445}, {
       1.5625, -4.999876821937004}, {1.625, -5.}}], 
      PolygonBox[{{1.5625000189670593`, -5.084292589556055}, {
       1.5625, -4.999876821937004}, {
       1.6377778151415994`, -5.097057141913445}, {
       1.5625000189670593`, -5.084292589556055}}], 
      PolygonBox[{{1.6377778151415994`, -5.097057141913445}, {
       1.6752404735808355`, -5.1875}, {
       1.5625000189670593`, -5.084292589556055}, {
       1.6377778151415994`, -5.097057141913445}}], 
      PolygonBox[{{1.5626550066464766`, -5.230251642536254}, {
       1.5625000189670593`, -5.084292589556055}, {
       1.6752404735808355`, -5.1875}, {
       1.5626550066464766`, -5.230251642536254}}], 
      PolygonBox[{{1.6752404735808355`, -5.1875}, {
       1.7348349570550448`, -5.265165042944956}, {
       1.5626550066464766`, -5.230251642536254}, {
       1.6752404735808355`, -5.1875}}], 
      PolygonBox[{{1.5950572556670028`, -5.404942744332997}, {
       1.5626550066464766`, -5.230251642536254}, {
       1.7348349570550448`, -5.265165042944956}, {
       1.5950572556670028`, -5.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, -5.265165042944956}, {
       1.8124999999999998`, -5.3247595264191645`}, {
       1.5950572556670028`, -5.404942744332997}, {
       1.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{1.769748357463745, -5.437344993353523}, {
       1.5950572556670028`, -5.404942744332997}, {
       1.8124999999999998`, -5.3247595264191645`}, {
       1.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{1.8124999999999998`, -5.3247595264191645`}, {
       1.9029428580865544`, -5.362222184858401}, {
       1.769748357463745, -5.437344993353523}, {
       1.8124999999999998`, -5.3247595264191645`}}], 
      PolygonBox[{{1.9157074104439358`, -5.437499981032941}, {
       1.769748357463745, -5.437344993353523}, {
       1.9029428580865544`, -5.362222184858401}, {
       1.9157074104439358`, -5.437499981032941}}], 
      PolygonBox[{{1.9029428580865544`, -5.362222184858401}, {2., -5.375}, {
       1.9157074104439358`, -5.437499981032941}, {
       1.9029428580865544`, -5.362222184858401}}], 
      PolygonBox[{{2.000134841831043, -5.4375}, {
       1.9157074104439358`, -5.437499981032941}, {2., -5.375}, {
       2.000134841831043, -5.4375}}], 
      PolygonBox[{{2., -5.375}, {2.097057141913445, -5.362222184858401}, {
       2.000134841831043, -5.4375}, {2., -5.375}}], 
      PolygonBox[{{2.0842925895560533`, -5.437499981032941}, {
       2.000134841831043, -5.4375}, {2.097057141913445, -5.362222184858401}, {
       2.0842925895560533`, -5.437499981032941}}], 
      PolygonBox[{{2.097057141913445, -5.362222184858401}, {
       2.1874999999999996`, -5.3247595264191645`}, {
       2.0842925895560533`, -5.437499981032941}, {
       2.097057141913445, -5.362222184858401}}], 
      PolygonBox[{{2.230251642536255, -5.437344993353523}, {
       2.0842925895560533`, -5.437499981032941}, {
       2.1874999999999996`, -5.3247595264191645`}, {
       2.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{2.1874999999999996`, -5.3247595264191645`}, {
       2.2651650429449552`, -5.265165042944956}, {
       2.230251642536255, -5.437344993353523}, {
       2.1874999999999996`, -5.3247595264191645`}}], 
      PolygonBox[{{2.404942744332997, -5.404942744332997}, {
       2.230251642536255, -5.437344993353523}, {
       2.2651650429449552`, -5.265165042944956}, {
       2.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, -5.265165042944956}, {
       2.2651650429449552`, -5.265165042944956}, {
       2.404942744332997, -5.404942744332997}, {
       2.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{2.404942744332997, -5.404942744332997}, {
       2.404942744332997, -5.404942744332997}, {
       2.2651650429449552`, -5.265165042944956}, {
       2.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{2.404942744332997, -5.404942744332997}, {
       2.4373449933535234`, -5.230251642536255}, {2.5, -5.5}, {
       2.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{2.5, -5.357662782649368}, {2.5, -5.5}, {
       2.4373449933535234`, -5.230251642536255}, {2.5, -5.357662782649368}}], 
      PolygonBox[{{2.4373449933535234`, -5.230251642536255}, {
       2.437499981032941, -5.084292589556062}, {2.5, -5.357662782649368}, {
       2.4373449933535234`, -5.230251642536255}}], 
      PolygonBox[{{2.5, -5.20590900530174}, {2.5, -5.357662782649368}, {
       2.437499981032941, -5.084292589556062}, {2.5, -5.20590900530174}}], 
      PolygonBox[{{2.437499981032941, -5.084292589556062}, {2.4375, -5.}, {
       2.5, -5.20590900530174}, {2.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{2.5, -5.}, {2.5, -5.20590900530174}, {2.4375, -5.}, {
       2.5, -5.}}], 
      PolygonBox[{{2.4375, -5.}, {2.437499981032941, -4.915707410443939}, {
       2.5, -5.}, {2.4375, -5.}}], 
      PolygonBox[{{2.5, -4.79409099469826}, {2.5, -5.}, {
       2.437499981032941, -4.915707410443939}, {2.5, -4.79409099469826}}], 
      PolygonBox[{{2.437499981032941, -4.915707410443939}, {
       2.4373449933535234`, -4.769748357463745}, {2.5, -4.79409099469826}, {
       2.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{2.5, -4.642337217350632}, {2.5, -4.79409099469826}, {
       2.4373449933535234`, -4.769748357463745}, {2.5, -4.642337217350632}}], 
      PolygonBox[{{2.4373449933535234`, -4.769748357463745}, {
       2.404942744332997, -4.595057255667003}, {2.5, -4.642337217350632}, {
       2.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{2.491446564961186, -4.508553435038814}, {
       2.5, -4.642337217350632}, {2.404942744332997, -4.595057255667003}, {
       2.491446564961186, -4.508553435038814}}], 
      PolygonBox[{{2.404942744332997, -4.595057255667003}, {
       2.2302516425362553`, -4.562655006646477}, {
       2.491446564961186, -4.508553435038814}, {
       2.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{2.357662782649368, -4.5}, {
       2.491446564961186, -4.508553435038814}, {
       2.2302516425362553`, -4.562655006646477}, {2.357662782649368, -4.5}}], 
      PolygonBox[{{2.2302516425362553`, -4.562655006646477}, {
       2.0842925895560604`, -4.562500018967059}, {2.357662782649368, -4.5}, {
       2.2302516425362553`, -4.562655006646477}}], 
      PolygonBox[{{2.2059090053732557`, -4.5}, {2.357662782649368, -4.5}, {
       2.0842925895560604`, -4.562500018967059}, {
       2.2059090053732557`, -4.5}}], 
      PolygonBox[{{2.0842925895560604`, -4.562500018967059}, {
       2.0001055272204877`, -4.5625}, {2.2059090053732557`, -4.5}, {
       2.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{2.07794195802689, -4.5}, {2.2059090053732557`, -4.5}, {
       2.0001055272204877`, -4.5625}, {2.07794195802689, -4.5}}], 
      PolygonBox[{{2.0001055272204877`, -4.5625}, {
       1.915707410443943, -4.562500018967059}, {2.07794195802689, -4.5}, {
       2.0001055272204877`, -4.5625}}], 
      PolygonBox[{{1.7940909946955543`, -4.5}, {2.07794195802689, -4.5}, {
       1.915707410443943, -4.562500018967059}, {1.7940909946955543`, -4.5}}], 
      PolygonBox[{{1.915707410443943, -4.562500018967059}, {
       1.769748357463745, -4.562655006646477}, {1.7940909946955543`, -4.5}, {
       1.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{1.6423372173506339`, -4.5}, {1.7940909946955543`, -4.5}, {
       1.769748357463745, -4.562655006646477}, {1.6423372173506339`, -4.5}}], 
      PolygonBox[{{1.769748357463745, -4.562655006646477}, {
       1.5950572556670028`, -4.595057255667003}, {
       1.6423372173506339`, -4.5}, {1.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{2.5, -4.5}, {1.6423372173506339`, -4.5}, {
       1.5950572556670028`, -4.595057255667003}, {2.5, -4.5}}], 
      PolygonBox[{{1.5950572556670028`, -4.595057255667003}, {
       1.5626550066464766`, -4.769748357463745}, {2.5, -4.5}, {
       1.5950572556670028`, -4.595057255667003}}], 
      PolygonBox[{{1.5, -4.642337217350631}, {2.5, -4.5}, {
       1.5626550066464766`, -4.769748357463745}, {1.5, -4.642337217350631}}], 
      PolygonBox[{{1.5626550066464766`, -4.769748357463745}, {
       1.5625000189670593`, -4.915707410443938}, {1.5, -4.642337217350631}, {
       1.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{1.5, -4.794090994717101}, {1.5, -4.642337217350631}, {
       1.5625000189670593`, -4.915707410443938}, {1.5, -4.794090994717101}}], 
      PolygonBox[{{1.5625000189670593`, -4.915707410443938}, {
       1.5625, -4.999876821937004}, {1.5, -4.794090994717101}, {
       1.5625000189670593`, -4.915707410443938}}], 
      PolygonBox[{{1.5, -4.9193213332412995`}, {1.5, -4.794090994717101}, {
       1.5625, -4.999876821937004}, {1.5, -4.9193213332412995`}}], 
      PolygonBox[{{1.5625, -4.999876821937004}, {
       1.5625000189670593`, -5.084292589556055}, {
       1.5, -4.9193213332412995`}, {1.5625, -4.999876821937004}}], 
      PolygonBox[{{1.5, -5.205909005145278}, {1.5, -4.9193213332412995`}, {
       1.5625000189670593`, -5.084292589556055}, {1.5, -5.205909005145278}}], 
      PolygonBox[{{1.5625000189670593`, -5.084292589556055}, {
       1.5626550066464766`, -5.230251642536254}, {1.5, -5.205909005145278}, {
       1.5625000189670593`, -5.084292589556055}}], 
      PolygonBox[{{1.5, -5.357662782649365}, {1.5, -5.205909005145278}, {
       1.5626550066464766`, -5.230251642536254}, {1.5, -5.357662782649365}}], 
      PolygonBox[{{1.5626550066464766`, -5.230251642536254}, {
       1.5950572556670028`, -5.404942744332997}, {1.5, -5.357662782649365}, {
       1.5626550066464766`, -5.230251642536254}}], 
      PolygonBox[{{1.5, -4.5}, {1.5, -5.357662782649365}, {
       1.5950572556670028`, -5.404942744332997}, {1.5, -4.5}}], 
      PolygonBox[{{1.5950572556670028`, -5.404942744332997}, {
       1.769748357463745, -5.437344993353523}, {1.5, -4.5}, {
       1.5950572556670028`, -5.404942744332997}}], 
      PolygonBox[{{1.5, -5.5}, {1.5, -4.5}, {
       1.769748357463745, -5.437344993353523}, {1.5, -5.5}}], 
      PolygonBox[{{1.769748357463745, -5.437344993353523}, {
       1.9157074104439358`, -5.437499981032941}, {1.5, -5.5}, {
       1.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{1.794090994433172, -5.5}, {1.5, -5.5}, {
       1.9157074104439358`, -5.437499981032941}, {1.794090994433172, -5.5}}], 
      PolygonBox[{{1.9157074104439358`, -5.437499981032941}, {
       2.000134841831043, -5.4375}, {1.794090994433172, -5.5}, {
       1.9157074104439358`, -5.437499981032941}}], 
      PolygonBox[{{2.0823238704010616`, -5.5}, {1.794090994433172, -5.5}, {
       2.000134841831043, -5.4375}, {2.0823238704010616`, -5.5}}], 
      PolygonBox[{{2.000134841831043, -5.4375}, {
       2.0842925895560533`, -5.437499981032941}, {
       2.0823238704010616`, -5.5}, {2.000134841831043, -5.4375}}], 
      PolygonBox[{{2.2059090053603976`, -5.5}, {2.0823238704010616`, -5.5}, {
       2.0842925895560533`, -5.437499981032941}, {
       2.2059090053603976`, -5.5}}], 
      PolygonBox[{{2.0842925895560533`, -5.437499981032941}, {
       2.230251642536255, -5.437344993353523}, {2.2059090053603976`, -5.5}, {
       2.0842925895560533`, -5.437499981032941}}], 
      PolygonBox[{{2.357662782649371, -5.5}, {2.2059090053603976`, -5.5}, {
       2.230251642536255, -5.437344993353523}, {2.357662782649371, -5.5}}], 
      PolygonBox[{{2.230251642536255, -5.437344993353523}, {
       2.404942744332997, -5.404942744332997}, {2.357662782649371, -5.5}, {
       2.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{2.5, -5.5}, {2.357662782649371, -5.5}, {
       2.404942744332997, -5.404942744332997}, {2.5, -5.5}}], 
      PolygonBox[{{2.404942744332997, -5.404942744332997}, {
       2.404942744332997, -5.404942744332997}, {2.5, -5.5}, {
       2.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{2.5, -5.5}, {2.5, -5.5}, {
       2.404942744332997, -5.404942744332997}, {2.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, -4.}, {1.5208333333333333`, -4.}, {
       1.5416666666666667`, -4.}, {1.5625, -4.}, {1.5833333333333333`, -4.}, {
       1.6041666666666665`, -4.}, {1.625, -4.}, {1.625, -4.}, {
       1.6041666666666667`, -4.}, {1.5833333333333333`, -4.}, {1.5625, -4.}, {
       1.5416666666666667`, -4.}, {1.5208333333333335`, -4.}, {1.5, -4.}, {
       1.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, -4.}, {2.3958333333333335`, -4.}, {
       2.4166666666666665`, -4.}, {2.4375, -4.}, {2.4583333333333335`, -4.}, {
       2.4791666666666665`, -4.}, {2.5, -4.}, {2.5, -4.}, {
       2.4791666666666665`, -4.}, {2.4583333333333335`, -4.}, {2.4375, -4.}, {
       2.4166666666666665`, -4.}, {2.3958333333333335`, -4.}, {2.375, -4.}, {
       2.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -4.5}, {2., -4.479166666666667}, {
       2., -4.458333333333333}, {2., -4.4375}, {2., -4.416666666666667}, {
       2., -4.395833333333333}, {2., -4.375}, {2., -4.375}, {
       2., -4.395833333333333}, {2., -4.416666666666667}, {2., -4.4375}, {
       2., -4.458333333333333}, {2., -4.479166666666667}, {2., -4.5}, {
       2., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -3.625}, {2., -3.6041666666666665`}, {
       2., -3.5833333333333335`}, {2., -3.5625}, {2., -3.5416666666666665`}, {
       2., -3.5208333333333335`}, {2., -3.5}, {2., -3.5}, {
       2., -3.5208333333333335`}, {2., -3.5416666666666665`}, {2., -3.5625}, {
       2., -3.5833333333333335`}, {2., -3.6041666666666665`}, {2., -3.625}, {
       2., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, -4.}, {1.75, -4.}, {1.875, -4.}, {2., -4.}, {
       2.125, -4.}, {2.25, -4.}, {2.375, -4.}, {2.375, -4.}, {2.25, -4.}, {
       2.125, -4.}, {2., -4.}, {1.875, -4.}, {1.75, -4.}, {1.625, -4.}, {
       1.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -4.375}, {2., -4.25}, {2., -4.125}, {2., -4.}, {
       2., -3.875}, {2., -3.75}, {2., -3.625}, {2., -3.625}, {2., -3.75}, {
       2., -3.875}, {2., -4.}, {2., -4.125}, {2., -4.25}, {2., -4.375}, {
       2., -4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhBa4MCri+v2XXnK5LBR+q2UlSX/AQP3E63S
M5kg8g18B2a/nX2TT57JIVUoRe3jA94DEHFGhws7zKuepPEe8H8i9PToMQYH
Mb1AR20pqDwDA9R83gPJ5rdMS4r+2aPK/7WH6T+lcsLn0cHf9jDzFxTmfzlx
9pc9zH6dmEVNYSa/7GHug+iHygPdD5NXL+r8lJQsgKr/gMCBk1Dzz347m9PO
L3jgPxj8sZ+h/ORQr4/ggUSo+75mhMe/KhJEdX+D4AE/qP9g8mDt9YwOMP2w
8DkHNR8l/A4gwlcD6j708AcAiDmY8Q==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhCa58DqVSDABOeHggEjnA/VAOeHgeX/2qPq
/2WPqv4HQT7EHl44H2IOH5p6ATR5ATT9gmjqhTD4q1DcJwT131809TD/CaH5
H6afyQFVPQtBPqr7WBxQ3Q9TL4Amzwfnh6GEDyK+AKPjXAs=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, -4.265165042944956}, {
       2.3247595264191645`, -4.1875}, {
       2.404942744332997, -4.404942744332997}, {
       2.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{2.4373449933535234`, -4.230251642536255}, {
       2.404942744332997, -4.404942744332997}, {
       2.3247595264191645`, -4.1875}, {
       2.4373449933535234`, -4.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, -4.1875}, {
       2.3622221848584006`, -4.097057141913445}, {
       2.4373449933535234`, -4.230251642536255}, {
       2.3247595264191645`, -4.1875}}], 
      PolygonBox[{{2.437499981032941, -4.084292589556062}, {
       2.4373449933535234`, -4.230251642536255}, {
       2.3622221848584006`, -4.097057141913445}, {
       2.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{2.3622221848584006`, -4.097057141913445}, {2.375, -4.}, {
       2.437499981032941, -4.084292589556062}, {
       2.3622221848584006`, -4.097057141913445}}], 
      PolygonBox[{{2.4375, -4.}, {2.437499981032941, -4.084292589556062}, {
       2.375, -4.}, {2.4375, -4.}}], 
      PolygonBox[{{2.375, -4.}, {2.3622221848584006`, -3.9029428580865546`}, {
       2.4375, -4.}, {2.375, -4.}}], 
      PolygonBox[{{2.437499981032941, -3.915707410443938}, {2.4375, -4.}, {
       2.3622221848584006`, -3.9029428580865546`}, {
       2.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{2.3622221848584006`, -3.9029428580865546`}, {
       2.3247595264191645`, -3.8125}, {
       2.437499981032941, -3.915707410443938}, {
       2.3622221848584006`, -3.9029428580865546`}}], 
      PolygonBox[{{2.4373449933535234`, -3.769748357463745}, {
       2.437499981032941, -3.915707410443938}, {
       2.3247595264191645`, -3.8125}, {
       2.4373449933535234`, -3.769748357463745}}], 
      PolygonBox[{{2.3247595264191645`, -3.8125}, {
       2.2651650429449552`, -3.7348349570550448`}, {
       2.4373449933535234`, -3.769748357463745}, {
       2.3247595264191645`, -3.8125}}], 
      PolygonBox[{{2.404942744332997, -3.595057255667003}, {
       2.4373449933535234`, -3.769748357463745}, {
       2.2651650429449552`, -3.7348349570550448`}, {
       2.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{2.2651650429449552`, -3.7348349570550448`}, {
       2.1875, -3.6752404735808355`}, {
       2.404942744332997, -3.595057255667003}, {
       2.2651650429449552`, -3.7348349570550448`}}], 
      PolygonBox[{{2.2302516425362553`, -3.5626550066464766`}, {
       2.404942744332997, -3.595057255667003}, {
       2.1875, -3.6752404735808355`}, {
       2.2302516425362553`, -3.5626550066464766`}}], 
      PolygonBox[{{2.1875, -3.6752404735808355`}, {
       2.0970571419134454`, -3.6377778151415994`}, {
       2.2302516425362553`, -3.5626550066464766`}, {
       2.1875, -3.6752404735808355`}}], 
      PolygonBox[{{2.0842925895560604`, -3.562500018967059}, {
       2.2302516425362553`, -3.5626550066464766`}, {
       2.0970571419134454`, -3.6377778151415994`}, {
       2.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{2.0970571419134454`, -3.6377778151415994`}, {2., -3.625}, {
       2.0842925895560604`, -3.562500018967059}, {
       2.0970571419134454`, -3.6377778151415994`}}], 
      PolygonBox[{{2.0001055272204877`, -3.5625}, {
       2.0842925895560604`, -3.562500018967059}, {2., -3.625}, {
       2.0001055272204877`, -3.5625}}], 
      PolygonBox[{{2., -3.625}, {1.9029428580865548`, -3.6377778151415994`}, {
       2.0001055272204877`, -3.5625}, {2., -3.625}}], 
      PolygonBox[{{1.915707410443943, -3.562500018967059}, {
       2.0001055272204877`, -3.5625}, {
       1.9029428580865548`, -3.6377778151415994`}, {
       1.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{1.9029428580865548`, -3.6377778151415994`}, {
       1.8125, -3.6752404735808355`}, {
       1.915707410443943, -3.562500018967059}, {
       1.9029428580865548`, -3.6377778151415994`}}], 
      PolygonBox[{{1.769748357463745, -3.5626550066464766`}, {
       1.915707410443943, -3.562500018967059}, {
       1.8125, -3.6752404735808355`}, {
       1.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{1.8125, -3.6752404735808355`}, {
       1.7348349570550448`, -3.7348349570550448`}, {
       1.769748357463745, -3.5626550066464766`}, {
       1.8125, -3.6752404735808355`}}], 
      PolygonBox[{{1.5950572556670028`, -3.595057255667003}, {
       1.769748357463745, -3.5626550066464766`}, {
       1.7348349570550448`, -3.7348349570550448`}, {
       1.5950572556670028`, -3.595057255667003}}], 
      PolygonBox[{{1.7348349570550448`, -3.7348349570550448`}, {
       1.6752404735808355`, -3.8125}, {
       1.5950572556670028`, -3.595057255667003}, {
       1.7348349570550448`, -3.7348349570550448`}}], 
      PolygonBox[{{1.5626550066464766`, -3.7697483574637447`}, {
       1.5950572556670028`, -3.595057255667003}, {
       1.6752404735808355`, -3.8125}, {
       1.5626550066464766`, -3.7697483574637447`}}], 
      PolygonBox[{{1.6752404735808355`, -3.8125}, {
       1.6377778151415994`, -3.9029428580865546`}, {
       1.5626550066464766`, -3.7697483574637447`}, {
       1.6752404735808355`, -3.8125}}], 
      PolygonBox[{{1.5625000189670593`, -3.9157074104439378`}, {
       1.5626550066464766`, -3.7697483574637447`}, {
       1.6377778151415994`, -3.9029428580865546`}, {
       1.5625000189670593`, -3.9157074104439378`}}], 
      PolygonBox[{{1.6377778151415994`, -3.9029428580865546`}, {1.625, -4.}, {
       1.5625000189670593`, -3.9157074104439378`}, {
       1.6377778151415994`, -3.9029428580865546`}}], 
      PolygonBox[{{1.5625, -3.9998768219370047`}, {
       1.5625000189670593`, -3.9157074104439378`}, {1.625, -4.}, {
       1.5625, -3.9998768219370047`}}], 
      PolygonBox[{{1.625, -4.}, {1.6377778151415994`, -4.097057141913445}, {
       1.5625, -3.9998768219370047`}, {1.625, -4.}}], 
      PolygonBox[{{1.5625000189670593`, -4.084292589556055}, {
       1.5625, -3.9998768219370047`}, {
       1.6377778151415994`, -4.097057141913445}, {
       1.5625000189670593`, -4.084292589556055}}], 
      PolygonBox[{{1.6377778151415994`, -4.097057141913445}, {
       1.6752404735808355`, -4.1875}, {
       1.5625000189670593`, -4.084292589556055}, {
       1.6377778151415994`, -4.097057141913445}}], 
      PolygonBox[{{1.5626550066464766`, -4.230251642536254}, {
       1.5625000189670593`, -4.084292589556055}, {
       1.6752404735808355`, -4.1875}, {
       1.5626550066464766`, -4.230251642536254}}], 
      PolygonBox[{{1.6752404735808355`, -4.1875}, {
       1.7348349570550448`, -4.265165042944956}, {
       1.5626550066464766`, -4.230251642536254}, {
       1.6752404735808355`, -4.1875}}], 
      PolygonBox[{{1.5950572556670028`, -4.404942744332997}, {
       1.5626550066464766`, -4.230251642536254}, {
       1.7348349570550448`, -4.265165042944956}, {
       1.5950572556670028`, -4.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, -4.265165042944956}, {
       1.8124999999999998`, -4.3247595264191645`}, {
       1.5950572556670028`, -4.404942744332997}, {
       1.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{1.769748357463745, -4.437344993353523}, {
       1.5950572556670028`, -4.404942744332997}, {
       1.8124999999999998`, -4.3247595264191645`}, {
       1.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{1.8124999999999998`, -4.3247595264191645`}, {
       1.9029428580865544`, -4.362222184858401}, {
       1.769748357463745, -4.437344993353523}, {
       1.8124999999999998`, -4.3247595264191645`}}], 
      PolygonBox[{{1.9157074104439358`, -4.437499981032941}, {
       1.769748357463745, -4.437344993353523}, {
       1.9029428580865544`, -4.362222184858401}, {
       1.9157074104439358`, -4.437499981032941}}], 
      PolygonBox[{{1.9029428580865544`, -4.362222184858401}, {2., -4.375}, {
       1.9157074104439358`, -4.437499981032941}, {
       1.9029428580865544`, -4.362222184858401}}], 
      PolygonBox[{{2.000134841831043, -4.4375}, {
       1.9157074104439358`, -4.437499981032941}, {2., -4.375}, {
       2.000134841831043, -4.4375}}], 
      PolygonBox[{{2., -4.375}, {2.097057141913445, -4.362222184858401}, {
       2.000134841831043, -4.4375}, {2., -4.375}}], 
      PolygonBox[{{2.0842925895560533`, -4.437499981032941}, {
       2.000134841831043, -4.4375}, {2.097057141913445, -4.362222184858401}, {
       2.0842925895560533`, -4.437499981032941}}], 
      PolygonBox[{{2.097057141913445, -4.362222184858401}, {
       2.1874999999999996`, -4.3247595264191645`}, {
       2.0842925895560533`, -4.437499981032941}, {
       2.097057141913445, -4.362222184858401}}], 
      PolygonBox[{{2.230251642536255, -4.437344993353523}, {
       2.0842925895560533`, -4.437499981032941}, {
       2.1874999999999996`, -4.3247595264191645`}, {
       2.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{2.1874999999999996`, -4.3247595264191645`}, {
       2.2651650429449552`, -4.265165042944956}, {
       2.230251642536255, -4.437344993353523}, {
       2.1874999999999996`, -4.3247595264191645`}}], 
      PolygonBox[{{2.404942744332997, -4.404942744332997}, {
       2.230251642536255, -4.437344993353523}, {
       2.2651650429449552`, -4.265165042944956}, {
       2.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, -4.265165042944956}, {
       2.2651650429449552`, -4.265165042944956}, {
       2.404942744332997, -4.404942744332997}, {
       2.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{2.404942744332997, -4.404942744332997}, {
       2.404942744332997, -4.404942744332997}, {
       2.2651650429449552`, -4.265165042944956}, {
       2.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{2.404942744332997, -4.404942744332997}, {
       2.4373449933535234`, -4.230251642536255}, {2.5, -4.5}, {
       2.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{2.5, -4.357662782649368}, {2.5, -4.5}, {
       2.4373449933535234`, -4.230251642536255}, {2.5, -4.357662782649368}}], 
      PolygonBox[{{2.4373449933535234`, -4.230251642536255}, {
       2.437499981032941, -4.084292589556062}, {2.5, -4.357662782649368}, {
       2.4373449933535234`, -4.230251642536255}}], 
      PolygonBox[{{2.5, -4.20590900530174}, {2.5, -4.357662782649368}, {
       2.437499981032941, -4.084292589556062}, {2.5, -4.20590900530174}}], 
      PolygonBox[{{2.437499981032941, -4.084292589556062}, {2.4375, -4.}, {
       2.5, -4.20590900530174}, {2.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{2.5, -4.}, {2.5, -4.20590900530174}, {2.4375, -4.}, {
       2.5, -4.}}], 
      PolygonBox[{{2.4375, -4.}, {2.437499981032941, -3.915707410443938}, {
       2.5, -4.}, {2.4375, -4.}}], 
      PolygonBox[{{2.5, -3.79409099469826}, {2.5, -4.}, {
       2.437499981032941, -3.915707410443938}, {2.5, -3.79409099469826}}], 
      PolygonBox[{{2.437499981032941, -3.915707410443938}, {
       2.4373449933535234`, -3.769748357463745}, {2.5, -3.79409099469826}, {
       2.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{2.5, -3.6423372173506325`}, {2.5, -3.79409099469826}, {
       2.4373449933535234`, -3.769748357463745}, {
       2.5, -3.6423372173506325`}}], 
      PolygonBox[{{2.4373449933535234`, -3.769748357463745}, {
       2.404942744332997, -3.595057255667003}, {2.5, -3.6423372173506325`}, {
       2.4373449933535234`, -3.769748357463745}}], 
      PolygonBox[{{2.491446564961186, -3.508553435038814}, {
       2.5, -3.6423372173506325`}, {2.404942744332997, -3.595057255667003}, {
       2.491446564961186, -3.508553435038814}}], 
      PolygonBox[{{2.404942744332997, -3.595057255667003}, {
       2.2302516425362553`, -3.5626550066464766`}, {
       2.491446564961186, -3.508553435038814}, {
       2.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{2.357662782649368, -3.5}, {
       2.491446564961186, -3.508553435038814}, {
       2.2302516425362553`, -3.5626550066464766`}, {
       2.357662782649368, -3.5}}], 
      PolygonBox[{{2.2302516425362553`, -3.5626550066464766`}, {
       2.0842925895560604`, -3.562500018967059}, {2.357662782649368, -3.5}, {
       2.2302516425362553`, -3.5626550066464766`}}], 
      PolygonBox[{{2.2059090053732557`, -3.5}, {2.357662782649368, -3.5}, {
       2.0842925895560604`, -3.562500018967059}, {
       2.2059090053732557`, -3.5}}], 
      PolygonBox[{{2.0842925895560604`, -3.562500018967059}, {
       2.0001055272204877`, -3.5625}, {2.2059090053732557`, -3.5}, {
       2.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{2.07794195802689, -3.5}, {2.2059090053732557`, -3.5}, {
       2.0001055272204877`, -3.5625}, {2.07794195802689, -3.5}}], 
      PolygonBox[{{2.0001055272204877`, -3.5625}, {
       1.915707410443943, -3.562500018967059}, {2.07794195802689, -3.5}, {
       2.0001055272204877`, -3.5625}}], 
      PolygonBox[{{1.7940909946955543`, -3.5}, {2.07794195802689, -3.5}, {
       1.915707410443943, -3.562500018967059}, {1.7940909946955543`, -3.5}}], 
      PolygonBox[{{1.915707410443943, -3.562500018967059}, {
       1.769748357463745, -3.5626550066464766`}, {
       1.7940909946955543`, -3.5}, {1.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{1.6423372173506339`, -3.5}, {1.7940909946955543`, -3.5}, {
       1.769748357463745, -3.5626550066464766`}, {
       1.6423372173506339`, -3.5}}], 
      PolygonBox[{{1.769748357463745, -3.5626550066464766`}, {
       1.5950572556670028`, -3.595057255667003}, {
       1.6423372173506339`, -3.5}, {
       1.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{2.5, -3.5}, {1.6423372173506339`, -3.5}, {
       1.5950572556670028`, -3.595057255667003}, {2.5, -3.5}}], 
      PolygonBox[{{1.5950572556670028`, -3.595057255667003}, {
       1.5626550066464766`, -3.7697483574637447`}, {2.5, -3.5}, {
       1.5950572556670028`, -3.595057255667003}}], 
      PolygonBox[{{1.5, -3.642337217350631}, {2.5, -3.5}, {
       1.5626550066464766`, -3.7697483574637447`}, {
       1.5, -3.642337217350631}}], 
      PolygonBox[{{1.5626550066464766`, -3.7697483574637447`}, {
       1.5625000189670593`, -3.9157074104439378`}, {
       1.5, -3.642337217350631}, {
       1.5626550066464766`, -3.7697483574637447`}}], 
      PolygonBox[{{1.5, -3.794090994717101}, {1.5, -3.642337217350631}, {
       1.5625000189670593`, -3.9157074104439378`}, {
       1.5, -3.794090994717101}}], 
      PolygonBox[{{1.5625000189670593`, -3.9157074104439378`}, {
       1.5625, -3.9998768219370047`}, {1.5, -3.794090994717101}, {
       1.5625000189670593`, -3.9157074104439378`}}], 
      PolygonBox[{{1.5, -3.9193213332413}, {1.5, -3.794090994717101}, {
       1.5625, -3.9998768219370047`}, {1.5, -3.9193213332413}}], 
      PolygonBox[{{1.5625, -3.9998768219370047`}, {
       1.5625000189670593`, -4.084292589556055}, {1.5, -3.9193213332413}, {
       1.5625, -3.9998768219370047`}}], 
      PolygonBox[{{1.5, -4.205909005145278}, {1.5, -3.9193213332413}, {
       1.5625000189670593`, -4.084292589556055}, {1.5, -4.205909005145278}}], 
      PolygonBox[{{1.5625000189670593`, -4.084292589556055}, {
       1.5626550066464766`, -4.230251642536254}, {1.5, -4.205909005145278}, {
       1.5625000189670593`, -4.084292589556055}}], 
      PolygonBox[{{1.5, -4.357662782649365}, {1.5, -4.205909005145278}, {
       1.5626550066464766`, -4.230251642536254}, {1.5, -4.357662782649365}}], 
      PolygonBox[{{1.5626550066464766`, -4.230251642536254}, {
       1.5950572556670028`, -4.404942744332997}, {1.5, -4.357662782649365}, {
       1.5626550066464766`, -4.230251642536254}}], 
      PolygonBox[{{1.5, -3.5}, {1.5, -4.357662782649365}, {
       1.5950572556670028`, -4.404942744332997}, {1.5, -3.5}}], 
      PolygonBox[{{1.5950572556670028`, -4.404942744332997}, {
       1.769748357463745, -4.437344993353523}, {1.5, -3.5}, {
       1.5950572556670028`, -4.404942744332997}}], 
      PolygonBox[{{1.5, -4.5}, {1.5, -3.5}, {
       1.769748357463745, -4.437344993353523}, {1.5, -4.5}}], 
      PolygonBox[{{1.769748357463745, -4.437344993353523}, {
       1.9157074104439358`, -4.437499981032941}, {1.5, -4.5}, {
       1.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{1.794090994433172, -4.5}, {1.5, -4.5}, {
       1.9157074104439358`, -4.437499981032941}, {1.794090994433172, -4.5}}], 
      PolygonBox[{{1.9157074104439358`, -4.437499981032941}, {
       2.000134841831043, -4.4375}, {1.794090994433172, -4.5}, {
       1.9157074104439358`, -4.437499981032941}}], 
      PolygonBox[{{2.0823238704010616`, -4.5}, {1.794090994433172, -4.5}, {
       2.000134841831043, -4.4375}, {2.0823238704010616`, -4.5}}], 
      PolygonBox[{{2.000134841831043, -4.4375}, {
       2.0842925895560533`, -4.437499981032941}, {
       2.0823238704010616`, -4.5}, {2.000134841831043, -4.4375}}], 
      PolygonBox[{{2.2059090053603976`, -4.5}, {2.0823238704010616`, -4.5}, {
       2.0842925895560533`, -4.437499981032941}, {
       2.2059090053603976`, -4.5}}], 
      PolygonBox[{{2.0842925895560533`, -4.437499981032941}, {
       2.230251642536255, -4.437344993353523}, {2.2059090053603976`, -4.5}, {
       2.0842925895560533`, -4.437499981032941}}], 
      PolygonBox[{{2.357662782649371, -4.5}, {2.2059090053603976`, -4.5}, {
       2.230251642536255, -4.437344993353523}, {2.357662782649371, -4.5}}], 
      PolygonBox[{{2.230251642536255, -4.437344993353523}, {
       2.404942744332997, -4.404942744332997}, {2.357662782649371, -4.5}, {
       2.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{2.5, -4.5}, {2.357662782649371, -4.5}, {
       2.404942744332997, -4.404942744332997}, {2.5, -4.5}}], 
      PolygonBox[{{2.404942744332997, -4.404942744332997}, {
       2.404942744332997, -4.404942744332997}, {2.5, -4.5}, {
       2.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{2.5, -4.5}, {2.5, -4.5}, {
       2.404942744332997, -4.404942744332997}, {2.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, -3.}, {1.5208333333333333`, -3.}, {
       1.5416666666666667`, -3.}, {1.5625, -3.}, {1.5833333333333333`, -3.}, {
       1.6041666666666665`, -3.}, {1.625, -3.}, {1.625, -3.}, {
       1.6041666666666667`, -3.}, {1.5833333333333333`, -3.}, {1.5625, -3.}, {
       1.5416666666666667`, -3.}, {1.5208333333333335`, -3.}, {1.5, -3.}, {
       1.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, -3.}, {2.3958333333333335`, -3.}, {
       2.4166666666666665`, -3.}, {2.4375, -3.}, {2.4583333333333335`, -3.}, {
       2.4791666666666665`, -3.}, {2.5, -3.}, {2.5, -3.}, {
       2.4791666666666665`, -3.}, {2.4583333333333335`, -3.}, {2.4375, -3.}, {
       2.4166666666666665`, -3.}, {2.3958333333333335`, -3.}, {2.375, -3.}, {
       2.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -3.5}, {2., -3.4791666666666665`}, {
       2., -3.4583333333333335`}, {2., -3.4375}, {2., -3.4166666666666665`}, {
       2., -3.3958333333333335`}, {2., -3.375}, {2., -3.375}, {
       2., -3.3958333333333335`}, {2., -3.4166666666666665`}, {2., -3.4375}, {
       2., -3.4583333333333335`}, {2., -3.4791666666666665`}, {2., -3.5}, {
       2., -3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -2.625}, {2., -2.6041666666666665`}, {
       2., -2.5833333333333335`}, {2., -2.5625}, {2., -2.5416666666666665`}, {
       2., -2.5208333333333335`}, {2., -2.5}, {2., -2.5}, {
       2., -2.5208333333333335`}, {2., -2.5416666666666665`}, {2., -2.5625}, {
       2., -2.5833333333333335`}, {2., -2.6041666666666665`}, {2., -2.625}, {
       2., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, -3.}, {1.75, -3.}, {1.875, -3.}, {2., -3.}, {
       2.125, -3.}, {2.25, -3.}, {2.375, -3.}, {2.375, -3.}, {2.25, -3.}, {
       2.125, -3.}, {2., -3.}, {1.875, -3.}, {1.75, -3.}, {1.625, -3.}, {
       1.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -3.375}, {2., -3.25}, {2., -3.125}, {2., -3.}, {
       2., -2.875}, {2., -2.75}, {2., -2.625}, {2., -2.625}, {2., -2.75}, {
       2., -2.875}, {2., -3.}, {2., -3.125}, {2., -3.25}, {2., -3.375}, {
       2., -3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhCa48Cri+v2XXnK5LBR+q2UlSX7AQP3E63S
M5kg8g1sB2a/nX2TT57JIVUoRe3jA9YDEHFGhws7zKuepLEe8H8i9PToMQYH
Mb1AR20pqDwDA9R81gPJ5rdMS4r+2aPK/7WH6T+lcsLn0cHf9jDzFxTmfzlx
9pc9zH6dmEVNYSa/7GHug+iHygPdD5P3A7uDA00/54GTUPMh/uA68B8M/thD
/Ml1IBHqPkg4cKG5n/uAH9R/MHmw9npGB5h+WPjAzEcNP054+PpD3Yce/gBx
x5l0
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDlD6wOpVIMAE54eCASOcD9UA54eB5f/ao+r/
ZY+q/gdBPsQeVjgfYg4bmnoONPWccD5Y+SouNPU8GPxVKO7jgfrvL5p6mP94
0PwP08/kgKqehSB/NYr7WBxQ3Q9Tz4Gmng3OD0MJH0R8AQDyCFtA
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, -3.2651650429449552`}, {
       2.3247595264191645`, -3.1875}, {
       2.404942744332997, -3.404942744332997}, {
       2.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{2.4373449933535234`, -3.2302516425362553`}, {
       2.404942744332997, -3.404942744332997}, {
       2.3247595264191645`, -3.1875}, {
       2.4373449933535234`, -3.2302516425362553`}}], 
      PolygonBox[{{2.3247595264191645`, -3.1875}, {
       2.3622221848584006`, -3.0970571419134454`}, {
       2.4373449933535234`, -3.2302516425362553`}, {
       2.3247595264191645`, -3.1875}}], 
      PolygonBox[{{2.437499981032941, -3.084292589556062}, {
       2.4373449933535234`, -3.2302516425362553`}, {
       2.3622221848584006`, -3.0970571419134454`}, {
       2.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{2.3622221848584006`, -3.0970571419134454`}, {2.375, -3.}, {
       2.437499981032941, -3.084292589556062}, {
       2.3622221848584006`, -3.0970571419134454`}}], 
      PolygonBox[{{2.4375, -3.}, {2.437499981032941, -3.084292589556062}, {
       2.375, -3.}, {2.4375, -3.}}], 
      PolygonBox[{{2.375, -3.}, {2.3622221848584006`, -2.9029428580865546`}, {
       2.4375, -3.}, {2.375, -3.}}], 
      PolygonBox[{{2.437499981032941, -2.915707410443938}, {2.4375, -3.}, {
       2.3622221848584006`, -2.9029428580865546`}, {
       2.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{2.3622221848584006`, -2.9029428580865546`}, {
       2.3247595264191645`, -2.8125}, {
       2.437499981032941, -2.915707410443938}, {
       2.3622221848584006`, -2.9029428580865546`}}], 
      PolygonBox[{{2.4373449933535234`, -2.769748357463745}, {
       2.437499981032941, -2.915707410443938}, {
       2.3247595264191645`, -2.8125}, {
       2.4373449933535234`, -2.769748357463745}}], 
      PolygonBox[{{2.3247595264191645`, -2.8125}, {
       2.2651650429449552`, -2.7348349570550448`}, {
       2.4373449933535234`, -2.769748357463745}, {
       2.3247595264191645`, -2.8125}}], 
      PolygonBox[{{2.404942744332997, -2.595057255667003}, {
       2.4373449933535234`, -2.769748357463745}, {
       2.2651650429449552`, -2.7348349570550448`}, {
       2.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{2.2651650429449552`, -2.7348349570550448`}, {
       2.1875, -2.6752404735808355`}, {
       2.404942744332997, -2.595057255667003}, {
       2.2651650429449552`, -2.7348349570550448`}}], 
      PolygonBox[{{2.2302516425362553`, -2.5626550066464766`}, {
       2.404942744332997, -2.595057255667003}, {
       2.1875, -2.6752404735808355`}, {
       2.2302516425362553`, -2.5626550066464766`}}], 
      PolygonBox[{{2.1875, -2.6752404735808355`}, {
       2.0970571419134454`, -2.6377778151415994`}, {
       2.2302516425362553`, -2.5626550066464766`}, {
       2.1875, -2.6752404735808355`}}], 
      PolygonBox[{{2.0842925895560604`, -2.562500018967059}, {
       2.2302516425362553`, -2.5626550066464766`}, {
       2.0970571419134454`, -2.6377778151415994`}, {
       2.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{2.0970571419134454`, -2.6377778151415994`}, {2., -2.625}, {
       2.0842925895560604`, -2.562500018967059}, {
       2.0970571419134454`, -2.6377778151415994`}}], 
      PolygonBox[{{2.0001055272204877`, -2.5625}, {
       2.0842925895560604`, -2.562500018967059}, {2., -2.625}, {
       2.0001055272204877`, -2.5625}}], 
      PolygonBox[{{2., -2.625}, {1.9029428580865548`, -2.6377778151415994`}, {
       2.0001055272204877`, -2.5625}, {2., -2.625}}], 
      PolygonBox[{{1.915707410443943, -2.562500018967059}, {
       2.0001055272204877`, -2.5625}, {
       1.9029428580865548`, -2.6377778151415994`}, {
       1.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{1.9029428580865548`, -2.6377778151415994`}, {
       1.8125, -2.6752404735808355`}, {
       1.915707410443943, -2.562500018967059}, {
       1.9029428580865548`, -2.6377778151415994`}}], 
      PolygonBox[{{1.769748357463745, -2.5626550066464766`}, {
       1.915707410443943, -2.562500018967059}, {
       1.8125, -2.6752404735808355`}, {
       1.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{1.8125, -2.6752404735808355`}, {
       1.7348349570550448`, -2.7348349570550448`}, {
       1.769748357463745, -2.5626550066464766`}, {
       1.8125, -2.6752404735808355`}}], 
      PolygonBox[{{1.5950572556670028`, -2.595057255667003}, {
       1.769748357463745, -2.5626550066464766`}, {
       1.7348349570550448`, -2.7348349570550448`}, {
       1.5950572556670028`, -2.595057255667003}}], 
      PolygonBox[{{1.7348349570550448`, -2.7348349570550448`}, {
       1.6752404735808355`, -2.8125}, {
       1.5950572556670028`, -2.595057255667003}, {
       1.7348349570550448`, -2.7348349570550448`}}], 
      PolygonBox[{{1.5626550066464766`, -2.7697483574637447`}, {
       1.5950572556670028`, -2.595057255667003}, {
       1.6752404735808355`, -2.8125}, {
       1.5626550066464766`, -2.7697483574637447`}}], 
      PolygonBox[{{1.6752404735808355`, -2.8125}, {
       1.6377778151415994`, -2.9029428580865546`}, {
       1.5626550066464766`, -2.7697483574637447`}, {
       1.6752404735808355`, -2.8125}}], 
      PolygonBox[{{1.5625000189670593`, -2.9157074104439378`}, {
       1.5626550066464766`, -2.7697483574637447`}, {
       1.6377778151415994`, -2.9029428580865546`}, {
       1.5625000189670593`, -2.9157074104439378`}}], 
      PolygonBox[{{1.6377778151415994`, -2.9029428580865546`}, {1.625, -3.}, {
       1.5625000189670593`, -2.9157074104439378`}, {
       1.6377778151415994`, -2.9029428580865546`}}], 
      PolygonBox[{{1.5625, -2.9998768219370047`}, {
       1.5625000189670593`, -2.9157074104439378`}, {1.625, -3.}, {
       1.5625, -2.9998768219370047`}}], 
      PolygonBox[{{1.625, -3.}, {1.6377778151415994`, -3.097057141913445}, {
       1.5625, -2.9998768219370047`}, {1.625, -3.}}], 
      PolygonBox[{{1.5625000189670593`, -3.084292589556055}, {
       1.5625, -2.9998768219370047`}, {
       1.6377778151415994`, -3.097057141913445}, {
       1.5625000189670593`, -3.084292589556055}}], 
      PolygonBox[{{1.6377778151415994`, -3.097057141913445}, {
       1.6752404735808355`, -3.1875}, {
       1.5625000189670593`, -3.084292589556055}, {
       1.6377778151415994`, -3.097057141913445}}], 
      PolygonBox[{{1.5626550066464766`, -3.230251642536255}, {
       1.5625000189670593`, -3.084292589556055}, {
       1.6752404735808355`, -3.1875}, {
       1.5626550066464766`, -3.230251642536255}}], 
      PolygonBox[{{1.6752404735808355`, -3.1875}, {
       1.7348349570550448`, -3.2651650429449552`}, {
       1.5626550066464766`, -3.230251642536255}, {
       1.6752404735808355`, -3.1875}}], 
      PolygonBox[{{1.5950572556670028`, -3.404942744332997}, {
       1.5626550066464766`, -3.230251642536255}, {
       1.7348349570550448`, -3.2651650429449552`}, {
       1.5950572556670028`, -3.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, -3.2651650429449552`}, {
       1.8124999999999998`, -3.3247595264191645`}, {
       1.5950572556670028`, -3.404942744332997}, {
       1.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{1.769748357463745, -3.4373449933535234`}, {
       1.5950572556670028`, -3.404942744332997}, {
       1.8124999999999998`, -3.3247595264191645`}, {
       1.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{1.8124999999999998`, -3.3247595264191645`}, {
       1.9029428580865544`, -3.3622221848584006`}, {
       1.769748357463745, -3.4373449933535234`}, {
       1.8124999999999998`, -3.3247595264191645`}}], 
      PolygonBox[{{1.9157074104439358`, -3.437499981032941}, {
       1.769748357463745, -3.4373449933535234`}, {
       1.9029428580865544`, -3.3622221848584006`}, {
       1.9157074104439358`, -3.437499981032941}}], 
      PolygonBox[{{1.9029428580865544`, -3.3622221848584006`}, {2., -3.375}, {
       1.9157074104439358`, -3.437499981032941}, {
       1.9029428580865544`, -3.3622221848584006`}}], 
      PolygonBox[{{2.000134841831043, -3.4375}, {
       1.9157074104439358`, -3.437499981032941}, {2., -3.375}, {
       2.000134841831043, -3.4375}}], 
      PolygonBox[{{2., -3.375}, {2.097057141913445, -3.3622221848584006`}, {
       2.000134841831043, -3.4375}, {2., -3.375}}], 
      PolygonBox[{{2.0842925895560533`, -3.437499981032941}, {
       2.000134841831043, -3.4375}, {
       2.097057141913445, -3.3622221848584006`}, {
       2.0842925895560533`, -3.437499981032941}}], 
      PolygonBox[{{2.097057141913445, -3.3622221848584006`}, {
       2.1874999999999996`, -3.3247595264191645`}, {
       2.0842925895560533`, -3.437499981032941}, {
       2.097057141913445, -3.3622221848584006`}}], 
      PolygonBox[{{2.230251642536255, -3.4373449933535234`}, {
       2.0842925895560533`, -3.437499981032941}, {
       2.1874999999999996`, -3.3247595264191645`}, {
       2.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{2.1874999999999996`, -3.3247595264191645`}, {
       2.2651650429449552`, -3.2651650429449552`}, {
       2.230251642536255, -3.4373449933535234`}, {
       2.1874999999999996`, -3.3247595264191645`}}], 
      PolygonBox[{{2.404942744332997, -3.404942744332997}, {
       2.230251642536255, -3.4373449933535234`}, {
       2.2651650429449552`, -3.2651650429449552`}, {
       2.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, -3.2651650429449552`}, {
       2.2651650429449552`, -3.2651650429449552`}, {
       2.404942744332997, -3.404942744332997}, {
       2.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{2.404942744332997, -3.404942744332997}, {
       2.404942744332997, -3.404942744332997}, {
       2.2651650429449552`, -3.2651650429449552`}, {
       2.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{2.404942744332997, -3.404942744332997}, {
       2.4373449933535234`, -3.2302516425362553`}, {2.5, -3.5}, {
       2.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{2.5, -3.357662782649368}, {2.5, -3.5}, {
       2.4373449933535234`, -3.2302516425362553`}, {
       2.5, -3.357662782649368}}], 
      PolygonBox[{{2.4373449933535234`, -3.2302516425362553`}, {
       2.437499981032941, -3.084292589556062}, {2.5, -3.357662782649368}, {
       2.4373449933535234`, -3.2302516425362553`}}], 
      PolygonBox[{{2.5, -3.20590900530174}, {2.5, -3.357662782649368}, {
       2.437499981032941, -3.084292589556062}, {2.5, -3.20590900530174}}], 
      PolygonBox[{{2.437499981032941, -3.084292589556062}, {2.4375, -3.}, {
       2.5, -3.20590900530174}, {2.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{2.5, -3.}, {2.5, -3.20590900530174}, {2.4375, -3.}, {
       2.5, -3.}}], 
      PolygonBox[{{2.4375, -3.}, {2.437499981032941, -2.915707410443938}, {
       2.5, -3.}, {2.4375, -3.}}], 
      PolygonBox[{{2.5, -2.79409099469826}, {2.5, -3.}, {
       2.437499981032941, -2.915707410443938}, {2.5, -2.79409099469826}}], 
      PolygonBox[{{2.437499981032941, -2.915707410443938}, {
       2.4373449933535234`, -2.769748357463745}, {2.5, -2.79409099469826}, {
       2.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{2.5, -2.6423372173506325`}, {2.5, -2.79409099469826}, {
       2.4373449933535234`, -2.769748357463745}, {
       2.5, -2.6423372173506325`}}], 
      PolygonBox[{{2.4373449933535234`, -2.769748357463745}, {
       2.404942744332997, -2.595057255667003}, {2.5, -2.6423372173506325`}, {
       2.4373449933535234`, -2.769748357463745}}], 
      PolygonBox[{{2.491446564961186, -2.508553435038814}, {
       2.5, -2.6423372173506325`}, {2.404942744332997, -2.595057255667003}, {
       2.491446564961186, -2.508553435038814}}], 
      PolygonBox[{{2.404942744332997, -2.595057255667003}, {
       2.2302516425362553`, -2.5626550066464766`}, {
       2.491446564961186, -2.508553435038814}, {
       2.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{2.357662782649368, -2.5}, {
       2.491446564961186, -2.508553435038814}, {
       2.2302516425362553`, -2.5626550066464766`}, {
       2.357662782649368, -2.5}}], 
      PolygonBox[{{2.2302516425362553`, -2.5626550066464766`}, {
       2.0842925895560604`, -2.562500018967059}, {2.357662782649368, -2.5}, {
       2.2302516425362553`, -2.5626550066464766`}}], 
      PolygonBox[{{2.2059090053732557`, -2.5}, {2.357662782649368, -2.5}, {
       2.0842925895560604`, -2.562500018967059}, {
       2.2059090053732557`, -2.5}}], 
      PolygonBox[{{2.0842925895560604`, -2.562500018967059}, {
       2.0001055272204877`, -2.5625}, {2.2059090053732557`, -2.5}, {
       2.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{2.07794195802689, -2.5}, {2.2059090053732557`, -2.5}, {
       2.0001055272204877`, -2.5625}, {2.07794195802689, -2.5}}], 
      PolygonBox[{{2.0001055272204877`, -2.5625}, {
       1.915707410443943, -2.562500018967059}, {2.07794195802689, -2.5}, {
       2.0001055272204877`, -2.5625}}], 
      PolygonBox[{{1.7940909946955543`, -2.5}, {2.07794195802689, -2.5}, {
       1.915707410443943, -2.562500018967059}, {1.7940909946955543`, -2.5}}], 
      PolygonBox[{{1.915707410443943, -2.562500018967059}, {
       1.769748357463745, -2.5626550066464766`}, {
       1.7940909946955543`, -2.5}, {1.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{1.6423372173506339`, -2.5}, {1.7940909946955543`, -2.5}, {
       1.769748357463745, -2.5626550066464766`}, {
       1.6423372173506339`, -2.5}}], 
      PolygonBox[{{1.769748357463745, -2.5626550066464766`}, {
       1.5950572556670028`, -2.595057255667003}, {
       1.6423372173506339`, -2.5}, {
       1.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{2.5, -2.5}, {1.6423372173506339`, -2.5}, {
       1.5950572556670028`, -2.595057255667003}, {2.5, -2.5}}], 
      PolygonBox[{{1.5950572556670028`, -2.595057255667003}, {
       1.5626550066464766`, -2.7697483574637447`}, {2.5, -2.5}, {
       1.5950572556670028`, -2.595057255667003}}], 
      PolygonBox[{{1.5, -2.642337217350631}, {2.5, -2.5}, {
       1.5626550066464766`, -2.7697483574637447`}, {
       1.5, -2.642337217350631}}], 
      PolygonBox[{{1.5626550066464766`, -2.7697483574637447`}, {
       1.5625000189670593`, -2.9157074104439378`}, {
       1.5, -2.642337217350631}, {
       1.5626550066464766`, -2.7697483574637447`}}], 
      PolygonBox[{{1.5, -2.794090994717101}, {1.5, -2.642337217350631}, {
       1.5625000189670593`, -2.9157074104439378`}, {
       1.5, -2.794090994717101}}], 
      PolygonBox[{{1.5625000189670593`, -2.9157074104439378`}, {
       1.5625, -2.9998768219370047`}, {1.5, -2.794090994717101}, {
       1.5625000189670593`, -2.9157074104439378`}}], 
      PolygonBox[{{1.5, -2.9193213332413}, {1.5, -2.794090994717101}, {
       1.5625, -2.9998768219370047`}, {1.5, -2.9193213332413}}], 
      PolygonBox[{{1.5625, -2.9998768219370047`}, {
       1.5625000189670593`, -3.084292589556055}, {1.5, -2.9193213332413}, {
       1.5625, -2.9998768219370047`}}], 
      PolygonBox[{{1.5, -3.2059090051452785`}, {1.5, -2.9193213332413}, {
       1.5625000189670593`, -3.084292589556055}, {
       1.5, -3.2059090051452785`}}], 
      PolygonBox[{{1.5625000189670593`, -3.084292589556055}, {
       1.5626550066464766`, -3.230251642536255}, {
       1.5, -3.2059090051452785`}, {
       1.5625000189670593`, -3.084292589556055}}], 
      PolygonBox[{{1.5, -3.3576627826493652`}, {1.5, -3.2059090051452785`}, {
       1.5626550066464766`, -3.230251642536255}, {
       1.5, -3.3576627826493652`}}], 
      PolygonBox[{{1.5626550066464766`, -3.230251642536255}, {
       1.5950572556670028`, -3.404942744332997}, {
       1.5, -3.3576627826493652`}, {
       1.5626550066464766`, -3.230251642536255}}], 
      PolygonBox[{{1.5, -2.5}, {1.5, -3.3576627826493652`}, {
       1.5950572556670028`, -3.404942744332997}, {1.5, -2.5}}], 
      PolygonBox[{{1.5950572556670028`, -3.404942744332997}, {
       1.769748357463745, -3.4373449933535234`}, {1.5, -2.5}, {
       1.5950572556670028`, -3.404942744332997}}], 
      PolygonBox[{{1.5, -3.5}, {1.5, -2.5}, {
       1.769748357463745, -3.4373449933535234`}, {1.5, -3.5}}], 
      PolygonBox[{{1.769748357463745, -3.4373449933535234`}, {
       1.9157074104439358`, -3.437499981032941}, {1.5, -3.5}, {
       1.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{1.794090994433172, -3.5}, {1.5, -3.5}, {
       1.9157074104439358`, -3.437499981032941}, {1.794090994433172, -3.5}}], 
      PolygonBox[{{1.9157074104439358`, -3.437499981032941}, {
       2.000134841831043, -3.4375}, {1.794090994433172, -3.5}, {
       1.9157074104439358`, -3.437499981032941}}], 
      PolygonBox[{{2.0823238704010616`, -3.5}, {1.794090994433172, -3.5}, {
       2.000134841831043, -3.4375}, {2.0823238704010616`, -3.5}}], 
      PolygonBox[{{2.000134841831043, -3.4375}, {
       2.0842925895560533`, -3.437499981032941}, {
       2.0823238704010616`, -3.5}, {2.000134841831043, -3.4375}}], 
      PolygonBox[{{2.2059090053603976`, -3.5}, {2.0823238704010616`, -3.5}, {
       2.0842925895560533`, -3.437499981032941}, {
       2.2059090053603976`, -3.5}}], 
      PolygonBox[{{2.0842925895560533`, -3.437499981032941}, {
       2.230251642536255, -3.4373449933535234`}, {
       2.2059090053603976`, -3.5}, {
       2.0842925895560533`, -3.437499981032941}}], 
      PolygonBox[{{2.357662782649371, -3.5}, {2.2059090053603976`, -3.5}, {
       2.230251642536255, -3.4373449933535234`}, {2.357662782649371, -3.5}}], 
      PolygonBox[{{2.230251642536255, -3.4373449933535234`}, {
       2.404942744332997, -3.404942744332997}, {2.357662782649371, -3.5}, {
       2.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{2.5, -3.5}, {2.357662782649371, -3.5}, {
       2.404942744332997, -3.404942744332997}, {2.5, -3.5}}], 
      PolygonBox[{{2.404942744332997, -3.404942744332997}, {
       2.404942744332997, -3.404942744332997}, {2.5, -3.5}, {
       2.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{2.5, -3.5}, {2.5, -3.5}, {
       2.404942744332997, -3.404942744332997}, {2.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, -2.}, {1.5208333333333333`, -2.}, {
       1.5416666666666667`, -2.}, {1.5625, -2.}, {1.5833333333333333`, -2.}, {
       1.6041666666666665`, -2.}, {1.625, -2.}, {1.625, -2.}, {
       1.6041666666666667`, -2.}, {1.5833333333333333`, -2.}, {1.5625, -2.}, {
       1.5416666666666667`, -2.}, {1.5208333333333335`, -2.}, {1.5, -2.}, {
       1.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, -2.}, {2.3958333333333335`, -2.}, {
       2.4166666666666665`, -2.}, {2.4375, -2.}, {2.4583333333333335`, -2.}, {
       2.4791666666666665`, -2.}, {2.5, -2.}, {2.5, -2.}, {
       2.4791666666666665`, -2.}, {2.4583333333333335`, -2.}, {2.4375, -2.}, {
       2.4166666666666665`, -2.}, {2.3958333333333335`, -2.}, {2.375, -2.}, {
       2.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -2.5}, {2., -2.4791666666666665`}, {
       2., -2.4583333333333335`}, {2., -2.4375}, {2., -2.4166666666666665`}, {
       2., -2.3958333333333335`}, {2., -2.375}, {2., -2.375}, {
       2., -2.3958333333333335`}, {2., -2.4166666666666665`}, {2., -2.4375}, {
       2., -2.4583333333333335`}, {2., -2.4791666666666665`}, {2., -2.5}, {
       2., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -1.625}, {2., -1.6041666666666667`}, {
       2., -1.5833333333333333`}, {2., -1.5625}, {2., -1.5416666666666667`}, {
       2., -1.5208333333333335`}, {2., -1.5}, {2., -1.5}, {
       2., -1.5208333333333333`}, {2., -1.5416666666666667`}, {2., -1.5625}, {
       2., -1.5833333333333333`}, {2., -1.6041666666666665`}, {2., -1.625}, {
       2., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, -2.}, {1.75, -2.}, {1.875, -2.}, {2., -2.}, {
       2.125, -2.}, {2.25, -2.}, {2.375, -2.}, {2.375, -2.}, {2.25, -2.}, {
       2.125, -2.}, {2., -2.}, {1.875, -2.}, {1.75, -2.}, {1.625, -2.}, {
       1.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -2.375}, {2., -2.25}, {2., -2.125}, {2., -2.}, {
       2., -1.875}, {2., -1.75}, {2., -1.625}, {2., -1.625}, {2., -1.75}, {
       2., -1.875}, {2., -2.}, {2., -2.125}, {2., -2.25}, {2., -2.375}, {
       2., -2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDlDGgVcX1+278pTJIcn8lmlJ0b/9Bu4nWqVn
MkHl/+6f/Xb2TT55JodTKid8Hh38vR8s3MDosKAw/8uJs7/2+z8Renr0GIOD
TsyipjCTX/uh5kL1/9qfDDHXHlX+rz1MP9Rce5j5UHF7mP1QffYw90HNtYe5
HybvB3HHART9DYwHTkLNh/rjwH8w+GMP9eeBRKj7oOFwANX9zAeg5jrA5MHa
6xkdYPph4QMzHyX8gPbDwhcaTgfQwx8ASSWoAg==
      "]], LineBox[CompressedData["
1:eJyFj9EJgDAMRNOSMfxxEjuDoAMIfrtXO0Q7VikIamsCpx89KOGRO3oZt2Pe
LREN93tmE7s2cwz+kVVeqozyG1Be6/6cMF8m9Ocu+5ZTbv+eHz8l3JuEeZvQ
zz/20I/TAv3FL/fJ3jjMW4d+7nKAfuywv/hJeYX7JV8i+nO8AEpNZyY=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, -2.2651650429449552`}, {
       2.3247595264191645`, -2.1875}, {
       2.404942744332997, -2.404942744332997}, {
       2.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{2.4373449933535234`, -2.2302516425362553`}, {
       2.404942744332997, -2.404942744332997}, {
       2.3247595264191645`, -2.1875}, {
       2.4373449933535234`, -2.2302516425362553`}}], 
      PolygonBox[{{2.3247595264191645`, -2.1875}, {
       2.3622221848584006`, -2.0970571419134454`}, {
       2.4373449933535234`, -2.2302516425362553`}, {
       2.3247595264191645`, -2.1875}}], 
      PolygonBox[{{2.437499981032941, -2.084292589556062}, {
       2.4373449933535234`, -2.2302516425362553`}, {
       2.3622221848584006`, -2.0970571419134454`}, {
       2.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{2.3622221848584006`, -2.0970571419134454`}, {2.375, -2.}, {
       2.437499981032941, -2.084292589556062}, {
       2.3622221848584006`, -2.0970571419134454`}}], 
      PolygonBox[{{2.4375, -2.}, {2.437499981032941, -2.084292589556062}, {
       2.375, -2.}, {2.4375, -2.}}], 
      PolygonBox[{{2.375, -2.}, {2.3622221848584006`, -1.9029428580865548`}, {
       2.4375, -2.}, {2.375, -2.}}], 
      PolygonBox[{{2.437499981032941, -1.9157074104439382`}, {2.4375, -2.}, {
       2.3622221848584006`, -1.9029428580865548`}, {
       2.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{2.3622221848584006`, -1.9029428580865548`}, {
       2.3247595264191645`, -1.8125}, {
       2.437499981032941, -1.9157074104439382`}, {
       2.3622221848584006`, -1.9029428580865548`}}], 
      PolygonBox[{{2.4373449933535234`, -1.769748357463745}, {
       2.437499981032941, -1.9157074104439382`}, {
       2.3247595264191645`, -1.8125}, {
       2.4373449933535234`, -1.769748357463745}}], 
      PolygonBox[{{2.3247595264191645`, -1.8125}, {
       2.2651650429449552`, -1.7348349570550448`}, {
       2.4373449933535234`, -1.769748357463745}, {
       2.3247595264191645`, -1.8125}}], 
      PolygonBox[{{2.404942744332997, -1.5950572556670028`}, {
       2.4373449933535234`, -1.769748357463745}, {
       2.2651650429449552`, -1.7348349570550448`}, {
       2.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{2.2651650429449552`, -1.7348349570550448`}, {
       2.1875, -1.6752404735808355`}, {
       2.404942744332997, -1.5950572556670028`}, {
       2.2651650429449552`, -1.7348349570550448`}}], 
      PolygonBox[{{2.2302516425362553`, -1.5626550066464766`}, {
       2.404942744332997, -1.5950572556670028`}, {
       2.1875, -1.6752404735808355`}, {
       2.2302516425362553`, -1.5626550066464766`}}], 
      PolygonBox[{{2.1875, -1.6752404735808355`}, {
       2.0970571419134454`, -1.6377778151415994`}, {
       2.2302516425362553`, -1.5626550066464766`}, {
       2.1875, -1.6752404735808355`}}], 
      PolygonBox[{{2.0842925895560604`, -1.5625000189670593`}, {
       2.2302516425362553`, -1.5626550066464766`}, {
       2.0970571419134454`, -1.6377778151415994`}, {
       2.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{2.0970571419134454`, -1.6377778151415994`}, {2., -1.625}, {
       2.0842925895560604`, -1.5625000189670593`}, {
       2.0970571419134454`, -1.6377778151415994`}}], 
      PolygonBox[{{2.0001055272204877`, -1.5625}, {
       2.0842925895560604`, -1.5625000189670593`}, {2., -1.625}, {
       2.0001055272204877`, -1.5625}}], 
      PolygonBox[{{2., -1.625}, {1.9029428580865548`, -1.6377778151415994`}, {
       2.0001055272204877`, -1.5625}, {2., -1.625}}], 
      PolygonBox[{{1.915707410443943, -1.5625000189670593`}, {
       2.0001055272204877`, -1.5625}, {
       1.9029428580865548`, -1.6377778151415994`}, {
       1.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{1.9029428580865548`, -1.6377778151415994`}, {
       1.8125, -1.6752404735808355`}, {
       1.915707410443943, -1.5625000189670593`}, {
       1.9029428580865548`, -1.6377778151415994`}}], 
      PolygonBox[{{1.769748357463745, -1.5626550066464766`}, {
       1.915707410443943, -1.5625000189670593`}, {
       1.8125, -1.6752404735808355`}, {
       1.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{1.8125, -1.6752404735808355`}, {
       1.7348349570550448`, -1.7348349570550448`}, {
       1.769748357463745, -1.5626550066464766`}, {
       1.8125, -1.6752404735808355`}}], 
      PolygonBox[{{1.5950572556670028`, -1.5950572556670028`}, {
       1.769748357463745, -1.5626550066464766`}, {
       1.7348349570550448`, -1.7348349570550448`}, {
       1.5950572556670028`, -1.5950572556670028`}}], 
      PolygonBox[{{1.7348349570550448`, -1.7348349570550448`}, {
       1.6752404735808355`, -1.8125}, {
       1.5950572556670028`, -1.5950572556670028`}, {
       1.7348349570550448`, -1.7348349570550448`}}], 
      PolygonBox[{{1.5626550066464766`, -1.7697483574637447`}, {
       1.5950572556670028`, -1.5950572556670028`}, {
       1.6752404735808355`, -1.8125}, {
       1.5626550066464766`, -1.7697483574637447`}}], 
      PolygonBox[{{1.6752404735808355`, -1.8125}, {
       1.6377778151415994`, -1.9029428580865546`}, {
       1.5626550066464766`, -1.7697483574637447`}, {
       1.6752404735808355`, -1.8125}}], 
      PolygonBox[{{1.5625000189670593`, -1.9157074104439376`}, {
       1.5626550066464766`, -1.7697483574637447`}, {
       1.6377778151415994`, -1.9029428580865546`}, {
       1.5625000189670593`, -1.9157074104439376`}}], 
      PolygonBox[{{1.6377778151415994`, -1.9029428580865546`}, {
       1.625, -1.9999999999999998`}, {
       1.5625000189670593`, -1.9157074104439376`}, {
       1.6377778151415994`, -1.9029428580865546`}}], 
      PolygonBox[{{1.5625, -1.9998768219370047`}, {
       1.5625000189670593`, -1.9157074104439376`}, {
       1.625, -1.9999999999999998`}, {1.5625, -1.9998768219370047`}}], 
      PolygonBox[{{1.625, -1.9999999999999998`}, {
       1.6377778151415994`, -2.097057141913445}, {
       1.5625, -1.9998768219370047`}, {1.625, -1.9999999999999998`}}], 
      PolygonBox[{{1.5625000189670593`, -2.084292589556055}, {
       1.5625, -1.9998768219370047`}, {
       1.6377778151415994`, -2.097057141913445}, {
       1.5625000189670593`, -2.084292589556055}}], 
      PolygonBox[{{1.6377778151415994`, -2.097057141913445}, {
       1.6752404735808355`, -2.1875}, {
       1.5625000189670593`, -2.084292589556055}, {
       1.6377778151415994`, -2.097057141913445}}], 
      PolygonBox[{{1.5626550066464766`, -2.230251642536255}, {
       1.5625000189670593`, -2.084292589556055}, {
       1.6752404735808355`, -2.1875}, {
       1.5626550066464766`, -2.230251642536255}}], 
      PolygonBox[{{1.6752404735808355`, -2.1875}, {
       1.7348349570550448`, -2.2651650429449552`}, {
       1.5626550066464766`, -2.230251642536255}, {
       1.6752404735808355`, -2.1875}}], 
      PolygonBox[{{1.5950572556670028`, -2.404942744332997}, {
       1.5626550066464766`, -2.230251642536255}, {
       1.7348349570550448`, -2.2651650429449552`}, {
       1.5950572556670028`, -2.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, -2.2651650429449552`}, {
       1.8124999999999998`, -2.3247595264191645`}, {
       1.5950572556670028`, -2.404942744332997}, {
       1.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{1.769748357463745, -2.4373449933535234`}, {
       1.5950572556670028`, -2.404942744332997}, {
       1.8124999999999998`, -2.3247595264191645`}, {
       1.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{1.8124999999999998`, -2.3247595264191645`}, {
       1.9029428580865544`, -2.3622221848584006`}, {
       1.769748357463745, -2.4373449933535234`}, {
       1.8124999999999998`, -2.3247595264191645`}}], 
      PolygonBox[{{1.9157074104439358`, -2.437499981032941}, {
       1.769748357463745, -2.4373449933535234`}, {
       1.9029428580865544`, -2.3622221848584006`}, {
       1.9157074104439358`, -2.437499981032941}}], 
      PolygonBox[{{1.9029428580865544`, -2.3622221848584006`}, {2., -2.375}, {
       1.9157074104439358`, -2.437499981032941}, {
       1.9029428580865544`, -2.3622221848584006`}}], 
      PolygonBox[{{2.000134841831043, -2.4375}, {
       1.9157074104439358`, -2.437499981032941}, {2., -2.375}, {
       2.000134841831043, -2.4375}}], 
      PolygonBox[{{2., -2.375}, {2.097057141913445, -2.3622221848584006`}, {
       2.000134841831043, -2.4375}, {2., -2.375}}], 
      PolygonBox[{{2.0842925895560533`, -2.437499981032941}, {
       2.000134841831043, -2.4375}, {
       2.097057141913445, -2.3622221848584006`}, {
       2.0842925895560533`, -2.437499981032941}}], 
      PolygonBox[{{2.097057141913445, -2.3622221848584006`}, {
       2.1874999999999996`, -2.3247595264191645`}, {
       2.0842925895560533`, -2.437499981032941}, {
       2.097057141913445, -2.3622221848584006`}}], 
      PolygonBox[{{2.230251642536255, -2.4373449933535234`}, {
       2.0842925895560533`, -2.437499981032941}, {
       2.1874999999999996`, -2.3247595264191645`}, {
       2.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{2.1874999999999996`, -2.3247595264191645`}, {
       2.2651650429449552`, -2.2651650429449552`}, {
       2.230251642536255, -2.4373449933535234`}, {
       2.1874999999999996`, -2.3247595264191645`}}], 
      PolygonBox[{{2.404942744332997, -2.404942744332997}, {
       2.230251642536255, -2.4373449933535234`}, {
       2.2651650429449552`, -2.2651650429449552`}, {
       2.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, -2.2651650429449552`}, {
       2.2651650429449552`, -2.2651650429449552`}, {
       2.404942744332997, -2.404942744332997}, {
       2.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{2.404942744332997, -2.404942744332997}, {
       2.404942744332997, -2.404942744332997}, {
       2.2651650429449552`, -2.2651650429449552`}, {
       2.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{2.404942744332997, -2.404942744332997}, {
       2.4373449933535234`, -2.2302516425362553`}, {2.5, -2.5}, {
       2.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{2.5, -2.357662782649368}, {2.5, -2.5}, {
       2.4373449933535234`, -2.2302516425362553`}, {
       2.5, -2.357662782649368}}], 
      PolygonBox[{{2.4373449933535234`, -2.2302516425362553`}, {
       2.437499981032941, -2.084292589556062}, {2.5, -2.357662782649368}, {
       2.4373449933535234`, -2.2302516425362553`}}], 
      PolygonBox[{{2.5, -2.20590900530174}, {2.5, -2.357662782649368}, {
       2.437499981032941, -2.084292589556062}, {2.5, -2.20590900530174}}], 
      PolygonBox[{{2.437499981032941, -2.084292589556062}, {2.4375, -2.}, {
       2.5, -2.20590900530174}, {2.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{2.5, -2.}, {2.5, -2.20590900530174}, {2.4375, -2.}, {
       2.5, -2.}}], 
      PolygonBox[{{2.4375, -2.}, {2.437499981032941, -1.9157074104439382`}, {
       2.5, -2.}, {2.4375, -2.}}], 
      PolygonBox[{{2.5, -1.7940909946982602`}, {2.5, -2.}, {
       2.437499981032941, -1.9157074104439382`}, {
       2.5, -1.7940909946982602`}}], 
      PolygonBox[{{2.437499981032941, -1.9157074104439382`}, {
       2.4373449933535234`, -1.769748357463745}, {
       2.5, -1.7940909946982602`}, {
       2.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{2.5, -1.6423372173506325`}, {2.5, -1.7940909946982602`}, {
       2.4373449933535234`, -1.769748357463745}, {
       2.5, -1.6423372173506325`}}], 
      PolygonBox[{{2.4373449933535234`, -1.769748357463745}, {
       2.404942744332997, -1.5950572556670028`}, {
       2.5, -1.6423372173506325`}, {
       2.4373449933535234`, -1.769748357463745}}], 
      PolygonBox[{{2.491446564961186, -1.508553435038814}, {
       2.5, -1.6423372173506325`}, {
       2.404942744332997, -1.5950572556670028`}, {
       2.491446564961186, -1.508553435038814}}], 
      PolygonBox[{{2.404942744332997, -1.5950572556670028`}, {
       2.2302516425362553`, -1.5626550066464766`}, {
       2.491446564961186, -1.508553435038814}, {
       2.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{2.357662782649368, -1.5}, {
       2.491446564961186, -1.508553435038814}, {
       2.2302516425362553`, -1.5626550066464766`}, {
       2.357662782649368, -1.5}}], 
      PolygonBox[{{2.2302516425362553`, -1.5626550066464766`}, {
       2.0842925895560604`, -1.5625000189670593`}, {
       2.357662782649368, -1.5}, {
       2.2302516425362553`, -1.5626550066464766`}}], 
      PolygonBox[{{2.2059090053732557`, -1.5}, {2.357662782649368, -1.5}, {
       2.0842925895560604`, -1.5625000189670593`}, {
       2.2059090053732557`, -1.5}}], 
      PolygonBox[{{2.0842925895560604`, -1.5625000189670593`}, {
       2.0001055272204877`, -1.5625}, {2.2059090053732557`, -1.5}, {
       2.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{2.07794195802689, -1.5}, {2.2059090053732557`, -1.5}, {
       2.0001055272204877`, -1.5625}, {2.07794195802689, -1.5}}], 
      PolygonBox[{{2.0001055272204877`, -1.5625}, {
       1.915707410443943, -1.5625000189670593`}, {2.07794195802689, -1.5}, {
       2.0001055272204877`, -1.5625}}], 
      PolygonBox[{{1.7940909946955543`, -1.5}, {2.07794195802689, -1.5}, {
       1.915707410443943, -1.5625000189670593`}, {
       1.7940909946955543`, -1.5}}], 
      PolygonBox[{{1.915707410443943, -1.5625000189670593`}, {
       1.769748357463745, -1.5626550066464766`}, {
       1.7940909946955543`, -1.5}, {
       1.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{1.6423372173506339`, -1.5}, {1.7940909946955543`, -1.5}, {
       1.769748357463745, -1.5626550066464766`}, {
       1.6423372173506339`, -1.5}}], 
      PolygonBox[{{1.769748357463745, -1.5626550066464766`}, {
       1.5950572556670028`, -1.5950572556670028`}, {
       1.6423372173506339`, -1.5}, {
       1.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{2.5, -1.5}, {1.6423372173506339`, -1.5}, {
       1.5950572556670028`, -1.5950572556670028`}, {2.5, -1.5}}], 
      PolygonBox[{{1.5950572556670028`, -1.5950572556670028`}, {
       1.5626550066464766`, -1.7697483574637447`}, {2.5, -1.5}, {
       1.5950572556670028`, -1.5950572556670028`}}], 
      PolygonBox[{{1.5, -1.642337217350631}, {2.5, -1.5}, {
       1.5626550066464766`, -1.7697483574637447`}, {
       1.5, -1.642337217350631}}], 
      PolygonBox[{{1.5626550066464766`, -1.7697483574637447`}, {
       1.5625000189670593`, -1.9157074104439376`}, {
       1.5, -1.642337217350631}, {
       1.5626550066464766`, -1.7697483574637447`}}], 
      PolygonBox[{{1.5, -1.794090994717101}, {1.5, -1.642337217350631}, {
       1.5625000189670593`, -1.9157074104439376`}, {
       1.5, -1.794090994717101}}], 
      PolygonBox[{{1.5625000189670593`, -1.9157074104439376`}, {
       1.5625, -1.9998768219370047`}, {1.5, -1.794090994717101}, {
       1.5625000189670593`, -1.9157074104439376`}}], 
      PolygonBox[{{1.5, -1.9193213332412997`}, {1.5, -1.794090994717101}, {
       1.5625, -1.9998768219370047`}, {1.5, -1.9193213332412997`}}], 
      PolygonBox[{{1.5625, -1.9998768219370047`}, {
       1.5625000189670593`, -2.084292589556055}, {
       1.5, -1.9193213332412997`}, {1.5625, -1.9998768219370047`}}], 
      PolygonBox[{{1.5, -2.2059090051452785`}, {1.5, -1.9193213332412997`}, {
       1.5625000189670593`, -2.084292589556055}, {
       1.5, -2.2059090051452785`}}], 
      PolygonBox[{{1.5625000189670593`, -2.084292589556055}, {
       1.5626550066464766`, -2.230251642536255}, {
       1.5, -2.2059090051452785`}, {
       1.5625000189670593`, -2.084292589556055}}], 
      PolygonBox[{{1.5, -2.3576627826493652`}, {1.5, -2.2059090051452785`}, {
       1.5626550066464766`, -2.230251642536255}, {
       1.5, -2.3576627826493652`}}], 
      PolygonBox[{{1.5626550066464766`, -2.230251642536255}, {
       1.5950572556670028`, -2.404942744332997}, {
       1.5, -2.3576627826493652`}, {
       1.5626550066464766`, -2.230251642536255}}], 
      PolygonBox[{{1.5, -1.5}, {1.5, -2.3576627826493652`}, {
       1.5950572556670028`, -2.404942744332997}, {1.5, -1.5}}], 
      PolygonBox[{{1.5950572556670028`, -2.404942744332997}, {
       1.769748357463745, -2.4373449933535234`}, {1.5, -1.5}, {
       1.5950572556670028`, -2.404942744332997}}], 
      PolygonBox[{{1.5, -2.5}, {1.5, -1.5}, {
       1.769748357463745, -2.4373449933535234`}, {1.5, -2.5}}], 
      PolygonBox[{{1.769748357463745, -2.4373449933535234`}, {
       1.9157074104439358`, -2.437499981032941}, {1.5, -2.5}, {
       1.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{1.794090994433172, -2.5}, {1.5, -2.5}, {
       1.9157074104439358`, -2.437499981032941}, {1.794090994433172, -2.5}}], 
      PolygonBox[{{1.9157074104439358`, -2.437499981032941}, {
       2.000134841831043, -2.4375}, {1.794090994433172, -2.5}, {
       1.9157074104439358`, -2.437499981032941}}], 
      PolygonBox[{{2.0823238704010616`, -2.5}, {1.794090994433172, -2.5}, {
       2.000134841831043, -2.4375}, {2.0823238704010616`, -2.5}}], 
      PolygonBox[{{2.000134841831043, -2.4375}, {
       2.0842925895560533`, -2.437499981032941}, {
       2.0823238704010616`, -2.5}, {2.000134841831043, -2.4375}}], 
      PolygonBox[{{2.2059090053603976`, -2.5}, {2.0823238704010616`, -2.5}, {
       2.0842925895560533`, -2.437499981032941}, {
       2.2059090053603976`, -2.5}}], 
      PolygonBox[{{2.0842925895560533`, -2.437499981032941}, {
       2.230251642536255, -2.4373449933535234`}, {
       2.2059090053603976`, -2.5}, {
       2.0842925895560533`, -2.437499981032941}}], 
      PolygonBox[{{2.357662782649371, -2.5}, {2.2059090053603976`, -2.5}, {
       2.230251642536255, -2.4373449933535234`}, {2.357662782649371, -2.5}}], 
      PolygonBox[{{2.230251642536255, -2.4373449933535234`}, {
       2.404942744332997, -2.404942744332997}, {2.357662782649371, -2.5}, {
       2.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{2.5, -2.5}, {2.357662782649371, -2.5}, {
       2.404942744332997, -2.404942744332997}, {2.5, -2.5}}], 
      PolygonBox[{{2.404942744332997, -2.404942744332997}, {
       2.404942744332997, -2.404942744332997}, {2.5, -2.5}, {
       2.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{2.5, -2.5}, {2.5, -2.5}, {
       2.404942744332997, -2.404942744332997}, {2.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, -1.}, {1.5208333333333333`, -1.}, {
       1.5416666666666667`, -1.}, {1.5625, -1.}, {1.5833333333333333`, -1.}, {
       1.6041666666666665`, -1.}, {1.625, -1.}, {1.625, -1.}, {
       1.6041666666666667`, -1.}, {1.5833333333333333`, -1.}, {1.5625, -1.}, {
       1.5416666666666667`, -1.}, {1.5208333333333335`, -1.}, {1.5, -1.}, {
       1.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, -1.}, {2.3958333333333335`, -1.}, {
       2.4166666666666665`, -1.}, {2.4375, -1.}, {2.4583333333333335`, -1.}, {
       2.4791666666666665`, -1.}, {2.5, -1.}, {2.5, -1.}, {
       2.4791666666666665`, -1.}, {2.4583333333333335`, -1.}, {2.4375, -1.}, {
       2.4166666666666665`, -1.}, {2.3958333333333335`, -1.}, {2.375, -1.}, {
       2.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -1.5}, {2., -1.4791666666666667`}, {
       2., -1.4583333333333333`}, {2., -1.4375}, {2., -1.4166666666666667`}, {
       2., -1.3958333333333335`}, {2., -1.375}, {2., -1.375}, {
       2., -1.3958333333333333`}, {2., -1.4166666666666667`}, {2., -1.4375}, {
       2., -1.4583333333333333`}, {2., -1.4791666666666665`}, {2., -1.5}, {
       2., -1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -0.625}, {2., -0.6041666666666667}, {
       2., -0.5833333333333333}, {2., -0.5625}, {2., -0.5416666666666667}, {
       2., -0.5208333333333334}, {2., -0.5}, {2., -0.5}, {
       2., -0.5208333333333333}, {2., -0.5416666666666667}, {2., -0.5625}, {
       2., -0.5833333333333333}, {2., -0.6041666666666666}, {2., -0.625}, {
       2., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, -1.}, {1.75, -1.}, {1.875, -1.}, {2., -1.}, {
       2.125, -1.}, {2.25, -1.}, {2.375, -1.}, {2.375, -1.}, {2.25, -1.}, {
       2.125, -1.}, {2., -1.}, {1.875, -1.}, {1.75, -1.}, {1.625, -1.}, {
       1.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -1.375}, {2., -1.25}, {2., -1.125}, {2., -1.}, {
       2., -0.875}, {2., -0.75}, {2., -0.625}, {2., -0.625}, {2., -0.75}, {
       2., -0.875}, {2., -1.}, {2., -1.125}, {2., -1.25}, {2., -1.375}, {
       2., -1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhD6w/5XF9ftu/KUyeFo3pbsF0/e7DdwP9Eq
PZMJKv9q/+y3s2/yyTM5TPGcMPNI8/P9YOEGRgeHx/deTJz9dL//E6GnR48x
OETscGFdm/FkP9QCqP4n+5PNb5mWFP2zR5X/aw/Tf0rlhM+jg7/tJ0PNX1CY
/+XE2V/2/8Hg5X6dmEVNYSa/7I9A3QfR/8se5n6Y/NwTqqe6ez/C9UPkP+8/
CTXf7Lb5Zlm7L/sh5v6xT+ibwG1u9HV/ItR9VxbH1q48/RXN/d/2+0H9B5MH
a69ndIDph4UPzHxY+DFC7YeF73yo+9DDHwCcb7bI
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhD6wf7Vq0CACc4PBQNGOB+qAc4PA8v/tUfV
/8seVf0PgnyIPU/hfLAxq16hqf+AJv8JTf9XNPU/MPirUNz3A+q/v2jqYf77
geZ/mH4mB1T1LAT5YSjuY3FYjeJ+mPoPaPKv0PQ/RVP/YD8A9Td0LA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, -1.2651650429449552`}, {
       2.3247595264191645`, -1.1875}, {
       2.404942744332997, -1.4049427443329972`}, {
       2.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{2.4373449933535234`, -1.230251642536255}, {
       2.404942744332997, -1.4049427443329972`}, {
       2.3247595264191645`, -1.1875}, {
       2.4373449933535234`, -1.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, -1.1875}, {
       2.3622221848584006`, -1.0970571419134454`}, {
       2.4373449933535234`, -1.230251642536255}, {
       2.3247595264191645`, -1.1875}}], 
      PolygonBox[{{2.437499981032941, -1.0842925895560618`}, {
       2.4373449933535234`, -1.230251642536255}, {
       2.3622221848584006`, -1.0970571419134454`}, {
       2.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{2.3622221848584006`, -1.0970571419134454`}, {2.375, -1.}, {
       2.437499981032941, -1.0842925895560618`}, {
       2.3622221848584006`, -1.0970571419134454`}}], 
      PolygonBox[{{2.4375, -1.}, {2.437499981032941, -1.0842925895560618`}, {
       2.375, -1.}, {2.4375, -1.}}], 
      PolygonBox[{{2.375, -1.}, {2.3622221848584006`, -0.9029428580865547}, {
       2.4375, -1.}, {2.375, -1.}}], 
      PolygonBox[{{2.437499981032941, -0.9157074104439382}, {2.4375, -1.}, {
       2.3622221848584006`, -0.9029428580865547}, {
       2.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{2.3622221848584006`, -0.9029428580865547}, {
       2.3247595264191645`, -0.8125}, {
       2.437499981032941, -0.9157074104439382}, {
       2.3622221848584006`, -0.9029428580865547}}], 
      PolygonBox[{{2.4373449933535234`, -0.7697483574637449}, {
       2.437499981032941, -0.9157074104439382}, {
       2.3247595264191645`, -0.8125}, {
       2.4373449933535234`, -0.7697483574637449}}], 
      PolygonBox[{{2.3247595264191645`, -0.8125}, {
       2.2651650429449552`, -0.7348349570550448}, {
       2.4373449933535234`, -0.7697483574637449}, {
       2.3247595264191645`, -0.8125}}], 
      PolygonBox[{{2.404942744332997, -0.5950572556670028}, {
       2.4373449933535234`, -0.7697483574637449}, {
       2.2651650429449552`, -0.7348349570550448}, {
       2.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{2.2651650429449552`, -0.7348349570550448}, {
       2.1875, -0.6752404735808355}, {
       2.404942744332997, -0.5950572556670028}, {
       2.2651650429449552`, -0.7348349570550448}}], 
      PolygonBox[{{2.2302516425362553`, -0.5626550066464766}, {
       2.404942744332997, -0.5950572556670028}, {
       2.1875, -0.6752404735808355}, {
       2.2302516425362553`, -0.5626550066464766}}], 
      PolygonBox[{{2.1875, -0.6752404735808355}, {
       2.0970571419134454`, -0.6377778151415994}, {
       2.2302516425362553`, -0.5626550066464766}, {
       2.1875, -0.6752404735808355}}], 
      PolygonBox[{{2.0842925895560604`, -0.5625000189670593}, {
       2.2302516425362553`, -0.5626550066464766}, {
       2.0970571419134454`, -0.6377778151415994}, {
       2.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{2.0970571419134454`, -0.6377778151415994}, {2., -0.625}, {
       2.0842925895560604`, -0.5625000189670593}, {
       2.0970571419134454`, -0.6377778151415994}}], 
      PolygonBox[{{2.0001055272204877`, -0.5625}, {
       2.0842925895560604`, -0.5625000189670593}, {2., -0.625}, {
       2.0001055272204877`, -0.5625}}], 
      PolygonBox[{{2., -0.625}, {1.9029428580865548`, -0.6377778151415994}, {
       2.0001055272204877`, -0.5625}, {2., -0.625}}], 
      PolygonBox[{{1.915707410443943, -0.5625000189670593}, {
       2.0001055272204877`, -0.5625}, {
       1.9029428580865548`, -0.6377778151415994}, {
       1.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{1.9029428580865548`, -0.6377778151415994}, {
       1.8125, -0.6752404735808355}, {
       1.915707410443943, -0.5625000189670593}, {
       1.9029428580865548`, -0.6377778151415994}}], 
      PolygonBox[{{1.769748357463745, -0.5626550066464766}, {
       1.915707410443943, -0.5625000189670593}, {
       1.8125, -0.6752404735808355}, {
       1.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{1.8125, -0.6752404735808355}, {
       1.7348349570550448`, -0.7348349570550446}, {
       1.769748357463745, -0.5626550066464766}, {
       1.8125, -0.6752404735808355}}], 
      PolygonBox[{{1.5950572556670028`, -0.5950572556670028}, {
       1.769748357463745, -0.5626550066464766}, {
       1.7348349570550448`, -0.7348349570550446}, {
       1.5950572556670028`, -0.5950572556670028}}], 
      PolygonBox[{{1.7348349570550448`, -0.7348349570550446}, {
       1.6752404735808355`, -0.8124999999999999}, {
       1.5950572556670028`, -0.5950572556670028}, {
       1.7348349570550448`, -0.7348349570550446}}], 
      PolygonBox[{{1.5626550066464766`, -0.7697483574637446}, {
       1.5950572556670028`, -0.5950572556670028}, {
       1.6752404735808355`, -0.8124999999999999}, {
       1.5626550066464766`, -0.7697483574637446}}], 
      PolygonBox[{{1.6752404735808355`, -0.8124999999999999}, {
       1.6377778151415994`, -0.9029428580865546}, {
       1.5626550066464766`, -0.7697483574637446}, {
       1.6752404735808355`, -0.8124999999999999}}], 
      PolygonBox[{{1.5625000189670593`, -0.9157074104439377}, {
       1.5626550066464766`, -0.7697483574637446}, {
       1.6377778151415994`, -0.9029428580865546}, {
       1.5625000189670593`, -0.9157074104439377}}], 
      PolygonBox[{{1.6377778151415994`, -0.9029428580865546}, {
       1.625, -0.9999999999999998}, {
       1.5625000189670593`, -0.9157074104439377}, {
       1.6377778151415994`, -0.9029428580865546}}], 
      PolygonBox[{{1.5625, -0.9998768219370047}, {
       1.5625000189670593`, -0.9157074104439377}, {
       1.625, -0.9999999999999998}, {1.5625, -0.9998768219370047}}], 
      PolygonBox[{{1.625, -0.9999999999999998}, {
       1.6377778151415994`, -1.0970571419134452`}, {
       1.5625, -0.9998768219370047}, {1.625, -0.9999999999999998}}], 
      PolygonBox[{{1.5625000189670593`, -1.084292589556055}, {
       1.5625, -0.9998768219370047}, {
       1.6377778151415994`, -1.0970571419134452`}, {
       1.5625000189670593`, -1.084292589556055}}], 
      PolygonBox[{{1.6377778151415994`, -1.0970571419134452`}, {
       1.6752404735808355`, -1.1874999999999998`}, {
       1.5625000189670593`, -1.084292589556055}, {
       1.6377778151415994`, -1.0970571419134452`}}], 
      PolygonBox[{{1.5626550066464766`, -1.2302516425362549`}, {
       1.5625000189670593`, -1.084292589556055}, {
       1.6752404735808355`, -1.1874999999999998`}, {
       1.5626550066464766`, -1.2302516425362549`}}], 
      PolygonBox[{{1.6752404735808355`, -1.1874999999999998`}, {
       1.7348349570550448`, -1.2651650429449552`}, {
       1.5626550066464766`, -1.2302516425362549`}, {
       1.6752404735808355`, -1.1874999999999998`}}], 
      PolygonBox[{{1.5950572556670028`, -1.4049427443329972`}, {
       1.5626550066464766`, -1.2302516425362549`}, {
       1.7348349570550448`, -1.2651650429449552`}, {
       1.5950572556670028`, -1.4049427443329972`}}], 
      PolygonBox[{{1.7348349570550448`, -1.2651650429449552`}, {
       1.8124999999999998`, -1.3247595264191645`}, {
       1.5950572556670028`, -1.4049427443329972`}, {
       1.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{1.769748357463745, -1.4373449933535234`}, {
       1.5950572556670028`, -1.4049427443329972`}, {
       1.8124999999999998`, -1.3247595264191645`}, {
       1.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{1.8124999999999998`, -1.3247595264191645`}, {
       1.9029428580865544`, -1.3622221848584006`}, {
       1.769748357463745, -1.4373449933535234`}, {
       1.8124999999999998`, -1.3247595264191645`}}], 
      PolygonBox[{{1.9157074104439358`, -1.4374999810329407`}, {
       1.769748357463745, -1.4373449933535234`}, {
       1.9029428580865544`, -1.3622221848584006`}, {
       1.9157074104439358`, -1.4374999810329407`}}], 
      PolygonBox[{{1.9029428580865544`, -1.3622221848584006`}, {2., -1.375}, {
       1.9157074104439358`, -1.4374999810329407`}, {
       1.9029428580865544`, -1.3622221848584006`}}], 
      PolygonBox[{{2.000134841831043, -1.4375}, {
       1.9157074104439358`, -1.4374999810329407`}, {2., -1.375}, {
       2.000134841831043, -1.4375}}], 
      PolygonBox[{{2., -1.375}, {2.097057141913445, -1.3622221848584006`}, {
       2.000134841831043, -1.4375}, {2., -1.375}}], 
      PolygonBox[{{2.0842925895560533`, -1.4374999810329407`}, {
       2.000134841831043, -1.4375}, {
       2.097057141913445, -1.3622221848584006`}, {
       2.0842925895560533`, -1.4374999810329407`}}], 
      PolygonBox[{{2.097057141913445, -1.3622221848584006`}, {
       2.1874999999999996`, -1.3247595264191645`}, {
       2.0842925895560533`, -1.4374999810329407`}, {
       2.097057141913445, -1.3622221848584006`}}], 
      PolygonBox[{{2.230251642536255, -1.4373449933535234`}, {
       2.0842925895560533`, -1.4374999810329407`}, {
       2.1874999999999996`, -1.3247595264191645`}, {
       2.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{2.1874999999999996`, -1.3247595264191645`}, {
       2.2651650429449552`, -1.2651650429449552`}, {
       2.230251642536255, -1.4373449933535234`}, {
       2.1874999999999996`, -1.3247595264191645`}}], 
      PolygonBox[{{2.404942744332997, -1.4049427443329972`}, {
       2.230251642536255, -1.4373449933535234`}, {
       2.2651650429449552`, -1.2651650429449552`}, {
       2.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{2.2651650429449552`, -1.2651650429449552`}, {
       2.2651650429449552`, -1.2651650429449552`}, {
       2.404942744332997, -1.4049427443329972`}, {
       2.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{2.404942744332997, -1.4049427443329972`}, {
       2.404942744332997, -1.4049427443329972`}, {
       2.2651650429449552`, -1.2651650429449552`}, {
       2.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{2.404942744332997, -1.4049427443329972`}, {
       2.4373449933535234`, -1.230251642536255}, {2.5, -1.5}, {
       2.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{2.5, -1.3576627826493677`}, {2.5, -1.5}, {
       2.4373449933535234`, -1.230251642536255}, {
       2.5, -1.3576627826493677`}}], 
      PolygonBox[{{2.4373449933535234`, -1.230251642536255}, {
       2.437499981032941, -1.0842925895560618`}, {
       2.5, -1.3576627826493677`}, {
       2.4373449933535234`, -1.230251642536255}}], 
      PolygonBox[{{2.5, -1.20590900530174}, {2.5, -1.3576627826493677`}, {
       2.437499981032941, -1.0842925895560618`}, {2.5, -1.20590900530174}}], 
      PolygonBox[{{2.437499981032941, -1.0842925895560618`}, {2.4375, -1.}, {
       2.5, -1.20590900530174}, {2.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{2.5, -1.}, {2.5, -1.20590900530174}, {2.4375, -1.}, {
       2.5, -1.}}], 
      PolygonBox[{{2.4375, -1.}, {2.437499981032941, -0.9157074104439382}, {
       2.5, -1.}, {2.4375, -1.}}], 
      PolygonBox[{{2.5, -0.79409099469826}, {2.5, -1.}, {
       2.437499981032941, -0.9157074104439382}, {2.5, -0.79409099469826}}], 
      PolygonBox[{{2.437499981032941, -0.9157074104439382}, {
       2.4373449933535234`, -0.7697483574637449}, {2.5, -0.79409099469826}, {
       2.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{2.5, -0.6423372173506324}, {2.5, -0.79409099469826}, {
       2.4373449933535234`, -0.7697483574637449}, {
       2.5, -0.6423372173506324}}], 
      PolygonBox[{{2.4373449933535234`, -0.7697483574637449}, {
       2.404942744332997, -0.5950572556670028}, {2.5, -0.6423372173506324}, {
       2.4373449933535234`, -0.7697483574637449}}], 
      PolygonBox[{{2.491446564961186, -0.508553435038814}, {
       2.5, -0.6423372173506324}, {2.404942744332997, -0.5950572556670028}, {
       2.491446564961186, -0.508553435038814}}], 
      PolygonBox[{{2.404942744332997, -0.5950572556670028}, {
       2.2302516425362553`, -0.5626550066464766}, {
       2.491446564961186, -0.508553435038814}, {
       2.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{2.357662782649368, -0.5}, {
       2.491446564961186, -0.508553435038814}, {
       2.2302516425362553`, -0.5626550066464766}, {2.357662782649368, -0.5}}],
       PolygonBox[{{2.2302516425362553`, -0.5626550066464766}, {
       2.0842925895560604`, -0.5625000189670593}, {2.357662782649368, -0.5}, {
       2.2302516425362553`, -0.5626550066464766}}], 
      PolygonBox[{{2.2059090053732557`, -0.5}, {2.357662782649368, -0.5}, {
       2.0842925895560604`, -0.5625000189670593}, {
       2.2059090053732557`, -0.5}}], 
      PolygonBox[{{2.0842925895560604`, -0.5625000189670593}, {
       2.0001055272204877`, -0.5625}, {2.2059090053732557`, -0.5}, {
       2.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{2.07794195802689, -0.5}, {2.2059090053732557`, -0.5}, {
       2.0001055272204877`, -0.5625}, {2.07794195802689, -0.5}}], 
      PolygonBox[{{2.0001055272204877`, -0.5625}, {
       1.915707410443943, -0.5625000189670593}, {2.07794195802689, -0.5}, {
       2.0001055272204877`, -0.5625}}], 
      PolygonBox[{{1.7940909946955543`, -0.5}, {2.07794195802689, -0.5}, {
       1.915707410443943, -0.5625000189670593}, {1.7940909946955543`, -0.5}}],
       PolygonBox[{{1.915707410443943, -0.5625000189670593}, {
       1.769748357463745, -0.5626550066464766}, {1.7940909946955543`, -0.5}, {
       1.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{1.6423372173506339`, -0.5}, {1.7940909946955543`, -0.5}, {
       1.769748357463745, -0.5626550066464766}, {1.6423372173506339`, -0.5}}],
       PolygonBox[{{1.769748357463745, -0.5626550066464766}, {
       1.5950572556670028`, -0.5950572556670028}, {
       1.6423372173506339`, -0.5}, {1.769748357463745, -0.5626550066464766}}],
       PolygonBox[{{2.5, -0.5}, {1.6423372173506339`, -0.5}, {
       1.5950572556670028`, -0.5950572556670028}, {2.5, -0.5}}], 
      PolygonBox[{{1.5950572556670028`, -0.5950572556670028}, {
       1.5626550066464766`, -0.7697483574637446}, {2.5, -0.5}, {
       1.5950572556670028`, -0.5950572556670028}}], 
      PolygonBox[{{1.5, -0.642337217350631}, {2.5, -0.5}, {
       1.5626550066464766`, -0.7697483574637446}, {1.5, -0.642337217350631}}],
       PolygonBox[{{1.5626550066464766`, -0.7697483574637446}, {
       1.5625000189670593`, -0.9157074104439377}, {1.5, -0.642337217350631}, {
       1.5626550066464766`, -0.7697483574637446}}], 
      PolygonBox[{{1.5, -0.7940909947171011}, {1.5, -0.642337217350631}, {
       1.5625000189670593`, -0.9157074104439377}, {
       1.5, -0.7940909947171011}}], 
      PolygonBox[{{1.5625000189670593`, -0.9157074104439377}, {
       1.5625, -0.9998768219370047}, {1.5, -0.7940909947171011}, {
       1.5625000189670593`, -0.9157074104439377}}], 
      PolygonBox[{{1.5, -0.9193213332412997}, {1.5, -0.7940909947171011}, {
       1.5625, -0.9998768219370047}, {1.5, -0.9193213332412997}}], 
      PolygonBox[{{1.5625, -0.9998768219370047}, {
       1.5625000189670593`, -1.084292589556055}, {1.5, -0.9193213332412997}, {
       1.5625, -0.9998768219370047}}], 
      PolygonBox[{{1.5, -1.2059090051452785`}, {1.5, -0.9193213332412997}, {
       1.5625000189670593`, -1.084292589556055}, {
       1.5, -1.2059090051452785`}}], 
      PolygonBox[{{1.5625000189670593`, -1.084292589556055}, {
       1.5626550066464766`, -1.2302516425362549`}, {
       1.5, -1.2059090051452785`}, {
       1.5625000189670593`, -1.084292589556055}}], 
      PolygonBox[{{1.5, -1.3576627826493652`}, {1.5, -1.2059090051452785`}, {
       1.5626550066464766`, -1.2302516425362549`}, {
       1.5, -1.3576627826493652`}}], 
      PolygonBox[{{1.5626550066464766`, -1.2302516425362549`}, {
       1.5950572556670028`, -1.4049427443329972`}, {
       1.5, -1.3576627826493652`}, {
       1.5626550066464766`, -1.2302516425362549`}}], 
      PolygonBox[{{1.5, -0.5}, {1.5, -1.3576627826493652`}, {
       1.5950572556670028`, -1.4049427443329972`}, {1.5, -0.5}}], 
      PolygonBox[{{1.5950572556670028`, -1.4049427443329972`}, {
       1.769748357463745, -1.4373449933535234`}, {1.5, -0.5}, {
       1.5950572556670028`, -1.4049427443329972`}}], 
      PolygonBox[{{1.5, -1.5}, {1.5, -0.5}, {
       1.769748357463745, -1.4373449933535234`}, {1.5, -1.5}}], 
      PolygonBox[{{1.769748357463745, -1.4373449933535234`}, {
       1.9157074104439358`, -1.4374999810329407`}, {1.5, -1.5}, {
       1.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{1.794090994433172, -1.5}, {1.5, -1.5}, {
       1.9157074104439358`, -1.4374999810329407`}, {
       1.794090994433172, -1.5}}], 
      PolygonBox[{{1.9157074104439358`, -1.4374999810329407`}, {
       2.000134841831043, -1.4375}, {1.794090994433172, -1.5}, {
       1.9157074104439358`, -1.4374999810329407`}}], 
      PolygonBox[{{2.0823238704010616`, -1.5}, {1.794090994433172, -1.5}, {
       2.000134841831043, -1.4375}, {2.0823238704010616`, -1.5}}], 
      PolygonBox[{{2.000134841831043, -1.4375}, {
       2.0842925895560533`, -1.4374999810329407`}, {
       2.0823238704010616`, -1.5}, {2.000134841831043, -1.4375}}], 
      PolygonBox[{{2.2059090053603976`, -1.5}, {2.0823238704010616`, -1.5}, {
       2.0842925895560533`, -1.4374999810329407`}, {
       2.2059090053603976`, -1.5}}], 
      PolygonBox[{{2.0842925895560533`, -1.4374999810329407`}, {
       2.230251642536255, -1.4373449933535234`}, {
       2.2059090053603976`, -1.5}, {
       2.0842925895560533`, -1.4374999810329407`}}], 
      PolygonBox[{{2.357662782649371, -1.5}, {2.2059090053603976`, -1.5}, {
       2.230251642536255, -1.4373449933535234`}, {2.357662782649371, -1.5}}], 
      PolygonBox[{{2.230251642536255, -1.4373449933535234`}, {
       2.404942744332997, -1.4049427443329972`}, {2.357662782649371, -1.5}, {
       2.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{2.5, -1.5}, {2.357662782649371, -1.5}, {
       2.404942744332997, -1.4049427443329972`}, {2.5, -1.5}}], 
      PolygonBox[{{2.404942744332997, -1.4049427443329972`}, {
       2.404942744332997, -1.4049427443329972`}, {2.5, -1.5}, {
       2.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{2.5, -1.5}, {2.5, -1.5}, {
       2.404942744332997, -1.4049427443329972`}, {2.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, 0.}, {1.5208333333333333`, 0.}, {1.5416666666666667`, 
       0.}, {1.5625, 0.}, {1.5833333333333333`, 0.}, {1.6041666666666665`, 
       0.}, {1.625, 0.}, {1.625, 0.}, {1.6041666666666667`, 0.}, {
       1.5833333333333333`, 0.}, {1.5625, 0.}, {1.5416666666666667`, 0.}, {
       1.5208333333333335`, 0.}, {1.5, 0.}, {1.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, 0.}, {2.3958333333333335`, 0.}, {2.4166666666666665`, 
       0.}, {2.4375, 0.}, {2.4583333333333335`, 0.}, {2.4791666666666665`, 
       0.}, {2.5, 0.}, {2.5, 0.}, {2.4791666666666665`, 0.}, {
       2.4583333333333335`, 0.}, {2.4375, 0.}, {2.4166666666666665`, 0.}, {
       2.3958333333333335`, 0.}, {2.375, 0.}, {2.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -0.5}, {2., -0.4791666666666667}, {
       2., -0.4583333333333333}, {2., -0.4375}, {2., -0.4166666666666667}, {
       2., -0.39583333333333337`}, {2., -0.375}, {2., -0.375}, {
       2., -0.3958333333333333}, {2., -0.4166666666666667}, {2., -0.4375}, {
       2., -0.4583333333333333}, {2., -0.47916666666666663`}, {2., -0.5}, {
       2., -0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 0.375}, {2., 0.3958333333333333}, {2., 
       0.4166666666666667}, {2., 0.4375}, {2., 0.4583333333333333}, {2., 
       0.47916666666666663`}, {2., 0.5}, {2., 0.5}, {2., 
       0.4791666666666667}, {2., 0.4583333333333333}, {2., 0.4375}, {2., 
       0.4166666666666667}, {2., 0.39583333333333337`}, {2., 0.375}, {2., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, 0.}, {1.75, 0.}, {1.875, 0.}, {2., 0.}, {2.125, 0.}, {
       2.25, 0.}, {2.375, 0.}, {2.375, 0.}, {2.25, 0.}, {2.125, 0.}, {2., 
       0.}, {1.875, 0.}, {1.75, 0.}, {1.625, 0.}, {1.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -0.375}, {2., -0.25}, {2., -0.125}, {2., 0.}, {2., 
       0.125}, {2., 0.25}, {2., 0.375}, {2., 0.375}, {2., 0.25}, {2., 
       0.125}, {2., 0.}, {2., -0.125}, {2., -0.25}, {2., -0.375}, {
       2., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDjDWq4vr9l15yuRwozNm0Z4bO+wN3E+0Ss9k
cvgPBsftZ7+dfZNPnsnhZs79M2U/LtiDNTUwOjRYOundOXHF3v+J0NOjxxgc
/PvLvi7Vu24PNRZq/g37ZPNbpiVF/+wDUOT/2sP0n1I54fPo4G/7W1DzFxTm
fzlx9pc9C1jdCXudmEVNYSa/7B9A3QfR/8ueq2uej2Vllw1M/hxEfj9M/x+I
+/efhJp/HWL+foi//tjXQezfnwh1nx/EffvR3L/fD+o/qPsh+usZHZqg+mHh
A3X/flj4sUHcvx8Wvu+g7oOFP8T9s/YAAK3lvBc=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhD6gf3qVSDABOeHggEjnA/VAOeHgeX/2qPq
/2WPqv4HQT7EnKto/KNo6mHgh30IRH4/Kv/qflT1DzD4q1Ddtz8U1f370fy3
H83/UP3w8NmPFn44+WEo7oPxj6KphwEWhxAU/8P4V+1R1T+wBwBZrGB2
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, -0.2651650429449553}, {
       2.3247595264191645`, -0.1875}, {
       2.404942744332997, -0.4049427443329971}, {
       2.2651650429449552`, -0.2651650429449553}}], 
      PolygonBox[{{2.4373449933535234`, -0.23025164253625516`}, {
       2.404942744332997, -0.4049427443329971}, {
       2.3247595264191645`, -0.1875}, {
       2.4373449933535234`, -0.23025164253625516`}}], 
      PolygonBox[{{2.3247595264191645`, -0.1875}, {
       2.3622221848584006`, -0.0970571419134453}, {
       2.4373449933535234`, -0.23025164253625516`}, {
       2.3247595264191645`, -0.1875}}], 
      PolygonBox[{{2.437499981032941, -0.08429258955606181}, {
       2.4373449933535234`, -0.23025164253625516`}, {
       2.3622221848584006`, -0.0970571419134453}, {
       2.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{2.3622221848584006`, -0.0970571419134453}, {2.375, 0.}, {
       2.437499981032941, -0.08429258955606181}, {
       2.3622221848584006`, -0.0970571419134453}}], 
      PolygonBox[{{2.4375, 0.}, {2.437499981032941, -0.08429258955606181}, {
       2.375, 0.}, {2.4375, 0.}}], 
      PolygonBox[{{2.375, 0.}, {2.3622221848584006`, 0.09705714191344525}, {
       2.4375, 0.}, {2.375, 0.}}], 
      PolygonBox[{{2.437499981032941, 0.08429258955606177}, {2.4375, 0.}, {
       2.3622221848584006`, 0.09705714191344525}, {2.437499981032941, 
       0.08429258955606177}}], 
      PolygonBox[{{2.3622221848584006`, 0.09705714191344525}, {
       2.3247595264191645`, 0.18749999999999994`}, {2.437499981032941, 
       0.08429258955606177}, {2.3622221848584006`, 0.09705714191344525}}], 
      PolygonBox[{{2.4373449933535234`, 0.23025164253625502`}, {
       2.437499981032941, 0.08429258955606177}, {2.3247595264191645`, 
       0.18749999999999994`}, {2.4373449933535234`, 0.23025164253625502`}}], 
      PolygonBox[{{2.3247595264191645`, 0.18749999999999994`}, {
       2.2651650429449552`, 0.2651650429449553}, {2.4373449933535234`, 
       0.23025164253625502`}, {2.3247595264191645`, 0.18749999999999994`}}], 
      PolygonBox[{{2.404942744332997, 0.40494274433299715`}, {
       2.4373449933535234`, 0.23025164253625502`}, {2.2651650429449552`, 
       0.2651650429449553}, {2.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{2.2651650429449552`, 0.2651650429449553}, {2.1875, 
       0.3247595264191645}, {2.404942744332997, 0.40494274433299715`}, {
       2.2651650429449552`, 0.2651650429449553}}], 
      PolygonBox[{{2.2302516425362553`, 0.4373449933535234}, {
       2.404942744332997, 0.40494274433299715`}, {2.1875, 
       0.3247595264191645}, {2.2302516425362553`, 0.4373449933535234}}], 
      PolygonBox[{{2.1875, 0.3247595264191645}, {2.0970571419134454`, 
       0.3622221848584006}, {2.2302516425362553`, 0.4373449933535234}, {
       2.1875, 0.3247595264191645}}], 
      PolygonBox[{{2.0842925895560604`, 0.4374999810329408}, {
       2.2302516425362553`, 0.4373449933535234}, {2.0970571419134454`, 
       0.3622221848584006}, {2.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{2.0970571419134454`, 0.3622221848584006}, {2., 0.375}, {
       2.0842925895560604`, 0.4374999810329408}, {2.0970571419134454`, 
       0.3622221848584006}}], 
      PolygonBox[{{2.0001055272204877`, 0.4375}, {2.0842925895560604`, 
       0.4374999810329408}, {2., 0.375}, {2.0001055272204877`, 0.4375}}], 
      PolygonBox[{{2., 0.375}, {1.9029428580865548`, 0.36222218485840063`}, {
       2.0001055272204877`, 0.4375}, {2., 0.375}}], 
      PolygonBox[{{1.915707410443943, 0.4374999810329408}, {
       2.0001055272204877`, 0.4375}, {1.9029428580865548`, 
       0.36222218485840063`}, {1.915707410443943, 0.4374999810329408}}], 
      PolygonBox[{{1.9029428580865548`, 0.36222218485840063`}, {1.8125, 
       0.3247595264191645}, {1.915707410443943, 0.4374999810329408}, {
       1.9029428580865548`, 0.36222218485840063`}}], 
      PolygonBox[{{1.769748357463745, 0.4373449933535234}, {1.915707410443943,
        0.4374999810329408}, {1.8125, 0.3247595264191645}, {1.769748357463745,
        0.4373449933535234}}], 
      PolygonBox[{{1.8125, 0.3247595264191645}, {1.7348349570550448`, 
       0.26516504294495535`}, {1.769748357463745, 0.4373449933535234}, {
       1.8125, 0.3247595264191645}}], 
      PolygonBox[{{1.5950572556670028`, 0.40494274433299715`}, {
       1.769748357463745, 0.4373449933535234}, {1.7348349570550448`, 
       0.26516504294495535`}, {1.5950572556670028`, 0.40494274433299715`}}], 
      PolygonBox[{{1.7348349570550448`, 0.26516504294495535`}, {
       1.6752404735808355`, 0.1875000000000001}, {1.5950572556670028`, 
       0.40494274433299715`}, {1.7348349570550448`, 0.26516504294495535`}}], 
      PolygonBox[{{1.5626550066464766`, 0.2302516425362554}, {
       1.5950572556670028`, 0.40494274433299715`}, {1.6752404735808355`, 
       0.1875000000000001}, {1.5626550066464766`, 0.2302516425362554}}], 
      PolygonBox[{{1.6752404735808355`, 0.1875000000000001}, {
       1.6377778151415994`, 0.09705714191344539}, {1.5626550066464766`, 
       0.2302516425362554}, {1.6752404735808355`, 0.1875000000000001}}], 
      PolygonBox[{{1.5625000189670593`, 0.08429258955606238}, {
       1.5626550066464766`, 0.2302516425362554}, {1.6377778151415994`, 
       0.09705714191344539}, {1.5625000189670593`, 0.08429258955606238}}], 
      PolygonBox[{{1.6377778151415994`, 0.09705714191344539}, {1.625, 
       2.1245770866179924`*^-16}, {1.5625000189670593`, 
       0.08429258955606238}, {1.6377778151415994`, 0.09705714191344539}}], 
      PolygonBox[{{1.5625, 0.00012317806299537147`}, {1.5625000189670593`, 
       0.08429258955606238}, {1.625, 2.1245770866179924`*^-16}, {1.5625, 
       0.00012317806299537147`}}], 
      PolygonBox[{{1.625, 2.1245770866179924`*^-16}, {
       1.6377778151415994`, -0.09705714191344514}, {1.5625, 
       0.00012317806299537147`}, {1.625, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{1.5625000189670593`, -0.084292589556055}, {1.5625, 
       0.00012317806299537147`}, {
       1.6377778151415994`, -0.09705714191344514}, {
       1.5625000189670593`, -0.084292589556055}}], 
      PolygonBox[{{1.6377778151415994`, -0.09705714191344514}, {
       1.6752404735808355`, -0.18749999999999978`}, {
       1.5625000189670593`, -0.084292589556055}, {
       1.6377778151415994`, -0.09705714191344514}}], 
      PolygonBox[{{1.5626550066464766`, -0.23025164253625477`}, {
       1.5625000189670593`, -0.084292589556055}, {
       1.6752404735808355`, -0.18749999999999978`}, {
       1.5626550066464766`, -0.23025164253625477`}}], 
      PolygonBox[{{1.6752404735808355`, -0.18749999999999978`}, {
       1.7348349570550448`, -0.2651650429449553}, {
       1.5626550066464766`, -0.23025164253625477`}, {
       1.6752404735808355`, -0.18749999999999978`}}], 
      PolygonBox[{{1.5950572556670028`, -0.4049427443329971}, {
       1.5626550066464766`, -0.23025164253625477`}, {
       1.7348349570550448`, -0.2651650429449553}, {
       1.5950572556670028`, -0.4049427443329971}}], 
      PolygonBox[{{1.7348349570550448`, -0.2651650429449553}, {
       1.8124999999999998`, -0.3247595264191644}, {
       1.5950572556670028`, -0.4049427443329971}, {
       1.7348349570550448`, -0.2651650429449553}}], 
      PolygonBox[{{1.769748357463745, -0.4373449933535234}, {
       1.5950572556670028`, -0.4049427443329971}, {
       1.8124999999999998`, -0.3247595264191644}, {
       1.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{1.8124999999999998`, -0.3247595264191644}, {
       1.9029428580865544`, -0.3622221848584005}, {
       1.769748357463745, -0.4373449933535234}, {
       1.8124999999999998`, -0.3247595264191644}}], 
      PolygonBox[{{1.9157074104439358`, -0.4374999810329408}, {
       1.769748357463745, -0.4373449933535234}, {
       1.9029428580865544`, -0.3622221848584005}, {
       1.9157074104439358`, -0.4374999810329408}}], 
      PolygonBox[{{1.9029428580865544`, -0.3622221848584005}, {2., -0.375}, {
       1.9157074104439358`, -0.4374999810329408}, {
       1.9029428580865544`, -0.3622221848584005}}], 
      PolygonBox[{{2.000134841831043, -0.4375}, {
       1.9157074104439358`, -0.4374999810329408}, {2., -0.375}, {
       2.000134841831043, -0.4375}}], 
      PolygonBox[{{2., -0.375}, {2.097057141913445, -0.36222218485840063`}, {
       2.000134841831043, -0.4375}, {2., -0.375}}], 
      PolygonBox[{{2.0842925895560533`, -0.4374999810329408}, {
       2.000134841831043, -0.4375}, {
       2.097057141913445, -0.36222218485840063`}, {
       2.0842925895560533`, -0.4374999810329408}}], 
      PolygonBox[{{2.097057141913445, -0.36222218485840063`}, {
       2.1874999999999996`, -0.3247595264191646}, {
       2.0842925895560533`, -0.4374999810329408}, {
       2.097057141913445, -0.36222218485840063`}}], 
      PolygonBox[{{2.230251642536255, -0.4373449933535234}, {
       2.0842925895560533`, -0.4374999810329408}, {
       2.1874999999999996`, -0.3247595264191646}, {
       2.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{2.1874999999999996`, -0.3247595264191646}, {
       2.2651650429449552`, -0.26516504294495535`}, {
       2.230251642536255, -0.4373449933535234}, {
       2.1874999999999996`, -0.3247595264191646}}], 
      PolygonBox[{{2.404942744332997, -0.40494274433299715`}, {
       2.230251642536255, -0.4373449933535234}, {
       2.2651650429449552`, -0.26516504294495535`}, {
       2.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{2.2651650429449552`, -0.26516504294495535`}, {
       2.2651650429449552`, -0.2651650429449553}, {
       2.404942744332997, -0.40494274433299715`}, {
       2.2651650429449552`, -0.26516504294495535`}}], 
      PolygonBox[{{2.404942744332997, -0.4049427443329971}, {
       2.404942744332997, -0.40494274433299715`}, {
       2.2651650429449552`, -0.2651650429449553}, {
       2.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{2.404942744332997, -0.4049427443329971}, {
       2.4373449933535234`, -0.23025164253625516`}, {2.5, -0.5}, {
       2.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{2.5, -0.3576627826493677}, {2.5, -0.5}, {
       2.4373449933535234`, -0.23025164253625516`}, {
       2.5, -0.3576627826493677}}], 
      PolygonBox[{{2.4373449933535234`, -0.23025164253625516`}, {
       2.437499981032941, -0.08429258955606181}, {2.5, -0.3576627826493677}, {
       2.4373449933535234`, -0.23025164253625516`}}], 
      PolygonBox[{{2.5, -0.20590900530173997`}, {2.5, -0.3576627826493677}, {
       2.437499981032941, -0.08429258955606181}, {
       2.5, -0.20590900530173997`}}], 
      PolygonBox[{{2.437499981032941, -0.08429258955606181}, {2.4375, 0.}, {
       2.5, -0.20590900530173997`}, {
       2.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{2.5, 0.}, {2.5, -0.20590900530173997`}, {2.4375, 0.}, {2.5,
        0.}}], PolygonBox[{{2.4375, 0.}, {2.437499981032941, 
       0.08429258955606177}, {2.5, 0.}, {2.4375, 0.}}], 
      PolygonBox[{{2.5, 0.20590900530173992`}, {2.5, 0.}, {2.437499981032941, 
       0.08429258955606177}, {2.5, 0.20590900530173992`}}], 
      PolygonBox[{{2.437499981032941, 0.08429258955606177}, {
       2.4373449933535234`, 0.23025164253625502`}, {2.5, 
       0.20590900530173992`}, {2.437499981032941, 0.08429258955606177}}], 
      PolygonBox[{{2.5, 0.35766278264936757`}, {2.5, 0.20590900530173992`}, {
       2.4373449933535234`, 0.23025164253625502`}, {2.5, 
       0.35766278264936757`}}], 
      PolygonBox[{{2.4373449933535234`, 0.23025164253625502`}, {
       2.404942744332997, 0.40494274433299715`}, {2.5, 
       0.35766278264936757`}, {2.4373449933535234`, 0.23025164253625502`}}], 
      PolygonBox[{{2.491446564961186, 0.491446564961186}, {2.5, 
       0.35766278264936757`}, {2.404942744332997, 0.40494274433299715`}, {
       2.491446564961186, 0.491446564961186}}], 
      PolygonBox[{{2.404942744332997, 0.40494274433299715`}, {
       2.2302516425362553`, 0.4373449933535234}, {2.491446564961186, 
       0.491446564961186}, {2.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{2.357662782649368, 0.5}, {2.491446564961186, 
       0.491446564961186}, {2.2302516425362553`, 0.4373449933535234}, {
       2.357662782649368, 0.5}}], 
      PolygonBox[{{2.2302516425362553`, 0.4373449933535234}, {
       2.0842925895560604`, 0.4374999810329408}, {2.357662782649368, 0.5}, {
       2.2302516425362553`, 0.4373449933535234}}], 
      PolygonBox[{{2.2059090053732557`, 0.5}, {2.357662782649368, 0.5}, {
       2.0842925895560604`, 0.4374999810329408}, {2.2059090053732557`, 0.5}}],
       PolygonBox[{{2.0842925895560604`, 0.4374999810329408}, {
       2.0001055272204877`, 0.4375}, {2.2059090053732557`, 0.5}, {
       2.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{2.07794195802689, 0.5}, {2.2059090053732557`, 0.5}, {
       2.0001055272204877`, 0.4375}, {2.07794195802689, 0.5}}], 
      PolygonBox[{{2.0001055272204877`, 0.4375}, {1.915707410443943, 
       0.4374999810329408}, {2.07794195802689, 0.5}, {2.0001055272204877`, 
       0.4375}}], 
      PolygonBox[{{1.7940909946955543`, 0.5}, {2.07794195802689, 0.5}, {
       1.915707410443943, 0.4374999810329408}, {1.7940909946955543`, 0.5}}], 
      PolygonBox[{{1.915707410443943, 0.4374999810329408}, {1.769748357463745,
        0.4373449933535234}, {1.7940909946955543`, 0.5}, {1.915707410443943, 
       0.4374999810329408}}], 
      PolygonBox[{{1.6423372173506339`, 0.5}, {1.7940909946955543`, 0.5}, {
       1.769748357463745, 0.4373449933535234}, {1.6423372173506339`, 0.5}}], 
      PolygonBox[{{1.769748357463745, 0.4373449933535234}, {
       1.5950572556670028`, 0.40494274433299715`}, {1.6423372173506339`, 
       0.5}, {1.769748357463745, 0.4373449933535234}}], 
      PolygonBox[{{2.5, 0.5}, {1.6423372173506339`, 0.5}, {
       1.5950572556670028`, 0.40494274433299715`}, {2.5, 0.5}}], 
      PolygonBox[{{1.5950572556670028`, 0.40494274433299715`}, {
       1.5626550066464766`, 0.2302516425362554}, {2.5, 0.5}, {
       1.5950572556670028`, 0.40494274433299715`}}], 
      PolygonBox[{{1.5, 0.357662782649369}, {2.5, 0.5}, {1.5626550066464766`, 
       0.2302516425362554}, {1.5, 0.357662782649369}}], 
      PolygonBox[{{1.5626550066464766`, 0.2302516425362554}, {
       1.5625000189670593`, 0.08429258955606238}, {1.5, 0.357662782649369}, {
       1.5626550066464766`, 0.2302516425362554}}], 
      PolygonBox[{{1.5, 0.20590900528289896`}, {1.5, 0.357662782649369}, {
       1.5625000189670593`, 0.08429258955606238}, {1.5, 
       0.20590900528289896`}}], 
      PolygonBox[{{1.5625000189670593`, 0.08429258955606238}, {1.5625, 
       0.00012317806299537147`}, {1.5, 0.20590900528289896`}, {
       1.5625000189670593`, 0.08429258955606238}}], 
      PolygonBox[{{1.5, 0.08067866675870025}, {1.5, 0.20590900528289896`}, {
       1.5625, 0.00012317806299537147`}, {1.5, 0.08067866675870025}}], 
      PolygonBox[{{1.5625, 0.00012317806299537147`}, {
       1.5625000189670593`, -0.084292589556055}, {1.5, 0.08067866675870025}, {
       1.5625, 0.00012317806299537147`}}], 
      PolygonBox[{{1.5, -0.20590900514527852`}, {1.5, 0.08067866675870025}, {
       1.5625000189670593`, -0.084292589556055}, {
       1.5, -0.20590900514527852`}}], 
      PolygonBox[{{1.5625000189670593`, -0.084292589556055}, {
       1.5626550066464766`, -0.23025164253625477`}, {
       1.5, -0.20590900514527852`}, {
       1.5625000189670593`, -0.084292589556055}}], 
      PolygonBox[{{1.5, -0.35766278264936535`}, {
       1.5, -0.20590900514527852`}, {
       1.5626550066464766`, -0.23025164253625477`}, {
       1.5, -0.35766278264936535`}}], 
      PolygonBox[{{1.5626550066464766`, -0.23025164253625477`}, {
       1.5950572556670028`, -0.4049427443329971}, {
       1.5, -0.35766278264936535`}, {
       1.5626550066464766`, -0.23025164253625477`}}], 
      PolygonBox[{{1.5, 0.5}, {1.5, -0.35766278264936535`}, {
       1.5950572556670028`, -0.4049427443329971}, {1.5, 0.5}}], 
      PolygonBox[{{1.5950572556670028`, -0.4049427443329971}, {
       1.769748357463745, -0.4373449933535234}, {1.5, 0.5}, {
       1.5950572556670028`, -0.4049427443329971}}], 
      PolygonBox[{{1.5, -0.5}, {1.5, 0.5}, {
       1.769748357463745, -0.4373449933535234}, {1.5, -0.5}}], 
      PolygonBox[{{1.769748357463745, -0.4373449933535234}, {
       1.9157074104439358`, -0.4374999810329408}, {1.5, -0.5}, {
       1.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{1.794090994433172, -0.5}, {1.5, -0.5}, {
       1.9157074104439358`, -0.4374999810329408}, {1.794090994433172, -0.5}}],
       PolygonBox[{{1.9157074104439358`, -0.4374999810329408}, {
       2.000134841831043, -0.4375}, {1.794090994433172, -0.5}, {
       1.9157074104439358`, -0.4374999810329408}}], 
      PolygonBox[{{2.0823238704010616`, -0.5}, {1.794090994433172, -0.5}, {
       2.000134841831043, -0.4375}, {2.0823238704010616`, -0.5}}], 
      PolygonBox[{{2.000134841831043, -0.4375}, {
       2.0842925895560533`, -0.4374999810329408}, {
       2.0823238704010616`, -0.5}, {2.000134841831043, -0.4375}}], 
      PolygonBox[{{2.2059090053603976`, -0.5}, {2.0823238704010616`, -0.5}, {
       2.0842925895560533`, -0.4374999810329408}, {
       2.2059090053603976`, -0.5}}], 
      PolygonBox[{{2.0842925895560533`, -0.4374999810329408}, {
       2.230251642536255, -0.4373449933535234}, {2.2059090053603976`, -0.5}, {
       2.0842925895560533`, -0.4374999810329408}}], 
      PolygonBox[{{2.357662782649371, -0.5}, {2.2059090053603976`, -0.5}, {
       2.230251642536255, -0.4373449933535234}, {2.357662782649371, -0.5}}], 
      PolygonBox[{{2.230251642536255, -0.4373449933535234}, {
       2.404942744332997, -0.40494274433299715`}, {2.357662782649371, -0.5}, {
       2.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{2.5, -0.5}, {2.357662782649371, -0.5}, {
       2.404942744332997, -0.40494274433299715`}, {2.5, -0.5}}], 
      PolygonBox[{{2.404942744332997, -0.40494274433299715`}, {
       2.404942744332997, -0.4049427443329971}, {2.5, -0.5}, {
       2.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{2.5, -0.5}, {2.5, -0.5}, {
       2.404942744332997, -0.4049427443329971}, {
       2.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, 1.}, {1.5208333333333333`, 1.}, {1.5416666666666667`, 
       1.}, {1.5625, 1.}, {1.5833333333333333`, 1.}, {1.6041666666666665`, 
       1.}, {1.625, 1.}, {1.625, 1.}, {1.6041666666666667`, 1.}, {
       1.5833333333333333`, 1.}, {1.5625, 1.}, {1.5416666666666667`, 1.}, {
       1.5208333333333335`, 1.}, {1.5, 1.}, {1.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, 1.}, {2.3958333333333335`, 1.}, {2.4166666666666665`, 
       1.}, {2.4375, 1.}, {2.4583333333333335`, 1.}, {2.4791666666666665`, 
       1.}, {2.5, 1.}, {2.5, 1.}, {2.4791666666666665`, 1.}, {
       2.4583333333333335`, 1.}, {2.4375, 1.}, {2.4166666666666665`, 1.}, {
       2.3958333333333335`, 1.}, {2.375, 1.}, {2.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 0.5}, {2., 0.5208333333333333}, {2., 
       0.5416666666666667}, {2., 0.5625}, {2., 0.5833333333333333}, {2., 
       0.6041666666666666}, {2., 0.625}, {2., 0.625}, {2., 
       0.6041666666666667}, {2., 0.5833333333333333}, {2., 0.5625}, {2., 
       0.5416666666666667}, {2., 0.5208333333333334}, {2., 0.5}, {2., 0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 1.375}, {2., 1.3958333333333333`}, {2., 
       1.4166666666666667`}, {2., 1.4375}, {2., 1.4583333333333333`}, {2., 
       1.4791666666666665`}, {2., 1.5}, {2., 1.5}, {2., 
       1.4791666666666667`}, {2., 1.4583333333333333`}, {2., 1.4375}, {2., 
       1.4166666666666667`}, {2., 1.3958333333333335`}, {2., 1.375}, {2., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, 1.}, {1.75, 1.}, {1.875, 1.}, {2., 1.}, {2.125, 1.}, {
       2.25, 1.}, {2.375, 1.}, {2.375, 1.}, {2.25, 1.}, {2.125, 1.}, {2., 
       1.}, {1.875, 1.}, {1.75, 1.}, {1.625, 1.}, {1.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 0.625}, {2., 0.75}, {2., 0.875}, {2., 1.}, {2., 1.125}, {
       2., 1.25}, {2., 1.375}, {2., 1.375}, {2., 1.25}, {2., 1.125}, {2., 
       1.}, {2., 0.875}, {2., 0.75}, {2., 0.625}, {2., 0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhD6g/2ri+v2XXnK5DDvhOqp7t6P9gbuJ1ql
ZzJB5T/bz347+yafPJOD2W3zzbJ2X+zBwg2MDgl9E7jNjb7a+z8Renr0GIPD
lcWxtStPf7WHWgDV/80+2fyWaUnRP3tU+b/2MP2nVE74PDr42x5m/oLC/C8n
zv6yh9mvE7OoKczklz3MfRBxmPwHuPyxvC3ZL568getnBMu/sj8JNX+K54SZ
R5qf2/8Hgz/2jo/vvZg4+6l9ItR9kTtcWNdmPEFz/xN7P6j/IqDyYO31jA72
UP2w8JkMNR8Wfv/ACl/Cw/cQ1H2w8Ie44709AJJFsEA=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhD6h/3qVSDABOeHggEjnA/VAOeHgeX/2qPq
/2WPqp4wDTHnK5o5n9DUfUCTf4Wm/yma+gcY/FUo7nsA9d9fNPUw/z1A8z9M
P5MDqnoWgvxQFPexOKxCcT9M/Qc0+U9o+r+iqf9hDwCtEmYs
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, 0.7348349570550448}, {
       2.3247595264191645`, 0.8125}, {2.404942744332997, 
       0.5950572556670028}, {2.2651650429449552`, 0.7348349570550448}}], 
      PolygonBox[{{2.4373449933535234`, 0.7697483574637448}, {
       2.404942744332997, 0.5950572556670028}, {2.3247595264191645`, 
       0.8125}, {2.4373449933535234`, 0.7697483574637448}}], 
      PolygonBox[{{2.3247595264191645`, 0.8125}, {2.3622221848584006`, 
       0.9029428580865547}, {2.4373449933535234`, 0.7697483574637448}, {
       2.3247595264191645`, 0.8125}}], 
      PolygonBox[{{2.437499981032941, 0.9157074104439382}, {
       2.4373449933535234`, 0.7697483574637448}, {2.3622221848584006`, 
       0.9029428580865547}, {2.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{2.3622221848584006`, 0.9029428580865547}, {2.375, 1.}, {
       2.437499981032941, 0.9157074104439382}, {2.3622221848584006`, 
       0.9029428580865547}}], 
      PolygonBox[{{2.4375, 1.}, {2.437499981032941, 0.9157074104439382}, {
       2.375, 1.}, {2.4375, 1.}}], 
      PolygonBox[{{2.375, 1.}, {2.3622221848584006`, 1.0970571419134452`}, {
       2.4375, 1.}, {2.375, 1.}}], 
      PolygonBox[{{2.437499981032941, 1.0842925895560618`}, {2.4375, 1.}, {
       2.3622221848584006`, 1.0970571419134452`}, {2.437499981032941, 
       1.0842925895560618`}}], 
      PolygonBox[{{2.3622221848584006`, 1.0970571419134452`}, {
       2.3247595264191645`, 1.1875}, {2.437499981032941, 
       1.0842925895560618`}, {2.3622221848584006`, 1.0970571419134452`}}], 
      PolygonBox[{{2.4373449933535234`, 1.230251642536255}, {
       2.437499981032941, 1.0842925895560618`}, {2.3247595264191645`, 
       1.1875}, {2.4373449933535234`, 1.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, 1.1875}, {2.2651650429449552`, 
       1.2651650429449552`}, {2.4373449933535234`, 1.230251642536255}, {
       2.3247595264191645`, 1.1875}}], 
      PolygonBox[{{2.404942744332997, 1.4049427443329972`}, {
       2.4373449933535234`, 1.230251642536255}, {2.2651650429449552`, 
       1.2651650429449552`}, {2.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{2.2651650429449552`, 1.2651650429449552`}, {2.1875, 
       1.3247595264191645`}, {2.404942744332997, 1.4049427443329972`}, {
       2.2651650429449552`, 1.2651650429449552`}}], 
      PolygonBox[{{2.2302516425362553`, 1.4373449933535234`}, {
       2.404942744332997, 1.4049427443329972`}, {2.1875, 
       1.3247595264191645`}, {2.2302516425362553`, 1.4373449933535234`}}], 
      PolygonBox[{{2.1875, 1.3247595264191645`}, {2.0970571419134454`, 
       1.3622221848584006`}, {2.2302516425362553`, 1.4373449933535234`}, {
       2.1875, 1.3247595264191645`}}], 
      PolygonBox[{{2.0842925895560604`, 1.4374999810329407`}, {
       2.2302516425362553`, 1.4373449933535234`}, {2.0970571419134454`, 
       1.3622221848584006`}, {2.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{2.0970571419134454`, 1.3622221848584006`}, {2., 1.375}, {
       2.0842925895560604`, 1.4374999810329407`}, {2.0970571419134454`, 
       1.3622221848584006`}}], 
      PolygonBox[{{2.0001055272204877`, 1.4375}, {2.0842925895560604`, 
       1.4374999810329407`}, {2., 1.375}, {2.0001055272204877`, 1.4375}}], 
      PolygonBox[{{2., 1.375}, {1.9029428580865548`, 1.3622221848584006`}, {
       2.0001055272204877`, 1.4375}, {2., 1.375}}], 
      PolygonBox[{{1.915707410443943, 1.4374999810329407`}, {
       2.0001055272204877`, 1.4375}, {1.9029428580865548`, 
       1.3622221848584006`}, {1.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{1.9029428580865548`, 1.3622221848584006`}, {1.8125, 
       1.3247595264191645`}, {1.915707410443943, 1.4374999810329407`}, {
       1.9029428580865548`, 1.3622221848584006`}}], 
      PolygonBox[{{1.769748357463745, 1.4373449933535234`}, {
       1.915707410443943, 1.4374999810329407`}, {1.8125, 
       1.3247595264191645`}, {1.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{1.8125, 1.3247595264191645`}, {1.7348349570550448`, 
       1.2651650429449552`}, {1.769748357463745, 1.4373449933535234`}, {
       1.8125, 1.3247595264191645`}}], 
      PolygonBox[{{1.5950572556670028`, 1.4049427443329972`}, {
       1.769748357463745, 1.4373449933535234`}, {1.7348349570550448`, 
       1.2651650429449552`}, {1.5950572556670028`, 1.4049427443329972`}}], 
      PolygonBox[{{1.7348349570550448`, 1.2651650429449552`}, {
       1.6752404735808355`, 1.1875}, {1.5950572556670028`, 
       1.4049427443329972`}, {1.7348349570550448`, 1.2651650429449552`}}], 
      PolygonBox[{{1.5626550066464766`, 1.2302516425362553`}, {
       1.5950572556670028`, 1.4049427443329972`}, {1.6752404735808355`, 
       1.1875}, {1.5626550066464766`, 1.2302516425362553`}}], 
      PolygonBox[{{1.6752404735808355`, 1.1875}, {1.6377778151415994`, 
       1.0970571419134454`}, {1.5626550066464766`, 1.2302516425362553`}, {
       1.6752404735808355`, 1.1875}}], 
      PolygonBox[{{1.5625000189670593`, 1.0842925895560624`}, {
       1.5626550066464766`, 1.2302516425362553`}, {1.6377778151415994`, 
       1.0970571419134454`}, {1.5625000189670593`, 1.0842925895560624`}}], 
      PolygonBox[{{1.6377778151415994`, 1.0970571419134454`}, {1.625, 
       1.0000000000000002`}, {1.5625000189670593`, 1.0842925895560624`}, {
       1.6377778151415994`, 1.0970571419134454`}}], 
      PolygonBox[{{1.5625, 1.0001231780629953`}, {1.5625000189670593`, 
       1.0842925895560624`}, {1.625, 1.0000000000000002`}, {1.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{1.625, 1.0000000000000002`}, {1.6377778151415994`, 
       0.9029428580865548}, {1.5625, 1.0001231780629953`}, {1.625, 
       1.0000000000000002`}}], 
      PolygonBox[{{1.5625000189670593`, 0.915707410443945}, {1.5625, 
       1.0001231780629953`}, {1.6377778151415994`, 0.9029428580865548}, {
       1.5625000189670593`, 0.915707410443945}}], 
      PolygonBox[{{1.6377778151415994`, 0.9029428580865548}, {
       1.6752404735808355`, 0.8125000000000002}, {1.5625000189670593`, 
       0.915707410443945}, {1.6377778151415994`, 0.9029428580865548}}], 
      PolygonBox[{{1.5626550066464766`, 0.7697483574637453}, {
       1.5625000189670593`, 0.915707410443945}, {1.6752404735808355`, 
       0.8125000000000002}, {1.5626550066464766`, 0.7697483574637453}}], 
      PolygonBox[{{1.6752404735808355`, 0.8125000000000002}, {
       1.7348349570550448`, 0.7348349570550448}, {1.5626550066464766`, 
       0.7697483574637453}, {1.6752404735808355`, 0.8125000000000002}}], 
      PolygonBox[{{1.5950572556670028`, 0.5950572556670028}, {
       1.5626550066464766`, 0.7697483574637453}, {1.7348349570550448`, 
       0.7348349570550448}, {1.5950572556670028`, 0.5950572556670028}}], 
      PolygonBox[{{1.7348349570550448`, 0.7348349570550448}, {
       1.8124999999999998`, 0.6752404735808356}, {1.5950572556670028`, 
       0.5950572556670028}, {1.7348349570550448`, 0.7348349570550448}}], 
      PolygonBox[{{1.769748357463745, 0.5626550066464766}, {
       1.5950572556670028`, 0.5950572556670028}, {1.8124999999999998`, 
       0.6752404735808356}, {1.769748357463745, 0.5626550066464766}}], 
      PolygonBox[{{1.8124999999999998`, 0.6752404735808356}, {
       1.9029428580865544`, 0.6377778151415995}, {1.769748357463745, 
       0.5626550066464766}, {1.8124999999999998`, 0.6752404735808356}}], 
      PolygonBox[{{1.9157074104439358`, 0.5625000189670593}, {
       1.769748357463745, 0.5626550066464766}, {1.9029428580865544`, 
       0.6377778151415995}, {1.9157074104439358`, 0.5625000189670593}}], 
      PolygonBox[{{1.9029428580865544`, 0.6377778151415995}, {2., 0.625}, {
       1.9157074104439358`, 0.5625000189670593}, {1.9029428580865544`, 
       0.6377778151415995}}], 
      PolygonBox[{{2.000134841831043, 0.5625}, {1.9157074104439358`, 
       0.5625000189670593}, {2., 0.625}, {2.000134841831043, 0.5625}}], 
      PolygonBox[{{2., 0.625}, {2.097057141913445, 0.6377778151415994}, {
       2.000134841831043, 0.5625}, {2., 0.625}}], 
      PolygonBox[{{2.0842925895560533`, 0.5625000189670593}, {
       2.000134841831043, 0.5625}, {2.097057141913445, 0.6377778151415994}, {
       2.0842925895560533`, 0.5625000189670593}}], 
      PolygonBox[{{2.097057141913445, 0.6377778151415994}, {
       2.1874999999999996`, 0.6752404735808354}, {2.0842925895560533`, 
       0.5625000189670593}, {2.097057141913445, 0.6377778151415994}}], 
      PolygonBox[{{2.230251642536255, 0.5626550066464766}, {
       2.0842925895560533`, 0.5625000189670593}, {2.1874999999999996`, 
       0.6752404735808354}, {2.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{2.1874999999999996`, 0.6752404735808354}, {
       2.2651650429449552`, 0.7348349570550446}, {2.230251642536255, 
       0.5626550066464766}, {2.1874999999999996`, 0.6752404735808354}}], 
      PolygonBox[{{2.404942744332997, 0.5950572556670028}, {2.230251642536255,
        0.5626550066464766}, {2.2651650429449552`, 0.7348349570550446}, {
       2.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{2.2651650429449552`, 0.7348349570550446}, {
       2.2651650429449552`, 0.7348349570550448}, {2.404942744332997, 
       0.5950572556670028}, {2.2651650429449552`, 0.7348349570550446}}], 
      PolygonBox[{{2.404942744332997, 0.5950572556670028}, {2.404942744332997,
        0.5950572556670028}, {2.2651650429449552`, 0.7348349570550448}, {
       2.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{2.404942744332997, 0.5950572556670028}, {
       2.4373449933535234`, 0.7697483574637448}, {2.5, 0.5}, {
       2.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{2.5, 0.6423372173506323}, {2.5, 0.5}, {2.4373449933535234`,
        0.7697483574637448}, {2.5, 0.6423372173506323}}], 
      PolygonBox[{{2.4373449933535234`, 0.7697483574637448}, {
       2.437499981032941, 0.9157074104439382}, {2.5, 0.6423372173506323}, {
       2.4373449933535234`, 0.7697483574637448}}], 
      PolygonBox[{{2.5, 0.79409099469826}, {2.5, 0.6423372173506323}, {
       2.437499981032941, 0.9157074104439382}, {2.5, 0.79409099469826}}], 
      PolygonBox[{{2.437499981032941, 0.9157074104439382}, {2.4375, 1.}, {2.5,
        0.79409099469826}, {2.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{2.5, 1.}, {2.5, 0.79409099469826}, {2.4375, 1.}, {2.5, 
       1.}}], PolygonBox[{{2.4375, 1.}, {2.437499981032941, 
       1.0842925895560618`}, {2.5, 1.}, {2.4375, 1.}}], 
      PolygonBox[{{2.5, 1.2059090053017398`}, {2.5, 1.}, {2.437499981032941, 
       1.0842925895560618`}, {2.5, 1.2059090053017398`}}], 
      PolygonBox[{{2.437499981032941, 1.0842925895560618`}, {
       2.4373449933535234`, 1.230251642536255}, {2.5, 1.2059090053017398`}, {
       2.437499981032941, 1.0842925895560618`}}], 
      PolygonBox[{{2.5, 1.3576627826493675`}, {2.5, 1.2059090053017398`}, {
       2.4373449933535234`, 1.230251642536255}, {2.5, 1.3576627826493675`}}], 
      PolygonBox[{{2.4373449933535234`, 1.230251642536255}, {
       2.404942744332997, 1.4049427443329972`}, {2.5, 1.3576627826493675`}, {
       2.4373449933535234`, 1.230251642536255}}], 
      PolygonBox[{{2.491446564961186, 1.491446564961186}, {2.5, 
       1.3576627826493675`}, {2.404942744332997, 1.4049427443329972`}, {
       2.491446564961186, 1.491446564961186}}], 
      PolygonBox[{{2.404942744332997, 1.4049427443329972`}, {
       2.2302516425362553`, 1.4373449933535234`}, {2.491446564961186, 
       1.491446564961186}, {2.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{2.357662782649368, 1.5}, {2.491446564961186, 
       1.491446564961186}, {2.2302516425362553`, 1.4373449933535234`}, {
       2.357662782649368, 1.5}}], 
      PolygonBox[{{2.2302516425362553`, 1.4373449933535234`}, {
       2.0842925895560604`, 1.4374999810329407`}, {2.357662782649368, 1.5}, {
       2.2302516425362553`, 1.4373449933535234`}}], 
      PolygonBox[{{2.2059090053732557`, 1.5}, {2.357662782649368, 1.5}, {
       2.0842925895560604`, 1.4374999810329407`}, {2.2059090053732557`, 
       1.5}}], PolygonBox[{{2.0842925895560604`, 1.4374999810329407`}, {
       2.0001055272204877`, 1.4375}, {2.2059090053732557`, 1.5}, {
       2.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{2.07794195802689, 1.5}, {2.2059090053732557`, 1.5}, {
       2.0001055272204877`, 1.4375}, {2.07794195802689, 1.5}}], 
      PolygonBox[{{2.0001055272204877`, 1.4375}, {1.915707410443943, 
       1.4374999810329407`}, {2.07794195802689, 1.5}, {2.0001055272204877`, 
       1.4375}}], 
      PolygonBox[{{1.7940909946955543`, 1.5}, {2.07794195802689, 1.5}, {
       1.915707410443943, 1.4374999810329407`}, {1.7940909946955543`, 1.5}}], 
      PolygonBox[{{1.915707410443943, 1.4374999810329407`}, {
       1.769748357463745, 1.4373449933535234`}, {1.7940909946955543`, 1.5}, {
       1.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{1.6423372173506339`, 1.5}, {1.7940909946955543`, 1.5}, {
       1.769748357463745, 1.4373449933535234`}, {1.6423372173506339`, 1.5}}], 
      PolygonBox[{{1.769748357463745, 1.4373449933535234`}, {
       1.5950572556670028`, 1.4049427443329972`}, {1.6423372173506339`, 
       1.5}, {1.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{2.5, 1.5}, {1.6423372173506339`, 1.5}, {
       1.5950572556670028`, 1.4049427443329972`}, {2.5, 1.5}}], 
      PolygonBox[{{1.5950572556670028`, 1.4049427443329972`}, {
       1.5626550066464766`, 1.2302516425362553`}, {2.5, 1.5}, {
       1.5950572556670028`, 1.4049427443329972`}}], 
      PolygonBox[{{1.5, 1.357662782649369}, {2.5, 1.5}, {1.5626550066464766`, 
       1.2302516425362553`}, {1.5, 1.357662782649369}}], 
      PolygonBox[{{1.5626550066464766`, 1.2302516425362553`}, {
       1.5625000189670593`, 1.0842925895560624`}, {1.5, 1.357662782649369}, {
       1.5626550066464766`, 1.2302516425362553`}}], 
      PolygonBox[{{1.5, 1.205909005282899}, {1.5, 1.357662782649369}, {
       1.5625000189670593`, 1.0842925895560624`}, {1.5, 1.205909005282899}}], 
      PolygonBox[{{1.5625000189670593`, 1.0842925895560624`}, {1.5625, 
       1.0001231780629953`}, {1.5, 1.205909005282899}, {1.5625000189670593`, 
       1.0842925895560624`}}], 
      PolygonBox[{{1.5, 1.0806786667587003`}, {1.5, 1.205909005282899}, {
       1.5625, 1.0001231780629953`}, {1.5, 1.0806786667587003`}}], 
      PolygonBox[{{1.5625, 1.0001231780629953`}, {1.5625000189670593`, 
       0.915707410443945}, {1.5, 1.0806786667587003`}, {1.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{1.5, 0.7940909948547215}, {1.5, 1.0806786667587003`}, {
       1.5625000189670593`, 0.915707410443945}, {1.5, 0.7940909948547215}}], 
      PolygonBox[{{1.5625000189670593`, 0.915707410443945}, {
       1.5626550066464766`, 0.7697483574637453}, {1.5, 0.7940909948547215}, {
       1.5625000189670593`, 0.915707410443945}}], 
      PolygonBox[{{1.5, 0.6423372173506346}, {1.5, 0.7940909948547215}, {
       1.5626550066464766`, 0.7697483574637453}, {1.5, 0.6423372173506346}}], 
      PolygonBox[{{1.5626550066464766`, 0.7697483574637453}, {
       1.5950572556670028`, 0.5950572556670028}, {1.5, 0.6423372173506346}, {
       1.5626550066464766`, 0.7697483574637453}}], 
      PolygonBox[{{1.5, 1.5}, {1.5, 0.6423372173506346}, {1.5950572556670028`,
        0.5950572556670028}, {1.5, 1.5}}], 
      PolygonBox[{{1.5950572556670028`, 0.5950572556670028}, {
       1.769748357463745, 0.5626550066464766}, {1.5, 1.5}, {
       1.5950572556670028`, 0.5950572556670028}}], 
      PolygonBox[{{1.5, 0.5}, {1.5, 1.5}, {1.769748357463745, 
       0.5626550066464766}, {1.5, 0.5}}], 
      PolygonBox[{{1.769748357463745, 0.5626550066464766}, {
       1.9157074104439358`, 0.5625000189670593}, {1.5, 0.5}, {
       1.769748357463745, 0.5626550066464766}}], 
      PolygonBox[{{1.794090994433172, 0.5}, {1.5, 0.5}, {1.9157074104439358`, 
       0.5625000189670593}, {1.794090994433172, 0.5}}], 
      PolygonBox[{{1.9157074104439358`, 0.5625000189670593}, {
       2.000134841831043, 0.5625}, {1.794090994433172, 0.5}, {
       1.9157074104439358`, 0.5625000189670593}}], 
      PolygonBox[{{2.0823238704010616`, 0.5}, {1.794090994433172, 0.5}, {
       2.000134841831043, 0.5625}, {2.0823238704010616`, 0.5}}], 
      PolygonBox[{{2.000134841831043, 0.5625}, {2.0842925895560533`, 
       0.5625000189670593}, {2.0823238704010616`, 0.5}, {2.000134841831043, 
       0.5625}}], 
      PolygonBox[{{2.2059090053603976`, 0.5}, {2.0823238704010616`, 0.5}, {
       2.0842925895560533`, 0.5625000189670593}, {2.2059090053603976`, 0.5}}],
       PolygonBox[{{2.0842925895560533`, 0.5625000189670593}, {
       2.230251642536255, 0.5626550066464766}, {2.2059090053603976`, 0.5}, {
       2.0842925895560533`, 0.5625000189670593}}], 
      PolygonBox[{{2.357662782649371, 0.5}, {2.2059090053603976`, 0.5}, {
       2.230251642536255, 0.5626550066464766}, {2.357662782649371, 0.5}}], 
      PolygonBox[{{2.230251642536255, 0.5626550066464766}, {2.404942744332997,
        0.5950572556670028}, {2.357662782649371, 0.5}, {2.230251642536255, 
       0.5626550066464766}}], 
      PolygonBox[{{2.5, 0.5}, {2.357662782649371, 0.5}, {2.404942744332997, 
       0.5950572556670028}, {2.5, 0.5}}], 
      PolygonBox[{{2.404942744332997, 0.5950572556670028}, {2.404942744332997,
        0.5950572556670028}, {2.5, 0.5}, {2.404942744332997, 
       0.5950572556670028}}], 
      PolygonBox[{{2.5, 0.5}, {2.5, 0.5}, {2.404942744332997, 
       0.5950572556670028}, {2.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, 2.}, {1.5208333333333333`, 2.}, {1.5416666666666667`, 
       2.}, {1.5625, 2.}, {1.5833333333333333`, 2.}, {1.6041666666666665`, 
       2.}, {1.625, 2.}, {1.625, 2.}, {1.6041666666666667`, 2.}, {
       1.5833333333333333`, 2.}, {1.5625, 2.}, {1.5416666666666667`, 2.}, {
       1.5208333333333335`, 2.}, {1.5, 2.}, {1.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, 2.}, {2.3958333333333335`, 2.}, {2.4166666666666665`, 
       2.}, {2.4375, 2.}, {2.4583333333333335`, 2.}, {2.4791666666666665`, 
       2.}, {2.5, 2.}, {2.5, 2.}, {2.4791666666666665`, 2.}, {
       2.4583333333333335`, 2.}, {2.4375, 2.}, {2.4166666666666665`, 2.}, {
       2.3958333333333335`, 2.}, {2.375, 2.}, {2.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 1.5}, {2., 1.5208333333333333`}, {2., 
       1.5416666666666667`}, {2., 1.5625}, {2., 1.5833333333333333`}, {2., 
       1.6041666666666665`}, {2., 1.625}, {2., 1.625}, {2., 
       1.6041666666666667`}, {2., 1.5833333333333333`}, {2., 1.5625}, {2., 
       1.5416666666666667`}, {2., 1.5208333333333335`}, {2., 1.5}, {2., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 2.375}, {2., 2.3958333333333335`}, {2., 
       2.4166666666666665`}, {2., 2.4375}, {2., 2.4583333333333335`}, {2., 
       2.4791666666666665`}, {2., 2.5}, {2., 2.5}, {2., 
       2.4791666666666665`}, {2., 2.4583333333333335`}, {2., 2.4375}, {2., 
       2.4166666666666665`}, {2., 2.3958333333333335`}, {2., 2.375}, {2., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, 2.}, {1.75, 2.}, {1.875, 2.}, {2., 2.}, {2.125, 2.}, {
       2.25, 2.}, {2.375, 2.}, {2.375, 2.}, {2.25, 2.}, {2.125, 2.}, {2., 
       2.}, {1.875, 2.}, {1.75, 2.}, {1.625, 2.}, {1.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 1.625}, {2., 1.75}, {2., 1.875}, {2., 2.}, {2., 2.125}, {
       2., 2.25}, {2., 2.375}, {2., 2.375}, {2., 2.25}, {2., 2.125}, {2., 
       2.}, {2., 1.875}, {2., 1.75}, {2., 1.625}, {2., 1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDlCGw6uL6/Zdecrk4P9E6OnRYwwOBu4nWqVn
MkHkGxgdZr+dfZNPnglOw8Rh6mD6YObAzIXZk2x+y7Sk6J89qvxfe5j+Uyon
fB4d/G0PM39BYf6XE2d/2cPs0YlZ1BRm8sseZg9EP1QeaA9MHmYPin6gPSeh
5sPs+Q8Gf+DqEqH6YOaguv+XvR/UXpg8WHs9I9ydMHfDzIf5C2YPzN8we9DD
HwAdt6F8
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDjB69SoQYILzQ8GA0QFVHQOcHwaW/2uPqv+X
Par6HwT5qPb+sEe1F6aeAc5HtRem/5c9qnpMehWaulA0c9DtQXfHKjR3EuvP
VWjhEooWbqj2Yob7KrR4gdEAnX9ZJg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, 1.7348349570550448`}, {
       2.3247595264191645`, 1.8125}, {2.404942744332997, 
       1.5950572556670028`}, {2.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{2.4373449933535234`, 1.769748357463745}, {
       2.404942744332997, 1.5950572556670028`}, {2.3247595264191645`, 
       1.8125}, {2.4373449933535234`, 1.769748357463745}}], 
      PolygonBox[{{2.3247595264191645`, 1.8125}, {2.3622221848584006`, 
       1.9029428580865546`}, {2.4373449933535234`, 1.769748357463745}, {
       2.3247595264191645`, 1.8125}}], 
      PolygonBox[{{2.437499981032941, 1.9157074104439382`}, {
       2.4373449933535234`, 1.769748357463745}, {2.3622221848584006`, 
       1.9029428580865546`}, {2.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{2.3622221848584006`, 1.9029428580865546`}, {2.375, 2.}, {
       2.437499981032941, 1.9157074104439382`}, {2.3622221848584006`, 
       1.9029428580865546`}}], 
      PolygonBox[{{2.4375, 2.}, {2.437499981032941, 1.9157074104439382`}, {
       2.375, 2.}, {2.4375, 2.}}], 
      PolygonBox[{{2.375, 2.}, {2.3622221848584006`, 2.0970571419134454`}, {
       2.4375, 2.}, {2.375, 2.}}], 
      PolygonBox[{{2.437499981032941, 2.084292589556062}, {2.4375, 2.}, {
       2.3622221848584006`, 2.0970571419134454`}, {2.437499981032941, 
       2.084292589556062}}], 
      PolygonBox[{{2.3622221848584006`, 2.0970571419134454`}, {
       2.3247595264191645`, 2.1875}, {2.437499981032941, 2.084292589556062}, {
       2.3622221848584006`, 2.0970571419134454`}}], 
      PolygonBox[{{2.4373449933535234`, 2.230251642536255}, {
       2.437499981032941, 2.084292589556062}, {2.3247595264191645`, 2.1875}, {
       2.4373449933535234`, 2.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, 2.1875}, {2.2651650429449552`, 
       2.2651650429449552`}, {2.4373449933535234`, 2.230251642536255}, {
       2.3247595264191645`, 2.1875}}], 
      PolygonBox[{{2.404942744332997, 2.404942744332997}, {
       2.4373449933535234`, 2.230251642536255}, {2.2651650429449552`, 
       2.2651650429449552`}, {2.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, 2.2651650429449552`}, {2.1875, 
       2.3247595264191645`}, {2.404942744332997, 2.404942744332997}, {
       2.2651650429449552`, 2.2651650429449552`}}], 
      PolygonBox[{{2.2302516425362553`, 2.4373449933535234`}, {
       2.404942744332997, 2.404942744332997}, {2.1875, 2.3247595264191645`}, {
       2.2302516425362553`, 2.4373449933535234`}}], 
      PolygonBox[{{2.1875, 2.3247595264191645`}, {2.0970571419134454`, 
       2.3622221848584006`}, {2.2302516425362553`, 2.4373449933535234`}, {
       2.1875, 2.3247595264191645`}}], 
      PolygonBox[{{2.0842925895560604`, 2.437499981032941}, {
       2.2302516425362553`, 2.4373449933535234`}, {2.0970571419134454`, 
       2.3622221848584006`}, {2.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{2.0970571419134454`, 2.3622221848584006`}, {2., 2.375}, {
       2.0842925895560604`, 2.437499981032941}, {2.0970571419134454`, 
       2.3622221848584006`}}], 
      PolygonBox[{{2.0001055272204877`, 2.4375}, {2.0842925895560604`, 
       2.437499981032941}, {2., 2.375}, {2.0001055272204877`, 2.4375}}], 
      PolygonBox[{{2., 2.375}, {1.9029428580865548`, 2.3622221848584006`}, {
       2.0001055272204877`, 2.4375}, {2., 2.375}}], 
      PolygonBox[{{1.915707410443943, 2.437499981032941}, {
       2.0001055272204877`, 2.4375}, {1.9029428580865548`, 
       2.3622221848584006`}, {1.915707410443943, 2.437499981032941}}], 
      PolygonBox[{{1.9029428580865548`, 2.3622221848584006`}, {1.8125, 
       2.3247595264191645`}, {1.915707410443943, 2.437499981032941}, {
       1.9029428580865548`, 2.3622221848584006`}}], 
      PolygonBox[{{1.769748357463745, 2.4373449933535234`}, {
       1.915707410443943, 2.437499981032941}, {1.8125, 2.3247595264191645`}, {
       1.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{1.8125, 2.3247595264191645`}, {1.7348349570550448`, 
       2.2651650429449552`}, {1.769748357463745, 2.4373449933535234`}, {
       1.8125, 2.3247595264191645`}}], 
      PolygonBox[{{1.5950572556670028`, 2.404942744332997}, {
       1.769748357463745, 2.4373449933535234`}, {1.7348349570550448`, 
       2.2651650429449552`}, {1.5950572556670028`, 2.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, 2.2651650429449552`}, {
       1.6752404735808355`, 2.1875}, {1.5950572556670028`, 
       2.404942744332997}, {1.7348349570550448`, 2.2651650429449552`}}], 
      PolygonBox[{{1.5626550066464766`, 2.2302516425362553`}, {
       1.5950572556670028`, 2.404942744332997}, {1.6752404735808355`, 
       2.1875}, {1.5626550066464766`, 2.2302516425362553`}}], 
      PolygonBox[{{1.6752404735808355`, 2.1875}, {1.6377778151415994`, 
       2.0970571419134454`}, {1.5626550066464766`, 2.2302516425362553`}, {
       1.6752404735808355`, 2.1875}}], 
      PolygonBox[{{1.5625000189670593`, 2.0842925895560622`}, {
       1.5626550066464766`, 2.2302516425362553`}, {1.6377778151415994`, 
       2.0970571419134454`}, {1.5625000189670593`, 2.0842925895560622`}}], 
      PolygonBox[{{1.6377778151415994`, 2.0970571419134454`}, {1.625, 2.}, {
       1.5625000189670593`, 2.0842925895560622`}, {1.6377778151415994`, 
       2.0970571419134454`}}], 
      PolygonBox[{{1.5625, 2.0001231780629953`}, {1.5625000189670593`, 
       2.0842925895560622`}, {1.625, 2.}, {1.5625, 2.0001231780629953`}}], 
      PolygonBox[{{1.625, 2.}, {1.6377778151415994`, 1.9029428580865548`}, {
       1.5625, 2.0001231780629953`}, {1.625, 2.}}], 
      PolygonBox[{{1.5625000189670593`, 1.915707410443945}, {1.5625, 
       2.0001231780629953`}, {1.6377778151415994`, 1.9029428580865548`}, {
       1.5625000189670593`, 1.915707410443945}}], 
      PolygonBox[{{1.6377778151415994`, 1.9029428580865548`}, {
       1.6752404735808355`, 1.8125000000000002`}, {1.5625000189670593`, 
       1.915707410443945}, {1.6377778151415994`, 1.9029428580865548`}}], 
      PolygonBox[{{1.5626550066464766`, 1.7697483574637451`}, {
       1.5625000189670593`, 1.915707410443945}, {1.6752404735808355`, 
       1.8125000000000002`}, {1.5626550066464766`, 1.7697483574637451`}}], 
      PolygonBox[{{1.6752404735808355`, 1.8125000000000002`}, {
       1.7348349570550448`, 1.7348349570550448`}, {1.5626550066464766`, 
       1.7697483574637451`}, {1.6752404735808355`, 1.8125000000000002`}}], 
      PolygonBox[{{1.5950572556670028`, 1.5950572556670028`}, {
       1.5626550066464766`, 1.7697483574637451`}, {1.7348349570550448`, 
       1.7348349570550448`}, {1.5950572556670028`, 1.5950572556670028`}}], 
      PolygonBox[{{1.7348349570550448`, 1.7348349570550448`}, {
       1.8124999999999998`, 1.6752404735808355`}, {1.5950572556670028`, 
       1.5950572556670028`}, {1.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{1.769748357463745, 1.5626550066464766`}, {
       1.5950572556670028`, 1.5950572556670028`}, {1.8124999999999998`, 
       1.6752404735808355`}, {1.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{1.8124999999999998`, 1.6752404735808355`}, {
       1.9029428580865544`, 1.6377778151415994`}, {1.769748357463745, 
       1.5626550066464766`}, {1.8124999999999998`, 1.6752404735808355`}}], 
      PolygonBox[{{1.9157074104439358`, 1.5625000189670593`}, {
       1.769748357463745, 1.5626550066464766`}, {1.9029428580865544`, 
       1.6377778151415994`}, {1.9157074104439358`, 1.5625000189670593`}}], 
      PolygonBox[{{1.9029428580865544`, 1.6377778151415994`}, {2., 1.625}, {
       1.9157074104439358`, 1.5625000189670593`}, {1.9029428580865544`, 
       1.6377778151415994`}}], 
      PolygonBox[{{2.000134841831043, 1.5625}, {1.9157074104439358`, 
       1.5625000189670593`}, {2., 1.625}, {2.000134841831043, 1.5625}}], 
      PolygonBox[{{2., 1.625}, {2.097057141913445, 1.6377778151415994`}, {
       2.000134841831043, 1.5625}, {2., 1.625}}], 
      PolygonBox[{{2.0842925895560533`, 1.5625000189670593`}, {
       2.000134841831043, 1.5625}, {2.097057141913445, 1.6377778151415994`}, {
       2.0842925895560533`, 1.5625000189670593`}}], 
      PolygonBox[{{2.097057141913445, 1.6377778151415994`}, {
       2.1874999999999996`, 1.6752404735808355`}, {2.0842925895560533`, 
       1.5625000189670593`}, {2.097057141913445, 1.6377778151415994`}}], 
      PolygonBox[{{2.230251642536255, 1.5626550066464766`}, {
       2.0842925895560533`, 1.5625000189670593`}, {2.1874999999999996`, 
       1.6752404735808355`}, {2.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{2.1874999999999996`, 1.6752404735808355`}, {
       2.2651650429449552`, 1.7348349570550448`}, {2.230251642536255, 
       1.5626550066464766`}, {2.1874999999999996`, 1.6752404735808355`}}], 
      PolygonBox[{{2.404942744332997, 1.5950572556670028`}, {
       2.230251642536255, 1.5626550066464766`}, {2.2651650429449552`, 
       1.7348349570550448`}, {2.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{2.2651650429449552`, 1.7348349570550448`}, {
       2.2651650429449552`, 1.7348349570550448`}, {2.404942744332997, 
       1.5950572556670028`}, {2.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{2.404942744332997, 1.5950572556670028`}, {
       2.404942744332997, 1.5950572556670028`}, {2.2651650429449552`, 
       1.7348349570550448`}, {2.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{2.404942744332997, 1.5950572556670028`}, {
       2.4373449933535234`, 1.769748357463745}, {2.5, 1.5}, {
       2.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{2.5, 1.6423372173506323`}, {2.5, 1.5}, {
       2.4373449933535234`, 1.769748357463745}, {2.5, 1.6423372173506323`}}], 
      PolygonBox[{{2.4373449933535234`, 1.769748357463745}, {
       2.437499981032941, 1.9157074104439382`}, {2.5, 1.6423372173506323`}, {
       2.4373449933535234`, 1.769748357463745}}], 
      PolygonBox[{{2.5, 1.79409099469826}, {2.5, 1.6423372173506323`}, {
       2.437499981032941, 1.9157074104439382`}, {2.5, 1.79409099469826}}], 
      PolygonBox[{{2.437499981032941, 1.9157074104439382`}, {2.4375, 2.}, {
       2.5, 1.79409099469826}, {2.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{2.5, 2.}, {2.5, 1.79409099469826}, {2.4375, 2.}, {2.5, 
       2.}}], PolygonBox[{{2.4375, 2.}, {2.437499981032941, 
       2.084292589556062}, {2.5, 2.}, {2.4375, 2.}}], 
      PolygonBox[{{2.5, 2.20590900530174}, {2.5, 2.}, {2.437499981032941, 
       2.084292589556062}, {2.5, 2.20590900530174}}], 
      PolygonBox[{{2.437499981032941, 2.084292589556062}, {
       2.4373449933535234`, 2.230251642536255}, {2.5, 2.20590900530174}, {
       2.437499981032941, 2.084292589556062}}], 
      PolygonBox[{{2.5, 2.3576627826493675`}, {2.5, 2.20590900530174}, {
       2.4373449933535234`, 2.230251642536255}, {2.5, 2.3576627826493675`}}], 
      PolygonBox[{{2.4373449933535234`, 2.230251642536255}, {
       2.404942744332997, 2.404942744332997}, {2.5, 2.3576627826493675`}, {
       2.4373449933535234`, 2.230251642536255}}], 
      PolygonBox[{{2.491446564961186, 2.491446564961186}, {2.5, 
       2.3576627826493675`}, {2.404942744332997, 2.404942744332997}, {
       2.491446564961186, 2.491446564961186}}], 
      PolygonBox[{{2.404942744332997, 2.404942744332997}, {
       2.2302516425362553`, 2.4373449933535234`}, {2.491446564961186, 
       2.491446564961186}, {2.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{2.357662782649368, 2.5}, {2.491446564961186, 
       2.491446564961186}, {2.2302516425362553`, 2.4373449933535234`}, {
       2.357662782649368, 2.5}}], 
      PolygonBox[{{2.2302516425362553`, 2.4373449933535234`}, {
       2.0842925895560604`, 2.437499981032941}, {2.357662782649368, 2.5}, {
       2.2302516425362553`, 2.4373449933535234`}}], 
      PolygonBox[{{2.2059090053732557`, 2.5}, {2.357662782649368, 2.5}, {
       2.0842925895560604`, 2.437499981032941}, {2.2059090053732557`, 2.5}}], 
      PolygonBox[{{2.0842925895560604`, 2.437499981032941}, {
       2.0001055272204877`, 2.4375}, {2.2059090053732557`, 2.5}, {
       2.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{2.07794195802689, 2.5}, {2.2059090053732557`, 2.5}, {
       2.0001055272204877`, 2.4375}, {2.07794195802689, 2.5}}], 
      PolygonBox[{{2.0001055272204877`, 2.4375}, {1.915707410443943, 
       2.437499981032941}, {2.07794195802689, 2.5}, {2.0001055272204877`, 
       2.4375}}], 
      PolygonBox[{{1.7940909946955543`, 2.5}, {2.07794195802689, 2.5}, {
       1.915707410443943, 2.437499981032941}, {1.7940909946955543`, 2.5}}], 
      PolygonBox[{{1.915707410443943, 2.437499981032941}, {1.769748357463745, 
       2.4373449933535234`}, {1.7940909946955543`, 2.5}, {1.915707410443943, 
       2.437499981032941}}], 
      PolygonBox[{{1.6423372173506339`, 2.5}, {1.7940909946955543`, 2.5}, {
       1.769748357463745, 2.4373449933535234`}, {1.6423372173506339`, 2.5}}], 
      PolygonBox[{{1.769748357463745, 2.4373449933535234`}, {
       1.5950572556670028`, 2.404942744332997}, {1.6423372173506339`, 2.5}, {
       1.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{2.5, 2.5}, {1.6423372173506339`, 2.5}, {
       1.5950572556670028`, 2.404942744332997}, {2.5, 2.5}}], 
      PolygonBox[{{1.5950572556670028`, 2.404942744332997}, {
       1.5626550066464766`, 2.2302516425362553`}, {2.5, 2.5}, {
       1.5950572556670028`, 2.404942744332997}}], 
      PolygonBox[{{1.5, 2.357662782649369}, {2.5, 2.5}, {1.5626550066464766`, 
       2.2302516425362553`}, {1.5, 2.357662782649369}}], 
      PolygonBox[{{1.5626550066464766`, 2.2302516425362553`}, {
       1.5625000189670593`, 2.0842925895560622`}, {1.5, 2.357662782649369}, {
       1.5626550066464766`, 2.2302516425362553`}}], 
      PolygonBox[{{1.5, 2.205909005282899}, {1.5, 2.357662782649369}, {
       1.5625000189670593`, 2.0842925895560622`}, {1.5, 2.205909005282899}}], 
      PolygonBox[{{1.5625000189670593`, 2.0842925895560622`}, {1.5625, 
       2.0001231780629953`}, {1.5, 2.205909005282899}, {1.5625000189670593`, 
       2.0842925895560622`}}], 
      PolygonBox[{{1.5, 2.0806786667587}, {1.5, 2.205909005282899}, {1.5625, 
       2.0001231780629953`}, {1.5, 2.0806786667587}}], 
      PolygonBox[{{1.5625, 2.0001231780629953`}, {1.5625000189670593`, 
       1.915707410443945}, {1.5, 2.0806786667587}, {1.5625, 
       2.0001231780629953`}}], 
      PolygonBox[{{1.5, 1.7940909948547215`}, {1.5, 2.0806786667587}, {
       1.5625000189670593`, 1.915707410443945}, {1.5, 1.7940909948547215`}}], 
      PolygonBox[{{1.5625000189670593`, 1.915707410443945}, {
       1.5626550066464766`, 1.7697483574637451`}, {1.5, 
       1.7940909948547215`}, {1.5625000189670593`, 1.915707410443945}}], 
      PolygonBox[{{1.5, 1.6423372173506348`}, {1.5, 1.7940909948547215`}, {
       1.5626550066464766`, 1.7697483574637451`}, {1.5, 
       1.6423372173506348`}}], 
      PolygonBox[{{1.5626550066464766`, 1.7697483574637451`}, {
       1.5950572556670028`, 1.5950572556670028`}, {1.5, 
       1.6423372173506348`}, {1.5626550066464766`, 1.7697483574637451`}}], 
      PolygonBox[{{1.5, 2.5}, {1.5, 1.6423372173506348`}, {
       1.5950572556670028`, 1.5950572556670028`}, {1.5, 2.5}}], 
      PolygonBox[{{1.5950572556670028`, 1.5950572556670028`}, {
       1.769748357463745, 1.5626550066464766`}, {1.5, 2.5}, {
       1.5950572556670028`, 1.5950572556670028`}}], 
      PolygonBox[{{1.5, 1.5}, {1.5, 2.5}, {1.769748357463745, 
       1.5626550066464766`}, {1.5, 1.5}}], 
      PolygonBox[{{1.769748357463745, 1.5626550066464766`}, {
       1.9157074104439358`, 1.5625000189670593`}, {1.5, 1.5}, {
       1.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{1.794090994433172, 1.5}, {1.5, 1.5}, {1.9157074104439358`, 
       1.5625000189670593`}, {1.794090994433172, 1.5}}], 
      PolygonBox[{{1.9157074104439358`, 1.5625000189670593`}, {
       2.000134841831043, 1.5625}, {1.794090994433172, 1.5}, {
       1.9157074104439358`, 1.5625000189670593`}}], 
      PolygonBox[{{2.0823238704010616`, 1.5}, {1.794090994433172, 1.5}, {
       2.000134841831043, 1.5625}, {2.0823238704010616`, 1.5}}], 
      PolygonBox[{{2.000134841831043, 1.5625}, {2.0842925895560533`, 
       1.5625000189670593`}, {2.0823238704010616`, 1.5}, {2.000134841831043, 
       1.5625}}], 
      PolygonBox[{{2.2059090053603976`, 1.5}, {2.0823238704010616`, 1.5}, {
       2.0842925895560533`, 1.5625000189670593`}, {2.2059090053603976`, 
       1.5}}], PolygonBox[{{2.0842925895560533`, 1.5625000189670593`}, {
       2.230251642536255, 1.5626550066464766`}, {2.2059090053603976`, 1.5}, {
       2.0842925895560533`, 1.5625000189670593`}}], 
      PolygonBox[{{2.357662782649371, 1.5}, {2.2059090053603976`, 1.5}, {
       2.230251642536255, 1.5626550066464766`}, {2.357662782649371, 1.5}}], 
      PolygonBox[{{2.230251642536255, 1.5626550066464766`}, {
       2.404942744332997, 1.5950572556670028`}, {2.357662782649371, 1.5}, {
       2.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{2.5, 1.5}, {2.357662782649371, 1.5}, {2.404942744332997, 
       1.5950572556670028`}, {2.5, 1.5}}], 
      PolygonBox[{{2.404942744332997, 1.5950572556670028`}, {
       2.404942744332997, 1.5950572556670028`}, {2.5, 1.5}, {
       2.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{2.5, 1.5}, {2.5, 1.5}, {2.404942744332997, 
       1.5950572556670028`}, {2.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, 3.}, {1.5208333333333333`, 3.}, {1.5416666666666667`, 
       3.}, {1.5625, 3.}, {1.5833333333333333`, 3.}, {1.6041666666666665`, 
       3.}, {1.625, 3.}, {1.625, 3.}, {1.6041666666666667`, 3.}, {
       1.5833333333333333`, 3.}, {1.5625, 3.}, {1.5416666666666667`, 3.}, {
       1.5208333333333335`, 3.}, {1.5, 3.}, {1.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, 3.}, {2.3958333333333335`, 3.}, {2.4166666666666665`, 
       3.}, {2.4375, 3.}, {2.4583333333333335`, 3.}, {2.4791666666666665`, 
       3.}, {2.5, 3.}, {2.5, 3.}, {2.4791666666666665`, 3.}, {
       2.4583333333333335`, 3.}, {2.4375, 3.}, {2.4166666666666665`, 3.}, {
       2.3958333333333335`, 3.}, {2.375, 3.}, {2.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 2.5}, {2., 2.5208333333333335`}, {2., 
       2.5416666666666665`}, {2., 2.5625}, {2., 2.5833333333333335`}, {2., 
       2.6041666666666665`}, {2., 2.625}, {2., 2.625}, {2., 
       2.6041666666666665`}, {2., 2.5833333333333335`}, {2., 2.5625}, {2., 
       2.5416666666666665`}, {2., 2.5208333333333335`}, {2., 2.5}, {2., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 3.375}, {2., 3.3958333333333335`}, {2., 
       3.4166666666666665`}, {2., 3.4375}, {2., 3.4583333333333335`}, {2., 
       3.4791666666666665`}, {2., 3.5}, {2., 3.5}, {2., 
       3.4791666666666665`}, {2., 3.4583333333333335`}, {2., 3.4375}, {2., 
       3.4166666666666665`}, {2., 3.3958333333333335`}, {2., 3.375}, {2., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, 3.}, {1.75, 3.}, {1.875, 3.}, {2., 3.}, {2.125, 3.}, {
       2.25, 3.}, {2.375, 3.}, {2.375, 3.}, {2.25, 3.}, {2.125, 3.}, {2., 
       3.}, {1.875, 3.}, {1.75, 3.}, {1.625, 3.}, {1.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 2.625}, {2., 2.75}, {2., 2.875}, {2., 3.}, {2., 3.125}, {
       2., 3.25}, {2., 3.375}, {2., 3.375}, {2., 3.25}, {2., 3.125}, {2., 
       3.}, {2., 2.875}, {2., 2.75}, {2., 2.625}, {2., 2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhCaw+HVxXX7rjxlcvB/IvT06DEOBwP3E63S
M5kg8g2cDrPfzr7JJ88Epbmg4oxQdVxQfQxQc6DyDAxQmtsh2fyWaUnRP3tU
+b/2MP2nVE74PDr42x5m/oLC/C8nzv6yh9mvE7OoKczklz3MfRD9UHmg+2Hy
m6TfSllZsqPpZ3M4CTU/VShF7eMDVof/YPDH/sIO86onaawOiVD3iekFOmpL
saK5n9XBD+o/mDxYez2jA0w/LHxg5qOGHxs8fDdC3Yce/gDnioz2
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhCax2H1KhBggvNDwYARzodqgPPDwPJ/7VH1
/7JHVf+DIB+ijwvOh9jLiaaeA009G5wPcQcrmnoWDP4qFPexQP33F009zH8s
aP6H6WdyQFVPmA5FcR+LA6r7Yeo40NRzwvmrUMIHEV8ARiNNQA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, 2.7348349570550448`}, {
       2.3247595264191645`, 2.8125}, {2.404942744332997, 2.595057255667003}, {
       2.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{2.4373449933535234`, 2.7697483574637447`}, {
       2.404942744332997, 2.595057255667003}, {2.3247595264191645`, 2.8125}, {
       2.4373449933535234`, 2.7697483574637447`}}], 
      PolygonBox[{{2.3247595264191645`, 2.8125}, {2.3622221848584006`, 
       2.9029428580865546`}, {2.4373449933535234`, 2.7697483574637447`}, {
       2.3247595264191645`, 2.8125}}], 
      PolygonBox[{{2.437499981032941, 2.915707410443938}, {
       2.4373449933535234`, 2.7697483574637447`}, {2.3622221848584006`, 
       2.9029428580865546`}, {2.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{2.3622221848584006`, 2.9029428580865546`}, {2.375, 3.}, {
       2.437499981032941, 2.915707410443938}, {2.3622221848584006`, 
       2.9029428580865546`}}], 
      PolygonBox[{{2.4375, 3.}, {2.437499981032941, 2.915707410443938}, {
       2.375, 3.}, {2.4375, 3.}}], 
      PolygonBox[{{2.375, 3.}, {2.3622221848584006`, 3.0970571419134454`}, {
       2.4375, 3.}, {2.375, 3.}}], 
      PolygonBox[{{2.437499981032941, 3.084292589556062}, {2.4375, 3.}, {
       2.3622221848584006`, 3.0970571419134454`}, {2.437499981032941, 
       3.084292589556062}}], 
      PolygonBox[{{2.3622221848584006`, 3.0970571419134454`}, {
       2.3247595264191645`, 3.1875}, {2.437499981032941, 3.084292589556062}, {
       2.3622221848584006`, 3.0970571419134454`}}], 
      PolygonBox[{{2.4373449933535234`, 3.230251642536255}, {
       2.437499981032941, 3.084292589556062}, {2.3247595264191645`, 3.1875}, {
       2.4373449933535234`, 3.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, 3.1875}, {2.2651650429449552`, 
       3.2651650429449552`}, {2.4373449933535234`, 3.230251642536255}, {
       2.3247595264191645`, 3.1875}}], 
      PolygonBox[{{2.404942744332997, 3.404942744332997}, {
       2.4373449933535234`, 3.230251642536255}, {2.2651650429449552`, 
       3.2651650429449552`}, {2.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, 3.2651650429449552`}, {2.1875, 
       3.3247595264191645`}, {2.404942744332997, 3.404942744332997}, {
       2.2651650429449552`, 3.2651650429449552`}}], 
      PolygonBox[{{2.2302516425362553`, 3.4373449933535234`}, {
       2.404942744332997, 3.404942744332997}, {2.1875, 3.3247595264191645`}, {
       2.2302516425362553`, 3.4373449933535234`}}], 
      PolygonBox[{{2.1875, 3.3247595264191645`}, {2.0970571419134454`, 
       3.3622221848584006`}, {2.2302516425362553`, 3.4373449933535234`}, {
       2.1875, 3.3247595264191645`}}], 
      PolygonBox[{{2.0842925895560604`, 3.437499981032941}, {
       2.2302516425362553`, 3.4373449933535234`}, {2.0970571419134454`, 
       3.3622221848584006`}, {2.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{2.0970571419134454`, 3.3622221848584006`}, {2., 3.375}, {
       2.0842925895560604`, 3.437499981032941}, {2.0970571419134454`, 
       3.3622221848584006`}}], 
      PolygonBox[{{2.0001055272204877`, 3.4375}, {2.0842925895560604`, 
       3.437499981032941}, {2., 3.375}, {2.0001055272204877`, 3.4375}}], 
      PolygonBox[{{2., 3.375}, {1.9029428580865548`, 3.3622221848584006`}, {
       2.0001055272204877`, 3.4375}, {2., 3.375}}], 
      PolygonBox[{{1.915707410443943, 3.437499981032941}, {
       2.0001055272204877`, 3.4375}, {1.9029428580865548`, 
       3.3622221848584006`}, {1.915707410443943, 3.437499981032941}}], 
      PolygonBox[{{1.9029428580865548`, 3.3622221848584006`}, {1.8125, 
       3.3247595264191645`}, {1.915707410443943, 3.437499981032941}, {
       1.9029428580865548`, 3.3622221848584006`}}], 
      PolygonBox[{{1.769748357463745, 3.4373449933535234`}, {
       1.915707410443943, 3.437499981032941}, {1.8125, 3.3247595264191645`}, {
       1.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{1.8125, 3.3247595264191645`}, {1.7348349570550448`, 
       3.2651650429449552`}, {1.769748357463745, 3.4373449933535234`}, {
       1.8125, 3.3247595264191645`}}], 
      PolygonBox[{{1.5950572556670028`, 3.404942744332997}, {
       1.769748357463745, 3.4373449933535234`}, {1.7348349570550448`, 
       3.2651650429449552`}, {1.5950572556670028`, 3.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, 3.2651650429449552`}, {
       1.6752404735808355`, 3.1875}, {1.5950572556670028`, 
       3.404942744332997}, {1.7348349570550448`, 3.2651650429449552`}}], 
      PolygonBox[{{1.5626550066464766`, 3.2302516425362553`}, {
       1.5950572556670028`, 3.404942744332997}, {1.6752404735808355`, 
       3.1875}, {1.5626550066464766`, 3.2302516425362553`}}], 
      PolygonBox[{{1.6752404735808355`, 3.1875}, {1.6377778151415994`, 
       3.0970571419134454`}, {1.5626550066464766`, 3.2302516425362553`}, {
       1.6752404735808355`, 3.1875}}], 
      PolygonBox[{{1.5625000189670593`, 3.0842925895560622`}, {
       1.5626550066464766`, 3.2302516425362553`}, {1.6377778151415994`, 
       3.0970571419134454`}, {1.5625000189670593`, 3.0842925895560622`}}], 
      PolygonBox[{{1.6377778151415994`, 3.0970571419134454`}, {1.625, 3.}, {
       1.5625000189670593`, 3.0842925895560622`}, {1.6377778151415994`, 
       3.0970571419134454`}}], 
      PolygonBox[{{1.5625, 3.0001231780629953`}, {1.5625000189670593`, 
       3.0842925895560622`}, {1.625, 3.}, {1.5625, 3.0001231780629953`}}], 
      PolygonBox[{{1.625, 3.}, {1.6377778151415994`, 2.902942858086555}, {
       1.5625, 3.0001231780629953`}, {1.625, 3.}}], 
      PolygonBox[{{1.5625000189670593`, 2.915707410443945}, {1.5625, 
       3.0001231780629953`}, {1.6377778151415994`, 2.902942858086555}, {
       1.5625000189670593`, 2.915707410443945}}], 
      PolygonBox[{{1.6377778151415994`, 2.902942858086555}, {
       1.6752404735808355`, 2.8125}, {1.5625000189670593`, 
       2.915707410443945}, {1.6377778151415994`, 2.902942858086555}}], 
      PolygonBox[{{1.5626550066464766`, 2.769748357463745}, {
       1.5625000189670593`, 2.915707410443945}, {1.6752404735808355`, 
       2.8125}, {1.5626550066464766`, 2.769748357463745}}], 
      PolygonBox[{{1.6752404735808355`, 2.8125}, {1.7348349570550448`, 
       2.7348349570550448`}, {1.5626550066464766`, 2.769748357463745}, {
       1.6752404735808355`, 2.8125}}], 
      PolygonBox[{{1.5950572556670028`, 2.595057255667003}, {
       1.5626550066464766`, 2.769748357463745}, {1.7348349570550448`, 
       2.7348349570550448`}, {1.5950572556670028`, 2.595057255667003}}], 
      PolygonBox[{{1.7348349570550448`, 2.7348349570550448`}, {
       1.8124999999999998`, 2.6752404735808355`}, {1.5950572556670028`, 
       2.595057255667003}, {1.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{1.769748357463745, 2.5626550066464766`}, {
       1.5950572556670028`, 2.595057255667003}, {1.8124999999999998`, 
       2.6752404735808355`}, {1.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{1.8124999999999998`, 2.6752404735808355`}, {
       1.9029428580865544`, 2.6377778151415994`}, {1.769748357463745, 
       2.5626550066464766`}, {1.8124999999999998`, 2.6752404735808355`}}], 
      PolygonBox[{{1.9157074104439358`, 2.562500018967059}, {
       1.769748357463745, 2.5626550066464766`}, {1.9029428580865544`, 
       2.6377778151415994`}, {1.9157074104439358`, 2.562500018967059}}], 
      PolygonBox[{{1.9029428580865544`, 2.6377778151415994`}, {2., 2.625}, {
       1.9157074104439358`, 2.562500018967059}, {1.9029428580865544`, 
       2.6377778151415994`}}], 
      PolygonBox[{{2.000134841831043, 2.5625}, {1.9157074104439358`, 
       2.562500018967059}, {2., 2.625}, {2.000134841831043, 2.5625}}], 
      PolygonBox[{{2., 2.625}, {2.097057141913445, 2.6377778151415994`}, {
       2.000134841831043, 2.5625}, {2., 2.625}}], 
      PolygonBox[{{2.0842925895560533`, 2.562500018967059}, {
       2.000134841831043, 2.5625}, {2.097057141913445, 2.6377778151415994`}, {
       2.0842925895560533`, 2.562500018967059}}], 
      PolygonBox[{{2.097057141913445, 2.6377778151415994`}, {
       2.1874999999999996`, 2.6752404735808355`}, {2.0842925895560533`, 
       2.562500018967059}, {2.097057141913445, 2.6377778151415994`}}], 
      PolygonBox[{{2.230251642536255, 2.5626550066464766`}, {
       2.0842925895560533`, 2.562500018967059}, {2.1874999999999996`, 
       2.6752404735808355`}, {2.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{2.1874999999999996`, 2.6752404735808355`}, {
       2.2651650429449552`, 2.7348349570550448`}, {2.230251642536255, 
       2.5626550066464766`}, {2.1874999999999996`, 2.6752404735808355`}}], 
      PolygonBox[{{2.404942744332997, 2.595057255667003}, {2.230251642536255, 
       2.5626550066464766`}, {2.2651650429449552`, 2.7348349570550448`}, {
       2.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{2.2651650429449552`, 2.7348349570550448`}, {
       2.2651650429449552`, 2.7348349570550448`}, {2.404942744332997, 
       2.595057255667003}, {2.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{2.404942744332997, 2.595057255667003}, {2.404942744332997, 
       2.595057255667003}, {2.2651650429449552`, 2.7348349570550448`}, {
       2.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{2.404942744332997, 2.595057255667003}, {
       2.4373449933535234`, 2.7697483574637447`}, {2.5, 2.5}, {
       2.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{2.5, 2.642337217350632}, {2.5, 2.5}, {2.4373449933535234`, 
       2.7697483574637447`}, {2.5, 2.642337217350632}}], 
      PolygonBox[{{2.4373449933535234`, 2.7697483574637447`}, {
       2.437499981032941, 2.915707410443938}, {2.5, 2.642337217350632}, {
       2.4373449933535234`, 2.7697483574637447`}}], 
      PolygonBox[{{2.5, 2.79409099469826}, {2.5, 2.642337217350632}, {
       2.437499981032941, 2.915707410443938}, {2.5, 2.79409099469826}}], 
      PolygonBox[{{2.437499981032941, 2.915707410443938}, {2.4375, 3.}, {2.5, 
       2.79409099469826}, {2.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{2.5, 3.}, {2.5, 2.79409099469826}, {2.4375, 3.}, {2.5, 3.}}
       ], 
      PolygonBox[{{2.4375, 3.}, {2.437499981032941, 3.084292589556062}, {2.5, 
       3.}, {2.4375, 3.}}], 
      PolygonBox[{{2.5, 3.20590900530174}, {2.5, 3.}, {2.437499981032941, 
       3.084292589556062}, {2.5, 3.20590900530174}}], 
      PolygonBox[{{2.437499981032941, 3.084292589556062}, {
       2.4373449933535234`, 3.230251642536255}, {2.5, 3.20590900530174}, {
       2.437499981032941, 3.084292589556062}}], 
      PolygonBox[{{2.5, 3.3576627826493675`}, {2.5, 3.20590900530174}, {
       2.4373449933535234`, 3.230251642536255}, {2.5, 3.3576627826493675`}}], 
      PolygonBox[{{2.4373449933535234`, 3.230251642536255}, {
       2.404942744332997, 3.404942744332997}, {2.5, 3.3576627826493675`}, {
       2.4373449933535234`, 3.230251642536255}}], 
      PolygonBox[{{2.491446564961186, 3.491446564961186}, {2.5, 
       3.3576627826493675`}, {2.404942744332997, 3.404942744332997}, {
       2.491446564961186, 3.491446564961186}}], 
      PolygonBox[{{2.404942744332997, 3.404942744332997}, {
       2.2302516425362553`, 3.4373449933535234`}, {2.491446564961186, 
       3.491446564961186}, {2.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{2.357662782649368, 3.5}, {2.491446564961186, 
       3.491446564961186}, {2.2302516425362553`, 3.4373449933535234`}, {
       2.357662782649368, 3.5}}], 
      PolygonBox[{{2.2302516425362553`, 3.4373449933535234`}, {
       2.0842925895560604`, 3.437499981032941}, {2.357662782649368, 3.5}, {
       2.2302516425362553`, 3.4373449933535234`}}], 
      PolygonBox[{{2.2059090053732557`, 3.5}, {2.357662782649368, 3.5}, {
       2.0842925895560604`, 3.437499981032941}, {2.2059090053732557`, 3.5}}], 
      PolygonBox[{{2.0842925895560604`, 3.437499981032941}, {
       2.0001055272204877`, 3.4375}, {2.2059090053732557`, 3.5}, {
       2.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{2.07794195802689, 3.5}, {2.2059090053732557`, 3.5}, {
       2.0001055272204877`, 3.4375}, {2.07794195802689, 3.5}}], 
      PolygonBox[{{2.0001055272204877`, 3.4375}, {1.915707410443943, 
       3.437499981032941}, {2.07794195802689, 3.5}, {2.0001055272204877`, 
       3.4375}}], 
      PolygonBox[{{1.7940909946955543`, 3.5}, {2.07794195802689, 3.5}, {
       1.915707410443943, 3.437499981032941}, {1.7940909946955543`, 3.5}}], 
      PolygonBox[{{1.915707410443943, 3.437499981032941}, {1.769748357463745, 
       3.4373449933535234`}, {1.7940909946955543`, 3.5}, {1.915707410443943, 
       3.437499981032941}}], 
      PolygonBox[{{1.6423372173506339`, 3.5}, {1.7940909946955543`, 3.5}, {
       1.769748357463745, 3.4373449933535234`}, {1.6423372173506339`, 3.5}}], 
      PolygonBox[{{1.769748357463745, 3.4373449933535234`}, {
       1.5950572556670028`, 3.404942744332997}, {1.6423372173506339`, 3.5}, {
       1.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{2.5, 3.5}, {1.6423372173506339`, 3.5}, {
       1.5950572556670028`, 3.404942744332997}, {2.5, 3.5}}], 
      PolygonBox[{{1.5950572556670028`, 3.404942744332997}, {
       1.5626550066464766`, 3.2302516425362553`}, {2.5, 3.5}, {
       1.5950572556670028`, 3.404942744332997}}], 
      PolygonBox[{{1.5, 3.357662782649369}, {2.5, 3.5}, {1.5626550066464766`, 
       3.2302516425362553`}, {1.5, 3.357662782649369}}], 
      PolygonBox[{{1.5626550066464766`, 3.2302516425362553`}, {
       1.5625000189670593`, 3.0842925895560622`}, {1.5, 3.357662782649369}, {
       1.5626550066464766`, 3.2302516425362553`}}], 
      PolygonBox[{{1.5, 3.205909005282899}, {1.5, 3.357662782649369}, {
       1.5625000189670593`, 3.0842925895560622`}, {1.5, 3.205909005282899}}], 
      PolygonBox[{{1.5625000189670593`, 3.0842925895560622`}, {1.5625, 
       3.0001231780629953`}, {1.5, 3.205909005282899}, {1.5625000189670593`, 
       3.0842925895560622`}}], 
      PolygonBox[{{1.5, 3.0806786667587}, {1.5, 3.205909005282899}, {1.5625, 
       3.0001231780629953`}, {1.5, 3.0806786667587}}], 
      PolygonBox[{{1.5625, 3.0001231780629953`}, {1.5625000189670593`, 
       2.915707410443945}, {1.5, 3.0806786667587}, {1.5625, 
       3.0001231780629953`}}], 
      PolygonBox[{{1.5, 2.7940909948547215`}, {1.5, 3.0806786667587}, {
       1.5625000189670593`, 2.915707410443945}, {1.5, 2.7940909948547215`}}], 
      PolygonBox[{{1.5625000189670593`, 2.915707410443945}, {
       1.5626550066464766`, 2.769748357463745}, {1.5, 2.7940909948547215`}, {
       1.5625000189670593`, 2.915707410443945}}], 
      PolygonBox[{{1.5, 2.6423372173506348`}, {1.5, 2.7940909948547215`}, {
       1.5626550066464766`, 2.769748357463745}, {1.5, 2.6423372173506348`}}], 
      PolygonBox[{{1.5626550066464766`, 2.769748357463745}, {
       1.5950572556670028`, 2.595057255667003}, {1.5, 2.6423372173506348`}, {
       1.5626550066464766`, 2.769748357463745}}], 
      PolygonBox[{{1.5, 3.5}, {1.5, 2.6423372173506348`}, {
       1.5950572556670028`, 2.595057255667003}, {1.5, 3.5}}], 
      PolygonBox[{{1.5950572556670028`, 2.595057255667003}, {
       1.769748357463745, 2.5626550066464766`}, {1.5, 3.5}, {
       1.5950572556670028`, 2.595057255667003}}], 
      PolygonBox[{{1.5, 2.5}, {1.5, 3.5}, {1.769748357463745, 
       2.5626550066464766`}, {1.5, 2.5}}], 
      PolygonBox[{{1.769748357463745, 2.5626550066464766`}, {
       1.9157074104439358`, 2.562500018967059}, {1.5, 2.5}, {
       1.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{1.794090994433172, 2.5}, {1.5, 2.5}, {1.9157074104439358`, 
       2.562500018967059}, {1.794090994433172, 2.5}}], 
      PolygonBox[{{1.9157074104439358`, 2.562500018967059}, {
       2.000134841831043, 2.5625}, {1.794090994433172, 2.5}, {
       1.9157074104439358`, 2.562500018967059}}], 
      PolygonBox[{{2.0823238704010616`, 2.5}, {1.794090994433172, 2.5}, {
       2.000134841831043, 2.5625}, {2.0823238704010616`, 2.5}}], 
      PolygonBox[{{2.000134841831043, 2.5625}, {2.0842925895560533`, 
       2.562500018967059}, {2.0823238704010616`, 2.5}, {2.000134841831043, 
       2.5625}}], 
      PolygonBox[{{2.2059090053603976`, 2.5}, {2.0823238704010616`, 2.5}, {
       2.0842925895560533`, 2.562500018967059}, {2.2059090053603976`, 2.5}}], 
      PolygonBox[{{2.0842925895560533`, 2.562500018967059}, {
       2.230251642536255, 2.5626550066464766`}, {2.2059090053603976`, 2.5}, {
       2.0842925895560533`, 2.562500018967059}}], 
      PolygonBox[{{2.357662782649371, 2.5}, {2.2059090053603976`, 2.5}, {
       2.230251642536255, 2.5626550066464766`}, {2.357662782649371, 2.5}}], 
      PolygonBox[{{2.230251642536255, 2.5626550066464766`}, {
       2.404942744332997, 2.595057255667003}, {2.357662782649371, 2.5}, {
       2.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{2.5, 2.5}, {2.357662782649371, 2.5}, {2.404942744332997, 
       2.595057255667003}, {2.5, 2.5}}], 
      PolygonBox[{{2.404942744332997, 2.595057255667003}, {2.404942744332997, 
       2.595057255667003}, {2.5, 2.5}, {2.404942744332997, 
       2.595057255667003}}], 
      PolygonBox[{{2.5, 2.5}, {2.5, 2.5}, {2.404942744332997, 
       2.595057255667003}, {2.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, 4.}, {1.5208333333333333`, 4.}, {1.5416666666666667`, 
       4.}, {1.5625, 4.}, {1.5833333333333333`, 4.}, {1.6041666666666665`, 
       4.}, {1.625, 4.}, {1.625, 4.}, {1.6041666666666667`, 4.}, {
       1.5833333333333333`, 4.}, {1.5625, 4.}, {1.5416666666666667`, 4.}, {
       1.5208333333333335`, 4.}, {1.5, 4.}, {1.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, 4.}, {2.3958333333333335`, 4.}, {2.4166666666666665`, 
       4.}, {2.4375, 4.}, {2.4583333333333335`, 4.}, {2.4791666666666665`, 
       4.}, {2.5, 4.}, {2.5, 4.}, {2.4791666666666665`, 4.}, {
       2.4583333333333335`, 4.}, {2.4375, 4.}, {2.4166666666666665`, 4.}, {
       2.3958333333333335`, 4.}, {2.375, 4.}, {2.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 3.5}, {2., 3.5208333333333335`}, {2., 
       3.5416666666666665`}, {2., 3.5625}, {2., 3.5833333333333335`}, {2., 
       3.6041666666666665`}, {2., 3.625}, {2., 3.625}, {2., 
       3.6041666666666665`}, {2., 3.5833333333333335`}, {2., 3.5625}, {2., 
       3.5416666666666665`}, {2., 3.5208333333333335`}, {2., 3.5}, {2., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 4.375}, {2., 4.395833333333333}, {2., 
       4.416666666666667}, {2., 4.4375}, {2., 4.458333333333333}, {2., 
       4.479166666666667}, {2., 4.5}, {2., 4.5}, {2., 4.479166666666667}, {2.,
        4.458333333333333}, {2., 4.4375}, {2., 4.416666666666667}, {2., 
       4.395833333333333}, {2., 4.375}, {2., 4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, 4.}, {1.75, 4.}, {1.875, 4.}, {2., 4.}, {2.125, 4.}, {
       2.25, 4.}, {2.375, 4.}, {2.375, 4.}, {2.25, 4.}, {2.125, 4.}, {2., 
       4.}, {1.875, 4.}, {1.75, 4.}, {1.625, 4.}, {1.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 3.625}, {2., 3.75}, {2., 3.875}, {2., 4.}, {2., 4.125}, {
       2., 4.25}, {2., 4.375}, {2., 4.375}, {2., 4.25}, {2., 4.125}, {2., 
       4.}, {2., 3.875}, {2., 3.75}, {2., 3.625}, {2., 3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhBawOHVxXX7rjxlclAv6vyUlCzgYOB+olV6
JhNE/oCAw+y3s2/yyTM5nPt2NqedXxAi3sDoMEP5yaFeH0EH/ydCT48eY3D4
mhEe/6oIKs/AAFUn6JBsfsu0pOifPar8X3uY/lMqJ3weHfxtDzN/QWH+lxNn
f9nD7NeJWdQUZvLLXgPqPoh+qDwDQn6T9FspK0t+VP0NfA4noeanCqWofXzA
6/AfDP7YX9hhXvUkjdchEeo+Mb1AR20pXlT3M/A6+EH9B5MHa69ndIDph4UP
zHyU8APaDwvfjVD3oYc/AAWcjHM=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhBayGH1KhBggvNDwYARzodqgPPDwPJ/7VH1
/7JHVf+DIB9ijyCcDzFHAE29AJo8H5wPcQcvmnoeDP4qFPfxQP33F009zH88
aP6H6WdyQFXPQpAfiuI+FgdU98PUC6DJC6DpF0RTL+QAAOrPTgs=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, 3.7348349570550448`}, {
       2.3247595264191645`, 3.8125}, {2.404942744332997, 3.595057255667003}, {
       2.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{2.4373449933535234`, 3.7697483574637447`}, {
       2.404942744332997, 3.595057255667003}, {2.3247595264191645`, 3.8125}, {
       2.4373449933535234`, 3.7697483574637447`}}], 
      PolygonBox[{{2.3247595264191645`, 3.8125}, {2.3622221848584006`, 
       3.9029428580865546`}, {2.4373449933535234`, 3.7697483574637447`}, {
       2.3247595264191645`, 3.8125}}], 
      PolygonBox[{{2.437499981032941, 3.915707410443938}, {
       2.4373449933535234`, 3.7697483574637447`}, {2.3622221848584006`, 
       3.9029428580865546`}, {2.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{2.3622221848584006`, 3.9029428580865546`}, {2.375, 4.}, {
       2.437499981032941, 3.915707410443938}, {2.3622221848584006`, 
       3.9029428580865546`}}], 
      PolygonBox[{{2.4375, 4.}, {2.437499981032941, 3.915707410443938}, {
       2.375, 4.}, {2.4375, 4.}}], 
      PolygonBox[{{2.375, 4.}, {2.3622221848584006`, 4.097057141913445}, {
       2.4375, 4.}, {2.375, 4.}}], 
      PolygonBox[{{2.437499981032941, 4.084292589556061}, {2.4375, 4.}, {
       2.3622221848584006`, 4.097057141913445}, {2.437499981032941, 
       4.084292589556061}}], 
      PolygonBox[{{2.3622221848584006`, 4.097057141913445}, {
       2.3247595264191645`, 4.1875}, {2.437499981032941, 4.084292589556061}, {
       2.3622221848584006`, 4.097057141913445}}], 
      PolygonBox[{{2.4373449933535234`, 4.230251642536255}, {
       2.437499981032941, 4.084292589556061}, {2.3247595264191645`, 4.1875}, {
       2.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, 4.1875}, {2.2651650429449552`, 
       4.265165042944956}, {2.4373449933535234`, 4.230251642536255}, {
       2.3247595264191645`, 4.1875}}], 
      PolygonBox[{{2.404942744332997, 4.404942744332997}, {
       2.4373449933535234`, 4.230251642536255}, {2.2651650429449552`, 
       4.265165042944956}, {2.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, 4.265165042944956}, {2.1875, 
       4.3247595264191645`}, {2.404942744332997, 4.404942744332997}, {
       2.2651650429449552`, 4.265165042944956}}], 
      PolygonBox[{{2.2302516425362553`, 4.437344993353523}, {
       2.404942744332997, 4.404942744332997}, {2.1875, 4.3247595264191645`}, {
       2.2302516425362553`, 4.437344993353523}}], 
      PolygonBox[{{2.1875, 4.3247595264191645`}, {2.0970571419134454`, 
       4.362222184858401}, {2.2302516425362553`, 4.437344993353523}, {2.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{2.0842925895560604`, 4.437499981032941}, {
       2.2302516425362553`, 4.437344993353523}, {2.0970571419134454`, 
       4.362222184858401}, {2.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{2.0970571419134454`, 4.362222184858401}, {2., 4.375}, {
       2.0842925895560604`, 4.437499981032941}, {2.0970571419134454`, 
       4.362222184858401}}], 
      PolygonBox[{{2.0001055272204877`, 4.4375}, {2.0842925895560604`, 
       4.437499981032941}, {2., 4.375}, {2.0001055272204877`, 4.4375}}], 
      PolygonBox[{{2., 4.375}, {1.9029428580865548`, 4.362222184858401}, {
       2.0001055272204877`, 4.4375}, {2., 4.375}}], 
      PolygonBox[{{1.915707410443943, 4.437499981032941}, {
       2.0001055272204877`, 4.4375}, {1.9029428580865548`, 
       4.362222184858401}, {1.915707410443943, 4.437499981032941}}], 
      PolygonBox[{{1.9029428580865548`, 4.362222184858401}, {1.8125, 
       4.3247595264191645`}, {1.915707410443943, 4.437499981032941}, {
       1.9029428580865548`, 4.362222184858401}}], 
      PolygonBox[{{1.769748357463745, 4.437344993353523}, {1.915707410443943, 
       4.437499981032941}, {1.8125, 4.3247595264191645`}, {1.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{1.8125, 4.3247595264191645`}, {1.7348349570550448`, 
       4.265165042944956}, {1.769748357463745, 4.437344993353523}, {1.8125, 
       4.3247595264191645`}}], 
      PolygonBox[{{1.5950572556670028`, 4.404942744332997}, {
       1.769748357463745, 4.437344993353523}, {1.7348349570550448`, 
       4.265165042944956}, {1.5950572556670028`, 4.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, 4.265165042944956}, {
       1.6752404735808355`, 4.1875}, {1.5950572556670028`, 
       4.404942744332997}, {1.7348349570550448`, 4.265165042944956}}], 
      PolygonBox[{{1.5626550066464766`, 4.230251642536255}, {
       1.5950572556670028`, 4.404942744332997}, {1.6752404735808355`, 
       4.1875}, {1.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{1.6752404735808355`, 4.1875}, {1.6377778151415994`, 
       4.097057141913446}, {1.5626550066464766`, 4.230251642536255}, {
       1.6752404735808355`, 4.1875}}], 
      PolygonBox[{{1.5625000189670593`, 4.084292589556062}, {
       1.5626550066464766`, 4.230251642536255}, {1.6377778151415994`, 
       4.097057141913446}, {1.5625000189670593`, 4.084292589556062}}], 
      PolygonBox[{{1.6377778151415994`, 4.097057141913446}, {1.625, 4.}, {
       1.5625000189670593`, 4.084292589556062}, {1.6377778151415994`, 
       4.097057141913446}}], 
      PolygonBox[{{1.5625, 4.000123178062996}, {1.5625000189670593`, 
       4.084292589556062}, {1.625, 4.}, {1.5625, 4.000123178062996}}], 
      PolygonBox[{{1.625, 4.}, {1.6377778151415994`, 3.902942858086555}, {
       1.5625, 4.000123178062996}, {1.625, 4.}}], 
      PolygonBox[{{1.5625000189670593`, 3.915707410443945}, {1.5625, 
       4.000123178062996}, {1.6377778151415994`, 3.902942858086555}, {
       1.5625000189670593`, 3.915707410443945}}], 
      PolygonBox[{{1.6377778151415994`, 3.902942858086555}, {
       1.6752404735808355`, 3.8125}, {1.5625000189670593`, 
       3.915707410443945}, {1.6377778151415994`, 3.902942858086555}}], 
      PolygonBox[{{1.5626550066464766`, 3.769748357463745}, {
       1.5625000189670593`, 3.915707410443945}, {1.6752404735808355`, 
       3.8125}, {1.5626550066464766`, 3.769748357463745}}], 
      PolygonBox[{{1.6752404735808355`, 3.8125}, {1.7348349570550448`, 
       3.7348349570550448`}, {1.5626550066464766`, 3.769748357463745}, {
       1.6752404735808355`, 3.8125}}], 
      PolygonBox[{{1.5950572556670028`, 3.595057255667003}, {
       1.5626550066464766`, 3.769748357463745}, {1.7348349570550448`, 
       3.7348349570550448`}, {1.5950572556670028`, 3.595057255667003}}], 
      PolygonBox[{{1.7348349570550448`, 3.7348349570550448`}, {
       1.8124999999999998`, 3.6752404735808355`}, {1.5950572556670028`, 
       3.595057255667003}, {1.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{1.769748357463745, 3.5626550066464766`}, {
       1.5950572556670028`, 3.595057255667003}, {1.8124999999999998`, 
       3.6752404735808355`}, {1.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{1.8124999999999998`, 3.6752404735808355`}, {
       1.9029428580865544`, 3.6377778151415994`}, {1.769748357463745, 
       3.5626550066464766`}, {1.8124999999999998`, 3.6752404735808355`}}], 
      PolygonBox[{{1.9157074104439358`, 3.562500018967059}, {
       1.769748357463745, 3.5626550066464766`}, {1.9029428580865544`, 
       3.6377778151415994`}, {1.9157074104439358`, 3.562500018967059}}], 
      PolygonBox[{{1.9029428580865544`, 3.6377778151415994`}, {2., 3.625}, {
       1.9157074104439358`, 3.562500018967059}, {1.9029428580865544`, 
       3.6377778151415994`}}], 
      PolygonBox[{{2.000134841831043, 3.5625}, {1.9157074104439358`, 
       3.562500018967059}, {2., 3.625}, {2.000134841831043, 3.5625}}], 
      PolygonBox[{{2., 3.625}, {2.097057141913445, 3.6377778151415994`}, {
       2.000134841831043, 3.5625}, {2., 3.625}}], 
      PolygonBox[{{2.0842925895560533`, 3.562500018967059}, {
       2.000134841831043, 3.5625}, {2.097057141913445, 3.6377778151415994`}, {
       2.0842925895560533`, 3.562500018967059}}], 
      PolygonBox[{{2.097057141913445, 3.6377778151415994`}, {
       2.1874999999999996`, 3.6752404735808355`}, {2.0842925895560533`, 
       3.562500018967059}, {2.097057141913445, 3.6377778151415994`}}], 
      PolygonBox[{{2.230251642536255, 3.5626550066464766`}, {
       2.0842925895560533`, 3.562500018967059}, {2.1874999999999996`, 
       3.6752404735808355`}, {2.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{2.1874999999999996`, 3.6752404735808355`}, {
       2.2651650429449552`, 3.7348349570550448`}, {2.230251642536255, 
       3.5626550066464766`}, {2.1874999999999996`, 3.6752404735808355`}}], 
      PolygonBox[{{2.404942744332997, 3.595057255667003}, {2.230251642536255, 
       3.5626550066464766`}, {2.2651650429449552`, 3.7348349570550448`}, {
       2.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{2.2651650429449552`, 3.7348349570550448`}, {
       2.2651650429449552`, 3.7348349570550448`}, {2.404942744332997, 
       3.595057255667003}, {2.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{2.404942744332997, 3.595057255667003}, {2.404942744332997, 
       3.595057255667003}, {2.2651650429449552`, 3.7348349570550448`}, {
       2.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{2.404942744332997, 3.595057255667003}, {
       2.4373449933535234`, 3.7697483574637447`}, {2.5, 3.5}, {
       2.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{2.5, 3.642337217350632}, {2.5, 3.5}, {2.4373449933535234`, 
       3.7697483574637447`}, {2.5, 3.642337217350632}}], 
      PolygonBox[{{2.4373449933535234`, 3.7697483574637447`}, {
       2.437499981032941, 3.915707410443938}, {2.5, 3.642337217350632}, {
       2.4373449933535234`, 3.7697483574637447`}}], 
      PolygonBox[{{2.5, 3.79409099469826}, {2.5, 3.642337217350632}, {
       2.437499981032941, 3.915707410443938}, {2.5, 3.79409099469826}}], 
      PolygonBox[{{2.437499981032941, 3.915707410443938}, {2.4375, 4.}, {2.5, 
       3.79409099469826}, {2.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{2.5, 4.}, {2.5, 3.79409099469826}, {2.4375, 4.}, {2.5, 
       4.}}], PolygonBox[{{2.4375, 4.}, {2.437499981032941, 
       4.084292589556061}, {2.5, 4.}, {2.4375, 4.}}], 
      PolygonBox[{{2.5, 4.20590900530174}, {2.5, 4.}, {2.437499981032941, 
       4.084292589556061}, {2.5, 4.20590900530174}}], 
      PolygonBox[{{2.437499981032941, 4.084292589556061}, {
       2.4373449933535234`, 4.230251642536255}, {2.5, 4.20590900530174}, {
       2.437499981032941, 4.084292589556061}}], 
      PolygonBox[{{2.5, 4.357662782649368}, {2.5, 4.20590900530174}, {
       2.4373449933535234`, 4.230251642536255}, {2.5, 4.357662782649368}}], 
      PolygonBox[{{2.4373449933535234`, 4.230251642536255}, {
       2.404942744332997, 4.404942744332997}, {2.5, 4.357662782649368}, {
       2.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{2.491446564961186, 4.491446564961186}, {2.5, 
       4.357662782649368}, {2.404942744332997, 4.404942744332997}, {
       2.491446564961186, 4.491446564961186}}], 
      PolygonBox[{{2.404942744332997, 4.404942744332997}, {
       2.2302516425362553`, 4.437344993353523}, {2.491446564961186, 
       4.491446564961186}, {2.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{2.357662782649368, 4.5}, {2.491446564961186, 
       4.491446564961186}, {2.2302516425362553`, 4.437344993353523}, {
       2.357662782649368, 4.5}}], 
      PolygonBox[{{2.2302516425362553`, 4.437344993353523}, {
       2.0842925895560604`, 4.437499981032941}, {2.357662782649368, 4.5}, {
       2.2302516425362553`, 4.437344993353523}}], 
      PolygonBox[{{2.2059090053732557`, 4.5}, {2.357662782649368, 4.5}, {
       2.0842925895560604`, 4.437499981032941}, {2.2059090053732557`, 4.5}}], 
      PolygonBox[{{2.0842925895560604`, 4.437499981032941}, {
       2.0001055272204877`, 4.4375}, {2.2059090053732557`, 4.5}, {
       2.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{2.07794195802689, 4.5}, {2.2059090053732557`, 4.5}, {
       2.0001055272204877`, 4.4375}, {2.07794195802689, 4.5}}], 
      PolygonBox[{{2.0001055272204877`, 4.4375}, {1.915707410443943, 
       4.437499981032941}, {2.07794195802689, 4.5}, {2.0001055272204877`, 
       4.4375}}], 
      PolygonBox[{{1.7940909946955543`, 4.5}, {2.07794195802689, 4.5}, {
       1.915707410443943, 4.437499981032941}, {1.7940909946955543`, 4.5}}], 
      PolygonBox[{{1.915707410443943, 4.437499981032941}, {1.769748357463745, 
       4.437344993353523}, {1.7940909946955543`, 4.5}, {1.915707410443943, 
       4.437499981032941}}], 
      PolygonBox[{{1.6423372173506339`, 4.5}, {1.7940909946955543`, 4.5}, {
       1.769748357463745, 4.437344993353523}, {1.6423372173506339`, 4.5}}], 
      PolygonBox[{{1.769748357463745, 4.437344993353523}, {
       1.5950572556670028`, 4.404942744332997}, {1.6423372173506339`, 4.5}, {
       1.769748357463745, 4.437344993353523}}], 
      PolygonBox[{{2.5, 4.5}, {1.6423372173506339`, 4.5}, {
       1.5950572556670028`, 4.404942744332997}, {2.5, 4.5}}], 
      PolygonBox[{{1.5950572556670028`, 4.404942744332997}, {
       1.5626550066464766`, 4.230251642536255}, {2.5, 4.5}, {
       1.5950572556670028`, 4.404942744332997}}], 
      PolygonBox[{{1.5, 4.357662782649369}, {2.5, 4.5}, {1.5626550066464766`, 
       4.230251642536255}, {1.5, 4.357662782649369}}], 
      PolygonBox[{{1.5626550066464766`, 4.230251642536255}, {
       1.5625000189670593`, 4.084292589556062}, {1.5, 4.357662782649369}, {
       1.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{1.5, 4.205909005282899}, {1.5, 4.357662782649369}, {
       1.5625000189670593`, 4.084292589556062}, {1.5, 4.205909005282899}}], 
      PolygonBox[{{1.5625000189670593`, 4.084292589556062}, {1.5625, 
       4.000123178062996}, {1.5, 4.205909005282899}, {1.5625000189670593`, 
       4.084292589556062}}], 
      PolygonBox[{{1.5, 4.0806786667587005`}, {1.5, 4.205909005282899}, {
       1.5625, 4.000123178062996}, {1.5, 4.0806786667587005`}}], 
      PolygonBox[{{1.5625, 4.000123178062996}, {1.5625000189670593`, 
       3.915707410443945}, {1.5, 4.0806786667587005`}, {1.5625, 
       4.000123178062996}}], 
      PolygonBox[{{1.5, 3.7940909948547215`}, {1.5, 4.0806786667587005`}, {
       1.5625000189670593`, 3.915707410443945}, {1.5, 3.7940909948547215`}}], 
      PolygonBox[{{1.5625000189670593`, 3.915707410443945}, {
       1.5626550066464766`, 3.769748357463745}, {1.5, 3.7940909948547215`}, {
       1.5625000189670593`, 3.915707410443945}}], 
      PolygonBox[{{1.5, 3.6423372173506348`}, {1.5, 3.7940909948547215`}, {
       1.5626550066464766`, 3.769748357463745}, {1.5, 3.6423372173506348`}}], 
      PolygonBox[{{1.5626550066464766`, 3.769748357463745}, {
       1.5950572556670028`, 3.595057255667003}, {1.5, 3.6423372173506348`}, {
       1.5626550066464766`, 3.769748357463745}}], 
      PolygonBox[{{1.5, 4.5}, {1.5, 3.6423372173506348`}, {
       1.5950572556670028`, 3.595057255667003}, {1.5, 4.5}}], 
      PolygonBox[{{1.5950572556670028`, 3.595057255667003}, {
       1.769748357463745, 3.5626550066464766`}, {1.5, 4.5}, {
       1.5950572556670028`, 3.595057255667003}}], 
      PolygonBox[{{1.5, 3.5}, {1.5, 4.5}, {1.769748357463745, 
       3.5626550066464766`}, {1.5, 3.5}}], 
      PolygonBox[{{1.769748357463745, 3.5626550066464766`}, {
       1.9157074104439358`, 3.562500018967059}, {1.5, 3.5}, {
       1.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{1.794090994433172, 3.5}, {1.5, 3.5}, {1.9157074104439358`, 
       3.562500018967059}, {1.794090994433172, 3.5}}], 
      PolygonBox[{{1.9157074104439358`, 3.562500018967059}, {
       2.000134841831043, 3.5625}, {1.794090994433172, 3.5}, {
       1.9157074104439358`, 3.562500018967059}}], 
      PolygonBox[{{2.0823238704010616`, 3.5}, {1.794090994433172, 3.5}, {
       2.000134841831043, 3.5625}, {2.0823238704010616`, 3.5}}], 
      PolygonBox[{{2.000134841831043, 3.5625}, {2.0842925895560533`, 
       3.562500018967059}, {2.0823238704010616`, 3.5}, {2.000134841831043, 
       3.5625}}], 
      PolygonBox[{{2.2059090053603976`, 3.5}, {2.0823238704010616`, 3.5}, {
       2.0842925895560533`, 3.562500018967059}, {2.2059090053603976`, 3.5}}], 
      PolygonBox[{{2.0842925895560533`, 3.562500018967059}, {
       2.230251642536255, 3.5626550066464766`}, {2.2059090053603976`, 3.5}, {
       2.0842925895560533`, 3.562500018967059}}], 
      PolygonBox[{{2.357662782649371, 3.5}, {2.2059090053603976`, 3.5}, {
       2.230251642536255, 3.5626550066464766`}, {2.357662782649371, 3.5}}], 
      PolygonBox[{{2.230251642536255, 3.5626550066464766`}, {
       2.404942744332997, 3.595057255667003}, {2.357662782649371, 3.5}, {
       2.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{2.5, 3.5}, {2.357662782649371, 3.5}, {2.404942744332997, 
       3.595057255667003}, {2.5, 3.5}}], 
      PolygonBox[{{2.404942744332997, 3.595057255667003}, {2.404942744332997, 
       3.595057255667003}, {2.5, 3.5}, {2.404942744332997, 
       3.595057255667003}}], 
      PolygonBox[{{2.5, 3.5}, {2.5, 3.5}, {2.404942744332997, 
       3.595057255667003}, {2.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5, 5.}, {1.5208333333333333`, 5.}, {1.5416666666666667`, 
       5.}, {1.5625, 5.}, {1.5833333333333333`, 5.}, {1.6041666666666665`, 
       5.}, {1.625, 5.}, {1.625, 5.}, {1.6041666666666667`, 5.}, {
       1.5833333333333333`, 5.}, {1.5625, 5.}, {1.5416666666666667`, 5.}, {
       1.5208333333333335`, 5.}, {1.5, 5.}, {1.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.375, 5.}, {2.3958333333333335`, 5.}, {2.4166666666666665`, 
       5.}, {2.4375, 5.}, {2.4583333333333335`, 5.}, {2.4791666666666665`, 
       5.}, {2.5, 5.}, {2.5, 5.}, {2.4791666666666665`, 5.}, {
       2.4583333333333335`, 5.}, {2.4375, 5.}, {2.4166666666666665`, 5.}, {
       2.3958333333333335`, 5.}, {2.375, 5.}, {2.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 4.5}, {2., 4.520833333333333}, {2., 4.541666666666667}, {
       2., 4.5625}, {2., 4.583333333333333}, {2., 4.604166666666667}, {2., 
       4.625}, {2., 4.625}, {2., 4.604166666666667}, {2., 
       4.583333333333333}, {2., 4.5625}, {2., 4.541666666666667}, {2., 
       4.520833333333333}, {2., 4.5}, {2., 4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 5.375}, {2., 5.395833333333333}, {2., 
       5.416666666666667}, {2., 5.4375}, {2., 5.458333333333333}, {2., 
       5.479166666666667}, {2., 5.5}, {2., 5.5}, {2., 5.479166666666667}, {2.,
        5.458333333333333}, {2., 5.4375}, {2., 5.416666666666667}, {2., 
       5.395833333333333}, {2., 5.375}, {2., 5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.625, 5.}, {1.75, 5.}, {1.875, 5.}, {2., 5.}, {2.125, 5.}, {
       2.25, 5.}, {2.375, 5.}, {2.375, 5.}, {2.25, 5.}, {2.125, 5.}, {2., 
       5.}, {1.875, 5.}, {1.75, 5.}, {1.625, 5.}, {1.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., 4.625}, {2., 4.75}, {2., 4.875}, {2., 5.}, {2., 5.125}, {
       2., 5.25}, {2., 5.375}, {2., 5.375}, {2., 5.25}, {2., 5.125}, {2., 
       5.}, {2., 4.875}, {2., 4.75}, {2., 4.625}, {2., 4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHMDhBaxOHVxXX7rjxlclAv6vyUlCziYOB+olV6
JhNE/oCIw+y3s2/yyTM5nPt2NqedXxQi3sDoMEP5yaFeH1EH/ydCT48eY3D4
mhEe/6oIKs/AAFUn6pBsfsu0pOifPar8X3uY/lMqJ3weHfxtDzN/QWH+lxNn
f9nD7NeJWdQUZvLLXgPqPoh+qDwDQv5mbxnv3DnCqPodhB1OQs035jSaXPFB
yOE/GPyxz7gjbVu0WcghEeo+7ukrFoj2CqG5X8jBD+o/mDxYez2jA0w/LHyM
oOajhB/Qflj43oC6Dz38ATUvjyE=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEsDhBazGH1KhBggvNDwYARzodqgPPDwPJ/7VH1
/7JHVf+DIB9ijyicDzFHBE29CJp6YTT1QmjqMfmrUNwnBPXfXzT1MP8Jofkf
pp/JAVU9C0E+qvtYHFDdD1MvgqZeBE29KJp6MQcAVzJOkA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{2.2651650429449552`, 4.734834957055044}, {
       2.3247595264191645`, 4.8125}, {2.404942744332997, 4.595057255667003}, {
       2.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{2.4373449933535234`, 4.769748357463745}, {
       2.404942744332997, 4.595057255667003}, {2.3247595264191645`, 4.8125}, {
       2.4373449933535234`, 4.769748357463745}}], 
      PolygonBox[{{2.3247595264191645`, 4.8125}, {2.3622221848584006`, 
       4.902942858086555}, {2.4373449933535234`, 4.769748357463745}, {
       2.3247595264191645`, 4.8125}}], 
      PolygonBox[{{2.437499981032941, 4.915707410443938}, {
       2.4373449933535234`, 4.769748357463745}, {2.3622221848584006`, 
       4.902942858086555}, {2.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{2.3622221848584006`, 4.902942858086555}, {2.375, 5.}, {
       2.437499981032941, 4.915707410443938}, {2.3622221848584006`, 
       4.902942858086555}}], 
      PolygonBox[{{2.4375, 5.}, {2.437499981032941, 4.915707410443938}, {
       2.375, 5.}, {2.4375, 5.}}], 
      PolygonBox[{{2.375, 5.}, {2.3622221848584006`, 5.097057141913445}, {
       2.4375, 5.}, {2.375, 5.}}], 
      PolygonBox[{{2.437499981032941, 5.084292589556061}, {2.4375, 5.}, {
       2.3622221848584006`, 5.097057141913445}, {2.437499981032941, 
       5.084292589556061}}], 
      PolygonBox[{{2.3622221848584006`, 5.097057141913445}, {
       2.3247595264191645`, 5.1875}, {2.437499981032941, 5.084292589556061}, {
       2.3622221848584006`, 5.097057141913445}}], 
      PolygonBox[{{2.4373449933535234`, 5.230251642536255}, {
       2.437499981032941, 5.084292589556061}, {2.3247595264191645`, 5.1875}, {
       2.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{2.3247595264191645`, 5.1875}, {2.2651650429449552`, 
       5.265165042944956}, {2.4373449933535234`, 5.230251642536255}, {
       2.3247595264191645`, 5.1875}}], 
      PolygonBox[{{2.404942744332997, 5.404942744332997}, {
       2.4373449933535234`, 5.230251642536255}, {2.2651650429449552`, 
       5.265165042944956}, {2.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{2.2651650429449552`, 5.265165042944956}, {2.1875, 
       5.3247595264191645`}, {2.404942744332997, 5.404942744332997}, {
       2.2651650429449552`, 5.265165042944956}}], 
      PolygonBox[{{2.2302516425362553`, 5.437344993353523}, {
       2.404942744332997, 5.404942744332997}, {2.1875, 5.3247595264191645`}, {
       2.2302516425362553`, 5.437344993353523}}], 
      PolygonBox[{{2.1875, 5.3247595264191645`}, {2.0970571419134454`, 
       5.362222184858401}, {2.2302516425362553`, 5.437344993353523}, {2.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{2.0842925895560604`, 5.437499981032941}, {
       2.2302516425362553`, 5.437344993353523}, {2.0970571419134454`, 
       5.362222184858401}, {2.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{2.0970571419134454`, 5.362222184858401}, {2., 5.375}, {
       2.0842925895560604`, 5.437499981032941}, {2.0970571419134454`, 
       5.362222184858401}}], 
      PolygonBox[{{2.0001055272204877`, 5.4375}, {2.0842925895560604`, 
       5.437499981032941}, {2., 5.375}, {2.0001055272204877`, 5.4375}}], 
      PolygonBox[{{2., 5.375}, {1.9029428580865548`, 5.362222184858401}, {
       2.0001055272204877`, 5.4375}, {2., 5.375}}], 
      PolygonBox[{{1.915707410443943, 5.437499981032941}, {
       2.0001055272204877`, 5.4375}, {1.9029428580865548`, 
       5.362222184858401}, {1.915707410443943, 5.437499981032941}}], 
      PolygonBox[{{1.9029428580865548`, 5.362222184858401}, {1.8125, 
       5.3247595264191645`}, {1.915707410443943, 5.437499981032941}, {
       1.9029428580865548`, 5.362222184858401}}], 
      PolygonBox[{{1.769748357463745, 5.437344993353523}, {1.915707410443943, 
       5.437499981032941}, {1.8125, 5.3247595264191645`}, {1.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{1.8125, 5.3247595264191645`}, {1.7348349570550448`, 
       5.265165042944956}, {1.769748357463745, 5.437344993353523}, {1.8125, 
       5.3247595264191645`}}], 
      PolygonBox[{{1.5950572556670028`, 5.404942744332997}, {
       1.769748357463745, 5.437344993353523}, {1.7348349570550448`, 
       5.265165042944956}, {1.5950572556670028`, 5.404942744332997}}], 
      PolygonBox[{{1.7348349570550448`, 5.265165042944956}, {
       1.6752404735808355`, 5.1875}, {1.5950572556670028`, 
       5.404942744332997}, {1.7348349570550448`, 5.265165042944956}}], 
      PolygonBox[{{1.5626550066464766`, 5.230251642536255}, {
       1.5950572556670028`, 5.404942744332997}, {1.6752404735808355`, 
       5.1875}, {1.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{1.6752404735808355`, 5.1875}, {1.6377778151415994`, 
       5.097057141913446}, {1.5626550066464766`, 5.230251642536255}, {
       1.6752404735808355`, 5.1875}}], 
      PolygonBox[{{1.5625000189670593`, 5.084292589556062}, {
       1.5626550066464766`, 5.230251642536255}, {1.6377778151415994`, 
       5.097057141913446}, {1.5625000189670593`, 5.084292589556062}}], 
      PolygonBox[{{1.6377778151415994`, 5.097057141913446}, {1.625, 5.}, {
       1.5625000189670593`, 5.084292589556062}, {1.6377778151415994`, 
       5.097057141913446}}], 
      PolygonBox[{{1.5625, 5.000123178062996}, {1.5625000189670593`, 
       5.084292589556062}, {1.625, 5.}, {1.5625, 5.000123178062996}}], 
      PolygonBox[{{1.625, 5.}, {1.6377778151415994`, 4.902942858086555}, {
       1.5625, 5.000123178062996}, {1.625, 5.}}], 
      PolygonBox[{{1.5625000189670593`, 4.915707410443945}, {1.5625, 
       5.000123178062996}, {1.6377778151415994`, 4.902942858086555}, {
       1.5625000189670593`, 4.915707410443945}}], 
      PolygonBox[{{1.6377778151415994`, 4.902942858086555}, {
       1.6752404735808355`, 4.8125}, {1.5625000189670593`, 
       4.915707410443945}, {1.6377778151415994`, 4.902942858086555}}], 
      PolygonBox[{{1.5626550066464766`, 4.769748357463746}, {
       1.5625000189670593`, 4.915707410443945}, {1.6752404735808355`, 
       4.8125}, {1.5626550066464766`, 4.769748357463746}}], 
      PolygonBox[{{1.6752404735808355`, 4.8125}, {1.7348349570550448`, 
       4.734834957055044}, {1.5626550066464766`, 4.769748357463746}, {
       1.6752404735808355`, 4.8125}}], 
      PolygonBox[{{1.5950572556670028`, 4.595057255667003}, {
       1.5626550066464766`, 4.769748357463746}, {1.7348349570550448`, 
       4.734834957055044}, {1.5950572556670028`, 4.595057255667003}}], 
      PolygonBox[{{1.7348349570550448`, 4.734834957055044}, {
       1.8124999999999998`, 4.6752404735808355`}, {1.5950572556670028`, 
       4.595057255667003}, {1.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{1.769748357463745, 4.562655006646477}, {
       1.5950572556670028`, 4.595057255667003}, {1.8124999999999998`, 
       4.6752404735808355`}, {1.769748357463745, 4.562655006646477}}], 
      PolygonBox[{{1.8124999999999998`, 4.6752404735808355`}, {
       1.9029428580865544`, 4.637777815141599}, {1.769748357463745, 
       4.562655006646477}, {1.8124999999999998`, 4.6752404735808355`}}], 
      PolygonBox[{{1.9157074104439358`, 4.562500018967059}, {
       1.769748357463745, 4.562655006646477}, {1.9029428580865544`, 
       4.637777815141599}, {1.9157074104439358`, 4.562500018967059}}], 
      PolygonBox[{{1.9029428580865544`, 4.637777815141599}, {2., 4.625}, {
       1.9157074104439358`, 4.562500018967059}, {1.9029428580865544`, 
       4.637777815141599}}], 
      PolygonBox[{{2.000134841831043, 4.5625}, {1.9157074104439358`, 
       4.562500018967059}, {2., 4.625}, {2.000134841831043, 4.5625}}], 
      PolygonBox[{{2., 4.625}, {2.097057141913445, 4.637777815141599}, {
       2.000134841831043, 4.5625}, {2., 4.625}}], 
      PolygonBox[{{2.0842925895560533`, 4.562500018967059}, {
       2.000134841831043, 4.5625}, {2.097057141913445, 4.637777815141599}, {
       2.0842925895560533`, 4.562500018967059}}], 
      PolygonBox[{{2.097057141913445, 4.637777815141599}, {
       2.1874999999999996`, 4.6752404735808355`}, {2.0842925895560533`, 
       4.562500018967059}, {2.097057141913445, 4.637777815141599}}], 
      PolygonBox[{{2.230251642536255, 4.562655006646477}, {
       2.0842925895560533`, 4.562500018967059}, {2.1874999999999996`, 
       4.6752404735808355`}, {2.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{2.1874999999999996`, 4.6752404735808355`}, {
       2.2651650429449552`, 4.734834957055044}, {2.230251642536255, 
       4.562655006646477}, {2.1874999999999996`, 4.6752404735808355`}}], 
      PolygonBox[{{2.404942744332997, 4.595057255667003}, {2.230251642536255, 
       4.562655006646477}, {2.2651650429449552`, 4.734834957055044}, {
       2.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{2.2651650429449552`, 4.734834957055044}, {
       2.2651650429449552`, 4.734834957055044}, {2.404942744332997, 
       4.595057255667003}, {2.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{2.404942744332997, 4.595057255667003}, {2.404942744332997, 
       4.595057255667003}, {2.2651650429449552`, 4.734834957055044}, {
       2.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{2.404942744332997, 4.595057255667003}, {
       2.4373449933535234`, 4.769748357463745}, {2.5, 4.5}, {
       2.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{2.5, 4.642337217350632}, {2.5, 4.5}, {2.4373449933535234`, 
       4.769748357463745}, {2.5, 4.642337217350632}}], 
      PolygonBox[{{2.4373449933535234`, 4.769748357463745}, {
       2.437499981032941, 4.915707410443938}, {2.5, 4.642337217350632}, {
       2.4373449933535234`, 4.769748357463745}}], 
      PolygonBox[{{2.5, 4.79409099469826}, {2.5, 4.642337217350632}, {
       2.437499981032941, 4.915707410443938}, {2.5, 4.79409099469826}}], 
      PolygonBox[{{2.437499981032941, 4.915707410443938}, {2.4375, 5.}, {2.5, 
       4.79409099469826}, {2.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{2.5, 5.}, {2.5, 4.79409099469826}, {2.4375, 5.}, {2.5, 
       5.}}], PolygonBox[{{2.4375, 5.}, {2.437499981032941, 
       5.084292589556061}, {2.5, 5.}, {2.4375, 5.}}], 
      PolygonBox[{{2.5, 5.20590900530174}, {2.5, 5.}, {2.437499981032941, 
       5.084292589556061}, {2.5, 5.20590900530174}}], 
      PolygonBox[{{2.437499981032941, 5.084292589556061}, {
       2.4373449933535234`, 5.230251642536255}, {2.5, 5.20590900530174}, {
       2.437499981032941, 5.084292589556061}}], 
      PolygonBox[{{2.5, 5.357662782649368}, {2.5, 5.20590900530174}, {
       2.4373449933535234`, 5.230251642536255}, {2.5, 5.357662782649368}}], 
      PolygonBox[{{2.4373449933535234`, 5.230251642536255}, {
       2.404942744332997, 5.404942744332997}, {2.5, 5.357662782649368}, {
       2.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{2.491446564961186, 5.491446564961186}, {2.5, 
       5.357662782649368}, {2.404942744332997, 5.404942744332997}, {
       2.491446564961186, 5.491446564961186}}], 
      PolygonBox[{{2.404942744332997, 5.404942744332997}, {
       2.2302516425362553`, 5.437344993353523}, {2.491446564961186, 
       5.491446564961186}, {2.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{2.357662782649368, 5.5}, {2.491446564961186, 
       5.491446564961186}, {2.2302516425362553`, 5.437344993353523}, {
       2.357662782649368, 5.5}}], 
      PolygonBox[{{2.2302516425362553`, 5.437344993353523}, {
       2.0842925895560604`, 5.437499981032941}, {2.357662782649368, 5.5}, {
       2.2302516425362553`, 5.437344993353523}}], 
      PolygonBox[{{2.2059090053732557`, 5.5}, {2.357662782649368, 5.5}, {
       2.0842925895560604`, 5.437499981032941}, {2.2059090053732557`, 5.5}}], 
      PolygonBox[{{2.0842925895560604`, 5.437499981032941}, {
       2.0001055272204877`, 5.4375}, {2.2059090053732557`, 5.5}, {
       2.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{2.07794195802689, 5.5}, {2.2059090053732557`, 5.5}, {
       2.0001055272204877`, 5.4375}, {2.07794195802689, 5.5}}], 
      PolygonBox[{{2.0001055272204877`, 5.4375}, {1.915707410443943, 
       5.437499981032941}, {2.07794195802689, 5.5}, {2.0001055272204877`, 
       5.4375}}], 
      PolygonBox[{{1.7940909946955543`, 5.5}, {2.07794195802689, 5.5}, {
       1.915707410443943, 5.437499981032941}, {1.7940909946955543`, 5.5}}], 
      PolygonBox[{{1.915707410443943, 5.437499981032941}, {1.769748357463745, 
       5.437344993353523}, {1.7940909946955543`, 5.5}, {1.915707410443943, 
       5.437499981032941}}], 
      PolygonBox[{{1.6423372173506339`, 5.5}, {1.7940909946955543`, 5.5}, {
       1.769748357463745, 5.437344993353523}, {1.6423372173506339`, 5.5}}], 
      PolygonBox[{{1.769748357463745, 5.437344993353523}, {
       1.5950572556670028`, 5.404942744332997}, {1.6423372173506339`, 5.5}, {
       1.769748357463745, 5.437344993353523}}], 
      PolygonBox[{{2.5, 5.5}, {1.6423372173506339`, 5.5}, {
       1.5950572556670028`, 5.404942744332997}, {2.5, 5.5}}], 
      PolygonBox[{{1.5950572556670028`, 5.404942744332997}, {
       1.5626550066464766`, 5.230251642536255}, {2.5, 5.5}, {
       1.5950572556670028`, 5.404942744332997}}], 
      PolygonBox[{{1.5, 5.357662782649369}, {2.5, 5.5}, {1.5626550066464766`, 
       5.230251642536255}, {1.5, 5.357662782649369}}], 
      PolygonBox[{{1.5626550066464766`, 5.230251642536255}, {
       1.5625000189670593`, 5.084292589556062}, {1.5, 5.357662782649369}, {
       1.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{1.5, 5.205909005282899}, {1.5, 5.357662782649369}, {
       1.5625000189670593`, 5.084292589556062}, {1.5, 5.205909005282899}}], 
      PolygonBox[{{1.5625000189670593`, 5.084292589556062}, {1.5625, 
       5.000123178062996}, {1.5, 5.205909005282899}, {1.5625000189670593`, 
       5.084292589556062}}], 
      PolygonBox[{{1.5, 5.0806786667587005`}, {1.5, 5.205909005282899}, {
       1.5625, 5.000123178062996}, {1.5, 5.0806786667587005`}}], 
      PolygonBox[{{1.5625, 5.000123178062996}, {1.5625000189670593`, 
       4.915707410443945}, {1.5, 5.0806786667587005`}, {1.5625, 
       5.000123178062996}}], 
      PolygonBox[{{1.5, 4.794090994854722}, {1.5, 5.0806786667587005`}, {
       1.5625000189670593`, 4.915707410443945}, {1.5, 4.794090994854722}}], 
      PolygonBox[{{1.5625000189670593`, 4.915707410443945}, {
       1.5626550066464766`, 4.769748357463746}, {1.5, 4.794090994854722}, {
       1.5625000189670593`, 4.915707410443945}}], 
      PolygonBox[{{1.5, 4.642337217350635}, {1.5, 4.794090994854722}, {
       1.5626550066464766`, 4.769748357463746}, {1.5, 4.642337217350635}}], 
      PolygonBox[{{1.5626550066464766`, 4.769748357463746}, {
       1.5950572556670028`, 4.595057255667003}, {1.5, 4.642337217350635}, {
       1.5626550066464766`, 4.769748357463746}}], 
      PolygonBox[{{1.5, 5.5}, {1.5, 4.642337217350635}, {1.5950572556670028`, 
       4.595057255667003}, {1.5, 5.5}}], 
      PolygonBox[{{1.5950572556670028`, 4.595057255667003}, {
       1.769748357463745, 4.562655006646477}, {1.5, 5.5}, {
       1.5950572556670028`, 4.595057255667003}}], 
      PolygonBox[{{1.5, 4.5}, {1.5, 5.5}, {1.769748357463745, 
       4.562655006646477}, {1.5, 4.5}}], 
      PolygonBox[{{1.769748357463745, 4.562655006646477}, {
       1.9157074104439358`, 4.562500018967059}, {1.5, 4.5}, {
       1.769748357463745, 4.562655006646477}}], 
      PolygonBox[{{1.794090994433172, 4.5}, {1.5, 4.5}, {1.9157074104439358`, 
       4.562500018967059}, {1.794090994433172, 4.5}}], 
      PolygonBox[{{1.9157074104439358`, 4.562500018967059}, {
       2.000134841831043, 4.5625}, {1.794090994433172, 4.5}, {
       1.9157074104439358`, 4.562500018967059}}], 
      PolygonBox[{{2.0823238704010616`, 4.5}, {1.794090994433172, 4.5}, {
       2.000134841831043, 4.5625}, {2.0823238704010616`, 4.5}}], 
      PolygonBox[{{2.000134841831043, 4.5625}, {2.0842925895560533`, 
       4.562500018967059}, {2.0823238704010616`, 4.5}, {2.000134841831043, 
       4.5625}}], 
      PolygonBox[{{2.2059090053603976`, 4.5}, {2.0823238704010616`, 4.5}, {
       2.0842925895560533`, 4.562500018967059}, {2.2059090053603976`, 4.5}}], 
      PolygonBox[{{2.0842925895560533`, 4.562500018967059}, {
       2.230251642536255, 4.562655006646477}, {2.2059090053603976`, 4.5}, {
       2.0842925895560533`, 4.562500018967059}}], 
      PolygonBox[{{2.357662782649371, 4.5}, {2.2059090053603976`, 4.5}, {
       2.230251642536255, 4.562655006646477}, {2.357662782649371, 4.5}}], 
      PolygonBox[{{2.230251642536255, 4.562655006646477}, {2.404942744332997, 
       4.595057255667003}, {2.357662782649371, 4.5}, {2.230251642536255, 
       4.562655006646477}}], 
      PolygonBox[{{2.5, 4.5}, {2.357662782649371, 4.5}, {2.404942744332997, 
       4.595057255667003}, {2.5, 4.5}}], 
      PolygonBox[{{2.404942744332997, 4.595057255667003}, {2.404942744332997, 
       4.595057255667003}, {2.5, 4.5}, {2.404942744332997, 
       4.595057255667003}}], 
      PolygonBox[{{2.5, 4.5}, {2.5, 4.5}, {2.404942744332997, 
       4.595057255667003}, {2.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, -5.}, {2.5208333333333335`, -5.}, {
       2.5416666666666665`, -5.}, {2.5625, -5.}, {2.5833333333333335`, -5.}, {
       2.6041666666666665`, -5.}, {2.625, -5.}, {2.625, -5.}, {
       2.6041666666666665`, -5.}, {2.5833333333333335`, -5.}, {2.5625, -5.}, {
       2.5416666666666665`, -5.}, {2.5208333333333335`, -5.}, {2.5, -5.}, {
       2.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, -5.}, {3.3958333333333335`, -5.}, {
       3.4166666666666665`, -5.}, {3.4375, -5.}, {3.4583333333333335`, -5.}, {
       3.4791666666666665`, -5.}, {3.5, -5.}, {3.5, -5.}, {
       3.4791666666666665`, -5.}, {3.4583333333333335`, -5.}, {3.4375, -5.}, {
       3.4166666666666665`, -5.}, {3.3958333333333335`, -5.}, {3.375, -5.}, {
       3.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -5.5}, {3., -5.479166666666667}, {
       3., -5.458333333333333}, {3., -5.4375}, {3., -5.416666666666667}, {
       3., -5.395833333333333}, {3., -5.375}, {3., -5.375}, {
       3., -5.395833333333333}, {3., -5.416666666666667}, {3., -5.4375}, {
       3., -5.458333333333333}, {3., -5.479166666666667}, {3., -5.5}, {
       3., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -4.625}, {3., -4.604166666666667}, {
       3., -4.583333333333333}, {3., -4.5625}, {3., -4.541666666666667}, {
       3., -4.520833333333333}, {3., -4.5}, {3., -4.5}, {
       3., -4.520833333333333}, {3., -4.541666666666667}, {3., -4.5625}, {
       3., -4.583333333333333}, {3., -4.604166666666667}, {3., -4.625}, {
       3., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, -5.}, {2.75, -5.}, {2.875, -5.}, {3., -5.}, {
       3.125, -5.}, {3.25, -5.}, {3.375, -5.}, {3.375, -5.}, {3.25, -5.}, {
       3.125, -5.}, {3., -5.}, {2.875, -5.}, {2.75, -5.}, {2.625, -5.}, {
       2.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -5.375}, {3., -5.25}, {3., -5.125}, {3., -5.}, {
       3., -4.875}, {3., -4.75}, {3., -4.625}, {3., -4.625}, {3., -4.75}, {
       3., -4.875}, {3., -5.}, {3., -5.125}, {3., -5.25}, {3., -5.375}, {
       3., -5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhBa5MCri+v2XXnK5XCzt4x37hzhAwbuJ1ql
Z3JB5B2ED8x+O/smnzyXgxGn0eSKD0IHwOINnA4Zd6RtizYLHfB/IvT06DEO
B+7pKxaI9kLlGTgg+huEDmyUfitlZcmOKt/ABtefKpSi9vEBK9z8CzvMq56k
scLtF9MLdNSWYnW4AXUfxHxWuPth8upFnZ+SkkVQ9R8QOZACNf/st7M57fyi
cPtnKD851OsjCnff14zw+FdFomjuFz3gB/UfTP4/CNRzwvXDwucc1HyU8DuA
CF8NqPvQwx8AllWHGA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhBa6MDqVSDABeeHggEnnA+hOdDUs8H5YWD1
rGjqWQjyIeYg+BB7hdHUi6CpF0FTL4qmXgyDH4riPjE098PUc6Cp54TzV6GE
D0w9D0E+qvt40NwPUy+Cpl4YTb0QmnqhAwDP0VCq
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, -5.265165042944956}, {
       3.3247595264191645`, -5.1875}, {
       3.404942744332997, -5.404942744332997}, {
       3.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{3.4373449933535234`, -5.230251642536255}, {
       3.404942744332997, -5.404942744332997}, {
       3.3247595264191645`, -5.1875}, {
       3.4373449933535234`, -5.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, -5.1875}, {
       3.3622221848584006`, -5.097057141913445}, {
       3.4373449933535234`, -5.230251642536255}, {
       3.3247595264191645`, -5.1875}}], 
      PolygonBox[{{3.437499981032941, -5.084292589556062}, {
       3.4373449933535234`, -5.230251642536255}, {
       3.3622221848584006`, -5.097057141913445}, {
       3.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{3.3622221848584006`, -5.097057141913445}, {3.375, -5.}, {
       3.437499981032941, -5.084292589556062}, {
       3.3622221848584006`, -5.097057141913445}}], 
      PolygonBox[{{3.4375, -5.}, {3.437499981032941, -5.084292589556062}, {
       3.375, -5.}, {3.4375, -5.}}], 
      PolygonBox[{{3.375, -5.}, {3.3622221848584006`, -4.902942858086555}, {
       3.4375, -5.}, {3.375, -5.}}], 
      PolygonBox[{{3.437499981032941, -4.915707410443939}, {3.4375, -5.}, {
       3.3622221848584006`, -4.902942858086555}, {
       3.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{3.3622221848584006`, -4.902942858086555}, {
       3.3247595264191645`, -4.8125}, {
       3.437499981032941, -4.915707410443939}, {
       3.3622221848584006`, -4.902942858086555}}], 
      PolygonBox[{{3.4373449933535234`, -4.769748357463745}, {
       3.437499981032941, -4.915707410443939}, {
       3.3247595264191645`, -4.8125}, {
       3.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{3.3247595264191645`, -4.8125}, {
       3.2651650429449552`, -4.734834957055044}, {
       3.4373449933535234`, -4.769748357463745}, {
       3.3247595264191645`, -4.8125}}], 
      PolygonBox[{{3.404942744332997, -4.595057255667003}, {
       3.4373449933535234`, -4.769748357463745}, {
       3.2651650429449552`, -4.734834957055044}, {
       3.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{3.2651650429449552`, -4.734834957055044}, {
       3.1875, -4.6752404735808355`}, {
       3.404942744332997, -4.595057255667003}, {
       3.2651650429449552`, -4.734834957055044}}], 
      PolygonBox[{{3.2302516425362553`, -4.562655006646477}, {
       3.404942744332997, -4.595057255667003}, {
       3.1875, -4.6752404735808355`}, {
       3.2302516425362553`, -4.562655006646477}}], 
      PolygonBox[{{3.1875, -4.6752404735808355`}, {
       3.0970571419134454`, -4.637777815141599}, {
       3.2302516425362553`, -4.562655006646477}, {
       3.1875, -4.6752404735808355`}}], 
      PolygonBox[{{3.0842925895560604`, -4.562500018967059}, {
       3.2302516425362553`, -4.562655006646477}, {
       3.0970571419134454`, -4.637777815141599}, {
       3.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{3.0970571419134454`, -4.637777815141599}, {3., -4.625}, {
       3.0842925895560604`, -4.562500018967059}, {
       3.0970571419134454`, -4.637777815141599}}], 
      PolygonBox[{{3.0001055272204877`, -4.5625}, {
       3.0842925895560604`, -4.562500018967059}, {3., -4.625}, {
       3.0001055272204877`, -4.5625}}], 
      PolygonBox[{{3., -4.625}, {2.902942858086555, -4.637777815141599}, {
       3.0001055272204877`, -4.5625}, {3., -4.625}}], 
      PolygonBox[{{2.915707410443943, -4.562500018967059}, {
       3.0001055272204877`, -4.5625}, {
       2.902942858086555, -4.637777815141599}, {
       2.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{2.902942858086555, -4.637777815141599}, {
       2.8125, -4.6752404735808355`}, {
       2.915707410443943, -4.562500018967059}, {
       2.902942858086555, -4.637777815141599}}], 
      PolygonBox[{{2.769748357463745, -4.562655006646477}, {
       2.915707410443943, -4.562500018967059}, {
       2.8125, -4.6752404735808355`}, {
       2.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{2.8125, -4.6752404735808355`}, {
       2.7348349570550448`, -4.734834957055044}, {
       2.769748357463745, -4.562655006646477}, {
       2.8125, -4.6752404735808355`}}], 
      PolygonBox[{{2.595057255667003, -4.595057255667003}, {
       2.769748357463745, -4.562655006646477}, {
       2.7348349570550448`, -4.734834957055044}, {
       2.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{2.7348349570550448`, -4.734834957055044}, {
       2.6752404735808355`, -4.8125}, {
       2.595057255667003, -4.595057255667003}, {
       2.7348349570550448`, -4.734834957055044}}], 
      PolygonBox[{{2.5626550066464766`, -4.769748357463745}, {
       2.595057255667003, -4.595057255667003}, {
       2.6752404735808355`, -4.8125}, {
       2.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{2.6752404735808355`, -4.8125}, {
       2.6377778151415994`, -4.902942858086554}, {
       2.5626550066464766`, -4.769748357463745}, {
       2.6752404735808355`, -4.8125}}], 
      PolygonBox[{{2.562500018967059, -4.915707410443938}, {
       2.5626550066464766`, -4.769748357463745}, {
       2.6377778151415994`, -4.902942858086554}, {
       2.562500018967059, -4.915707410443938}}], 
      PolygonBox[{{2.6377778151415994`, -4.902942858086554}, {2.625, -5.}, {
       2.562500018967059, -4.915707410443938}, {
       2.6377778151415994`, -4.902942858086554}}], 
      PolygonBox[{{2.5625, -4.999876821937004}, {
       2.562500018967059, -4.915707410443938}, {2.625, -5.}, {
       2.5625, -4.999876821937004}}], 
      PolygonBox[{{2.625, -5.}, {2.6377778151415994`, -5.097057141913445}, {
       2.5625, -4.999876821937004}, {2.625, -5.}}], 
      PolygonBox[{{2.562500018967059, -5.084292589556055}, {
       2.5625, -4.999876821937004}, {
       2.6377778151415994`, -5.097057141913445}, {
       2.562500018967059, -5.084292589556055}}], 
      PolygonBox[{{2.6377778151415994`, -5.097057141913445}, {
       2.6752404735808355`, -5.1875}, {
       2.562500018967059, -5.084292589556055}, {
       2.6377778151415994`, -5.097057141913445}}], 
      PolygonBox[{{2.5626550066464766`, -5.230251642536254}, {
       2.562500018967059, -5.084292589556055}, {
       2.6752404735808355`, -5.1875}, {
       2.5626550066464766`, -5.230251642536254}}], 
      PolygonBox[{{2.6752404735808355`, -5.1875}, {
       2.7348349570550448`, -5.265165042944956}, {
       2.5626550066464766`, -5.230251642536254}, {
       2.6752404735808355`, -5.1875}}], 
      PolygonBox[{{2.595057255667003, -5.404942744332997}, {
       2.5626550066464766`, -5.230251642536254}, {
       2.7348349570550448`, -5.265165042944956}, {
       2.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, -5.265165042944956}, {
       2.8125, -5.3247595264191645`}, {
       2.595057255667003, -5.404942744332997}, {
       2.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{2.769748357463745, -5.437344993353523}, {
       2.595057255667003, -5.404942744332997}, {
       2.8125, -5.3247595264191645`}, {
       2.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{2.8125, -5.3247595264191645`}, {
       2.9029428580865546`, -5.362222184858401}, {
       2.769748357463745, -5.437344993353523}, {
       2.8125, -5.3247595264191645`}}], 
      PolygonBox[{{2.915707410443936, -5.437499981032941}, {
       2.769748357463745, -5.437344993353523}, {
       2.9029428580865546`, -5.362222184858401}, {
       2.915707410443936, -5.437499981032941}}], 
      PolygonBox[{{2.9029428580865546`, -5.362222184858401}, {3., -5.375}, {
       2.915707410443936, -5.437499981032941}, {
       2.9029428580865546`, -5.362222184858401}}], 
      PolygonBox[{{3.000134841831043, -5.4375}, {
       2.915707410443936, -5.437499981032941}, {3., -5.375}, {
       3.000134841831043, -5.4375}}], 
      PolygonBox[{{3., -5.375}, {3.097057141913445, -5.362222184858401}, {
       3.000134841831043, -5.4375}, {3., -5.375}}], 
      PolygonBox[{{3.0842925895560533`, -5.437499981032941}, {
       3.000134841831043, -5.4375}, {3.097057141913445, -5.362222184858401}, {
       3.0842925895560533`, -5.437499981032941}}], 
      PolygonBox[{{3.097057141913445, -5.362222184858401}, {
       3.1874999999999996`, -5.3247595264191645`}, {
       3.0842925895560533`, -5.437499981032941}, {
       3.097057141913445, -5.362222184858401}}], 
      PolygonBox[{{3.230251642536255, -5.437344993353523}, {
       3.0842925895560533`, -5.437499981032941}, {
       3.1874999999999996`, -5.3247595264191645`}, {
       3.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{3.1874999999999996`, -5.3247595264191645`}, {
       3.2651650429449552`, -5.265165042944956}, {
       3.230251642536255, -5.437344993353523}, {
       3.1874999999999996`, -5.3247595264191645`}}], 
      PolygonBox[{{3.404942744332997, -5.404942744332997}, {
       3.230251642536255, -5.437344993353523}, {
       3.2651650429449552`, -5.265165042944956}, {
       3.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, -5.265165042944956}, {
       3.2651650429449552`, -5.265165042944956}, {
       3.404942744332997, -5.404942744332997}, {
       3.2651650429449552`, -5.265165042944956}}], 
      PolygonBox[{{3.404942744332997, -5.404942744332997}, {
       3.404942744332997, -5.404942744332997}, {
       3.2651650429449552`, -5.265165042944956}, {
       3.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{3.404942744332997, -5.404942744332997}, {
       3.4373449933535234`, -5.230251642536255}, {3.5, -5.5}, {
       3.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{3.5, -5.357662782649368}, {3.5, -5.5}, {
       3.4373449933535234`, -5.230251642536255}, {3.5, -5.357662782649368}}], 
      PolygonBox[{{3.4373449933535234`, -5.230251642536255}, {
       3.437499981032941, -5.084292589556062}, {3.5, -5.357662782649368}, {
       3.4373449933535234`, -5.230251642536255}}], 
      PolygonBox[{{3.5, -5.20590900530174}, {3.5, -5.357662782649368}, {
       3.437499981032941, -5.084292589556062}, {3.5, -5.20590900530174}}], 
      PolygonBox[{{3.437499981032941, -5.084292589556062}, {3.4375, -5.}, {
       3.5, -5.20590900530174}, {3.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{3.5, -5.}, {3.5, -5.20590900530174}, {3.4375, -5.}, {
       3.5, -5.}}], 
      PolygonBox[{{3.4375, -5.}, {3.437499981032941, -4.915707410443939}, {
       3.5, -5.}, {3.4375, -5.}}], 
      PolygonBox[{{3.5, -4.79409099469826}, {3.5, -5.}, {
       3.437499981032941, -4.915707410443939}, {3.5, -4.79409099469826}}], 
      PolygonBox[{{3.437499981032941, -4.915707410443939}, {
       3.4373449933535234`, -4.769748357463745}, {3.5, -4.79409099469826}, {
       3.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{3.5, -4.642337217350632}, {3.5, -4.79409099469826}, {
       3.4373449933535234`, -4.769748357463745}, {3.5, -4.642337217350632}}], 
      PolygonBox[{{3.4373449933535234`, -4.769748357463745}, {
       3.404942744332997, -4.595057255667003}, {3.5, -4.642337217350632}, {
       3.4373449933535234`, -4.769748357463745}}], 
      PolygonBox[{{3.491446564961186, -4.508553435038814}, {
       3.5, -4.642337217350632}, {3.404942744332997, -4.595057255667003}, {
       3.491446564961186, -4.508553435038814}}], 
      PolygonBox[{{3.404942744332997, -4.595057255667003}, {
       3.2302516425362553`, -4.562655006646477}, {
       3.491446564961186, -4.508553435038814}, {
       3.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{3.357662782649368, -4.5}, {
       3.491446564961186, -4.508553435038814}, {
       3.2302516425362553`, -4.562655006646477}, {3.357662782649368, -4.5}}], 
      PolygonBox[{{3.2302516425362553`, -4.562655006646477}, {
       3.0842925895560604`, -4.562500018967059}, {3.357662782649368, -4.5}, {
       3.2302516425362553`, -4.562655006646477}}], 
      PolygonBox[{{3.2059090053732557`, -4.5}, {3.357662782649368, -4.5}, {
       3.0842925895560604`, -4.562500018967059}, {
       3.2059090053732557`, -4.5}}], 
      PolygonBox[{{3.0842925895560604`, -4.562500018967059}, {
       3.0001055272204877`, -4.5625}, {3.2059090053732557`, -4.5}, {
       3.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{3.07794195802689, -4.5}, {3.2059090053732557`, -4.5}, {
       3.0001055272204877`, -4.5625}, {3.07794195802689, -4.5}}], 
      PolygonBox[{{3.0001055272204877`, -4.5625}, {
       2.915707410443943, -4.562500018967059}, {3.07794195802689, -4.5}, {
       3.0001055272204877`, -4.5625}}], 
      PolygonBox[{{2.7940909946955546`, -4.5}, {3.07794195802689, -4.5}, {
       2.915707410443943, -4.562500018967059}, {2.7940909946955546`, -4.5}}], 
      PolygonBox[{{2.915707410443943, -4.562500018967059}, {
       2.769748357463745, -4.562655006646477}, {2.7940909946955546`, -4.5}, {
       2.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{2.642337217350634, -4.5}, {2.7940909946955546`, -4.5}, {
       2.769748357463745, -4.562655006646477}, {2.642337217350634, -4.5}}], 
      PolygonBox[{{2.769748357463745, -4.562655006646477}, {
       2.595057255667003, -4.595057255667003}, {2.642337217350634, -4.5}, {
       2.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{3.5, -4.5}, {2.642337217350634, -4.5}, {
       2.595057255667003, -4.595057255667003}, {3.5, -4.5}}], 
      PolygonBox[{{2.595057255667003, -4.595057255667003}, {
       2.5626550066464766`, -4.769748357463745}, {3.5, -4.5}, {
       2.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{2.5, -4.642337217350631}, {3.5, -4.5}, {
       2.5626550066464766`, -4.769748357463745}, {2.5, -4.642337217350631}}], 
      PolygonBox[{{2.5626550066464766`, -4.769748357463745}, {
       2.562500018967059, -4.915707410443938}, {2.5, -4.642337217350631}, {
       2.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{2.5, -4.794090994717101}, {2.5, -4.642337217350631}, {
       2.562500018967059, -4.915707410443938}, {2.5, -4.794090994717101}}], 
      PolygonBox[{{2.562500018967059, -4.915707410443938}, {
       2.5625, -4.999876821937004}, {2.5, -4.794090994717101}, {
       2.562500018967059, -4.915707410443938}}], 
      PolygonBox[{{2.5, -4.9193213332412995`}, {2.5, -4.794090994717101}, {
       2.5625, -4.999876821937004}, {2.5, -4.9193213332412995`}}], 
      PolygonBox[{{2.5625, -4.999876821937004}, {
       2.562500018967059, -5.084292589556055}, {2.5, -4.9193213332412995`}, {
       2.5625, -4.999876821937004}}], 
      PolygonBox[{{2.5, -5.205909005145278}, {2.5, -4.9193213332412995`}, {
       2.562500018967059, -5.084292589556055}, {2.5, -5.205909005145278}}], 
      PolygonBox[{{2.562500018967059, -5.084292589556055}, {
       2.5626550066464766`, -5.230251642536254}, {2.5, -5.205909005145278}, {
       2.562500018967059, -5.084292589556055}}], 
      PolygonBox[{{2.5, -5.357662782649365}, {2.5, -5.205909005145278}, {
       2.5626550066464766`, -5.230251642536254}, {2.5, -5.357662782649365}}], 
      PolygonBox[{{2.5626550066464766`, -5.230251642536254}, {
       2.595057255667003, -5.404942744332997}, {2.5, -5.357662782649365}, {
       2.5626550066464766`, -5.230251642536254}}], 
      PolygonBox[{{2.5, -4.5}, {2.5, -5.357662782649365}, {
       2.595057255667003, -5.404942744332997}, {2.5, -4.5}}], 
      PolygonBox[{{2.595057255667003, -5.404942744332997}, {
       2.769748357463745, -5.437344993353523}, {2.5, -4.5}, {
       2.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{2.5, -5.5}, {2.5, -4.5}, {
       2.769748357463745, -5.437344993353523}, {2.5, -5.5}}], 
      PolygonBox[{{2.769748357463745, -5.437344993353523}, {
       2.915707410443936, -5.437499981032941}, {2.5, -5.5}, {
       2.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{2.794090994433172, -5.5}, {2.5, -5.5}, {
       2.915707410443936, -5.437499981032941}, {2.794090994433172, -5.5}}], 
      PolygonBox[{{2.915707410443936, -5.437499981032941}, {
       3.000134841831043, -5.4375}, {2.794090994433172, -5.5}, {
       2.915707410443936, -5.437499981032941}}], 
      PolygonBox[{{3.0823238704010616`, -5.5}, {2.794090994433172, -5.5}, {
       3.000134841831043, -5.4375}, {3.0823238704010616`, -5.5}}], 
      PolygonBox[{{3.000134841831043, -5.4375}, {
       3.0842925895560533`, -5.437499981032941}, {
       3.0823238704010616`, -5.5}, {3.000134841831043, -5.4375}}], 
      PolygonBox[{{3.2059090053603976`, -5.5}, {3.0823238704010616`, -5.5}, {
       3.0842925895560533`, -5.437499981032941}, {
       3.2059090053603976`, -5.5}}], 
      PolygonBox[{{3.0842925895560533`, -5.437499981032941}, {
       3.230251642536255, -5.437344993353523}, {3.2059090053603976`, -5.5}, {
       3.0842925895560533`, -5.437499981032941}}], 
      PolygonBox[{{3.357662782649371, -5.5}, {3.2059090053603976`, -5.5}, {
       3.230251642536255, -5.437344993353523}, {3.357662782649371, -5.5}}], 
      PolygonBox[{{3.230251642536255, -5.437344993353523}, {
       3.404942744332997, -5.404942744332997}, {3.357662782649371, -5.5}, {
       3.230251642536255, -5.437344993353523}}], 
      PolygonBox[{{3.5, -5.5}, {3.357662782649371, -5.5}, {
       3.404942744332997, -5.404942744332997}, {3.5, -5.5}}], 
      PolygonBox[{{3.404942744332997, -5.404942744332997}, {
       3.404942744332997, -5.404942744332997}, {3.5, -5.5}, {
       3.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{3.5, -5.5}, {3.5, -5.5}, {
       3.404942744332997, -5.404942744332997}, {3.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, -4.}, {2.5208333333333335`, -4.}, {
       2.5416666666666665`, -4.}, {2.5625, -4.}, {2.5833333333333335`, -4.}, {
       2.6041666666666665`, -4.}, {2.625, -4.}, {2.625, -4.}, {
       2.6041666666666665`, -4.}, {2.5833333333333335`, -4.}, {2.5625, -4.}, {
       2.5416666666666665`, -4.}, {2.5208333333333335`, -4.}, {2.5, -4.}, {
       2.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, -4.}, {3.3958333333333335`, -4.}, {
       3.4166666666666665`, -4.}, {3.4375, -4.}, {3.4583333333333335`, -4.}, {
       3.4791666666666665`, -4.}, {3.5, -4.}, {3.5, -4.}, {
       3.4791666666666665`, -4.}, {3.4583333333333335`, -4.}, {3.4375, -4.}, {
       3.4166666666666665`, -4.}, {3.3958333333333335`, -4.}, {3.375, -4.}, {
       3.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -4.5}, {3., -4.479166666666667}, {
       3., -4.458333333333333}, {3., -4.4375}, {3., -4.416666666666667}, {
       3., -4.395833333333333}, {3., -4.375}, {3., -4.375}, {
       3., -4.395833333333333}, {3., -4.416666666666667}, {3., -4.4375}, {
       3., -4.458333333333333}, {3., -4.479166666666667}, {3., -4.5}, {
       3., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -3.625}, {3., -3.6041666666666665`}, {
       3., -3.5833333333333335`}, {3., -3.5625}, {3., -3.5416666666666665`}, {
       3., -3.5208333333333335`}, {3., -3.5}, {3., -3.5}, {
       3., -3.5208333333333335`}, {3., -3.5416666666666665`}, {3., -3.5625}, {
       3., -3.5833333333333335`}, {3., -3.6041666666666665`}, {3., -3.625}, {
       3., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, -4.}, {2.75, -4.}, {2.875, -4.}, {3., -4.}, {
       3.125, -4.}, {3.25, -4.}, {3.375, -4.}, {3.375, -4.}, {3.25, -4.}, {
       3.125, -4.}, {3., -4.}, {2.875, -4.}, {2.75, -4.}, {2.625, -4.}, {
       2.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -4.375}, {3., -4.25}, {3., -4.125}, {3., -4.}, {
       3., -3.875}, {3., -3.75}, {3., -3.625}, {3., -3.625}, {3., -3.75}, {
       3., -3.875}, {3., -4.}, {3., -4.125}, {3., -4.25}, {3., -4.375}, {
       3., -4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhBa4MCri+v2XXnK5bBR+q2UlSX/AQP3E63S
M7kg8g18B2a/nX2TT57LIVUoRe3jA94DEHFOhws7zKuepPEe8H8i9PToMQ4H
Mb1AR20pqDwDB9R83gMQc9lR5RvY4Poh5rLCzYeIs8Lth+hjhbsPYi4r3P0w
efWizk9JyQKo+g8IHEiBmn/229mcdn5BuP0zlJ8c6vURhLvva0Z4/KsiQVT3
Nwge8IP6Dyb/HwTqOeH6YeFzDmo+SvgdQISvBtR96OEPAK8EhGo=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DlD6wOpVIMAF54eCASecD6E50NSzwflhYPWs
aOpZCPIh9vDC+RBz+dDUC6DJC6DpF0RTL4TBD0VxnxCa+2HqOdDUc8L5q1DC
B6aehyAf1X08aO6HqRdAk+eD88NQwgcRXwBWXVAl
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, -4.265165042944956}, {
       3.3247595264191645`, -4.1875}, {
       3.404942744332997, -4.404942744332997}, {
       3.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{3.4373449933535234`, -4.230251642536255}, {
       3.404942744332997, -4.404942744332997}, {
       3.3247595264191645`, -4.1875}, {
       3.4373449933535234`, -4.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, -4.1875}, {
       3.3622221848584006`, -4.097057141913445}, {
       3.4373449933535234`, -4.230251642536255}, {
       3.3247595264191645`, -4.1875}}], 
      PolygonBox[{{3.437499981032941, -4.084292589556062}, {
       3.4373449933535234`, -4.230251642536255}, {
       3.3622221848584006`, -4.097057141913445}, {
       3.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{3.3622221848584006`, -4.097057141913445}, {3.375, -4.}, {
       3.437499981032941, -4.084292589556062}, {
       3.3622221848584006`, -4.097057141913445}}], 
      PolygonBox[{{3.4375, -4.}, {3.437499981032941, -4.084292589556062}, {
       3.375, -4.}, {3.4375, -4.}}], 
      PolygonBox[{{3.375, -4.}, {3.3622221848584006`, -3.9029428580865546`}, {
       3.4375, -4.}, {3.375, -4.}}], 
      PolygonBox[{{3.437499981032941, -3.915707410443938}, {3.4375, -4.}, {
       3.3622221848584006`, -3.9029428580865546`}, {
       3.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{3.3622221848584006`, -3.9029428580865546`}, {
       3.3247595264191645`, -3.8125}, {
       3.437499981032941, -3.915707410443938}, {
       3.3622221848584006`, -3.9029428580865546`}}], 
      PolygonBox[{{3.4373449933535234`, -3.769748357463745}, {
       3.437499981032941, -3.915707410443938}, {
       3.3247595264191645`, -3.8125}, {
       3.4373449933535234`, -3.769748357463745}}], 
      PolygonBox[{{3.3247595264191645`, -3.8125}, {
       3.2651650429449552`, -3.7348349570550448`}, {
       3.4373449933535234`, -3.769748357463745}, {
       3.3247595264191645`, -3.8125}}], 
      PolygonBox[{{3.404942744332997, -3.595057255667003}, {
       3.4373449933535234`, -3.769748357463745}, {
       3.2651650429449552`, -3.7348349570550448`}, {
       3.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{3.2651650429449552`, -3.7348349570550448`}, {
       3.1875, -3.6752404735808355`}, {
       3.404942744332997, -3.595057255667003}, {
       3.2651650429449552`, -3.7348349570550448`}}], 
      PolygonBox[{{3.2302516425362553`, -3.5626550066464766`}, {
       3.404942744332997, -3.595057255667003}, {
       3.1875, -3.6752404735808355`}, {
       3.2302516425362553`, -3.5626550066464766`}}], 
      PolygonBox[{{3.1875, -3.6752404735808355`}, {
       3.0970571419134454`, -3.6377778151415994`}, {
       3.2302516425362553`, -3.5626550066464766`}, {
       3.1875, -3.6752404735808355`}}], 
      PolygonBox[{{3.0842925895560604`, -3.562500018967059}, {
       3.2302516425362553`, -3.5626550066464766`}, {
       3.0970571419134454`, -3.6377778151415994`}, {
       3.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{3.0970571419134454`, -3.6377778151415994`}, {3., -3.625}, {
       3.0842925895560604`, -3.562500018967059}, {
       3.0970571419134454`, -3.6377778151415994`}}], 
      PolygonBox[{{3.0001055272204877`, -3.5625}, {
       3.0842925895560604`, -3.562500018967059}, {3., -3.625}, {
       3.0001055272204877`, -3.5625}}], 
      PolygonBox[{{3., -3.625}, {2.902942858086555, -3.6377778151415994`}, {
       3.0001055272204877`, -3.5625}, {3., -3.625}}], 
      PolygonBox[{{2.915707410443943, -3.562500018967059}, {
       3.0001055272204877`, -3.5625}, {
       2.902942858086555, -3.6377778151415994`}, {
       2.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{2.902942858086555, -3.6377778151415994`}, {
       2.8125, -3.6752404735808355`}, {
       2.915707410443943, -3.562500018967059}, {
       2.902942858086555, -3.6377778151415994`}}], 
      PolygonBox[{{2.769748357463745, -3.5626550066464766`}, {
       2.915707410443943, -3.562500018967059}, {
       2.8125, -3.6752404735808355`}, {
       2.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{2.8125, -3.6752404735808355`}, {
       2.7348349570550448`, -3.7348349570550448`}, {
       2.769748357463745, -3.5626550066464766`}, {
       2.8125, -3.6752404735808355`}}], 
      PolygonBox[{{2.595057255667003, -3.595057255667003}, {
       2.769748357463745, -3.5626550066464766`}, {
       2.7348349570550448`, -3.7348349570550448`}, {
       2.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{2.7348349570550448`, -3.7348349570550448`}, {
       2.6752404735808355`, -3.8125}, {
       2.595057255667003, -3.595057255667003}, {
       2.7348349570550448`, -3.7348349570550448`}}], 
      PolygonBox[{{2.5626550066464766`, -3.7697483574637447`}, {
       2.595057255667003, -3.595057255667003}, {
       2.6752404735808355`, -3.8125}, {
       2.5626550066464766`, -3.7697483574637447`}}], 
      PolygonBox[{{2.6752404735808355`, -3.8125}, {
       2.6377778151415994`, -3.9029428580865546`}, {
       2.5626550066464766`, -3.7697483574637447`}, {
       2.6752404735808355`, -3.8125}}], 
      PolygonBox[{{2.562500018967059, -3.9157074104439378`}, {
       2.5626550066464766`, -3.7697483574637447`}, {
       2.6377778151415994`, -3.9029428580865546`}, {
       2.562500018967059, -3.9157074104439378`}}], 
      PolygonBox[{{2.6377778151415994`, -3.9029428580865546`}, {2.625, -4.}, {
       2.562500018967059, -3.9157074104439378`}, {
       2.6377778151415994`, -3.9029428580865546`}}], 
      PolygonBox[{{2.5625, -3.9998768219370047`}, {
       2.562500018967059, -3.9157074104439378`}, {2.625, -4.}, {
       2.5625, -3.9998768219370047`}}], 
      PolygonBox[{{2.625, -4.}, {2.6377778151415994`, -4.097057141913445}, {
       2.5625, -3.9998768219370047`}, {2.625, -4.}}], 
      PolygonBox[{{2.562500018967059, -4.084292589556055}, {
       2.5625, -3.9998768219370047`}, {
       2.6377778151415994`, -4.097057141913445}, {
       2.562500018967059, -4.084292589556055}}], 
      PolygonBox[{{2.6377778151415994`, -4.097057141913445}, {
       2.6752404735808355`, -4.1875}, {
       2.562500018967059, -4.084292589556055}, {
       2.6377778151415994`, -4.097057141913445}}], 
      PolygonBox[{{2.5626550066464766`, -4.230251642536254}, {
       2.562500018967059, -4.084292589556055}, {
       2.6752404735808355`, -4.1875}, {
       2.5626550066464766`, -4.230251642536254}}], 
      PolygonBox[{{2.6752404735808355`, -4.1875}, {
       2.7348349570550448`, -4.265165042944956}, {
       2.5626550066464766`, -4.230251642536254}, {
       2.6752404735808355`, -4.1875}}], 
      PolygonBox[{{2.595057255667003, -4.404942744332997}, {
       2.5626550066464766`, -4.230251642536254}, {
       2.7348349570550448`, -4.265165042944956}, {
       2.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, -4.265165042944956}, {
       2.8125, -4.3247595264191645`}, {
       2.595057255667003, -4.404942744332997}, {
       2.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{2.769748357463745, -4.437344993353523}, {
       2.595057255667003, -4.404942744332997}, {
       2.8125, -4.3247595264191645`}, {
       2.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{2.8125, -4.3247595264191645`}, {
       2.9029428580865546`, -4.362222184858401}, {
       2.769748357463745, -4.437344993353523}, {
       2.8125, -4.3247595264191645`}}], 
      PolygonBox[{{2.915707410443936, -4.437499981032941}, {
       2.769748357463745, -4.437344993353523}, {
       2.9029428580865546`, -4.362222184858401}, {
       2.915707410443936, -4.437499981032941}}], 
      PolygonBox[{{2.9029428580865546`, -4.362222184858401}, {3., -4.375}, {
       2.915707410443936, -4.437499981032941}, {
       2.9029428580865546`, -4.362222184858401}}], 
      PolygonBox[{{3.000134841831043, -4.4375}, {
       2.915707410443936, -4.437499981032941}, {3., -4.375}, {
       3.000134841831043, -4.4375}}], 
      PolygonBox[{{3., -4.375}, {3.097057141913445, -4.362222184858401}, {
       3.000134841831043, -4.4375}, {3., -4.375}}], 
      PolygonBox[{{3.0842925895560533`, -4.437499981032941}, {
       3.000134841831043, -4.4375}, {3.097057141913445, -4.362222184858401}, {
       3.0842925895560533`, -4.437499981032941}}], 
      PolygonBox[{{3.097057141913445, -4.362222184858401}, {
       3.1874999999999996`, -4.3247595264191645`}, {
       3.0842925895560533`, -4.437499981032941}, {
       3.097057141913445, -4.362222184858401}}], 
      PolygonBox[{{3.230251642536255, -4.437344993353523}, {
       3.0842925895560533`, -4.437499981032941}, {
       3.1874999999999996`, -4.3247595264191645`}, {
       3.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{3.1874999999999996`, -4.3247595264191645`}, {
       3.2651650429449552`, -4.265165042944956}, {
       3.230251642536255, -4.437344993353523}, {
       3.1874999999999996`, -4.3247595264191645`}}], 
      PolygonBox[{{3.404942744332997, -4.404942744332997}, {
       3.230251642536255, -4.437344993353523}, {
       3.2651650429449552`, -4.265165042944956}, {
       3.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, -4.265165042944956}, {
       3.2651650429449552`, -4.265165042944956}, {
       3.404942744332997, -4.404942744332997}, {
       3.2651650429449552`, -4.265165042944956}}], 
      PolygonBox[{{3.404942744332997, -4.404942744332997}, {
       3.404942744332997, -4.404942744332997}, {
       3.2651650429449552`, -4.265165042944956}, {
       3.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{3.404942744332997, -4.404942744332997}, {
       3.4373449933535234`, -4.230251642536255}, {3.5, -4.5}, {
       3.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{3.5, -4.357662782649368}, {3.5, -4.5}, {
       3.4373449933535234`, -4.230251642536255}, {3.5, -4.357662782649368}}], 
      PolygonBox[{{3.4373449933535234`, -4.230251642536255}, {
       3.437499981032941, -4.084292589556062}, {3.5, -4.357662782649368}, {
       3.4373449933535234`, -4.230251642536255}}], 
      PolygonBox[{{3.5, -4.20590900530174}, {3.5, -4.357662782649368}, {
       3.437499981032941, -4.084292589556062}, {3.5, -4.20590900530174}}], 
      PolygonBox[{{3.437499981032941, -4.084292589556062}, {3.4375, -4.}, {
       3.5, -4.20590900530174}, {3.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{3.5, -4.}, {3.5, -4.20590900530174}, {3.4375, -4.}, {
       3.5, -4.}}], 
      PolygonBox[{{3.4375, -4.}, {3.437499981032941, -3.915707410443938}, {
       3.5, -4.}, {3.4375, -4.}}], 
      PolygonBox[{{3.5, -3.79409099469826}, {3.5, -4.}, {
       3.437499981032941, -3.915707410443938}, {3.5, -3.79409099469826}}], 
      PolygonBox[{{3.437499981032941, -3.915707410443938}, {
       3.4373449933535234`, -3.769748357463745}, {3.5, -3.79409099469826}, {
       3.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{3.5, -3.6423372173506325`}, {3.5, -3.79409099469826}, {
       3.4373449933535234`, -3.769748357463745}, {
       3.5, -3.6423372173506325`}}], 
      PolygonBox[{{3.4373449933535234`, -3.769748357463745}, {
       3.404942744332997, -3.595057255667003}, {3.5, -3.6423372173506325`}, {
       3.4373449933535234`, -3.769748357463745}}], 
      PolygonBox[{{3.491446564961186, -3.508553435038814}, {
       3.5, -3.6423372173506325`}, {3.404942744332997, -3.595057255667003}, {
       3.491446564961186, -3.508553435038814}}], 
      PolygonBox[{{3.404942744332997, -3.595057255667003}, {
       3.2302516425362553`, -3.5626550066464766`}, {
       3.491446564961186, -3.508553435038814}, {
       3.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{3.357662782649368, -3.5}, {
       3.491446564961186, -3.508553435038814}, {
       3.2302516425362553`, -3.5626550066464766`}, {
       3.357662782649368, -3.5}}], 
      PolygonBox[{{3.2302516425362553`, -3.5626550066464766`}, {
       3.0842925895560604`, -3.562500018967059}, {3.357662782649368, -3.5}, {
       3.2302516425362553`, -3.5626550066464766`}}], 
      PolygonBox[{{3.2059090053732557`, -3.5}, {3.357662782649368, -3.5}, {
       3.0842925895560604`, -3.562500018967059}, {
       3.2059090053732557`, -3.5}}], 
      PolygonBox[{{3.0842925895560604`, -3.562500018967059}, {
       3.0001055272204877`, -3.5625}, {3.2059090053732557`, -3.5}, {
       3.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{3.07794195802689, -3.5}, {3.2059090053732557`, -3.5}, {
       3.0001055272204877`, -3.5625}, {3.07794195802689, -3.5}}], 
      PolygonBox[{{3.0001055272204877`, -3.5625}, {
       2.915707410443943, -3.562500018967059}, {3.07794195802689, -3.5}, {
       3.0001055272204877`, -3.5625}}], 
      PolygonBox[{{2.7940909946955546`, -3.5}, {3.07794195802689, -3.5}, {
       2.915707410443943, -3.562500018967059}, {2.7940909946955546`, -3.5}}], 
      PolygonBox[{{2.915707410443943, -3.562500018967059}, {
       2.769748357463745, -3.5626550066464766`}, {
       2.7940909946955546`, -3.5}, {2.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{2.642337217350634, -3.5}, {2.7940909946955546`, -3.5}, {
       2.769748357463745, -3.5626550066464766`}, {2.642337217350634, -3.5}}], 
      PolygonBox[{{2.769748357463745, -3.5626550066464766`}, {
       2.595057255667003, -3.595057255667003}, {2.642337217350634, -3.5}, {
       2.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{3.5, -3.5}, {2.642337217350634, -3.5}, {
       2.595057255667003, -3.595057255667003}, {3.5, -3.5}}], 
      PolygonBox[{{2.595057255667003, -3.595057255667003}, {
       2.5626550066464766`, -3.7697483574637447`}, {3.5, -3.5}, {
       2.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{2.5, -3.642337217350631}, {3.5, -3.5}, {
       2.5626550066464766`, -3.7697483574637447`}, {
       2.5, -3.642337217350631}}], 
      PolygonBox[{{2.5626550066464766`, -3.7697483574637447`}, {
       2.562500018967059, -3.9157074104439378`}, {2.5, -3.642337217350631}, {
       2.5626550066464766`, -3.7697483574637447`}}], 
      PolygonBox[{{2.5, -3.794090994717101}, {2.5, -3.642337217350631}, {
       2.562500018967059, -3.9157074104439378`}, {2.5, -3.794090994717101}}], 
      PolygonBox[{{2.562500018967059, -3.9157074104439378`}, {
       2.5625, -3.9998768219370047`}, {2.5, -3.794090994717101}, {
       2.562500018967059, -3.9157074104439378`}}], 
      PolygonBox[{{2.5, -3.9193213332413}, {2.5, -3.794090994717101}, {
       2.5625, -3.9998768219370047`}, {2.5, -3.9193213332413}}], 
      PolygonBox[{{2.5625, -3.9998768219370047`}, {
       2.562500018967059, -4.084292589556055}, {2.5, -3.9193213332413}, {
       2.5625, -3.9998768219370047`}}], 
      PolygonBox[{{2.5, -4.205909005145278}, {2.5, -3.9193213332413}, {
       2.562500018967059, -4.084292589556055}, {2.5, -4.205909005145278}}], 
      PolygonBox[{{2.562500018967059, -4.084292589556055}, {
       2.5626550066464766`, -4.230251642536254}, {2.5, -4.205909005145278}, {
       2.562500018967059, -4.084292589556055}}], 
      PolygonBox[{{2.5, -4.357662782649365}, {2.5, -4.205909005145278}, {
       2.5626550066464766`, -4.230251642536254}, {2.5, -4.357662782649365}}], 
      PolygonBox[{{2.5626550066464766`, -4.230251642536254}, {
       2.595057255667003, -4.404942744332997}, {2.5, -4.357662782649365}, {
       2.5626550066464766`, -4.230251642536254}}], 
      PolygonBox[{{2.5, -3.5}, {2.5, -4.357662782649365}, {
       2.595057255667003, -4.404942744332997}, {2.5, -3.5}}], 
      PolygonBox[{{2.595057255667003, -4.404942744332997}, {
       2.769748357463745, -4.437344993353523}, {2.5, -3.5}, {
       2.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{2.5, -4.5}, {2.5, -3.5}, {
       2.769748357463745, -4.437344993353523}, {2.5, -4.5}}], 
      PolygonBox[{{2.769748357463745, -4.437344993353523}, {
       2.915707410443936, -4.437499981032941}, {2.5, -4.5}, {
       2.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{2.794090994433172, -4.5}, {2.5, -4.5}, {
       2.915707410443936, -4.437499981032941}, {2.794090994433172, -4.5}}], 
      PolygonBox[{{2.915707410443936, -4.437499981032941}, {
       3.000134841831043, -4.4375}, {2.794090994433172, -4.5}, {
       2.915707410443936, -4.437499981032941}}], 
      PolygonBox[{{3.0823238704010616`, -4.5}, {2.794090994433172, -4.5}, {
       3.000134841831043, -4.4375}, {3.0823238704010616`, -4.5}}], 
      PolygonBox[{{3.000134841831043, -4.4375}, {
       3.0842925895560533`, -4.437499981032941}, {
       3.0823238704010616`, -4.5}, {3.000134841831043, -4.4375}}], 
      PolygonBox[{{3.2059090053603976`, -4.5}, {3.0823238704010616`, -4.5}, {
       3.0842925895560533`, -4.437499981032941}, {
       3.2059090053603976`, -4.5}}], 
      PolygonBox[{{3.0842925895560533`, -4.437499981032941}, {
       3.230251642536255, -4.437344993353523}, {3.2059090053603976`, -4.5}, {
       3.0842925895560533`, -4.437499981032941}}], 
      PolygonBox[{{3.357662782649371, -4.5}, {3.2059090053603976`, -4.5}, {
       3.230251642536255, -4.437344993353523}, {3.357662782649371, -4.5}}], 
      PolygonBox[{{3.230251642536255, -4.437344993353523}, {
       3.404942744332997, -4.404942744332997}, {3.357662782649371, -4.5}, {
       3.230251642536255, -4.437344993353523}}], 
      PolygonBox[{{3.5, -4.5}, {3.357662782649371, -4.5}, {
       3.404942744332997, -4.404942744332997}, {3.5, -4.5}}], 
      PolygonBox[{{3.404942744332997, -4.404942744332997}, {
       3.404942744332997, -4.404942744332997}, {3.5, -4.5}, {
       3.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{3.5, -4.5}, {3.5, -4.5}, {
       3.404942744332997, -4.404942744332997}, {3.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, -3.}, {2.5208333333333335`, -3.}, {
       2.5416666666666665`, -3.}, {2.5625, -3.}, {2.5833333333333335`, -3.}, {
       2.6041666666666665`, -3.}, {2.625, -3.}, {2.625, -3.}, {
       2.6041666666666665`, -3.}, {2.5833333333333335`, -3.}, {2.5625, -3.}, {
       2.5416666666666665`, -3.}, {2.5208333333333335`, -3.}, {2.5, -3.}, {
       2.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, -3.}, {3.3958333333333335`, -3.}, {
       3.4166666666666665`, -3.}, {3.4375, -3.}, {3.4583333333333335`, -3.}, {
       3.4791666666666665`, -3.}, {3.5, -3.}, {3.5, -3.}, {
       3.4791666666666665`, -3.}, {3.4583333333333335`, -3.}, {3.4375, -3.}, {
       3.4166666666666665`, -3.}, {3.3958333333333335`, -3.}, {3.375, -3.}, {
       3.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -3.5}, {3., -3.4791666666666665`}, {
       3., -3.4583333333333335`}, {3., -3.4375}, {3., -3.4166666666666665`}, {
       3., -3.3958333333333335`}, {3., -3.375}, {3., -3.375}, {
       3., -3.3958333333333335`}, {3., -3.4166666666666665`}, {3., -3.4375}, {
       3., -3.4583333333333335`}, {3., -3.4791666666666665`}, {3., -3.5}, {
       3., -3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -2.625}, {3., -2.6041666666666665`}, {
       3., -2.5833333333333335`}, {3., -2.5625}, {3., -2.5416666666666665`}, {
       3., -2.5208333333333335`}, {3., -2.5}, {3., -2.5}, {
       3., -2.5208333333333335`}, {3., -2.5416666666666665`}, {3., -2.5625}, {
       3., -2.5833333333333335`}, {3., -2.6041666666666665`}, {3., -2.625}, {
       3., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, -3.}, {2.75, -3.}, {2.875, -3.}, {3., -3.}, {
       3.125, -3.}, {3.25, -3.}, {3.375, -3.}, {3.375, -3.}, {3.25, -3.}, {
       3.125, -3.}, {3., -3.}, {2.875, -3.}, {2.75, -3.}, {2.625, -3.}, {
       2.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -3.375}, {3., -3.25}, {3., -3.125}, {3., -3.}, {
       3., -2.875}, {3., -2.75}, {3., -2.625}, {3., -2.625}, {3., -2.75}, {
       3., -2.875}, {3., -3.}, {3., -3.125}, {3., -3.25}, {3., -3.375}, {
       3., -3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhCa48Cri+v2XXnK5bBR+q2UlSX7AQP3E63S
M7kg8g1sB2a/nX2TT57LIVUoRe3jA9YDEHFOhws7zKuepLEe8H8i9PToMQ4H
Mb1AR20pqDwDB9R81gNQc1HlG9jg+qHmws2HisPth+qDuw9qLtz9MHk/iDvQ
9HMeSIGaD/UH3H6oP+Hug4YDmvu5D0DNhcv/B4F6Trh+WPjAzEcNP054+ELD
6QB6+AMAmJKE7Q==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhCa5cDqVSDABeeHggEnnA+hOdDUs8H5YWD1
rGjqWQjyIfawwvlQc9HUc6Cp54TzV0HcjaaeB4MfiuI+HjT3w9RzoKnnhPNX
oYQPTD0PQf5qFPfxoLkfpp4DTT0bnB+GEj6I+AIApIJPWg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, -3.2651650429449552`}, {
       3.3247595264191645`, -3.1875}, {
       3.404942744332997, -3.404942744332997}, {
       3.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{3.4373449933535234`, -3.2302516425362553`}, {
       3.404942744332997, -3.404942744332997}, {
       3.3247595264191645`, -3.1875}, {
       3.4373449933535234`, -3.2302516425362553`}}], 
      PolygonBox[{{3.3247595264191645`, -3.1875}, {
       3.3622221848584006`, -3.0970571419134454`}, {
       3.4373449933535234`, -3.2302516425362553`}, {
       3.3247595264191645`, -3.1875}}], 
      PolygonBox[{{3.437499981032941, -3.084292589556062}, {
       3.4373449933535234`, -3.2302516425362553`}, {
       3.3622221848584006`, -3.0970571419134454`}, {
       3.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{3.3622221848584006`, -3.0970571419134454`}, {3.375, -3.}, {
       3.437499981032941, -3.084292589556062}, {
       3.3622221848584006`, -3.0970571419134454`}}], 
      PolygonBox[{{3.4375, -3.}, {3.437499981032941, -3.084292589556062}, {
       3.375, -3.}, {3.4375, -3.}}], 
      PolygonBox[{{3.375, -3.}, {3.3622221848584006`, -2.9029428580865546`}, {
       3.4375, -3.}, {3.375, -3.}}], 
      PolygonBox[{{3.437499981032941, -2.915707410443938}, {3.4375, -3.}, {
       3.3622221848584006`, -2.9029428580865546`}, {
       3.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{3.3622221848584006`, -2.9029428580865546`}, {
       3.3247595264191645`, -2.8125}, {
       3.437499981032941, -2.915707410443938}, {
       3.3622221848584006`, -2.9029428580865546`}}], 
      PolygonBox[{{3.4373449933535234`, -2.769748357463745}, {
       3.437499981032941, -2.915707410443938}, {
       3.3247595264191645`, -2.8125}, {
       3.4373449933535234`, -2.769748357463745}}], 
      PolygonBox[{{3.3247595264191645`, -2.8125}, {
       3.2651650429449552`, -2.7348349570550448`}, {
       3.4373449933535234`, -2.769748357463745}, {
       3.3247595264191645`, -2.8125}}], 
      PolygonBox[{{3.404942744332997, -2.595057255667003}, {
       3.4373449933535234`, -2.769748357463745}, {
       3.2651650429449552`, -2.7348349570550448`}, {
       3.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{3.2651650429449552`, -2.7348349570550448`}, {
       3.1875, -2.6752404735808355`}, {
       3.404942744332997, -2.595057255667003}, {
       3.2651650429449552`, -2.7348349570550448`}}], 
      PolygonBox[{{3.2302516425362553`, -2.5626550066464766`}, {
       3.404942744332997, -2.595057255667003}, {
       3.1875, -2.6752404735808355`}, {
       3.2302516425362553`, -2.5626550066464766`}}], 
      PolygonBox[{{3.1875, -2.6752404735808355`}, {
       3.0970571419134454`, -2.6377778151415994`}, {
       3.2302516425362553`, -2.5626550066464766`}, {
       3.1875, -2.6752404735808355`}}], 
      PolygonBox[{{3.0842925895560604`, -2.562500018967059}, {
       3.2302516425362553`, -2.5626550066464766`}, {
       3.0970571419134454`, -2.6377778151415994`}, {
       3.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{3.0970571419134454`, -2.6377778151415994`}, {3., -2.625}, {
       3.0842925895560604`, -2.562500018967059}, {
       3.0970571419134454`, -2.6377778151415994`}}], 
      PolygonBox[{{3.0001055272204877`, -2.5625}, {
       3.0842925895560604`, -2.562500018967059}, {3., -2.625}, {
       3.0001055272204877`, -2.5625}}], 
      PolygonBox[{{3., -2.625}, {2.902942858086555, -2.6377778151415994`}, {
       3.0001055272204877`, -2.5625}, {3., -2.625}}], 
      PolygonBox[{{2.915707410443943, -2.562500018967059}, {
       3.0001055272204877`, -2.5625}, {
       2.902942858086555, -2.6377778151415994`}, {
       2.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{2.902942858086555, -2.6377778151415994`}, {
       2.8125, -2.6752404735808355`}, {
       2.915707410443943, -2.562500018967059}, {
       2.902942858086555, -2.6377778151415994`}}], 
      PolygonBox[{{2.769748357463745, -2.5626550066464766`}, {
       2.915707410443943, -2.562500018967059}, {
       2.8125, -2.6752404735808355`}, {
       2.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{2.8125, -2.6752404735808355`}, {
       2.7348349570550448`, -2.7348349570550448`}, {
       2.769748357463745, -2.5626550066464766`}, {
       2.8125, -2.6752404735808355`}}], 
      PolygonBox[{{2.595057255667003, -2.595057255667003}, {
       2.769748357463745, -2.5626550066464766`}, {
       2.7348349570550448`, -2.7348349570550448`}, {
       2.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{2.7348349570550448`, -2.7348349570550448`}, {
       2.6752404735808355`, -2.8125}, {
       2.595057255667003, -2.595057255667003}, {
       2.7348349570550448`, -2.7348349570550448`}}], 
      PolygonBox[{{2.5626550066464766`, -2.7697483574637447`}, {
       2.595057255667003, -2.595057255667003}, {
       2.6752404735808355`, -2.8125}, {
       2.5626550066464766`, -2.7697483574637447`}}], 
      PolygonBox[{{2.6752404735808355`, -2.8125}, {
       2.6377778151415994`, -2.9029428580865546`}, {
       2.5626550066464766`, -2.7697483574637447`}, {
       2.6752404735808355`, -2.8125}}], 
      PolygonBox[{{2.562500018967059, -2.9157074104439378`}, {
       2.5626550066464766`, -2.7697483574637447`}, {
       2.6377778151415994`, -2.9029428580865546`}, {
       2.562500018967059, -2.9157074104439378`}}], 
      PolygonBox[{{2.6377778151415994`, -2.9029428580865546`}, {2.625, -3.}, {
       2.562500018967059, -2.9157074104439378`}, {
       2.6377778151415994`, -2.9029428580865546`}}], 
      PolygonBox[{{2.5625, -2.9998768219370047`}, {
       2.562500018967059, -2.9157074104439378`}, {2.625, -3.}, {
       2.5625, -2.9998768219370047`}}], 
      PolygonBox[{{2.625, -3.}, {2.6377778151415994`, -3.097057141913445}, {
       2.5625, -2.9998768219370047`}, {2.625, -3.}}], 
      PolygonBox[{{2.562500018967059, -3.084292589556055}, {
       2.5625, -2.9998768219370047`}, {
       2.6377778151415994`, -3.097057141913445}, {
       2.562500018967059, -3.084292589556055}}], 
      PolygonBox[{{2.6377778151415994`, -3.097057141913445}, {
       2.6752404735808355`, -3.1875}, {
       2.562500018967059, -3.084292589556055}, {
       2.6377778151415994`, -3.097057141913445}}], 
      PolygonBox[{{2.5626550066464766`, -3.230251642536255}, {
       2.562500018967059, -3.084292589556055}, {
       2.6752404735808355`, -3.1875}, {
       2.5626550066464766`, -3.230251642536255}}], 
      PolygonBox[{{2.6752404735808355`, -3.1875}, {
       2.7348349570550448`, -3.2651650429449552`}, {
       2.5626550066464766`, -3.230251642536255}, {
       2.6752404735808355`, -3.1875}}], 
      PolygonBox[{{2.595057255667003, -3.404942744332997}, {
       2.5626550066464766`, -3.230251642536255}, {
       2.7348349570550448`, -3.2651650429449552`}, {
       2.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, -3.2651650429449552`}, {
       2.8125, -3.3247595264191645`}, {
       2.595057255667003, -3.404942744332997}, {
       2.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{2.769748357463745, -3.4373449933535234`}, {
       2.595057255667003, -3.404942744332997}, {
       2.8125, -3.3247595264191645`}, {
       2.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{2.8125, -3.3247595264191645`}, {
       2.9029428580865546`, -3.3622221848584006`}, {
       2.769748357463745, -3.4373449933535234`}, {
       2.8125, -3.3247595264191645`}}], 
      PolygonBox[{{2.915707410443936, -3.437499981032941}, {
       2.769748357463745, -3.4373449933535234`}, {
       2.9029428580865546`, -3.3622221848584006`}, {
       2.915707410443936, -3.437499981032941}}], 
      PolygonBox[{{2.9029428580865546`, -3.3622221848584006`}, {3., -3.375}, {
       2.915707410443936, -3.437499981032941}, {
       2.9029428580865546`, -3.3622221848584006`}}], 
      PolygonBox[{{3.000134841831043, -3.4375}, {
       2.915707410443936, -3.437499981032941}, {3., -3.375}, {
       3.000134841831043, -3.4375}}], 
      PolygonBox[{{3., -3.375}, {3.097057141913445, -3.3622221848584006`}, {
       3.000134841831043, -3.4375}, {3., -3.375}}], 
      PolygonBox[{{3.0842925895560533`, -3.437499981032941}, {
       3.000134841831043, -3.4375}, {
       3.097057141913445, -3.3622221848584006`}, {
       3.0842925895560533`, -3.437499981032941}}], 
      PolygonBox[{{3.097057141913445, -3.3622221848584006`}, {
       3.1874999999999996`, -3.3247595264191645`}, {
       3.0842925895560533`, -3.437499981032941}, {
       3.097057141913445, -3.3622221848584006`}}], 
      PolygonBox[{{3.230251642536255, -3.4373449933535234`}, {
       3.0842925895560533`, -3.437499981032941}, {
       3.1874999999999996`, -3.3247595264191645`}, {
       3.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{3.1874999999999996`, -3.3247595264191645`}, {
       3.2651650429449552`, -3.2651650429449552`}, {
       3.230251642536255, -3.4373449933535234`}, {
       3.1874999999999996`, -3.3247595264191645`}}], 
      PolygonBox[{{3.404942744332997, -3.404942744332997}, {
       3.230251642536255, -3.4373449933535234`}, {
       3.2651650429449552`, -3.2651650429449552`}, {
       3.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, -3.2651650429449552`}, {
       3.2651650429449552`, -3.2651650429449552`}, {
       3.404942744332997, -3.404942744332997}, {
       3.2651650429449552`, -3.2651650429449552`}}], 
      PolygonBox[{{3.404942744332997, -3.404942744332997}, {
       3.404942744332997, -3.404942744332997}, {
       3.2651650429449552`, -3.2651650429449552`}, {
       3.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{3.404942744332997, -3.404942744332997}, {
       3.4373449933535234`, -3.2302516425362553`}, {3.5, -3.5}, {
       3.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{3.5, -3.357662782649368}, {3.5, -3.5}, {
       3.4373449933535234`, -3.2302516425362553`}, {
       3.5, -3.357662782649368}}], 
      PolygonBox[{{3.4373449933535234`, -3.2302516425362553`}, {
       3.437499981032941, -3.084292589556062}, {3.5, -3.357662782649368}, {
       3.4373449933535234`, -3.2302516425362553`}}], 
      PolygonBox[{{3.5, -3.20590900530174}, {3.5, -3.357662782649368}, {
       3.437499981032941, -3.084292589556062}, {3.5, -3.20590900530174}}], 
      PolygonBox[{{3.437499981032941, -3.084292589556062}, {3.4375, -3.}, {
       3.5, -3.20590900530174}, {3.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{3.5, -3.}, {3.5, -3.20590900530174}, {3.4375, -3.}, {
       3.5, -3.}}], 
      PolygonBox[{{3.4375, -3.}, {3.437499981032941, -2.915707410443938}, {
       3.5, -3.}, {3.4375, -3.}}], 
      PolygonBox[{{3.5, -2.79409099469826}, {3.5, -3.}, {
       3.437499981032941, -2.915707410443938}, {3.5, -2.79409099469826}}], 
      PolygonBox[{{3.437499981032941, -2.915707410443938}, {
       3.4373449933535234`, -2.769748357463745}, {3.5, -2.79409099469826}, {
       3.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{3.5, -2.6423372173506325`}, {3.5, -2.79409099469826}, {
       3.4373449933535234`, -2.769748357463745}, {
       3.5, -2.6423372173506325`}}], 
      PolygonBox[{{3.4373449933535234`, -2.769748357463745}, {
       3.404942744332997, -2.595057255667003}, {3.5, -2.6423372173506325`}, {
       3.4373449933535234`, -2.769748357463745}}], 
      PolygonBox[{{3.491446564961186, -2.508553435038814}, {
       3.5, -2.6423372173506325`}, {3.404942744332997, -2.595057255667003}, {
       3.491446564961186, -2.508553435038814}}], 
      PolygonBox[{{3.404942744332997, -2.595057255667003}, {
       3.2302516425362553`, -2.5626550066464766`}, {
       3.491446564961186, -2.508553435038814}, {
       3.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{3.357662782649368, -2.5}, {
       3.491446564961186, -2.508553435038814}, {
       3.2302516425362553`, -2.5626550066464766`}, {
       3.357662782649368, -2.5}}], 
      PolygonBox[{{3.2302516425362553`, -2.5626550066464766`}, {
       3.0842925895560604`, -2.562500018967059}, {3.357662782649368, -2.5}, {
       3.2302516425362553`, -2.5626550066464766`}}], 
      PolygonBox[{{3.2059090053732557`, -2.5}, {3.357662782649368, -2.5}, {
       3.0842925895560604`, -2.562500018967059}, {
       3.2059090053732557`, -2.5}}], 
      PolygonBox[{{3.0842925895560604`, -2.562500018967059}, {
       3.0001055272204877`, -2.5625}, {3.2059090053732557`, -2.5}, {
       3.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{3.07794195802689, -2.5}, {3.2059090053732557`, -2.5}, {
       3.0001055272204877`, -2.5625}, {3.07794195802689, -2.5}}], 
      PolygonBox[{{3.0001055272204877`, -2.5625}, {
       2.915707410443943, -2.562500018967059}, {3.07794195802689, -2.5}, {
       3.0001055272204877`, -2.5625}}], 
      PolygonBox[{{2.7940909946955546`, -2.5}, {3.07794195802689, -2.5}, {
       2.915707410443943, -2.562500018967059}, {2.7940909946955546`, -2.5}}], 
      PolygonBox[{{2.915707410443943, -2.562500018967059}, {
       2.769748357463745, -2.5626550066464766`}, {
       2.7940909946955546`, -2.5}, {2.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{2.642337217350634, -2.5}, {2.7940909946955546`, -2.5}, {
       2.769748357463745, -2.5626550066464766`}, {2.642337217350634, -2.5}}], 
      PolygonBox[{{2.769748357463745, -2.5626550066464766`}, {
       2.595057255667003, -2.595057255667003}, {2.642337217350634, -2.5}, {
       2.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{3.5, -2.5}, {2.642337217350634, -2.5}, {
       2.595057255667003, -2.595057255667003}, {3.5, -2.5}}], 
      PolygonBox[{{2.595057255667003, -2.595057255667003}, {
       2.5626550066464766`, -2.7697483574637447`}, {3.5, -2.5}, {
       2.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{2.5, -2.642337217350631}, {3.5, -2.5}, {
       2.5626550066464766`, -2.7697483574637447`}, {
       2.5, -2.642337217350631}}], 
      PolygonBox[{{2.5626550066464766`, -2.7697483574637447`}, {
       2.562500018967059, -2.9157074104439378`}, {2.5, -2.642337217350631}, {
       2.5626550066464766`, -2.7697483574637447`}}], 
      PolygonBox[{{2.5, -2.794090994717101}, {2.5, -2.642337217350631}, {
       2.562500018967059, -2.9157074104439378`}, {2.5, -2.794090994717101}}], 
      PolygonBox[{{2.562500018967059, -2.9157074104439378`}, {
       2.5625, -2.9998768219370047`}, {2.5, -2.794090994717101}, {
       2.562500018967059, -2.9157074104439378`}}], 
      PolygonBox[{{2.5, -2.9193213332413}, {2.5, -2.794090994717101}, {
       2.5625, -2.9998768219370047`}, {2.5, -2.9193213332413}}], 
      PolygonBox[{{2.5625, -2.9998768219370047`}, {
       2.562500018967059, -3.084292589556055}, {2.5, -2.9193213332413}, {
       2.5625, -2.9998768219370047`}}], 
      PolygonBox[{{2.5, -3.2059090051452785`}, {2.5, -2.9193213332413}, {
       2.562500018967059, -3.084292589556055}, {2.5, -3.2059090051452785`}}], 
      PolygonBox[{{2.562500018967059, -3.084292589556055}, {
       2.5626550066464766`, -3.230251642536255}, {
       2.5, -3.2059090051452785`}, {2.562500018967059, -3.084292589556055}}], 
      PolygonBox[{{2.5, -3.3576627826493652`}, {2.5, -3.2059090051452785`}, {
       2.5626550066464766`, -3.230251642536255}, {
       2.5, -3.3576627826493652`}}], 
      PolygonBox[{{2.5626550066464766`, -3.230251642536255}, {
       2.595057255667003, -3.404942744332997}, {2.5, -3.3576627826493652`}, {
       2.5626550066464766`, -3.230251642536255}}], 
      PolygonBox[{{2.5, -2.5}, {2.5, -3.3576627826493652`}, {
       2.595057255667003, -3.404942744332997}, {2.5, -2.5}}], 
      PolygonBox[{{2.595057255667003, -3.404942744332997}, {
       2.769748357463745, -3.4373449933535234`}, {2.5, -2.5}, {
       2.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{2.5, -3.5}, {2.5, -2.5}, {
       2.769748357463745, -3.4373449933535234`}, {2.5, -3.5}}], 
      PolygonBox[{{2.769748357463745, -3.4373449933535234`}, {
       2.915707410443936, -3.437499981032941}, {2.5, -3.5}, {
       2.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{2.794090994433172, -3.5}, {2.5, -3.5}, {
       2.915707410443936, -3.437499981032941}, {2.794090994433172, -3.5}}], 
      PolygonBox[{{2.915707410443936, -3.437499981032941}, {
       3.000134841831043, -3.4375}, {2.794090994433172, -3.5}, {
       2.915707410443936, -3.437499981032941}}], 
      PolygonBox[{{3.0823238704010616`, -3.5}, {2.794090994433172, -3.5}, {
       3.000134841831043, -3.4375}, {3.0823238704010616`, -3.5}}], 
      PolygonBox[{{3.000134841831043, -3.4375}, {
       3.0842925895560533`, -3.437499981032941}, {
       3.0823238704010616`, -3.5}, {3.000134841831043, -3.4375}}], 
      PolygonBox[{{3.2059090053603976`, -3.5}, {3.0823238704010616`, -3.5}, {
       3.0842925895560533`, -3.437499981032941}, {
       3.2059090053603976`, -3.5}}], 
      PolygonBox[{{3.0842925895560533`, -3.437499981032941}, {
       3.230251642536255, -3.4373449933535234`}, {
       3.2059090053603976`, -3.5}, {
       3.0842925895560533`, -3.437499981032941}}], 
      PolygonBox[{{3.357662782649371, -3.5}, {3.2059090053603976`, -3.5}, {
       3.230251642536255, -3.4373449933535234`}, {3.357662782649371, -3.5}}], 
      PolygonBox[{{3.230251642536255, -3.4373449933535234`}, {
       3.404942744332997, -3.404942744332997}, {3.357662782649371, -3.5}, {
       3.230251642536255, -3.4373449933535234`}}], 
      PolygonBox[{{3.5, -3.5}, {3.357662782649371, -3.5}, {
       3.404942744332997, -3.404942744332997}, {3.5, -3.5}}], 
      PolygonBox[{{3.404942744332997, -3.404942744332997}, {
       3.404942744332997, -3.404942744332997}, {3.5, -3.5}, {
       3.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{3.5, -3.5}, {3.5, -3.5}, {
       3.404942744332997, -3.404942744332997}, {3.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, -2.}, {2.5208333333333335`, -2.}, {
       2.5416666666666665`, -2.}, {2.5625, -2.}, {2.5833333333333335`, -2.}, {
       2.6041666666666665`, -2.}, {2.625, -2.}, {2.625, -2.}, {
       2.6041666666666665`, -2.}, {2.5833333333333335`, -2.}, {2.5625, -2.}, {
       2.5416666666666665`, -2.}, {2.5208333333333335`, -2.}, {2.5, -2.}, {
       2.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, -2.}, {3.3958333333333335`, -2.}, {
       3.4166666666666665`, -2.}, {3.4375, -2.}, {3.4583333333333335`, -2.}, {
       3.4791666666666665`, -2.}, {3.5, -2.}, {3.5, -2.}, {
       3.4791666666666665`, -2.}, {3.4583333333333335`, -2.}, {3.4375, -2.}, {
       3.4166666666666665`, -2.}, {3.3958333333333335`, -2.}, {3.375, -2.}, {
       3.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -2.5}, {3., -2.4791666666666665`}, {
       3., -2.4583333333333335`}, {3., -2.4375}, {3., -2.4166666666666665`}, {
       3., -2.3958333333333335`}, {3., -2.375}, {3., -2.375}, {
       3., -2.3958333333333335`}, {3., -2.4166666666666665`}, {3., -2.4375}, {
       3., -2.4583333333333335`}, {3., -2.4791666666666665`}, {3., -2.5}, {
       3., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -1.625}, {3., -1.6041666666666667`}, {
       3., -1.5833333333333333`}, {3., -1.5625}, {3., -1.5416666666666667`}, {
       3., -1.5208333333333335`}, {3., -1.5}, {3., -1.5}, {
       3., -1.5208333333333333`}, {3., -1.5416666666666667`}, {3., -1.5625}, {
       3., -1.5833333333333333`}, {3., -1.6041666666666665`}, {3., -1.625}, {
       3., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, -2.}, {2.75, -2.}, {2.875, -2.}, {3., -2.}, {
       3.125, -2.}, {3.25, -2.}, {3.375, -2.}, {3.375, -2.}, {3.25, -2.}, {
       3.125, -2.}, {3., -2.}, {2.875, -2.}, {2.75, -2.}, {2.625, -2.}, {
       2.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -2.375}, {3., -2.25}, {3., -2.125}, {3., -2.}, {
       3., -1.875}, {3., -1.75}, {3., -1.625}, {3., -1.625}, {3., -1.75}, {
       3., -1.875}, {3., -2.}, {3., -2.125}, {3., -2.25}, {3., -2.375}, {
       3., -2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDlDGgVcX1+278pTLIcn8lmlJ0b/9Bu4nWqVn
ckHl/+6f/Xb2TT55LodTKid8Hh38vR8s3MDpsKAw/8uJs7/2+z8Renr0GIeD
TsyipjCTXxB5Bg6o/l/7N0q/lbKyZEeVb2CD608VSlH7+IAVbv6FHeZVT9JY
4faL6QU6akuxwt0HEYfJMxyAyfuB3cFwAEV/A+OBFKj5EH8wHYDZD/En0wGY
+yDhAJWHu5/5gB/UfzD5/yBQzwnXDwsfmPko4Qe0Hxa+/lD3oYc/AG/wk3s=

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhD6x/7Vq0CAC84PBQNOOB9Cc6CpZ4Pzw8Dq
WdHUsxDkg41Z9QvOh9j7F009wwFUecYDqPqZDqCqZ8Hgh6K4j+UAqvth6jnQ
1HPC+atQwgemnocgfzWK+3jQ3A9TzwDnh6H4H6b/135U9T/2AwD8uFtA
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, -2.2651650429449552`}, {
       3.3247595264191645`, -2.1875}, {
       3.404942744332997, -2.404942744332997}, {
       3.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{3.4373449933535234`, -2.2302516425362553`}, {
       3.404942744332997, -2.404942744332997}, {
       3.3247595264191645`, -2.1875}, {
       3.4373449933535234`, -2.2302516425362553`}}], 
      PolygonBox[{{3.3247595264191645`, -2.1875}, {
       3.3622221848584006`, -2.0970571419134454`}, {
       3.4373449933535234`, -2.2302516425362553`}, {
       3.3247595264191645`, -2.1875}}], 
      PolygonBox[{{3.437499981032941, -2.084292589556062}, {
       3.4373449933535234`, -2.2302516425362553`}, {
       3.3622221848584006`, -2.0970571419134454`}, {
       3.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{3.3622221848584006`, -2.0970571419134454`}, {3.375, -2.}, {
       3.437499981032941, -2.084292589556062}, {
       3.3622221848584006`, -2.0970571419134454`}}], 
      PolygonBox[{{3.4375, -2.}, {3.437499981032941, -2.084292589556062}, {
       3.375, -2.}, {3.4375, -2.}}], 
      PolygonBox[{{3.375, -2.}, {3.3622221848584006`, -1.9029428580865548`}, {
       3.4375, -2.}, {3.375, -2.}}], 
      PolygonBox[{{3.437499981032941, -1.9157074104439382`}, {3.4375, -2.}, {
       3.3622221848584006`, -1.9029428580865548`}, {
       3.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{3.3622221848584006`, -1.9029428580865548`}, {
       3.3247595264191645`, -1.8125}, {
       3.437499981032941, -1.9157074104439382`}, {
       3.3622221848584006`, -1.9029428580865548`}}], 
      PolygonBox[{{3.4373449933535234`, -1.769748357463745}, {
       3.437499981032941, -1.9157074104439382`}, {
       3.3247595264191645`, -1.8125}, {
       3.4373449933535234`, -1.769748357463745}}], 
      PolygonBox[{{3.3247595264191645`, -1.8125}, {
       3.2651650429449552`, -1.7348349570550448`}, {
       3.4373449933535234`, -1.769748357463745}, {
       3.3247595264191645`, -1.8125}}], 
      PolygonBox[{{3.404942744332997, -1.5950572556670028`}, {
       3.4373449933535234`, -1.769748357463745}, {
       3.2651650429449552`, -1.7348349570550448`}, {
       3.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{3.2651650429449552`, -1.7348349570550448`}, {
       3.1875, -1.6752404735808355`}, {
       3.404942744332997, -1.5950572556670028`}, {
       3.2651650429449552`, -1.7348349570550448`}}], 
      PolygonBox[{{3.2302516425362553`, -1.5626550066464766`}, {
       3.404942744332997, -1.5950572556670028`}, {
       3.1875, -1.6752404735808355`}, {
       3.2302516425362553`, -1.5626550066464766`}}], 
      PolygonBox[{{3.1875, -1.6752404735808355`}, {
       3.0970571419134454`, -1.6377778151415994`}, {
       3.2302516425362553`, -1.5626550066464766`}, {
       3.1875, -1.6752404735808355`}}], 
      PolygonBox[{{3.0842925895560604`, -1.5625000189670593`}, {
       3.2302516425362553`, -1.5626550066464766`}, {
       3.0970571419134454`, -1.6377778151415994`}, {
       3.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{3.0970571419134454`, -1.6377778151415994`}, {3., -1.625}, {
       3.0842925895560604`, -1.5625000189670593`}, {
       3.0970571419134454`, -1.6377778151415994`}}], 
      PolygonBox[{{3.0001055272204877`, -1.5625}, {
       3.0842925895560604`, -1.5625000189670593`}, {3., -1.625}, {
       3.0001055272204877`, -1.5625}}], 
      PolygonBox[{{3., -1.625}, {2.902942858086555, -1.6377778151415994`}, {
       3.0001055272204877`, -1.5625}, {3., -1.625}}], 
      PolygonBox[{{2.915707410443943, -1.5625000189670593`}, {
       3.0001055272204877`, -1.5625}, {
       2.902942858086555, -1.6377778151415994`}, {
       2.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{2.902942858086555, -1.6377778151415994`}, {
       2.8125, -1.6752404735808355`}, {
       2.915707410443943, -1.5625000189670593`}, {
       2.902942858086555, -1.6377778151415994`}}], 
      PolygonBox[{{2.769748357463745, -1.5626550066464766`}, {
       2.915707410443943, -1.5625000189670593`}, {
       2.8125, -1.6752404735808355`}, {
       2.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{2.8125, -1.6752404735808355`}, {
       2.7348349570550448`, -1.7348349570550448`}, {
       2.769748357463745, -1.5626550066464766`}, {
       2.8125, -1.6752404735808355`}}], 
      PolygonBox[{{2.595057255667003, -1.5950572556670028`}, {
       2.769748357463745, -1.5626550066464766`}, {
       2.7348349570550448`, -1.7348349570550448`}, {
       2.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{2.7348349570550448`, -1.7348349570550448`}, {
       2.6752404735808355`, -1.8125}, {
       2.595057255667003, -1.5950572556670028`}, {
       2.7348349570550448`, -1.7348349570550448`}}], 
      PolygonBox[{{2.5626550066464766`, -1.7697483574637447`}, {
       2.595057255667003, -1.5950572556670028`}, {
       2.6752404735808355`, -1.8125}, {
       2.5626550066464766`, -1.7697483574637447`}}], 
      PolygonBox[{{2.6752404735808355`, -1.8125}, {
       2.6377778151415994`, -1.9029428580865546`}, {
       2.5626550066464766`, -1.7697483574637447`}, {
       2.6752404735808355`, -1.8125}}], 
      PolygonBox[{{2.562500018967059, -1.9157074104439376`}, {
       2.5626550066464766`, -1.7697483574637447`}, {
       2.6377778151415994`, -1.9029428580865546`}, {
       2.562500018967059, -1.9157074104439376`}}], 
      PolygonBox[{{2.6377778151415994`, -1.9029428580865546`}, {
       2.625, -1.9999999999999998`}, {
       2.562500018967059, -1.9157074104439376`}, {
       2.6377778151415994`, -1.9029428580865546`}}], 
      PolygonBox[{{2.5625, -1.9998768219370047`}, {
       2.562500018967059, -1.9157074104439376`}, {
       2.625, -1.9999999999999998`}, {2.5625, -1.9998768219370047`}}], 
      PolygonBox[{{2.625, -1.9999999999999998`}, {
       2.6377778151415994`, -2.097057141913445}, {
       2.5625, -1.9998768219370047`}, {2.625, -1.9999999999999998`}}], 
      PolygonBox[{{2.562500018967059, -2.084292589556055}, {
       2.5625, -1.9998768219370047`}, {
       2.6377778151415994`, -2.097057141913445}, {
       2.562500018967059, -2.084292589556055}}], 
      PolygonBox[{{2.6377778151415994`, -2.097057141913445}, {
       2.6752404735808355`, -2.1875}, {
       2.562500018967059, -2.084292589556055}, {
       2.6377778151415994`, -2.097057141913445}}], 
      PolygonBox[{{2.5626550066464766`, -2.230251642536255}, {
       2.562500018967059, -2.084292589556055}, {
       2.6752404735808355`, -2.1875}, {
       2.5626550066464766`, -2.230251642536255}}], 
      PolygonBox[{{2.6752404735808355`, -2.1875}, {
       2.7348349570550448`, -2.2651650429449552`}, {
       2.5626550066464766`, -2.230251642536255}, {
       2.6752404735808355`, -2.1875}}], 
      PolygonBox[{{2.595057255667003, -2.404942744332997}, {
       2.5626550066464766`, -2.230251642536255}, {
       2.7348349570550448`, -2.2651650429449552`}, {
       2.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, -2.2651650429449552`}, {
       2.8125, -2.3247595264191645`}, {
       2.595057255667003, -2.404942744332997}, {
       2.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{2.769748357463745, -2.4373449933535234`}, {
       2.595057255667003, -2.404942744332997}, {
       2.8125, -2.3247595264191645`}, {
       2.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{2.8125, -2.3247595264191645`}, {
       2.9029428580865546`, -2.3622221848584006`}, {
       2.769748357463745, -2.4373449933535234`}, {
       2.8125, -2.3247595264191645`}}], 
      PolygonBox[{{2.915707410443936, -2.437499981032941}, {
       2.769748357463745, -2.4373449933535234`}, {
       2.9029428580865546`, -2.3622221848584006`}, {
       2.915707410443936, -2.437499981032941}}], 
      PolygonBox[{{2.9029428580865546`, -2.3622221848584006`}, {3., -2.375}, {
       2.915707410443936, -2.437499981032941}, {
       2.9029428580865546`, -2.3622221848584006`}}], 
      PolygonBox[{{3.000134841831043, -2.4375}, {
       2.915707410443936, -2.437499981032941}, {3., -2.375}, {
       3.000134841831043, -2.4375}}], 
      PolygonBox[{{3., -2.375}, {3.097057141913445, -2.3622221848584006`}, {
       3.000134841831043, -2.4375}, {3., -2.375}}], 
      PolygonBox[{{3.0842925895560533`, -2.437499981032941}, {
       3.000134841831043, -2.4375}, {
       3.097057141913445, -2.3622221848584006`}, {
       3.0842925895560533`, -2.437499981032941}}], 
      PolygonBox[{{3.097057141913445, -2.3622221848584006`}, {
       3.1874999999999996`, -2.3247595264191645`}, {
       3.0842925895560533`, -2.437499981032941}, {
       3.097057141913445, -2.3622221848584006`}}], 
      PolygonBox[{{3.230251642536255, -2.4373449933535234`}, {
       3.0842925895560533`, -2.437499981032941}, {
       3.1874999999999996`, -2.3247595264191645`}, {
       3.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{3.1874999999999996`, -2.3247595264191645`}, {
       3.2651650429449552`, -2.2651650429449552`}, {
       3.230251642536255, -2.4373449933535234`}, {
       3.1874999999999996`, -2.3247595264191645`}}], 
      PolygonBox[{{3.404942744332997, -2.404942744332997}, {
       3.230251642536255, -2.4373449933535234`}, {
       3.2651650429449552`, -2.2651650429449552`}, {
       3.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, -2.2651650429449552`}, {
       3.2651650429449552`, -2.2651650429449552`}, {
       3.404942744332997, -2.404942744332997}, {
       3.2651650429449552`, -2.2651650429449552`}}], 
      PolygonBox[{{3.404942744332997, -2.404942744332997}, {
       3.404942744332997, -2.404942744332997}, {
       3.2651650429449552`, -2.2651650429449552`}, {
       3.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{3.404942744332997, -2.404942744332997}, {
       3.4373449933535234`, -2.2302516425362553`}, {3.5, -2.5}, {
       3.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{3.5, -2.357662782649368}, {3.5, -2.5}, {
       3.4373449933535234`, -2.2302516425362553`}, {
       3.5, -2.357662782649368}}], 
      PolygonBox[{{3.4373449933535234`, -2.2302516425362553`}, {
       3.437499981032941, -2.084292589556062}, {3.5, -2.357662782649368}, {
       3.4373449933535234`, -2.2302516425362553`}}], 
      PolygonBox[{{3.5, -2.20590900530174}, {3.5, -2.357662782649368}, {
       3.437499981032941, -2.084292589556062}, {3.5, -2.20590900530174}}], 
      PolygonBox[{{3.437499981032941, -2.084292589556062}, {3.4375, -2.}, {
       3.5, -2.20590900530174}, {3.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{3.5, -2.}, {3.5, -2.20590900530174}, {3.4375, -2.}, {
       3.5, -2.}}], 
      PolygonBox[{{3.4375, -2.}, {3.437499981032941, -1.9157074104439382`}, {
       3.5, -2.}, {3.4375, -2.}}], 
      PolygonBox[{{3.5, -1.7940909946982602`}, {3.5, -2.}, {
       3.437499981032941, -1.9157074104439382`}, {
       3.5, -1.7940909946982602`}}], 
      PolygonBox[{{3.437499981032941, -1.9157074104439382`}, {
       3.4373449933535234`, -1.769748357463745}, {
       3.5, -1.7940909946982602`}, {
       3.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{3.5, -1.6423372173506325`}, {3.5, -1.7940909946982602`}, {
       3.4373449933535234`, -1.769748357463745}, {
       3.5, -1.6423372173506325`}}], 
      PolygonBox[{{3.4373449933535234`, -1.769748357463745}, {
       3.404942744332997, -1.5950572556670028`}, {
       3.5, -1.6423372173506325`}, {
       3.4373449933535234`, -1.769748357463745}}], 
      PolygonBox[{{3.491446564961186, -1.508553435038814}, {
       3.5, -1.6423372173506325`}, {
       3.404942744332997, -1.5950572556670028`}, {
       3.491446564961186, -1.508553435038814}}], 
      PolygonBox[{{3.404942744332997, -1.5950572556670028`}, {
       3.2302516425362553`, -1.5626550066464766`}, {
       3.491446564961186, -1.508553435038814}, {
       3.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{3.357662782649368, -1.5}, {
       3.491446564961186, -1.508553435038814}, {
       3.2302516425362553`, -1.5626550066464766`}, {
       3.357662782649368, -1.5}}], 
      PolygonBox[{{3.2302516425362553`, -1.5626550066464766`}, {
       3.0842925895560604`, -1.5625000189670593`}, {
       3.357662782649368, -1.5}, {
       3.2302516425362553`, -1.5626550066464766`}}], 
      PolygonBox[{{3.2059090053732557`, -1.5}, {3.357662782649368, -1.5}, {
       3.0842925895560604`, -1.5625000189670593`}, {
       3.2059090053732557`, -1.5}}], 
      PolygonBox[{{3.0842925895560604`, -1.5625000189670593`}, {
       3.0001055272204877`, -1.5625}, {3.2059090053732557`, -1.5}, {
       3.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{3.07794195802689, -1.5}, {3.2059090053732557`, -1.5}, {
       3.0001055272204877`, -1.5625}, {3.07794195802689, -1.5}}], 
      PolygonBox[{{3.0001055272204877`, -1.5625}, {
       2.915707410443943, -1.5625000189670593`}, {3.07794195802689, -1.5}, {
       3.0001055272204877`, -1.5625}}], 
      PolygonBox[{{2.7940909946955546`, -1.5}, {3.07794195802689, -1.5}, {
       2.915707410443943, -1.5625000189670593`}, {
       2.7940909946955546`, -1.5}}], 
      PolygonBox[{{2.915707410443943, -1.5625000189670593`}, {
       2.769748357463745, -1.5626550066464766`}, {
       2.7940909946955546`, -1.5}, {
       2.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{2.642337217350634, -1.5}, {2.7940909946955546`, -1.5}, {
       2.769748357463745, -1.5626550066464766`}, {2.642337217350634, -1.5}}], 
      PolygonBox[{{2.769748357463745, -1.5626550066464766`}, {
       2.595057255667003, -1.5950572556670028`}, {2.642337217350634, -1.5}, {
       2.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{3.5, -1.5}, {2.642337217350634, -1.5}, {
       2.595057255667003, -1.5950572556670028`}, {3.5, -1.5}}], 
      PolygonBox[{{2.595057255667003, -1.5950572556670028`}, {
       2.5626550066464766`, -1.7697483574637447`}, {3.5, -1.5}, {
       2.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{2.5, -1.642337217350631}, {3.5, -1.5}, {
       2.5626550066464766`, -1.7697483574637447`}, {
       2.5, -1.642337217350631}}], 
      PolygonBox[{{2.5626550066464766`, -1.7697483574637447`}, {
       2.562500018967059, -1.9157074104439376`}, {2.5, -1.642337217350631}, {
       2.5626550066464766`, -1.7697483574637447`}}], 
      PolygonBox[{{2.5, -1.794090994717101}, {2.5, -1.642337217350631}, {
       2.562500018967059, -1.9157074104439376`}, {2.5, -1.794090994717101}}], 
      PolygonBox[{{2.562500018967059, -1.9157074104439376`}, {
       2.5625, -1.9998768219370047`}, {2.5, -1.794090994717101}, {
       2.562500018967059, -1.9157074104439376`}}], 
      PolygonBox[{{2.5, -1.9193213332412997`}, {2.5, -1.794090994717101}, {
       2.5625, -1.9998768219370047`}, {2.5, -1.9193213332412997`}}], 
      PolygonBox[{{2.5625, -1.9998768219370047`}, {
       2.562500018967059, -2.084292589556055}, {2.5, -1.9193213332412997`}, {
       2.5625, -1.9998768219370047`}}], 
      PolygonBox[{{2.5, -2.2059090051452785`}, {2.5, -1.9193213332412997`}, {
       2.562500018967059, -2.084292589556055}, {2.5, -2.2059090051452785`}}], 
      PolygonBox[{{2.562500018967059, -2.084292589556055}, {
       2.5626550066464766`, -2.230251642536255}, {
       2.5, -2.2059090051452785`}, {2.562500018967059, -2.084292589556055}}], 
      PolygonBox[{{2.5, -2.3576627826493652`}, {2.5, -2.2059090051452785`}, {
       2.5626550066464766`, -2.230251642536255}, {
       2.5, -2.3576627826493652`}}], 
      PolygonBox[{{2.5626550066464766`, -2.230251642536255}, {
       2.595057255667003, -2.404942744332997}, {2.5, -2.3576627826493652`}, {
       2.5626550066464766`, -2.230251642536255}}], 
      PolygonBox[{{2.5, -1.5}, {2.5, -2.3576627826493652`}, {
       2.595057255667003, -2.404942744332997}, {2.5, -1.5}}], 
      PolygonBox[{{2.595057255667003, -2.404942744332997}, {
       2.769748357463745, -2.4373449933535234`}, {2.5, -1.5}, {
       2.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{2.5, -2.5}, {2.5, -1.5}, {
       2.769748357463745, -2.4373449933535234`}, {2.5, -2.5}}], 
      PolygonBox[{{2.769748357463745, -2.4373449933535234`}, {
       2.915707410443936, -2.437499981032941}, {2.5, -2.5}, {
       2.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{2.794090994433172, -2.5}, {2.5, -2.5}, {
       2.915707410443936, -2.437499981032941}, {2.794090994433172, -2.5}}], 
      PolygonBox[{{2.915707410443936, -2.437499981032941}, {
       3.000134841831043, -2.4375}, {2.794090994433172, -2.5}, {
       2.915707410443936, -2.437499981032941}}], 
      PolygonBox[{{3.0823238704010616`, -2.5}, {2.794090994433172, -2.5}, {
       3.000134841831043, -2.4375}, {3.0823238704010616`, -2.5}}], 
      PolygonBox[{{3.000134841831043, -2.4375}, {
       3.0842925895560533`, -2.437499981032941}, {
       3.0823238704010616`, -2.5}, {3.000134841831043, -2.4375}}], 
      PolygonBox[{{3.2059090053603976`, -2.5}, {3.0823238704010616`, -2.5}, {
       3.0842925895560533`, -2.437499981032941}, {
       3.2059090053603976`, -2.5}}], 
      PolygonBox[{{3.0842925895560533`, -2.437499981032941}, {
       3.230251642536255, -2.4373449933535234`}, {
       3.2059090053603976`, -2.5}, {
       3.0842925895560533`, -2.437499981032941}}], 
      PolygonBox[{{3.357662782649371, -2.5}, {3.2059090053603976`, -2.5}, {
       3.230251642536255, -2.4373449933535234`}, {3.357662782649371, -2.5}}], 
      PolygonBox[{{3.230251642536255, -2.4373449933535234`}, {
       3.404942744332997, -2.404942744332997}, {3.357662782649371, -2.5}, {
       3.230251642536255, -2.4373449933535234`}}], 
      PolygonBox[{{3.5, -2.5}, {3.357662782649371, -2.5}, {
       3.404942744332997, -2.404942744332997}, {3.5, -2.5}}], 
      PolygonBox[{{3.404942744332997, -2.404942744332997}, {
       3.404942744332997, -2.404942744332997}, {3.5, -2.5}, {
       3.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{3.5, -2.5}, {3.5, -2.5}, {
       3.404942744332997, -2.404942744332997}, {3.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, -1.}, {2.5208333333333335`, -1.}, {
       2.5416666666666665`, -1.}, {2.5625, -1.}, {2.5833333333333335`, -1.}, {
       2.6041666666666665`, -1.}, {2.625, -1.}, {2.625, -1.}, {
       2.6041666666666665`, -1.}, {2.5833333333333335`, -1.}, {2.5625, -1.}, {
       2.5416666666666665`, -1.}, {2.5208333333333335`, -1.}, {2.5, -1.}, {
       2.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, -1.}, {3.3958333333333335`, -1.}, {
       3.4166666666666665`, -1.}, {3.4375, -1.}, {3.4583333333333335`, -1.}, {
       3.4791666666666665`, -1.}, {3.5, -1.}, {3.5, -1.}, {
       3.4791666666666665`, -1.}, {3.4583333333333335`, -1.}, {3.4375, -1.}, {
       3.4166666666666665`, -1.}, {3.3958333333333335`, -1.}, {3.375, -1.}, {
       3.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -1.5}, {3., -1.4791666666666667`}, {
       3., -1.4583333333333333`}, {3., -1.4375}, {3., -1.4166666666666667`}, {
       3., -1.3958333333333335`}, {3., -1.375}, {3., -1.375}, {
       3., -1.3958333333333333`}, {3., -1.4166666666666667`}, {3., -1.4375}, {
       3., -1.4583333333333333`}, {3., -1.4791666666666665`}, {3., -1.5}, {
       3., -1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -0.625}, {3., -0.6041666666666667}, {
       3., -0.5833333333333333}, {3., -0.5625}, {3., -0.5416666666666667}, {
       3., -0.5208333333333334}, {3., -0.5}, {3., -0.5}, {
       3., -0.5208333333333333}, {3., -0.5416666666666667}, {3., -0.5625}, {
       3., -0.5833333333333333}, {3., -0.6041666666666666}, {3., -0.625}, {
       3., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, -1.}, {2.75, -1.}, {2.875, -1.}, {3., -1.}, {
       3.125, -1.}, {3.25, -1.}, {3.375, -1.}, {3.375, -1.}, {3.25, -1.}, {
       3.125, -1.}, {3., -1.}, {2.875, -1.}, {2.75, -1.}, {2.625, -1.}, {
       2.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -1.375}, {3., -1.25}, {3., -1.125}, {3., -1.}, {
       3., -0.875}, {3., -0.75}, {3., -0.625}, {3., -0.625}, {3., -0.75}, {
       3., -0.875}, {3., -1.}, {3., -1.125}, {3., -1.25}, {3., -1.375}, {
       3., -1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhD6w/5XF9ftu/KUy+Fo3pbsF0/e7DdwP9Eq
PZMLKv9q/+y3s2/yyXM5TPGcMPNI8/P9YOEGTgeHx/deTJz9dL//E6GnR49x
OETscGFdm/EEIs/AAdX/ZP9G6bdSVpbsqPINbHD9qUIpah8fsDpMhpp/YYd5
1ZM0Vof/YPByv5heoKO2FKvDEaj7IOaywt0Pk597QvVUd+9HuH6I/Of9KVDz
zW6bb5a1+wK3P6FvAre50Ve4+64sjq1deformvu/7feD+g8mD3ZWPSdcPyx8
YObDwo8Raj8sfOdD3Yce/gDDOqJB
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhD6wf7Vq0CAC84PBQNOOB9Cc6CpZ4Pzw8Dq
WdHUsxDkQ+x5CueDjV31Ck39BzT5T2j6v6Kp/4HBD0Vx3w809/9A898PNP//
2L8KJXxg6nkI8sNQ3MfjsBrF/TD1H9DkX6Hpf4qm/sF+AKexaEY=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, -1.2651650429449552`}, {
       3.3247595264191645`, -1.1875}, {
       3.404942744332997, -1.4049427443329972`}, {
       3.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{3.4373449933535234`, -1.230251642536255}, {
       3.404942744332997, -1.4049427443329972`}, {
       3.3247595264191645`, -1.1875}, {
       3.4373449933535234`, -1.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, -1.1875}, {
       3.3622221848584006`, -1.0970571419134454`}, {
       3.4373449933535234`, -1.230251642536255}, {
       3.3247595264191645`, -1.1875}}], 
      PolygonBox[{{3.437499981032941, -1.0842925895560618`}, {
       3.4373449933535234`, -1.230251642536255}, {
       3.3622221848584006`, -1.0970571419134454`}, {
       3.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{3.3622221848584006`, -1.0970571419134454`}, {3.375, -1.}, {
       3.437499981032941, -1.0842925895560618`}, {
       3.3622221848584006`, -1.0970571419134454`}}], 
      PolygonBox[{{3.4375, -1.}, {3.437499981032941, -1.0842925895560618`}, {
       3.375, -1.}, {3.4375, -1.}}], 
      PolygonBox[{{3.375, -1.}, {3.3622221848584006`, -0.9029428580865547}, {
       3.4375, -1.}, {3.375, -1.}}], 
      PolygonBox[{{3.437499981032941, -0.9157074104439382}, {3.4375, -1.}, {
       3.3622221848584006`, -0.9029428580865547}, {
       3.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{3.3622221848584006`, -0.9029428580865547}, {
       3.3247595264191645`, -0.8125}, {
       3.437499981032941, -0.9157074104439382}, {
       3.3622221848584006`, -0.9029428580865547}}], 
      PolygonBox[{{3.4373449933535234`, -0.7697483574637449}, {
       3.437499981032941, -0.9157074104439382}, {
       3.3247595264191645`, -0.8125}, {
       3.4373449933535234`, -0.7697483574637449}}], 
      PolygonBox[{{3.3247595264191645`, -0.8125}, {
       3.2651650429449552`, -0.7348349570550448}, {
       3.4373449933535234`, -0.7697483574637449}, {
       3.3247595264191645`, -0.8125}}], 
      PolygonBox[{{3.404942744332997, -0.5950572556670028}, {
       3.4373449933535234`, -0.7697483574637449}, {
       3.2651650429449552`, -0.7348349570550448}, {
       3.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{3.2651650429449552`, -0.7348349570550448}, {
       3.1875, -0.6752404735808355}, {
       3.404942744332997, -0.5950572556670028}, {
       3.2651650429449552`, -0.7348349570550448}}], 
      PolygonBox[{{3.2302516425362553`, -0.5626550066464766}, {
       3.404942744332997, -0.5950572556670028}, {
       3.1875, -0.6752404735808355}, {
       3.2302516425362553`, -0.5626550066464766}}], 
      PolygonBox[{{3.1875, -0.6752404735808355}, {
       3.0970571419134454`, -0.6377778151415994}, {
       3.2302516425362553`, -0.5626550066464766}, {
       3.1875, -0.6752404735808355}}], 
      PolygonBox[{{3.0842925895560604`, -0.5625000189670593}, {
       3.2302516425362553`, -0.5626550066464766}, {
       3.0970571419134454`, -0.6377778151415994}, {
       3.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{3.0970571419134454`, -0.6377778151415994}, {3., -0.625}, {
       3.0842925895560604`, -0.5625000189670593}, {
       3.0970571419134454`, -0.6377778151415994}}], 
      PolygonBox[{{3.0001055272204877`, -0.5625}, {
       3.0842925895560604`, -0.5625000189670593}, {3., -0.625}, {
       3.0001055272204877`, -0.5625}}], 
      PolygonBox[{{3., -0.625}, {2.902942858086555, -0.6377778151415994}, {
       3.0001055272204877`, -0.5625}, {3., -0.625}}], 
      PolygonBox[{{2.915707410443943, -0.5625000189670593}, {
       3.0001055272204877`, -0.5625}, {
       2.902942858086555, -0.6377778151415994}, {
       2.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{2.902942858086555, -0.6377778151415994}, {
       2.8125, -0.6752404735808355}, {
       2.915707410443943, -0.5625000189670593}, {
       2.902942858086555, -0.6377778151415994}}], 
      PolygonBox[{{2.769748357463745, -0.5626550066464766}, {
       2.915707410443943, -0.5625000189670593}, {
       2.8125, -0.6752404735808355}, {
       2.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{2.8125, -0.6752404735808355}, {
       2.7348349570550448`, -0.7348349570550446}, {
       2.769748357463745, -0.5626550066464766}, {
       2.8125, -0.6752404735808355}}], 
      PolygonBox[{{2.595057255667003, -0.5950572556670028}, {
       2.769748357463745, -0.5626550066464766}, {
       2.7348349570550448`, -0.7348349570550446}, {
       2.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{2.7348349570550448`, -0.7348349570550446}, {
       2.6752404735808355`, -0.8124999999999999}, {
       2.595057255667003, -0.5950572556670028}, {
       2.7348349570550448`, -0.7348349570550446}}], 
      PolygonBox[{{2.5626550066464766`, -0.7697483574637446}, {
       2.595057255667003, -0.5950572556670028}, {
       2.6752404735808355`, -0.8124999999999999}, {
       2.5626550066464766`, -0.7697483574637446}}], 
      PolygonBox[{{2.6752404735808355`, -0.8124999999999999}, {
       2.6377778151415994`, -0.9029428580865546}, {
       2.5626550066464766`, -0.7697483574637446}, {
       2.6752404735808355`, -0.8124999999999999}}], 
      PolygonBox[{{2.562500018967059, -0.9157074104439377}, {
       2.5626550066464766`, -0.7697483574637446}, {
       2.6377778151415994`, -0.9029428580865546}, {
       2.562500018967059, -0.9157074104439377}}], 
      PolygonBox[{{2.6377778151415994`, -0.9029428580865546}, {
       2.625, -0.9999999999999998}, {
       2.562500018967059, -0.9157074104439377}, {
       2.6377778151415994`, -0.9029428580865546}}], 
      PolygonBox[{{2.5625, -0.9998768219370047}, {
       2.562500018967059, -0.9157074104439377}, {
       2.625, -0.9999999999999998}, {2.5625, -0.9998768219370047}}], 
      PolygonBox[{{2.625, -0.9999999999999998}, {
       2.6377778151415994`, -1.0970571419134452`}, {
       2.5625, -0.9998768219370047}, {2.625, -0.9999999999999998}}], 
      PolygonBox[{{2.562500018967059, -1.084292589556055}, {
       2.5625, -0.9998768219370047}, {
       2.6377778151415994`, -1.0970571419134452`}, {
       2.562500018967059, -1.084292589556055}}], 
      PolygonBox[{{2.6377778151415994`, -1.0970571419134452`}, {
       2.6752404735808355`, -1.1874999999999998`}, {
       2.562500018967059, -1.084292589556055}, {
       2.6377778151415994`, -1.0970571419134452`}}], 
      PolygonBox[{{2.5626550066464766`, -1.2302516425362549`}, {
       2.562500018967059, -1.084292589556055}, {
       2.6752404735808355`, -1.1874999999999998`}, {
       2.5626550066464766`, -1.2302516425362549`}}], 
      PolygonBox[{{2.6752404735808355`, -1.1874999999999998`}, {
       2.7348349570550448`, -1.2651650429449552`}, {
       2.5626550066464766`, -1.2302516425362549`}, {
       2.6752404735808355`, -1.1874999999999998`}}], 
      PolygonBox[{{2.595057255667003, -1.4049427443329972`}, {
       2.5626550066464766`, -1.2302516425362549`}, {
       2.7348349570550448`, -1.2651650429449552`}, {
       2.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{2.7348349570550448`, -1.2651650429449552`}, {
       2.8125, -1.3247595264191645`}, {
       2.595057255667003, -1.4049427443329972`}, {
       2.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{2.769748357463745, -1.4373449933535234`}, {
       2.595057255667003, -1.4049427443329972`}, {
       2.8125, -1.3247595264191645`}, {
       2.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{2.8125, -1.3247595264191645`}, {
       2.9029428580865546`, -1.3622221848584006`}, {
       2.769748357463745, -1.4373449933535234`}, {
       2.8125, -1.3247595264191645`}}], 
      PolygonBox[{{2.915707410443936, -1.4374999810329407`}, {
       2.769748357463745, -1.4373449933535234`}, {
       2.9029428580865546`, -1.3622221848584006`}, {
       2.915707410443936, -1.4374999810329407`}}], 
      PolygonBox[{{2.9029428580865546`, -1.3622221848584006`}, {3., -1.375}, {
       2.915707410443936, -1.4374999810329407`}, {
       2.9029428580865546`, -1.3622221848584006`}}], 
      PolygonBox[{{3.000134841831043, -1.4375}, {
       2.915707410443936, -1.4374999810329407`}, {3., -1.375}, {
       3.000134841831043, -1.4375}}], 
      PolygonBox[{{3., -1.375}, {3.097057141913445, -1.3622221848584006`}, {
       3.000134841831043, -1.4375}, {3., -1.375}}], 
      PolygonBox[{{3.0842925895560533`, -1.4374999810329407`}, {
       3.000134841831043, -1.4375}, {
       3.097057141913445, -1.3622221848584006`}, {
       3.0842925895560533`, -1.4374999810329407`}}], 
      PolygonBox[{{3.097057141913445, -1.3622221848584006`}, {
       3.1874999999999996`, -1.3247595264191645`}, {
       3.0842925895560533`, -1.4374999810329407`}, {
       3.097057141913445, -1.3622221848584006`}}], 
      PolygonBox[{{3.230251642536255, -1.4373449933535234`}, {
       3.0842925895560533`, -1.4374999810329407`}, {
       3.1874999999999996`, -1.3247595264191645`}, {
       3.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{3.1874999999999996`, -1.3247595264191645`}, {
       3.2651650429449552`, -1.2651650429449552`}, {
       3.230251642536255, -1.4373449933535234`}, {
       3.1874999999999996`, -1.3247595264191645`}}], 
      PolygonBox[{{3.404942744332997, -1.4049427443329972`}, {
       3.230251642536255, -1.4373449933535234`}, {
       3.2651650429449552`, -1.2651650429449552`}, {
       3.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{3.2651650429449552`, -1.2651650429449552`}, {
       3.2651650429449552`, -1.2651650429449552`}, {
       3.404942744332997, -1.4049427443329972`}, {
       3.2651650429449552`, -1.2651650429449552`}}], 
      PolygonBox[{{3.404942744332997, -1.4049427443329972`}, {
       3.404942744332997, -1.4049427443329972`}, {
       3.2651650429449552`, -1.2651650429449552`}, {
       3.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{3.404942744332997, -1.4049427443329972`}, {
       3.4373449933535234`, -1.230251642536255}, {3.5, -1.5}, {
       3.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{3.5, -1.3576627826493677`}, {3.5, -1.5}, {
       3.4373449933535234`, -1.230251642536255}, {
       3.5, -1.3576627826493677`}}], 
      PolygonBox[{{3.4373449933535234`, -1.230251642536255}, {
       3.437499981032941, -1.0842925895560618`}, {
       3.5, -1.3576627826493677`}, {
       3.4373449933535234`, -1.230251642536255}}], 
      PolygonBox[{{3.5, -1.20590900530174}, {3.5, -1.3576627826493677`}, {
       3.437499981032941, -1.0842925895560618`}, {3.5, -1.20590900530174}}], 
      PolygonBox[{{3.437499981032941, -1.0842925895560618`}, {3.4375, -1.}, {
       3.5, -1.20590900530174}, {3.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{3.5, -1.}, {3.5, -1.20590900530174}, {3.4375, -1.}, {
       3.5, -1.}}], 
      PolygonBox[{{3.4375, -1.}, {3.437499981032941, -0.9157074104439382}, {
       3.5, -1.}, {3.4375, -1.}}], 
      PolygonBox[{{3.5, -0.79409099469826}, {3.5, -1.}, {
       3.437499981032941, -0.9157074104439382}, {3.5, -0.79409099469826}}], 
      PolygonBox[{{3.437499981032941, -0.9157074104439382}, {
       3.4373449933535234`, -0.7697483574637449}, {3.5, -0.79409099469826}, {
       3.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{3.5, -0.6423372173506324}, {3.5, -0.79409099469826}, {
       3.4373449933535234`, -0.7697483574637449}, {
       3.5, -0.6423372173506324}}], 
      PolygonBox[{{3.4373449933535234`, -0.7697483574637449}, {
       3.404942744332997, -0.5950572556670028}, {3.5, -0.6423372173506324}, {
       3.4373449933535234`, -0.7697483574637449}}], 
      PolygonBox[{{3.491446564961186, -0.508553435038814}, {
       3.5, -0.6423372173506324}, {3.404942744332997, -0.5950572556670028}, {
       3.491446564961186, -0.508553435038814}}], 
      PolygonBox[{{3.404942744332997, -0.5950572556670028}, {
       3.2302516425362553`, -0.5626550066464766}, {
       3.491446564961186, -0.508553435038814}, {
       3.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{3.357662782649368, -0.5}, {
       3.491446564961186, -0.508553435038814}, {
       3.2302516425362553`, -0.5626550066464766}, {3.357662782649368, -0.5}}],
       PolygonBox[{{3.2302516425362553`, -0.5626550066464766}, {
       3.0842925895560604`, -0.5625000189670593}, {3.357662782649368, -0.5}, {
       3.2302516425362553`, -0.5626550066464766}}], 
      PolygonBox[{{3.2059090053732557`, -0.5}, {3.357662782649368, -0.5}, {
       3.0842925895560604`, -0.5625000189670593}, {
       3.2059090053732557`, -0.5}}], 
      PolygonBox[{{3.0842925895560604`, -0.5625000189670593}, {
       3.0001055272204877`, -0.5625}, {3.2059090053732557`, -0.5}, {
       3.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{3.07794195802689, -0.5}, {3.2059090053732557`, -0.5}, {
       3.0001055272204877`, -0.5625}, {3.07794195802689, -0.5}}], 
      PolygonBox[{{3.0001055272204877`, -0.5625}, {
       2.915707410443943, -0.5625000189670593}, {3.07794195802689, -0.5}, {
       3.0001055272204877`, -0.5625}}], 
      PolygonBox[{{2.7940909946955546`, -0.5}, {3.07794195802689, -0.5}, {
       2.915707410443943, -0.5625000189670593}, {2.7940909946955546`, -0.5}}],
       PolygonBox[{{2.915707410443943, -0.5625000189670593}, {
       2.769748357463745, -0.5626550066464766}, {2.7940909946955546`, -0.5}, {
       2.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{2.642337217350634, -0.5}, {2.7940909946955546`, -0.5}, {
       2.769748357463745, -0.5626550066464766}, {2.642337217350634, -0.5}}], 
      PolygonBox[{{2.769748357463745, -0.5626550066464766}, {
       2.595057255667003, -0.5950572556670028}, {2.642337217350634, -0.5}, {
       2.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{3.5, -0.5}, {2.642337217350634, -0.5}, {
       2.595057255667003, -0.5950572556670028}, {3.5, -0.5}}], 
      PolygonBox[{{2.595057255667003, -0.5950572556670028}, {
       2.5626550066464766`, -0.7697483574637446}, {3.5, -0.5}, {
       2.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{2.5, -0.642337217350631}, {3.5, -0.5}, {
       2.5626550066464766`, -0.7697483574637446}, {2.5, -0.642337217350631}}],
       PolygonBox[{{2.5626550066464766`, -0.7697483574637446}, {
       2.562500018967059, -0.9157074104439377}, {2.5, -0.642337217350631}, {
       2.5626550066464766`, -0.7697483574637446}}], 
      PolygonBox[{{2.5, -0.7940909947171011}, {2.5, -0.642337217350631}, {
       2.562500018967059, -0.9157074104439377}, {2.5, -0.7940909947171011}}], 
      PolygonBox[{{2.562500018967059, -0.9157074104439377}, {
       2.5625, -0.9998768219370047}, {2.5, -0.7940909947171011}, {
       2.562500018967059, -0.9157074104439377}}], 
      PolygonBox[{{2.5, -0.9193213332412997}, {2.5, -0.7940909947171011}, {
       2.5625, -0.9998768219370047}, {2.5, -0.9193213332412997}}], 
      PolygonBox[{{2.5625, -0.9998768219370047}, {
       2.562500018967059, -1.084292589556055}, {2.5, -0.9193213332412997}, {
       2.5625, -0.9998768219370047}}], 
      PolygonBox[{{2.5, -1.2059090051452785`}, {2.5, -0.9193213332412997}, {
       2.562500018967059, -1.084292589556055}, {2.5, -1.2059090051452785`}}], 
      PolygonBox[{{2.562500018967059, -1.084292589556055}, {
       2.5626550066464766`, -1.2302516425362549`}, {
       2.5, -1.2059090051452785`}, {2.562500018967059, -1.084292589556055}}], 
      PolygonBox[{{2.5, -1.3576627826493652`}, {2.5, -1.2059090051452785`}, {
       2.5626550066464766`, -1.2302516425362549`}, {
       2.5, -1.3576627826493652`}}], 
      PolygonBox[{{2.5626550066464766`, -1.2302516425362549`}, {
       2.595057255667003, -1.4049427443329972`}, {
       2.5, -1.3576627826493652`}, {
       2.5626550066464766`, -1.2302516425362549`}}], 
      PolygonBox[{{2.5, -0.5}, {2.5, -1.3576627826493652`}, {
       2.595057255667003, -1.4049427443329972`}, {2.5, -0.5}}], 
      PolygonBox[{{2.595057255667003, -1.4049427443329972`}, {
       2.769748357463745, -1.4373449933535234`}, {2.5, -0.5}, {
       2.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{2.5, -1.5}, {2.5, -0.5}, {
       2.769748357463745, -1.4373449933535234`}, {2.5, -1.5}}], 
      PolygonBox[{{2.769748357463745, -1.4373449933535234`}, {
       2.915707410443936, -1.4374999810329407`}, {2.5, -1.5}, {
       2.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{2.794090994433172, -1.5}, {2.5, -1.5}, {
       2.915707410443936, -1.4374999810329407`}, {2.794090994433172, -1.5}}], 
      PolygonBox[{{2.915707410443936, -1.4374999810329407`}, {
       3.000134841831043, -1.4375}, {2.794090994433172, -1.5}, {
       2.915707410443936, -1.4374999810329407`}}], 
      PolygonBox[{{3.0823238704010616`, -1.5}, {2.794090994433172, -1.5}, {
       3.000134841831043, -1.4375}, {3.0823238704010616`, -1.5}}], 
      PolygonBox[{{3.000134841831043, -1.4375}, {
       3.0842925895560533`, -1.4374999810329407`}, {
       3.0823238704010616`, -1.5}, {3.000134841831043, -1.4375}}], 
      PolygonBox[{{3.2059090053603976`, -1.5}, {3.0823238704010616`, -1.5}, {
       3.0842925895560533`, -1.4374999810329407`}, {
       3.2059090053603976`, -1.5}}], 
      PolygonBox[{{3.0842925895560533`, -1.4374999810329407`}, {
       3.230251642536255, -1.4373449933535234`}, {
       3.2059090053603976`, -1.5}, {
       3.0842925895560533`, -1.4374999810329407`}}], 
      PolygonBox[{{3.357662782649371, -1.5}, {3.2059090053603976`, -1.5}, {
       3.230251642536255, -1.4373449933535234`}, {3.357662782649371, -1.5}}], 
      PolygonBox[{{3.230251642536255, -1.4373449933535234`}, {
       3.404942744332997, -1.4049427443329972`}, {3.357662782649371, -1.5}, {
       3.230251642536255, -1.4373449933535234`}}], 
      PolygonBox[{{3.5, -1.5}, {3.357662782649371, -1.5}, {
       3.404942744332997, -1.4049427443329972`}, {3.5, -1.5}}], 
      PolygonBox[{{3.404942744332997, -1.4049427443329972`}, {
       3.404942744332997, -1.4049427443329972`}, {3.5, -1.5}, {
       3.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{3.5, -1.5}, {3.5, -1.5}, {
       3.404942744332997, -1.4049427443329972`}, {3.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, 0.}, {2.5208333333333335`, 0.}, {2.5416666666666665`, 
       0.}, {2.5625, 0.}, {2.5833333333333335`, 0.}, {2.6041666666666665`, 
       0.}, {2.625, 0.}, {2.625, 0.}, {2.6041666666666665`, 0.}, {
       2.5833333333333335`, 0.}, {2.5625, 0.}, {2.5416666666666665`, 0.}, {
       2.5208333333333335`, 0.}, {2.5, 0.}, {2.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, 0.}, {3.3958333333333335`, 0.}, {3.4166666666666665`, 
       0.}, {3.4375, 0.}, {3.4583333333333335`, 0.}, {3.4791666666666665`, 
       0.}, {3.5, 0.}, {3.5, 0.}, {3.4791666666666665`, 0.}, {
       3.4583333333333335`, 0.}, {3.4375, 0.}, {3.4166666666666665`, 0.}, {
       3.3958333333333335`, 0.}, {3.375, 0.}, {3.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -0.5}, {3., -0.4791666666666667}, {
       3., -0.4583333333333333}, {3., -0.4375}, {3., -0.4166666666666667}, {
       3., -0.39583333333333337`}, {3., -0.375}, {3., -0.375}, {
       3., -0.3958333333333333}, {3., -0.4166666666666667}, {3., -0.4375}, {
       3., -0.4583333333333333}, {3., -0.47916666666666663`}, {3., -0.5}, {
       3., -0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 0.375}, {3., 0.3958333333333333}, {3., 
       0.4166666666666667}, {3., 0.4375}, {3., 0.4583333333333333}, {3., 
       0.47916666666666663`}, {3., 0.5}, {3., 0.5}, {3., 
       0.4791666666666667}, {3., 0.4583333333333333}, {3., 0.4375}, {3., 
       0.4166666666666667}, {3., 0.39583333333333337`}, {3., 0.375}, {3., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, 0.}, {2.75, 0.}, {2.875, 0.}, {3., 0.}, {3.125, 0.}, {
       3.25, 0.}, {3.375, 0.}, {3.375, 0.}, {3.25, 0.}, {3.125, 0.}, {3., 
       0.}, {2.875, 0.}, {2.75, 0.}, {2.625, 0.}, {2.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -0.375}, {3., -0.25}, {3., -0.125}, {3., 0.}, {3., 
       0.125}, {3., 0.25}, {3., 0.375}, {3., 0.375}, {3., 0.25}, {3., 
       0.125}, {3., 0.}, {3., -0.125}, {3., -0.25}, {3., -0.375}, {
       3., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDjDWq4vr9l15yuVwozNm0Z4bO+wN3E+0Ss/k
cvgPBsftZ7+dfZNPnsvhZs79M2U/LtiDNTVwOjRYOundOXHF3v+J0NOjxzgc
/PvLvi7Vuw6RZ+CAmn/DfqP0WykrS3aHAGT5Bja4/lShFLWPD1gdbkHNv7DD
vOpJGqsDC1jhCXsxvUBHbSlWhwdQ90HMZXXg6prnY1nZZQOTPweR3w/T/wfi
/v0pUPOvQ8zfD7O/DmL/fpj7/CDu24/m/v1+UP9B3b8fbGw9p0MTVD8sfKDu
3w8LPzaI+/fDwvcd1H2w8Ie4f9YeANSwp5A=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhD6gf3qVSDABeeHggEnnA+hOdDUs8H5YWD1
rGjqWQjyIfquovGPoqmHARaHEIj8flT+1f2o6h9g8ENR3bcfzf370fy3H83/
+1ehhg9UPQ9BfhiK+2D8o2jqYYAH5j97VP5Ve1T1D+wBDCZUkA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, -0.2651650429449553}, {
       3.3247595264191645`, -0.1875}, {
       3.404942744332997, -0.4049427443329971}, {
       3.2651650429449552`, -0.2651650429449553}}], 
      PolygonBox[{{3.4373449933535234`, -0.23025164253625516`}, {
       3.404942744332997, -0.4049427443329971}, {
       3.3247595264191645`, -0.1875}, {
       3.4373449933535234`, -0.23025164253625516`}}], 
      PolygonBox[{{3.3247595264191645`, -0.1875}, {
       3.3622221848584006`, -0.0970571419134453}, {
       3.4373449933535234`, -0.23025164253625516`}, {
       3.3247595264191645`, -0.1875}}], 
      PolygonBox[{{3.437499981032941, -0.08429258955606181}, {
       3.4373449933535234`, -0.23025164253625516`}, {
       3.3622221848584006`, -0.0970571419134453}, {
       3.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{3.3622221848584006`, -0.0970571419134453}, {3.375, 0.}, {
       3.437499981032941, -0.08429258955606181}, {
       3.3622221848584006`, -0.0970571419134453}}], 
      PolygonBox[{{3.4375, 0.}, {3.437499981032941, -0.08429258955606181}, {
       3.375, 0.}, {3.4375, 0.}}], 
      PolygonBox[{{3.375, 0.}, {3.3622221848584006`, 0.09705714191344525}, {
       3.4375, 0.}, {3.375, 0.}}], 
      PolygonBox[{{3.437499981032941, 0.08429258955606177}, {3.4375, 0.}, {
       3.3622221848584006`, 0.09705714191344525}, {3.437499981032941, 
       0.08429258955606177}}], 
      PolygonBox[{{3.3622221848584006`, 0.09705714191344525}, {
       3.3247595264191645`, 0.18749999999999994`}, {3.437499981032941, 
       0.08429258955606177}, {3.3622221848584006`, 0.09705714191344525}}], 
      PolygonBox[{{3.4373449933535234`, 0.23025164253625502`}, {
       3.437499981032941, 0.08429258955606177}, {3.3247595264191645`, 
       0.18749999999999994`}, {3.4373449933535234`, 0.23025164253625502`}}], 
      PolygonBox[{{3.3247595264191645`, 0.18749999999999994`}, {
       3.2651650429449552`, 0.2651650429449553}, {3.4373449933535234`, 
       0.23025164253625502`}, {3.3247595264191645`, 0.18749999999999994`}}], 
      PolygonBox[{{3.404942744332997, 0.40494274433299715`}, {
       3.4373449933535234`, 0.23025164253625502`}, {3.2651650429449552`, 
       0.2651650429449553}, {3.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{3.2651650429449552`, 0.2651650429449553}, {3.1875, 
       0.3247595264191645}, {3.404942744332997, 0.40494274433299715`}, {
       3.2651650429449552`, 0.2651650429449553}}], 
      PolygonBox[{{3.2302516425362553`, 0.4373449933535234}, {
       3.404942744332997, 0.40494274433299715`}, {3.1875, 
       0.3247595264191645}, {3.2302516425362553`, 0.4373449933535234}}], 
      PolygonBox[{{3.1875, 0.3247595264191645}, {3.0970571419134454`, 
       0.3622221848584006}, {3.2302516425362553`, 0.4373449933535234}, {
       3.1875, 0.3247595264191645}}], 
      PolygonBox[{{3.0842925895560604`, 0.4374999810329408}, {
       3.2302516425362553`, 0.4373449933535234}, {3.0970571419134454`, 
       0.3622221848584006}, {3.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{3.0970571419134454`, 0.3622221848584006}, {3., 0.375}, {
       3.0842925895560604`, 0.4374999810329408}, {3.0970571419134454`, 
       0.3622221848584006}}], 
      PolygonBox[{{3.0001055272204877`, 0.4375}, {3.0842925895560604`, 
       0.4374999810329408}, {3., 0.375}, {3.0001055272204877`, 0.4375}}], 
      PolygonBox[{{3., 0.375}, {2.902942858086555, 0.36222218485840063`}, {
       3.0001055272204877`, 0.4375}, {3., 0.375}}], 
      PolygonBox[{{2.915707410443943, 0.4374999810329408}, {
       3.0001055272204877`, 0.4375}, {2.902942858086555, 
       0.36222218485840063`}, {2.915707410443943, 0.4374999810329408}}], 
      PolygonBox[{{2.902942858086555, 0.36222218485840063`}, {2.8125, 
       0.3247595264191645}, {2.915707410443943, 0.4374999810329408}, {
       2.902942858086555, 0.36222218485840063`}}], 
      PolygonBox[{{2.769748357463745, 0.4373449933535234}, {2.915707410443943,
        0.4374999810329408}, {2.8125, 0.3247595264191645}, {2.769748357463745,
        0.4373449933535234}}], 
      PolygonBox[{{2.8125, 0.3247595264191645}, {2.7348349570550448`, 
       0.26516504294495535`}, {2.769748357463745, 0.4373449933535234}, {
       2.8125, 0.3247595264191645}}], 
      PolygonBox[{{2.595057255667003, 0.40494274433299715`}, {
       2.769748357463745, 0.4373449933535234}, {2.7348349570550448`, 
       0.26516504294495535`}, {2.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{2.7348349570550448`, 0.26516504294495535`}, {
       2.6752404735808355`, 0.1875000000000001}, {2.595057255667003, 
       0.40494274433299715`}, {2.7348349570550448`, 0.26516504294495535`}}], 
      PolygonBox[{{2.5626550066464766`, 0.2302516425362554}, {
       2.595057255667003, 0.40494274433299715`}, {2.6752404735808355`, 
       0.1875000000000001}, {2.5626550066464766`, 0.2302516425362554}}], 
      PolygonBox[{{2.6752404735808355`, 0.1875000000000001}, {
       2.6377778151415994`, 0.09705714191344539}, {2.5626550066464766`, 
       0.2302516425362554}, {2.6752404735808355`, 0.1875000000000001}}], 
      PolygonBox[{{2.562500018967059, 0.08429258955606238}, {
       2.5626550066464766`, 0.2302516425362554}, {2.6377778151415994`, 
       0.09705714191344539}, {2.562500018967059, 0.08429258955606238}}], 
      PolygonBox[{{2.6377778151415994`, 0.09705714191344539}, {2.625, 
       2.1245770866179924`*^-16}, {2.562500018967059, 0.08429258955606238}, {
       2.6377778151415994`, 0.09705714191344539}}], 
      PolygonBox[{{2.5625, 0.00012317806299537147`}, {2.562500018967059, 
       0.08429258955606238}, {2.625, 2.1245770866179924`*^-16}, {2.5625, 
       0.00012317806299537147`}}], 
      PolygonBox[{{2.625, 2.1245770866179924`*^-16}, {
       2.6377778151415994`, -0.09705714191344514}, {2.5625, 
       0.00012317806299537147`}, {2.625, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{2.562500018967059, -0.084292589556055}, {2.5625, 
       0.00012317806299537147`}, {
       2.6377778151415994`, -0.09705714191344514}, {
       2.562500018967059, -0.084292589556055}}], 
      PolygonBox[{{2.6377778151415994`, -0.09705714191344514}, {
       2.6752404735808355`, -0.18749999999999978`}, {
       2.562500018967059, -0.084292589556055}, {
       2.6377778151415994`, -0.09705714191344514}}], 
      PolygonBox[{{2.5626550066464766`, -0.23025164253625477`}, {
       2.562500018967059, -0.084292589556055}, {
       2.6752404735808355`, -0.18749999999999978`}, {
       2.5626550066464766`, -0.23025164253625477`}}], 
      PolygonBox[{{2.6752404735808355`, -0.18749999999999978`}, {
       2.7348349570550448`, -0.2651650429449553}, {
       2.5626550066464766`, -0.23025164253625477`}, {
       2.6752404735808355`, -0.18749999999999978`}}], 
      PolygonBox[{{2.595057255667003, -0.4049427443329971}, {
       2.5626550066464766`, -0.23025164253625477`}, {
       2.7348349570550448`, -0.2651650429449553}, {
       2.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{2.7348349570550448`, -0.2651650429449553}, {
       2.8125, -0.3247595264191644}, {
       2.595057255667003, -0.4049427443329971}, {
       2.7348349570550448`, -0.2651650429449553}}], 
      PolygonBox[{{2.769748357463745, -0.4373449933535234}, {
       2.595057255667003, -0.4049427443329971}, {
       2.8125, -0.3247595264191644}, {
       2.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{2.8125, -0.3247595264191644}, {
       2.9029428580865546`, -0.3622221848584005}, {
       2.769748357463745, -0.4373449933535234}, {
       2.8125, -0.3247595264191644}}], 
      PolygonBox[{{2.915707410443936, -0.4374999810329408}, {
       2.769748357463745, -0.4373449933535234}, {
       2.9029428580865546`, -0.3622221848584005}, {
       2.915707410443936, -0.4374999810329408}}], 
      PolygonBox[{{2.9029428580865546`, -0.3622221848584005}, {3., -0.375}, {
       2.915707410443936, -0.4374999810329408}, {
       2.9029428580865546`, -0.3622221848584005}}], 
      PolygonBox[{{3.000134841831043, -0.4375}, {
       2.915707410443936, -0.4374999810329408}, {3., -0.375}, {
       3.000134841831043, -0.4375}}], 
      PolygonBox[{{3., -0.375}, {3.097057141913445, -0.36222218485840063`}, {
       3.000134841831043, -0.4375}, {3., -0.375}}], 
      PolygonBox[{{3.0842925895560533`, -0.4374999810329408}, {
       3.000134841831043, -0.4375}, {
       3.097057141913445, -0.36222218485840063`}, {
       3.0842925895560533`, -0.4374999810329408}}], 
      PolygonBox[{{3.097057141913445, -0.36222218485840063`}, {
       3.1874999999999996`, -0.3247595264191646}, {
       3.0842925895560533`, -0.4374999810329408}, {
       3.097057141913445, -0.36222218485840063`}}], 
      PolygonBox[{{3.230251642536255, -0.4373449933535234}, {
       3.0842925895560533`, -0.4374999810329408}, {
       3.1874999999999996`, -0.3247595264191646}, {
       3.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{3.1874999999999996`, -0.3247595264191646}, {
       3.2651650429449552`, -0.26516504294495535`}, {
       3.230251642536255, -0.4373449933535234}, {
       3.1874999999999996`, -0.3247595264191646}}], 
      PolygonBox[{{3.404942744332997, -0.40494274433299715`}, {
       3.230251642536255, -0.4373449933535234}, {
       3.2651650429449552`, -0.26516504294495535`}, {
       3.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{3.2651650429449552`, -0.26516504294495535`}, {
       3.2651650429449552`, -0.2651650429449553}, {
       3.404942744332997, -0.40494274433299715`}, {
       3.2651650429449552`, -0.26516504294495535`}}], 
      PolygonBox[{{3.404942744332997, -0.4049427443329971}, {
       3.404942744332997, -0.40494274433299715`}, {
       3.2651650429449552`, -0.2651650429449553}, {
       3.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{3.404942744332997, -0.4049427443329971}, {
       3.4373449933535234`, -0.23025164253625516`}, {3.5, -0.5}, {
       3.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{3.5, -0.3576627826493677}, {3.5, -0.5}, {
       3.4373449933535234`, -0.23025164253625516`}, {
       3.5, -0.3576627826493677}}], 
      PolygonBox[{{3.4373449933535234`, -0.23025164253625516`}, {
       3.437499981032941, -0.08429258955606181}, {3.5, -0.3576627826493677}, {
       3.4373449933535234`, -0.23025164253625516`}}], 
      PolygonBox[{{3.5, -0.20590900530173997`}, {3.5, -0.3576627826493677}, {
       3.437499981032941, -0.08429258955606181}, {
       3.5, -0.20590900530173997`}}], 
      PolygonBox[{{3.437499981032941, -0.08429258955606181}, {3.4375, 0.}, {
       3.5, -0.20590900530173997`}, {
       3.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{3.5, 0.}, {3.5, -0.20590900530173997`}, {3.4375, 0.}, {3.5,
        0.}}], PolygonBox[{{3.4375, 0.}, {3.437499981032941, 
       0.08429258955606177}, {3.5, 0.}, {3.4375, 0.}}], 
      PolygonBox[{{3.5, 0.20590900530173992`}, {3.5, 0.}, {3.437499981032941, 
       0.08429258955606177}, {3.5, 0.20590900530173992`}}], 
      PolygonBox[{{3.437499981032941, 0.08429258955606177}, {
       3.4373449933535234`, 0.23025164253625502`}, {3.5, 
       0.20590900530173992`}, {3.437499981032941, 0.08429258955606177}}], 
      PolygonBox[{{3.5, 0.35766278264936757`}, {3.5, 0.20590900530173992`}, {
       3.4373449933535234`, 0.23025164253625502`}, {3.5, 
       0.35766278264936757`}}], 
      PolygonBox[{{3.4373449933535234`, 0.23025164253625502`}, {
       3.404942744332997, 0.40494274433299715`}, {3.5, 
       0.35766278264936757`}, {3.4373449933535234`, 0.23025164253625502`}}], 
      PolygonBox[{{3.491446564961186, 0.491446564961186}, {3.5, 
       0.35766278264936757`}, {3.404942744332997, 0.40494274433299715`}, {
       3.491446564961186, 0.491446564961186}}], 
      PolygonBox[{{3.404942744332997, 0.40494274433299715`}, {
       3.2302516425362553`, 0.4373449933535234}, {3.491446564961186, 
       0.491446564961186}, {3.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{3.357662782649368, 0.5}, {3.491446564961186, 
       0.491446564961186}, {3.2302516425362553`, 0.4373449933535234}, {
       3.357662782649368, 0.5}}], 
      PolygonBox[{{3.2302516425362553`, 0.4373449933535234}, {
       3.0842925895560604`, 0.4374999810329408}, {3.357662782649368, 0.5}, {
       3.2302516425362553`, 0.4373449933535234}}], 
      PolygonBox[{{3.2059090053732557`, 0.5}, {3.357662782649368, 0.5}, {
       3.0842925895560604`, 0.4374999810329408}, {3.2059090053732557`, 0.5}}],
       PolygonBox[{{3.0842925895560604`, 0.4374999810329408}, {
       3.0001055272204877`, 0.4375}, {3.2059090053732557`, 0.5}, {
       3.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{3.07794195802689, 0.5}, {3.2059090053732557`, 0.5}, {
       3.0001055272204877`, 0.4375}, {3.07794195802689, 0.5}}], 
      PolygonBox[{{3.0001055272204877`, 0.4375}, {2.915707410443943, 
       0.4374999810329408}, {3.07794195802689, 0.5}, {3.0001055272204877`, 
       0.4375}}], 
      PolygonBox[{{2.7940909946955546`, 0.5}, {3.07794195802689, 0.5}, {
       2.915707410443943, 0.4374999810329408}, {2.7940909946955546`, 0.5}}], 
      PolygonBox[{{2.915707410443943, 0.4374999810329408}, {2.769748357463745,
        0.4373449933535234}, {2.7940909946955546`, 0.5}, {2.915707410443943, 
       0.4374999810329408}}], 
      PolygonBox[{{2.642337217350634, 0.5}, {2.7940909946955546`, 0.5}, {
       2.769748357463745, 0.4373449933535234}, {2.642337217350634, 0.5}}], 
      PolygonBox[{{2.769748357463745, 0.4373449933535234}, {2.595057255667003,
        0.40494274433299715`}, {2.642337217350634, 0.5}, {2.769748357463745, 
       0.4373449933535234}}], 
      PolygonBox[{{3.5, 0.5}, {2.642337217350634, 0.5}, {2.595057255667003, 
       0.40494274433299715`}, {3.5, 0.5}}], 
      PolygonBox[{{2.595057255667003, 0.40494274433299715`}, {
       2.5626550066464766`, 0.2302516425362554}, {3.5, 0.5}, {
       2.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{2.5, 0.357662782649369}, {3.5, 0.5}, {2.5626550066464766`, 
       0.2302516425362554}, {2.5, 0.357662782649369}}], 
      PolygonBox[{{2.5626550066464766`, 0.2302516425362554}, {
       2.562500018967059, 0.08429258955606238}, {2.5, 0.357662782649369}, {
       2.5626550066464766`, 0.2302516425362554}}], 
      PolygonBox[{{2.5, 0.20590900528289896`}, {2.5, 0.357662782649369}, {
       2.562500018967059, 0.08429258955606238}, {2.5, 0.20590900528289896`}}],
       PolygonBox[{{2.562500018967059, 0.08429258955606238}, {2.5625, 
       0.00012317806299537147`}, {2.5, 0.20590900528289896`}, {
       2.562500018967059, 0.08429258955606238}}], 
      PolygonBox[{{2.5, 0.08067866675870025}, {2.5, 0.20590900528289896`}, {
       2.5625, 0.00012317806299537147`}, {2.5, 0.08067866675870025}}], 
      PolygonBox[{{2.5625, 0.00012317806299537147`}, {
       2.562500018967059, -0.084292589556055}, {2.5, 0.08067866675870025}, {
       2.5625, 0.00012317806299537147`}}], 
      PolygonBox[{{2.5, -0.20590900514527852`}, {2.5, 0.08067866675870025}, {
       2.562500018967059, -0.084292589556055}, {2.5, -0.20590900514527852`}}],
       PolygonBox[{{2.562500018967059, -0.084292589556055}, {
       2.5626550066464766`, -0.23025164253625477`}, {
       2.5, -0.20590900514527852`}, {2.562500018967059, -0.084292589556055}}],
       PolygonBox[{{2.5, -0.35766278264936535`}, {
       2.5, -0.20590900514527852`}, {
       2.5626550066464766`, -0.23025164253625477`}, {
       2.5, -0.35766278264936535`}}], 
      PolygonBox[{{2.5626550066464766`, -0.23025164253625477`}, {
       2.595057255667003, -0.4049427443329971}, {
       2.5, -0.35766278264936535`}, {
       2.5626550066464766`, -0.23025164253625477`}}], 
      PolygonBox[{{2.5, 0.5}, {2.5, -0.35766278264936535`}, {
       2.595057255667003, -0.4049427443329971}, {2.5, 0.5}}], 
      PolygonBox[{{2.595057255667003, -0.4049427443329971}, {
       2.769748357463745, -0.4373449933535234}, {2.5, 0.5}, {
       2.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{2.5, -0.5}, {2.5, 0.5}, {
       2.769748357463745, -0.4373449933535234}, {2.5, -0.5}}], 
      PolygonBox[{{2.769748357463745, -0.4373449933535234}, {
       2.915707410443936, -0.4374999810329408}, {2.5, -0.5}, {
       2.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{2.794090994433172, -0.5}, {2.5, -0.5}, {
       2.915707410443936, -0.4374999810329408}, {2.794090994433172, -0.5}}], 
      PolygonBox[{{2.915707410443936, -0.4374999810329408}, {
       3.000134841831043, -0.4375}, {2.794090994433172, -0.5}, {
       2.915707410443936, -0.4374999810329408}}], 
      PolygonBox[{{3.0823238704010616`, -0.5}, {2.794090994433172, -0.5}, {
       3.000134841831043, -0.4375}, {3.0823238704010616`, -0.5}}], 
      PolygonBox[{{3.000134841831043, -0.4375}, {
       3.0842925895560533`, -0.4374999810329408}, {
       3.0823238704010616`, -0.5}, {3.000134841831043, -0.4375}}], 
      PolygonBox[{{3.2059090053603976`, -0.5}, {3.0823238704010616`, -0.5}, {
       3.0842925895560533`, -0.4374999810329408}, {
       3.2059090053603976`, -0.5}}], 
      PolygonBox[{{3.0842925895560533`, -0.4374999810329408}, {
       3.230251642536255, -0.4373449933535234}, {3.2059090053603976`, -0.5}, {
       3.0842925895560533`, -0.4374999810329408}}], 
      PolygonBox[{{3.357662782649371, -0.5}, {3.2059090053603976`, -0.5}, {
       3.230251642536255, -0.4373449933535234}, {3.357662782649371, -0.5}}], 
      PolygonBox[{{3.230251642536255, -0.4373449933535234}, {
       3.404942744332997, -0.40494274433299715`}, {3.357662782649371, -0.5}, {
       3.230251642536255, -0.4373449933535234}}], 
      PolygonBox[{{3.5, -0.5}, {3.357662782649371, -0.5}, {
       3.404942744332997, -0.40494274433299715`}, {3.5, -0.5}}], 
      PolygonBox[{{3.404942744332997, -0.40494274433299715`}, {
       3.404942744332997, -0.4049427443329971}, {3.5, -0.5}, {
       3.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{3.5, -0.5}, {3.5, -0.5}, {
       3.404942744332997, -0.4049427443329971}, {
       3.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, 1.}, {2.5208333333333335`, 1.}, {2.5416666666666665`, 
       1.}, {2.5625, 1.}, {2.5833333333333335`, 1.}, {2.6041666666666665`, 
       1.}, {2.625, 1.}, {2.625, 1.}, {2.6041666666666665`, 1.}, {
       2.5833333333333335`, 1.}, {2.5625, 1.}, {2.5416666666666665`, 1.}, {
       2.5208333333333335`, 1.}, {2.5, 1.}, {2.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, 1.}, {3.3958333333333335`, 1.}, {3.4166666666666665`, 
       1.}, {3.4375, 1.}, {3.4583333333333335`, 1.}, {3.4791666666666665`, 
       1.}, {3.5, 1.}, {3.5, 1.}, {3.4791666666666665`, 1.}, {
       3.4583333333333335`, 1.}, {3.4375, 1.}, {3.4166666666666665`, 1.}, {
       3.3958333333333335`, 1.}, {3.375, 1.}, {3.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 0.5}, {3., 0.5208333333333333}, {3., 
       0.5416666666666667}, {3., 0.5625}, {3., 0.5833333333333333}, {3., 
       0.6041666666666666}, {3., 0.625}, {3., 0.625}, {3., 
       0.6041666666666667}, {3., 0.5833333333333333}, {3., 0.5625}, {3., 
       0.5416666666666667}, {3., 0.5208333333333334}, {3., 0.5}, {3., 0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 1.375}, {3., 1.3958333333333333`}, {3., 
       1.4166666666666667`}, {3., 1.4375}, {3., 1.4583333333333333`}, {3., 
       1.4791666666666665`}, {3., 1.5}, {3., 1.5}, {3., 
       1.4791666666666667`}, {3., 1.4583333333333333`}, {3., 1.4375}, {3., 
       1.4166666666666667`}, {3., 1.3958333333333335`}, {3., 1.375}, {3., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, 1.}, {2.75, 1.}, {2.875, 1.}, {3., 1.}, {3.125, 1.}, {
       3.25, 1.}, {3.375, 1.}, {3.375, 1.}, {3.25, 1.}, {3.125, 1.}, {3., 
       1.}, {2.875, 1.}, {2.75, 1.}, {2.625, 1.}, {2.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 0.625}, {3., 0.75}, {3., 0.875}, {3., 1.}, {3., 1.125}, {
       3., 1.25}, {3., 1.375}, {3., 1.375}, {3., 1.25}, {3., 1.125}, {3., 
       1.}, {3., 0.875}, {3., 0.75}, {3., 0.625}, {3., 0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhD6g/2ri+v2XXnK5TDvhOqp7t6P9gbuJ1ql
Z3JB5T/bz347+yafPJeD2W3zzbJ2X+zBwg2cDgl9E7jNjb7a+z8Renr0GIfD
lcWxtStPf4XIM3BA9X+z3yj9VsrKkh1VvoENrj9VKEXt4wNWuPkXdphXPUlj
hdsvphfoqC3FCncfRBwm/wEufyxvS/aLJ2/g+hnB8q/sU6DmT/GcMPNI83O4
/Y6P772YOPsp3H2RO1xY12Y8QXP/E3s/qP8ioPL/QaCe08Eeqh8WPpOh5sPC
7x9Y4Ut4+B6Cug8W/mDp/+/tAbkQm7k=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhD6h/3qVSDABeeHggEnnA+hOdDUs8H5YWD1
rGjqWQjyIfq+wvkQcz+hqf+AJv8KTf9TNPUPMPihKO57gOb+B2j+e4Dm/wf2
q1DCB6aehyA/FMV9PA6rUNwPU/8BTf4Tmv6vaOp/2AMAX4xaRg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, 0.7348349570550448}, {
       3.3247595264191645`, 0.8125}, {3.404942744332997, 
       0.5950572556670028}, {3.2651650429449552`, 0.7348349570550448}}], 
      PolygonBox[{{3.4373449933535234`, 0.7697483574637448}, {
       3.404942744332997, 0.5950572556670028}, {3.3247595264191645`, 
       0.8125}, {3.4373449933535234`, 0.7697483574637448}}], 
      PolygonBox[{{3.3247595264191645`, 0.8125}, {3.3622221848584006`, 
       0.9029428580865547}, {3.4373449933535234`, 0.7697483574637448}, {
       3.3247595264191645`, 0.8125}}], 
      PolygonBox[{{3.437499981032941, 0.9157074104439382}, {
       3.4373449933535234`, 0.7697483574637448}, {3.3622221848584006`, 
       0.9029428580865547}, {3.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{3.3622221848584006`, 0.9029428580865547}, {3.375, 1.}, {
       3.437499981032941, 0.9157074104439382}, {3.3622221848584006`, 
       0.9029428580865547}}], 
      PolygonBox[{{3.4375, 1.}, {3.437499981032941, 0.9157074104439382}, {
       3.375, 1.}, {3.4375, 1.}}], 
      PolygonBox[{{3.375, 1.}, {3.3622221848584006`, 1.0970571419134452`}, {
       3.4375, 1.}, {3.375, 1.}}], 
      PolygonBox[{{3.437499981032941, 1.0842925895560618`}, {3.4375, 1.}, {
       3.3622221848584006`, 1.0970571419134452`}, {3.437499981032941, 
       1.0842925895560618`}}], 
      PolygonBox[{{3.3622221848584006`, 1.0970571419134452`}, {
       3.3247595264191645`, 1.1875}, {3.437499981032941, 
       1.0842925895560618`}, {3.3622221848584006`, 1.0970571419134452`}}], 
      PolygonBox[{{3.4373449933535234`, 1.230251642536255}, {
       3.437499981032941, 1.0842925895560618`}, {3.3247595264191645`, 
       1.1875}, {3.4373449933535234`, 1.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, 1.1875}, {3.2651650429449552`, 
       1.2651650429449552`}, {3.4373449933535234`, 1.230251642536255}, {
       3.3247595264191645`, 1.1875}}], 
      PolygonBox[{{3.404942744332997, 1.4049427443329972`}, {
       3.4373449933535234`, 1.230251642536255}, {3.2651650429449552`, 
       1.2651650429449552`}, {3.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{3.2651650429449552`, 1.2651650429449552`}, {3.1875, 
       1.3247595264191645`}, {3.404942744332997, 1.4049427443329972`}, {
       3.2651650429449552`, 1.2651650429449552`}}], 
      PolygonBox[{{3.2302516425362553`, 1.4373449933535234`}, {
       3.404942744332997, 1.4049427443329972`}, {3.1875, 
       1.3247595264191645`}, {3.2302516425362553`, 1.4373449933535234`}}], 
      PolygonBox[{{3.1875, 1.3247595264191645`}, {3.0970571419134454`, 
       1.3622221848584006`}, {3.2302516425362553`, 1.4373449933535234`}, {
       3.1875, 1.3247595264191645`}}], 
      PolygonBox[{{3.0842925895560604`, 1.4374999810329407`}, {
       3.2302516425362553`, 1.4373449933535234`}, {3.0970571419134454`, 
       1.3622221848584006`}, {3.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{3.0970571419134454`, 1.3622221848584006`}, {3., 1.375}, {
       3.0842925895560604`, 1.4374999810329407`}, {3.0970571419134454`, 
       1.3622221848584006`}}], 
      PolygonBox[{{3.0001055272204877`, 1.4375}, {3.0842925895560604`, 
       1.4374999810329407`}, {3., 1.375}, {3.0001055272204877`, 1.4375}}], 
      PolygonBox[{{3., 1.375}, {2.902942858086555, 1.3622221848584006`}, {
       3.0001055272204877`, 1.4375}, {3., 1.375}}], 
      PolygonBox[{{2.915707410443943, 1.4374999810329407`}, {
       3.0001055272204877`, 1.4375}, {2.902942858086555, 
       1.3622221848584006`}, {2.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{2.902942858086555, 1.3622221848584006`}, {2.8125, 
       1.3247595264191645`}, {2.915707410443943, 1.4374999810329407`}, {
       2.902942858086555, 1.3622221848584006`}}], 
      PolygonBox[{{2.769748357463745, 1.4373449933535234`}, {
       2.915707410443943, 1.4374999810329407`}, {2.8125, 
       1.3247595264191645`}, {2.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{2.8125, 1.3247595264191645`}, {2.7348349570550448`, 
       1.2651650429449552`}, {2.769748357463745, 1.4373449933535234`}, {
       2.8125, 1.3247595264191645`}}], 
      PolygonBox[{{2.595057255667003, 1.4049427443329972`}, {
       2.769748357463745, 1.4373449933535234`}, {2.7348349570550448`, 
       1.2651650429449552`}, {2.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{2.7348349570550448`, 1.2651650429449552`}, {
       2.6752404735808355`, 1.1875}, {2.595057255667003, 
       1.4049427443329972`}, {2.7348349570550448`, 1.2651650429449552`}}], 
      PolygonBox[{{2.5626550066464766`, 1.2302516425362553`}, {
       2.595057255667003, 1.4049427443329972`}, {2.6752404735808355`, 
       1.1875}, {2.5626550066464766`, 1.2302516425362553`}}], 
      PolygonBox[{{2.6752404735808355`, 1.1875}, {2.6377778151415994`, 
       1.0970571419134454`}, {2.5626550066464766`, 1.2302516425362553`}, {
       2.6752404735808355`, 1.1875}}], 
      PolygonBox[{{2.562500018967059, 1.0842925895560624`}, {
       2.5626550066464766`, 1.2302516425362553`}, {2.6377778151415994`, 
       1.0970571419134454`}, {2.562500018967059, 1.0842925895560624`}}], 
      PolygonBox[{{2.6377778151415994`, 1.0970571419134454`}, {2.625, 
       1.0000000000000002`}, {2.562500018967059, 1.0842925895560624`}, {
       2.6377778151415994`, 1.0970571419134454`}}], 
      PolygonBox[{{2.5625, 1.0001231780629953`}, {2.562500018967059, 
       1.0842925895560624`}, {2.625, 1.0000000000000002`}, {2.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{2.625, 1.0000000000000002`}, {2.6377778151415994`, 
       0.9029428580865548}, {2.5625, 1.0001231780629953`}, {2.625, 
       1.0000000000000002`}}], 
      PolygonBox[{{2.562500018967059, 0.915707410443945}, {2.5625, 
       1.0001231780629953`}, {2.6377778151415994`, 0.9029428580865548}, {
       2.562500018967059, 0.915707410443945}}], 
      PolygonBox[{{2.6377778151415994`, 0.9029428580865548}, {
       2.6752404735808355`, 0.8125000000000002}, {2.562500018967059, 
       0.915707410443945}, {2.6377778151415994`, 0.9029428580865548}}], 
      PolygonBox[{{2.5626550066464766`, 0.7697483574637453}, {
       2.562500018967059, 0.915707410443945}, {2.6752404735808355`, 
       0.8125000000000002}, {2.5626550066464766`, 0.7697483574637453}}], 
      PolygonBox[{{2.6752404735808355`, 0.8125000000000002}, {
       2.7348349570550448`, 0.7348349570550448}, {2.5626550066464766`, 
       0.7697483574637453}, {2.6752404735808355`, 0.8125000000000002}}], 
      PolygonBox[{{2.595057255667003, 0.5950572556670028}, {
       2.5626550066464766`, 0.7697483574637453}, {2.7348349570550448`, 
       0.7348349570550448}, {2.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{2.7348349570550448`, 0.7348349570550448}, {2.8125, 
       0.6752404735808356}, {2.595057255667003, 0.5950572556670028}, {
       2.7348349570550448`, 0.7348349570550448}}], 
      PolygonBox[{{2.769748357463745, 0.5626550066464766}, {2.595057255667003,
        0.5950572556670028}, {2.8125, 0.6752404735808356}, {2.769748357463745,
        0.5626550066464766}}], 
      PolygonBox[{{2.8125, 0.6752404735808356}, {2.9029428580865546`, 
       0.6377778151415995}, {2.769748357463745, 0.5626550066464766}, {2.8125, 
       0.6752404735808356}}], 
      PolygonBox[{{2.915707410443936, 0.5625000189670593}, {2.769748357463745,
        0.5626550066464766}, {2.9029428580865546`, 0.6377778151415995}, {
       2.915707410443936, 0.5625000189670593}}], 
      PolygonBox[{{2.9029428580865546`, 0.6377778151415995}, {3., 0.625}, {
       2.915707410443936, 0.5625000189670593}, {2.9029428580865546`, 
       0.6377778151415995}}], 
      PolygonBox[{{3.000134841831043, 0.5625}, {2.915707410443936, 
       0.5625000189670593}, {3., 0.625}, {3.000134841831043, 0.5625}}], 
      PolygonBox[{{3., 0.625}, {3.097057141913445, 0.6377778151415994}, {
       3.000134841831043, 0.5625}, {3., 0.625}}], 
      PolygonBox[{{3.0842925895560533`, 0.5625000189670593}, {
       3.000134841831043, 0.5625}, {3.097057141913445, 0.6377778151415994}, {
       3.0842925895560533`, 0.5625000189670593}}], 
      PolygonBox[{{3.097057141913445, 0.6377778151415994}, {
       3.1874999999999996`, 0.6752404735808354}, {3.0842925895560533`, 
       0.5625000189670593}, {3.097057141913445, 0.6377778151415994}}], 
      PolygonBox[{{3.230251642536255, 0.5626550066464766}, {
       3.0842925895560533`, 0.5625000189670593}, {3.1874999999999996`, 
       0.6752404735808354}, {3.230251642536255, 0.5626550066464766}}], 
      PolygonBox[{{3.1874999999999996`, 0.6752404735808354}, {
       3.2651650429449552`, 0.7348349570550446}, {3.230251642536255, 
       0.5626550066464766}, {3.1874999999999996`, 0.6752404735808354}}], 
      PolygonBox[{{3.404942744332997, 0.5950572556670028}, {3.230251642536255,
        0.5626550066464766}, {3.2651650429449552`, 0.7348349570550446}, {
       3.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{3.2651650429449552`, 0.7348349570550446}, {
       3.2651650429449552`, 0.7348349570550448}, {3.404942744332997, 
       0.5950572556670028}, {3.2651650429449552`, 0.7348349570550446}}], 
      PolygonBox[{{3.404942744332997, 0.5950572556670028}, {3.404942744332997,
        0.5950572556670028}, {3.2651650429449552`, 0.7348349570550448}, {
       3.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{3.404942744332997, 0.5950572556670028}, {
       3.4373449933535234`, 0.7697483574637448}, {3.5, 0.5}, {
       3.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{3.5, 0.6423372173506323}, {3.5, 0.5}, {3.4373449933535234`,
        0.7697483574637448}, {3.5, 0.6423372173506323}}], 
      PolygonBox[{{3.4373449933535234`, 0.7697483574637448}, {
       3.437499981032941, 0.9157074104439382}, {3.5, 0.6423372173506323}, {
       3.4373449933535234`, 0.7697483574637448}}], 
      PolygonBox[{{3.5, 0.79409099469826}, {3.5, 0.6423372173506323}, {
       3.437499981032941, 0.9157074104439382}, {3.5, 0.79409099469826}}], 
      PolygonBox[{{3.437499981032941, 0.9157074104439382}, {3.4375, 1.}, {3.5,
        0.79409099469826}, {3.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{3.5, 1.}, {3.5, 0.79409099469826}, {3.4375, 1.}, {3.5, 
       1.}}], PolygonBox[{{3.4375, 1.}, {3.437499981032941, 
       1.0842925895560618`}, {3.5, 1.}, {3.4375, 1.}}], 
      PolygonBox[{{3.5, 1.2059090053017398`}, {3.5, 1.}, {3.437499981032941, 
       1.0842925895560618`}, {3.5, 1.2059090053017398`}}], 
      PolygonBox[{{3.437499981032941, 1.0842925895560618`}, {
       3.4373449933535234`, 1.230251642536255}, {3.5, 1.2059090053017398`}, {
       3.437499981032941, 1.0842925895560618`}}], 
      PolygonBox[{{3.5, 1.3576627826493675`}, {3.5, 1.2059090053017398`}, {
       3.4373449933535234`, 1.230251642536255}, {3.5, 1.3576627826493675`}}], 
      PolygonBox[{{3.4373449933535234`, 1.230251642536255}, {
       3.404942744332997, 1.4049427443329972`}, {3.5, 1.3576627826493675`}, {
       3.4373449933535234`, 1.230251642536255}}], 
      PolygonBox[{{3.491446564961186, 1.491446564961186}, {3.5, 
       1.3576627826493675`}, {3.404942744332997, 1.4049427443329972`}, {
       3.491446564961186, 1.491446564961186}}], 
      PolygonBox[{{3.404942744332997, 1.4049427443329972`}, {
       3.2302516425362553`, 1.4373449933535234`}, {3.491446564961186, 
       1.491446564961186}, {3.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{3.357662782649368, 1.5}, {3.491446564961186, 
       1.491446564961186}, {3.2302516425362553`, 1.4373449933535234`}, {
       3.357662782649368, 1.5}}], 
      PolygonBox[{{3.2302516425362553`, 1.4373449933535234`}, {
       3.0842925895560604`, 1.4374999810329407`}, {3.357662782649368, 1.5}, {
       3.2302516425362553`, 1.4373449933535234`}}], 
      PolygonBox[{{3.2059090053732557`, 1.5}, {3.357662782649368, 1.5}, {
       3.0842925895560604`, 1.4374999810329407`}, {3.2059090053732557`, 
       1.5}}], PolygonBox[{{3.0842925895560604`, 1.4374999810329407`}, {
       3.0001055272204877`, 1.4375}, {3.2059090053732557`, 1.5}, {
       3.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{3.07794195802689, 1.5}, {3.2059090053732557`, 1.5}, {
       3.0001055272204877`, 1.4375}, {3.07794195802689, 1.5}}], 
      PolygonBox[{{3.0001055272204877`, 1.4375}, {2.915707410443943, 
       1.4374999810329407`}, {3.07794195802689, 1.5}, {3.0001055272204877`, 
       1.4375}}], 
      PolygonBox[{{2.7940909946955546`, 1.5}, {3.07794195802689, 1.5}, {
       2.915707410443943, 1.4374999810329407`}, {2.7940909946955546`, 1.5}}], 
      PolygonBox[{{2.915707410443943, 1.4374999810329407`}, {
       2.769748357463745, 1.4373449933535234`}, {2.7940909946955546`, 1.5}, {
       2.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{2.642337217350634, 1.5}, {2.7940909946955546`, 1.5}, {
       2.769748357463745, 1.4373449933535234`}, {2.642337217350634, 1.5}}], 
      PolygonBox[{{2.769748357463745, 1.4373449933535234`}, {
       2.595057255667003, 1.4049427443329972`}, {2.642337217350634, 1.5}, {
       2.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{3.5, 1.5}, {2.642337217350634, 1.5}, {2.595057255667003, 
       1.4049427443329972`}, {3.5, 1.5}}], 
      PolygonBox[{{2.595057255667003, 1.4049427443329972`}, {
       2.5626550066464766`, 1.2302516425362553`}, {3.5, 1.5}, {
       2.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{2.5, 1.357662782649369}, {3.5, 1.5}, {2.5626550066464766`, 
       1.2302516425362553`}, {2.5, 1.357662782649369}}], 
      PolygonBox[{{2.5626550066464766`, 1.2302516425362553`}, {
       2.562500018967059, 1.0842925895560624`}, {2.5, 1.357662782649369}, {
       2.5626550066464766`, 1.2302516425362553`}}], 
      PolygonBox[{{2.5, 1.205909005282899}, {2.5, 1.357662782649369}, {
       2.562500018967059, 1.0842925895560624`}, {2.5, 1.205909005282899}}], 
      PolygonBox[{{2.562500018967059, 1.0842925895560624`}, {2.5625, 
       1.0001231780629953`}, {2.5, 1.205909005282899}, {2.562500018967059, 
       1.0842925895560624`}}], 
      PolygonBox[{{2.5, 1.0806786667587003`}, {2.5, 1.205909005282899}, {
       2.5625, 1.0001231780629953`}, {2.5, 1.0806786667587003`}}], 
      PolygonBox[{{2.5625, 1.0001231780629953`}, {2.562500018967059, 
       0.915707410443945}, {2.5, 1.0806786667587003`}, {2.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{2.5, 0.7940909948547215}, {2.5, 1.0806786667587003`}, {
       2.562500018967059, 0.915707410443945}, {2.5, 0.7940909948547215}}], 
      PolygonBox[{{2.562500018967059, 0.915707410443945}, {
       2.5626550066464766`, 0.7697483574637453}, {2.5, 0.7940909948547215}, {
       2.562500018967059, 0.915707410443945}}], 
      PolygonBox[{{2.5, 0.6423372173506346}, {2.5, 0.7940909948547215}, {
       2.5626550066464766`, 0.7697483574637453}, {2.5, 0.6423372173506346}}], 
      PolygonBox[{{2.5626550066464766`, 0.7697483574637453}, {
       2.595057255667003, 0.5950572556670028}, {2.5, 0.6423372173506346}, {
       2.5626550066464766`, 0.7697483574637453}}], 
      PolygonBox[{{2.5, 1.5}, {2.5, 0.6423372173506346}, {2.595057255667003, 
       0.5950572556670028}, {2.5, 1.5}}], 
      PolygonBox[{{2.595057255667003, 0.5950572556670028}, {2.769748357463745,
        0.5626550066464766}, {2.5, 1.5}, {2.595057255667003, 
       0.5950572556670028}}], 
      PolygonBox[{{2.5, 0.5}, {2.5, 1.5}, {2.769748357463745, 
       0.5626550066464766}, {2.5, 0.5}}], 
      PolygonBox[{{2.769748357463745, 0.5626550066464766}, {2.915707410443936,
        0.5625000189670593}, {2.5, 0.5}, {2.769748357463745, 
       0.5626550066464766}}], 
      PolygonBox[{{2.794090994433172, 0.5}, {2.5, 0.5}, {2.915707410443936, 
       0.5625000189670593}, {2.794090994433172, 0.5}}], 
      PolygonBox[{{2.915707410443936, 0.5625000189670593}, {3.000134841831043,
        0.5625}, {2.794090994433172, 0.5}, {2.915707410443936, 
       0.5625000189670593}}], 
      PolygonBox[{{3.0823238704010616`, 0.5}, {2.794090994433172, 0.5}, {
       3.000134841831043, 0.5625}, {3.0823238704010616`, 0.5}}], 
      PolygonBox[{{3.000134841831043, 0.5625}, {3.0842925895560533`, 
       0.5625000189670593}, {3.0823238704010616`, 0.5}, {3.000134841831043, 
       0.5625}}], 
      PolygonBox[{{3.2059090053603976`, 0.5}, {3.0823238704010616`, 0.5}, {
       3.0842925895560533`, 0.5625000189670593}, {3.2059090053603976`, 0.5}}],
       PolygonBox[{{3.0842925895560533`, 0.5625000189670593}, {
       3.230251642536255, 0.5626550066464766}, {3.2059090053603976`, 0.5}, {
       3.0842925895560533`, 0.5625000189670593}}], 
      PolygonBox[{{3.357662782649371, 0.5}, {3.2059090053603976`, 0.5}, {
       3.230251642536255, 0.5626550066464766}, {3.357662782649371, 0.5}}], 
      PolygonBox[{{3.230251642536255, 0.5626550066464766}, {3.404942744332997,
        0.5950572556670028}, {3.357662782649371, 0.5}, {3.230251642536255, 
       0.5626550066464766}}], 
      PolygonBox[{{3.5, 0.5}, {3.357662782649371, 0.5}, {3.404942744332997, 
       0.5950572556670028}, {3.5, 0.5}}], 
      PolygonBox[{{3.404942744332997, 0.5950572556670028}, {3.404942744332997,
        0.5950572556670028}, {3.5, 0.5}, {3.404942744332997, 
       0.5950572556670028}}], 
      PolygonBox[{{3.5, 0.5}, {3.5, 0.5}, {3.404942744332997, 
       0.5950572556670028}, {3.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, 2.}, {2.5208333333333335`, 2.}, {2.5416666666666665`, 
       2.}, {2.5625, 2.}, {2.5833333333333335`, 2.}, {2.6041666666666665`, 
       2.}, {2.625, 2.}, {2.625, 2.}, {2.6041666666666665`, 2.}, {
       2.5833333333333335`, 2.}, {2.5625, 2.}, {2.5416666666666665`, 2.}, {
       2.5208333333333335`, 2.}, {2.5, 2.}, {2.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, 2.}, {3.3958333333333335`, 2.}, {3.4166666666666665`, 
       2.}, {3.4375, 2.}, {3.4583333333333335`, 2.}, {3.4791666666666665`, 
       2.}, {3.5, 2.}, {3.5, 2.}, {3.4791666666666665`, 2.}, {
       3.4583333333333335`, 2.}, {3.4375, 2.}, {3.4166666666666665`, 2.}, {
       3.3958333333333335`, 2.}, {3.375, 2.}, {3.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 1.5}, {3., 1.5208333333333333`}, {3., 
       1.5416666666666667`}, {3., 1.5625}, {3., 1.5833333333333333`}, {3., 
       1.6041666666666665`}, {3., 1.625}, {3., 1.625}, {3., 
       1.6041666666666667`}, {3., 1.5833333333333333`}, {3., 1.5625}, {3., 
       1.5416666666666667`}, {3., 1.5208333333333335`}, {3., 1.5}, {3., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 2.375}, {3., 2.3958333333333335`}, {3., 
       2.4166666666666665`}, {3., 2.4375}, {3., 2.4583333333333335`}, {3., 
       2.4791666666666665`}, {3., 2.5}, {3., 2.5}, {3., 
       2.4791666666666665`}, {3., 2.4583333333333335`}, {3., 2.4375}, {3., 
       2.4166666666666665`}, {3., 2.3958333333333335`}, {3., 2.375}, {3., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, 2.}, {2.75, 2.}, {2.875, 2.}, {3., 2.}, {3.125, 2.}, {
       3.25, 2.}, {3.375, 2.}, {3.375, 2.}, {3.25, 2.}, {3.125, 2.}, {3., 
       2.}, {2.875, 2.}, {2.75, 2.}, {2.625, 2.}, {2.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 1.625}, {3., 1.75}, {3., 1.875}, {3., 2.}, {3., 2.125}, {
       3., 2.25}, {3., 2.375}, {3., 2.375}, {3., 2.25}, {3., 2.125}, {3., 
       2.}, {3., 1.875}, {3., 1.75}, {3., 1.625}, {3., 1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDlCGw6uL6/Zdecrl4P9E6OnRYwwOBu4nWqVn
ckHkGxgdZr+dfZNPngtKM0HFOaHqmKD6OKDmQOUZOKA0s8NG6bdSVpbsqPIN
bHD9qUIpah8fsMLNv7DDvOpJGivcfjG9QEdtKVa4+yDmssLdD5NPNr9lWlL0
zx5FP8Nf+xSo+adUTvg8OvjbHmb/gsL8LyfO/rKHuU8nZlFTmMkve1T3/7L3
g/oPJv8fBOo54fph4QMzHxZ+YHX//9jDwjcR6j708AcARIKM9Q==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhCaxWH1KhDggvNDwYATzofQHGjq2eD8MLB6
VjT1hGmIOUxo9jKiqWNAs+evPar+X/ao6n9g8ENR3PfDHtX9MPUcaOo54fxV
KOEDU89DkL8KxX08UP/9RVMP8x8Pmv9h+pkcUNWzOAAAT/lNQA==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, 1.7348349570550448`}, {
       3.3247595264191645`, 1.8125}, {3.404942744332997, 
       1.5950572556670028`}, {3.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{3.4373449933535234`, 1.769748357463745}, {
       3.404942744332997, 1.5950572556670028`}, {3.3247595264191645`, 
       1.8125}, {3.4373449933535234`, 1.769748357463745}}], 
      PolygonBox[{{3.3247595264191645`, 1.8125}, {3.3622221848584006`, 
       1.9029428580865546`}, {3.4373449933535234`, 1.769748357463745}, {
       3.3247595264191645`, 1.8125}}], 
      PolygonBox[{{3.437499981032941, 1.9157074104439382`}, {
       3.4373449933535234`, 1.769748357463745}, {3.3622221848584006`, 
       1.9029428580865546`}, {3.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{3.3622221848584006`, 1.9029428580865546`}, {3.375, 2.}, {
       3.437499981032941, 1.9157074104439382`}, {3.3622221848584006`, 
       1.9029428580865546`}}], 
      PolygonBox[{{3.4375, 2.}, {3.437499981032941, 1.9157074104439382`}, {
       3.375, 2.}, {3.4375, 2.}}], 
      PolygonBox[{{3.375, 2.}, {3.3622221848584006`, 2.0970571419134454`}, {
       3.4375, 2.}, {3.375, 2.}}], 
      PolygonBox[{{3.437499981032941, 2.084292589556062}, {3.4375, 2.}, {
       3.3622221848584006`, 2.0970571419134454`}, {3.437499981032941, 
       2.084292589556062}}], 
      PolygonBox[{{3.3622221848584006`, 2.0970571419134454`}, {
       3.3247595264191645`, 2.1875}, {3.437499981032941, 2.084292589556062}, {
       3.3622221848584006`, 2.0970571419134454`}}], 
      PolygonBox[{{3.4373449933535234`, 2.230251642536255}, {
       3.437499981032941, 2.084292589556062}, {3.3247595264191645`, 2.1875}, {
       3.4373449933535234`, 2.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, 2.1875}, {3.2651650429449552`, 
       2.2651650429449552`}, {3.4373449933535234`, 2.230251642536255}, {
       3.3247595264191645`, 2.1875}}], 
      PolygonBox[{{3.404942744332997, 2.404942744332997}, {
       3.4373449933535234`, 2.230251642536255}, {3.2651650429449552`, 
       2.2651650429449552`}, {3.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, 2.2651650429449552`}, {3.1875, 
       2.3247595264191645`}, {3.404942744332997, 2.404942744332997}, {
       3.2651650429449552`, 2.2651650429449552`}}], 
      PolygonBox[{{3.2302516425362553`, 2.4373449933535234`}, {
       3.404942744332997, 2.404942744332997}, {3.1875, 2.3247595264191645`}, {
       3.2302516425362553`, 2.4373449933535234`}}], 
      PolygonBox[{{3.1875, 2.3247595264191645`}, {3.0970571419134454`, 
       2.3622221848584006`}, {3.2302516425362553`, 2.4373449933535234`}, {
       3.1875, 2.3247595264191645`}}], 
      PolygonBox[{{3.0842925895560604`, 2.437499981032941}, {
       3.2302516425362553`, 2.4373449933535234`}, {3.0970571419134454`, 
       2.3622221848584006`}, {3.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{3.0970571419134454`, 2.3622221848584006`}, {3., 2.375}, {
       3.0842925895560604`, 2.437499981032941}, {3.0970571419134454`, 
       2.3622221848584006`}}], 
      PolygonBox[{{3.0001055272204877`, 2.4375}, {3.0842925895560604`, 
       2.437499981032941}, {3., 2.375}, {3.0001055272204877`, 2.4375}}], 
      PolygonBox[{{3., 2.375}, {2.902942858086555, 2.3622221848584006`}, {
       3.0001055272204877`, 2.4375}, {3., 2.375}}], 
      PolygonBox[{{2.915707410443943, 2.437499981032941}, {
       3.0001055272204877`, 2.4375}, {2.902942858086555, 
       2.3622221848584006`}, {2.915707410443943, 2.437499981032941}}], 
      PolygonBox[{{2.902942858086555, 2.3622221848584006`}, {2.8125, 
       2.3247595264191645`}, {2.915707410443943, 2.437499981032941}, {
       2.902942858086555, 2.3622221848584006`}}], 
      PolygonBox[{{2.769748357463745, 2.4373449933535234`}, {
       2.915707410443943, 2.437499981032941}, {2.8125, 2.3247595264191645`}, {
       2.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{2.8125, 2.3247595264191645`}, {2.7348349570550448`, 
       2.2651650429449552`}, {2.769748357463745, 2.4373449933535234`}, {
       2.8125, 2.3247595264191645`}}], 
      PolygonBox[{{2.595057255667003, 2.404942744332997}, {2.769748357463745, 
       2.4373449933535234`}, {2.7348349570550448`, 2.2651650429449552`}, {
       2.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, 2.2651650429449552`}, {
       2.6752404735808355`, 2.1875}, {2.595057255667003, 2.404942744332997}, {
       2.7348349570550448`, 2.2651650429449552`}}], 
      PolygonBox[{{2.5626550066464766`, 2.2302516425362553`}, {
       2.595057255667003, 2.404942744332997}, {2.6752404735808355`, 2.1875}, {
       2.5626550066464766`, 2.2302516425362553`}}], 
      PolygonBox[{{2.6752404735808355`, 2.1875}, {2.6377778151415994`, 
       2.0970571419134454`}, {2.5626550066464766`, 2.2302516425362553`}, {
       2.6752404735808355`, 2.1875}}], 
      PolygonBox[{{2.562500018967059, 2.0842925895560622`}, {
       2.5626550066464766`, 2.2302516425362553`}, {2.6377778151415994`, 
       2.0970571419134454`}, {2.562500018967059, 2.0842925895560622`}}], 
      PolygonBox[{{2.6377778151415994`, 2.0970571419134454`}, {2.625, 2.}, {
       2.562500018967059, 2.0842925895560622`}, {2.6377778151415994`, 
       2.0970571419134454`}}], 
      PolygonBox[{{2.5625, 2.0001231780629953`}, {2.562500018967059, 
       2.0842925895560622`}, {2.625, 2.}, {2.5625, 2.0001231780629953`}}], 
      PolygonBox[{{2.625, 2.}, {2.6377778151415994`, 1.9029428580865548`}, {
       2.5625, 2.0001231780629953`}, {2.625, 2.}}], 
      PolygonBox[{{2.562500018967059, 1.915707410443945}, {2.5625, 
       2.0001231780629953`}, {2.6377778151415994`, 1.9029428580865548`}, {
       2.562500018967059, 1.915707410443945}}], 
      PolygonBox[{{2.6377778151415994`, 1.9029428580865548`}, {
       2.6752404735808355`, 1.8125000000000002`}, {2.562500018967059, 
       1.915707410443945}, {2.6377778151415994`, 1.9029428580865548`}}], 
      PolygonBox[{{2.5626550066464766`, 1.7697483574637451`}, {
       2.562500018967059, 1.915707410443945}, {2.6752404735808355`, 
       1.8125000000000002`}, {2.5626550066464766`, 1.7697483574637451`}}], 
      PolygonBox[{{2.6752404735808355`, 1.8125000000000002`}, {
       2.7348349570550448`, 1.7348349570550448`}, {2.5626550066464766`, 
       1.7697483574637451`}, {2.6752404735808355`, 1.8125000000000002`}}], 
      PolygonBox[{{2.595057255667003, 1.5950572556670028`}, {
       2.5626550066464766`, 1.7697483574637451`}, {2.7348349570550448`, 
       1.7348349570550448`}, {2.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{2.7348349570550448`, 1.7348349570550448`}, {2.8125, 
       1.6752404735808355`}, {2.595057255667003, 1.5950572556670028`}, {
       2.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{2.769748357463745, 1.5626550066464766`}, {
       2.595057255667003, 1.5950572556670028`}, {2.8125, 
       1.6752404735808355`}, {2.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{2.8125, 1.6752404735808355`}, {2.9029428580865546`, 
       1.6377778151415994`}, {2.769748357463745, 1.5626550066464766`}, {
       2.8125, 1.6752404735808355`}}], 
      PolygonBox[{{2.915707410443936, 1.5625000189670593`}, {
       2.769748357463745, 1.5626550066464766`}, {2.9029428580865546`, 
       1.6377778151415994`}, {2.915707410443936, 1.5625000189670593`}}], 
      PolygonBox[{{2.9029428580865546`, 1.6377778151415994`}, {3., 1.625}, {
       2.915707410443936, 1.5625000189670593`}, {2.9029428580865546`, 
       1.6377778151415994`}}], 
      PolygonBox[{{3.000134841831043, 1.5625}, {2.915707410443936, 
       1.5625000189670593`}, {3., 1.625}, {3.000134841831043, 1.5625}}], 
      PolygonBox[{{3., 1.625}, {3.097057141913445, 1.6377778151415994`}, {
       3.000134841831043, 1.5625}, {3., 1.625}}], 
      PolygonBox[{{3.0842925895560533`, 1.5625000189670593`}, {
       3.000134841831043, 1.5625}, {3.097057141913445, 1.6377778151415994`}, {
       3.0842925895560533`, 1.5625000189670593`}}], 
      PolygonBox[{{3.097057141913445, 1.6377778151415994`}, {
       3.1874999999999996`, 1.6752404735808355`}, {3.0842925895560533`, 
       1.5625000189670593`}, {3.097057141913445, 1.6377778151415994`}}], 
      PolygonBox[{{3.230251642536255, 1.5626550066464766`}, {
       3.0842925895560533`, 1.5625000189670593`}, {3.1874999999999996`, 
       1.6752404735808355`}, {3.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{3.1874999999999996`, 1.6752404735808355`}, {
       3.2651650429449552`, 1.7348349570550448`}, {3.230251642536255, 
       1.5626550066464766`}, {3.1874999999999996`, 1.6752404735808355`}}], 
      PolygonBox[{{3.404942744332997, 1.5950572556670028`}, {
       3.230251642536255, 1.5626550066464766`}, {3.2651650429449552`, 
       1.7348349570550448`}, {3.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{3.2651650429449552`, 1.7348349570550448`}, {
       3.2651650429449552`, 1.7348349570550448`}, {3.404942744332997, 
       1.5950572556670028`}, {3.2651650429449552`, 1.7348349570550448`}}], 
      PolygonBox[{{3.404942744332997, 1.5950572556670028`}, {
       3.404942744332997, 1.5950572556670028`}, {3.2651650429449552`, 
       1.7348349570550448`}, {3.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{3.404942744332997, 1.5950572556670028`}, {
       3.4373449933535234`, 1.769748357463745}, {3.5, 1.5}, {
       3.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{3.5, 1.6423372173506323`}, {3.5, 1.5}, {
       3.4373449933535234`, 1.769748357463745}, {3.5, 1.6423372173506323`}}], 
      PolygonBox[{{3.4373449933535234`, 1.769748357463745}, {
       3.437499981032941, 1.9157074104439382`}, {3.5, 1.6423372173506323`}, {
       3.4373449933535234`, 1.769748357463745}}], 
      PolygonBox[{{3.5, 1.79409099469826}, {3.5, 1.6423372173506323`}, {
       3.437499981032941, 1.9157074104439382`}, {3.5, 1.79409099469826}}], 
      PolygonBox[{{3.437499981032941, 1.9157074104439382`}, {3.4375, 2.}, {
       3.5, 1.79409099469826}, {3.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{3.5, 2.}, {3.5, 1.79409099469826}, {3.4375, 2.}, {3.5, 
       2.}}], PolygonBox[{{3.4375, 2.}, {3.437499981032941, 
       2.084292589556062}, {3.5, 2.}, {3.4375, 2.}}], 
      PolygonBox[{{3.5, 2.20590900530174}, {3.5, 2.}, {3.437499981032941, 
       2.084292589556062}, {3.5, 2.20590900530174}}], 
      PolygonBox[{{3.437499981032941, 2.084292589556062}, {
       3.4373449933535234`, 2.230251642536255}, {3.5, 2.20590900530174}, {
       3.437499981032941, 2.084292589556062}}], 
      PolygonBox[{{3.5, 2.3576627826493675`}, {3.5, 2.20590900530174}, {
       3.4373449933535234`, 2.230251642536255}, {3.5, 2.3576627826493675`}}], 
      PolygonBox[{{3.4373449933535234`, 2.230251642536255}, {
       3.404942744332997, 2.404942744332997}, {3.5, 2.3576627826493675`}, {
       3.4373449933535234`, 2.230251642536255}}], 
      PolygonBox[{{3.491446564961186, 2.491446564961186}, {3.5, 
       2.3576627826493675`}, {3.404942744332997, 2.404942744332997}, {
       3.491446564961186, 2.491446564961186}}], 
      PolygonBox[{{3.404942744332997, 2.404942744332997}, {
       3.2302516425362553`, 2.4373449933535234`}, {3.491446564961186, 
       2.491446564961186}, {3.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{3.357662782649368, 2.5}, {3.491446564961186, 
       2.491446564961186}, {3.2302516425362553`, 2.4373449933535234`}, {
       3.357662782649368, 2.5}}], 
      PolygonBox[{{3.2302516425362553`, 2.4373449933535234`}, {
       3.0842925895560604`, 2.437499981032941}, {3.357662782649368, 2.5}, {
       3.2302516425362553`, 2.4373449933535234`}}], 
      PolygonBox[{{3.2059090053732557`, 2.5}, {3.357662782649368, 2.5}, {
       3.0842925895560604`, 2.437499981032941}, {3.2059090053732557`, 2.5}}], 
      PolygonBox[{{3.0842925895560604`, 2.437499981032941}, {
       3.0001055272204877`, 2.4375}, {3.2059090053732557`, 2.5}, {
       3.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{3.07794195802689, 2.5}, {3.2059090053732557`, 2.5}, {
       3.0001055272204877`, 2.4375}, {3.07794195802689, 2.5}}], 
      PolygonBox[{{3.0001055272204877`, 2.4375}, {2.915707410443943, 
       2.437499981032941}, {3.07794195802689, 2.5}, {3.0001055272204877`, 
       2.4375}}], 
      PolygonBox[{{2.7940909946955546`, 2.5}, {3.07794195802689, 2.5}, {
       2.915707410443943, 2.437499981032941}, {2.7940909946955546`, 2.5}}], 
      PolygonBox[{{2.915707410443943, 2.437499981032941}, {2.769748357463745, 
       2.4373449933535234`}, {2.7940909946955546`, 2.5}, {2.915707410443943, 
       2.437499981032941}}], 
      PolygonBox[{{2.642337217350634, 2.5}, {2.7940909946955546`, 2.5}, {
       2.769748357463745, 2.4373449933535234`}, {2.642337217350634, 2.5}}], 
      PolygonBox[{{2.769748357463745, 2.4373449933535234`}, {
       2.595057255667003, 2.404942744332997}, {2.642337217350634, 2.5}, {
       2.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{3.5, 2.5}, {2.642337217350634, 2.5}, {2.595057255667003, 
       2.404942744332997}, {3.5, 2.5}}], 
      PolygonBox[{{2.595057255667003, 2.404942744332997}, {
       2.5626550066464766`, 2.2302516425362553`}, {3.5, 2.5}, {
       2.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{2.5, 2.357662782649369}, {3.5, 2.5}, {2.5626550066464766`, 
       2.2302516425362553`}, {2.5, 2.357662782649369}}], 
      PolygonBox[{{2.5626550066464766`, 2.2302516425362553`}, {
       2.562500018967059, 2.0842925895560622`}, {2.5, 2.357662782649369}, {
       2.5626550066464766`, 2.2302516425362553`}}], 
      PolygonBox[{{2.5, 2.205909005282899}, {2.5, 2.357662782649369}, {
       2.562500018967059, 2.0842925895560622`}, {2.5, 2.205909005282899}}], 
      PolygonBox[{{2.562500018967059, 2.0842925895560622`}, {2.5625, 
       2.0001231780629953`}, {2.5, 2.205909005282899}, {2.562500018967059, 
       2.0842925895560622`}}], 
      PolygonBox[{{2.5, 2.0806786667587}, {2.5, 2.205909005282899}, {2.5625, 
       2.0001231780629953`}, {2.5, 2.0806786667587}}], 
      PolygonBox[{{2.5625, 2.0001231780629953`}, {2.562500018967059, 
       1.915707410443945}, {2.5, 2.0806786667587}, {2.5625, 
       2.0001231780629953`}}], 
      PolygonBox[{{2.5, 1.7940909948547215`}, {2.5, 2.0806786667587}, {
       2.562500018967059, 1.915707410443945}, {2.5, 1.7940909948547215`}}], 
      PolygonBox[{{2.562500018967059, 1.915707410443945}, {
       2.5626550066464766`, 1.7697483574637451`}, {2.5, 
       1.7940909948547215`}, {2.562500018967059, 1.915707410443945}}], 
      PolygonBox[{{2.5, 1.6423372173506348`}, {2.5, 1.7940909948547215`}, {
       2.5626550066464766`, 1.7697483574637451`}, {2.5, 
       1.6423372173506348`}}], 
      PolygonBox[{{2.5626550066464766`, 1.7697483574637451`}, {
       2.595057255667003, 1.5950572556670028`}, {2.5, 1.6423372173506348`}, {
       2.5626550066464766`, 1.7697483574637451`}}], 
      PolygonBox[{{2.5, 2.5}, {2.5, 1.6423372173506348`}, {2.595057255667003, 
       1.5950572556670028`}, {2.5, 2.5}}], 
      PolygonBox[{{2.595057255667003, 1.5950572556670028`}, {
       2.769748357463745, 1.5626550066464766`}, {2.5, 2.5}, {
       2.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{2.5, 1.5}, {2.5, 2.5}, {2.769748357463745, 
       1.5626550066464766`}, {2.5, 1.5}}], 
      PolygonBox[{{2.769748357463745, 1.5626550066464766`}, {
       2.915707410443936, 1.5625000189670593`}, {2.5, 1.5}, {
       2.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{2.794090994433172, 1.5}, {2.5, 1.5}, {2.915707410443936, 
       1.5625000189670593`}, {2.794090994433172, 1.5}}], 
      PolygonBox[{{2.915707410443936, 1.5625000189670593`}, {
       3.000134841831043, 1.5625}, {2.794090994433172, 1.5}, {
       2.915707410443936, 1.5625000189670593`}}], 
      PolygonBox[{{3.0823238704010616`, 1.5}, {2.794090994433172, 1.5}, {
       3.000134841831043, 1.5625}, {3.0823238704010616`, 1.5}}], 
      PolygonBox[{{3.000134841831043, 1.5625}, {3.0842925895560533`, 
       1.5625000189670593`}, {3.0823238704010616`, 1.5}, {3.000134841831043, 
       1.5625}}], 
      PolygonBox[{{3.2059090053603976`, 1.5}, {3.0823238704010616`, 1.5}, {
       3.0842925895560533`, 1.5625000189670593`}, {3.2059090053603976`, 
       1.5}}], PolygonBox[{{3.0842925895560533`, 1.5625000189670593`}, {
       3.230251642536255, 1.5626550066464766`}, {3.2059090053603976`, 1.5}, {
       3.0842925895560533`, 1.5625000189670593`}}], 
      PolygonBox[{{3.357662782649371, 1.5}, {3.2059090053603976`, 1.5}, {
       3.230251642536255, 1.5626550066464766`}, {3.357662782649371, 1.5}}], 
      PolygonBox[{{3.230251642536255, 1.5626550066464766`}, {
       3.404942744332997, 1.5950572556670028`}, {3.357662782649371, 1.5}, {
       3.230251642536255, 1.5626550066464766`}}], 
      PolygonBox[{{3.5, 1.5}, {3.357662782649371, 1.5}, {3.404942744332997, 
       1.5950572556670028`}, {3.5, 1.5}}], 
      PolygonBox[{{3.404942744332997, 1.5950572556670028`}, {
       3.404942744332997, 1.5950572556670028`}, {3.5, 1.5}, {
       3.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{3.5, 1.5}, {3.5, 1.5}, {3.404942744332997, 
       1.5950572556670028`}, {3.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, 3.}, {2.5208333333333335`, 3.}, {2.5416666666666665`, 
       3.}, {2.5625, 3.}, {2.5833333333333335`, 3.}, {2.6041666666666665`, 
       3.}, {2.625, 3.}, {2.625, 3.}, {2.6041666666666665`, 3.}, {
       2.5833333333333335`, 3.}, {2.5625, 3.}, {2.5416666666666665`, 3.}, {
       2.5208333333333335`, 3.}, {2.5, 3.}, {2.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, 3.}, {3.3958333333333335`, 3.}, {3.4166666666666665`, 
       3.}, {3.4375, 3.}, {3.4583333333333335`, 3.}, {3.4791666666666665`, 
       3.}, {3.5, 3.}, {3.5, 3.}, {3.4791666666666665`, 3.}, {
       3.4583333333333335`, 3.}, {3.4375, 3.}, {3.4166666666666665`, 3.}, {
       3.3958333333333335`, 3.}, {3.375, 3.}, {3.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 2.5}, {3., 2.5208333333333335`}, {3., 
       2.5416666666666665`}, {3., 2.5625}, {3., 2.5833333333333335`}, {3., 
       2.6041666666666665`}, {3., 2.625}, {3., 2.625}, {3., 
       2.6041666666666665`}, {3., 2.5833333333333335`}, {3., 2.5625}, {3., 
       2.5416666666666665`}, {3., 2.5208333333333335`}, {3., 2.5}, {3., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 3.375}, {3., 3.3958333333333335`}, {3., 
       3.4166666666666665`}, {3., 3.4375}, {3., 3.4583333333333335`}, {3., 
       3.4791666666666665`}, {3., 3.5}, {3., 3.5}, {3., 
       3.4791666666666665`}, {3., 3.4583333333333335`}, {3., 3.4375}, {3., 
       3.4166666666666665`}, {3., 3.3958333333333335`}, {3., 3.375}, {3., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, 3.}, {2.75, 3.}, {2.875, 3.}, {3., 3.}, {3.125, 3.}, {
       3.25, 3.}, {3.375, 3.}, {3.375, 3.}, {3.25, 3.}, {3.125, 3.}, {3., 
       3.}, {2.875, 3.}, {2.75, 3.}, {2.625, 3.}, {2.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 2.625}, {3., 2.75}, {3., 2.875}, {3., 3.}, {3., 3.125}, {
       3., 3.25}, {3., 3.375}, {3., 3.375}, {3., 3.25}, {3., 3.125}, {3., 
       3.}, {3., 2.875}, {3., 2.75}, {3., 2.625}, {3., 2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhCaw+HVxXX7rjzlcvB/IvT06DEOBwP3E63S
M7kg8g2cDrPfzr7JJ88Fp2HiMHUwfTBzYObC7Nko/VbKypIdVb6BDa4/VShF
7eMDVrj5F3aYVz1JY4XbI6YX6KgtxQq3B2IuK9wemPwmqD2o+tkcUqDmw+yB
icPUwdwHMwfV/awOflB7YfL/QaCeE64f5m6Y+ajhxwb3N8we9PAHAA5keG8=

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DjB69SoQ4ILzQ8GA0wFVHQeaejY4PwysnhVN
PQtBPqq9LGj2wtRzoKlng/NR7WXBSYeiqUM3B90edHesQnMnsf4MRQsX9HBD
tRcz3FehxQuMBgD4jkFa
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, 2.7348349570550448`}, {
       3.3247595264191645`, 2.8125}, {3.404942744332997, 2.595057255667003}, {
       3.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{3.4373449933535234`, 2.7697483574637447`}, {
       3.404942744332997, 2.595057255667003}, {3.3247595264191645`, 2.8125}, {
       3.4373449933535234`, 2.7697483574637447`}}], 
      PolygonBox[{{3.3247595264191645`, 2.8125}, {3.3622221848584006`, 
       2.9029428580865546`}, {3.4373449933535234`, 2.7697483574637447`}, {
       3.3247595264191645`, 2.8125}}], 
      PolygonBox[{{3.437499981032941, 2.915707410443938}, {
       3.4373449933535234`, 2.7697483574637447`}, {3.3622221848584006`, 
       2.9029428580865546`}, {3.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{3.3622221848584006`, 2.9029428580865546`}, {3.375, 3.}, {
       3.437499981032941, 2.915707410443938}, {3.3622221848584006`, 
       2.9029428580865546`}}], 
      PolygonBox[{{3.4375, 3.}, {3.437499981032941, 2.915707410443938}, {
       3.375, 3.}, {3.4375, 3.}}], 
      PolygonBox[{{3.375, 3.}, {3.3622221848584006`, 3.0970571419134454`}, {
       3.4375, 3.}, {3.375, 3.}}], 
      PolygonBox[{{3.437499981032941, 3.084292589556062}, {3.4375, 3.}, {
       3.3622221848584006`, 3.0970571419134454`}, {3.437499981032941, 
       3.084292589556062}}], 
      PolygonBox[{{3.3622221848584006`, 3.0970571419134454`}, {
       3.3247595264191645`, 3.1875}, {3.437499981032941, 3.084292589556062}, {
       3.3622221848584006`, 3.0970571419134454`}}], 
      PolygonBox[{{3.4373449933535234`, 3.230251642536255}, {
       3.437499981032941, 3.084292589556062}, {3.3247595264191645`, 3.1875}, {
       3.4373449933535234`, 3.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, 3.1875}, {3.2651650429449552`, 
       3.2651650429449552`}, {3.4373449933535234`, 3.230251642536255}, {
       3.3247595264191645`, 3.1875}}], 
      PolygonBox[{{3.404942744332997, 3.404942744332997}, {
       3.4373449933535234`, 3.230251642536255}, {3.2651650429449552`, 
       3.2651650429449552`}, {3.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, 3.2651650429449552`}, {3.1875, 
       3.3247595264191645`}, {3.404942744332997, 3.404942744332997}, {
       3.2651650429449552`, 3.2651650429449552`}}], 
      PolygonBox[{{3.2302516425362553`, 3.4373449933535234`}, {
       3.404942744332997, 3.404942744332997}, {3.1875, 3.3247595264191645`}, {
       3.2302516425362553`, 3.4373449933535234`}}], 
      PolygonBox[{{3.1875, 3.3247595264191645`}, {3.0970571419134454`, 
       3.3622221848584006`}, {3.2302516425362553`, 3.4373449933535234`}, {
       3.1875, 3.3247595264191645`}}], 
      PolygonBox[{{3.0842925895560604`, 3.437499981032941}, {
       3.2302516425362553`, 3.4373449933535234`}, {3.0970571419134454`, 
       3.3622221848584006`}, {3.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{3.0970571419134454`, 3.3622221848584006`}, {3., 3.375}, {
       3.0842925895560604`, 3.437499981032941}, {3.0970571419134454`, 
       3.3622221848584006`}}], 
      PolygonBox[{{3.0001055272204877`, 3.4375}, {3.0842925895560604`, 
       3.437499981032941}, {3., 3.375}, {3.0001055272204877`, 3.4375}}], 
      PolygonBox[{{3., 3.375}, {2.902942858086555, 3.3622221848584006`}, {
       3.0001055272204877`, 3.4375}, {3., 3.375}}], 
      PolygonBox[{{2.915707410443943, 3.437499981032941}, {
       3.0001055272204877`, 3.4375}, {2.902942858086555, 
       3.3622221848584006`}, {2.915707410443943, 3.437499981032941}}], 
      PolygonBox[{{2.902942858086555, 3.3622221848584006`}, {2.8125, 
       3.3247595264191645`}, {2.915707410443943, 3.437499981032941}, {
       2.902942858086555, 3.3622221848584006`}}], 
      PolygonBox[{{2.769748357463745, 3.4373449933535234`}, {
       2.915707410443943, 3.437499981032941}, {2.8125, 3.3247595264191645`}, {
       2.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{2.8125, 3.3247595264191645`}, {2.7348349570550448`, 
       3.2651650429449552`}, {2.769748357463745, 3.4373449933535234`}, {
       2.8125, 3.3247595264191645`}}], 
      PolygonBox[{{2.595057255667003, 3.404942744332997}, {2.769748357463745, 
       3.4373449933535234`}, {2.7348349570550448`, 3.2651650429449552`}, {
       2.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, 3.2651650429449552`}, {
       2.6752404735808355`, 3.1875}, {2.595057255667003, 3.404942744332997}, {
       2.7348349570550448`, 3.2651650429449552`}}], 
      PolygonBox[{{2.5626550066464766`, 3.2302516425362553`}, {
       2.595057255667003, 3.404942744332997}, {2.6752404735808355`, 3.1875}, {
       2.5626550066464766`, 3.2302516425362553`}}], 
      PolygonBox[{{2.6752404735808355`, 3.1875}, {2.6377778151415994`, 
       3.0970571419134454`}, {2.5626550066464766`, 3.2302516425362553`}, {
       2.6752404735808355`, 3.1875}}], 
      PolygonBox[{{2.562500018967059, 3.0842925895560622`}, {
       2.5626550066464766`, 3.2302516425362553`}, {2.6377778151415994`, 
       3.0970571419134454`}, {2.562500018967059, 3.0842925895560622`}}], 
      PolygonBox[{{2.6377778151415994`, 3.0970571419134454`}, {2.625, 3.}, {
       2.562500018967059, 3.0842925895560622`}, {2.6377778151415994`, 
       3.0970571419134454`}}], 
      PolygonBox[{{2.5625, 3.0001231780629953`}, {2.562500018967059, 
       3.0842925895560622`}, {2.625, 3.}, {2.5625, 3.0001231780629953`}}], 
      PolygonBox[{{2.625, 3.}, {2.6377778151415994`, 2.902942858086555}, {
       2.5625, 3.0001231780629953`}, {2.625, 3.}}], 
      PolygonBox[{{2.562500018967059, 2.915707410443945}, {2.5625, 
       3.0001231780629953`}, {2.6377778151415994`, 2.902942858086555}, {
       2.562500018967059, 2.915707410443945}}], 
      PolygonBox[{{2.6377778151415994`, 2.902942858086555}, {
       2.6752404735808355`, 2.8125}, {2.562500018967059, 2.915707410443945}, {
       2.6377778151415994`, 2.902942858086555}}], 
      PolygonBox[{{2.5626550066464766`, 2.769748357463745}, {
       2.562500018967059, 2.915707410443945}, {2.6752404735808355`, 2.8125}, {
       2.5626550066464766`, 2.769748357463745}}], 
      PolygonBox[{{2.6752404735808355`, 2.8125}, {2.7348349570550448`, 
       2.7348349570550448`}, {2.5626550066464766`, 2.769748357463745}, {
       2.6752404735808355`, 2.8125}}], 
      PolygonBox[{{2.595057255667003, 2.595057255667003}, {
       2.5626550066464766`, 2.769748357463745}, {2.7348349570550448`, 
       2.7348349570550448`}, {2.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{2.7348349570550448`, 2.7348349570550448`}, {2.8125, 
       2.6752404735808355`}, {2.595057255667003, 2.595057255667003}, {
       2.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{2.769748357463745, 2.5626550066464766`}, {
       2.595057255667003, 2.595057255667003}, {2.8125, 2.6752404735808355`}, {
       2.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{2.8125, 2.6752404735808355`}, {2.9029428580865546`, 
       2.6377778151415994`}, {2.769748357463745, 2.5626550066464766`}, {
       2.8125, 2.6752404735808355`}}], 
      PolygonBox[{{2.915707410443936, 2.562500018967059}, {2.769748357463745, 
       2.5626550066464766`}, {2.9029428580865546`, 2.6377778151415994`}, {
       2.915707410443936, 2.562500018967059}}], 
      PolygonBox[{{2.9029428580865546`, 2.6377778151415994`}, {3., 2.625}, {
       2.915707410443936, 2.562500018967059}, {2.9029428580865546`, 
       2.6377778151415994`}}], 
      PolygonBox[{{3.000134841831043, 2.5625}, {2.915707410443936, 
       2.562500018967059}, {3., 2.625}, {3.000134841831043, 2.5625}}], 
      PolygonBox[{{3., 2.625}, {3.097057141913445, 2.6377778151415994`}, {
       3.000134841831043, 2.5625}, {3., 2.625}}], 
      PolygonBox[{{3.0842925895560533`, 2.562500018967059}, {
       3.000134841831043, 2.5625}, {3.097057141913445, 2.6377778151415994`}, {
       3.0842925895560533`, 2.562500018967059}}], 
      PolygonBox[{{3.097057141913445, 2.6377778151415994`}, {
       3.1874999999999996`, 2.6752404735808355`}, {3.0842925895560533`, 
       2.562500018967059}, {3.097057141913445, 2.6377778151415994`}}], 
      PolygonBox[{{3.230251642536255, 2.5626550066464766`}, {
       3.0842925895560533`, 2.562500018967059}, {3.1874999999999996`, 
       2.6752404735808355`}, {3.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{3.1874999999999996`, 2.6752404735808355`}, {
       3.2651650429449552`, 2.7348349570550448`}, {3.230251642536255, 
       2.5626550066464766`}, {3.1874999999999996`, 2.6752404735808355`}}], 
      PolygonBox[{{3.404942744332997, 2.595057255667003}, {3.230251642536255, 
       2.5626550066464766`}, {3.2651650429449552`, 2.7348349570550448`}, {
       3.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{3.2651650429449552`, 2.7348349570550448`}, {
       3.2651650429449552`, 2.7348349570550448`}, {3.404942744332997, 
       2.595057255667003}, {3.2651650429449552`, 2.7348349570550448`}}], 
      PolygonBox[{{3.404942744332997, 2.595057255667003}, {3.404942744332997, 
       2.595057255667003}, {3.2651650429449552`, 2.7348349570550448`}, {
       3.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{3.404942744332997, 2.595057255667003}, {
       3.4373449933535234`, 2.7697483574637447`}, {3.5, 2.5}, {
       3.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{3.5, 2.642337217350632}, {3.5, 2.5}, {3.4373449933535234`, 
       2.7697483574637447`}, {3.5, 2.642337217350632}}], 
      PolygonBox[{{3.4373449933535234`, 2.7697483574637447`}, {
       3.437499981032941, 2.915707410443938}, {3.5, 2.642337217350632}, {
       3.4373449933535234`, 2.7697483574637447`}}], 
      PolygonBox[{{3.5, 2.79409099469826}, {3.5, 2.642337217350632}, {
       3.437499981032941, 2.915707410443938}, {3.5, 2.79409099469826}}], 
      PolygonBox[{{3.437499981032941, 2.915707410443938}, {3.4375, 3.}, {3.5, 
       2.79409099469826}, {3.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{3.5, 3.}, {3.5, 2.79409099469826}, {3.4375, 3.}, {3.5, 
       3.}}], PolygonBox[{{3.4375, 3.}, {3.437499981032941, 
       3.084292589556062}, {3.5, 3.}, {3.4375, 3.}}], 
      PolygonBox[{{3.5, 3.20590900530174}, {3.5, 3.}, {3.437499981032941, 
       3.084292589556062}, {3.5, 3.20590900530174}}], 
      PolygonBox[{{3.437499981032941, 3.084292589556062}, {
       3.4373449933535234`, 3.230251642536255}, {3.5, 3.20590900530174}, {
       3.437499981032941, 3.084292589556062}}], 
      PolygonBox[{{3.5, 3.3576627826493675`}, {3.5, 3.20590900530174}, {
       3.4373449933535234`, 3.230251642536255}, {3.5, 3.3576627826493675`}}], 
      PolygonBox[{{3.4373449933535234`, 3.230251642536255}, {
       3.404942744332997, 3.404942744332997}, {3.5, 3.3576627826493675`}, {
       3.4373449933535234`, 3.230251642536255}}], 
      PolygonBox[{{3.491446564961186, 3.491446564961186}, {3.5, 
       3.3576627826493675`}, {3.404942744332997, 3.404942744332997}, {
       3.491446564961186, 3.491446564961186}}], 
      PolygonBox[{{3.404942744332997, 3.404942744332997}, {
       3.2302516425362553`, 3.4373449933535234`}, {3.491446564961186, 
       3.491446564961186}, {3.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{3.357662782649368, 3.5}, {3.491446564961186, 
       3.491446564961186}, {3.2302516425362553`, 3.4373449933535234`}, {
       3.357662782649368, 3.5}}], 
      PolygonBox[{{3.2302516425362553`, 3.4373449933535234`}, {
       3.0842925895560604`, 3.437499981032941}, {3.357662782649368, 3.5}, {
       3.2302516425362553`, 3.4373449933535234`}}], 
      PolygonBox[{{3.2059090053732557`, 3.5}, {3.357662782649368, 3.5}, {
       3.0842925895560604`, 3.437499981032941}, {3.2059090053732557`, 3.5}}], 
      PolygonBox[{{3.0842925895560604`, 3.437499981032941}, {
       3.0001055272204877`, 3.4375}, {3.2059090053732557`, 3.5}, {
       3.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{3.07794195802689, 3.5}, {3.2059090053732557`, 3.5}, {
       3.0001055272204877`, 3.4375}, {3.07794195802689, 3.5}}], 
      PolygonBox[{{3.0001055272204877`, 3.4375}, {2.915707410443943, 
       3.437499981032941}, {3.07794195802689, 3.5}, {3.0001055272204877`, 
       3.4375}}], 
      PolygonBox[{{2.7940909946955546`, 3.5}, {3.07794195802689, 3.5}, {
       2.915707410443943, 3.437499981032941}, {2.7940909946955546`, 3.5}}], 
      PolygonBox[{{2.915707410443943, 3.437499981032941}, {2.769748357463745, 
       3.4373449933535234`}, {2.7940909946955546`, 3.5}, {2.915707410443943, 
       3.437499981032941}}], 
      PolygonBox[{{2.642337217350634, 3.5}, {2.7940909946955546`, 3.5}, {
       2.769748357463745, 3.4373449933535234`}, {2.642337217350634, 3.5}}], 
      PolygonBox[{{2.769748357463745, 3.4373449933535234`}, {
       2.595057255667003, 3.404942744332997}, {2.642337217350634, 3.5}, {
       2.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{3.5, 3.5}, {2.642337217350634, 3.5}, {2.595057255667003, 
       3.404942744332997}, {3.5, 3.5}}], 
      PolygonBox[{{2.595057255667003, 3.404942744332997}, {
       2.5626550066464766`, 3.2302516425362553`}, {3.5, 3.5}, {
       2.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{2.5, 3.357662782649369}, {3.5, 3.5}, {2.5626550066464766`, 
       3.2302516425362553`}, {2.5, 3.357662782649369}}], 
      PolygonBox[{{2.5626550066464766`, 3.2302516425362553`}, {
       2.562500018967059, 3.0842925895560622`}, {2.5, 3.357662782649369}, {
       2.5626550066464766`, 3.2302516425362553`}}], 
      PolygonBox[{{2.5, 3.205909005282899}, {2.5, 3.357662782649369}, {
       2.562500018967059, 3.0842925895560622`}, {2.5, 3.205909005282899}}], 
      PolygonBox[{{2.562500018967059, 3.0842925895560622`}, {2.5625, 
       3.0001231780629953`}, {2.5, 3.205909005282899}, {2.562500018967059, 
       3.0842925895560622`}}], 
      PolygonBox[{{2.5, 3.0806786667587}, {2.5, 3.205909005282899}, {2.5625, 
       3.0001231780629953`}, {2.5, 3.0806786667587}}], 
      PolygonBox[{{2.5625, 3.0001231780629953`}, {2.562500018967059, 
       2.915707410443945}, {2.5, 3.0806786667587}, {2.5625, 
       3.0001231780629953`}}], 
      PolygonBox[{{2.5, 2.7940909948547215`}, {2.5, 3.0806786667587}, {
       2.562500018967059, 2.915707410443945}, {2.5, 2.7940909948547215`}}], 
      PolygonBox[{{2.562500018967059, 2.915707410443945}, {
       2.5626550066464766`, 2.769748357463745}, {2.5, 2.7940909948547215`}, {
       2.562500018967059, 2.915707410443945}}], 
      PolygonBox[{{2.5, 2.6423372173506348`}, {2.5, 2.7940909948547215`}, {
       2.5626550066464766`, 2.769748357463745}, {2.5, 2.6423372173506348`}}], 
      PolygonBox[{{2.5626550066464766`, 2.769748357463745}, {
       2.595057255667003, 2.595057255667003}, {2.5, 2.6423372173506348`}, {
       2.5626550066464766`, 2.769748357463745}}], 
      PolygonBox[{{2.5, 3.5}, {2.5, 2.6423372173506348`}, {2.595057255667003, 
       2.595057255667003}, {2.5, 3.5}}], 
      PolygonBox[{{2.595057255667003, 2.595057255667003}, {2.769748357463745, 
       2.5626550066464766`}, {2.5, 3.5}, {2.595057255667003, 
       2.595057255667003}}], 
      PolygonBox[{{2.5, 2.5}, {2.5, 3.5}, {2.769748357463745, 
       2.5626550066464766`}, {2.5, 2.5}}], 
      PolygonBox[{{2.769748357463745, 2.5626550066464766`}, {
       2.915707410443936, 2.562500018967059}, {2.5, 2.5}, {2.769748357463745, 
       2.5626550066464766`}}], 
      PolygonBox[{{2.794090994433172, 2.5}, {2.5, 2.5}, {2.915707410443936, 
       2.562500018967059}, {2.794090994433172, 2.5}}], 
      PolygonBox[{{2.915707410443936, 2.562500018967059}, {3.000134841831043, 
       2.5625}, {2.794090994433172, 2.5}, {2.915707410443936, 
       2.562500018967059}}], 
      PolygonBox[{{3.0823238704010616`, 2.5}, {2.794090994433172, 2.5}, {
       3.000134841831043, 2.5625}, {3.0823238704010616`, 2.5}}], 
      PolygonBox[{{3.000134841831043, 2.5625}, {3.0842925895560533`, 
       2.562500018967059}, {3.0823238704010616`, 2.5}, {3.000134841831043, 
       2.5625}}], 
      PolygonBox[{{3.2059090053603976`, 2.5}, {3.0823238704010616`, 2.5}, {
       3.0842925895560533`, 2.562500018967059}, {3.2059090053603976`, 2.5}}], 
      PolygonBox[{{3.0842925895560533`, 2.562500018967059}, {
       3.230251642536255, 2.5626550066464766`}, {3.2059090053603976`, 2.5}, {
       3.0842925895560533`, 2.562500018967059}}], 
      PolygonBox[{{3.357662782649371, 2.5}, {3.2059090053603976`, 2.5}, {
       3.230251642536255, 2.5626550066464766`}, {3.357662782649371, 2.5}}], 
      PolygonBox[{{3.230251642536255, 2.5626550066464766`}, {
       3.404942744332997, 2.595057255667003}, {3.357662782649371, 2.5}, {
       3.230251642536255, 2.5626550066464766`}}], 
      PolygonBox[{{3.5, 2.5}, {3.357662782649371, 2.5}, {3.404942744332997, 
       2.595057255667003}, {3.5, 2.5}}], 
      PolygonBox[{{3.404942744332997, 2.595057255667003}, {3.404942744332997, 
       2.595057255667003}, {3.5, 2.5}, {3.404942744332997, 
       2.595057255667003}}], 
      PolygonBox[{{3.5, 2.5}, {3.5, 2.5}, {3.404942744332997, 
       2.595057255667003}, {3.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, 4.}, {2.5208333333333335`, 4.}, {2.5416666666666665`, 
       4.}, {2.5625, 4.}, {2.5833333333333335`, 4.}, {2.6041666666666665`, 
       4.}, {2.625, 4.}, {2.625, 4.}, {2.6041666666666665`, 4.}, {
       2.5833333333333335`, 4.}, {2.5625, 4.}, {2.5416666666666665`, 4.}, {
       2.5208333333333335`, 4.}, {2.5, 4.}, {2.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, 4.}, {3.3958333333333335`, 4.}, {3.4166666666666665`, 
       4.}, {3.4375, 4.}, {3.4583333333333335`, 4.}, {3.4791666666666665`, 
       4.}, {3.5, 4.}, {3.5, 4.}, {3.4791666666666665`, 4.}, {
       3.4583333333333335`, 4.}, {3.4375, 4.}, {3.4166666666666665`, 4.}, {
       3.3958333333333335`, 4.}, {3.375, 4.}, {3.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 3.5}, {3., 3.5208333333333335`}, {3., 
       3.5416666666666665`}, {3., 3.5625}, {3., 3.5833333333333335`}, {3., 
       3.6041666666666665`}, {3., 3.625}, {3., 3.625}, {3., 
       3.6041666666666665`}, {3., 3.5833333333333335`}, {3., 3.5625}, {3., 
       3.5416666666666665`}, {3., 3.5208333333333335`}, {3., 3.5}, {3., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 4.375}, {3., 4.395833333333333}, {3., 
       4.416666666666667}, {3., 4.4375}, {3., 4.458333333333333}, {3., 
       4.479166666666667}, {3., 4.5}, {3., 4.5}, {3., 4.479166666666667}, {3.,
        4.458333333333333}, {3., 4.4375}, {3., 4.416666666666667}, {3., 
       4.395833333333333}, {3., 4.375}, {3., 4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, 4.}, {2.75, 4.}, {2.875, 4.}, {3., 4.}, {3.125, 4.}, {
       3.25, 4.}, {3.375, 4.}, {3.375, 4.}, {3.25, 4.}, {3.125, 4.}, {3., 
       4.}, {2.875, 4.}, {2.75, 4.}, {2.625, 4.}, {2.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 3.625}, {3., 3.75}, {3., 3.875}, {3., 4.}, {3., 4.125}, {
       3., 4.25}, {3., 4.375}, {3., 4.375}, {3., 4.25}, {3., 4.125}, {3., 
       4.}, {3., 3.875}, {3., 3.75}, {3., 3.625}, {3., 3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhBawOHVxXX7rjzlclAv6vyUlCzgYOB+olV6
JhdE/oCAw+y3s2/yyXM5nPt2NqedXxAi3sDpMEP5yaFeH0EH/ydCT48e43D4
mhEe/6oIKs/AAVUn6LBR+q2UlSU7qnwDG1x/qlCK2scHrHDzL+wwr3qSxgq3
X0wv0FFbitVBA+o+iPmscPfD5DeB7eFH1d/A55ACNR9iDy/cfog6Xrj7IObw
orqfgdfBD+o/mPx/EKjnhOuHhQ/MfJTwA9oPC9+NUPehhz8ALGd37A==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhBayGH1KhDggvNDwYATzofQHGjq2eD8MLB6
VjT1LAT5EHsE4XyIuQJo6gXQ5PngfIi9vGjqeTD4oSju40FzP0w9B5p6Tjh/
FUr48BBNh6K4jwfN/TB1AmjyAmj6BdHUCzkAAJ1JQiU=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, 3.7348349570550448`}, {
       3.3247595264191645`, 3.8125}, {3.404942744332997, 3.595057255667003}, {
       3.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{3.4373449933535234`, 3.7697483574637447`}, {
       3.404942744332997, 3.595057255667003}, {3.3247595264191645`, 3.8125}, {
       3.4373449933535234`, 3.7697483574637447`}}], 
      PolygonBox[{{3.3247595264191645`, 3.8125}, {3.3622221848584006`, 
       3.9029428580865546`}, {3.4373449933535234`, 3.7697483574637447`}, {
       3.3247595264191645`, 3.8125}}], 
      PolygonBox[{{3.437499981032941, 3.915707410443938}, {
       3.4373449933535234`, 3.7697483574637447`}, {3.3622221848584006`, 
       3.9029428580865546`}, {3.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{3.3622221848584006`, 3.9029428580865546`}, {3.375, 4.}, {
       3.437499981032941, 3.915707410443938}, {3.3622221848584006`, 
       3.9029428580865546`}}], 
      PolygonBox[{{3.4375, 4.}, {3.437499981032941, 3.915707410443938}, {
       3.375, 4.}, {3.4375, 4.}}], 
      PolygonBox[{{3.375, 4.}, {3.3622221848584006`, 4.097057141913445}, {
       3.4375, 4.}, {3.375, 4.}}], 
      PolygonBox[{{3.437499981032941, 4.084292589556061}, {3.4375, 4.}, {
       3.3622221848584006`, 4.097057141913445}, {3.437499981032941, 
       4.084292589556061}}], 
      PolygonBox[{{3.3622221848584006`, 4.097057141913445}, {
       3.3247595264191645`, 4.1875}, {3.437499981032941, 4.084292589556061}, {
       3.3622221848584006`, 4.097057141913445}}], 
      PolygonBox[{{3.4373449933535234`, 4.230251642536255}, {
       3.437499981032941, 4.084292589556061}, {3.3247595264191645`, 4.1875}, {
       3.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, 4.1875}, {3.2651650429449552`, 
       4.265165042944956}, {3.4373449933535234`, 4.230251642536255}, {
       3.3247595264191645`, 4.1875}}], 
      PolygonBox[{{3.404942744332997, 4.404942744332997}, {
       3.4373449933535234`, 4.230251642536255}, {3.2651650429449552`, 
       4.265165042944956}, {3.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, 4.265165042944956}, {3.1875, 
       4.3247595264191645`}, {3.404942744332997, 4.404942744332997}, {
       3.2651650429449552`, 4.265165042944956}}], 
      PolygonBox[{{3.2302516425362553`, 4.437344993353523}, {
       3.404942744332997, 4.404942744332997}, {3.1875, 4.3247595264191645`}, {
       3.2302516425362553`, 4.437344993353523}}], 
      PolygonBox[{{3.1875, 4.3247595264191645`}, {3.0970571419134454`, 
       4.362222184858401}, {3.2302516425362553`, 4.437344993353523}, {3.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{3.0842925895560604`, 4.437499981032941}, {
       3.2302516425362553`, 4.437344993353523}, {3.0970571419134454`, 
       4.362222184858401}, {3.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{3.0970571419134454`, 4.362222184858401}, {3., 4.375}, {
       3.0842925895560604`, 4.437499981032941}, {3.0970571419134454`, 
       4.362222184858401}}], 
      PolygonBox[{{3.0001055272204877`, 4.4375}, {3.0842925895560604`, 
       4.437499981032941}, {3., 4.375}, {3.0001055272204877`, 4.4375}}], 
      PolygonBox[{{3., 4.375}, {2.902942858086555, 4.362222184858401}, {
       3.0001055272204877`, 4.4375}, {3., 4.375}}], 
      PolygonBox[{{2.915707410443943, 4.437499981032941}, {
       3.0001055272204877`, 4.4375}, {2.902942858086555, 4.362222184858401}, {
       2.915707410443943, 4.437499981032941}}], 
      PolygonBox[{{2.902942858086555, 4.362222184858401}, {2.8125, 
       4.3247595264191645`}, {2.915707410443943, 4.437499981032941}, {
       2.902942858086555, 4.362222184858401}}], 
      PolygonBox[{{2.769748357463745, 4.437344993353523}, {2.915707410443943, 
       4.437499981032941}, {2.8125, 4.3247595264191645`}, {2.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{2.8125, 4.3247595264191645`}, {2.7348349570550448`, 
       4.265165042944956}, {2.769748357463745, 4.437344993353523}, {2.8125, 
       4.3247595264191645`}}], 
      PolygonBox[{{2.595057255667003, 4.404942744332997}, {2.769748357463745, 
       4.437344993353523}, {2.7348349570550448`, 4.265165042944956}, {
       2.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, 4.265165042944956}, {
       2.6752404735808355`, 4.1875}, {2.595057255667003, 4.404942744332997}, {
       2.7348349570550448`, 4.265165042944956}}], 
      PolygonBox[{{2.5626550066464766`, 4.230251642536255}, {
       2.595057255667003, 4.404942744332997}, {2.6752404735808355`, 4.1875}, {
       2.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{2.6752404735808355`, 4.1875}, {2.6377778151415994`, 
       4.097057141913446}, {2.5626550066464766`, 4.230251642536255}, {
       2.6752404735808355`, 4.1875}}], 
      PolygonBox[{{2.562500018967059, 4.084292589556062}, {
       2.5626550066464766`, 4.230251642536255}, {2.6377778151415994`, 
       4.097057141913446}, {2.562500018967059, 4.084292589556062}}], 
      PolygonBox[{{2.6377778151415994`, 4.097057141913446}, {2.625, 4.}, {
       2.562500018967059, 4.084292589556062}, {2.6377778151415994`, 
       4.097057141913446}}], 
      PolygonBox[{{2.5625, 4.000123178062996}, {2.562500018967059, 
       4.084292589556062}, {2.625, 4.}, {2.5625, 4.000123178062996}}], 
      PolygonBox[{{2.625, 4.}, {2.6377778151415994`, 3.902942858086555}, {
       2.5625, 4.000123178062996}, {2.625, 4.}}], 
      PolygonBox[{{2.562500018967059, 3.915707410443945}, {2.5625, 
       4.000123178062996}, {2.6377778151415994`, 3.902942858086555}, {
       2.562500018967059, 3.915707410443945}}], 
      PolygonBox[{{2.6377778151415994`, 3.902942858086555}, {
       2.6752404735808355`, 3.8125}, {2.562500018967059, 3.915707410443945}, {
       2.6377778151415994`, 3.902942858086555}}], 
      PolygonBox[{{2.5626550066464766`, 3.769748357463745}, {
       2.562500018967059, 3.915707410443945}, {2.6752404735808355`, 3.8125}, {
       2.5626550066464766`, 3.769748357463745}}], 
      PolygonBox[{{2.6752404735808355`, 3.8125}, {2.7348349570550448`, 
       3.7348349570550448`}, {2.5626550066464766`, 3.769748357463745}, {
       2.6752404735808355`, 3.8125}}], 
      PolygonBox[{{2.595057255667003, 3.595057255667003}, {
       2.5626550066464766`, 3.769748357463745}, {2.7348349570550448`, 
       3.7348349570550448`}, {2.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{2.7348349570550448`, 3.7348349570550448`}, {2.8125, 
       3.6752404735808355`}, {2.595057255667003, 3.595057255667003}, {
       2.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{2.769748357463745, 3.5626550066464766`}, {
       2.595057255667003, 3.595057255667003}, {2.8125, 3.6752404735808355`}, {
       2.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{2.8125, 3.6752404735808355`}, {2.9029428580865546`, 
       3.6377778151415994`}, {2.769748357463745, 3.5626550066464766`}, {
       2.8125, 3.6752404735808355`}}], 
      PolygonBox[{{2.915707410443936, 3.562500018967059}, {2.769748357463745, 
       3.5626550066464766`}, {2.9029428580865546`, 3.6377778151415994`}, {
       2.915707410443936, 3.562500018967059}}], 
      PolygonBox[{{2.9029428580865546`, 3.6377778151415994`}, {3., 3.625}, {
       2.915707410443936, 3.562500018967059}, {2.9029428580865546`, 
       3.6377778151415994`}}], 
      PolygonBox[{{3.000134841831043, 3.5625}, {2.915707410443936, 
       3.562500018967059}, {3., 3.625}, {3.000134841831043, 3.5625}}], 
      PolygonBox[{{3., 3.625}, {3.097057141913445, 3.6377778151415994`}, {
       3.000134841831043, 3.5625}, {3., 3.625}}], 
      PolygonBox[{{3.0842925895560533`, 3.562500018967059}, {
       3.000134841831043, 3.5625}, {3.097057141913445, 3.6377778151415994`}, {
       3.0842925895560533`, 3.562500018967059}}], 
      PolygonBox[{{3.097057141913445, 3.6377778151415994`}, {
       3.1874999999999996`, 3.6752404735808355`}, {3.0842925895560533`, 
       3.562500018967059}, {3.097057141913445, 3.6377778151415994`}}], 
      PolygonBox[{{3.230251642536255, 3.5626550066464766`}, {
       3.0842925895560533`, 3.562500018967059}, {3.1874999999999996`, 
       3.6752404735808355`}, {3.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{3.1874999999999996`, 3.6752404735808355`}, {
       3.2651650429449552`, 3.7348349570550448`}, {3.230251642536255, 
       3.5626550066464766`}, {3.1874999999999996`, 3.6752404735808355`}}], 
      PolygonBox[{{3.404942744332997, 3.595057255667003}, {3.230251642536255, 
       3.5626550066464766`}, {3.2651650429449552`, 3.7348349570550448`}, {
       3.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{3.2651650429449552`, 3.7348349570550448`}, {
       3.2651650429449552`, 3.7348349570550448`}, {3.404942744332997, 
       3.595057255667003}, {3.2651650429449552`, 3.7348349570550448`}}], 
      PolygonBox[{{3.404942744332997, 3.595057255667003}, {3.404942744332997, 
       3.595057255667003}, {3.2651650429449552`, 3.7348349570550448`}, {
       3.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{3.404942744332997, 3.595057255667003}, {
       3.4373449933535234`, 3.7697483574637447`}, {3.5, 3.5}, {
       3.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{3.5, 3.642337217350632}, {3.5, 3.5}, {3.4373449933535234`, 
       3.7697483574637447`}, {3.5, 3.642337217350632}}], 
      PolygonBox[{{3.4373449933535234`, 3.7697483574637447`}, {
       3.437499981032941, 3.915707410443938}, {3.5, 3.642337217350632}, {
       3.4373449933535234`, 3.7697483574637447`}}], 
      PolygonBox[{{3.5, 3.79409099469826}, {3.5, 3.642337217350632}, {
       3.437499981032941, 3.915707410443938}, {3.5, 3.79409099469826}}], 
      PolygonBox[{{3.437499981032941, 3.915707410443938}, {3.4375, 4.}, {3.5, 
       3.79409099469826}, {3.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{3.5, 4.}, {3.5, 3.79409099469826}, {3.4375, 4.}, {3.5, 
       4.}}], PolygonBox[{{3.4375, 4.}, {3.437499981032941, 
       4.084292589556061}, {3.5, 4.}, {3.4375, 4.}}], 
      PolygonBox[{{3.5, 4.20590900530174}, {3.5, 4.}, {3.437499981032941, 
       4.084292589556061}, {3.5, 4.20590900530174}}], 
      PolygonBox[{{3.437499981032941, 4.084292589556061}, {
       3.4373449933535234`, 4.230251642536255}, {3.5, 4.20590900530174}, {
       3.437499981032941, 4.084292589556061}}], 
      PolygonBox[{{3.5, 4.357662782649368}, {3.5, 4.20590900530174}, {
       3.4373449933535234`, 4.230251642536255}, {3.5, 4.357662782649368}}], 
      PolygonBox[{{3.4373449933535234`, 4.230251642536255}, {
       3.404942744332997, 4.404942744332997}, {3.5, 4.357662782649368}, {
       3.4373449933535234`, 4.230251642536255}}], 
      PolygonBox[{{3.491446564961186, 4.491446564961186}, {3.5, 
       4.357662782649368}, {3.404942744332997, 4.404942744332997}, {
       3.491446564961186, 4.491446564961186}}], 
      PolygonBox[{{3.404942744332997, 4.404942744332997}, {
       3.2302516425362553`, 4.437344993353523}, {3.491446564961186, 
       4.491446564961186}, {3.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{3.357662782649368, 4.5}, {3.491446564961186, 
       4.491446564961186}, {3.2302516425362553`, 4.437344993353523}, {
       3.357662782649368, 4.5}}], 
      PolygonBox[{{3.2302516425362553`, 4.437344993353523}, {
       3.0842925895560604`, 4.437499981032941}, {3.357662782649368, 4.5}, {
       3.2302516425362553`, 4.437344993353523}}], 
      PolygonBox[{{3.2059090053732557`, 4.5}, {3.357662782649368, 4.5}, {
       3.0842925895560604`, 4.437499981032941}, {3.2059090053732557`, 4.5}}], 
      PolygonBox[{{3.0842925895560604`, 4.437499981032941}, {
       3.0001055272204877`, 4.4375}, {3.2059090053732557`, 4.5}, {
       3.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{3.07794195802689, 4.5}, {3.2059090053732557`, 4.5}, {
       3.0001055272204877`, 4.4375}, {3.07794195802689, 4.5}}], 
      PolygonBox[{{3.0001055272204877`, 4.4375}, {2.915707410443943, 
       4.437499981032941}, {3.07794195802689, 4.5}, {3.0001055272204877`, 
       4.4375}}], 
      PolygonBox[{{2.7940909946955546`, 4.5}, {3.07794195802689, 4.5}, {
       2.915707410443943, 4.437499981032941}, {2.7940909946955546`, 4.5}}], 
      PolygonBox[{{2.915707410443943, 4.437499981032941}, {2.769748357463745, 
       4.437344993353523}, {2.7940909946955546`, 4.5}, {2.915707410443943, 
       4.437499981032941}}], 
      PolygonBox[{{2.642337217350634, 4.5}, {2.7940909946955546`, 4.5}, {
       2.769748357463745, 4.437344993353523}, {2.642337217350634, 4.5}}], 
      PolygonBox[{{2.769748357463745, 4.437344993353523}, {2.595057255667003, 
       4.404942744332997}, {2.642337217350634, 4.5}, {2.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{3.5, 4.5}, {2.642337217350634, 4.5}, {2.595057255667003, 
       4.404942744332997}, {3.5, 4.5}}], 
      PolygonBox[{{2.595057255667003, 4.404942744332997}, {
       2.5626550066464766`, 4.230251642536255}, {3.5, 4.5}, {
       2.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{2.5, 4.357662782649369}, {3.5, 4.5}, {2.5626550066464766`, 
       4.230251642536255}, {2.5, 4.357662782649369}}], 
      PolygonBox[{{2.5626550066464766`, 4.230251642536255}, {
       2.562500018967059, 4.084292589556062}, {2.5, 4.357662782649369}, {
       2.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{2.5, 4.205909005282899}, {2.5, 4.357662782649369}, {
       2.562500018967059, 4.084292589556062}, {2.5, 4.205909005282899}}], 
      PolygonBox[{{2.562500018967059, 4.084292589556062}, {2.5625, 
       4.000123178062996}, {2.5, 4.205909005282899}, {2.562500018967059, 
       4.084292589556062}}], 
      PolygonBox[{{2.5, 4.0806786667587005`}, {2.5, 4.205909005282899}, {
       2.5625, 4.000123178062996}, {2.5, 4.0806786667587005`}}], 
      PolygonBox[{{2.5625, 4.000123178062996}, {2.562500018967059, 
       3.915707410443945}, {2.5, 4.0806786667587005`}, {2.5625, 
       4.000123178062996}}], 
      PolygonBox[{{2.5, 3.7940909948547215`}, {2.5, 4.0806786667587005`}, {
       2.562500018967059, 3.915707410443945}, {2.5, 3.7940909948547215`}}], 
      PolygonBox[{{2.562500018967059, 3.915707410443945}, {
       2.5626550066464766`, 3.769748357463745}, {2.5, 3.7940909948547215`}, {
       2.562500018967059, 3.915707410443945}}], 
      PolygonBox[{{2.5, 3.6423372173506348`}, {2.5, 3.7940909948547215`}, {
       2.5626550066464766`, 3.769748357463745}, {2.5, 3.6423372173506348`}}], 
      PolygonBox[{{2.5626550066464766`, 3.769748357463745}, {
       2.595057255667003, 3.595057255667003}, {2.5, 3.6423372173506348`}, {
       2.5626550066464766`, 3.769748357463745}}], 
      PolygonBox[{{2.5, 4.5}, {2.5, 3.6423372173506348`}, {2.595057255667003, 
       3.595057255667003}, {2.5, 4.5}}], 
      PolygonBox[{{2.595057255667003, 3.595057255667003}, {2.769748357463745, 
       3.5626550066464766`}, {2.5, 4.5}, {2.595057255667003, 
       3.595057255667003}}], 
      PolygonBox[{{2.5, 3.5}, {2.5, 4.5}, {2.769748357463745, 
       3.5626550066464766`}, {2.5, 3.5}}], 
      PolygonBox[{{2.769748357463745, 3.5626550066464766`}, {
       2.915707410443936, 3.562500018967059}, {2.5, 3.5}, {2.769748357463745, 
       3.5626550066464766`}}], 
      PolygonBox[{{2.794090994433172, 3.5}, {2.5, 3.5}, {2.915707410443936, 
       3.562500018967059}, {2.794090994433172, 3.5}}], 
      PolygonBox[{{2.915707410443936, 3.562500018967059}, {3.000134841831043, 
       3.5625}, {2.794090994433172, 3.5}, {2.915707410443936, 
       3.562500018967059}}], 
      PolygonBox[{{3.0823238704010616`, 3.5}, {2.794090994433172, 3.5}, {
       3.000134841831043, 3.5625}, {3.0823238704010616`, 3.5}}], 
      PolygonBox[{{3.000134841831043, 3.5625}, {3.0842925895560533`, 
       3.562500018967059}, {3.0823238704010616`, 3.5}, {3.000134841831043, 
       3.5625}}], 
      PolygonBox[{{3.2059090053603976`, 3.5}, {3.0823238704010616`, 3.5}, {
       3.0842925895560533`, 3.562500018967059}, {3.2059090053603976`, 3.5}}], 
      PolygonBox[{{3.0842925895560533`, 3.562500018967059}, {
       3.230251642536255, 3.5626550066464766`}, {3.2059090053603976`, 3.5}, {
       3.0842925895560533`, 3.562500018967059}}], 
      PolygonBox[{{3.357662782649371, 3.5}, {3.2059090053603976`, 3.5}, {
       3.230251642536255, 3.5626550066464766`}, {3.357662782649371, 3.5}}], 
      PolygonBox[{{3.230251642536255, 3.5626550066464766`}, {
       3.404942744332997, 3.595057255667003}, {3.357662782649371, 3.5}, {
       3.230251642536255, 3.5626550066464766`}}], 
      PolygonBox[{{3.5, 3.5}, {3.357662782649371, 3.5}, {3.404942744332997, 
       3.595057255667003}, {3.5, 3.5}}], 
      PolygonBox[{{3.404942744332997, 3.595057255667003}, {3.404942744332997, 
       3.595057255667003}, {3.5, 3.5}, {3.404942744332997, 
       3.595057255667003}}], 
      PolygonBox[{{3.5, 3.5}, {3.5, 3.5}, {3.404942744332997, 
       3.595057255667003}, {3.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5, 5.}, {2.5208333333333335`, 5.}, {2.5416666666666665`, 
       5.}, {2.5625, 5.}, {2.5833333333333335`, 5.}, {2.6041666666666665`, 
       5.}, {2.625, 5.}, {2.625, 5.}, {2.6041666666666665`, 5.}, {
       2.5833333333333335`, 5.}, {2.5625, 5.}, {2.5416666666666665`, 5.}, {
       2.5208333333333335`, 5.}, {2.5, 5.}, {2.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375, 5.}, {3.3958333333333335`, 5.}, {3.4166666666666665`, 
       5.}, {3.4375, 5.}, {3.4583333333333335`, 5.}, {3.4791666666666665`, 
       5.}, {3.5, 5.}, {3.5, 5.}, {3.4791666666666665`, 5.}, {
       3.4583333333333335`, 5.}, {3.4375, 5.}, {3.4166666666666665`, 5.}, {
       3.3958333333333335`, 5.}, {3.375, 5.}, {3.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 4.5}, {3., 4.520833333333333}, {3., 4.541666666666667}, {
       3., 4.5625}, {3., 4.583333333333333}, {3., 4.604166666666667}, {3., 
       4.625}, {3., 4.625}, {3., 4.604166666666667}, {3., 
       4.583333333333333}, {3., 4.5625}, {3., 4.541666666666667}, {3., 
       4.520833333333333}, {3., 4.5}, {3., 4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 5.375}, {3., 5.395833333333333}, {3., 
       5.416666666666667}, {3., 5.4375}, {3., 5.458333333333333}, {3., 
       5.479166666666667}, {3., 5.5}, {3., 5.5}, {3., 5.479166666666667}, {3.,
        5.458333333333333}, {3., 5.4375}, {3., 5.416666666666667}, {3., 
       5.395833333333333}, {3., 5.375}, {3., 5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.625, 5.}, {2.75, 5.}, {2.875, 5.}, {3., 5.}, {3.125, 5.}, {
       3.25, 5.}, {3.375, 5.}, {3.375, 5.}, {3.25, 5.}, {3.125, 5.}, {3., 
       5.}, {2.875, 5.}, {2.75, 5.}, {2.625, 5.}, {2.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., 4.625}, {3., 4.75}, {3., 4.875}, {3., 5.}, {3., 5.125}, {
       3., 5.25}, {3., 5.375}, {3., 5.375}, {3., 5.25}, {3., 5.125}, {3., 
       5.}, {3., 4.875}, {3., 4.75}, {3., 4.625}, {3., 4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQHcDhBaxOHVxXX7rjzlclAv6vyUlCziYOB+olV6
JhdE/oCIw+y3s2/yyXM5nPt2NqedXxQi3sDpMEP5yaFeH1EH/ydCT48e43D4
mhEe/6oIKs/AAVUn6rBR+q2UlSU7qnwDG1x/qlCK2scHrHDzL+wwr3qSxgq3
X0wv0FFbitVBA+o+iPmscPfD5G/2lvHOnSOMqt9B2CEFar4xp9Hkig9CcPsz
7kjbFm0WgruPe/qKBaK9QmjuF3Lwg/oPJv8fBOo54fph4WMENR8l/ID2w8L3
BtR96OEPAFv6epo=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQE8DhBazGH1KhDggvNDwYATzofQHGjq2eD8MLB6
VjT1LAT5EHtE4XyIuSJo6kXQ1AujqRdCU4/JD0VxnxCa+2HqOdDUc8L5q1DC
B6aehyAf1X08aO6HqRdBUy+Cpl4UTb2YAwAJrEKq
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{3.2651650429449552`, 4.734834957055044}, {
       3.3247595264191645`, 4.8125}, {3.404942744332997, 4.595057255667003}, {
       3.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{3.4373449933535234`, 4.769748357463745}, {
       3.404942744332997, 4.595057255667003}, {3.3247595264191645`, 4.8125}, {
       3.4373449933535234`, 4.769748357463745}}], 
      PolygonBox[{{3.3247595264191645`, 4.8125}, {3.3622221848584006`, 
       4.902942858086555}, {3.4373449933535234`, 4.769748357463745}, {
       3.3247595264191645`, 4.8125}}], 
      PolygonBox[{{3.437499981032941, 4.915707410443938}, {
       3.4373449933535234`, 4.769748357463745}, {3.3622221848584006`, 
       4.902942858086555}, {3.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{3.3622221848584006`, 4.902942858086555}, {3.375, 5.}, {
       3.437499981032941, 4.915707410443938}, {3.3622221848584006`, 
       4.902942858086555}}], 
      PolygonBox[{{3.4375, 5.}, {3.437499981032941, 4.915707410443938}, {
       3.375, 5.}, {3.4375, 5.}}], 
      PolygonBox[{{3.375, 5.}, {3.3622221848584006`, 5.097057141913445}, {
       3.4375, 5.}, {3.375, 5.}}], 
      PolygonBox[{{3.437499981032941, 5.084292589556061}, {3.4375, 5.}, {
       3.3622221848584006`, 5.097057141913445}, {3.437499981032941, 
       5.084292589556061}}], 
      PolygonBox[{{3.3622221848584006`, 5.097057141913445}, {
       3.3247595264191645`, 5.1875}, {3.437499981032941, 5.084292589556061}, {
       3.3622221848584006`, 5.097057141913445}}], 
      PolygonBox[{{3.4373449933535234`, 5.230251642536255}, {
       3.437499981032941, 5.084292589556061}, {3.3247595264191645`, 5.1875}, {
       3.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{3.3247595264191645`, 5.1875}, {3.2651650429449552`, 
       5.265165042944956}, {3.4373449933535234`, 5.230251642536255}, {
       3.3247595264191645`, 5.1875}}], 
      PolygonBox[{{3.404942744332997, 5.404942744332997}, {
       3.4373449933535234`, 5.230251642536255}, {3.2651650429449552`, 
       5.265165042944956}, {3.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{3.2651650429449552`, 5.265165042944956}, {3.1875, 
       5.3247595264191645`}, {3.404942744332997, 5.404942744332997}, {
       3.2651650429449552`, 5.265165042944956}}], 
      PolygonBox[{{3.2302516425362553`, 5.437344993353523}, {
       3.404942744332997, 5.404942744332997}, {3.1875, 5.3247595264191645`}, {
       3.2302516425362553`, 5.437344993353523}}], 
      PolygonBox[{{3.1875, 5.3247595264191645`}, {3.0970571419134454`, 
       5.362222184858401}, {3.2302516425362553`, 5.437344993353523}, {3.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{3.0842925895560604`, 5.437499981032941}, {
       3.2302516425362553`, 5.437344993353523}, {3.0970571419134454`, 
       5.362222184858401}, {3.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{3.0970571419134454`, 5.362222184858401}, {3., 5.375}, {
       3.0842925895560604`, 5.437499981032941}, {3.0970571419134454`, 
       5.362222184858401}}], 
      PolygonBox[{{3.0001055272204877`, 5.4375}, {3.0842925895560604`, 
       5.437499981032941}, {3., 5.375}, {3.0001055272204877`, 5.4375}}], 
      PolygonBox[{{3., 5.375}, {2.902942858086555, 5.362222184858401}, {
       3.0001055272204877`, 5.4375}, {3., 5.375}}], 
      PolygonBox[{{2.915707410443943, 5.437499981032941}, {
       3.0001055272204877`, 5.4375}, {2.902942858086555, 5.362222184858401}, {
       2.915707410443943, 5.437499981032941}}], 
      PolygonBox[{{2.902942858086555, 5.362222184858401}, {2.8125, 
       5.3247595264191645`}, {2.915707410443943, 5.437499981032941}, {
       2.902942858086555, 5.362222184858401}}], 
      PolygonBox[{{2.769748357463745, 5.437344993353523}, {2.915707410443943, 
       5.437499981032941}, {2.8125, 5.3247595264191645`}, {2.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{2.8125, 5.3247595264191645`}, {2.7348349570550448`, 
       5.265165042944956}, {2.769748357463745, 5.437344993353523}, {2.8125, 
       5.3247595264191645`}}], 
      PolygonBox[{{2.595057255667003, 5.404942744332997}, {2.769748357463745, 
       5.437344993353523}, {2.7348349570550448`, 5.265165042944956}, {
       2.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{2.7348349570550448`, 5.265165042944956}, {
       2.6752404735808355`, 5.1875}, {2.595057255667003, 5.404942744332997}, {
       2.7348349570550448`, 5.265165042944956}}], 
      PolygonBox[{{2.5626550066464766`, 5.230251642536255}, {
       2.595057255667003, 5.404942744332997}, {2.6752404735808355`, 5.1875}, {
       2.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{2.6752404735808355`, 5.1875}, {2.6377778151415994`, 
       5.097057141913446}, {2.5626550066464766`, 5.230251642536255}, {
       2.6752404735808355`, 5.1875}}], 
      PolygonBox[{{2.562500018967059, 5.084292589556062}, {
       2.5626550066464766`, 5.230251642536255}, {2.6377778151415994`, 
       5.097057141913446}, {2.562500018967059, 5.084292589556062}}], 
      PolygonBox[{{2.6377778151415994`, 5.097057141913446}, {2.625, 5.}, {
       2.562500018967059, 5.084292589556062}, {2.6377778151415994`, 
       5.097057141913446}}], 
      PolygonBox[{{2.5625, 5.000123178062996}, {2.562500018967059, 
       5.084292589556062}, {2.625, 5.}, {2.5625, 5.000123178062996}}], 
      PolygonBox[{{2.625, 5.}, {2.6377778151415994`, 4.902942858086555}, {
       2.5625, 5.000123178062996}, {2.625, 5.}}], 
      PolygonBox[{{2.562500018967059, 4.915707410443945}, {2.5625, 
       5.000123178062996}, {2.6377778151415994`, 4.902942858086555}, {
       2.562500018967059, 4.915707410443945}}], 
      PolygonBox[{{2.6377778151415994`, 4.902942858086555}, {
       2.6752404735808355`, 4.8125}, {2.562500018967059, 4.915707410443945}, {
       2.6377778151415994`, 4.902942858086555}}], 
      PolygonBox[{{2.5626550066464766`, 4.769748357463746}, {
       2.562500018967059, 4.915707410443945}, {2.6752404735808355`, 4.8125}, {
       2.5626550066464766`, 4.769748357463746}}], 
      PolygonBox[{{2.6752404735808355`, 4.8125}, {2.7348349570550448`, 
       4.734834957055044}, {2.5626550066464766`, 4.769748357463746}, {
       2.6752404735808355`, 4.8125}}], 
      PolygonBox[{{2.595057255667003, 4.595057255667003}, {
       2.5626550066464766`, 4.769748357463746}, {2.7348349570550448`, 
       4.734834957055044}, {2.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{2.7348349570550448`, 4.734834957055044}, {2.8125, 
       4.6752404735808355`}, {2.595057255667003, 4.595057255667003}, {
       2.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{2.769748357463745, 4.562655006646477}, {2.595057255667003, 
       4.595057255667003}, {2.8125, 4.6752404735808355`}, {2.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{2.8125, 4.6752404735808355`}, {2.9029428580865546`, 
       4.637777815141599}, {2.769748357463745, 4.562655006646477}, {2.8125, 
       4.6752404735808355`}}], 
      PolygonBox[{{2.915707410443936, 4.562500018967059}, {2.769748357463745, 
       4.562655006646477}, {2.9029428580865546`, 4.637777815141599}, {
       2.915707410443936, 4.562500018967059}}], 
      PolygonBox[{{2.9029428580865546`, 4.637777815141599}, {3., 4.625}, {
       2.915707410443936, 4.562500018967059}, {2.9029428580865546`, 
       4.637777815141599}}], 
      PolygonBox[{{3.000134841831043, 4.5625}, {2.915707410443936, 
       4.562500018967059}, {3., 4.625}, {3.000134841831043, 4.5625}}], 
      PolygonBox[{{3., 4.625}, {3.097057141913445, 4.637777815141599}, {
       3.000134841831043, 4.5625}, {3., 4.625}}], 
      PolygonBox[{{3.0842925895560533`, 4.562500018967059}, {
       3.000134841831043, 4.5625}, {3.097057141913445, 4.637777815141599}, {
       3.0842925895560533`, 4.562500018967059}}], 
      PolygonBox[{{3.097057141913445, 4.637777815141599}, {
       3.1874999999999996`, 4.6752404735808355`}, {3.0842925895560533`, 
       4.562500018967059}, {3.097057141913445, 4.637777815141599}}], 
      PolygonBox[{{3.230251642536255, 4.562655006646477}, {
       3.0842925895560533`, 4.562500018967059}, {3.1874999999999996`, 
       4.6752404735808355`}, {3.230251642536255, 4.562655006646477}}], 
      PolygonBox[{{3.1874999999999996`, 4.6752404735808355`}, {
       3.2651650429449552`, 4.734834957055044}, {3.230251642536255, 
       4.562655006646477}, {3.1874999999999996`, 4.6752404735808355`}}], 
      PolygonBox[{{3.404942744332997, 4.595057255667003}, {3.230251642536255, 
       4.562655006646477}, {3.2651650429449552`, 4.734834957055044}, {
       3.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{3.2651650429449552`, 4.734834957055044}, {
       3.2651650429449552`, 4.734834957055044}, {3.404942744332997, 
       4.595057255667003}, {3.2651650429449552`, 4.734834957055044}}], 
      PolygonBox[{{3.404942744332997, 4.595057255667003}, {3.404942744332997, 
       4.595057255667003}, {3.2651650429449552`, 4.734834957055044}, {
       3.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{3.404942744332997, 4.595057255667003}, {
       3.4373449933535234`, 4.769748357463745}, {3.5, 4.5}, {
       3.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{3.5, 4.642337217350632}, {3.5, 4.5}, {3.4373449933535234`, 
       4.769748357463745}, {3.5, 4.642337217350632}}], 
      PolygonBox[{{3.4373449933535234`, 4.769748357463745}, {
       3.437499981032941, 4.915707410443938}, {3.5, 4.642337217350632}, {
       3.4373449933535234`, 4.769748357463745}}], 
      PolygonBox[{{3.5, 4.79409099469826}, {3.5, 4.642337217350632}, {
       3.437499981032941, 4.915707410443938}, {3.5, 4.79409099469826}}], 
      PolygonBox[{{3.437499981032941, 4.915707410443938}, {3.4375, 5.}, {3.5, 
       4.79409099469826}, {3.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{3.5, 5.}, {3.5, 4.79409099469826}, {3.4375, 5.}, {3.5, 
       5.}}], PolygonBox[{{3.4375, 5.}, {3.437499981032941, 
       5.084292589556061}, {3.5, 5.}, {3.4375, 5.}}], 
      PolygonBox[{{3.5, 5.20590900530174}, {3.5, 5.}, {3.437499981032941, 
       5.084292589556061}, {3.5, 5.20590900530174}}], 
      PolygonBox[{{3.437499981032941, 5.084292589556061}, {
       3.4373449933535234`, 5.230251642536255}, {3.5, 5.20590900530174}, {
       3.437499981032941, 5.084292589556061}}], 
      PolygonBox[{{3.5, 5.357662782649368}, {3.5, 5.20590900530174}, {
       3.4373449933535234`, 5.230251642536255}, {3.5, 5.357662782649368}}], 
      PolygonBox[{{3.4373449933535234`, 5.230251642536255}, {
       3.404942744332997, 5.404942744332997}, {3.5, 5.357662782649368}, {
       3.4373449933535234`, 5.230251642536255}}], 
      PolygonBox[{{3.491446564961186, 5.491446564961186}, {3.5, 
       5.357662782649368}, {3.404942744332997, 5.404942744332997}, {
       3.491446564961186, 5.491446564961186}}], 
      PolygonBox[{{3.404942744332997, 5.404942744332997}, {
       3.2302516425362553`, 5.437344993353523}, {3.491446564961186, 
       5.491446564961186}, {3.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{3.357662782649368, 5.5}, {3.491446564961186, 
       5.491446564961186}, {3.2302516425362553`, 5.437344993353523}, {
       3.357662782649368, 5.5}}], 
      PolygonBox[{{3.2302516425362553`, 5.437344993353523}, {
       3.0842925895560604`, 5.437499981032941}, {3.357662782649368, 5.5}, {
       3.2302516425362553`, 5.437344993353523}}], 
      PolygonBox[{{3.2059090053732557`, 5.5}, {3.357662782649368, 5.5}, {
       3.0842925895560604`, 5.437499981032941}, {3.2059090053732557`, 5.5}}], 
      PolygonBox[{{3.0842925895560604`, 5.437499981032941}, {
       3.0001055272204877`, 5.4375}, {3.2059090053732557`, 5.5}, {
       3.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{3.07794195802689, 5.5}, {3.2059090053732557`, 5.5}, {
       3.0001055272204877`, 5.4375}, {3.07794195802689, 5.5}}], 
      PolygonBox[{{3.0001055272204877`, 5.4375}, {2.915707410443943, 
       5.437499981032941}, {3.07794195802689, 5.5}, {3.0001055272204877`, 
       5.4375}}], 
      PolygonBox[{{2.7940909946955546`, 5.5}, {3.07794195802689, 5.5}, {
       2.915707410443943, 5.437499981032941}, {2.7940909946955546`, 5.5}}], 
      PolygonBox[{{2.915707410443943, 5.437499981032941}, {2.769748357463745, 
       5.437344993353523}, {2.7940909946955546`, 5.5}, {2.915707410443943, 
       5.437499981032941}}], 
      PolygonBox[{{2.642337217350634, 5.5}, {2.7940909946955546`, 5.5}, {
       2.769748357463745, 5.437344993353523}, {2.642337217350634, 5.5}}], 
      PolygonBox[{{2.769748357463745, 5.437344993353523}, {2.595057255667003, 
       5.404942744332997}, {2.642337217350634, 5.5}, {2.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{3.5, 5.5}, {2.642337217350634, 5.5}, {2.595057255667003, 
       5.404942744332997}, {3.5, 5.5}}], 
      PolygonBox[{{2.595057255667003, 5.404942744332997}, {
       2.5626550066464766`, 5.230251642536255}, {3.5, 5.5}, {
       2.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{2.5, 5.357662782649369}, {3.5, 5.5}, {2.5626550066464766`, 
       5.230251642536255}, {2.5, 5.357662782649369}}], 
      PolygonBox[{{2.5626550066464766`, 5.230251642536255}, {
       2.562500018967059, 5.084292589556062}, {2.5, 5.357662782649369}, {
       2.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{2.5, 5.205909005282899}, {2.5, 5.357662782649369}, {
       2.562500018967059, 5.084292589556062}, {2.5, 5.205909005282899}}], 
      PolygonBox[{{2.562500018967059, 5.084292589556062}, {2.5625, 
       5.000123178062996}, {2.5, 5.205909005282899}, {2.562500018967059, 
       5.084292589556062}}], 
      PolygonBox[{{2.5, 5.0806786667587005`}, {2.5, 5.205909005282899}, {
       2.5625, 5.000123178062996}, {2.5, 5.0806786667587005`}}], 
      PolygonBox[{{2.5625, 5.000123178062996}, {2.562500018967059, 
       4.915707410443945}, {2.5, 5.0806786667587005`}, {2.5625, 
       5.000123178062996}}], 
      PolygonBox[{{2.5, 4.794090994854722}, {2.5, 5.0806786667587005`}, {
       2.562500018967059, 4.915707410443945}, {2.5, 4.794090994854722}}], 
      PolygonBox[{{2.562500018967059, 4.915707410443945}, {
       2.5626550066464766`, 4.769748357463746}, {2.5, 4.794090994854722}, {
       2.562500018967059, 4.915707410443945}}], 
      PolygonBox[{{2.5, 4.642337217350635}, {2.5, 4.794090994854722}, {
       2.5626550066464766`, 4.769748357463746}, {2.5, 4.642337217350635}}], 
      PolygonBox[{{2.5626550066464766`, 4.769748357463746}, {
       2.595057255667003, 4.595057255667003}, {2.5, 4.642337217350635}, {
       2.5626550066464766`, 4.769748357463746}}], 
      PolygonBox[{{2.5, 5.5}, {2.5, 4.642337217350635}, {2.595057255667003, 
       4.595057255667003}, {2.5, 5.5}}], 
      PolygonBox[{{2.595057255667003, 4.595057255667003}, {2.769748357463745, 
       4.562655006646477}, {2.5, 5.5}, {2.595057255667003, 
       4.595057255667003}}], 
      PolygonBox[{{2.5, 4.5}, {2.5, 5.5}, {2.769748357463745, 
       4.562655006646477}, {2.5, 4.5}}], 
      PolygonBox[{{2.769748357463745, 4.562655006646477}, {2.915707410443936, 
       4.562500018967059}, {2.5, 4.5}, {2.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{2.794090994433172, 4.5}, {2.5, 4.5}, {2.915707410443936, 
       4.562500018967059}, {2.794090994433172, 4.5}}], 
      PolygonBox[{{2.915707410443936, 4.562500018967059}, {3.000134841831043, 
       4.5625}, {2.794090994433172, 4.5}, {2.915707410443936, 
       4.562500018967059}}], 
      PolygonBox[{{3.0823238704010616`, 4.5}, {2.794090994433172, 4.5}, {
       3.000134841831043, 4.5625}, {3.0823238704010616`, 4.5}}], 
      PolygonBox[{{3.000134841831043, 4.5625}, {3.0842925895560533`, 
       4.562500018967059}, {3.0823238704010616`, 4.5}, {3.000134841831043, 
       4.5625}}], 
      PolygonBox[{{3.2059090053603976`, 4.5}, {3.0823238704010616`, 4.5}, {
       3.0842925895560533`, 4.562500018967059}, {3.2059090053603976`, 4.5}}], 
      PolygonBox[{{3.0842925895560533`, 4.562500018967059}, {
       3.230251642536255, 4.562655006646477}, {3.2059090053603976`, 4.5}, {
       3.0842925895560533`, 4.562500018967059}}], 
      PolygonBox[{{3.357662782649371, 4.5}, {3.2059090053603976`, 4.5}, {
       3.230251642536255, 4.562655006646477}, {3.357662782649371, 4.5}}], 
      PolygonBox[{{3.230251642536255, 4.562655006646477}, {3.404942744332997, 
       4.595057255667003}, {3.357662782649371, 4.5}, {3.230251642536255, 
       4.562655006646477}}], 
      PolygonBox[{{3.5, 4.5}, {3.357662782649371, 4.5}, {3.404942744332997, 
       4.595057255667003}, {3.5, 4.5}}], 
      PolygonBox[{{3.404942744332997, 4.595057255667003}, {3.404942744332997, 
       4.595057255667003}, {3.5, 4.5}, {3.404942744332997, 
       4.595057255667003}}], 
      PolygonBox[{{3.5, 4.5}, {3.5, 4.5}, {3.404942744332997, 
       4.595057255667003}, {3.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, -5.}, {3.5208333333333335`, -5.}, {
       3.5416666666666665`, -5.}, {3.5625, -5.}, {3.5833333333333335`, -5.}, {
       3.6041666666666665`, -5.}, {3.625, -5.}, {3.625, -5.}, {
       3.6041666666666665`, -5.}, {3.5833333333333335`, -5.}, {3.5625, -5.}, {
       3.5416666666666665`, -5.}, {3.5208333333333335`, -5.}, {3.5, -5.}, {
       3.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, -5.}, {4.395833333333333, -5.}, {
       4.416666666666667, -5.}, {4.4375, -5.}, {4.458333333333333, -5.}, {
       4.479166666666667, -5.}, {4.5, -5.}, {4.5, -5.}, {
       4.479166666666667, -5.}, {4.458333333333333, -5.}, {4.4375, -5.}, {
       4.416666666666667, -5.}, {4.395833333333333, -5.}, {4.375, -5.}, {
       4.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -5.5}, {4., -5.479166666666667}, {
       4., -5.458333333333333}, {4., -5.4375}, {4., -5.416666666666667}, {
       4., -5.395833333333333}, {4., -5.375}, {4., -5.375}, {
       4., -5.395833333333333}, {4., -5.416666666666667}, {4., -5.4375}, {
       4., -5.458333333333333}, {4., -5.479166666666667}, {4., -5.5}, {
       4., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -4.625}, {4., -4.604166666666667}, {
       4., -4.583333333333333}, {4., -4.5625}, {4., -4.541666666666667}, {
       4., -4.520833333333333}, {4., -4.5}, {4., -4.5}, {
       4., -4.520833333333333}, {4., -4.541666666666667}, {4., -4.5625}, {
       4., -4.583333333333333}, {4., -4.604166666666667}, {4., -4.625}, {
       4., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, -5.}, {3.75, -5.}, {3.875, -5.}, {4., -5.}, {
       4.125, -5.}, {4.25, -5.}, {4.375, -5.}, {4.375, -5.}, {4.25, -5.}, {
       4.125, -5.}, {4., -5.}, {3.875, -5.}, {3.75, -5.}, {3.625, -5.}, {
       3.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -5.375}, {4., -5.25}, {4., -5.125}, {4., -5.}, {
       4., -4.875}, {4., -4.75}, {4., -4.625}, {4., -4.625}, {4., -4.75}, {
       4., -4.875}, {4., -5.}, {4., -5.125}, {4., -5.25}, {4., -5.375}, {
       4., -5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4QhsiBrxnh8a+KBB1u9pbxzp0jfGCG8pND
vT5QeQfhA+e+nc1p5xd0MOI0mlzxQegAWPyAgEPGHWnbos1CB9SLOj8lJQs4
cE9fsUC0FyrPIADR3yB0YKP0WykrS35U+QY+uP5UoRS1jw944eZf2GFe9SSN
F26/mF6go7YUr8MNqPsg5vPC3Q+Th7hDBFX/AZEDKVDzz4L9IQq3H+JPUbj7
IOEgiuZ+Ubj/UOSB/ofph4XPOaj5KOF3ABG+GlD3oYc/AAv9ghk=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDlD6QCgYCML5q1eBgACcD6EF0OT54PwwsH5e
NPU8BPkQcxB8iDuE0dSLoKkXQVMviqZeDIMfiuI+MTT3w9QLoMkLoOkXRFMv
RJCP6j4hNPfD1IugqRdGUy+Epl7oAACKNFF1
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, -5.265165042944956}, {
       4.3247595264191645`, -5.1875}, {
       4.404942744332997, -5.404942744332997}, {
       4.265165042944956, -5.265165042944956}}], 
      PolygonBox[{{4.437344993353523, -5.230251642536255}, {
       4.404942744332997, -5.404942744332997}, {
       4.3247595264191645`, -5.1875}, {
       4.437344993353523, -5.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, -5.1875}, {
       4.362222184858401, -5.097057141913445}, {
       4.437344993353523, -5.230251642536255}, {
       4.3247595264191645`, -5.1875}}], 
      PolygonBox[{{4.437499981032941, -5.084292589556062}, {
       4.437344993353523, -5.230251642536255}, {
       4.362222184858401, -5.097057141913445}, {
       4.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{4.362222184858401, -5.097057141913445}, {4.375, -5.}, {
       4.437499981032941, -5.084292589556062}, {
       4.362222184858401, -5.097057141913445}}], 
      PolygonBox[{{4.4375, -5.}, {4.437499981032941, -5.084292589556062}, {
       4.375, -5.}, {4.4375, -5.}}], 
      PolygonBox[{{4.375, -5.}, {4.362222184858401, -4.902942858086555}, {
       4.4375, -5.}, {4.375, -5.}}], 
      PolygonBox[{{4.437499981032941, -4.915707410443939}, {4.4375, -5.}, {
       4.362222184858401, -4.902942858086555}, {
       4.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{4.362222184858401, -4.902942858086555}, {
       4.3247595264191645`, -4.8125}, {
       4.437499981032941, -4.915707410443939}, {
       4.362222184858401, -4.902942858086555}}], 
      PolygonBox[{{4.437344993353523, -4.769748357463745}, {
       4.437499981032941, -4.915707410443939}, {
       4.3247595264191645`, -4.8125}, {
       4.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{4.3247595264191645`, -4.8125}, {
       4.265165042944956, -4.734834957055044}, {
       4.437344993353523, -4.769748357463745}, {
       4.3247595264191645`, -4.8125}}], 
      PolygonBox[{{4.404942744332997, -4.595057255667003}, {
       4.437344993353523, -4.769748357463745}, {
       4.265165042944956, -4.734834957055044}, {
       4.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{4.265165042944956, -4.734834957055044}, {
       4.1875, -4.6752404735808355`}, {
       4.404942744332997, -4.595057255667003}, {
       4.265165042944956, -4.734834957055044}}], 
      PolygonBox[{{4.230251642536255, -4.562655006646477}, {
       4.404942744332997, -4.595057255667003}, {
       4.1875, -4.6752404735808355`}, {
       4.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{4.1875, -4.6752404735808355`}, {
       4.097057141913445, -4.637777815141599}, {
       4.230251642536255, -4.562655006646477}, {
       4.1875, -4.6752404735808355`}}], 
      PolygonBox[{{4.0842925895560604`, -4.562500018967059}, {
       4.230251642536255, -4.562655006646477}, {
       4.097057141913445, -4.637777815141599}, {
       4.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{4.097057141913445, -4.637777815141599}, {4., -4.625}, {
       4.0842925895560604`, -4.562500018967059}, {
       4.097057141913445, -4.637777815141599}}], 
      PolygonBox[{{4.000105527220487, -4.5625}, {
       4.0842925895560604`, -4.562500018967059}, {4., -4.625}, {
       4.000105527220487, -4.5625}}], 
      PolygonBox[{{4., -4.625}, {3.902942858086555, -4.637777815141599}, {
       4.000105527220487, -4.5625}, {4., -4.625}}], 
      PolygonBox[{{3.915707410443943, -4.562500018967059}, {
       4.000105527220487, -4.5625}, {3.902942858086555, -4.637777815141599}, {
       3.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{3.902942858086555, -4.637777815141599}, {
       3.8125, -4.6752404735808355`}, {
       3.915707410443943, -4.562500018967059}, {
       3.902942858086555, -4.637777815141599}}], 
      PolygonBox[{{3.769748357463745, -4.562655006646477}, {
       3.915707410443943, -4.562500018967059}, {
       3.8125, -4.6752404735808355`}, {
       3.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{3.8125, -4.6752404735808355`}, {
       3.7348349570550448`, -4.734834957055044}, {
       3.769748357463745, -4.562655006646477}, {
       3.8125, -4.6752404735808355`}}], 
      PolygonBox[{{3.595057255667003, -4.595057255667003}, {
       3.769748357463745, -4.562655006646477}, {
       3.7348349570550448`, -4.734834957055044}, {
       3.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{3.7348349570550448`, -4.734834957055044}, {
       3.6752404735808355`, -4.8125}, {
       3.595057255667003, -4.595057255667003}, {
       3.7348349570550448`, -4.734834957055044}}], 
      PolygonBox[{{3.5626550066464766`, -4.769748357463745}, {
       3.595057255667003, -4.595057255667003}, {
       3.6752404735808355`, -4.8125}, {
       3.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{3.6752404735808355`, -4.8125}, {
       3.6377778151415994`, -4.902942858086554}, {
       3.5626550066464766`, -4.769748357463745}, {
       3.6752404735808355`, -4.8125}}], 
      PolygonBox[{{3.562500018967059, -4.915707410443938}, {
       3.5626550066464766`, -4.769748357463745}, {
       3.6377778151415994`, -4.902942858086554}, {
       3.562500018967059, -4.915707410443938}}], 
      PolygonBox[{{3.6377778151415994`, -4.902942858086554}, {3.625, -5.}, {
       3.562500018967059, -4.915707410443938}, {
       3.6377778151415994`, -4.902942858086554}}], 
      PolygonBox[{{3.5625, -4.999876821937004}, {
       3.562500018967059, -4.915707410443938}, {3.625, -5.}, {
       3.5625, -4.999876821937004}}], 
      PolygonBox[{{3.625, -5.}, {3.6377778151415994`, -5.097057141913445}, {
       3.5625, -4.999876821937004}, {3.625, -5.}}], 
      PolygonBox[{{3.562500018967059, -5.084292589556055}, {
       3.5625, -4.999876821937004}, {
       3.6377778151415994`, -5.097057141913445}, {
       3.562500018967059, -5.084292589556055}}], 
      PolygonBox[{{3.6377778151415994`, -5.097057141913445}, {
       3.6752404735808355`, -5.1875}, {
       3.562500018967059, -5.084292589556055}, {
       3.6377778151415994`, -5.097057141913445}}], 
      PolygonBox[{{3.5626550066464766`, -5.230251642536254}, {
       3.562500018967059, -5.084292589556055}, {
       3.6752404735808355`, -5.1875}, {
       3.5626550066464766`, -5.230251642536254}}], 
      PolygonBox[{{3.6752404735808355`, -5.1875}, {
       3.7348349570550448`, -5.265165042944956}, {
       3.5626550066464766`, -5.230251642536254}, {
       3.6752404735808355`, -5.1875}}], 
      PolygonBox[{{3.595057255667003, -5.404942744332997}, {
       3.5626550066464766`, -5.230251642536254}, {
       3.7348349570550448`, -5.265165042944956}, {
       3.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, -5.265165042944956}, {
       3.8125, -5.3247595264191645`}, {
       3.595057255667003, -5.404942744332997}, {
       3.7348349570550448`, -5.265165042944956}}], 
      PolygonBox[{{3.769748357463745, -5.437344993353523}, {
       3.595057255667003, -5.404942744332997}, {
       3.8125, -5.3247595264191645`}, {
       3.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{3.8125, -5.3247595264191645`}, {
       3.9029428580865546`, -5.362222184858401}, {
       3.769748357463745, -5.437344993353523}, {
       3.8125, -5.3247595264191645`}}], 
      PolygonBox[{{3.915707410443936, -5.437499981032941}, {
       3.769748357463745, -5.437344993353523}, {
       3.9029428580865546`, -5.362222184858401}, {
       3.915707410443936, -5.437499981032941}}], 
      PolygonBox[{{3.9029428580865546`, -5.362222184858401}, {4., -5.375}, {
       3.915707410443936, -5.437499981032941}, {
       3.9029428580865546`, -5.362222184858401}}], 
      PolygonBox[{{4.000134841831043, -5.4375}, {
       3.915707410443936, -5.437499981032941}, {4., -5.375}, {
       4.000134841831043, -5.4375}}], 
      PolygonBox[{{4., -5.375}, {4.097057141913445, -5.362222184858401}, {
       4.000134841831043, -5.4375}, {4., -5.375}}], 
      PolygonBox[{{4.084292589556053, -5.437499981032941}, {
       4.000134841831043, -5.4375}, {4.097057141913445, -5.362222184858401}, {
       4.084292589556053, -5.437499981032941}}], 
      PolygonBox[{{4.097057141913445, -5.362222184858401}, {
       4.1875, -5.3247595264191645`}, {
       4.084292589556053, -5.437499981032941}, {
       4.097057141913445, -5.362222184858401}}], 
      PolygonBox[{{4.230251642536254, -5.437344993353523}, {
       4.084292589556053, -5.437499981032941}, {
       4.1875, -5.3247595264191645`}, {
       4.230251642536254, -5.437344993353523}}], 
      PolygonBox[{{4.1875, -5.3247595264191645`}, {
       4.265165042944956, -5.265165042944956}, {
       4.230251642536254, -5.437344993353523}, {
       4.1875, -5.3247595264191645`}}], 
      PolygonBox[{{4.404942744332997, -5.404942744332997}, {
       4.230251642536254, -5.437344993353523}, {
       4.265165042944956, -5.265165042944956}, {
       4.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{4.265165042944956, -5.265165042944956}, {
       4.265165042944956, -5.265165042944956}, {
       4.404942744332997, -5.404942744332997}, {
       4.265165042944956, -5.265165042944956}}], 
      PolygonBox[{{4.404942744332997, -5.404942744332997}, {
       4.404942744332997, -5.404942744332997}, {
       4.265165042944956, -5.265165042944956}, {
       4.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{4.404942744332997, -5.404942744332997}, {
       4.437344993353523, -5.230251642536255}, {4.5, -5.5}, {
       4.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{4.5, -5.357662782649368}, {4.5, -5.5}, {
       4.437344993353523, -5.230251642536255}, {4.5, -5.357662782649368}}], 
      PolygonBox[{{4.437344993353523, -5.230251642536255}, {
       4.437499981032941, -5.084292589556062}, {4.5, -5.357662782649368}, {
       4.437344993353523, -5.230251642536255}}], 
      PolygonBox[{{4.5, -5.20590900530174}, {4.5, -5.357662782649368}, {
       4.437499981032941, -5.084292589556062}, {4.5, -5.20590900530174}}], 
      PolygonBox[{{4.437499981032941, -5.084292589556062}, {4.4375, -5.}, {
       4.5, -5.20590900530174}, {4.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{4.5, -5.}, {4.5, -5.20590900530174}, {4.4375, -5.}, {
       4.5, -5.}}], 
      PolygonBox[{{4.4375, -5.}, {4.437499981032941, -4.915707410443939}, {
       4.5, -5.}, {4.4375, -5.}}], 
      PolygonBox[{{4.5, -4.79409099469826}, {4.5, -5.}, {
       4.437499981032941, -4.915707410443939}, {4.5, -4.79409099469826}}], 
      PolygonBox[{{4.437499981032941, -4.915707410443939}, {
       4.437344993353523, -4.769748357463745}, {4.5, -4.79409099469826}, {
       4.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{4.5, -4.642337217350632}, {4.5, -4.79409099469826}, {
       4.437344993353523, -4.769748357463745}, {4.5, -4.642337217350632}}], 
      PolygonBox[{{4.437344993353523, -4.769748357463745}, {
       4.404942744332997, -4.595057255667003}, {4.5, -4.642337217350632}, {
       4.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{4.491446564961186, -4.508553435038814}, {
       4.5, -4.642337217350632}, {4.404942744332997, -4.595057255667003}, {
       4.491446564961186, -4.508553435038814}}], 
      PolygonBox[{{4.404942744332997, -4.595057255667003}, {
       4.230251642536255, -4.562655006646477}, {
       4.491446564961186, -4.508553435038814}, {
       4.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{4.357662782649368, -4.5}, {
       4.491446564961186, -4.508553435038814}, {
       4.230251642536255, -4.562655006646477}, {4.357662782649368, -4.5}}], 
      PolygonBox[{{4.230251642536255, -4.562655006646477}, {
       4.0842925895560604`, -4.562500018967059}, {4.357662782649368, -4.5}, {
       4.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{4.205909005373256, -4.5}, {4.357662782649368, -4.5}, {
       4.0842925895560604`, -4.562500018967059}, {4.205909005373256, -4.5}}], 
      PolygonBox[{{4.0842925895560604`, -4.562500018967059}, {
       4.000105527220487, -4.5625}, {4.205909005373256, -4.5}, {
       4.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{4.07794195802689, -4.5}, {4.205909005373256, -4.5}, {
       4.000105527220487, -4.5625}, {4.07794195802689, -4.5}}], 
      PolygonBox[{{4.000105527220487, -4.5625}, {
       3.915707410443943, -4.562500018967059}, {4.07794195802689, -4.5}, {
       4.000105527220487, -4.5625}}], 
      PolygonBox[{{3.7940909946955546`, -4.5}, {4.07794195802689, -4.5}, {
       3.915707410443943, -4.562500018967059}, {3.7940909946955546`, -4.5}}], 
      PolygonBox[{{3.915707410443943, -4.562500018967059}, {
       3.769748357463745, -4.562655006646477}, {3.7940909946955546`, -4.5}, {
       3.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{3.642337217350634, -4.5}, {3.7940909946955546`, -4.5}, {
       3.769748357463745, -4.562655006646477}, {3.642337217350634, -4.5}}], 
      PolygonBox[{{3.769748357463745, -4.562655006646477}, {
       3.595057255667003, -4.595057255667003}, {3.642337217350634, -4.5}, {
       3.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{4.5, -4.5}, {3.642337217350634, -4.5}, {
       3.595057255667003, -4.595057255667003}, {4.5, -4.5}}], 
      PolygonBox[{{3.595057255667003, -4.595057255667003}, {
       3.5626550066464766`, -4.769748357463745}, {4.5, -4.5}, {
       3.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{3.5, -4.642337217350631}, {4.5, -4.5}, {
       3.5626550066464766`, -4.769748357463745}, {3.5, -4.642337217350631}}], 
      PolygonBox[{{3.5626550066464766`, -4.769748357463745}, {
       3.562500018967059, -4.915707410443938}, {3.5, -4.642337217350631}, {
       3.5626550066464766`, -4.769748357463745}}], 
      PolygonBox[{{3.5, -4.794090994717101}, {3.5, -4.642337217350631}, {
       3.562500018967059, -4.915707410443938}, {3.5, -4.794090994717101}}], 
      PolygonBox[{{3.562500018967059, -4.915707410443938}, {
       3.5625, -4.999876821937004}, {3.5, -4.794090994717101}, {
       3.562500018967059, -4.915707410443938}}], 
      PolygonBox[{{3.5, -4.9193213332412995`}, {3.5, -4.794090994717101}, {
       3.5625, -4.999876821937004}, {3.5, -4.9193213332412995`}}], 
      PolygonBox[{{3.5625, -4.999876821937004}, {
       3.562500018967059, -5.084292589556055}, {3.5, -4.9193213332412995`}, {
       3.5625, -4.999876821937004}}], 
      PolygonBox[{{3.5, -5.205909005145278}, {3.5, -4.9193213332412995`}, {
       3.562500018967059, -5.084292589556055}, {3.5, -5.205909005145278}}], 
      PolygonBox[{{3.562500018967059, -5.084292589556055}, {
       3.5626550066464766`, -5.230251642536254}, {3.5, -5.205909005145278}, {
       3.562500018967059, -5.084292589556055}}], 
      PolygonBox[{{3.5, -5.357662782649365}, {3.5, -5.205909005145278}, {
       3.5626550066464766`, -5.230251642536254}, {3.5, -5.357662782649365}}], 
      PolygonBox[{{3.5626550066464766`, -5.230251642536254}, {
       3.595057255667003, -5.404942744332997}, {3.5, -5.357662782649365}, {
       3.5626550066464766`, -5.230251642536254}}], 
      PolygonBox[{{3.5, -4.5}, {3.5, -5.357662782649365}, {
       3.595057255667003, -5.404942744332997}, {3.5, -4.5}}], 
      PolygonBox[{{3.595057255667003, -5.404942744332997}, {
       3.769748357463745, -5.437344993353523}, {3.5, -4.5}, {
       3.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{3.5, -5.5}, {3.5, -4.5}, {
       3.769748357463745, -5.437344993353523}, {3.5, -5.5}}], 
      PolygonBox[{{3.769748357463745, -5.437344993353523}, {
       3.915707410443936, -5.437499981032941}, {3.5, -5.5}, {
       3.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{3.794090994433172, -5.5}, {3.5, -5.5}, {
       3.915707410443936, -5.437499981032941}, {3.794090994433172, -5.5}}], 
      PolygonBox[{{3.915707410443936, -5.437499981032941}, {
       4.000134841831043, -5.4375}, {3.794090994433172, -5.5}, {
       3.915707410443936, -5.437499981032941}}], 
      PolygonBox[{{4.082323870401062, -5.5}, {3.794090994433172, -5.5}, {
       4.000134841831043, -5.4375}, {4.082323870401062, -5.5}}], 
      PolygonBox[{{4.000134841831043, -5.4375}, {
       4.084292589556053, -5.437499981032941}, {4.082323870401062, -5.5}, {
       4.000134841831043, -5.4375}}], 
      PolygonBox[{{4.205909005360398, -5.5}, {4.082323870401062, -5.5}, {
       4.084292589556053, -5.437499981032941}, {4.205909005360398, -5.5}}], 
      PolygonBox[{{4.084292589556053, -5.437499981032941}, {
       4.230251642536254, -5.437344993353523}, {4.205909005360398, -5.5}, {
       4.084292589556053, -5.437499981032941}}], 
      PolygonBox[{{4.3576627826493715`, -5.5}, {4.205909005360398, -5.5}, {
       4.230251642536254, -5.437344993353523}, {4.3576627826493715`, -5.5}}], 
      PolygonBox[{{4.230251642536254, -5.437344993353523}, {
       4.404942744332997, -5.404942744332997}, {4.3576627826493715`, -5.5}, {
       4.230251642536254, -5.437344993353523}}], 
      PolygonBox[{{4.5, -5.5}, {4.3576627826493715`, -5.5}, {
       4.404942744332997, -5.404942744332997}, {4.5, -5.5}}], 
      PolygonBox[{{4.404942744332997, -5.404942744332997}, {
       4.404942744332997, -5.404942744332997}, {4.5, -5.5}, {
       4.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{4.5, -5.5}, {4.5, -5.5}, {
       4.404942744332997, -5.404942744332997}, {4.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, -4.}, {3.5208333333333335`, -4.}, {
       3.5416666666666665`, -4.}, {3.5625, -4.}, {3.5833333333333335`, -4.}, {
       3.6041666666666665`, -4.}, {3.625, -4.}, {3.625, -4.}, {
       3.6041666666666665`, -4.}, {3.5833333333333335`, -4.}, {3.5625, -4.}, {
       3.5416666666666665`, -4.}, {3.5208333333333335`, -4.}, {3.5, -4.}, {
       3.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, -4.}, {4.395833333333333, -4.}, {
       4.416666666666667, -4.}, {4.4375, -4.}, {4.458333333333333, -4.}, {
       4.479166666666667, -4.}, {4.5, -4.}, {4.5, -4.}, {
       4.479166666666667, -4.}, {4.458333333333333, -4.}, {4.4375, -4.}, {
       4.416666666666667, -4.}, {4.395833333333333, -4.}, {4.375, -4.}, {
       4.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -4.5}, {4., -4.479166666666667}, {
       4., -4.458333333333333}, {4., -4.4375}, {4., -4.416666666666667}, {
       4., -4.395833333333333}, {4., -4.375}, {4., -4.375}, {
       4., -4.395833333333333}, {4., -4.416666666666667}, {4., -4.4375}, {
       4., -4.458333333333333}, {4., -4.479166666666667}, {4., -4.5}, {
       4., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -3.625}, {4., -3.6041666666666665`}, {
       4., -3.5833333333333335`}, {4., -3.5625}, {4., -3.5416666666666665`}, {
       4., -3.5208333333333335`}, {4., -3.5}, {4., -3.5}, {
       4., -3.5208333333333335`}, {4., -3.5416666666666665`}, {4., -3.5625}, {
       4., -3.5833333333333335`}, {4., -3.6041666666666665`}, {4., -3.625}, {
       4., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, -4.}, {3.75, -4.}, {3.875, -4.}, {4., -4.}, {
       4.125, -4.}, {4.25, -4.}, {4.375, -4.}, {4.375, -4.}, {4.25, -4.}, {
       4.125, -4.}, {4., -4.}, {3.875, -4.}, {3.75, -4.}, {3.625, -4.}, {
       3.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -4.375}, {4., -4.25}, {4., -4.125}, {4., -4.}, {
       4., -3.875}, {4., -3.75}, {4., -3.625}, {4., -3.625}, {4., -3.75}, {
       4., -3.875}, {4., -4.}, {4., -4.125}, {4., -4.25}, {4., -4.375}, {
       4., -4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4QhsCBrxnh8a+KBB02Sr+VsrLkPzBD+cmh
Xh+ofAPfgXPfzua08ws6pAqlqH18wHsALH5AwOHCDvOqJ2m8B9SLOj8lJQs4
iOkFOmpLQeUZBKDm8x6Amosq38AH1w81F24+VBxuP1Qf3H1Qc+Huh8lD3YGq
/4DAgRSo+Wch/oDbD/Un3H3QcEB1f4Mg3H8o8kD/w/TDwgdKo4bfAUT4akDd
hx7+ACSsf2s=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhCa50AoGAjC+atXgYAAnA+hBdDk+eD8MLB+
XjT1PAT5EHt54XyouWjqBdDkBdD0C6KpF8Lgh6K4TwjN/TD1AmjyAmj6BdHU
CxHko7pPCM39MPUCaPJ8cH4YSvgg4gsAEMBQ8A==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, -4.265165042944956}, {
       4.3247595264191645`, -4.1875}, {
       4.404942744332997, -4.404942744332997}, {
       4.265165042944956, -4.265165042944956}}], 
      PolygonBox[{{4.437344993353523, -4.230251642536255}, {
       4.404942744332997, -4.404942744332997}, {
       4.3247595264191645`, -4.1875}, {
       4.437344993353523, -4.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, -4.1875}, {
       4.362222184858401, -4.097057141913445}, {
       4.437344993353523, -4.230251642536255}, {
       4.3247595264191645`, -4.1875}}], 
      PolygonBox[{{4.437499981032941, -4.084292589556062}, {
       4.437344993353523, -4.230251642536255}, {
       4.362222184858401, -4.097057141913445}, {
       4.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{4.362222184858401, -4.097057141913445}, {4.375, -4.}, {
       4.437499981032941, -4.084292589556062}, {
       4.362222184858401, -4.097057141913445}}], 
      PolygonBox[{{4.4375, -4.}, {4.437499981032941, -4.084292589556062}, {
       4.375, -4.}, {4.4375, -4.}}], 
      PolygonBox[{{4.375, -4.}, {4.362222184858401, -3.9029428580865546`}, {
       4.4375, -4.}, {4.375, -4.}}], 
      PolygonBox[{{4.437499981032941, -3.915707410443938}, {4.4375, -4.}, {
       4.362222184858401, -3.9029428580865546`}, {
       4.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{4.362222184858401, -3.9029428580865546`}, {
       4.3247595264191645`, -3.8125}, {
       4.437499981032941, -3.915707410443938}, {
       4.362222184858401, -3.9029428580865546`}}], 
      PolygonBox[{{4.437344993353523, -3.769748357463745}, {
       4.437499981032941, -3.915707410443938}, {
       4.3247595264191645`, -3.8125}, {
       4.437344993353523, -3.769748357463745}}], 
      PolygonBox[{{4.3247595264191645`, -3.8125}, {
       4.265165042944956, -3.7348349570550448`}, {
       4.437344993353523, -3.769748357463745}, {
       4.3247595264191645`, -3.8125}}], 
      PolygonBox[{{4.404942744332997, -3.595057255667003}, {
       4.437344993353523, -3.769748357463745}, {
       4.265165042944956, -3.7348349570550448`}, {
       4.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{4.265165042944956, -3.7348349570550448`}, {
       4.1875, -3.6752404735808355`}, {
       4.404942744332997, -3.595057255667003}, {
       4.265165042944956, -3.7348349570550448`}}], 
      PolygonBox[{{4.230251642536255, -3.5626550066464766`}, {
       4.404942744332997, -3.595057255667003}, {
       4.1875, -3.6752404735808355`}, {
       4.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{4.1875, -3.6752404735808355`}, {
       4.097057141913445, -3.6377778151415994`}, {
       4.230251642536255, -3.5626550066464766`}, {
       4.1875, -3.6752404735808355`}}], 
      PolygonBox[{{4.0842925895560604`, -3.562500018967059}, {
       4.230251642536255, -3.5626550066464766`}, {
       4.097057141913445, -3.6377778151415994`}, {
       4.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{4.097057141913445, -3.6377778151415994`}, {4., -3.625}, {
       4.0842925895560604`, -3.562500018967059}, {
       4.097057141913445, -3.6377778151415994`}}], 
      PolygonBox[{{4.000105527220487, -3.5625}, {
       4.0842925895560604`, -3.562500018967059}, {4., -3.625}, {
       4.000105527220487, -3.5625}}], 
      PolygonBox[{{4., -3.625}, {3.902942858086555, -3.6377778151415994`}, {
       4.000105527220487, -3.5625}, {4., -3.625}}], 
      PolygonBox[{{3.915707410443943, -3.562500018967059}, {
       4.000105527220487, -3.5625}, {
       3.902942858086555, -3.6377778151415994`}, {
       3.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{3.902942858086555, -3.6377778151415994`}, {
       3.8125, -3.6752404735808355`}, {
       3.915707410443943, -3.562500018967059}, {
       3.902942858086555, -3.6377778151415994`}}], 
      PolygonBox[{{3.769748357463745, -3.5626550066464766`}, {
       3.915707410443943, -3.562500018967059}, {
       3.8125, -3.6752404735808355`}, {
       3.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{3.8125, -3.6752404735808355`}, {
       3.7348349570550448`, -3.7348349570550448`}, {
       3.769748357463745, -3.5626550066464766`}, {
       3.8125, -3.6752404735808355`}}], 
      PolygonBox[{{3.595057255667003, -3.595057255667003}, {
       3.769748357463745, -3.5626550066464766`}, {
       3.7348349570550448`, -3.7348349570550448`}, {
       3.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{3.7348349570550448`, -3.7348349570550448`}, {
       3.6752404735808355`, -3.8125}, {
       3.595057255667003, -3.595057255667003}, {
       3.7348349570550448`, -3.7348349570550448`}}], 
      PolygonBox[{{3.5626550066464766`, -3.7697483574637447`}, {
       3.595057255667003, -3.595057255667003}, {
       3.6752404735808355`, -3.8125}, {
       3.5626550066464766`, -3.7697483574637447`}}], 
      PolygonBox[{{3.6752404735808355`, -3.8125}, {
       3.6377778151415994`, -3.9029428580865546`}, {
       3.5626550066464766`, -3.7697483574637447`}, {
       3.6752404735808355`, -3.8125}}], 
      PolygonBox[{{3.562500018967059, -3.9157074104439378`}, {
       3.5626550066464766`, -3.7697483574637447`}, {
       3.6377778151415994`, -3.9029428580865546`}, {
       3.562500018967059, -3.9157074104439378`}}], 
      PolygonBox[{{3.6377778151415994`, -3.9029428580865546`}, {3.625, -4.}, {
       3.562500018967059, -3.9157074104439378`}, {
       3.6377778151415994`, -3.9029428580865546`}}], 
      PolygonBox[{{3.5625, -3.9998768219370047`}, {
       3.562500018967059, -3.9157074104439378`}, {3.625, -4.}, {
       3.5625, -3.9998768219370047`}}], 
      PolygonBox[{{3.625, -4.}, {3.6377778151415994`, -4.097057141913445}, {
       3.5625, -3.9998768219370047`}, {3.625, -4.}}], 
      PolygonBox[{{3.562500018967059, -4.084292589556055}, {
       3.5625, -3.9998768219370047`}, {
       3.6377778151415994`, -4.097057141913445}, {
       3.562500018967059, -4.084292589556055}}], 
      PolygonBox[{{3.6377778151415994`, -4.097057141913445}, {
       3.6752404735808355`, -4.1875}, {
       3.562500018967059, -4.084292589556055}, {
       3.6377778151415994`, -4.097057141913445}}], 
      PolygonBox[{{3.5626550066464766`, -4.230251642536254}, {
       3.562500018967059, -4.084292589556055}, {
       3.6752404735808355`, -4.1875}, {
       3.5626550066464766`, -4.230251642536254}}], 
      PolygonBox[{{3.6752404735808355`, -4.1875}, {
       3.7348349570550448`, -4.265165042944956}, {
       3.5626550066464766`, -4.230251642536254}, {
       3.6752404735808355`, -4.1875}}], 
      PolygonBox[{{3.595057255667003, -4.404942744332997}, {
       3.5626550066464766`, -4.230251642536254}, {
       3.7348349570550448`, -4.265165042944956}, {
       3.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, -4.265165042944956}, {
       3.8125, -4.3247595264191645`}, {
       3.595057255667003, -4.404942744332997}, {
       3.7348349570550448`, -4.265165042944956}}], 
      PolygonBox[{{3.769748357463745, -4.437344993353523}, {
       3.595057255667003, -4.404942744332997}, {
       3.8125, -4.3247595264191645`}, {
       3.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{3.8125, -4.3247595264191645`}, {
       3.9029428580865546`, -4.362222184858401}, {
       3.769748357463745, -4.437344993353523}, {
       3.8125, -4.3247595264191645`}}], 
      PolygonBox[{{3.915707410443936, -4.437499981032941}, {
       3.769748357463745, -4.437344993353523}, {
       3.9029428580865546`, -4.362222184858401}, {
       3.915707410443936, -4.437499981032941}}], 
      PolygonBox[{{3.9029428580865546`, -4.362222184858401}, {4., -4.375}, {
       3.915707410443936, -4.437499981032941}, {
       3.9029428580865546`, -4.362222184858401}}], 
      PolygonBox[{{4.000134841831043, -4.4375}, {
       3.915707410443936, -4.437499981032941}, {4., -4.375}, {
       4.000134841831043, -4.4375}}], 
      PolygonBox[{{4., -4.375}, {4.097057141913445, -4.362222184858401}, {
       4.000134841831043, -4.4375}, {4., -4.375}}], 
      PolygonBox[{{4.084292589556053, -4.437499981032941}, {
       4.000134841831043, -4.4375}, {4.097057141913445, -4.362222184858401}, {
       4.084292589556053, -4.437499981032941}}], 
      PolygonBox[{{4.097057141913445, -4.362222184858401}, {
       4.1875, -4.3247595264191645`}, {
       4.084292589556053, -4.437499981032941}, {
       4.097057141913445, -4.362222184858401}}], 
      PolygonBox[{{4.230251642536254, -4.437344993353523}, {
       4.084292589556053, -4.437499981032941}, {
       4.1875, -4.3247595264191645`}, {
       4.230251642536254, -4.437344993353523}}], 
      PolygonBox[{{4.1875, -4.3247595264191645`}, {
       4.265165042944956, -4.265165042944956}, {
       4.230251642536254, -4.437344993353523}, {
       4.1875, -4.3247595264191645`}}], 
      PolygonBox[{{4.404942744332997, -4.404942744332997}, {
       4.230251642536254, -4.437344993353523}, {
       4.265165042944956, -4.265165042944956}, {
       4.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{4.265165042944956, -4.265165042944956}, {
       4.265165042944956, -4.265165042944956}, {
       4.404942744332997, -4.404942744332997}, {
       4.265165042944956, -4.265165042944956}}], 
      PolygonBox[{{4.404942744332997, -4.404942744332997}, {
       4.404942744332997, -4.404942744332997}, {
       4.265165042944956, -4.265165042944956}, {
       4.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{4.404942744332997, -4.404942744332997}, {
       4.437344993353523, -4.230251642536255}, {4.5, -4.5}, {
       4.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{4.5, -4.357662782649368}, {4.5, -4.5}, {
       4.437344993353523, -4.230251642536255}, {4.5, -4.357662782649368}}], 
      PolygonBox[{{4.437344993353523, -4.230251642536255}, {
       4.437499981032941, -4.084292589556062}, {4.5, -4.357662782649368}, {
       4.437344993353523, -4.230251642536255}}], 
      PolygonBox[{{4.5, -4.20590900530174}, {4.5, -4.357662782649368}, {
       4.437499981032941, -4.084292589556062}, {4.5, -4.20590900530174}}], 
      PolygonBox[{{4.437499981032941, -4.084292589556062}, {4.4375, -4.}, {
       4.5, -4.20590900530174}, {4.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{4.5, -4.}, {4.5, -4.20590900530174}, {4.4375, -4.}, {
       4.5, -4.}}], 
      PolygonBox[{{4.4375, -4.}, {4.437499981032941, -3.915707410443938}, {
       4.5, -4.}, {4.4375, -4.}}], 
      PolygonBox[{{4.5, -3.79409099469826}, {4.5, -4.}, {
       4.437499981032941, -3.915707410443938}, {4.5, -3.79409099469826}}], 
      PolygonBox[{{4.437499981032941, -3.915707410443938}, {
       4.437344993353523, -3.769748357463745}, {4.5, -3.79409099469826}, {
       4.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{4.5, -3.6423372173506325`}, {4.5, -3.79409099469826}, {
       4.437344993353523, -3.769748357463745}, {4.5, -3.6423372173506325`}}], 
      PolygonBox[{{4.437344993353523, -3.769748357463745}, {
       4.404942744332997, -3.595057255667003}, {4.5, -3.6423372173506325`}, {
       4.437344993353523, -3.769748357463745}}], 
      PolygonBox[{{4.491446564961186, -3.508553435038814}, {
       4.5, -3.6423372173506325`}, {4.404942744332997, -3.595057255667003}, {
       4.491446564961186, -3.508553435038814}}], 
      PolygonBox[{{4.404942744332997, -3.595057255667003}, {
       4.230251642536255, -3.5626550066464766`}, {
       4.491446564961186, -3.508553435038814}, {
       4.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{4.357662782649368, -3.5}, {
       4.491446564961186, -3.508553435038814}, {
       4.230251642536255, -3.5626550066464766`}, {4.357662782649368, -3.5}}], 
      PolygonBox[{{4.230251642536255, -3.5626550066464766`}, {
       4.0842925895560604`, -3.562500018967059}, {4.357662782649368, -3.5}, {
       4.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{4.205909005373256, -3.5}, {4.357662782649368, -3.5}, {
       4.0842925895560604`, -3.562500018967059}, {4.205909005373256, -3.5}}], 
      PolygonBox[{{4.0842925895560604`, -3.562500018967059}, {
       4.000105527220487, -3.5625}, {4.205909005373256, -3.5}, {
       4.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{4.07794195802689, -3.5}, {4.205909005373256, -3.5}, {
       4.000105527220487, -3.5625}, {4.07794195802689, -3.5}}], 
      PolygonBox[{{4.000105527220487, -3.5625}, {
       3.915707410443943, -3.562500018967059}, {4.07794195802689, -3.5}, {
       4.000105527220487, -3.5625}}], 
      PolygonBox[{{3.7940909946955546`, -3.5}, {4.07794195802689, -3.5}, {
       3.915707410443943, -3.562500018967059}, {3.7940909946955546`, -3.5}}], 
      PolygonBox[{{3.915707410443943, -3.562500018967059}, {
       3.769748357463745, -3.5626550066464766`}, {
       3.7940909946955546`, -3.5}, {3.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{3.642337217350634, -3.5}, {3.7940909946955546`, -3.5}, {
       3.769748357463745, -3.5626550066464766`}, {3.642337217350634, -3.5}}], 
      PolygonBox[{{3.769748357463745, -3.5626550066464766`}, {
       3.595057255667003, -3.595057255667003}, {3.642337217350634, -3.5}, {
       3.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{4.5, -3.5}, {3.642337217350634, -3.5}, {
       3.595057255667003, -3.595057255667003}, {4.5, -3.5}}], 
      PolygonBox[{{3.595057255667003, -3.595057255667003}, {
       3.5626550066464766`, -3.7697483574637447`}, {4.5, -3.5}, {
       3.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{3.5, -3.642337217350631}, {4.5, -3.5}, {
       3.5626550066464766`, -3.7697483574637447`}, {
       3.5, -3.642337217350631}}], 
      PolygonBox[{{3.5626550066464766`, -3.7697483574637447`}, {
       3.562500018967059, -3.9157074104439378`}, {3.5, -3.642337217350631}, {
       3.5626550066464766`, -3.7697483574637447`}}], 
      PolygonBox[{{3.5, -3.794090994717101}, {3.5, -3.642337217350631}, {
       3.562500018967059, -3.9157074104439378`}, {3.5, -3.794090994717101}}], 
      PolygonBox[{{3.562500018967059, -3.9157074104439378`}, {
       3.5625, -3.9998768219370047`}, {3.5, -3.794090994717101}, {
       3.562500018967059, -3.9157074104439378`}}], 
      PolygonBox[{{3.5, -3.9193213332413}, {3.5, -3.794090994717101}, {
       3.5625, -3.9998768219370047`}, {3.5, -3.9193213332413}}], 
      PolygonBox[{{3.5625, -3.9998768219370047`}, {
       3.562500018967059, -4.084292589556055}, {3.5, -3.9193213332413}, {
       3.5625, -3.9998768219370047`}}], 
      PolygonBox[{{3.5, -4.205909005145278}, {3.5, -3.9193213332413}, {
       3.562500018967059, -4.084292589556055}, {3.5, -4.205909005145278}}], 
      PolygonBox[{{3.562500018967059, -4.084292589556055}, {
       3.5626550066464766`, -4.230251642536254}, {3.5, -4.205909005145278}, {
       3.562500018967059, -4.084292589556055}}], 
      PolygonBox[{{3.5, -4.357662782649365}, {3.5, -4.205909005145278}, {
       3.5626550066464766`, -4.230251642536254}, {3.5, -4.357662782649365}}], 
      PolygonBox[{{3.5626550066464766`, -4.230251642536254}, {
       3.595057255667003, -4.404942744332997}, {3.5, -4.357662782649365}, {
       3.5626550066464766`, -4.230251642536254}}], 
      PolygonBox[{{3.5, -3.5}, {3.5, -4.357662782649365}, {
       3.595057255667003, -4.404942744332997}, {3.5, -3.5}}], 
      PolygonBox[{{3.595057255667003, -4.404942744332997}, {
       3.769748357463745, -4.437344993353523}, {3.5, -3.5}, {
       3.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{3.5, -4.5}, {3.5, -3.5}, {
       3.769748357463745, -4.437344993353523}, {3.5, -4.5}}], 
      PolygonBox[{{3.769748357463745, -4.437344993353523}, {
       3.915707410443936, -4.437499981032941}, {3.5, -4.5}, {
       3.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{3.794090994433172, -4.5}, {3.5, -4.5}, {
       3.915707410443936, -4.437499981032941}, {3.794090994433172, -4.5}}], 
      PolygonBox[{{3.915707410443936, -4.437499981032941}, {
       4.000134841831043, -4.4375}, {3.794090994433172, -4.5}, {
       3.915707410443936, -4.437499981032941}}], 
      PolygonBox[{{4.082323870401062, -4.5}, {3.794090994433172, -4.5}, {
       4.000134841831043, -4.4375}, {4.082323870401062, -4.5}}], 
      PolygonBox[{{4.000134841831043, -4.4375}, {
       4.084292589556053, -4.437499981032941}, {4.082323870401062, -4.5}, {
       4.000134841831043, -4.4375}}], 
      PolygonBox[{{4.205909005360398, -4.5}, {4.082323870401062, -4.5}, {
       4.084292589556053, -4.437499981032941}, {4.205909005360398, -4.5}}], 
      PolygonBox[{{4.084292589556053, -4.437499981032941}, {
       4.230251642536254, -4.437344993353523}, {4.205909005360398, -4.5}, {
       4.084292589556053, -4.437499981032941}}], 
      PolygonBox[{{4.3576627826493715`, -4.5}, {4.205909005360398, -4.5}, {
       4.230251642536254, -4.437344993353523}, {4.3576627826493715`, -4.5}}], 
      PolygonBox[{{4.230251642536254, -4.437344993353523}, {
       4.404942744332997, -4.404942744332997}, {4.3576627826493715`, -4.5}, {
       4.230251642536254, -4.437344993353523}}], 
      PolygonBox[{{4.5, -4.5}, {4.3576627826493715`, -4.5}, {
       4.404942744332997, -4.404942744332997}, {4.5, -4.5}}], 
      PolygonBox[{{4.404942744332997, -4.404942744332997}, {
       4.404942744332997, -4.404942744332997}, {4.5, -4.5}, {
       4.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{4.5, -4.5}, {4.5, -4.5}, {
       4.404942744332997, -4.404942744332997}, {4.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, -3.}, {3.5208333333333335`, -3.}, {
       3.5416666666666665`, -3.}, {3.5625, -3.}, {3.5833333333333335`, -3.}, {
       3.6041666666666665`, -3.}, {3.625, -3.}, {3.625, -3.}, {
       3.6041666666666665`, -3.}, {3.5833333333333335`, -3.}, {3.5625, -3.}, {
       3.5416666666666665`, -3.}, {3.5208333333333335`, -3.}, {3.5, -3.}, {
       3.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, -3.}, {4.395833333333333, -3.}, {
       4.416666666666667, -3.}, {4.4375, -3.}, {4.458333333333333, -3.}, {
       4.479166666666667, -3.}, {4.5, -3.}, {4.5, -3.}, {
       4.479166666666667, -3.}, {4.458333333333333, -3.}, {4.4375, -3.}, {
       4.416666666666667, -3.}, {4.395833333333333, -3.}, {4.375, -3.}, {
       4.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -3.5}, {4., -3.4791666666666665`}, {
       4., -3.4583333333333335`}, {4., -3.4375}, {4., -3.4166666666666665`}, {
       4., -3.3958333333333335`}, {4., -3.375}, {4., -3.375}, {
       4., -3.3958333333333335`}, {4., -3.4166666666666665`}, {4., -3.4375}, {
       4., -3.4583333333333335`}, {4., -3.4791666666666665`}, {4., -3.5}, {
       4., -3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -2.625}, {4., -2.6041666666666665`}, {
       4., -2.5833333333333335`}, {4., -2.5625}, {4., -2.5416666666666665`}, {
       4., -2.5208333333333335`}, {4., -2.5}, {4., -2.5}, {
       4., -2.5208333333333335`}, {4., -2.5416666666666665`}, {4., -2.5625}, {
       4., -2.5833333333333335`}, {4., -2.6041666666666665`}, {4., -2.625}, {
       4., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, -3.}, {3.75, -3.}, {3.875, -3.}, {4., -3.}, {
       4.125, -3.}, {4.25, -3.}, {4.375, -3.}, {4.375, -3.}, {4.25, -3.}, {
       4.125, -3.}, {4., -3.}, {3.875, -3.}, {3.75, -3.}, {3.625, -3.}, {
       3.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -3.375}, {4., -3.25}, {4., -3.125}, {4., -3.}, {
       4., -2.875}, {4., -2.75}, {4., -2.625}, {4., -2.625}, {4., -2.75}, {
       4., -2.875}, {4., -3.}, {4., -3.125}, {4., -3.25}, {4., -3.375}, {
       4., -3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4QBseBrxnh8a+KBB02Sr+VsrJkPzBD+cmh
Xh+ofAPbgXPfzua08ws6pAqlqH18wHoALH5AwOHCDvOqJ2msB9SLOj8lJQs4
iOkFOmpLQeUZBKDmsx6AmMuPKt/AB9cPMZcXbj5EnBduP0QfL9x9EHN54e6H
yfs9EXp69BgHmn7OAylQ82e/nX2TT54Lbr+B+4lW6ZlccPe9urhu35WnXGju
54b7D0Ue6H+Yflj4wMxHDT9OePj6Q92HHv4ADjp/7g==
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhCa5UAoGAjC+atXgYAAnA+hBdDk+eD8MLB+
XjT1PAT5EHtZ4XyIuWxo6jnQ1HPC+WDlq7jQ1PNg8ENR3MeD5n6YegE0eQE0
/YJo6oUI8lejuE8Izf0w9Rxo6tng/DCU8EHEFwBe5VAl
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, -3.2651650429449552`}, {
       4.3247595264191645`, -3.1875}, {
       4.404942744332997, -3.404942744332997}, {
       4.265165042944956, -3.2651650429449552`}}], 
      PolygonBox[{{4.437344993353523, -3.2302516425362553`}, {
       4.404942744332997, -3.404942744332997}, {
       4.3247595264191645`, -3.1875}, {
       4.437344993353523, -3.2302516425362553`}}], 
      PolygonBox[{{4.3247595264191645`, -3.1875}, {
       4.362222184858401, -3.0970571419134454`}, {
       4.437344993353523, -3.2302516425362553`}, {
       4.3247595264191645`, -3.1875}}], 
      PolygonBox[{{4.437499981032941, -3.084292589556062}, {
       4.437344993353523, -3.2302516425362553`}, {
       4.362222184858401, -3.0970571419134454`}, {
       4.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{4.362222184858401, -3.0970571419134454`}, {4.375, -3.}, {
       4.437499981032941, -3.084292589556062}, {
       4.362222184858401, -3.0970571419134454`}}], 
      PolygonBox[{{4.4375, -3.}, {4.437499981032941, -3.084292589556062}, {
       4.375, -3.}, {4.4375, -3.}}], 
      PolygonBox[{{4.375, -3.}, {4.362222184858401, -2.9029428580865546`}, {
       4.4375, -3.}, {4.375, -3.}}], 
      PolygonBox[{{4.437499981032941, -2.915707410443938}, {4.4375, -3.}, {
       4.362222184858401, -2.9029428580865546`}, {
       4.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{4.362222184858401, -2.9029428580865546`}, {
       4.3247595264191645`, -2.8125}, {
       4.437499981032941, -2.915707410443938}, {
       4.362222184858401, -2.9029428580865546`}}], 
      PolygonBox[{{4.437344993353523, -2.769748357463745}, {
       4.437499981032941, -2.915707410443938}, {
       4.3247595264191645`, -2.8125}, {
       4.437344993353523, -2.769748357463745}}], 
      PolygonBox[{{4.3247595264191645`, -2.8125}, {
       4.265165042944956, -2.7348349570550448`}, {
       4.437344993353523, -2.769748357463745}, {
       4.3247595264191645`, -2.8125}}], 
      PolygonBox[{{4.404942744332997, -2.595057255667003}, {
       4.437344993353523, -2.769748357463745}, {
       4.265165042944956, -2.7348349570550448`}, {
       4.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{4.265165042944956, -2.7348349570550448`}, {
       4.1875, -2.6752404735808355`}, {
       4.404942744332997, -2.595057255667003}, {
       4.265165042944956, -2.7348349570550448`}}], 
      PolygonBox[{{4.230251642536255, -2.5626550066464766`}, {
       4.404942744332997, -2.595057255667003}, {
       4.1875, -2.6752404735808355`}, {
       4.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{4.1875, -2.6752404735808355`}, {
       4.097057141913445, -2.6377778151415994`}, {
       4.230251642536255, -2.5626550066464766`}, {
       4.1875, -2.6752404735808355`}}], 
      PolygonBox[{{4.0842925895560604`, -2.562500018967059}, {
       4.230251642536255, -2.5626550066464766`}, {
       4.097057141913445, -2.6377778151415994`}, {
       4.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{4.097057141913445, -2.6377778151415994`}, {4., -2.625}, {
       4.0842925895560604`, -2.562500018967059}, {
       4.097057141913445, -2.6377778151415994`}}], 
      PolygonBox[{{4.000105527220487, -2.5625}, {
       4.0842925895560604`, -2.562500018967059}, {4., -2.625}, {
       4.000105527220487, -2.5625}}], 
      PolygonBox[{{4., -2.625}, {3.902942858086555, -2.6377778151415994`}, {
       4.000105527220487, -2.5625}, {4., -2.625}}], 
      PolygonBox[{{3.915707410443943, -2.562500018967059}, {
       4.000105527220487, -2.5625}, {
       3.902942858086555, -2.6377778151415994`}, {
       3.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{3.902942858086555, -2.6377778151415994`}, {
       3.8125, -2.6752404735808355`}, {
       3.915707410443943, -2.562500018967059}, {
       3.902942858086555, -2.6377778151415994`}}], 
      PolygonBox[{{3.769748357463745, -2.5626550066464766`}, {
       3.915707410443943, -2.562500018967059}, {
       3.8125, -2.6752404735808355`}, {
       3.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{3.8125, -2.6752404735808355`}, {
       3.7348349570550448`, -2.7348349570550448`}, {
       3.769748357463745, -2.5626550066464766`}, {
       3.8125, -2.6752404735808355`}}], 
      PolygonBox[{{3.595057255667003, -2.595057255667003}, {
       3.769748357463745, -2.5626550066464766`}, {
       3.7348349570550448`, -2.7348349570550448`}, {
       3.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{3.7348349570550448`, -2.7348349570550448`}, {
       3.6752404735808355`, -2.8125}, {
       3.595057255667003, -2.595057255667003}, {
       3.7348349570550448`, -2.7348349570550448`}}], 
      PolygonBox[{{3.5626550066464766`, -2.7697483574637447`}, {
       3.595057255667003, -2.595057255667003}, {
       3.6752404735808355`, -2.8125}, {
       3.5626550066464766`, -2.7697483574637447`}}], 
      PolygonBox[{{3.6752404735808355`, -2.8125}, {
       3.6377778151415994`, -2.9029428580865546`}, {
       3.5626550066464766`, -2.7697483574637447`}, {
       3.6752404735808355`, -2.8125}}], 
      PolygonBox[{{3.562500018967059, -2.9157074104439378`}, {
       3.5626550066464766`, -2.7697483574637447`}, {
       3.6377778151415994`, -2.9029428580865546`}, {
       3.562500018967059, -2.9157074104439378`}}], 
      PolygonBox[{{3.6377778151415994`, -2.9029428580865546`}, {3.625, -3.}, {
       3.562500018967059, -2.9157074104439378`}, {
       3.6377778151415994`, -2.9029428580865546`}}], 
      PolygonBox[{{3.5625, -2.9998768219370047`}, {
       3.562500018967059, -2.9157074104439378`}, {3.625, -3.}, {
       3.5625, -2.9998768219370047`}}], 
      PolygonBox[{{3.625, -3.}, {3.6377778151415994`, -3.097057141913445}, {
       3.5625, -2.9998768219370047`}, {3.625, -3.}}], 
      PolygonBox[{{3.562500018967059, -3.084292589556055}, {
       3.5625, -2.9998768219370047`}, {
       3.6377778151415994`, -3.097057141913445}, {
       3.562500018967059, -3.084292589556055}}], 
      PolygonBox[{{3.6377778151415994`, -3.097057141913445}, {
       3.6752404735808355`, -3.1875}, {
       3.562500018967059, -3.084292589556055}, {
       3.6377778151415994`, -3.097057141913445}}], 
      PolygonBox[{{3.5626550066464766`, -3.230251642536255}, {
       3.562500018967059, -3.084292589556055}, {
       3.6752404735808355`, -3.1875}, {
       3.5626550066464766`, -3.230251642536255}}], 
      PolygonBox[{{3.6752404735808355`, -3.1875}, {
       3.7348349570550448`, -3.2651650429449552`}, {
       3.5626550066464766`, -3.230251642536255}, {
       3.6752404735808355`, -3.1875}}], 
      PolygonBox[{{3.595057255667003, -3.404942744332997}, {
       3.5626550066464766`, -3.230251642536255}, {
       3.7348349570550448`, -3.2651650429449552`}, {
       3.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, -3.2651650429449552`}, {
       3.8125, -3.3247595264191645`}, {
       3.595057255667003, -3.404942744332997}, {
       3.7348349570550448`, -3.2651650429449552`}}], 
      PolygonBox[{{3.769748357463745, -3.4373449933535234`}, {
       3.595057255667003, -3.404942744332997}, {
       3.8125, -3.3247595264191645`}, {
       3.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{3.8125, -3.3247595264191645`}, {
       3.9029428580865546`, -3.3622221848584006`}, {
       3.769748357463745, -3.4373449933535234`}, {
       3.8125, -3.3247595264191645`}}], 
      PolygonBox[{{3.915707410443936, -3.437499981032941}, {
       3.769748357463745, -3.4373449933535234`}, {
       3.9029428580865546`, -3.3622221848584006`}, {
       3.915707410443936, -3.437499981032941}}], 
      PolygonBox[{{3.9029428580865546`, -3.3622221848584006`}, {4., -3.375}, {
       3.915707410443936, -3.437499981032941}, {
       3.9029428580865546`, -3.3622221848584006`}}], 
      PolygonBox[{{4.000134841831043, -3.4375}, {
       3.915707410443936, -3.437499981032941}, {4., -3.375}, {
       4.000134841831043, -3.4375}}], 
      PolygonBox[{{4., -3.375}, {4.097057141913445, -3.3622221848584006`}, {
       4.000134841831043, -3.4375}, {4., -3.375}}], 
      PolygonBox[{{4.084292589556053, -3.437499981032941}, {
       4.000134841831043, -3.4375}, {
       4.097057141913445, -3.3622221848584006`}, {
       4.084292589556053, -3.437499981032941}}], 
      PolygonBox[{{4.097057141913445, -3.3622221848584006`}, {
       4.1875, -3.3247595264191645`}, {
       4.084292589556053, -3.437499981032941}, {
       4.097057141913445, -3.3622221848584006`}}], 
      PolygonBox[{{4.230251642536254, -3.4373449933535234`}, {
       4.084292589556053, -3.437499981032941}, {
       4.1875, -3.3247595264191645`}, {
       4.230251642536254, -3.4373449933535234`}}], 
      PolygonBox[{{4.1875, -3.3247595264191645`}, {
       4.265165042944956, -3.2651650429449552`}, {
       4.230251642536254, -3.4373449933535234`}, {
       4.1875, -3.3247595264191645`}}], 
      PolygonBox[{{4.404942744332997, -3.404942744332997}, {
       4.230251642536254, -3.4373449933535234`}, {
       4.265165042944956, -3.2651650429449552`}, {
       4.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{4.265165042944956, -3.2651650429449552`}, {
       4.265165042944956, -3.2651650429449552`}, {
       4.404942744332997, -3.404942744332997}, {
       4.265165042944956, -3.2651650429449552`}}], 
      PolygonBox[{{4.404942744332997, -3.404942744332997}, {
       4.404942744332997, -3.404942744332997}, {
       4.265165042944956, -3.2651650429449552`}, {
       4.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{4.404942744332997, -3.404942744332997}, {
       4.437344993353523, -3.2302516425362553`}, {4.5, -3.5}, {
       4.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{4.5, -3.357662782649368}, {4.5, -3.5}, {
       4.437344993353523, -3.2302516425362553`}, {4.5, -3.357662782649368}}], 
      PolygonBox[{{4.437344993353523, -3.2302516425362553`}, {
       4.437499981032941, -3.084292589556062}, {4.5, -3.357662782649368}, {
       4.437344993353523, -3.2302516425362553`}}], 
      PolygonBox[{{4.5, -3.20590900530174}, {4.5, -3.357662782649368}, {
       4.437499981032941, -3.084292589556062}, {4.5, -3.20590900530174}}], 
      PolygonBox[{{4.437499981032941, -3.084292589556062}, {4.4375, -3.}, {
       4.5, -3.20590900530174}, {4.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{4.5, -3.}, {4.5, -3.20590900530174}, {4.4375, -3.}, {
       4.5, -3.}}], 
      PolygonBox[{{4.4375, -3.}, {4.437499981032941, -2.915707410443938}, {
       4.5, -3.}, {4.4375, -3.}}], 
      PolygonBox[{{4.5, -2.79409099469826}, {4.5, -3.}, {
       4.437499981032941, -2.915707410443938}, {4.5, -2.79409099469826}}], 
      PolygonBox[{{4.437499981032941, -2.915707410443938}, {
       4.437344993353523, -2.769748357463745}, {4.5, -2.79409099469826}, {
       4.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{4.5, -2.6423372173506325`}, {4.5, -2.79409099469826}, {
       4.437344993353523, -2.769748357463745}, {4.5, -2.6423372173506325`}}], 
      PolygonBox[{{4.437344993353523, -2.769748357463745}, {
       4.404942744332997, -2.595057255667003}, {4.5, -2.6423372173506325`}, {
       4.437344993353523, -2.769748357463745}}], 
      PolygonBox[{{4.491446564961186, -2.508553435038814}, {
       4.5, -2.6423372173506325`}, {4.404942744332997, -2.595057255667003}, {
       4.491446564961186, -2.508553435038814}}], 
      PolygonBox[{{4.404942744332997, -2.595057255667003}, {
       4.230251642536255, -2.5626550066464766`}, {
       4.491446564961186, -2.508553435038814}, {
       4.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{4.357662782649368, -2.5}, {
       4.491446564961186, -2.508553435038814}, {
       4.230251642536255, -2.5626550066464766`}, {4.357662782649368, -2.5}}], 
      PolygonBox[{{4.230251642536255, -2.5626550066464766`}, {
       4.0842925895560604`, -2.562500018967059}, {4.357662782649368, -2.5}, {
       4.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{4.205909005373256, -2.5}, {4.357662782649368, -2.5}, {
       4.0842925895560604`, -2.562500018967059}, {4.205909005373256, -2.5}}], 
      PolygonBox[{{4.0842925895560604`, -2.562500018967059}, {
       4.000105527220487, -2.5625}, {4.205909005373256, -2.5}, {
       4.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{4.07794195802689, -2.5}, {4.205909005373256, -2.5}, {
       4.000105527220487, -2.5625}, {4.07794195802689, -2.5}}], 
      PolygonBox[{{4.000105527220487, -2.5625}, {
       3.915707410443943, -2.562500018967059}, {4.07794195802689, -2.5}, {
       4.000105527220487, -2.5625}}], 
      PolygonBox[{{3.7940909946955546`, -2.5}, {4.07794195802689, -2.5}, {
       3.915707410443943, -2.562500018967059}, {3.7940909946955546`, -2.5}}], 
      PolygonBox[{{3.915707410443943, -2.562500018967059}, {
       3.769748357463745, -2.5626550066464766`}, {
       3.7940909946955546`, -2.5}, {3.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{3.642337217350634, -2.5}, {3.7940909946955546`, -2.5}, {
       3.769748357463745, -2.5626550066464766`}, {3.642337217350634, -2.5}}], 
      PolygonBox[{{3.769748357463745, -2.5626550066464766`}, {
       3.595057255667003, -2.595057255667003}, {3.642337217350634, -2.5}, {
       3.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{4.5, -2.5}, {3.642337217350634, -2.5}, {
       3.595057255667003, -2.595057255667003}, {4.5, -2.5}}], 
      PolygonBox[{{3.595057255667003, -2.595057255667003}, {
       3.5626550066464766`, -2.7697483574637447`}, {4.5, -2.5}, {
       3.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{3.5, -2.642337217350631}, {4.5, -2.5}, {
       3.5626550066464766`, -2.7697483574637447`}, {
       3.5, -2.642337217350631}}], 
      PolygonBox[{{3.5626550066464766`, -2.7697483574637447`}, {
       3.562500018967059, -2.9157074104439378`}, {3.5, -2.642337217350631}, {
       3.5626550066464766`, -2.7697483574637447`}}], 
      PolygonBox[{{3.5, -2.794090994717101}, {3.5, -2.642337217350631}, {
       3.562500018967059, -2.9157074104439378`}, {3.5, -2.794090994717101}}], 
      PolygonBox[{{3.562500018967059, -2.9157074104439378`}, {
       3.5625, -2.9998768219370047`}, {3.5, -2.794090994717101}, {
       3.562500018967059, -2.9157074104439378`}}], 
      PolygonBox[{{3.5, -2.9193213332413}, {3.5, -2.794090994717101}, {
       3.5625, -2.9998768219370047`}, {3.5, -2.9193213332413}}], 
      PolygonBox[{{3.5625, -2.9998768219370047`}, {
       3.562500018967059, -3.084292589556055}, {3.5, -2.9193213332413}, {
       3.5625, -2.9998768219370047`}}], 
      PolygonBox[{{3.5, -3.2059090051452785`}, {3.5, -2.9193213332413}, {
       3.562500018967059, -3.084292589556055}, {3.5, -3.2059090051452785`}}], 
      PolygonBox[{{3.562500018967059, -3.084292589556055}, {
       3.5626550066464766`, -3.230251642536255}, {
       3.5, -3.2059090051452785`}, {3.562500018967059, -3.084292589556055}}], 
      PolygonBox[{{3.5, -3.3576627826493652`}, {3.5, -3.2059090051452785`}, {
       3.5626550066464766`, -3.230251642536255}, {
       3.5, -3.3576627826493652`}}], 
      PolygonBox[{{3.5626550066464766`, -3.230251642536255}, {
       3.595057255667003, -3.404942744332997}, {3.5, -3.3576627826493652`}, {
       3.5626550066464766`, -3.230251642536255}}], 
      PolygonBox[{{3.5, -2.5}, {3.5, -3.3576627826493652`}, {
       3.595057255667003, -3.404942744332997}, {3.5, -2.5}}], 
      PolygonBox[{{3.595057255667003, -3.404942744332997}, {
       3.769748357463745, -3.4373449933535234`}, {3.5, -2.5}, {
       3.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{3.5, -3.5}, {3.5, -2.5}, {
       3.769748357463745, -3.4373449933535234`}, {3.5, -3.5}}], 
      PolygonBox[{{3.769748357463745, -3.4373449933535234`}, {
       3.915707410443936, -3.437499981032941}, {3.5, -3.5}, {
       3.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{3.794090994433172, -3.5}, {3.5, -3.5}, {
       3.915707410443936, -3.437499981032941}, {3.794090994433172, -3.5}}], 
      PolygonBox[{{3.915707410443936, -3.437499981032941}, {
       4.000134841831043, -3.4375}, {3.794090994433172, -3.5}, {
       3.915707410443936, -3.437499981032941}}], 
      PolygonBox[{{4.082323870401062, -3.5}, {3.794090994433172, -3.5}, {
       4.000134841831043, -3.4375}, {4.082323870401062, -3.5}}], 
      PolygonBox[{{4.000134841831043, -3.4375}, {
       4.084292589556053, -3.437499981032941}, {4.082323870401062, -3.5}, {
       4.000134841831043, -3.4375}}], 
      PolygonBox[{{4.205909005360398, -3.5}, {4.082323870401062, -3.5}, {
       4.084292589556053, -3.437499981032941}, {4.205909005360398, -3.5}}], 
      PolygonBox[{{4.084292589556053, -3.437499981032941}, {
       4.230251642536254, -3.4373449933535234`}, {4.205909005360398, -3.5}, {
       4.084292589556053, -3.437499981032941}}], 
      PolygonBox[{{4.3576627826493715`, -3.5}, {4.205909005360398, -3.5}, {
       4.230251642536254, -3.4373449933535234`}, {
       4.3576627826493715`, -3.5}}], 
      PolygonBox[{{4.230251642536254, -3.4373449933535234`}, {
       4.404942744332997, -3.404942744332997}, {4.3576627826493715`, -3.5}, {
       4.230251642536254, -3.4373449933535234`}}], 
      PolygonBox[{{4.5, -3.5}, {4.3576627826493715`, -3.5}, {
       4.404942744332997, -3.404942744332997}, {4.5, -3.5}}], 
      PolygonBox[{{4.404942744332997, -3.404942744332997}, {
       4.404942744332997, -3.404942744332997}, {4.5, -3.5}, {
       4.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{4.5, -3.5}, {4.5, -3.5}, {
       4.404942744332997, -3.404942744332997}, {4.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, -2.}, {3.5208333333333335`, -2.}, {
       3.5416666666666665`, -2.}, {3.5625, -2.}, {3.5833333333333335`, -2.}, {
       3.6041666666666665`, -2.}, {3.625, -2.}, {3.625, -2.}, {
       3.6041666666666665`, -2.}, {3.5833333333333335`, -2.}, {3.5625, -2.}, {
       3.5416666666666665`, -2.}, {3.5208333333333335`, -2.}, {3.5, -2.}, {
       3.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, -2.}, {4.395833333333333, -2.}, {
       4.416666666666667, -2.}, {4.4375, -2.}, {4.458333333333333, -2.}, {
       4.479166666666667, -2.}, {4.5, -2.}, {4.5, -2.}, {
       4.479166666666667, -2.}, {4.458333333333333, -2.}, {4.4375, -2.}, {
       4.416666666666667, -2.}, {4.395833333333333, -2.}, {4.375, -2.}, {
       4.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -2.5}, {4., -2.4791666666666665`}, {
       4., -2.4583333333333335`}, {4., -2.4375}, {4., -2.4166666666666665`}, {
       4., -2.3958333333333335`}, {4., -2.375}, {4., -2.375}, {
       4., -2.3958333333333335`}, {4., -2.4166666666666665`}, {4., -2.4375}, {
       4., -2.4583333333333335`}, {4., -2.4791666666666665`}, {4., -2.5}, {
       4., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -1.625}, {4., -1.6041666666666667`}, {
       4., -1.5833333333333333`}, {4., -1.5625}, {4., -1.5416666666666667`}, {
       4., -1.5208333333333335`}, {4., -1.5}, {4., -1.5}, {
       4., -1.5208333333333333`}, {4., -1.5416666666666667`}, {4., -1.5625}, {
       4., -1.5833333333333333`}, {4., -1.6041666666666665`}, {4., -1.625}, {
       4., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, -2.}, {3.75, -2.}, {3.875, -2.}, {4., -2.}, {
       4.125, -2.}, {4.25, -2.}, {4.375, -2.}, {4.375, -2.}, {4.25, -2.}, {
       4.125, -2.}, {4., -2.}, {3.875, -2.}, {3.75, -2.}, {3.625, -2.}, {
       3.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -2.375}, {4., -2.25}, {4., -2.125}, {4., -2.}, {
       4., -1.875}, {4., -1.75}, {4., -1.625}, {4., -1.625}, {4., -1.75}, {
       4., -1.875}, {4., -2.}, {4., -2.125}, {4., -2.25}, {4., -2.375}, {
       4., -2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg5Q1oGvGeHxr4oEHZLMb5mWFP3bP0P5yaFe
H5j83/3nvp3NaecXdDilcsLn0cHf+yG6BBwWFOZ/OXH21371os5PSckCDjox
i5rCTH5B5BkEoPp/7d8o/VbKypIfVb6BD64/VShF7eMDXrj5F3aYVz1J44Xb
L6YX6KgtxQt3H0QcJs9wACbv90To6dFjDAdQ9DcwHkiBmj/77eybfPJMB2D2
G7ifaJWeyXQA5r5XF9ftu/IUKg93P/MBmP9Q5IH+h+mHhQ/MfJTwA9oPC19/
qPvQwx8A5YmOfA==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhD6x/5QMBCE81evAgEBOB9CC6DJ88H5YWD9
vGjqeQjywcas+gXnQ9zxF009wwFUecYDqPqZDqCqZ8Hgh6K4j+UAqvth6gXQ
5AXQ9AuiqRciyF+N4j4hNPfD1DPA+WEo/ofp/7UfVf2P/QC3G1wL
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, -2.2651650429449552`}, {
       4.3247595264191645`, -2.1875}, {
       4.404942744332997, -2.404942744332997}, {
       4.265165042944956, -2.2651650429449552`}}], 
      PolygonBox[{{4.437344993353523, -2.2302516425362553`}, {
       4.404942744332997, -2.404942744332997}, {
       4.3247595264191645`, -2.1875}, {
       4.437344993353523, -2.2302516425362553`}}], 
      PolygonBox[{{4.3247595264191645`, -2.1875}, {
       4.362222184858401, -2.0970571419134454`}, {
       4.437344993353523, -2.2302516425362553`}, {
       4.3247595264191645`, -2.1875}}], 
      PolygonBox[{{4.437499981032941, -2.084292589556062}, {
       4.437344993353523, -2.2302516425362553`}, {
       4.362222184858401, -2.0970571419134454`}, {
       4.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{4.362222184858401, -2.0970571419134454`}, {4.375, -2.}, {
       4.437499981032941, -2.084292589556062}, {
       4.362222184858401, -2.0970571419134454`}}], 
      PolygonBox[{{4.4375, -2.}, {4.437499981032941, -2.084292589556062}, {
       4.375, -2.}, {4.4375, -2.}}], 
      PolygonBox[{{4.375, -2.}, {4.362222184858401, -1.9029428580865548`}, {
       4.4375, -2.}, {4.375, -2.}}], 
      PolygonBox[{{4.437499981032941, -1.9157074104439382`}, {4.4375, -2.}, {
       4.362222184858401, -1.9029428580865548`}, {
       4.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{4.362222184858401, -1.9029428580865548`}, {
       4.3247595264191645`, -1.8125}, {
       4.437499981032941, -1.9157074104439382`}, {
       4.362222184858401, -1.9029428580865548`}}], 
      PolygonBox[{{4.437344993353523, -1.769748357463745}, {
       4.437499981032941, -1.9157074104439382`}, {
       4.3247595264191645`, -1.8125}, {
       4.437344993353523, -1.769748357463745}}], 
      PolygonBox[{{4.3247595264191645`, -1.8125}, {
       4.265165042944956, -1.7348349570550448`}, {
       4.437344993353523, -1.769748357463745}, {
       4.3247595264191645`, -1.8125}}], 
      PolygonBox[{{4.404942744332997, -1.5950572556670028`}, {
       4.437344993353523, -1.769748357463745}, {
       4.265165042944956, -1.7348349570550448`}, {
       4.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{4.265165042944956, -1.7348349570550448`}, {
       4.1875, -1.6752404735808355`}, {
       4.404942744332997, -1.5950572556670028`}, {
       4.265165042944956, -1.7348349570550448`}}], 
      PolygonBox[{{4.230251642536255, -1.5626550066464766`}, {
       4.404942744332997, -1.5950572556670028`}, {
       4.1875, -1.6752404735808355`}, {
       4.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{4.1875, -1.6752404735808355`}, {
       4.097057141913445, -1.6377778151415994`}, {
       4.230251642536255, -1.5626550066464766`}, {
       4.1875, -1.6752404735808355`}}], 
      PolygonBox[{{4.0842925895560604`, -1.5625000189670593`}, {
       4.230251642536255, -1.5626550066464766`}, {
       4.097057141913445, -1.6377778151415994`}, {
       4.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{4.097057141913445, -1.6377778151415994`}, {4., -1.625}, {
       4.0842925895560604`, -1.5625000189670593`}, {
       4.097057141913445, -1.6377778151415994`}}], 
      PolygonBox[{{4.000105527220487, -1.5625}, {
       4.0842925895560604`, -1.5625000189670593`}, {4., -1.625}, {
       4.000105527220487, -1.5625}}], 
      PolygonBox[{{4., -1.625}, {3.902942858086555, -1.6377778151415994`}, {
       4.000105527220487, -1.5625}, {4., -1.625}}], 
      PolygonBox[{{3.915707410443943, -1.5625000189670593`}, {
       4.000105527220487, -1.5625}, {
       3.902942858086555, -1.6377778151415994`}, {
       3.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{3.902942858086555, -1.6377778151415994`}, {
       3.8125, -1.6752404735808355`}, {
       3.915707410443943, -1.5625000189670593`}, {
       3.902942858086555, -1.6377778151415994`}}], 
      PolygonBox[{{3.769748357463745, -1.5626550066464766`}, {
       3.915707410443943, -1.5625000189670593`}, {
       3.8125, -1.6752404735808355`}, {
       3.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{3.8125, -1.6752404735808355`}, {
       3.7348349570550448`, -1.7348349570550448`}, {
       3.769748357463745, -1.5626550066464766`}, {
       3.8125, -1.6752404735808355`}}], 
      PolygonBox[{{3.595057255667003, -1.5950572556670028`}, {
       3.769748357463745, -1.5626550066464766`}, {
       3.7348349570550448`, -1.7348349570550448`}, {
       3.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{3.7348349570550448`, -1.7348349570550448`}, {
       3.6752404735808355`, -1.8125}, {
       3.595057255667003, -1.5950572556670028`}, {
       3.7348349570550448`, -1.7348349570550448`}}], 
      PolygonBox[{{3.5626550066464766`, -1.7697483574637447`}, {
       3.595057255667003, -1.5950572556670028`}, {
       3.6752404735808355`, -1.8125}, {
       3.5626550066464766`, -1.7697483574637447`}}], 
      PolygonBox[{{3.6752404735808355`, -1.8125}, {
       3.6377778151415994`, -1.9029428580865546`}, {
       3.5626550066464766`, -1.7697483574637447`}, {
       3.6752404735808355`, -1.8125}}], 
      PolygonBox[{{3.562500018967059, -1.9157074104439376`}, {
       3.5626550066464766`, -1.7697483574637447`}, {
       3.6377778151415994`, -1.9029428580865546`}, {
       3.562500018967059, -1.9157074104439376`}}], 
      PolygonBox[{{3.6377778151415994`, -1.9029428580865546`}, {
       3.625, -1.9999999999999998`}, {
       3.562500018967059, -1.9157074104439376`}, {
       3.6377778151415994`, -1.9029428580865546`}}], 
      PolygonBox[{{3.5625, -1.9998768219370047`}, {
       3.562500018967059, -1.9157074104439376`}, {
       3.625, -1.9999999999999998`}, {3.5625, -1.9998768219370047`}}], 
      PolygonBox[{{3.625, -1.9999999999999998`}, {
       3.6377778151415994`, -2.097057141913445}, {
       3.5625, -1.9998768219370047`}, {3.625, -1.9999999999999998`}}], 
      PolygonBox[{{3.562500018967059, -2.084292589556055}, {
       3.5625, -1.9998768219370047`}, {
       3.6377778151415994`, -2.097057141913445}, {
       3.562500018967059, -2.084292589556055}}], 
      PolygonBox[{{3.6377778151415994`, -2.097057141913445}, {
       3.6752404735808355`, -2.1875}, {
       3.562500018967059, -2.084292589556055}, {
       3.6377778151415994`, -2.097057141913445}}], 
      PolygonBox[{{3.5626550066464766`, -2.230251642536255}, {
       3.562500018967059, -2.084292589556055}, {
       3.6752404735808355`, -2.1875}, {
       3.5626550066464766`, -2.230251642536255}}], 
      PolygonBox[{{3.6752404735808355`, -2.1875}, {
       3.7348349570550448`, -2.2651650429449552`}, {
       3.5626550066464766`, -2.230251642536255}, {
       3.6752404735808355`, -2.1875}}], 
      PolygonBox[{{3.595057255667003, -2.404942744332997}, {
       3.5626550066464766`, -2.230251642536255}, {
       3.7348349570550448`, -2.2651650429449552`}, {
       3.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, -2.2651650429449552`}, {
       3.8125, -2.3247595264191645`}, {
       3.595057255667003, -2.404942744332997}, {
       3.7348349570550448`, -2.2651650429449552`}}], 
      PolygonBox[{{3.769748357463745, -2.4373449933535234`}, {
       3.595057255667003, -2.404942744332997}, {
       3.8125, -2.3247595264191645`}, {
       3.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{3.8125, -2.3247595264191645`}, {
       3.9029428580865546`, -2.3622221848584006`}, {
       3.769748357463745, -2.4373449933535234`}, {
       3.8125, -2.3247595264191645`}}], 
      PolygonBox[{{3.915707410443936, -2.437499981032941}, {
       3.769748357463745, -2.4373449933535234`}, {
       3.9029428580865546`, -2.3622221848584006`}, {
       3.915707410443936, -2.437499981032941}}], 
      PolygonBox[{{3.9029428580865546`, -2.3622221848584006`}, {4., -2.375}, {
       3.915707410443936, -2.437499981032941}, {
       3.9029428580865546`, -2.3622221848584006`}}], 
      PolygonBox[{{4.000134841831043, -2.4375}, {
       3.915707410443936, -2.437499981032941}, {4., -2.375}, {
       4.000134841831043, -2.4375}}], 
      PolygonBox[{{4., -2.375}, {4.097057141913445, -2.3622221848584006`}, {
       4.000134841831043, -2.4375}, {4., -2.375}}], 
      PolygonBox[{{4.084292589556053, -2.437499981032941}, {
       4.000134841831043, -2.4375}, {
       4.097057141913445, -2.3622221848584006`}, {
       4.084292589556053, -2.437499981032941}}], 
      PolygonBox[{{4.097057141913445, -2.3622221848584006`}, {
       4.1875, -2.3247595264191645`}, {
       4.084292589556053, -2.437499981032941}, {
       4.097057141913445, -2.3622221848584006`}}], 
      PolygonBox[{{4.230251642536254, -2.4373449933535234`}, {
       4.084292589556053, -2.437499981032941}, {
       4.1875, -2.3247595264191645`}, {
       4.230251642536254, -2.4373449933535234`}}], 
      PolygonBox[{{4.1875, -2.3247595264191645`}, {
       4.265165042944956, -2.2651650429449552`}, {
       4.230251642536254, -2.4373449933535234`}, {
       4.1875, -2.3247595264191645`}}], 
      PolygonBox[{{4.404942744332997, -2.404942744332997}, {
       4.230251642536254, -2.4373449933535234`}, {
       4.265165042944956, -2.2651650429449552`}, {
       4.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{4.265165042944956, -2.2651650429449552`}, {
       4.265165042944956, -2.2651650429449552`}, {
       4.404942744332997, -2.404942744332997}, {
       4.265165042944956, -2.2651650429449552`}}], 
      PolygonBox[{{4.404942744332997, -2.404942744332997}, {
       4.404942744332997, -2.404942744332997}, {
       4.265165042944956, -2.2651650429449552`}, {
       4.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{4.404942744332997, -2.404942744332997}, {4.437344993353523,
        -2.2302516425362553`}, {4.5, -2.5}, {
       4.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{4.5, -2.357662782649368}, {4.5, -2.5}, {
       4.437344993353523, -2.2302516425362553`}, {4.5, -2.357662782649368}}], 
      PolygonBox[{{4.437344993353523, -2.2302516425362553`}, {
       4.437499981032941, -2.084292589556062}, {4.5, -2.357662782649368}, {
       4.437344993353523, -2.2302516425362553`}}], 
      PolygonBox[{{4.5, -2.20590900530174}, {4.5, -2.357662782649368}, {
       4.437499981032941, -2.084292589556062}, {4.5, -2.20590900530174}}], 
      PolygonBox[{{4.437499981032941, -2.084292589556062}, {4.4375, -2.}, {
       4.5, -2.20590900530174}, {4.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{4.5, -2.}, {4.5, -2.20590900530174}, {4.4375, -2.}, {
       4.5, -2.}}], 
      PolygonBox[{{4.4375, -2.}, {4.437499981032941, -1.9157074104439382`}, {
       4.5, -2.}, {4.4375, -2.}}], 
      PolygonBox[{{4.5, -1.7940909946982602`}, {4.5, -2.}, {
       4.437499981032941, -1.9157074104439382`}, {
       4.5, -1.7940909946982602`}}], 
      PolygonBox[{{4.437499981032941, -1.9157074104439382`}, {
       4.437344993353523, -1.769748357463745}, {4.5, -1.7940909946982602`}, {
       4.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{4.5, -1.6423372173506325`}, {4.5, -1.7940909946982602`}, {
       4.437344993353523, -1.769748357463745}, {4.5, -1.6423372173506325`}}], 
      PolygonBox[{{4.437344993353523, -1.769748357463745}, {
       4.404942744332997, -1.5950572556670028`}, {
       4.5, -1.6423372173506325`}, {4.437344993353523, -1.769748357463745}}], 
      PolygonBox[{{4.491446564961186, -1.508553435038814}, {
       4.5, -1.6423372173506325`}, {
       4.404942744332997, -1.5950572556670028`}, {
       4.491446564961186, -1.508553435038814}}], 
      PolygonBox[{{4.404942744332997, -1.5950572556670028`}, {
       4.230251642536255, -1.5626550066464766`}, {
       4.491446564961186, -1.508553435038814}, {
       4.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{4.357662782649368, -1.5}, {
       4.491446564961186, -1.508553435038814}, {
       4.230251642536255, -1.5626550066464766`}, {4.357662782649368, -1.5}}], 
      PolygonBox[{{4.230251642536255, -1.5626550066464766`}, {
       4.0842925895560604`, -1.5625000189670593`}, {
       4.357662782649368, -1.5}, {4.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{4.205909005373256, -1.5}, {4.357662782649368, -1.5}, {
       4.0842925895560604`, -1.5625000189670593`}, {
       4.205909005373256, -1.5}}], 
      PolygonBox[{{4.0842925895560604`, -1.5625000189670593`}, {
       4.000105527220487, -1.5625}, {4.205909005373256, -1.5}, {
       4.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{4.07794195802689, -1.5}, {4.205909005373256, -1.5}, {
       4.000105527220487, -1.5625}, {4.07794195802689, -1.5}}], 
      PolygonBox[{{4.000105527220487, -1.5625}, {
       3.915707410443943, -1.5625000189670593`}, {4.07794195802689, -1.5}, {
       4.000105527220487, -1.5625}}], 
      PolygonBox[{{3.7940909946955546`, -1.5}, {4.07794195802689, -1.5}, {
       3.915707410443943, -1.5625000189670593`}, {
       3.7940909946955546`, -1.5}}], 
      PolygonBox[{{3.915707410443943, -1.5625000189670593`}, {
       3.769748357463745, -1.5626550066464766`}, {
       3.7940909946955546`, -1.5}, {
       3.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{3.642337217350634, -1.5}, {3.7940909946955546`, -1.5}, {
       3.769748357463745, -1.5626550066464766`}, {3.642337217350634, -1.5}}], 
      PolygonBox[{{3.769748357463745, -1.5626550066464766`}, {
       3.595057255667003, -1.5950572556670028`}, {3.642337217350634, -1.5}, {
       3.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{4.5, -1.5}, {3.642337217350634, -1.5}, {
       3.595057255667003, -1.5950572556670028`}, {4.5, -1.5}}], 
      PolygonBox[{{3.595057255667003, -1.5950572556670028`}, {
       3.5626550066464766`, -1.7697483574637447`}, {4.5, -1.5}, {
       3.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{3.5, -1.642337217350631}, {4.5, -1.5}, {
       3.5626550066464766`, -1.7697483574637447`}, {
       3.5, -1.642337217350631}}], 
      PolygonBox[{{3.5626550066464766`, -1.7697483574637447`}, {
       3.562500018967059, -1.9157074104439376`}, {3.5, -1.642337217350631}, {
       3.5626550066464766`, -1.7697483574637447`}}], 
      PolygonBox[{{3.5, -1.794090994717101}, {3.5, -1.642337217350631}, {
       3.562500018967059, -1.9157074104439376`}, {3.5, -1.794090994717101}}], 
      PolygonBox[{{3.562500018967059, -1.9157074104439376`}, {
       3.5625, -1.9998768219370047`}, {3.5, -1.794090994717101}, {
       3.562500018967059, -1.9157074104439376`}}], 
      PolygonBox[{{3.5, -1.9193213332412997`}, {3.5, -1.794090994717101}, {
       3.5625, -1.9998768219370047`}, {3.5, -1.9193213332412997`}}], 
      PolygonBox[{{3.5625, -1.9998768219370047`}, {
       3.562500018967059, -2.084292589556055}, {3.5, -1.9193213332412997`}, {
       3.5625, -1.9998768219370047`}}], 
      PolygonBox[{{3.5, -2.2059090051452785`}, {3.5, -1.9193213332412997`}, {
       3.562500018967059, -2.084292589556055}, {3.5, -2.2059090051452785`}}], 
      PolygonBox[{{3.562500018967059, -2.084292589556055}, {
       3.5626550066464766`, -2.230251642536255}, {
       3.5, -2.2059090051452785`}, {3.562500018967059, -2.084292589556055}}], 
      PolygonBox[{{3.5, -2.3576627826493652`}, {3.5, -2.2059090051452785`}, {
       3.5626550066464766`, -2.230251642536255}, {
       3.5, -2.3576627826493652`}}], 
      PolygonBox[{{3.5626550066464766`, -2.230251642536255}, {
       3.595057255667003, -2.404942744332997}, {3.5, -2.3576627826493652`}, {
       3.5626550066464766`, -2.230251642536255}}], 
      PolygonBox[{{3.5, -1.5}, {3.5, -2.3576627826493652`}, {
       3.595057255667003, -2.404942744332997}, {3.5, -1.5}}], 
      PolygonBox[{{3.595057255667003, -2.404942744332997}, {
       3.769748357463745, -2.4373449933535234`}, {3.5, -1.5}, {
       3.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{3.5, -2.5}, {3.5, -1.5}, {
       3.769748357463745, -2.4373449933535234`}, {3.5, -2.5}}], 
      PolygonBox[{{3.769748357463745, -2.4373449933535234`}, {
       3.915707410443936, -2.437499981032941}, {3.5, -2.5}, {
       3.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{3.794090994433172, -2.5}, {3.5, -2.5}, {
       3.915707410443936, -2.437499981032941}, {3.794090994433172, -2.5}}], 
      PolygonBox[{{3.915707410443936, -2.437499981032941}, {
       4.000134841831043, -2.4375}, {3.794090994433172, -2.5}, {
       3.915707410443936, -2.437499981032941}}], 
      PolygonBox[{{4.082323870401062, -2.5}, {3.794090994433172, -2.5}, {
       4.000134841831043, -2.4375}, {4.082323870401062, -2.5}}], 
      PolygonBox[{{4.000134841831043, -2.4375}, {
       4.084292589556053, -2.437499981032941}, {4.082323870401062, -2.5}, {
       4.000134841831043, -2.4375}}], 
      PolygonBox[{{4.205909005360398, -2.5}, {4.082323870401062, -2.5}, {
       4.084292589556053, -2.437499981032941}, {4.205909005360398, -2.5}}], 
      PolygonBox[{{4.084292589556053, -2.437499981032941}, {
       4.230251642536254, -2.4373449933535234`}, {4.205909005360398, -2.5}, {
       4.084292589556053, -2.437499981032941}}], 
      PolygonBox[{{4.3576627826493715`, -2.5}, {4.205909005360398, -2.5}, {
       4.230251642536254, -2.4373449933535234`}, {
       4.3576627826493715`, -2.5}}], 
      PolygonBox[{{4.230251642536254, -2.4373449933535234`}, {
       4.404942744332997, -2.404942744332997}, {4.3576627826493715`, -2.5}, {
       4.230251642536254, -2.4373449933535234`}}], 
      PolygonBox[{{4.5, -2.5}, {4.3576627826493715`, -2.5}, {
       4.404942744332997, -2.404942744332997}, {4.5, -2.5}}], 
      PolygonBox[{{4.404942744332997, -2.404942744332997}, {
       4.404942744332997, -2.404942744332997}, {4.5, -2.5}, {
       4.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{4.5, -2.5}, {4.5, -2.5}, {
       4.404942744332997, -2.404942744332997}, {4.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, -1.}, {3.5208333333333335`, -1.}, {
       3.5416666666666665`, -1.}, {3.5625, -1.}, {3.5833333333333335`, -1.}, {
       3.6041666666666665`, -1.}, {3.625, -1.}, {3.625, -1.}, {
       3.6041666666666665`, -1.}, {3.5833333333333335`, -1.}, {3.5625, -1.}, {
       3.5416666666666665`, -1.}, {3.5208333333333335`, -1.}, {3.5, -1.}, {
       3.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, -1.}, {4.395833333333333, -1.}, {
       4.416666666666667, -1.}, {4.4375, -1.}, {4.458333333333333, -1.}, {
       4.479166666666667, -1.}, {4.5, -1.}, {4.5, -1.}, {
       4.479166666666667, -1.}, {4.458333333333333, -1.}, {4.4375, -1.}, {
       4.416666666666667, -1.}, {4.395833333333333, -1.}, {4.375, -1.}, {
       4.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -1.5}, {4., -1.4791666666666667`}, {
       4., -1.4583333333333333`}, {4., -1.4375}, {4., -1.4166666666666667`}, {
       4., -1.3958333333333335`}, {4., -1.375}, {4., -1.375}, {
       4., -1.3958333333333333`}, {4., -1.4166666666666667`}, {4., -1.4375}, {
       4., -1.4583333333333333`}, {4., -1.4791666666666665`}, {4., -1.5}, {
       4., -1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -0.625}, {4., -0.6041666666666667}, {
       4., -0.5833333333333333}, {4., -0.5625}, {4., -0.5416666666666667}, {
       4., -0.5208333333333334}, {4., -0.5}, {4., -0.5}, {
       4., -0.5208333333333333}, {4., -0.5416666666666667}, {4., -0.5625}, {
       4., -0.5833333333333333}, {4., -0.6041666666666666}, {4., -0.625}, {
       4., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, -1.}, {3.75, -1.}, {3.875, -1.}, {4., -1.}, {
       4.125, -1.}, {4.25, -1.}, {4.375, -1.}, {4.375, -1.}, {4.25, -1.}, {
       4.125, -1.}, {4., -1.}, {3.875, -1.}, {3.75, -1.}, {3.625, -1.}, {
       3.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -1.375}, {4., -1.25}, {4., -1.125}, {4., -1.}, {
       4., -0.875}, {4., -0.75}, {4., -0.625}, {4., -0.625}, {4., -0.75}, {
       4., -0.875}, {4., -1.}, {4., -1.125}, {4., -1.25}, {4., -1.375}, {
       4., -1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4Qxof9XzPC418VCToczduS/eLJm/0zlJ8c
6vWByb/af+7b2Zx2fkGHKZ4TZh5pfr4fLHxAwMHh8b0XE2c/3a9e1PkpKVnA
IWKHC+vajCcQeQYBqP4n+zdKv5WysuRHlW/gg+tPFUpR+/iA12Ey1PwLO8yr
nqTxOvwHg5f7xfQCHbWleB2OQN0HMZcX7n6Y/NwTqqe6ez/C9UPkP+9PgZpv
dtt8s6zdF7j9CX0TuM2NvsLdd2VxbO3K01/R3P8N7j8UeaD/Yfph4QMzHxZ+
jFD7YeE7H+o+9PAHADjinUI=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhD6wf5QMBCE81evAgEBOB9CC6DJ88H5YWD9
vGjqeQjyIfY+hfPBxq56hab+A5r8JzT9X9HU/8Dgh6K47wea+3+g+e8Hmv9/
oIUPTL0QQX4YivuEHFajuB+m/gOa/Cs0/U/R1D/YDwBiFGkR
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, -1.2651650429449552`}, {
       4.3247595264191645`, -1.1875}, {
       4.404942744332997, -1.4049427443329972`}, {
       4.265165042944956, -1.2651650429449552`}}], 
      PolygonBox[{{4.437344993353523, -1.230251642536255}, {
       4.404942744332997, -1.4049427443329972`}, {
       4.3247595264191645`, -1.1875}, {
       4.437344993353523, -1.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, -1.1875}, {
       4.362222184858401, -1.0970571419134454`}, {
       4.437344993353523, -1.230251642536255}, {
       4.3247595264191645`, -1.1875}}], 
      PolygonBox[{{4.437499981032941, -1.0842925895560618`}, {
       4.437344993353523, -1.230251642536255}, {
       4.362222184858401, -1.0970571419134454`}, {
       4.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{4.362222184858401, -1.0970571419134454`}, {4.375, -1.}, {
       4.437499981032941, -1.0842925895560618`}, {
       4.362222184858401, -1.0970571419134454`}}], 
      PolygonBox[{{4.4375, -1.}, {4.437499981032941, -1.0842925895560618`}, {
       4.375, -1.}, {4.4375, -1.}}], 
      PolygonBox[{{4.375, -1.}, {4.362222184858401, -0.9029428580865547}, {
       4.4375, -1.}, {4.375, -1.}}], 
      PolygonBox[{{4.437499981032941, -0.9157074104439382}, {4.4375, -1.}, {
       4.362222184858401, -0.9029428580865547}, {
       4.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{4.362222184858401, -0.9029428580865547}, {
       4.3247595264191645`, -0.8125}, {
       4.437499981032941, -0.9157074104439382}, {
       4.362222184858401, -0.9029428580865547}}], 
      PolygonBox[{{4.437344993353523, -0.7697483574637449}, {
       4.437499981032941, -0.9157074104439382}, {
       4.3247595264191645`, -0.8125}, {
       4.437344993353523, -0.7697483574637449}}], 
      PolygonBox[{{4.3247595264191645`, -0.8125}, {
       4.265165042944956, -0.7348349570550448}, {
       4.437344993353523, -0.7697483574637449}, {
       4.3247595264191645`, -0.8125}}], 
      PolygonBox[{{4.404942744332997, -0.5950572556670028}, {
       4.437344993353523, -0.7697483574637449}, {
       4.265165042944956, -0.7348349570550448}, {
       4.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{4.265165042944956, -0.7348349570550448}, {
       4.1875, -0.6752404735808355}, {
       4.404942744332997, -0.5950572556670028}, {
       4.265165042944956, -0.7348349570550448}}], 
      PolygonBox[{{4.230251642536255, -0.5626550066464766}, {
       4.404942744332997, -0.5950572556670028}, {
       4.1875, -0.6752404735808355}, {
       4.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{4.1875, -0.6752404735808355}, {
       4.097057141913445, -0.6377778151415994}, {
       4.230251642536255, -0.5626550066464766}, {
       4.1875, -0.6752404735808355}}], 
      PolygonBox[{{4.0842925895560604`, -0.5625000189670593}, {
       4.230251642536255, -0.5626550066464766}, {
       4.097057141913445, -0.6377778151415994}, {
       4.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{4.097057141913445, -0.6377778151415994}, {4., -0.625}, {
       4.0842925895560604`, -0.5625000189670593}, {
       4.097057141913445, -0.6377778151415994}}], 
      PolygonBox[{{4.000105527220487, -0.5625}, {
       4.0842925895560604`, -0.5625000189670593}, {4., -0.625}, {
       4.000105527220487, -0.5625}}], 
      PolygonBox[{{4., -0.625}, {3.902942858086555, -0.6377778151415994}, {
       4.000105527220487, -0.5625}, {4., -0.625}}], 
      PolygonBox[{{3.915707410443943, -0.5625000189670593}, {
       4.000105527220487, -0.5625}, {
       3.902942858086555, -0.6377778151415994}, {
       3.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{3.902942858086555, -0.6377778151415994}, {
       3.8125, -0.6752404735808355}, {
       3.915707410443943, -0.5625000189670593}, {
       3.902942858086555, -0.6377778151415994}}], 
      PolygonBox[{{3.769748357463745, -0.5626550066464766}, {
       3.915707410443943, -0.5625000189670593}, {
       3.8125, -0.6752404735808355}, {
       3.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{3.8125, -0.6752404735808355}, {
       3.7348349570550448`, -0.7348349570550446}, {
       3.769748357463745, -0.5626550066464766}, {
       3.8125, -0.6752404735808355}}], 
      PolygonBox[{{3.595057255667003, -0.5950572556670028}, {
       3.769748357463745, -0.5626550066464766}, {
       3.7348349570550448`, -0.7348349570550446}, {
       3.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{3.7348349570550448`, -0.7348349570550446}, {
       3.6752404735808355`, -0.8124999999999999}, {
       3.595057255667003, -0.5950572556670028}, {
       3.7348349570550448`, -0.7348349570550446}}], 
      PolygonBox[{{3.5626550066464766`, -0.7697483574637446}, {
       3.595057255667003, -0.5950572556670028}, {
       3.6752404735808355`, -0.8124999999999999}, {
       3.5626550066464766`, -0.7697483574637446}}], 
      PolygonBox[{{3.6752404735808355`, -0.8124999999999999}, {
       3.6377778151415994`, -0.9029428580865546}, {
       3.5626550066464766`, -0.7697483574637446}, {
       3.6752404735808355`, -0.8124999999999999}}], 
      PolygonBox[{{3.562500018967059, -0.9157074104439377}, {
       3.5626550066464766`, -0.7697483574637446}, {
       3.6377778151415994`, -0.9029428580865546}, {
       3.562500018967059, -0.9157074104439377}}], 
      PolygonBox[{{3.6377778151415994`, -0.9029428580865546}, {
       3.625, -0.9999999999999998}, {
       3.562500018967059, -0.9157074104439377}, {
       3.6377778151415994`, -0.9029428580865546}}], 
      PolygonBox[{{3.5625, -0.9998768219370047}, {
       3.562500018967059, -0.9157074104439377}, {
       3.625, -0.9999999999999998}, {3.5625, -0.9998768219370047}}], 
      PolygonBox[{{3.625, -0.9999999999999998}, {
       3.6377778151415994`, -1.0970571419134452`}, {
       3.5625, -0.9998768219370047}, {3.625, -0.9999999999999998}}], 
      PolygonBox[{{3.562500018967059, -1.084292589556055}, {
       3.5625, -0.9998768219370047}, {
       3.6377778151415994`, -1.0970571419134452`}, {
       3.562500018967059, -1.084292589556055}}], 
      PolygonBox[{{3.6377778151415994`, -1.0970571419134452`}, {
       3.6752404735808355`, -1.1874999999999998`}, {
       3.562500018967059, -1.084292589556055}, {
       3.6377778151415994`, -1.0970571419134452`}}], 
      PolygonBox[{{3.5626550066464766`, -1.2302516425362549`}, {
       3.562500018967059, -1.084292589556055}, {
       3.6752404735808355`, -1.1874999999999998`}, {
       3.5626550066464766`, -1.2302516425362549`}}], 
      PolygonBox[{{3.6752404735808355`, -1.1874999999999998`}, {
       3.7348349570550448`, -1.2651650429449552`}, {
       3.5626550066464766`, -1.2302516425362549`}, {
       3.6752404735808355`, -1.1874999999999998`}}], 
      PolygonBox[{{3.595057255667003, -1.4049427443329972`}, {
       3.5626550066464766`, -1.2302516425362549`}, {
       3.7348349570550448`, -1.2651650429449552`}, {
       3.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{3.7348349570550448`, -1.2651650429449552`}, {
       3.8125, -1.3247595264191645`}, {
       3.595057255667003, -1.4049427443329972`}, {
       3.7348349570550448`, -1.2651650429449552`}}], 
      PolygonBox[{{3.769748357463745, -1.4373449933535234`}, {
       3.595057255667003, -1.4049427443329972`}, {
       3.8125, -1.3247595264191645`}, {
       3.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{3.8125, -1.3247595264191645`}, {
       3.9029428580865546`, -1.3622221848584006`}, {
       3.769748357463745, -1.4373449933535234`}, {
       3.8125, -1.3247595264191645`}}], 
      PolygonBox[{{3.915707410443936, -1.4374999810329407`}, {
       3.769748357463745, -1.4373449933535234`}, {
       3.9029428580865546`, -1.3622221848584006`}, {
       3.915707410443936, -1.4374999810329407`}}], 
      PolygonBox[{{3.9029428580865546`, -1.3622221848584006`}, {4., -1.375}, {
       3.915707410443936, -1.4374999810329407`}, {
       3.9029428580865546`, -1.3622221848584006`}}], 
      PolygonBox[{{4.000134841831043, -1.4375}, {
       3.915707410443936, -1.4374999810329407`}, {4., -1.375}, {
       4.000134841831043, -1.4375}}], 
      PolygonBox[{{4., -1.375}, {4.097057141913445, -1.3622221848584006`}, {
       4.000134841831043, -1.4375}, {4., -1.375}}], 
      PolygonBox[{{4.084292589556053, -1.4374999810329407`}, {
       4.000134841831043, -1.4375}, {
       4.097057141913445, -1.3622221848584006`}, {
       4.084292589556053, -1.4374999810329407`}}], 
      PolygonBox[{{4.097057141913445, -1.3622221848584006`}, {
       4.1875, -1.3247595264191645`}, {
       4.084292589556053, -1.4374999810329407`}, {
       4.097057141913445, -1.3622221848584006`}}], 
      PolygonBox[{{4.230251642536254, -1.4373449933535234`}, {
       4.084292589556053, -1.4374999810329407`}, {
       4.1875, -1.3247595264191645`}, {
       4.230251642536254, -1.4373449933535234`}}], 
      PolygonBox[{{4.1875, -1.3247595264191645`}, {
       4.265165042944956, -1.2651650429449552`}, {
       4.230251642536254, -1.4373449933535234`}, {
       4.1875, -1.3247595264191645`}}], 
      PolygonBox[{{4.404942744332997, -1.4049427443329972`}, {
       4.230251642536254, -1.4373449933535234`}, {
       4.265165042944956, -1.2651650429449552`}, {
       4.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{4.265165042944956, -1.2651650429449552`}, {
       4.265165042944956, -1.2651650429449552`}, {
       4.404942744332997, -1.4049427443329972`}, {
       4.265165042944956, -1.2651650429449552`}}], 
      PolygonBox[{{4.404942744332997, -1.4049427443329972`}, {
       4.404942744332997, -1.4049427443329972`}, {
       4.265165042944956, -1.2651650429449552`}, {
       4.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{4.404942744332997, -1.4049427443329972`}, {
       4.437344993353523, -1.230251642536255}, {4.5, -1.5}, {
       4.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{4.5, -1.3576627826493677`}, {4.5, -1.5}, {
       4.437344993353523, -1.230251642536255}, {4.5, -1.3576627826493677`}}], 
      PolygonBox[{{4.437344993353523, -1.230251642536255}, {
       4.437499981032941, -1.0842925895560618`}, {
       4.5, -1.3576627826493677`}, {4.437344993353523, -1.230251642536255}}], 
      PolygonBox[{{4.5, -1.20590900530174}, {4.5, -1.3576627826493677`}, {
       4.437499981032941, -1.0842925895560618`}, {4.5, -1.20590900530174}}], 
      PolygonBox[{{4.437499981032941, -1.0842925895560618`}, {4.4375, -1.}, {
       4.5, -1.20590900530174}, {4.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{4.5, -1.}, {4.5, -1.20590900530174}, {4.4375, -1.}, {
       4.5, -1.}}], 
      PolygonBox[{{4.4375, -1.}, {4.437499981032941, -0.9157074104439382}, {
       4.5, -1.}, {4.4375, -1.}}], 
      PolygonBox[{{4.5, -0.79409099469826}, {4.5, -1.}, {
       4.437499981032941, -0.9157074104439382}, {4.5, -0.79409099469826}}], 
      PolygonBox[{{4.437499981032941, -0.9157074104439382}, {
       4.437344993353523, -0.7697483574637449}, {4.5, -0.79409099469826}, {
       4.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{4.5, -0.6423372173506324}, {4.5, -0.79409099469826}, {
       4.437344993353523, -0.7697483574637449}, {4.5, -0.6423372173506324}}], 
      PolygonBox[{{4.437344993353523, -0.7697483574637449}, {
       4.404942744332997, -0.5950572556670028}, {4.5, -0.6423372173506324}, {
       4.437344993353523, -0.7697483574637449}}], 
      PolygonBox[{{4.491446564961186, -0.508553435038814}, {
       4.5, -0.6423372173506324}, {4.404942744332997, -0.5950572556670028}, {
       4.491446564961186, -0.508553435038814}}], 
      PolygonBox[{{4.404942744332997, -0.5950572556670028}, {
       4.230251642536255, -0.5626550066464766}, {
       4.491446564961186, -0.508553435038814}, {
       4.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{4.357662782649368, -0.5}, {
       4.491446564961186, -0.508553435038814}, {
       4.230251642536255, -0.5626550066464766}, {4.357662782649368, -0.5}}], 
      PolygonBox[{{4.230251642536255, -0.5626550066464766}, {
       4.0842925895560604`, -0.5625000189670593}, {4.357662782649368, -0.5}, {
       4.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{4.205909005373256, -0.5}, {4.357662782649368, -0.5}, {
       4.0842925895560604`, -0.5625000189670593}, {4.205909005373256, -0.5}}],
       PolygonBox[{{4.0842925895560604`, -0.5625000189670593}, {
       4.000105527220487, -0.5625}, {4.205909005373256, -0.5}, {
       4.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{4.07794195802689, -0.5}, {4.205909005373256, -0.5}, {
       4.000105527220487, -0.5625}, {4.07794195802689, -0.5}}], 
      PolygonBox[{{4.000105527220487, -0.5625}, {
       3.915707410443943, -0.5625000189670593}, {4.07794195802689, -0.5}, {
       4.000105527220487, -0.5625}}], 
      PolygonBox[{{3.7940909946955546`, -0.5}, {4.07794195802689, -0.5}, {
       3.915707410443943, -0.5625000189670593}, {3.7940909946955546`, -0.5}}],
       PolygonBox[{{3.915707410443943, -0.5625000189670593}, {
       3.769748357463745, -0.5626550066464766}, {3.7940909946955546`, -0.5}, {
       3.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{3.642337217350634, -0.5}, {3.7940909946955546`, -0.5}, {
       3.769748357463745, -0.5626550066464766}, {3.642337217350634, -0.5}}], 
      PolygonBox[{{3.769748357463745, -0.5626550066464766}, {
       3.595057255667003, -0.5950572556670028}, {3.642337217350634, -0.5}, {
       3.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{4.5, -0.5}, {3.642337217350634, -0.5}, {
       3.595057255667003, -0.5950572556670028}, {4.5, -0.5}}], 
      PolygonBox[{{3.595057255667003, -0.5950572556670028}, {
       3.5626550066464766`, -0.7697483574637446}, {4.5, -0.5}, {
       3.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{3.5, -0.642337217350631}, {4.5, -0.5}, {
       3.5626550066464766`, -0.7697483574637446}, {3.5, -0.642337217350631}}],
       PolygonBox[{{3.5626550066464766`, -0.7697483574637446}, {
       3.562500018967059, -0.9157074104439377}, {3.5, -0.642337217350631}, {
       3.5626550066464766`, -0.7697483574637446}}], 
      PolygonBox[{{3.5, -0.7940909947171011}, {3.5, -0.642337217350631}, {
       3.562500018967059, -0.9157074104439377}, {3.5, -0.7940909947171011}}], 
      PolygonBox[{{3.562500018967059, -0.9157074104439377}, {
       3.5625, -0.9998768219370047}, {3.5, -0.7940909947171011}, {
       3.562500018967059, -0.9157074104439377}}], 
      PolygonBox[{{3.5, -0.9193213332412997}, {3.5, -0.7940909947171011}, {
       3.5625, -0.9998768219370047}, {3.5, -0.9193213332412997}}], 
      PolygonBox[{{3.5625, -0.9998768219370047}, {
       3.562500018967059, -1.084292589556055}, {3.5, -0.9193213332412997}, {
       3.5625, -0.9998768219370047}}], 
      PolygonBox[{{3.5, -1.2059090051452785`}, {3.5, -0.9193213332412997}, {
       3.562500018967059, -1.084292589556055}, {3.5, -1.2059090051452785`}}], 
      PolygonBox[{{3.562500018967059, -1.084292589556055}, {
       3.5626550066464766`, -1.2302516425362549`}, {
       3.5, -1.2059090051452785`}, {3.562500018967059, -1.084292589556055}}], 
      PolygonBox[{{3.5, -1.3576627826493652`}, {3.5, -1.2059090051452785`}, {
       3.5626550066464766`, -1.2302516425362549`}, {
       3.5, -1.3576627826493652`}}], 
      PolygonBox[{{3.5626550066464766`, -1.2302516425362549`}, {
       3.595057255667003, -1.4049427443329972`}, {
       3.5, -1.3576627826493652`}, {
       3.5626550066464766`, -1.2302516425362549`}}], 
      PolygonBox[{{3.5, -0.5}, {3.5, -1.3576627826493652`}, {
       3.595057255667003, -1.4049427443329972`}, {3.5, -0.5}}], 
      PolygonBox[{{3.595057255667003, -1.4049427443329972`}, {
       3.769748357463745, -1.4373449933535234`}, {3.5, -0.5}, {
       3.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{3.5, -1.5}, {3.5, -0.5}, {
       3.769748357463745, -1.4373449933535234`}, {3.5, -1.5}}], 
      PolygonBox[{{3.769748357463745, -1.4373449933535234`}, {
       3.915707410443936, -1.4374999810329407`}, {3.5, -1.5}, {
       3.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{3.794090994433172, -1.5}, {3.5, -1.5}, {
       3.915707410443936, -1.4374999810329407`}, {3.794090994433172, -1.5}}], 
      PolygonBox[{{3.915707410443936, -1.4374999810329407`}, {
       4.000134841831043, -1.4375}, {3.794090994433172, -1.5}, {
       3.915707410443936, -1.4374999810329407`}}], 
      PolygonBox[{{4.082323870401062, -1.5}, {3.794090994433172, -1.5}, {
       4.000134841831043, -1.4375}, {4.082323870401062, -1.5}}], 
      PolygonBox[{{4.000134841831043, -1.4375}, {
       4.084292589556053, -1.4374999810329407`}, {4.082323870401062, -1.5}, {
       4.000134841831043, -1.4375}}], 
      PolygonBox[{{4.205909005360398, -1.5}, {4.082323870401062, -1.5}, {
       4.084292589556053, -1.4374999810329407`}, {4.205909005360398, -1.5}}], 
      PolygonBox[{{4.084292589556053, -1.4374999810329407`}, {
       4.230251642536254, -1.4373449933535234`}, {4.205909005360398, -1.5}, {
       4.084292589556053, -1.4374999810329407`}}], 
      PolygonBox[{{4.3576627826493715`, -1.5}, {4.205909005360398, -1.5}, {
       4.230251642536254, -1.4373449933535234`}, {
       4.3576627826493715`, -1.5}}], 
      PolygonBox[{{4.230251642536254, -1.4373449933535234`}, {
       4.404942744332997, -1.4049427443329972`}, {
       4.3576627826493715`, -1.5}, {
       4.230251642536254, -1.4373449933535234`}}], 
      PolygonBox[{{4.5, -1.5}, {4.3576627826493715`, -1.5}, {
       4.404942744332997, -1.4049427443329972`}, {4.5, -1.5}}], 
      PolygonBox[{{4.404942744332997, -1.4049427443329972`}, {
       4.404942744332997, -1.4049427443329972`}, {4.5, -1.5}, {
       4.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{4.5, -1.5}, {4.5, -1.5}, {
       4.404942744332997, -1.4049427443329972`}, {4.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, 0.}, {3.5208333333333335`, 0.}, {3.5416666666666665`, 
       0.}, {3.5625, 0.}, {3.5833333333333335`, 0.}, {3.6041666666666665`, 
       0.}, {3.625, 0.}, {3.625, 0.}, {3.6041666666666665`, 0.}, {
       3.5833333333333335`, 0.}, {3.5625, 0.}, {3.5416666666666665`, 0.}, {
       3.5208333333333335`, 0.}, {3.5, 0.}, {3.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, 0.}, {4.395833333333333, 0.}, {4.416666666666667, 
       0.}, {4.4375, 0.}, {4.458333333333333, 0.}, {4.479166666666667, 0.}, {
       4.5, 0.}, {4.5, 0.}, {4.479166666666667, 0.}, {4.458333333333333, 
       0.}, {4.4375, 0.}, {4.416666666666667, 0.}, {4.395833333333333, 0.}, {
       4.375, 0.}, {4.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -0.5}, {4., -0.4791666666666667}, {
       4., -0.4583333333333333}, {4., -0.4375}, {4., -0.4166666666666667}, {
       4., -0.39583333333333337`}, {4., -0.375}, {4., -0.375}, {
       4., -0.3958333333333333}, {4., -0.4166666666666667}, {4., -0.4375}, {
       4., -0.4583333333333333}, {4., -0.47916666666666663`}, {4., -0.5}, {
       4., -0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 0.375}, {4., 0.3958333333333333}, {4., 
       0.4166666666666667}, {4., 0.4375}, {4., 0.4583333333333333}, {4., 
       0.47916666666666663`}, {4., 0.5}, {4., 0.5}, {4., 
       0.4791666666666667}, {4., 0.4583333333333333}, {4., 0.4375}, {4., 
       0.4166666666666667}, {4., 0.39583333333333337`}, {4., 0.375}, {4., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, 0.}, {3.75, 0.}, {3.875, 0.}, {4., 0.}, {4.125, 0.}, {
       4.25, 0.}, {4.375, 0.}, {4.375, 0.}, {4.25, 0.}, {4.125, 0.}, {4., 
       0.}, {3.875, 0.}, {3.75, 0.}, {3.625, 0.}, {3.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -0.375}, {4., -0.25}, {4., -0.125}, {4., 0.}, {4., 
       0.125}, {4., 0.25}, {4., 0.375}, {4., 0.375}, {4., 0.25}, {4., 
       0.125}, {4., 0.}, {4., -0.125}, {4., -0.25}, {4., -0.375}, {
       4., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4w5teM8PhXRYIONzpjFu25scN+hvKTQ70+
gg7/weC4/blvZ3Pa+QUdbubcP1P244I9WNMBAYcGSye9Oyeu2KsXdX5KShZw
8O8v+7pU7zpEnkEAav4N+43Sb6WsLPkdApDlG/jg+lOFUtQ+PuB1uAU1/8IO
86onabwOLGCFJ+zF9AIdtaV4HR5A3Qcxl9eBq2uej2Vllw1M/hxEfj9M/x+I
+/enQM2/DjF/P8z+Ooj9+2Hu84O4bz+a+/fD/BeALA/0fxNUPyx8oO7fDws/
Noj798PC9x3UfbDwh7h/1h4ASliikQ==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhD6gX0oGAjC+atXgYAAnA+hBdDk+eD8MLB+
XjT1PAT5EH1X0fhH0dTDAI9DCER+Pyr/6n5U9Q8w+KGo7tuP5v79aP7bj+b/
/WjhA1UvRJAfhuI+GP8omnoYEIL5zx6Vf9UeVf0DewDGelVb
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, -0.2651650429449553}, {
       4.3247595264191645`, -0.1875}, {
       4.404942744332997, -0.4049427443329971}, {
       4.265165042944956, -0.2651650429449553}}], 
      PolygonBox[{{4.437344993353523, -0.23025164253625516`}, {
       4.404942744332997, -0.4049427443329971}, {
       4.3247595264191645`, -0.1875}, {
       4.437344993353523, -0.23025164253625516`}}], 
      PolygonBox[{{4.3247595264191645`, -0.1875}, {
       4.362222184858401, -0.0970571419134453}, {
       4.437344993353523, -0.23025164253625516`}, {
       4.3247595264191645`, -0.1875}}], 
      PolygonBox[{{4.437499981032941, -0.08429258955606181}, {
       4.437344993353523, -0.23025164253625516`}, {
       4.362222184858401, -0.0970571419134453}, {
       4.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{4.362222184858401, -0.0970571419134453}, {4.375, 0.}, {
       4.437499981032941, -0.08429258955606181}, {
       4.362222184858401, -0.0970571419134453}}], 
      PolygonBox[{{4.4375, 0.}, {4.437499981032941, -0.08429258955606181}, {
       4.375, 0.}, {4.4375, 0.}}], 
      PolygonBox[{{4.375, 0.}, {4.362222184858401, 0.09705714191344525}, {
       4.4375, 0.}, {4.375, 0.}}], 
      PolygonBox[{{4.437499981032941, 0.08429258955606177}, {4.4375, 0.}, {
       4.362222184858401, 0.09705714191344525}, {4.437499981032941, 
       0.08429258955606177}}], 
      PolygonBox[{{4.362222184858401, 0.09705714191344525}, {
       4.3247595264191645`, 0.18749999999999994`}, {4.437499981032941, 
       0.08429258955606177}, {4.362222184858401, 0.09705714191344525}}], 
      PolygonBox[{{4.437344993353523, 0.23025164253625502`}, {
       4.437499981032941, 0.08429258955606177}, {4.3247595264191645`, 
       0.18749999999999994`}, {4.437344993353523, 0.23025164253625502`}}], 
      PolygonBox[{{4.3247595264191645`, 0.18749999999999994`}, {
       4.265165042944956, 0.2651650429449553}, {4.437344993353523, 
       0.23025164253625502`}, {4.3247595264191645`, 0.18749999999999994`}}], 
      PolygonBox[{{4.404942744332997, 0.40494274433299715`}, {
       4.437344993353523, 0.23025164253625502`}, {4.265165042944956, 
       0.2651650429449553}, {4.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{4.265165042944956, 0.2651650429449553}, {4.1875, 
       0.3247595264191645}, {4.404942744332997, 0.40494274433299715`}, {
       4.265165042944956, 0.2651650429449553}}], 
      PolygonBox[{{4.230251642536255, 0.4373449933535234}, {4.404942744332997,
        0.40494274433299715`}, {4.1875, 0.3247595264191645}, {
       4.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{4.1875, 0.3247595264191645}, {4.097057141913445, 
       0.3622221848584006}, {4.230251642536255, 0.4373449933535234}, {4.1875, 
       0.3247595264191645}}], 
      PolygonBox[{{4.0842925895560604`, 0.4374999810329408}, {
       4.230251642536255, 0.4373449933535234}, {4.097057141913445, 
       0.3622221848584006}, {4.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{4.097057141913445, 0.3622221848584006}, {4., 0.375}, {
       4.0842925895560604`, 0.4374999810329408}, {4.097057141913445, 
       0.3622221848584006}}], 
      PolygonBox[{{4.000105527220487, 0.4375}, {4.0842925895560604`, 
       0.4374999810329408}, {4., 0.375}, {4.000105527220487, 0.4375}}], 
      PolygonBox[{{4., 0.375}, {3.902942858086555, 0.36222218485840063`}, {
       4.000105527220487, 0.4375}, {4., 0.375}}], 
      PolygonBox[{{3.915707410443943, 0.4374999810329408}, {4.000105527220487,
        0.4375}, {3.902942858086555, 0.36222218485840063`}, {
       3.915707410443943, 0.4374999810329408}}], 
      PolygonBox[{{3.902942858086555, 0.36222218485840063`}, {3.8125, 
       0.3247595264191645}, {3.915707410443943, 0.4374999810329408}, {
       3.902942858086555, 0.36222218485840063`}}], 
      PolygonBox[{{3.769748357463745, 0.4373449933535234}, {3.915707410443943,
        0.4374999810329408}, {3.8125, 0.3247595264191645}, {3.769748357463745,
        0.4373449933535234}}], 
      PolygonBox[{{3.8125, 0.3247595264191645}, {3.7348349570550448`, 
       0.26516504294495535`}, {3.769748357463745, 0.4373449933535234}, {
       3.8125, 0.3247595264191645}}], 
      PolygonBox[{{3.595057255667003, 0.40494274433299715`}, {
       3.769748357463745, 0.4373449933535234}, {3.7348349570550448`, 
       0.26516504294495535`}, {3.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{3.7348349570550448`, 0.26516504294495535`}, {
       3.6752404735808355`, 0.1875000000000001}, {3.595057255667003, 
       0.40494274433299715`}, {3.7348349570550448`, 0.26516504294495535`}}], 
      PolygonBox[{{3.5626550066464766`, 0.2302516425362554}, {
       3.595057255667003, 0.40494274433299715`}, {3.6752404735808355`, 
       0.1875000000000001}, {3.5626550066464766`, 0.2302516425362554}}], 
      PolygonBox[{{3.6752404735808355`, 0.1875000000000001}, {
       3.6377778151415994`, 0.09705714191344539}, {3.5626550066464766`, 
       0.2302516425362554}, {3.6752404735808355`, 0.1875000000000001}}], 
      PolygonBox[{{3.562500018967059, 0.08429258955606238}, {
       3.5626550066464766`, 0.2302516425362554}, {3.6377778151415994`, 
       0.09705714191344539}, {3.562500018967059, 0.08429258955606238}}], 
      PolygonBox[{{3.6377778151415994`, 0.09705714191344539}, {3.625, 
       2.1245770866179924`*^-16}, {3.562500018967059, 0.08429258955606238}, {
       3.6377778151415994`, 0.09705714191344539}}], 
      PolygonBox[{{3.5625, 0.00012317806299537147`}, {3.562500018967059, 
       0.08429258955606238}, {3.625, 2.1245770866179924`*^-16}, {3.5625, 
       0.00012317806299537147`}}], 
      PolygonBox[{{3.625, 2.1245770866179924`*^-16}, {
       3.6377778151415994`, -0.09705714191344514}, {3.5625, 
       0.00012317806299537147`}, {3.625, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{3.562500018967059, -0.084292589556055}, {3.5625, 
       0.00012317806299537147`}, {
       3.6377778151415994`, -0.09705714191344514}, {
       3.562500018967059, -0.084292589556055}}], 
      PolygonBox[{{3.6377778151415994`, -0.09705714191344514}, {
       3.6752404735808355`, -0.18749999999999978`}, {
       3.562500018967059, -0.084292589556055}, {
       3.6377778151415994`, -0.09705714191344514}}], 
      PolygonBox[{{3.5626550066464766`, -0.23025164253625477`}, {
       3.562500018967059, -0.084292589556055}, {
       3.6752404735808355`, -0.18749999999999978`}, {
       3.5626550066464766`, -0.23025164253625477`}}], 
      PolygonBox[{{3.6752404735808355`, -0.18749999999999978`}, {
       3.7348349570550448`, -0.2651650429449553}, {
       3.5626550066464766`, -0.23025164253625477`}, {
       3.6752404735808355`, -0.18749999999999978`}}], 
      PolygonBox[{{3.595057255667003, -0.4049427443329971}, {
       3.5626550066464766`, -0.23025164253625477`}, {
       3.7348349570550448`, -0.2651650429449553}, {
       3.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{3.7348349570550448`, -0.2651650429449553}, {
       3.8125, -0.3247595264191644}, {
       3.595057255667003, -0.4049427443329971}, {
       3.7348349570550448`, -0.2651650429449553}}], 
      PolygonBox[{{3.769748357463745, -0.4373449933535234}, {
       3.595057255667003, -0.4049427443329971}, {
       3.8125, -0.3247595264191644}, {
       3.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{3.8125, -0.3247595264191644}, {
       3.9029428580865546`, -0.3622221848584005}, {
       3.769748357463745, -0.4373449933535234}, {
       3.8125, -0.3247595264191644}}], 
      PolygonBox[{{3.915707410443936, -0.4374999810329408}, {
       3.769748357463745, -0.4373449933535234}, {
       3.9029428580865546`, -0.3622221848584005}, {
       3.915707410443936, -0.4374999810329408}}], 
      PolygonBox[{{3.9029428580865546`, -0.3622221848584005}, {4., -0.375}, {
       3.915707410443936, -0.4374999810329408}, {
       3.9029428580865546`, -0.3622221848584005}}], 
      PolygonBox[{{4.000134841831043, -0.4375}, {
       3.915707410443936, -0.4374999810329408}, {4., -0.375}, {
       4.000134841831043, -0.4375}}], 
      PolygonBox[{{4., -0.375}, {4.097057141913445, -0.36222218485840063`}, {
       4.000134841831043, -0.4375}, {4., -0.375}}], 
      PolygonBox[{{4.084292589556053, -0.4374999810329408}, {
       4.000134841831043, -0.4375}, {
       4.097057141913445, -0.36222218485840063`}, {
       4.084292589556053, -0.4374999810329408}}], 
      PolygonBox[{{4.097057141913445, -0.36222218485840063`}, {
       4.1875, -0.3247595264191646}, {
       4.084292589556053, -0.4374999810329408}, {
       4.097057141913445, -0.36222218485840063`}}], 
      PolygonBox[{{4.230251642536254, -0.4373449933535234}, {
       4.084292589556053, -0.4374999810329408}, {
       4.1875, -0.3247595264191646}, {
       4.230251642536254, -0.4373449933535234}}], 
      PolygonBox[{{4.1875, -0.3247595264191646}, {
       4.265165042944956, -0.26516504294495535`}, {
       4.230251642536254, -0.4373449933535234}, {
       4.1875, -0.3247595264191646}}], 
      PolygonBox[{{4.404942744332997, -0.40494274433299715`}, {
       4.230251642536254, -0.4373449933535234}, {
       4.265165042944956, -0.26516504294495535`}, {
       4.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{4.265165042944956, -0.26516504294495535`}, {
       4.265165042944956, -0.2651650429449553}, {
       4.404942744332997, -0.40494274433299715`}, {
       4.265165042944956, -0.26516504294495535`}}], 
      PolygonBox[{{4.404942744332997, -0.4049427443329971}, {
       4.404942744332997, -0.40494274433299715`}, {
       4.265165042944956, -0.2651650429449553}, {
       4.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{4.404942744332997, -0.4049427443329971}, {
       4.437344993353523, -0.23025164253625516`}, {4.5, -0.5}, {
       4.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{4.5, -0.3576627826493677}, {4.5, -0.5}, {
       4.437344993353523, -0.23025164253625516`}, {
       4.5, -0.3576627826493677}}], 
      PolygonBox[{{4.437344993353523, -0.23025164253625516`}, {
       4.437499981032941, -0.08429258955606181}, {4.5, -0.3576627826493677}, {
       4.437344993353523, -0.23025164253625516`}}], 
      PolygonBox[{{4.5, -0.20590900530173997`}, {4.5, -0.3576627826493677}, {
       4.437499981032941, -0.08429258955606181}, {
       4.5, -0.20590900530173997`}}], 
      PolygonBox[{{4.437499981032941, -0.08429258955606181}, {4.4375, 0.}, {
       4.5, -0.20590900530173997`}, {
       4.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{4.5, 0.}, {4.5, -0.20590900530173997`}, {4.4375, 0.}, {4.5,
        0.}}], PolygonBox[{{4.4375, 0.}, {4.437499981032941, 
       0.08429258955606177}, {4.5, 0.}, {4.4375, 0.}}], 
      PolygonBox[{{4.5, 0.20590900530173992`}, {4.5, 0.}, {4.437499981032941, 
       0.08429258955606177}, {4.5, 0.20590900530173992`}}], 
      PolygonBox[{{4.437499981032941, 0.08429258955606177}, {
       4.437344993353523, 0.23025164253625502`}, {4.5, 
       0.20590900530173992`}, {4.437499981032941, 0.08429258955606177}}], 
      PolygonBox[{{4.5, 0.35766278264936757`}, {4.5, 0.20590900530173992`}, {
       4.437344993353523, 0.23025164253625502`}, {4.5, 
       0.35766278264936757`}}], 
      PolygonBox[{{4.437344993353523, 0.23025164253625502`}, {
       4.404942744332997, 0.40494274433299715`}, {4.5, 
       0.35766278264936757`}, {4.437344993353523, 0.23025164253625502`}}], 
      PolygonBox[{{4.491446564961186, 0.491446564961186}, {4.5, 
       0.35766278264936757`}, {4.404942744332997, 0.40494274433299715`}, {
       4.491446564961186, 0.491446564961186}}], 
      PolygonBox[{{4.404942744332997, 0.40494274433299715`}, {
       4.230251642536255, 0.4373449933535234}, {4.491446564961186, 
       0.491446564961186}, {4.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{4.357662782649368, 0.5}, {4.491446564961186, 
       0.491446564961186}, {4.230251642536255, 0.4373449933535234}, {
       4.357662782649368, 0.5}}], 
      PolygonBox[{{4.230251642536255, 0.4373449933535234}, {
       4.0842925895560604`, 0.4374999810329408}, {4.357662782649368, 0.5}, {
       4.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{4.205909005373256, 0.5}, {4.357662782649368, 0.5}, {
       4.0842925895560604`, 0.4374999810329408}, {4.205909005373256, 0.5}}], 
      PolygonBox[{{4.0842925895560604`, 0.4374999810329408}, {
       4.000105527220487, 0.4375}, {4.205909005373256, 0.5}, {
       4.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{4.07794195802689, 0.5}, {4.205909005373256, 0.5}, {
       4.000105527220487, 0.4375}, {4.07794195802689, 0.5}}], 
      PolygonBox[{{4.000105527220487, 0.4375}, {3.915707410443943, 
       0.4374999810329408}, {4.07794195802689, 0.5}, {4.000105527220487, 
       0.4375}}], 
      PolygonBox[{{3.7940909946955546`, 0.5}, {4.07794195802689, 0.5}, {
       3.915707410443943, 0.4374999810329408}, {3.7940909946955546`, 0.5}}], 
      PolygonBox[{{3.915707410443943, 0.4374999810329408}, {3.769748357463745,
        0.4373449933535234}, {3.7940909946955546`, 0.5}, {3.915707410443943, 
       0.4374999810329408}}], 
      PolygonBox[{{3.642337217350634, 0.5}, {3.7940909946955546`, 0.5}, {
       3.769748357463745, 0.4373449933535234}, {3.642337217350634, 0.5}}], 
      PolygonBox[{{3.769748357463745, 0.4373449933535234}, {3.595057255667003,
        0.40494274433299715`}, {3.642337217350634, 0.5}, {3.769748357463745, 
       0.4373449933535234}}], 
      PolygonBox[{{4.5, 0.5}, {3.642337217350634, 0.5}, {3.595057255667003, 
       0.40494274433299715`}, {4.5, 0.5}}], 
      PolygonBox[{{3.595057255667003, 0.40494274433299715`}, {
       3.5626550066464766`, 0.2302516425362554}, {4.5, 0.5}, {
       3.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{3.5, 0.357662782649369}, {4.5, 0.5}, {3.5626550066464766`, 
       0.2302516425362554}, {3.5, 0.357662782649369}}], 
      PolygonBox[{{3.5626550066464766`, 0.2302516425362554}, {
       3.562500018967059, 0.08429258955606238}, {3.5, 0.357662782649369}, {
       3.5626550066464766`, 0.2302516425362554}}], 
      PolygonBox[{{3.5, 0.20590900528289896`}, {3.5, 0.357662782649369}, {
       3.562500018967059, 0.08429258955606238}, {3.5, 0.20590900528289896`}}],
       PolygonBox[{{3.562500018967059, 0.08429258955606238}, {3.5625, 
       0.00012317806299537147`}, {3.5, 0.20590900528289896`}, {
       3.562500018967059, 0.08429258955606238}}], 
      PolygonBox[{{3.5, 0.08067866675870025}, {3.5, 0.20590900528289896`}, {
       3.5625, 0.00012317806299537147`}, {3.5, 0.08067866675870025}}], 
      PolygonBox[{{3.5625, 0.00012317806299537147`}, {
       3.562500018967059, -0.084292589556055}, {3.5, 0.08067866675870025}, {
       3.5625, 0.00012317806299537147`}}], 
      PolygonBox[{{3.5, -0.20590900514527852`}, {3.5, 0.08067866675870025}, {
       3.562500018967059, -0.084292589556055}, {3.5, -0.20590900514527852`}}],
       PolygonBox[{{3.562500018967059, -0.084292589556055}, {
       3.5626550066464766`, -0.23025164253625477`}, {
       3.5, -0.20590900514527852`}, {3.562500018967059, -0.084292589556055}}],
       PolygonBox[{{3.5, -0.35766278264936535`}, {
       3.5, -0.20590900514527852`}, {
       3.5626550066464766`, -0.23025164253625477`}, {
       3.5, -0.35766278264936535`}}], 
      PolygonBox[{{3.5626550066464766`, -0.23025164253625477`}, {
       3.595057255667003, -0.4049427443329971}, {
       3.5, -0.35766278264936535`}, {
       3.5626550066464766`, -0.23025164253625477`}}], 
      PolygonBox[{{3.5, 0.5}, {3.5, -0.35766278264936535`}, {
       3.595057255667003, -0.4049427443329971}, {3.5, 0.5}}], 
      PolygonBox[{{3.595057255667003, -0.4049427443329971}, {
       3.769748357463745, -0.4373449933535234}, {3.5, 0.5}, {
       3.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{3.5, -0.5}, {3.5, 0.5}, {
       3.769748357463745, -0.4373449933535234}, {3.5, -0.5}}], 
      PolygonBox[{{3.769748357463745, -0.4373449933535234}, {
       3.915707410443936, -0.4374999810329408}, {3.5, -0.5}, {
       3.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{3.794090994433172, -0.5}, {3.5, -0.5}, {
       3.915707410443936, -0.4374999810329408}, {3.794090994433172, -0.5}}], 
      PolygonBox[{{3.915707410443936, -0.4374999810329408}, {
       4.000134841831043, -0.4375}, {3.794090994433172, -0.5}, {
       3.915707410443936, -0.4374999810329408}}], 
      PolygonBox[{{4.082323870401062, -0.5}, {3.794090994433172, -0.5}, {
       4.000134841831043, -0.4375}, {4.082323870401062, -0.5}}], 
      PolygonBox[{{4.000134841831043, -0.4375}, {
       4.084292589556053, -0.4374999810329408}, {4.082323870401062, -0.5}, {
       4.000134841831043, -0.4375}}], 
      PolygonBox[{{4.205909005360398, -0.5}, {4.082323870401062, -0.5}, {
       4.084292589556053, -0.4374999810329408}, {4.205909005360398, -0.5}}], 
      PolygonBox[{{4.084292589556053, -0.4374999810329408}, {
       4.230251642536254, -0.4373449933535234}, {4.205909005360398, -0.5}, {
       4.084292589556053, -0.4374999810329408}}], 
      PolygonBox[{{4.3576627826493715`, -0.5}, {4.205909005360398, -0.5}, {
       4.230251642536254, -0.4373449933535234}, {4.3576627826493715`, -0.5}}],
       PolygonBox[{{4.230251642536254, -0.4373449933535234}, {
       4.404942744332997, -0.40494274433299715`}, {
       4.3576627826493715`, -0.5}, {4.230251642536254, -0.4373449933535234}}],
       PolygonBox[{{4.5, -0.5}, {4.3576627826493715`, -0.5}, {
       4.404942744332997, -0.40494274433299715`}, {4.5, -0.5}}], 
      PolygonBox[{{4.404942744332997, -0.40494274433299715`}, {
       4.404942744332997, -0.4049427443329971}, {4.5, -0.5}, {
       4.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{4.5, -0.5}, {4.5, -0.5}, {
       4.404942744332997, -0.4049427443329971}, {
       4.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, 1.}, {3.5208333333333335`, 1.}, {3.5416666666666665`, 
       1.}, {3.5625, 1.}, {3.5833333333333335`, 1.}, {3.6041666666666665`, 
       1.}, {3.625, 1.}, {3.625, 1.}, {3.6041666666666665`, 1.}, {
       3.5833333333333335`, 1.}, {3.5625, 1.}, {3.5416666666666665`, 1.}, {
       3.5208333333333335`, 1.}, {3.5, 1.}, {3.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, 1.}, {4.395833333333333, 1.}, {4.416666666666667, 
       1.}, {4.4375, 1.}, {4.458333333333333, 1.}, {4.479166666666667, 1.}, {
       4.5, 1.}, {4.5, 1.}, {4.479166666666667, 1.}, {4.458333333333333, 
       1.}, {4.4375, 1.}, {4.416666666666667, 1.}, {4.395833333333333, 1.}, {
       4.375, 1.}, {4.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 0.5}, {4., 0.5208333333333333}, {4., 
       0.5416666666666667}, {4., 0.5625}, {4., 0.5833333333333333}, {4., 
       0.6041666666666666}, {4., 0.625}, {4., 0.625}, {4., 
       0.6041666666666667}, {4., 0.5833333333333333}, {4., 0.5625}, {4., 
       0.5416666666666667}, {4., 0.5208333333333334}, {4., 0.5}, {4., 0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 1.375}, {4., 1.3958333333333333`}, {4., 
       1.4166666666666667`}, {4., 1.4375}, {4., 1.4583333333333333`}, {4., 
       1.4791666666666665`}, {4., 1.5}, {4., 1.5}, {4., 
       1.4791666666666667`}, {4., 1.4583333333333333`}, {4., 1.4375}, {4., 
       1.4166666666666667`}, {4., 1.3958333333333335`}, {4., 1.375}, {4., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, 1.}, {3.75, 1.}, {3.875, 1.}, {4., 1.}, {4.125, 1.}, {
       4.25, 1.}, {4.375, 1.}, {4.375, 1.}, {4.25, 1.}, {4.125, 1.}, {4., 
       1.}, {3.875, 1.}, {3.75, 1.}, {3.625, 1.}, {3.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 0.625}, {4., 0.75}, {4., 0.875}, {4., 1.}, {4., 1.125}, {
       4., 1.25}, {4., 1.375}, {4., 1.375}, {4., 1.25}, {4., 1.125}, {4., 
       1.}, {4., 0.875}, {4., 0.75}, {4., 0.625}, {4., 0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4Qxgf7rxnh8a+KBB3mnVA91d370X6G8pND
vT4w+c/2576dzWnnF3Qwu22+Wdbuiz1Y+ICAQ0LfBG5zo6/26kWdn5KSBRyu
LI6tXXn6K0SeQQCq/5v9Rum3UlaW/KjyDXxw/alCKWofH/DCzb+ww7zqSRov
3H4xvUBHbSleuPsg4jD5D3D5Y3lbsl88eQPXzwiWf2WfAjV/iueEmUean8Pt
d3x878XE2U/h7ovc4cK6NuMJmvufwP0XgSwP9L89VD8sfCZDzYeF37//IPAS
Hr6HoO6DhT9Y+v97ewAuuJa6
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhD6h30oGAjC+atXgYAAnA+hBdDk+eD8MLB+
XjT1PAT5EH1f4XyIuZ/Q1H9Ak3+Fpv8pmvoHGPxQFPc9QHP/AzT/PUDz/wO0
8IGpFyLID0Vxn5DDKhT3w9R/QJP/hKb/K5r6H/YAGe9bEQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, 0.7348349570550448}, {
       4.3247595264191645`, 0.8125}, {4.404942744332997, 
       0.5950572556670028}, {4.265165042944956, 0.7348349570550448}}], 
      PolygonBox[{{4.437344993353523, 0.7697483574637448}, {4.404942744332997,
        0.5950572556670028}, {4.3247595264191645`, 0.8125}, {
       4.437344993353523, 0.7697483574637448}}], 
      PolygonBox[{{4.3247595264191645`, 0.8125}, {4.362222184858401, 
       0.9029428580865547}, {4.437344993353523, 0.7697483574637448}, {
       4.3247595264191645`, 0.8125}}], 
      PolygonBox[{{4.437499981032941, 0.9157074104439382}, {4.437344993353523,
        0.7697483574637448}, {4.362222184858401, 0.9029428580865547}, {
       4.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{4.362222184858401, 0.9029428580865547}, {4.375, 1.}, {
       4.437499981032941, 0.9157074104439382}, {4.362222184858401, 
       0.9029428580865547}}], 
      PolygonBox[{{4.4375, 1.}, {4.437499981032941, 0.9157074104439382}, {
       4.375, 1.}, {4.4375, 1.}}], 
      PolygonBox[{{4.375, 1.}, {4.362222184858401, 1.0970571419134452`}, {
       4.4375, 1.}, {4.375, 1.}}], 
      PolygonBox[{{4.437499981032941, 1.0842925895560618`}, {4.4375, 1.}, {
       4.362222184858401, 1.0970571419134452`}, {4.437499981032941, 
       1.0842925895560618`}}], 
      PolygonBox[{{4.362222184858401, 1.0970571419134452`}, {
       4.3247595264191645`, 1.1875}, {4.437499981032941, 
       1.0842925895560618`}, {4.362222184858401, 1.0970571419134452`}}], 
      PolygonBox[{{4.437344993353523, 1.230251642536255}, {4.437499981032941, 
       1.0842925895560618`}, {4.3247595264191645`, 1.1875}, {
       4.437344993353523, 1.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, 1.1875}, {4.265165042944956, 
       1.2651650429449552`}, {4.437344993353523, 1.230251642536255}, {
       4.3247595264191645`, 1.1875}}], 
      PolygonBox[{{4.404942744332997, 1.4049427443329972`}, {
       4.437344993353523, 1.230251642536255}, {4.265165042944956, 
       1.2651650429449552`}, {4.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{4.265165042944956, 1.2651650429449552`}, {4.1875, 
       1.3247595264191645`}, {4.404942744332997, 1.4049427443329972`}, {
       4.265165042944956, 1.2651650429449552`}}], 
      PolygonBox[{{4.230251642536255, 1.4373449933535234`}, {
       4.404942744332997, 1.4049427443329972`}, {4.1875, 
       1.3247595264191645`}, {4.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{4.1875, 1.3247595264191645`}, {4.097057141913445, 
       1.3622221848584006`}, {4.230251642536255, 1.4373449933535234`}, {
       4.1875, 1.3247595264191645`}}], 
      PolygonBox[{{4.0842925895560604`, 1.4374999810329407`}, {
       4.230251642536255, 1.4373449933535234`}, {4.097057141913445, 
       1.3622221848584006`}, {4.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{4.097057141913445, 1.3622221848584006`}, {4., 1.375}, {
       4.0842925895560604`, 1.4374999810329407`}, {4.097057141913445, 
       1.3622221848584006`}}], 
      PolygonBox[{{4.000105527220487, 1.4375}, {4.0842925895560604`, 
       1.4374999810329407`}, {4., 1.375}, {4.000105527220487, 1.4375}}], 
      PolygonBox[{{4., 1.375}, {3.902942858086555, 1.3622221848584006`}, {
       4.000105527220487, 1.4375}, {4., 1.375}}], 
      PolygonBox[{{3.915707410443943, 1.4374999810329407`}, {
       4.000105527220487, 1.4375}, {3.902942858086555, 1.3622221848584006`}, {
       3.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{3.902942858086555, 1.3622221848584006`}, {3.8125, 
       1.3247595264191645`}, {3.915707410443943, 1.4374999810329407`}, {
       3.902942858086555, 1.3622221848584006`}}], 
      PolygonBox[{{3.769748357463745, 1.4373449933535234`}, {
       3.915707410443943, 1.4374999810329407`}, {3.8125, 
       1.3247595264191645`}, {3.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{3.8125, 1.3247595264191645`}, {3.7348349570550448`, 
       1.2651650429449552`}, {3.769748357463745, 1.4373449933535234`}, {
       3.8125, 1.3247595264191645`}}], 
      PolygonBox[{{3.595057255667003, 1.4049427443329972`}, {
       3.769748357463745, 1.4373449933535234`}, {3.7348349570550448`, 
       1.2651650429449552`}, {3.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{3.7348349570550448`, 1.2651650429449552`}, {
       3.6752404735808355`, 1.1875}, {3.595057255667003, 
       1.4049427443329972`}, {3.7348349570550448`, 1.2651650429449552`}}], 
      PolygonBox[{{3.5626550066464766`, 1.2302516425362553`}, {
       3.595057255667003, 1.4049427443329972`}, {3.6752404735808355`, 
       1.1875}, {3.5626550066464766`, 1.2302516425362553`}}], 
      PolygonBox[{{3.6752404735808355`, 1.1875}, {3.6377778151415994`, 
       1.0970571419134454`}, {3.5626550066464766`, 1.2302516425362553`}, {
       3.6752404735808355`, 1.1875}}], 
      PolygonBox[{{3.562500018967059, 1.0842925895560624`}, {
       3.5626550066464766`, 1.2302516425362553`}, {3.6377778151415994`, 
       1.0970571419134454`}, {3.562500018967059, 1.0842925895560624`}}], 
      PolygonBox[{{3.6377778151415994`, 1.0970571419134454`}, {3.625, 
       1.0000000000000002`}, {3.562500018967059, 1.0842925895560624`}, {
       3.6377778151415994`, 1.0970571419134454`}}], 
      PolygonBox[{{3.5625, 1.0001231780629953`}, {3.562500018967059, 
       1.0842925895560624`}, {3.625, 1.0000000000000002`}, {3.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{3.625, 1.0000000000000002`}, {3.6377778151415994`, 
       0.9029428580865548}, {3.5625, 1.0001231780629953`}, {3.625, 
       1.0000000000000002`}}], 
      PolygonBox[{{3.562500018967059, 0.915707410443945}, {3.5625, 
       1.0001231780629953`}, {3.6377778151415994`, 0.9029428580865548}, {
       3.562500018967059, 0.915707410443945}}], 
      PolygonBox[{{3.6377778151415994`, 0.9029428580865548}, {
       3.6752404735808355`, 0.8125000000000002}, {3.562500018967059, 
       0.915707410443945}, {3.6377778151415994`, 0.9029428580865548}}], 
      PolygonBox[{{3.5626550066464766`, 0.7697483574637453}, {
       3.562500018967059, 0.915707410443945}, {3.6752404735808355`, 
       0.8125000000000002}, {3.5626550066464766`, 0.7697483574637453}}], 
      PolygonBox[{{3.6752404735808355`, 0.8125000000000002}, {
       3.7348349570550448`, 0.7348349570550448}, {3.5626550066464766`, 
       0.7697483574637453}, {3.6752404735808355`, 0.8125000000000002}}], 
      PolygonBox[{{3.595057255667003, 0.5950572556670028}, {
       3.5626550066464766`, 0.7697483574637453}, {3.7348349570550448`, 
       0.7348349570550448}, {3.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{3.7348349570550448`, 0.7348349570550448}, {3.8125, 
       0.6752404735808356}, {3.595057255667003, 0.5950572556670028}, {
       3.7348349570550448`, 0.7348349570550448}}], 
      PolygonBox[{{3.769748357463745, 0.5626550066464766}, {3.595057255667003,
        0.5950572556670028}, {3.8125, 0.6752404735808356}, {3.769748357463745,
        0.5626550066464766}}], 
      PolygonBox[{{3.8125, 0.6752404735808356}, {3.9029428580865546`, 
       0.6377778151415995}, {3.769748357463745, 0.5626550066464766}, {3.8125, 
       0.6752404735808356}}], 
      PolygonBox[{{3.915707410443936, 0.5625000189670593}, {3.769748357463745,
        0.5626550066464766}, {3.9029428580865546`, 0.6377778151415995}, {
       3.915707410443936, 0.5625000189670593}}], 
      PolygonBox[{{3.9029428580865546`, 0.6377778151415995}, {4., 0.625}, {
       3.915707410443936, 0.5625000189670593}, {3.9029428580865546`, 
       0.6377778151415995}}], 
      PolygonBox[{{4.000134841831043, 0.5625}, {3.915707410443936, 
       0.5625000189670593}, {4., 0.625}, {4.000134841831043, 0.5625}}], 
      PolygonBox[{{4., 0.625}, {4.097057141913445, 0.6377778151415994}, {
       4.000134841831043, 0.5625}, {4., 0.625}}], 
      PolygonBox[{{4.084292589556053, 0.5625000189670593}, {4.000134841831043,
        0.5625}, {4.097057141913445, 0.6377778151415994}, {4.084292589556053, 
       0.5625000189670593}}], 
      PolygonBox[{{4.097057141913445, 0.6377778151415994}, {4.1875, 
       0.6752404735808354}, {4.084292589556053, 0.5625000189670593}, {
       4.097057141913445, 0.6377778151415994}}], 
      PolygonBox[{{4.230251642536254, 0.5626550066464766}, {4.084292589556053,
        0.5625000189670593}, {4.1875, 0.6752404735808354}, {4.230251642536254,
        0.5626550066464766}}], 
      PolygonBox[{{4.1875, 0.6752404735808354}, {4.265165042944956, 
       0.7348349570550446}, {4.230251642536254, 0.5626550066464766}, {4.1875, 
       0.6752404735808354}}], 
      PolygonBox[{{4.404942744332997, 0.5950572556670028}, {4.230251642536254,
        0.5626550066464766}, {4.265165042944956, 0.7348349570550446}, {
       4.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{4.265165042944956, 0.7348349570550446}, {4.265165042944956,
        0.7348349570550448}, {4.404942744332997, 0.5950572556670028}, {
       4.265165042944956, 0.7348349570550446}}], 
      PolygonBox[{{4.404942744332997, 0.5950572556670028}, {4.404942744332997,
        0.5950572556670028}, {4.265165042944956, 0.7348349570550448}, {
       4.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{4.404942744332997, 0.5950572556670028}, {4.437344993353523,
        0.7697483574637448}, {4.5, 0.5}, {4.404942744332997, 
       0.5950572556670028}}], 
      PolygonBox[{{4.5, 0.6423372173506323}, {4.5, 0.5}, {4.437344993353523, 
       0.7697483574637448}, {4.5, 0.6423372173506323}}], 
      PolygonBox[{{4.437344993353523, 0.7697483574637448}, {4.437499981032941,
        0.9157074104439382}, {4.5, 0.6423372173506323}, {4.437344993353523, 
       0.7697483574637448}}], 
      PolygonBox[{{4.5, 0.79409099469826}, {4.5, 0.6423372173506323}, {
       4.437499981032941, 0.9157074104439382}, {4.5, 0.79409099469826}}], 
      PolygonBox[{{4.437499981032941, 0.9157074104439382}, {4.4375, 1.}, {4.5,
        0.79409099469826}, {4.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{4.5, 1.}, {4.5, 0.79409099469826}, {4.4375, 1.}, {4.5, 
       1.}}], PolygonBox[{{4.4375, 1.}, {4.437499981032941, 
       1.0842925895560618`}, {4.5, 1.}, {4.4375, 1.}}], 
      PolygonBox[{{4.5, 1.2059090053017398`}, {4.5, 1.}, {4.437499981032941, 
       1.0842925895560618`}, {4.5, 1.2059090053017398`}}], 
      PolygonBox[{{4.437499981032941, 1.0842925895560618`}, {
       4.437344993353523, 1.230251642536255}, {4.5, 1.2059090053017398`}, {
       4.437499981032941, 1.0842925895560618`}}], 
      PolygonBox[{{4.5, 1.3576627826493675`}, {4.5, 1.2059090053017398`}, {
       4.437344993353523, 1.230251642536255}, {4.5, 1.3576627826493675`}}], 
      PolygonBox[{{4.437344993353523, 1.230251642536255}, {4.404942744332997, 
       1.4049427443329972`}, {4.5, 1.3576627826493675`}, {4.437344993353523, 
       1.230251642536255}}], 
      PolygonBox[{{4.491446564961186, 1.491446564961186}, {4.5, 
       1.3576627826493675`}, {4.404942744332997, 1.4049427443329972`}, {
       4.491446564961186, 1.491446564961186}}], 
      PolygonBox[{{4.404942744332997, 1.4049427443329972`}, {
       4.230251642536255, 1.4373449933535234`}, {4.491446564961186, 
       1.491446564961186}, {4.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{4.357662782649368, 1.5}, {4.491446564961186, 
       1.491446564961186}, {4.230251642536255, 1.4373449933535234`}, {
       4.357662782649368, 1.5}}], 
      PolygonBox[{{4.230251642536255, 1.4373449933535234`}, {
       4.0842925895560604`, 1.4374999810329407`}, {4.357662782649368, 1.5}, {
       4.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{4.205909005373256, 1.5}, {4.357662782649368, 1.5}, {
       4.0842925895560604`, 1.4374999810329407`}, {4.205909005373256, 1.5}}], 
      PolygonBox[{{4.0842925895560604`, 1.4374999810329407`}, {
       4.000105527220487, 1.4375}, {4.205909005373256, 1.5}, {
       4.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{4.07794195802689, 1.5}, {4.205909005373256, 1.5}, {
       4.000105527220487, 1.4375}, {4.07794195802689, 1.5}}], 
      PolygonBox[{{4.000105527220487, 1.4375}, {3.915707410443943, 
       1.4374999810329407`}, {4.07794195802689, 1.5}, {4.000105527220487, 
       1.4375}}], 
      PolygonBox[{{3.7940909946955546`, 1.5}, {4.07794195802689, 1.5}, {
       3.915707410443943, 1.4374999810329407`}, {3.7940909946955546`, 1.5}}], 
      PolygonBox[{{3.915707410443943, 1.4374999810329407`}, {
       3.769748357463745, 1.4373449933535234`}, {3.7940909946955546`, 1.5}, {
       3.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{3.642337217350634, 1.5}, {3.7940909946955546`, 1.5}, {
       3.769748357463745, 1.4373449933535234`}, {3.642337217350634, 1.5}}], 
      PolygonBox[{{3.769748357463745, 1.4373449933535234`}, {
       3.595057255667003, 1.4049427443329972`}, {3.642337217350634, 1.5}, {
       3.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{4.5, 1.5}, {3.642337217350634, 1.5}, {3.595057255667003, 
       1.4049427443329972`}, {4.5, 1.5}}], 
      PolygonBox[{{3.595057255667003, 1.4049427443329972`}, {
       3.5626550066464766`, 1.2302516425362553`}, {4.5, 1.5}, {
       3.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{3.5, 1.357662782649369}, {4.5, 1.5}, {3.5626550066464766`, 
       1.2302516425362553`}, {3.5, 1.357662782649369}}], 
      PolygonBox[{{3.5626550066464766`, 1.2302516425362553`}, {
       3.562500018967059, 1.0842925895560624`}, {3.5, 1.357662782649369}, {
       3.5626550066464766`, 1.2302516425362553`}}], 
      PolygonBox[{{3.5, 1.205909005282899}, {3.5, 1.357662782649369}, {
       3.562500018967059, 1.0842925895560624`}, {3.5, 1.205909005282899}}], 
      PolygonBox[{{3.562500018967059, 1.0842925895560624`}, {3.5625, 
       1.0001231780629953`}, {3.5, 1.205909005282899}, {3.562500018967059, 
       1.0842925895560624`}}], 
      PolygonBox[{{3.5, 1.0806786667587003`}, {3.5, 1.205909005282899}, {
       3.5625, 1.0001231780629953`}, {3.5, 1.0806786667587003`}}], 
      PolygonBox[{{3.5625, 1.0001231780629953`}, {3.562500018967059, 
       0.915707410443945}, {3.5, 1.0806786667587003`}, {3.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{3.5, 0.7940909948547215}, {3.5, 1.0806786667587003`}, {
       3.562500018967059, 0.915707410443945}, {3.5, 0.7940909948547215}}], 
      PolygonBox[{{3.562500018967059, 0.915707410443945}, {
       3.5626550066464766`, 0.7697483574637453}, {3.5, 0.7940909948547215}, {
       3.562500018967059, 0.915707410443945}}], 
      PolygonBox[{{3.5, 0.6423372173506346}, {3.5, 0.7940909948547215}, {
       3.5626550066464766`, 0.7697483574637453}, {3.5, 0.6423372173506346}}], 
      PolygonBox[{{3.5626550066464766`, 0.7697483574637453}, {
       3.595057255667003, 0.5950572556670028}, {3.5, 0.6423372173506346}, {
       3.5626550066464766`, 0.7697483574637453}}], 
      PolygonBox[{{3.5, 1.5}, {3.5, 0.6423372173506346}, {3.595057255667003, 
       0.5950572556670028}, {3.5, 1.5}}], 
      PolygonBox[{{3.595057255667003, 0.5950572556670028}, {3.769748357463745,
        0.5626550066464766}, {3.5, 1.5}, {3.595057255667003, 
       0.5950572556670028}}], 
      PolygonBox[{{3.5, 0.5}, {3.5, 1.5}, {3.769748357463745, 
       0.5626550066464766}, {3.5, 0.5}}], 
      PolygonBox[{{3.769748357463745, 0.5626550066464766}, {3.915707410443936,
        0.5625000189670593}, {3.5, 0.5}, {3.769748357463745, 
       0.5626550066464766}}], 
      PolygonBox[{{3.794090994433172, 0.5}, {3.5, 0.5}, {3.915707410443936, 
       0.5625000189670593}, {3.794090994433172, 0.5}}], 
      PolygonBox[{{3.915707410443936, 0.5625000189670593}, {4.000134841831043,
        0.5625}, {3.794090994433172, 0.5}, {3.915707410443936, 
       0.5625000189670593}}], 
      PolygonBox[{{4.082323870401062, 0.5}, {3.794090994433172, 0.5}, {
       4.000134841831043, 0.5625}, {4.082323870401062, 0.5}}], 
      PolygonBox[{{4.000134841831043, 0.5625}, {4.084292589556053, 
       0.5625000189670593}, {4.082323870401062, 0.5}, {4.000134841831043, 
       0.5625}}], 
      PolygonBox[{{4.205909005360398, 0.5}, {4.082323870401062, 0.5}, {
       4.084292589556053, 0.5625000189670593}, {4.205909005360398, 0.5}}], 
      PolygonBox[{{4.084292589556053, 0.5625000189670593}, {4.230251642536254,
        0.5626550066464766}, {4.205909005360398, 0.5}, {4.084292589556053, 
       0.5625000189670593}}], 
      PolygonBox[{{4.3576627826493715`, 0.5}, {4.205909005360398, 0.5}, {
       4.230251642536254, 0.5626550066464766}, {4.3576627826493715`, 0.5}}], 
      PolygonBox[{{4.230251642536254, 0.5626550066464766}, {4.404942744332997,
        0.5950572556670028}, {4.3576627826493715`, 0.5}, {4.230251642536254, 
       0.5626550066464766}}], 
      PolygonBox[{{4.5, 0.5}, {4.3576627826493715`, 0.5}, {4.404942744332997, 
       0.5950572556670028}, {4.5, 0.5}}], 
      PolygonBox[{{4.404942744332997, 0.5950572556670028}, {4.404942744332997,
        0.5950572556670028}, {4.5, 0.5}, {4.404942744332997, 
       0.5950572556670028}}], 
      PolygonBox[{{4.5, 0.5}, {4.5, 0.5}, {4.404942744332997, 
       0.5950572556670028}, {4.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, 2.}, {3.5208333333333335`, 2.}, {3.5416666666666665`, 
       2.}, {3.5625, 2.}, {3.5833333333333335`, 2.}, {3.6041666666666665`, 
       2.}, {3.625, 2.}, {3.625, 2.}, {3.6041666666666665`, 2.}, {
       3.5833333333333335`, 2.}, {3.5625, 2.}, {3.5416666666666665`, 2.}, {
       3.5208333333333335`, 2.}, {3.5, 2.}, {3.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, 2.}, {4.395833333333333, 2.}, {4.416666666666667, 
       2.}, {4.4375, 2.}, {4.458333333333333, 2.}, {4.479166666666667, 2.}, {
       4.5, 2.}, {4.5, 2.}, {4.479166666666667, 2.}, {4.458333333333333, 
       2.}, {4.4375, 2.}, {4.416666666666667, 2.}, {4.395833333333333, 2.}, {
       4.375, 2.}, {4.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 1.5}, {4., 1.5208333333333333`}, {4., 
       1.5416666666666667`}, {4., 1.5625}, {4., 1.5833333333333333`}, {4., 
       1.6041666666666665`}, {4., 1.625}, {4., 1.625}, {4., 
       1.6041666666666667`}, {4., 1.5833333333333333`}, {4., 1.5625}, {4., 
       1.5416666666666667`}, {4., 1.5208333333333335`}, {4., 1.5}, {4., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 2.375}, {4., 2.3958333333333335`}, {4., 
       2.4166666666666665`}, {4., 2.4375}, {4., 2.4583333333333335`}, {4., 
       2.4791666666666665`}, {4., 2.5}, {4., 2.5}, {4., 
       2.4791666666666665`}, {4., 2.4583333333333335`}, {4., 2.4375}, {4., 
       2.4166666666666665`}, {4., 2.3958333333333335`}, {4., 2.375}, {4., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, 2.}, {3.75, 2.}, {3.875, 2.}, {4., 2.}, {4.125, 2.}, {
       4.25, 2.}, {4.375, 2.}, {4.375, 2.}, {4.25, 2.}, {4.125, 2.}, {4., 
       2.}, {3.875, 2.}, {3.75, 2.}, {3.625, 2.}, {3.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 1.625}, {4., 1.75}, {4., 1.875}, {4., 2.}, {4., 2.125}, {
       4., 2.25}, {4., 2.375}, {4., 2.375}, {4., 2.25}, {4., 2.125}, {4., 
       2.}, {4., 1.875}, {4., 1.75}, {4., 1.625}, {4., 1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg5QlsPXjPD4V0WCDv5PhJ4ePcbgMEP5yaFe
H6h8A6PDuW9nc9r5BR1mv519k0+eCSJ+QMDBwP1Eq/RMJgf1os5PSckCDq8u
rtt35SlUnkEASjM7bJR+K2VlyY8q38AH158qlKL28QEv3PwLO8yrnqTxwu0X
0wt01JbihbsPYi4v3P0w+WTzW6YlRf/sUfQz/LVPgZp/SuWEz6ODv+1h9i8o
zP9y4uwve5j7dGIWNYWZ/LJHdf8ve5j/UOSB/ofph4UPzHxY+P0Hgz/2sPBN
hLoPPfwBuhuH9g==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhCaxSEUDATh/NWrQEAAzofQAmjyfHB+GFg/
L5p6HoJ8iDlMcD7EHYxo6hngfIg9f+1R9f+yR1X/A4MfiuK+H/ao7oepF0CT
F0DTL4imXoggfxWK+4Sg/vuLph7mPyE0/8P0MzmgqmdxAAAKXE4L
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, 1.7348349570550448`}, {
       4.3247595264191645`, 1.8125}, {4.404942744332997, 
       1.5950572556670028`}, {4.265165042944956, 1.7348349570550448`}}], 
      PolygonBox[{{4.437344993353523, 1.769748357463745}, {4.404942744332997, 
       1.5950572556670028`}, {4.3247595264191645`, 1.8125}, {
       4.437344993353523, 1.769748357463745}}], 
      PolygonBox[{{4.3247595264191645`, 1.8125}, {4.362222184858401, 
       1.9029428580865546`}, {4.437344993353523, 1.769748357463745}, {
       4.3247595264191645`, 1.8125}}], 
      PolygonBox[{{4.437499981032941, 1.9157074104439382`}, {
       4.437344993353523, 1.769748357463745}, {4.362222184858401, 
       1.9029428580865546`}, {4.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{4.362222184858401, 1.9029428580865546`}, {4.375, 2.}, {
       4.437499981032941, 1.9157074104439382`}, {4.362222184858401, 
       1.9029428580865546`}}], 
      PolygonBox[{{4.4375, 2.}, {4.437499981032941, 1.9157074104439382`}, {
       4.375, 2.}, {4.4375, 2.}}], 
      PolygonBox[{{4.375, 2.}, {4.362222184858401, 2.0970571419134454`}, {
       4.4375, 2.}, {4.375, 2.}}], 
      PolygonBox[{{4.437499981032941, 2.084292589556062}, {4.4375, 2.}, {
       4.362222184858401, 2.0970571419134454`}, {4.437499981032941, 
       2.084292589556062}}], 
      PolygonBox[{{4.362222184858401, 2.0970571419134454`}, {
       4.3247595264191645`, 2.1875}, {4.437499981032941, 2.084292589556062}, {
       4.362222184858401, 2.0970571419134454`}}], 
      PolygonBox[{{4.437344993353523, 2.230251642536255}, {4.437499981032941, 
       2.084292589556062}, {4.3247595264191645`, 2.1875}, {4.437344993353523, 
       2.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, 2.1875}, {4.265165042944956, 
       2.2651650429449552`}, {4.437344993353523, 2.230251642536255}, {
       4.3247595264191645`, 2.1875}}], 
      PolygonBox[{{4.404942744332997, 2.404942744332997}, {4.437344993353523, 
       2.230251642536255}, {4.265165042944956, 2.2651650429449552`}, {
       4.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{4.265165042944956, 2.2651650429449552`}, {4.1875, 
       2.3247595264191645`}, {4.404942744332997, 2.404942744332997}, {
       4.265165042944956, 2.2651650429449552`}}], 
      PolygonBox[{{4.230251642536255, 2.4373449933535234`}, {
       4.404942744332997, 2.404942744332997}, {4.1875, 2.3247595264191645`}, {
       4.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{4.1875, 2.3247595264191645`}, {4.097057141913445, 
       2.3622221848584006`}, {4.230251642536255, 2.4373449933535234`}, {
       4.1875, 2.3247595264191645`}}], 
      PolygonBox[{{4.0842925895560604`, 2.437499981032941}, {
       4.230251642536255, 2.4373449933535234`}, {4.097057141913445, 
       2.3622221848584006`}, {4.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{4.097057141913445, 2.3622221848584006`}, {4., 2.375}, {
       4.0842925895560604`, 2.437499981032941}, {4.097057141913445, 
       2.3622221848584006`}}], 
      PolygonBox[{{4.000105527220487, 2.4375}, {4.0842925895560604`, 
       2.437499981032941}, {4., 2.375}, {4.000105527220487, 2.4375}}], 
      PolygonBox[{{4., 2.375}, {3.902942858086555, 2.3622221848584006`}, {
       4.000105527220487, 2.4375}, {4., 2.375}}], 
      PolygonBox[{{3.915707410443943, 2.437499981032941}, {4.000105527220487, 
       2.4375}, {3.902942858086555, 2.3622221848584006`}, {3.915707410443943, 
       2.437499981032941}}], 
      PolygonBox[{{3.902942858086555, 2.3622221848584006`}, {3.8125, 
       2.3247595264191645`}, {3.915707410443943, 2.437499981032941}, {
       3.902942858086555, 2.3622221848584006`}}], 
      PolygonBox[{{3.769748357463745, 2.4373449933535234`}, {
       3.915707410443943, 2.437499981032941}, {3.8125, 2.3247595264191645`}, {
       3.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{3.8125, 2.3247595264191645`}, {3.7348349570550448`, 
       2.2651650429449552`}, {3.769748357463745, 2.4373449933535234`}, {
       3.8125, 2.3247595264191645`}}], 
      PolygonBox[{{3.595057255667003, 2.404942744332997}, {3.769748357463745, 
       2.4373449933535234`}, {3.7348349570550448`, 2.2651650429449552`}, {
       3.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, 2.2651650429449552`}, {
       3.6752404735808355`, 2.1875}, {3.595057255667003, 2.404942744332997}, {
       3.7348349570550448`, 2.2651650429449552`}}], 
      PolygonBox[{{3.5626550066464766`, 2.2302516425362553`}, {
       3.595057255667003, 2.404942744332997}, {3.6752404735808355`, 2.1875}, {
       3.5626550066464766`, 2.2302516425362553`}}], 
      PolygonBox[{{3.6752404735808355`, 2.1875}, {3.6377778151415994`, 
       2.0970571419134454`}, {3.5626550066464766`, 2.2302516425362553`}, {
       3.6752404735808355`, 2.1875}}], 
      PolygonBox[{{3.562500018967059, 2.0842925895560622`}, {
       3.5626550066464766`, 2.2302516425362553`}, {3.6377778151415994`, 
       2.0970571419134454`}, {3.562500018967059, 2.0842925895560622`}}], 
      PolygonBox[{{3.6377778151415994`, 2.0970571419134454`}, {3.625, 2.}, {
       3.562500018967059, 2.0842925895560622`}, {3.6377778151415994`, 
       2.0970571419134454`}}], 
      PolygonBox[{{3.5625, 2.0001231780629953`}, {3.562500018967059, 
       2.0842925895560622`}, {3.625, 2.}, {3.5625, 2.0001231780629953`}}], 
      PolygonBox[{{3.625, 2.}, {3.6377778151415994`, 1.9029428580865548`}, {
       3.5625, 2.0001231780629953`}, {3.625, 2.}}], 
      PolygonBox[{{3.562500018967059, 1.915707410443945}, {3.5625, 
       2.0001231780629953`}, {3.6377778151415994`, 1.9029428580865548`}, {
       3.562500018967059, 1.915707410443945}}], 
      PolygonBox[{{3.6377778151415994`, 1.9029428580865548`}, {
       3.6752404735808355`, 1.8125000000000002`}, {3.562500018967059, 
       1.915707410443945}, {3.6377778151415994`, 1.9029428580865548`}}], 
      PolygonBox[{{3.5626550066464766`, 1.7697483574637451`}, {
       3.562500018967059, 1.915707410443945}, {3.6752404735808355`, 
       1.8125000000000002`}, {3.5626550066464766`, 1.7697483574637451`}}], 
      PolygonBox[{{3.6752404735808355`, 1.8125000000000002`}, {
       3.7348349570550448`, 1.7348349570550448`}, {3.5626550066464766`, 
       1.7697483574637451`}, {3.6752404735808355`, 1.8125000000000002`}}], 
      PolygonBox[{{3.595057255667003, 1.5950572556670028`}, {
       3.5626550066464766`, 1.7697483574637451`}, {3.7348349570550448`, 
       1.7348349570550448`}, {3.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{3.7348349570550448`, 1.7348349570550448`}, {3.8125, 
       1.6752404735808355`}, {3.595057255667003, 1.5950572556670028`}, {
       3.7348349570550448`, 1.7348349570550448`}}], 
      PolygonBox[{{3.769748357463745, 1.5626550066464766`}, {
       3.595057255667003, 1.5950572556670028`}, {3.8125, 
       1.6752404735808355`}, {3.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{3.8125, 1.6752404735808355`}, {3.9029428580865546`, 
       1.6377778151415994`}, {3.769748357463745, 1.5626550066464766`}, {
       3.8125, 1.6752404735808355`}}], 
      PolygonBox[{{3.915707410443936, 1.5625000189670593`}, {
       3.769748357463745, 1.5626550066464766`}, {3.9029428580865546`, 
       1.6377778151415994`}, {3.915707410443936, 1.5625000189670593`}}], 
      PolygonBox[{{3.9029428580865546`, 1.6377778151415994`}, {4., 1.625}, {
       3.915707410443936, 1.5625000189670593`}, {3.9029428580865546`, 
       1.6377778151415994`}}], 
      PolygonBox[{{4.000134841831043, 1.5625}, {3.915707410443936, 
       1.5625000189670593`}, {4., 1.625}, {4.000134841831043, 1.5625}}], 
      PolygonBox[{{4., 1.625}, {4.097057141913445, 1.6377778151415994`}, {
       4.000134841831043, 1.5625}, {4., 1.625}}], 
      PolygonBox[{{4.084292589556053, 1.5625000189670593`}, {
       4.000134841831043, 1.5625}, {4.097057141913445, 1.6377778151415994`}, {
       4.084292589556053, 1.5625000189670593`}}], 
      PolygonBox[{{4.097057141913445, 1.6377778151415994`}, {4.1875, 
       1.6752404735808355`}, {4.084292589556053, 1.5625000189670593`}, {
       4.097057141913445, 1.6377778151415994`}}], 
      PolygonBox[{{4.230251642536254, 1.5626550066464766`}, {
       4.084292589556053, 1.5625000189670593`}, {4.1875, 
       1.6752404735808355`}, {4.230251642536254, 1.5626550066464766`}}], 
      PolygonBox[{{4.1875, 1.6752404735808355`}, {4.265165042944956, 
       1.7348349570550448`}, {4.230251642536254, 1.5626550066464766`}, {
       4.1875, 1.6752404735808355`}}], 
      PolygonBox[{{4.404942744332997, 1.5950572556670028`}, {
       4.230251642536254, 1.5626550066464766`}, {4.265165042944956, 
       1.7348349570550448`}, {4.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{4.265165042944956, 1.7348349570550448`}, {
       4.265165042944956, 1.7348349570550448`}, {4.404942744332997, 
       1.5950572556670028`}, {4.265165042944956, 1.7348349570550448`}}], 
      PolygonBox[{{4.404942744332997, 1.5950572556670028`}, {
       4.404942744332997, 1.5950572556670028`}, {4.265165042944956, 
       1.7348349570550448`}, {4.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{4.404942744332997, 1.5950572556670028`}, {
       4.437344993353523, 1.769748357463745}, {4.5, 1.5}, {4.404942744332997, 
       1.5950572556670028`}}], 
      PolygonBox[{{4.5, 1.6423372173506323`}, {4.5, 1.5}, {4.437344993353523, 
       1.769748357463745}, {4.5, 1.6423372173506323`}}], 
      PolygonBox[{{4.437344993353523, 1.769748357463745}, {4.437499981032941, 
       1.9157074104439382`}, {4.5, 1.6423372173506323`}, {4.437344993353523, 
       1.769748357463745}}], 
      PolygonBox[{{4.5, 1.79409099469826}, {4.5, 1.6423372173506323`}, {
       4.437499981032941, 1.9157074104439382`}, {4.5, 1.79409099469826}}], 
      PolygonBox[{{4.437499981032941, 1.9157074104439382`}, {4.4375, 2.}, {
       4.5, 1.79409099469826}, {4.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{4.5, 2.}, {4.5, 1.79409099469826}, {4.4375, 2.}, {4.5, 
       2.}}], PolygonBox[{{4.4375, 2.}, {4.437499981032941, 
       2.084292589556062}, {4.5, 2.}, {4.4375, 2.}}], 
      PolygonBox[{{4.5, 2.20590900530174}, {4.5, 2.}, {4.437499981032941, 
       2.084292589556062}, {4.5, 2.20590900530174}}], 
      PolygonBox[{{4.437499981032941, 2.084292589556062}, {4.437344993353523, 
       2.230251642536255}, {4.5, 2.20590900530174}, {4.437499981032941, 
       2.084292589556062}}], 
      PolygonBox[{{4.5, 2.3576627826493675`}, {4.5, 2.20590900530174}, {
       4.437344993353523, 2.230251642536255}, {4.5, 2.3576627826493675`}}], 
      PolygonBox[{{4.437344993353523, 2.230251642536255}, {4.404942744332997, 
       2.404942744332997}, {4.5, 2.3576627826493675`}, {4.437344993353523, 
       2.230251642536255}}], 
      PolygonBox[{{4.491446564961186, 2.491446564961186}, {4.5, 
       2.3576627826493675`}, {4.404942744332997, 2.404942744332997}, {
       4.491446564961186, 2.491446564961186}}], 
      PolygonBox[{{4.404942744332997, 2.404942744332997}, {4.230251642536255, 
       2.4373449933535234`}, {4.491446564961186, 2.491446564961186}, {
       4.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{4.357662782649368, 2.5}, {4.491446564961186, 
       2.491446564961186}, {4.230251642536255, 2.4373449933535234`}, {
       4.357662782649368, 2.5}}], 
      PolygonBox[{{4.230251642536255, 2.4373449933535234`}, {
       4.0842925895560604`, 2.437499981032941}, {4.357662782649368, 2.5}, {
       4.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{4.205909005373256, 2.5}, {4.357662782649368, 2.5}, {
       4.0842925895560604`, 2.437499981032941}, {4.205909005373256, 2.5}}], 
      PolygonBox[{{4.0842925895560604`, 2.437499981032941}, {
       4.000105527220487, 2.4375}, {4.205909005373256, 2.5}, {
       4.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{4.07794195802689, 2.5}, {4.205909005373256, 2.5}, {
       4.000105527220487, 2.4375}, {4.07794195802689, 2.5}}], 
      PolygonBox[{{4.000105527220487, 2.4375}, {3.915707410443943, 
       2.437499981032941}, {4.07794195802689, 2.5}, {4.000105527220487, 
       2.4375}}], 
      PolygonBox[{{3.7940909946955546`, 2.5}, {4.07794195802689, 2.5}, {
       3.915707410443943, 2.437499981032941}, {3.7940909946955546`, 2.5}}], 
      PolygonBox[{{3.915707410443943, 2.437499981032941}, {3.769748357463745, 
       2.4373449933535234`}, {3.7940909946955546`, 2.5}, {3.915707410443943, 
       2.437499981032941}}], 
      PolygonBox[{{3.642337217350634, 2.5}, {3.7940909946955546`, 2.5}, {
       3.769748357463745, 2.4373449933535234`}, {3.642337217350634, 2.5}}], 
      PolygonBox[{{3.769748357463745, 2.4373449933535234`}, {
       3.595057255667003, 2.404942744332997}, {3.642337217350634, 2.5}, {
       3.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{4.5, 2.5}, {3.642337217350634, 2.5}, {3.595057255667003, 
       2.404942744332997}, {4.5, 2.5}}], 
      PolygonBox[{{3.595057255667003, 2.404942744332997}, {
       3.5626550066464766`, 2.2302516425362553`}, {4.5, 2.5}, {
       3.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{3.5, 2.357662782649369}, {4.5, 2.5}, {3.5626550066464766`, 
       2.2302516425362553`}, {3.5, 2.357662782649369}}], 
      PolygonBox[{{3.5626550066464766`, 2.2302516425362553`}, {
       3.562500018967059, 2.0842925895560622`}, {3.5, 2.357662782649369}, {
       3.5626550066464766`, 2.2302516425362553`}}], 
      PolygonBox[{{3.5, 2.205909005282899}, {3.5, 2.357662782649369}, {
       3.562500018967059, 2.0842925895560622`}, {3.5, 2.205909005282899}}], 
      PolygonBox[{{3.562500018967059, 2.0842925895560622`}, {3.5625, 
       2.0001231780629953`}, {3.5, 2.205909005282899}, {3.562500018967059, 
       2.0842925895560622`}}], 
      PolygonBox[{{3.5, 2.0806786667587}, {3.5, 2.205909005282899}, {3.5625, 
       2.0001231780629953`}, {3.5, 2.0806786667587}}], 
      PolygonBox[{{3.5625, 2.0001231780629953`}, {3.562500018967059, 
       1.915707410443945}, {3.5, 2.0806786667587}, {3.5625, 
       2.0001231780629953`}}], 
      PolygonBox[{{3.5, 1.7940909948547215`}, {3.5, 2.0806786667587}, {
       3.562500018967059, 1.915707410443945}, {3.5, 1.7940909948547215`}}], 
      PolygonBox[{{3.562500018967059, 1.915707410443945}, {
       3.5626550066464766`, 1.7697483574637451`}, {3.5, 
       1.7940909948547215`}, {3.562500018967059, 1.915707410443945}}], 
      PolygonBox[{{3.5, 1.6423372173506348`}, {3.5, 1.7940909948547215`}, {
       3.5626550066464766`, 1.7697483574637451`}, {3.5, 
       1.6423372173506348`}}], 
      PolygonBox[{{3.5626550066464766`, 1.7697483574637451`}, {
       3.595057255667003, 1.5950572556670028`}, {3.5, 1.6423372173506348`}, {
       3.5626550066464766`, 1.7697483574637451`}}], 
      PolygonBox[{{3.5, 2.5}, {3.5, 1.6423372173506348`}, {3.595057255667003, 
       1.5950572556670028`}, {3.5, 2.5}}], 
      PolygonBox[{{3.595057255667003, 1.5950572556670028`}, {
       3.769748357463745, 1.5626550066464766`}, {3.5, 2.5}, {
       3.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{3.5, 1.5}, {3.5, 2.5}, {3.769748357463745, 
       1.5626550066464766`}, {3.5, 1.5}}], 
      PolygonBox[{{3.769748357463745, 1.5626550066464766`}, {
       3.915707410443936, 1.5625000189670593`}, {3.5, 1.5}, {
       3.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{3.794090994433172, 1.5}, {3.5, 1.5}, {3.915707410443936, 
       1.5625000189670593`}, {3.794090994433172, 1.5}}], 
      PolygonBox[{{3.915707410443936, 1.5625000189670593`}, {
       4.000134841831043, 1.5625}, {3.794090994433172, 1.5}, {
       3.915707410443936, 1.5625000189670593`}}], 
      PolygonBox[{{4.082323870401062, 1.5}, {3.794090994433172, 1.5}, {
       4.000134841831043, 1.5625}, {4.082323870401062, 1.5}}], 
      PolygonBox[{{4.000134841831043, 1.5625}, {4.084292589556053, 
       1.5625000189670593`}, {4.082323870401062, 1.5}, {4.000134841831043, 
       1.5625}}], 
      PolygonBox[{{4.205909005360398, 1.5}, {4.082323870401062, 1.5}, {
       4.084292589556053, 1.5625000189670593`}, {4.205909005360398, 1.5}}], 
      PolygonBox[{{4.084292589556053, 1.5625000189670593`}, {
       4.230251642536254, 1.5626550066464766`}, {4.205909005360398, 1.5}, {
       4.084292589556053, 1.5625000189670593`}}], 
      PolygonBox[{{4.3576627826493715`, 1.5}, {4.205909005360398, 1.5}, {
       4.230251642536254, 1.5626550066464766`}, {4.3576627826493715`, 1.5}}], 
      PolygonBox[{{4.230251642536254, 1.5626550066464766`}, {
       4.404942744332997, 1.5950572556670028`}, {4.3576627826493715`, 1.5}, {
       4.230251642536254, 1.5626550066464766`}}], 
      PolygonBox[{{4.5, 1.5}, {4.3576627826493715`, 1.5}, {4.404942744332997, 
       1.5950572556670028`}, {4.5, 1.5}}], 
      PolygonBox[{{4.404942744332997, 1.5950572556670028`}, {
       4.404942744332997, 1.5950572556670028`}, {4.5, 1.5}, {
       4.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{4.5, 1.5}, {4.5, 1.5}, {4.404942744332997, 
       1.5950572556670028`}, {4.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, 3.}, {3.5208333333333335`, 3.}, {3.5416666666666665`, 
       3.}, {3.5625, 3.}, {3.5833333333333335`, 3.}, {3.6041666666666665`, 
       3.}, {3.625, 3.}, {3.625, 3.}, {3.6041666666666665`, 3.}, {
       3.5833333333333335`, 3.}, {3.5625, 3.}, {3.5416666666666665`, 3.}, {
       3.5208333333333335`, 3.}, {3.5, 3.}, {3.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, 3.}, {4.395833333333333, 3.}, {4.416666666666667, 
       3.}, {4.4375, 3.}, {4.458333333333333, 3.}, {4.479166666666667, 3.}, {
       4.5, 3.}, {4.5, 3.}, {4.479166666666667, 3.}, {4.458333333333333, 
       3.}, {4.4375, 3.}, {4.416666666666667, 3.}, {4.395833333333333, 3.}, {
       4.375, 3.}, {4.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 2.5}, {4., 2.5208333333333335`}, {4., 
       2.5416666666666665`}, {4., 2.5625}, {4., 2.5833333333333335`}, {4., 
       2.6041666666666665`}, {4., 2.625}, {4., 2.625}, {4., 
       2.6041666666666665`}, {4., 2.5833333333333335`}, {4., 2.5625}, {4., 
       2.5416666666666665`}, {4., 2.5208333333333335`}, {4., 2.5}, {4., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 3.375}, {4., 3.3958333333333335`}, {4., 
       3.4166666666666665`}, {4., 3.4375}, {4., 3.4583333333333335`}, {4., 
       3.4791666666666665`}, {4., 3.5}, {4., 3.5}, {4., 
       3.4791666666666665`}, {4., 3.4583333333333335`}, {4., 3.4375}, {4., 
       3.4166666666666665`}, {4., 3.3958333333333335`}, {4., 3.375}, {4., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, 3.}, {3.75, 3.}, {3.875, 3.}, {4., 3.}, {4.125, 3.}, {
       4.25, 3.}, {4.375, 3.}, {4.375, 3.}, {4.25, 3.}, {4.125, 3.}, {4., 
       3.}, {3.875, 3.}, {3.75, 3.}, {3.625, 3.}, {3.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 2.625}, {4., 2.75}, {4., 2.875}, {4., 3.}, {4., 3.125}, {
       4., 3.25}, {4., 3.375}, {4., 3.375}, {4., 3.25}, {4., 3.125}, {4., 
       3.}, {4., 2.875}, {4., 2.75}, {4., 2.625}, {4., 2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4QBofD14zw+FdFgg7+T4SeHj3G4TBD+cmh
Xh+ofAOnw7lvZ3Pa+QUdZr+dfZNPngsifkDAwcD9RKv0TC4H9aLOT0nJAg6v
Lq7bd+UpVJ5BAEpzO2yUfitlZcmPKt/AB9efKpSi9vEBL9z8CzvMq56k8cLt
F9MLdNSW4oW7D2IuL9z9MPlNYHvY0fSzOaRAzYfYwwq3H6KOFe4+iDmsaO5n
hfsPRR7of5h+WPjAzEcNPzZ4+G6Eug89/AGD/XNw
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhCaxyEUDATh/NWrQEAAzofQAmjyfHB+GFg/
L5p6wjTEHC40d3CiqeNAU8+GZi8rmnoWDH4oivtY0NwPUy+AJi+Apl8QTb0Q
QX4oivuE0NwPU8+Bpp4Tzl+FEj6I+AIAsvFCJQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, 2.7348349570550448`}, {
       4.3247595264191645`, 2.8125}, {4.404942744332997, 2.595057255667003}, {
       4.265165042944956, 2.7348349570550448`}}], 
      PolygonBox[{{4.437344993353523, 2.7697483574637447`}, {
       4.404942744332997, 2.595057255667003}, {4.3247595264191645`, 2.8125}, {
       4.437344993353523, 2.7697483574637447`}}], 
      PolygonBox[{{4.3247595264191645`, 2.8125}, {4.362222184858401, 
       2.9029428580865546`}, {4.437344993353523, 2.7697483574637447`}, {
       4.3247595264191645`, 2.8125}}], 
      PolygonBox[{{4.437499981032941, 2.915707410443938}, {4.437344993353523, 
       2.7697483574637447`}, {4.362222184858401, 2.9029428580865546`}, {
       4.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{4.362222184858401, 2.9029428580865546`}, {4.375, 3.}, {
       4.437499981032941, 2.915707410443938}, {4.362222184858401, 
       2.9029428580865546`}}], 
      PolygonBox[{{4.4375, 3.}, {4.437499981032941, 2.915707410443938}, {
       4.375, 3.}, {4.4375, 3.}}], 
      PolygonBox[{{4.375, 3.}, {4.362222184858401, 3.0970571419134454`}, {
       4.4375, 3.}, {4.375, 3.}}], 
      PolygonBox[{{4.437499981032941, 3.084292589556062}, {4.4375, 3.}, {
       4.362222184858401, 3.0970571419134454`}, {4.437499981032941, 
       3.084292589556062}}], 
      PolygonBox[{{4.362222184858401, 3.0970571419134454`}, {
       4.3247595264191645`, 3.1875}, {4.437499981032941, 3.084292589556062}, {
       4.362222184858401, 3.0970571419134454`}}], 
      PolygonBox[{{4.437344993353523, 3.230251642536255}, {4.437499981032941, 
       3.084292589556062}, {4.3247595264191645`, 3.1875}, {4.437344993353523, 
       3.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, 3.1875}, {4.265165042944956, 
       3.2651650429449552`}, {4.437344993353523, 3.230251642536255}, {
       4.3247595264191645`, 3.1875}}], 
      PolygonBox[{{4.404942744332997, 3.404942744332997}, {4.437344993353523, 
       3.230251642536255}, {4.265165042944956, 3.2651650429449552`}, {
       4.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{4.265165042944956, 3.2651650429449552`}, {4.1875, 
       3.3247595264191645`}, {4.404942744332997, 3.404942744332997}, {
       4.265165042944956, 3.2651650429449552`}}], 
      PolygonBox[{{4.230251642536255, 3.4373449933535234`}, {
       4.404942744332997, 3.404942744332997}, {4.1875, 3.3247595264191645`}, {
       4.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{4.1875, 3.3247595264191645`}, {4.097057141913445, 
       3.3622221848584006`}, {4.230251642536255, 3.4373449933535234`}, {
       4.1875, 3.3247595264191645`}}], 
      PolygonBox[{{4.0842925895560604`, 3.437499981032941}, {
       4.230251642536255, 3.4373449933535234`}, {4.097057141913445, 
       3.3622221848584006`}, {4.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{4.097057141913445, 3.3622221848584006`}, {4., 3.375}, {
       4.0842925895560604`, 3.437499981032941}, {4.097057141913445, 
       3.3622221848584006`}}], 
      PolygonBox[{{4.000105527220487, 3.4375}, {4.0842925895560604`, 
       3.437499981032941}, {4., 3.375}, {4.000105527220487, 3.4375}}], 
      PolygonBox[{{4., 3.375}, {3.902942858086555, 3.3622221848584006`}, {
       4.000105527220487, 3.4375}, {4., 3.375}}], 
      PolygonBox[{{3.915707410443943, 3.437499981032941}, {4.000105527220487, 
       3.4375}, {3.902942858086555, 3.3622221848584006`}, {3.915707410443943, 
       3.437499981032941}}], 
      PolygonBox[{{3.902942858086555, 3.3622221848584006`}, {3.8125, 
       3.3247595264191645`}, {3.915707410443943, 3.437499981032941}, {
       3.902942858086555, 3.3622221848584006`}}], 
      PolygonBox[{{3.769748357463745, 3.4373449933535234`}, {
       3.915707410443943, 3.437499981032941}, {3.8125, 3.3247595264191645`}, {
       3.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{3.8125, 3.3247595264191645`}, {3.7348349570550448`, 
       3.2651650429449552`}, {3.769748357463745, 3.4373449933535234`}, {
       3.8125, 3.3247595264191645`}}], 
      PolygonBox[{{3.595057255667003, 3.404942744332997}, {3.769748357463745, 
       3.4373449933535234`}, {3.7348349570550448`, 3.2651650429449552`}, {
       3.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, 3.2651650429449552`}, {
       3.6752404735808355`, 3.1875}, {3.595057255667003, 3.404942744332997}, {
       3.7348349570550448`, 3.2651650429449552`}}], 
      PolygonBox[{{3.5626550066464766`, 3.2302516425362553`}, {
       3.595057255667003, 3.404942744332997}, {3.6752404735808355`, 3.1875}, {
       3.5626550066464766`, 3.2302516425362553`}}], 
      PolygonBox[{{3.6752404735808355`, 3.1875}, {3.6377778151415994`, 
       3.0970571419134454`}, {3.5626550066464766`, 3.2302516425362553`}, {
       3.6752404735808355`, 3.1875}}], 
      PolygonBox[{{3.562500018967059, 3.0842925895560622`}, {
       3.5626550066464766`, 3.2302516425362553`}, {3.6377778151415994`, 
       3.0970571419134454`}, {3.562500018967059, 3.0842925895560622`}}], 
      PolygonBox[{{3.6377778151415994`, 3.0970571419134454`}, {3.625, 3.}, {
       3.562500018967059, 3.0842925895560622`}, {3.6377778151415994`, 
       3.0970571419134454`}}], 
      PolygonBox[{{3.5625, 3.0001231780629953`}, {3.562500018967059, 
       3.0842925895560622`}, {3.625, 3.}, {3.5625, 3.0001231780629953`}}], 
      PolygonBox[{{3.625, 3.}, {3.6377778151415994`, 2.902942858086555}, {
       3.5625, 3.0001231780629953`}, {3.625, 3.}}], 
      PolygonBox[{{3.562500018967059, 2.915707410443945}, {3.5625, 
       3.0001231780629953`}, {3.6377778151415994`, 2.902942858086555}, {
       3.562500018967059, 2.915707410443945}}], 
      PolygonBox[{{3.6377778151415994`, 2.902942858086555}, {
       3.6752404735808355`, 2.8125}, {3.562500018967059, 2.915707410443945}, {
       3.6377778151415994`, 2.902942858086555}}], 
      PolygonBox[{{3.5626550066464766`, 2.769748357463745}, {
       3.562500018967059, 2.915707410443945}, {3.6752404735808355`, 2.8125}, {
       3.5626550066464766`, 2.769748357463745}}], 
      PolygonBox[{{3.6752404735808355`, 2.8125}, {3.7348349570550448`, 
       2.7348349570550448`}, {3.5626550066464766`, 2.769748357463745}, {
       3.6752404735808355`, 2.8125}}], 
      PolygonBox[{{3.595057255667003, 2.595057255667003}, {
       3.5626550066464766`, 2.769748357463745}, {3.7348349570550448`, 
       2.7348349570550448`}, {3.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{3.7348349570550448`, 2.7348349570550448`}, {3.8125, 
       2.6752404735808355`}, {3.595057255667003, 2.595057255667003}, {
       3.7348349570550448`, 2.7348349570550448`}}], 
      PolygonBox[{{3.769748357463745, 2.5626550066464766`}, {
       3.595057255667003, 2.595057255667003}, {3.8125, 2.6752404735808355`}, {
       3.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{3.8125, 2.6752404735808355`}, {3.9029428580865546`, 
       2.6377778151415994`}, {3.769748357463745, 2.5626550066464766`}, {
       3.8125, 2.6752404735808355`}}], 
      PolygonBox[{{3.915707410443936, 2.562500018967059}, {3.769748357463745, 
       2.5626550066464766`}, {3.9029428580865546`, 2.6377778151415994`}, {
       3.915707410443936, 2.562500018967059}}], 
      PolygonBox[{{3.9029428580865546`, 2.6377778151415994`}, {4., 2.625}, {
       3.915707410443936, 2.562500018967059}, {3.9029428580865546`, 
       2.6377778151415994`}}], 
      PolygonBox[{{4.000134841831043, 2.5625}, {3.915707410443936, 
       2.562500018967059}, {4., 2.625}, {4.000134841831043, 2.5625}}], 
      PolygonBox[{{4., 2.625}, {4.097057141913445, 2.6377778151415994`}, {
       4.000134841831043, 2.5625}, {4., 2.625}}], 
      PolygonBox[{{4.084292589556053, 2.562500018967059}, {4.000134841831043, 
       2.5625}, {4.097057141913445, 2.6377778151415994`}, {4.084292589556053, 
       2.562500018967059}}], 
      PolygonBox[{{4.097057141913445, 2.6377778151415994`}, {4.1875, 
       2.6752404735808355`}, {4.084292589556053, 2.562500018967059}, {
       4.097057141913445, 2.6377778151415994`}}], 
      PolygonBox[{{4.230251642536254, 2.5626550066464766`}, {
       4.084292589556053, 2.562500018967059}, {4.1875, 2.6752404735808355`}, {
       4.230251642536254, 2.5626550066464766`}}], 
      PolygonBox[{{4.1875, 2.6752404735808355`}, {4.265165042944956, 
       2.7348349570550448`}, {4.230251642536254, 2.5626550066464766`}, {
       4.1875, 2.6752404735808355`}}], 
      PolygonBox[{{4.404942744332997, 2.595057255667003}, {4.230251642536254, 
       2.5626550066464766`}, {4.265165042944956, 2.7348349570550448`}, {
       4.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{4.265165042944956, 2.7348349570550448`}, {
       4.265165042944956, 2.7348349570550448`}, {4.404942744332997, 
       2.595057255667003}, {4.265165042944956, 2.7348349570550448`}}], 
      PolygonBox[{{4.404942744332997, 2.595057255667003}, {4.404942744332997, 
       2.595057255667003}, {4.265165042944956, 2.7348349570550448`}, {
       4.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{4.404942744332997, 2.595057255667003}, {4.437344993353523, 
       2.7697483574637447`}, {4.5, 2.5}, {4.404942744332997, 
       2.595057255667003}}], 
      PolygonBox[{{4.5, 2.642337217350632}, {4.5, 2.5}, {4.437344993353523, 
       2.7697483574637447`}, {4.5, 2.642337217350632}}], 
      PolygonBox[{{4.437344993353523, 2.7697483574637447`}, {
       4.437499981032941, 2.915707410443938}, {4.5, 2.642337217350632}, {
       4.437344993353523, 2.7697483574637447`}}], 
      PolygonBox[{{4.5, 2.79409099469826}, {4.5, 2.642337217350632}, {
       4.437499981032941, 2.915707410443938}, {4.5, 2.79409099469826}}], 
      PolygonBox[{{4.437499981032941, 2.915707410443938}, {4.4375, 3.}, {4.5, 
       2.79409099469826}, {4.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{4.5, 3.}, {4.5, 2.79409099469826}, {4.4375, 3.}, {4.5, 
       3.}}], PolygonBox[{{4.4375, 3.}, {4.437499981032941, 
       3.084292589556062}, {4.5, 3.}, {4.4375, 3.}}], 
      PolygonBox[{{4.5, 3.20590900530174}, {4.5, 3.}, {4.437499981032941, 
       3.084292589556062}, {4.5, 3.20590900530174}}], 
      PolygonBox[{{4.437499981032941, 3.084292589556062}, {4.437344993353523, 
       3.230251642536255}, {4.5, 3.20590900530174}, {4.437499981032941, 
       3.084292589556062}}], 
      PolygonBox[{{4.5, 3.3576627826493675`}, {4.5, 3.20590900530174}, {
       4.437344993353523, 3.230251642536255}, {4.5, 3.3576627826493675`}}], 
      PolygonBox[{{4.437344993353523, 3.230251642536255}, {4.404942744332997, 
       3.404942744332997}, {4.5, 3.3576627826493675`}, {4.437344993353523, 
       3.230251642536255}}], 
      PolygonBox[{{4.491446564961186, 3.491446564961186}, {4.5, 
       3.3576627826493675`}, {4.404942744332997, 3.404942744332997}, {
       4.491446564961186, 3.491446564961186}}], 
      PolygonBox[{{4.404942744332997, 3.404942744332997}, {4.230251642536255, 
       3.4373449933535234`}, {4.491446564961186, 3.491446564961186}, {
       4.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{4.357662782649368, 3.5}, {4.491446564961186, 
       3.491446564961186}, {4.230251642536255, 3.4373449933535234`}, {
       4.357662782649368, 3.5}}], 
      PolygonBox[{{4.230251642536255, 3.4373449933535234`}, {
       4.0842925895560604`, 3.437499981032941}, {4.357662782649368, 3.5}, {
       4.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{4.205909005373256, 3.5}, {4.357662782649368, 3.5}, {
       4.0842925895560604`, 3.437499981032941}, {4.205909005373256, 3.5}}], 
      PolygonBox[{{4.0842925895560604`, 3.437499981032941}, {
       4.000105527220487, 3.4375}, {4.205909005373256, 3.5}, {
       4.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{4.07794195802689, 3.5}, {4.205909005373256, 3.5}, {
       4.000105527220487, 3.4375}, {4.07794195802689, 3.5}}], 
      PolygonBox[{{4.000105527220487, 3.4375}, {3.915707410443943, 
       3.437499981032941}, {4.07794195802689, 3.5}, {4.000105527220487, 
       3.4375}}], 
      PolygonBox[{{3.7940909946955546`, 3.5}, {4.07794195802689, 3.5}, {
       3.915707410443943, 3.437499981032941}, {3.7940909946955546`, 3.5}}], 
      PolygonBox[{{3.915707410443943, 3.437499981032941}, {3.769748357463745, 
       3.4373449933535234`}, {3.7940909946955546`, 3.5}, {3.915707410443943, 
       3.437499981032941}}], 
      PolygonBox[{{3.642337217350634, 3.5}, {3.7940909946955546`, 3.5}, {
       3.769748357463745, 3.4373449933535234`}, {3.642337217350634, 3.5}}], 
      PolygonBox[{{3.769748357463745, 3.4373449933535234`}, {
       3.595057255667003, 3.404942744332997}, {3.642337217350634, 3.5}, {
       3.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{4.5, 3.5}, {3.642337217350634, 3.5}, {3.595057255667003, 
       3.404942744332997}, {4.5, 3.5}}], 
      PolygonBox[{{3.595057255667003, 3.404942744332997}, {
       3.5626550066464766`, 3.2302516425362553`}, {4.5, 3.5}, {
       3.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{3.5, 3.357662782649369}, {4.5, 3.5}, {3.5626550066464766`, 
       3.2302516425362553`}, {3.5, 3.357662782649369}}], 
      PolygonBox[{{3.5626550066464766`, 3.2302516425362553`}, {
       3.562500018967059, 3.0842925895560622`}, {3.5, 3.357662782649369}, {
       3.5626550066464766`, 3.2302516425362553`}}], 
      PolygonBox[{{3.5, 3.205909005282899}, {3.5, 3.357662782649369}, {
       3.562500018967059, 3.0842925895560622`}, {3.5, 3.205909005282899}}], 
      PolygonBox[{{3.562500018967059, 3.0842925895560622`}, {3.5625, 
       3.0001231780629953`}, {3.5, 3.205909005282899}, {3.562500018967059, 
       3.0842925895560622`}}], 
      PolygonBox[{{3.5, 3.0806786667587}, {3.5, 3.205909005282899}, {3.5625, 
       3.0001231780629953`}, {3.5, 3.0806786667587}}], 
      PolygonBox[{{3.5625, 3.0001231780629953`}, {3.562500018967059, 
       2.915707410443945}, {3.5, 3.0806786667587}, {3.5625, 
       3.0001231780629953`}}], 
      PolygonBox[{{3.5, 2.7940909948547215`}, {3.5, 3.0806786667587}, {
       3.562500018967059, 2.915707410443945}, {3.5, 2.7940909948547215`}}], 
      PolygonBox[{{3.562500018967059, 2.915707410443945}, {
       3.5626550066464766`, 2.769748357463745}, {3.5, 2.7940909948547215`}, {
       3.562500018967059, 2.915707410443945}}], 
      PolygonBox[{{3.5, 2.6423372173506348`}, {3.5, 2.7940909948547215`}, {
       3.5626550066464766`, 2.769748357463745}, {3.5, 2.6423372173506348`}}], 
      PolygonBox[{{3.5626550066464766`, 2.769748357463745}, {
       3.595057255667003, 2.595057255667003}, {3.5, 2.6423372173506348`}, {
       3.5626550066464766`, 2.769748357463745}}], 
      PolygonBox[{{3.5, 3.5}, {3.5, 2.6423372173506348`}, {3.595057255667003, 
       2.595057255667003}, {3.5, 3.5}}], 
      PolygonBox[{{3.595057255667003, 2.595057255667003}, {3.769748357463745, 
       2.5626550066464766`}, {3.5, 3.5}, {3.595057255667003, 
       2.595057255667003}}], 
      PolygonBox[{{3.5, 2.5}, {3.5, 3.5}, {3.769748357463745, 
       2.5626550066464766`}, {3.5, 2.5}}], 
      PolygonBox[{{3.769748357463745, 2.5626550066464766`}, {
       3.915707410443936, 2.562500018967059}, {3.5, 2.5}, {3.769748357463745, 
       2.5626550066464766`}}], 
      PolygonBox[{{3.794090994433172, 2.5}, {3.5, 2.5}, {3.915707410443936, 
       2.562500018967059}, {3.794090994433172, 2.5}}], 
      PolygonBox[{{3.915707410443936, 2.562500018967059}, {4.000134841831043, 
       2.5625}, {3.794090994433172, 2.5}, {3.915707410443936, 
       2.562500018967059}}], 
      PolygonBox[{{4.082323870401062, 2.5}, {3.794090994433172, 2.5}, {
       4.000134841831043, 2.5625}, {4.082323870401062, 2.5}}], 
      PolygonBox[{{4.000134841831043, 2.5625}, {4.084292589556053, 
       2.562500018967059}, {4.082323870401062, 2.5}, {4.000134841831043, 
       2.5625}}], 
      PolygonBox[{{4.205909005360398, 2.5}, {4.082323870401062, 2.5}, {
       4.084292589556053, 2.562500018967059}, {4.205909005360398, 2.5}}], 
      PolygonBox[{{4.084292589556053, 2.562500018967059}, {4.230251642536254, 
       2.5626550066464766`}, {4.205909005360398, 2.5}, {4.084292589556053, 
       2.562500018967059}}], 
      PolygonBox[{{4.3576627826493715`, 2.5}, {4.205909005360398, 2.5}, {
       4.230251642536254, 2.5626550066464766`}, {4.3576627826493715`, 2.5}}], 
      PolygonBox[{{4.230251642536254, 2.5626550066464766`}, {
       4.404942744332997, 2.595057255667003}, {4.3576627826493715`, 2.5}, {
       4.230251642536254, 2.5626550066464766`}}], 
      PolygonBox[{{4.5, 2.5}, {4.3576627826493715`, 2.5}, {4.404942744332997, 
       2.595057255667003}, {4.5, 2.5}}], 
      PolygonBox[{{4.404942744332997, 2.595057255667003}, {4.404942744332997, 
       2.595057255667003}, {4.5, 2.5}, {4.404942744332997, 
       2.595057255667003}}], 
      PolygonBox[{{4.5, 2.5}, {4.5, 2.5}, {4.404942744332997, 
       2.595057255667003}, {4.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, 4.}, {3.5208333333333335`, 4.}, {3.5416666666666665`, 
       4.}, {3.5625, 4.}, {3.5833333333333335`, 4.}, {3.6041666666666665`, 
       4.}, {3.625, 4.}, {3.625, 4.}, {3.6041666666666665`, 4.}, {
       3.5833333333333335`, 4.}, {3.5625, 4.}, {3.5416666666666665`, 4.}, {
       3.5208333333333335`, 4.}, {3.5, 4.}, {3.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, 4.}, {4.395833333333333, 4.}, {4.416666666666667, 
       4.}, {4.4375, 4.}, {4.458333333333333, 4.}, {4.479166666666667, 4.}, {
       4.5, 4.}, {4.5, 4.}, {4.479166666666667, 4.}, {4.458333333333333, 
       4.}, {4.4375, 4.}, {4.416666666666667, 4.}, {4.395833333333333, 4.}, {
       4.375, 4.}, {4.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 3.5}, {4., 3.5208333333333335`}, {4., 
       3.5416666666666665`}, {4., 3.5625}, {4., 3.5833333333333335`}, {4., 
       3.6041666666666665`}, {4., 3.625}, {4., 3.625}, {4., 
       3.6041666666666665`}, {4., 3.5833333333333335`}, {4., 3.5625}, {4., 
       3.5416666666666665`}, {4., 3.5208333333333335`}, {4., 3.5}, {4., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 4.375}, {4., 4.395833333333333}, {4., 
       4.416666666666667}, {4., 4.4375}, {4., 4.458333333333333}, {4., 
       4.479166666666667}, {4., 4.5}, {4., 4.5}, {4., 4.479166666666667}, {4.,
        4.458333333333333}, {4., 4.4375}, {4., 4.416666666666667}, {4., 
       4.395833333333333}, {4., 4.375}, {4., 4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, 4.}, {3.75, 4.}, {3.875, 4.}, {4., 4.}, {4.125, 4.}, {
       4.25, 4.}, {4.375, 4.}, {4.375, 4.}, {4.25, 4.}, {4.125, 4.}, {4., 
       4.}, {3.875, 4.}, {3.75, 4.}, {3.625, 4.}, {3.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 3.625}, {4., 3.75}, {4., 3.875}, {4., 4.}, {4., 4.125}, {
       4., 4.25}, {4., 4.375}, {4., 4.375}, {4., 4.25}, {4., 4.125}, {4., 
       4.}, {4., 3.875}, {4., 3.75}, {4., 3.625}, {4., 3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4QhoDD14zw+FdFgg7qRZ2fkpIFHGYoPznU
6wOVPyDgcO7b2Zx2fkE4DROHqYPpg5kDMxdmz0bpt1JWlvyo8g18cP2pQilq
Hx/wws2/sMO86kkaL9weMb1AR20pXgcNqD0Q83nh9sDkN0HtQdEPtCcFaj7M
Hpg4TB3MfTBzUNwPtAfmPxR5oLtg+mHuhpmPEn5Ae2D+htmDHv4AogBy7Q==

      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDjA6FAwE4fzVq0BAwAFVnQCaPB+cHwbWz4um
nocgH9VeHjR7YeoF0OT54HxUe3lw0qFo6tDNwW6PAJp+QTT1hP0ZihYu6OGG
ai9muKPHC4wGAFesQvA=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, 3.7348349570550448`}, {
       4.3247595264191645`, 3.8125}, {4.404942744332997, 3.595057255667003}, {
       4.265165042944956, 3.7348349570550448`}}], 
      PolygonBox[{{4.437344993353523, 3.7697483574637447`}, {
       4.404942744332997, 3.595057255667003}, {4.3247595264191645`, 3.8125}, {
       4.437344993353523, 3.7697483574637447`}}], 
      PolygonBox[{{4.3247595264191645`, 3.8125}, {4.362222184858401, 
       3.9029428580865546`}, {4.437344993353523, 3.7697483574637447`}, {
       4.3247595264191645`, 3.8125}}], 
      PolygonBox[{{4.437499981032941, 3.915707410443938}, {4.437344993353523, 
       3.7697483574637447`}, {4.362222184858401, 3.9029428580865546`}, {
       4.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{4.362222184858401, 3.9029428580865546`}, {4.375, 4.}, {
       4.437499981032941, 3.915707410443938}, {4.362222184858401, 
       3.9029428580865546`}}], 
      PolygonBox[{{4.4375, 4.}, {4.437499981032941, 3.915707410443938}, {
       4.375, 4.}, {4.4375, 4.}}], 
      PolygonBox[{{4.375, 4.}, {4.362222184858401, 4.097057141913445}, {
       4.4375, 4.}, {4.375, 4.}}], 
      PolygonBox[{{4.437499981032941, 4.084292589556061}, {4.4375, 4.}, {
       4.362222184858401, 4.097057141913445}, {4.437499981032941, 
       4.084292589556061}}], 
      PolygonBox[{{4.362222184858401, 4.097057141913445}, {
       4.3247595264191645`, 4.1875}, {4.437499981032941, 4.084292589556061}, {
       4.362222184858401, 4.097057141913445}}], 
      PolygonBox[{{4.437344993353523, 4.230251642536255}, {4.437499981032941, 
       4.084292589556061}, {4.3247595264191645`, 4.1875}, {4.437344993353523, 
       4.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, 4.1875}, {4.265165042944956, 
       4.265165042944956}, {4.437344993353523, 4.230251642536255}, {
       4.3247595264191645`, 4.1875}}], 
      PolygonBox[{{4.404942744332997, 4.404942744332997}, {4.437344993353523, 
       4.230251642536255}, {4.265165042944956, 4.265165042944956}, {
       4.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{4.265165042944956, 4.265165042944956}, {4.1875, 
       4.3247595264191645`}, {4.404942744332997, 4.404942744332997}, {
       4.265165042944956, 4.265165042944956}}], 
      PolygonBox[{{4.230251642536255, 4.437344993353523}, {4.404942744332997, 
       4.404942744332997}, {4.1875, 4.3247595264191645`}, {4.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{4.1875, 4.3247595264191645`}, {4.097057141913445, 
       4.362222184858401}, {4.230251642536255, 4.437344993353523}, {4.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{4.0842925895560604`, 4.437499981032941}, {
       4.230251642536255, 4.437344993353523}, {4.097057141913445, 
       4.362222184858401}, {4.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{4.097057141913445, 4.362222184858401}, {4., 4.375}, {
       4.0842925895560604`, 4.437499981032941}, {4.097057141913445, 
       4.362222184858401}}], 
      PolygonBox[{{4.000105527220487, 4.4375}, {4.0842925895560604`, 
       4.437499981032941}, {4., 4.375}, {4.000105527220487, 4.4375}}], 
      PolygonBox[{{4., 4.375}, {3.902942858086555, 4.362222184858401}, {
       4.000105527220487, 4.4375}, {4., 4.375}}], 
      PolygonBox[{{3.915707410443943, 4.437499981032941}, {4.000105527220487, 
       4.4375}, {3.902942858086555, 4.362222184858401}, {3.915707410443943, 
       4.437499981032941}}], 
      PolygonBox[{{3.902942858086555, 4.362222184858401}, {3.8125, 
       4.3247595264191645`}, {3.915707410443943, 4.437499981032941}, {
       3.902942858086555, 4.362222184858401}}], 
      PolygonBox[{{3.769748357463745, 4.437344993353523}, {3.915707410443943, 
       4.437499981032941}, {3.8125, 4.3247595264191645`}, {3.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{3.8125, 4.3247595264191645`}, {3.7348349570550448`, 
       4.265165042944956}, {3.769748357463745, 4.437344993353523}, {3.8125, 
       4.3247595264191645`}}], 
      PolygonBox[{{3.595057255667003, 4.404942744332997}, {3.769748357463745, 
       4.437344993353523}, {3.7348349570550448`, 4.265165042944956}, {
       3.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, 4.265165042944956}, {
       3.6752404735808355`, 4.1875}, {3.595057255667003, 4.404942744332997}, {
       3.7348349570550448`, 4.265165042944956}}], 
      PolygonBox[{{3.5626550066464766`, 4.230251642536255}, {
       3.595057255667003, 4.404942744332997}, {3.6752404735808355`, 4.1875}, {
       3.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{3.6752404735808355`, 4.1875}, {3.6377778151415994`, 
       4.097057141913446}, {3.5626550066464766`, 4.230251642536255}, {
       3.6752404735808355`, 4.1875}}], 
      PolygonBox[{{3.562500018967059, 4.084292589556062}, {
       3.5626550066464766`, 4.230251642536255}, {3.6377778151415994`, 
       4.097057141913446}, {3.562500018967059, 4.084292589556062}}], 
      PolygonBox[{{3.6377778151415994`, 4.097057141913446}, {3.625, 4.}, {
       3.562500018967059, 4.084292589556062}, {3.6377778151415994`, 
       4.097057141913446}}], 
      PolygonBox[{{3.5625, 4.000123178062996}, {3.562500018967059, 
       4.084292589556062}, {3.625, 4.}, {3.5625, 4.000123178062996}}], 
      PolygonBox[{{3.625, 4.}, {3.6377778151415994`, 3.902942858086555}, {
       3.5625, 4.000123178062996}, {3.625, 4.}}], 
      PolygonBox[{{3.562500018967059, 3.915707410443945}, {3.5625, 
       4.000123178062996}, {3.6377778151415994`, 3.902942858086555}, {
       3.562500018967059, 3.915707410443945}}], 
      PolygonBox[{{3.6377778151415994`, 3.902942858086555}, {
       3.6752404735808355`, 3.8125}, {3.562500018967059, 3.915707410443945}, {
       3.6377778151415994`, 3.902942858086555}}], 
      PolygonBox[{{3.5626550066464766`, 3.769748357463745}, {
       3.562500018967059, 3.915707410443945}, {3.6752404735808355`, 3.8125}, {
       3.5626550066464766`, 3.769748357463745}}], 
      PolygonBox[{{3.6752404735808355`, 3.8125}, {3.7348349570550448`, 
       3.7348349570550448`}, {3.5626550066464766`, 3.769748357463745}, {
       3.6752404735808355`, 3.8125}}], 
      PolygonBox[{{3.595057255667003, 3.595057255667003}, {
       3.5626550066464766`, 3.769748357463745}, {3.7348349570550448`, 
       3.7348349570550448`}, {3.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{3.7348349570550448`, 3.7348349570550448`}, {3.8125, 
       3.6752404735808355`}, {3.595057255667003, 3.595057255667003}, {
       3.7348349570550448`, 3.7348349570550448`}}], 
      PolygonBox[{{3.769748357463745, 3.5626550066464766`}, {
       3.595057255667003, 3.595057255667003}, {3.8125, 3.6752404735808355`}, {
       3.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{3.8125, 3.6752404735808355`}, {3.9029428580865546`, 
       3.6377778151415994`}, {3.769748357463745, 3.5626550066464766`}, {
       3.8125, 3.6752404735808355`}}], 
      PolygonBox[{{3.915707410443936, 3.562500018967059}, {3.769748357463745, 
       3.5626550066464766`}, {3.9029428580865546`, 3.6377778151415994`}, {
       3.915707410443936, 3.562500018967059}}], 
      PolygonBox[{{3.9029428580865546`, 3.6377778151415994`}, {4., 3.625}, {
       3.915707410443936, 3.562500018967059}, {3.9029428580865546`, 
       3.6377778151415994`}}], 
      PolygonBox[{{4.000134841831043, 3.5625}, {3.915707410443936, 
       3.562500018967059}, {4., 3.625}, {4.000134841831043, 3.5625}}], 
      PolygonBox[{{4., 3.625}, {4.097057141913445, 3.6377778151415994`}, {
       4.000134841831043, 3.5625}, {4., 3.625}}], 
      PolygonBox[{{4.084292589556053, 3.562500018967059}, {4.000134841831043, 
       3.5625}, {4.097057141913445, 3.6377778151415994`}, {4.084292589556053, 
       3.562500018967059}}], 
      PolygonBox[{{4.097057141913445, 3.6377778151415994`}, {4.1875, 
       3.6752404735808355`}, {4.084292589556053, 3.562500018967059}, {
       4.097057141913445, 3.6377778151415994`}}], 
      PolygonBox[{{4.230251642536254, 3.5626550066464766`}, {
       4.084292589556053, 3.562500018967059}, {4.1875, 3.6752404735808355`}, {
       4.230251642536254, 3.5626550066464766`}}], 
      PolygonBox[{{4.1875, 3.6752404735808355`}, {4.265165042944956, 
       3.7348349570550448`}, {4.230251642536254, 3.5626550066464766`}, {
       4.1875, 3.6752404735808355`}}], 
      PolygonBox[{{4.404942744332997, 3.595057255667003}, {4.230251642536254, 
       3.5626550066464766`}, {4.265165042944956, 3.7348349570550448`}, {
       4.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{4.265165042944956, 3.7348349570550448`}, {
       4.265165042944956, 3.7348349570550448`}, {4.404942744332997, 
       3.595057255667003}, {4.265165042944956, 3.7348349570550448`}}], 
      PolygonBox[{{4.404942744332997, 3.595057255667003}, {4.404942744332997, 
       3.595057255667003}, {4.265165042944956, 3.7348349570550448`}, {
       4.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{4.404942744332997, 3.595057255667003}, {4.437344993353523, 
       3.7697483574637447`}, {4.5, 3.5}, {4.404942744332997, 
       3.595057255667003}}], 
      PolygonBox[{{4.5, 3.642337217350632}, {4.5, 3.5}, {4.437344993353523, 
       3.7697483574637447`}, {4.5, 3.642337217350632}}], 
      PolygonBox[{{4.437344993353523, 3.7697483574637447`}, {
       4.437499981032941, 3.915707410443938}, {4.5, 3.642337217350632}, {
       4.437344993353523, 3.7697483574637447`}}], 
      PolygonBox[{{4.5, 3.79409099469826}, {4.5, 3.642337217350632}, {
       4.437499981032941, 3.915707410443938}, {4.5, 3.79409099469826}}], 
      PolygonBox[{{4.437499981032941, 3.915707410443938}, {4.4375, 4.}, {4.5, 
       3.79409099469826}, {4.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{4.5, 4.}, {4.5, 3.79409099469826}, {4.4375, 4.}, {4.5, 
       4.}}], PolygonBox[{{4.4375, 4.}, {4.437499981032941, 
       4.084292589556061}, {4.5, 4.}, {4.4375, 4.}}], 
      PolygonBox[{{4.5, 4.20590900530174}, {4.5, 4.}, {4.437499981032941, 
       4.084292589556061}, {4.5, 4.20590900530174}}], 
      PolygonBox[{{4.437499981032941, 4.084292589556061}, {4.437344993353523, 
       4.230251642536255}, {4.5, 4.20590900530174}, {4.437499981032941, 
       4.084292589556061}}], 
      PolygonBox[{{4.5, 4.357662782649368}, {4.5, 4.20590900530174}, {
       4.437344993353523, 4.230251642536255}, {4.5, 4.357662782649368}}], 
      PolygonBox[{{4.437344993353523, 4.230251642536255}, {4.404942744332997, 
       4.404942744332997}, {4.5, 4.357662782649368}, {4.437344993353523, 
       4.230251642536255}}], 
      PolygonBox[{{4.491446564961186, 4.491446564961186}, {4.5, 
       4.357662782649368}, {4.404942744332997, 4.404942744332997}, {
       4.491446564961186, 4.491446564961186}}], 
      PolygonBox[{{4.404942744332997, 4.404942744332997}, {4.230251642536255, 
       4.437344993353523}, {4.491446564961186, 4.491446564961186}, {
       4.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{4.357662782649368, 4.5}, {4.491446564961186, 
       4.491446564961186}, {4.230251642536255, 4.437344993353523}, {
       4.357662782649368, 4.5}}], 
      PolygonBox[{{4.230251642536255, 4.437344993353523}, {
       4.0842925895560604`, 4.437499981032941}, {4.357662782649368, 4.5}, {
       4.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{4.205909005373256, 4.5}, {4.357662782649368, 4.5}, {
       4.0842925895560604`, 4.437499981032941}, {4.205909005373256, 4.5}}], 
      PolygonBox[{{4.0842925895560604`, 4.437499981032941}, {
       4.000105527220487, 4.4375}, {4.205909005373256, 4.5}, {
       4.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{4.07794195802689, 4.5}, {4.205909005373256, 4.5}, {
       4.000105527220487, 4.4375}, {4.07794195802689, 4.5}}], 
      PolygonBox[{{4.000105527220487, 4.4375}, {3.915707410443943, 
       4.437499981032941}, {4.07794195802689, 4.5}, {4.000105527220487, 
       4.4375}}], 
      PolygonBox[{{3.7940909946955546`, 4.5}, {4.07794195802689, 4.5}, {
       3.915707410443943, 4.437499981032941}, {3.7940909946955546`, 4.5}}], 
      PolygonBox[{{3.915707410443943, 4.437499981032941}, {3.769748357463745, 
       4.437344993353523}, {3.7940909946955546`, 4.5}, {3.915707410443943, 
       4.437499981032941}}], 
      PolygonBox[{{3.642337217350634, 4.5}, {3.7940909946955546`, 4.5}, {
       3.769748357463745, 4.437344993353523}, {3.642337217350634, 4.5}}], 
      PolygonBox[{{3.769748357463745, 4.437344993353523}, {3.595057255667003, 
       4.404942744332997}, {3.642337217350634, 4.5}, {3.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{4.5, 4.5}, {3.642337217350634, 4.5}, {3.595057255667003, 
       4.404942744332997}, {4.5, 4.5}}], 
      PolygonBox[{{3.595057255667003, 4.404942744332997}, {
       3.5626550066464766`, 4.230251642536255}, {4.5, 4.5}, {
       3.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{3.5, 4.357662782649369}, {4.5, 4.5}, {3.5626550066464766`, 
       4.230251642536255}, {3.5, 4.357662782649369}}], 
      PolygonBox[{{3.5626550066464766`, 4.230251642536255}, {
       3.562500018967059, 4.084292589556062}, {3.5, 4.357662782649369}, {
       3.5626550066464766`, 4.230251642536255}}], 
      PolygonBox[{{3.5, 4.205909005282899}, {3.5, 4.357662782649369}, {
       3.562500018967059, 4.084292589556062}, {3.5, 4.205909005282899}}], 
      PolygonBox[{{3.562500018967059, 4.084292589556062}, {3.5625, 
       4.000123178062996}, {3.5, 4.205909005282899}, {3.562500018967059, 
       4.084292589556062}}], 
      PolygonBox[{{3.5, 4.0806786667587005`}, {3.5, 4.205909005282899}, {
       3.5625, 4.000123178062996}, {3.5, 4.0806786667587005`}}], 
      PolygonBox[{{3.5625, 4.000123178062996}, {3.562500018967059, 
       3.915707410443945}, {3.5, 4.0806786667587005`}, {3.5625, 
       4.000123178062996}}], 
      PolygonBox[{{3.5, 3.7940909948547215`}, {3.5, 4.0806786667587005`}, {
       3.562500018967059, 3.915707410443945}, {3.5, 3.7940909948547215`}}], 
      PolygonBox[{{3.562500018967059, 3.915707410443945}, {
       3.5626550066464766`, 3.769748357463745}, {3.5, 3.7940909948547215`}, {
       3.562500018967059, 3.915707410443945}}], 
      PolygonBox[{{3.5, 3.6423372173506348`}, {3.5, 3.7940909948547215`}, {
       3.5626550066464766`, 3.769748357463745}, {3.5, 3.6423372173506348`}}], 
      PolygonBox[{{3.5626550066464766`, 3.769748357463745}, {
       3.595057255667003, 3.595057255667003}, {3.5, 3.6423372173506348`}, {
       3.5626550066464766`, 3.769748357463745}}], 
      PolygonBox[{{3.5, 4.5}, {3.5, 3.6423372173506348`}, {3.595057255667003, 
       3.595057255667003}, {3.5, 4.5}}], 
      PolygonBox[{{3.595057255667003, 3.595057255667003}, {3.769748357463745, 
       3.5626550066464766`}, {3.5, 4.5}, {3.595057255667003, 
       3.595057255667003}}], 
      PolygonBox[{{3.5, 3.5}, {3.5, 4.5}, {3.769748357463745, 
       3.5626550066464766`}, {3.5, 3.5}}], 
      PolygonBox[{{3.769748357463745, 3.5626550066464766`}, {
       3.915707410443936, 3.562500018967059}, {3.5, 3.5}, {3.769748357463745, 
       3.5626550066464766`}}], 
      PolygonBox[{{3.794090994433172, 3.5}, {3.5, 3.5}, {3.915707410443936, 
       3.562500018967059}, {3.794090994433172, 3.5}}], 
      PolygonBox[{{3.915707410443936, 3.562500018967059}, {4.000134841831043, 
       3.5625}, {3.794090994433172, 3.5}, {3.915707410443936, 
       3.562500018967059}}], 
      PolygonBox[{{4.082323870401062, 3.5}, {3.794090994433172, 3.5}, {
       4.000134841831043, 3.5625}, {4.082323870401062, 3.5}}], 
      PolygonBox[{{4.000134841831043, 3.5625}, {4.084292589556053, 
       3.562500018967059}, {4.082323870401062, 3.5}, {4.000134841831043, 
       3.5625}}], 
      PolygonBox[{{4.205909005360398, 3.5}, {4.082323870401062, 3.5}, {
       4.084292589556053, 3.562500018967059}, {4.205909005360398, 3.5}}], 
      PolygonBox[{{4.084292589556053, 3.562500018967059}, {4.230251642536254, 
       3.5626550066464766`}, {4.205909005360398, 3.5}, {4.084292589556053, 
       3.562500018967059}}], 
      PolygonBox[{{4.3576627826493715`, 3.5}, {4.205909005360398, 3.5}, {
       4.230251642536254, 3.5626550066464766`}, {4.3576627826493715`, 3.5}}], 
      PolygonBox[{{4.230251642536254, 3.5626550066464766`}, {
       4.404942744332997, 3.595057255667003}, {4.3576627826493715`, 3.5}, {
       4.230251642536254, 3.5626550066464766`}}], 
      PolygonBox[{{4.5, 3.5}, {4.3576627826493715`, 3.5}, {4.404942744332997, 
       3.595057255667003}, {4.5, 3.5}}], 
      PolygonBox[{{4.404942744332997, 3.595057255667003}, {4.404942744332997, 
       3.595057255667003}, {4.5, 3.5}, {4.404942744332997, 
       3.595057255667003}}], 
      PolygonBox[{{4.5, 3.5}, {4.5, 3.5}, {4.404942744332997, 
       3.595057255667003}, {4.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5, 5.}, {3.5208333333333335`, 5.}, {3.5416666666666665`, 
       5.}, {3.5625, 5.}, {3.5833333333333335`, 5.}, {3.6041666666666665`, 
       5.}, {3.625, 5.}, {3.625, 5.}, {3.6041666666666665`, 5.}, {
       3.5833333333333335`, 5.}, {3.5625, 5.}, {3.5416666666666665`, 5.}, {
       3.5208333333333335`, 5.}, {3.5, 5.}, {3.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375, 5.}, {4.395833333333333, 5.}, {4.416666666666667, 
       5.}, {4.4375, 5.}, {4.458333333333333, 5.}, {4.479166666666667, 5.}, {
       4.5, 5.}, {4.5, 5.}, {4.479166666666667, 5.}, {4.458333333333333, 
       5.}, {4.4375, 5.}, {4.416666666666667, 5.}, {4.395833333333333, 5.}, {
       4.375, 5.}, {4.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 4.5}, {4., 4.520833333333333}, {4., 4.541666666666667}, {
       4., 4.5625}, {4., 4.583333333333333}, {4., 4.604166666666667}, {4., 
       4.625}, {4., 4.625}, {4., 4.604166666666667}, {4., 
       4.583333333333333}, {4., 4.5625}, {4., 4.541666666666667}, {4., 
       4.520833333333333}, {4., 4.5}, {4., 4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 5.375}, {4., 5.395833333333333}, {4., 
       5.416666666666667}, {4., 5.4375}, {4., 5.458333333333333}, {4., 
       5.479166666666667}, {4., 5.5}, {4., 5.5}, {4., 5.479166666666667}, {4.,
        5.458333333333333}, {4., 5.4375}, {4., 5.416666666666667}, {4., 
       5.395833333333333}, {4., 5.375}, {4., 5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.625, 5.}, {3.75, 5.}, {3.875, 5.}, {4., 5.}, {4.125, 5.}, {
       4.25, 5.}, {4.375, 5.}, {4.375, 5.}, {4.25, 5.}, {4.125, 5.}, {4., 
       5.}, {3.875, 5.}, {3.75, 5.}, {3.625, 5.}, {3.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., 4.625}, {4., 4.75}, {4., 4.875}, {4., 5.}, {4., 5.125}, {
       4., 5.25}, {4., 5.375}, {4., 5.375}, {4., 5.25}, {4., 5.125}, {4., 
       5.}, {4., 4.875}, {4., 4.75}, {4., 4.625}, {4., 4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNgg4QhojD14zw+FdFgg7qRZ2fkpJFHGYoPznU
6wOVPyDicO7b2Zx2fkEoLQoVF4CqE4XqE4CaA5VnEIDQDaIOG6XfSllZ8qPK
N/DB9acKpah9fMALN//CDvOqJ2m8cPvF9AIdtaV4HTSg7oOYzwt3P0z+Zm8Z
79w5wqj6HYQdUqDmG3MaTa74IAS3P+OOtG3RZiG4+7inr1gg2iuE5n4huP9Q
5IH+h+mHhY8R1HyU8APaDwvfG1D3oYc/ANGTdZs=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFCDhBazCEUDATh/NWrQEAAzofQAmjyfHB+GFg/
L5p6HoJ8iL2icD7EXBE09SJo6oXR1Auhqcfkh6K4TwjN/TD1AmjyAmj6BdHU
E6ZR3SeE5n6YuAiaehE09aJo6sUcAMQAQ3U=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{4.265165042944956, 4.734834957055044}, {
       4.3247595264191645`, 4.8125}, {4.404942744332997, 4.595057255667003}, {
       4.265165042944956, 4.734834957055044}}], 
      PolygonBox[{{4.437344993353523, 4.769748357463745}, {4.404942744332997, 
       4.595057255667003}, {4.3247595264191645`, 4.8125}, {4.437344993353523, 
       4.769748357463745}}], 
      PolygonBox[{{4.3247595264191645`, 4.8125}, {4.362222184858401, 
       4.902942858086555}, {4.437344993353523, 4.769748357463745}, {
       4.3247595264191645`, 4.8125}}], 
      PolygonBox[{{4.437499981032941, 4.915707410443938}, {4.437344993353523, 
       4.769748357463745}, {4.362222184858401, 4.902942858086555}, {
       4.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{4.362222184858401, 4.902942858086555}, {4.375, 5.}, {
       4.437499981032941, 4.915707410443938}, {4.362222184858401, 
       4.902942858086555}}], 
      PolygonBox[{{4.4375, 5.}, {4.437499981032941, 4.915707410443938}, {
       4.375, 5.}, {4.4375, 5.}}], 
      PolygonBox[{{4.375, 5.}, {4.362222184858401, 5.097057141913445}, {
       4.4375, 5.}, {4.375, 5.}}], 
      PolygonBox[{{4.437499981032941, 5.084292589556061}, {4.4375, 5.}, {
       4.362222184858401, 5.097057141913445}, {4.437499981032941, 
       5.084292589556061}}], 
      PolygonBox[{{4.362222184858401, 5.097057141913445}, {
       4.3247595264191645`, 5.1875}, {4.437499981032941, 5.084292589556061}, {
       4.362222184858401, 5.097057141913445}}], 
      PolygonBox[{{4.437344993353523, 5.230251642536255}, {4.437499981032941, 
       5.084292589556061}, {4.3247595264191645`, 5.1875}, {4.437344993353523, 
       5.230251642536255}}], 
      PolygonBox[{{4.3247595264191645`, 5.1875}, {4.265165042944956, 
       5.265165042944956}, {4.437344993353523, 5.230251642536255}, {
       4.3247595264191645`, 5.1875}}], 
      PolygonBox[{{4.404942744332997, 5.404942744332997}, {4.437344993353523, 
       5.230251642536255}, {4.265165042944956, 5.265165042944956}, {
       4.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{4.265165042944956, 5.265165042944956}, {4.1875, 
       5.3247595264191645`}, {4.404942744332997, 5.404942744332997}, {
       4.265165042944956, 5.265165042944956}}], 
      PolygonBox[{{4.230251642536255, 5.437344993353523}, {4.404942744332997, 
       5.404942744332997}, {4.1875, 5.3247595264191645`}, {4.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{4.1875, 5.3247595264191645`}, {4.097057141913445, 
       5.362222184858401}, {4.230251642536255, 5.437344993353523}, {4.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{4.0842925895560604`, 5.437499981032941}, {
       4.230251642536255, 5.437344993353523}, {4.097057141913445, 
       5.362222184858401}, {4.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{4.097057141913445, 5.362222184858401}, {4., 5.375}, {
       4.0842925895560604`, 5.437499981032941}, {4.097057141913445, 
       5.362222184858401}}], 
      PolygonBox[{{4.000105527220487, 5.4375}, {4.0842925895560604`, 
       5.437499981032941}, {4., 5.375}, {4.000105527220487, 5.4375}}], 
      PolygonBox[{{4., 5.375}, {3.902942858086555, 5.362222184858401}, {
       4.000105527220487, 5.4375}, {4., 5.375}}], 
      PolygonBox[{{3.915707410443943, 5.437499981032941}, {4.000105527220487, 
       5.4375}, {3.902942858086555, 5.362222184858401}, {3.915707410443943, 
       5.437499981032941}}], 
      PolygonBox[{{3.902942858086555, 5.362222184858401}, {3.8125, 
       5.3247595264191645`}, {3.915707410443943, 5.437499981032941}, {
       3.902942858086555, 5.362222184858401}}], 
      PolygonBox[{{3.769748357463745, 5.437344993353523}, {3.915707410443943, 
       5.437499981032941}, {3.8125, 5.3247595264191645`}, {3.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{3.8125, 5.3247595264191645`}, {3.7348349570550448`, 
       5.265165042944956}, {3.769748357463745, 5.437344993353523}, {3.8125, 
       5.3247595264191645`}}], 
      PolygonBox[{{3.595057255667003, 5.404942744332997}, {3.769748357463745, 
       5.437344993353523}, {3.7348349570550448`, 5.265165042944956}, {
       3.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{3.7348349570550448`, 5.265165042944956}, {
       3.6752404735808355`, 5.1875}, {3.595057255667003, 5.404942744332997}, {
       3.7348349570550448`, 5.265165042944956}}], 
      PolygonBox[{{3.5626550066464766`, 5.230251642536255}, {
       3.595057255667003, 5.404942744332997}, {3.6752404735808355`, 5.1875}, {
       3.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{3.6752404735808355`, 5.1875}, {3.6377778151415994`, 
       5.097057141913446}, {3.5626550066464766`, 5.230251642536255}, {
       3.6752404735808355`, 5.1875}}], 
      PolygonBox[{{3.562500018967059, 5.084292589556062}, {
       3.5626550066464766`, 5.230251642536255}, {3.6377778151415994`, 
       5.097057141913446}, {3.562500018967059, 5.084292589556062}}], 
      PolygonBox[{{3.6377778151415994`, 5.097057141913446}, {3.625, 5.}, {
       3.562500018967059, 5.084292589556062}, {3.6377778151415994`, 
       5.097057141913446}}], 
      PolygonBox[{{3.5625, 5.000123178062996}, {3.562500018967059, 
       5.084292589556062}, {3.625, 5.}, {3.5625, 5.000123178062996}}], 
      PolygonBox[{{3.625, 5.}, {3.6377778151415994`, 4.902942858086555}, {
       3.5625, 5.000123178062996}, {3.625, 5.}}], 
      PolygonBox[{{3.562500018967059, 4.915707410443945}, {3.5625, 
       5.000123178062996}, {3.6377778151415994`, 4.902942858086555}, {
       3.562500018967059, 4.915707410443945}}], 
      PolygonBox[{{3.6377778151415994`, 4.902942858086555}, {
       3.6752404735808355`, 4.8125}, {3.562500018967059, 4.915707410443945}, {
       3.6377778151415994`, 4.902942858086555}}], 
      PolygonBox[{{3.5626550066464766`, 4.769748357463746}, {
       3.562500018967059, 4.915707410443945}, {3.6752404735808355`, 4.8125}, {
       3.5626550066464766`, 4.769748357463746}}], 
      PolygonBox[{{3.6752404735808355`, 4.8125}, {3.7348349570550448`, 
       4.734834957055044}, {3.5626550066464766`, 4.769748357463746}, {
       3.6752404735808355`, 4.8125}}], 
      PolygonBox[{{3.595057255667003, 4.595057255667003}, {
       3.5626550066464766`, 4.769748357463746}, {3.7348349570550448`, 
       4.734834957055044}, {3.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{3.7348349570550448`, 4.734834957055044}, {3.8125, 
       4.6752404735808355`}, {3.595057255667003, 4.595057255667003}, {
       3.7348349570550448`, 4.734834957055044}}], 
      PolygonBox[{{3.769748357463745, 4.562655006646477}, {3.595057255667003, 
       4.595057255667003}, {3.8125, 4.6752404735808355`}, {3.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{3.8125, 4.6752404735808355`}, {3.9029428580865546`, 
       4.637777815141599}, {3.769748357463745, 4.562655006646477}, {3.8125, 
       4.6752404735808355`}}], 
      PolygonBox[{{3.915707410443936, 4.562500018967059}, {3.769748357463745, 
       4.562655006646477}, {3.9029428580865546`, 4.637777815141599}, {
       3.915707410443936, 4.562500018967059}}], 
      PolygonBox[{{3.9029428580865546`, 4.637777815141599}, {4., 4.625}, {
       3.915707410443936, 4.562500018967059}, {3.9029428580865546`, 
       4.637777815141599}}], 
      PolygonBox[{{4.000134841831043, 4.5625}, {3.915707410443936, 
       4.562500018967059}, {4., 4.625}, {4.000134841831043, 4.5625}}], 
      PolygonBox[{{4., 4.625}, {4.097057141913445, 4.637777815141599}, {
       4.000134841831043, 4.5625}, {4., 4.625}}], 
      PolygonBox[{{4.084292589556053, 4.562500018967059}, {4.000134841831043, 
       4.5625}, {4.097057141913445, 4.637777815141599}, {4.084292589556053, 
       4.562500018967059}}], 
      PolygonBox[{{4.097057141913445, 4.637777815141599}, {4.1875, 
       4.6752404735808355`}, {4.084292589556053, 4.562500018967059}, {
       4.097057141913445, 4.637777815141599}}], 
      PolygonBox[{{4.230251642536254, 4.562655006646477}, {4.084292589556053, 
       4.562500018967059}, {4.1875, 4.6752404735808355`}, {4.230251642536254, 
       4.562655006646477}}], 
      PolygonBox[{{4.1875, 4.6752404735808355`}, {4.265165042944956, 
       4.734834957055044}, {4.230251642536254, 4.562655006646477}, {4.1875, 
       4.6752404735808355`}}], 
      PolygonBox[{{4.404942744332997, 4.595057255667003}, {4.230251642536254, 
       4.562655006646477}, {4.265165042944956, 4.734834957055044}, {
       4.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{4.265165042944956, 4.734834957055044}, {4.265165042944956, 
       4.734834957055044}, {4.404942744332997, 4.595057255667003}, {
       4.265165042944956, 4.734834957055044}}], 
      PolygonBox[{{4.404942744332997, 4.595057255667003}, {4.404942744332997, 
       4.595057255667003}, {4.265165042944956, 4.734834957055044}, {
       4.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{4.404942744332997, 4.595057255667003}, {4.437344993353523, 
       4.769748357463745}, {4.5, 4.5}, {4.404942744332997, 
       4.595057255667003}}], 
      PolygonBox[{{4.5, 4.642337217350632}, {4.5, 4.5}, {4.437344993353523, 
       4.769748357463745}, {4.5, 4.642337217350632}}], 
      PolygonBox[{{4.437344993353523, 4.769748357463745}, {4.437499981032941, 
       4.915707410443938}, {4.5, 4.642337217350632}, {4.437344993353523, 
       4.769748357463745}}], 
      PolygonBox[{{4.5, 4.79409099469826}, {4.5, 4.642337217350632}, {
       4.437499981032941, 4.915707410443938}, {4.5, 4.79409099469826}}], 
      PolygonBox[{{4.437499981032941, 4.915707410443938}, {4.4375, 5.}, {4.5, 
       4.79409099469826}, {4.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{4.5, 5.}, {4.5, 4.79409099469826}, {4.4375, 5.}, {4.5, 
       5.}}], PolygonBox[{{4.4375, 5.}, {4.437499981032941, 
       5.084292589556061}, {4.5, 5.}, {4.4375, 5.}}], 
      PolygonBox[{{4.5, 5.20590900530174}, {4.5, 5.}, {4.437499981032941, 
       5.084292589556061}, {4.5, 5.20590900530174}}], 
      PolygonBox[{{4.437499981032941, 5.084292589556061}, {4.437344993353523, 
       5.230251642536255}, {4.5, 5.20590900530174}, {4.437499981032941, 
       5.084292589556061}}], 
      PolygonBox[{{4.5, 5.357662782649368}, {4.5, 5.20590900530174}, {
       4.437344993353523, 5.230251642536255}, {4.5, 5.357662782649368}}], 
      PolygonBox[{{4.437344993353523, 5.230251642536255}, {4.404942744332997, 
       5.404942744332997}, {4.5, 5.357662782649368}, {4.437344993353523, 
       5.230251642536255}}], 
      PolygonBox[{{4.491446564961186, 5.491446564961186}, {4.5, 
       5.357662782649368}, {4.404942744332997, 5.404942744332997}, {
       4.491446564961186, 5.491446564961186}}], 
      PolygonBox[{{4.404942744332997, 5.404942744332997}, {4.230251642536255, 
       5.437344993353523}, {4.491446564961186, 5.491446564961186}, {
       4.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{4.357662782649368, 5.5}, {4.491446564961186, 
       5.491446564961186}, {4.230251642536255, 5.437344993353523}, {
       4.357662782649368, 5.5}}], 
      PolygonBox[{{4.230251642536255, 5.437344993353523}, {
       4.0842925895560604`, 5.437499981032941}, {4.357662782649368, 5.5}, {
       4.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{4.205909005373256, 5.5}, {4.357662782649368, 5.5}, {
       4.0842925895560604`, 5.437499981032941}, {4.205909005373256, 5.5}}], 
      PolygonBox[{{4.0842925895560604`, 5.437499981032941}, {
       4.000105527220487, 5.4375}, {4.205909005373256, 5.5}, {
       4.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{4.07794195802689, 5.5}, {4.205909005373256, 5.5}, {
       4.000105527220487, 5.4375}, {4.07794195802689, 5.5}}], 
      PolygonBox[{{4.000105527220487, 5.4375}, {3.915707410443943, 
       5.437499981032941}, {4.07794195802689, 5.5}, {4.000105527220487, 
       5.4375}}], 
      PolygonBox[{{3.7940909946955546`, 5.5}, {4.07794195802689, 5.5}, {
       3.915707410443943, 5.437499981032941}, {3.7940909946955546`, 5.5}}], 
      PolygonBox[{{3.915707410443943, 5.437499981032941}, {3.769748357463745, 
       5.437344993353523}, {3.7940909946955546`, 5.5}, {3.915707410443943, 
       5.437499981032941}}], 
      PolygonBox[{{3.642337217350634, 5.5}, {3.7940909946955546`, 5.5}, {
       3.769748357463745, 5.437344993353523}, {3.642337217350634, 5.5}}], 
      PolygonBox[{{3.769748357463745, 5.437344993353523}, {3.595057255667003, 
       5.404942744332997}, {3.642337217350634, 5.5}, {3.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{4.5, 5.5}, {3.642337217350634, 5.5}, {3.595057255667003, 
       5.404942744332997}, {4.5, 5.5}}], 
      PolygonBox[{{3.595057255667003, 5.404942744332997}, {
       3.5626550066464766`, 5.230251642536255}, {4.5, 5.5}, {
       3.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{3.5, 5.357662782649369}, {4.5, 5.5}, {3.5626550066464766`, 
       5.230251642536255}, {3.5, 5.357662782649369}}], 
      PolygonBox[{{3.5626550066464766`, 5.230251642536255}, {
       3.562500018967059, 5.084292589556062}, {3.5, 5.357662782649369}, {
       3.5626550066464766`, 5.230251642536255}}], 
      PolygonBox[{{3.5, 5.205909005282899}, {3.5, 5.357662782649369}, {
       3.562500018967059, 5.084292589556062}, {3.5, 5.205909005282899}}], 
      PolygonBox[{{3.562500018967059, 5.084292589556062}, {3.5625, 
       5.000123178062996}, {3.5, 5.205909005282899}, {3.562500018967059, 
       5.084292589556062}}], 
      PolygonBox[{{3.5, 5.0806786667587005`}, {3.5, 5.205909005282899}, {
       3.5625, 5.000123178062996}, {3.5, 5.0806786667587005`}}], 
      PolygonBox[{{3.5625, 5.000123178062996}, {3.562500018967059, 
       4.915707410443945}, {3.5, 5.0806786667587005`}, {3.5625, 
       5.000123178062996}}], 
      PolygonBox[{{3.5, 4.794090994854722}, {3.5, 5.0806786667587005`}, {
       3.562500018967059, 4.915707410443945}, {3.5, 4.794090994854722}}], 
      PolygonBox[{{3.562500018967059, 4.915707410443945}, {
       3.5626550066464766`, 4.769748357463746}, {3.5, 4.794090994854722}, {
       3.562500018967059, 4.915707410443945}}], 
      PolygonBox[{{3.5, 4.642337217350635}, {3.5, 4.794090994854722}, {
       3.5626550066464766`, 4.769748357463746}, {3.5, 4.642337217350635}}], 
      PolygonBox[{{3.5626550066464766`, 4.769748357463746}, {
       3.595057255667003, 4.595057255667003}, {3.5, 4.642337217350635}, {
       3.5626550066464766`, 4.769748357463746}}], 
      PolygonBox[{{3.5, 5.5}, {3.5, 4.642337217350635}, {3.595057255667003, 
       4.595057255667003}, {3.5, 5.5}}], 
      PolygonBox[{{3.595057255667003, 4.595057255667003}, {3.769748357463745, 
       4.562655006646477}, {3.5, 5.5}, {3.595057255667003, 
       4.595057255667003}}], 
      PolygonBox[{{3.5, 4.5}, {3.5, 5.5}, {3.769748357463745, 
       4.562655006646477}, {3.5, 4.5}}], 
      PolygonBox[{{3.769748357463745, 4.562655006646477}, {3.915707410443936, 
       4.562500018967059}, {3.5, 4.5}, {3.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{3.794090994433172, 4.5}, {3.5, 4.5}, {3.915707410443936, 
       4.562500018967059}, {3.794090994433172, 4.5}}], 
      PolygonBox[{{3.915707410443936, 4.562500018967059}, {4.000134841831043, 
       4.5625}, {3.794090994433172, 4.5}, {3.915707410443936, 
       4.562500018967059}}], 
      PolygonBox[{{4.082323870401062, 4.5}, {3.794090994433172, 4.5}, {
       4.000134841831043, 4.5625}, {4.082323870401062, 4.5}}], 
      PolygonBox[{{4.000134841831043, 4.5625}, {4.084292589556053, 
       4.562500018967059}, {4.082323870401062, 4.5}, {4.000134841831043, 
       4.5625}}], 
      PolygonBox[{{4.205909005360398, 4.5}, {4.082323870401062, 4.5}, {
       4.084292589556053, 4.562500018967059}, {4.205909005360398, 4.5}}], 
      PolygonBox[{{4.084292589556053, 4.562500018967059}, {4.230251642536254, 
       4.562655006646477}, {4.205909005360398, 4.5}, {4.084292589556053, 
       4.562500018967059}}], 
      PolygonBox[{{4.3576627826493715`, 4.5}, {4.205909005360398, 4.5}, {
       4.230251642536254, 4.562655006646477}, {4.3576627826493715`, 4.5}}], 
      PolygonBox[{{4.230251642536254, 4.562655006646477}, {4.404942744332997, 
       4.595057255667003}, {4.3576627826493715`, 4.5}, {4.230251642536254, 
       4.562655006646477}}], 
      PolygonBox[{{4.5, 4.5}, {4.3576627826493715`, 4.5}, {4.404942744332997, 
       4.595057255667003}, {4.5, 4.5}}], 
      PolygonBox[{{4.404942744332997, 4.595057255667003}, {4.404942744332997, 
       4.595057255667003}, {4.5, 4.5}, {4.404942744332997, 
       4.595057255667003}}], 
      PolygonBox[{{4.5, 4.5}, {4.5, 4.5}, {4.404942744332997, 
       4.595057255667003}, {4.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, -5.}, {4.520833333333333, -5.}, {
       4.541666666666667, -5.}, {4.5625, -5.}, {4.583333333333333, -5.}, {
       4.604166666666667, -5.}, {4.625, -5.}, {4.625, -5.}, {
       4.604166666666667, -5.}, {4.583333333333333, -5.}, {4.5625, -5.}, {
       4.541666666666667, -5.}, {4.520833333333333, -5.}, {4.5, -5.}, {
       4.5, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, -5.}, {5.395833333333333, -5.}, {
       5.416666666666667, -5.}, {5.4375, -5.}, {5.458333333333333, -5.}, {
       5.479166666666667, -5.}, {5.5, -5.}, {5.5, -5.}, {
       5.479166666666667, -5.}, {5.458333333333333, -5.}, {5.4375, -5.}, {
       5.416666666666667, -5.}, {5.395833333333333, -5.}, {5.375, -5.}, {
       5.375, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -5.5}, {5., -5.479166666666667}, {
       5., -5.458333333333333}, {5., -5.4375}, {5., -5.416666666666667}, {
       5., -5.395833333333333}, {5., -5.375}, {5., -5.375}, {
       5., -5.395833333333333}, {5., -5.416666666666667}, {5., -5.4375}, {
       5., -5.458333333333333}, {5., -5.479166666666667}, {5., -5.5}, {
       5., -5.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -4.625}, {5., -4.604166666666667}, {
       5., -4.583333333333333}, {5., -4.5625}, {5., -4.541666666666667}, {
       5., -4.520833333333333}, {5., -4.5}, {5., -4.5}, {
       5., -4.520833333333333}, {5., -4.541666666666667}, {5., -4.5625}, {
       5., -4.583333333333333}, {5., -4.604166666666667}, {5., -4.625}, {
       5., -4.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, -5.}, {4.75, -5.}, {4.875, -5.}, {5., -5.}, {
       5.125, -5.}, {5.25, -5.}, {5.375, -5.}, {5.375, -5.}, {5.25, -5.}, {
       5.125, -5.}, {5., -5.}, {4.875, -5.}, {4.75, -5.}, {4.625, -5.}, {
       4.625, -5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -5.375}, {5., -5.25}, {5., -5.125}, {5., -5.}, {
       5., -4.875}, {5., -4.75}, {5., -4.625}, {5., -4.625}, {5., -4.75}, {
       5., -4.875}, {5., -5.}, {5., -5.125}, {5., -5.25}, {5., -5.375}, {
       5., -5.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4QhsiBrxnh8a+KRB1u9pbxzp0jfGCG8pND
vT5QeQfhA+e+nc1p5xd1MOI0mlzxQegAWPyAiEPGHWnbos1CB9SLOj8lJYs4
cE9fsUC0FyrPIALR3yB0AGouqryDMFw/1Fy4+VBxuP1QfQ43oO6Dmgt3P0we
6g5U/QdE4OafhfgDbj/Unweg5jpAwwHN/aJw/6HIA/0P0w8LHyiNGn4HEOGr
AXUfevgDAC2PhMg=
      "]], LineBox[CompressedData["
1:eJyFzs0JgDAMhuHiCGmakxc3cQbBBQTP7qVLdDSt/YG+HgyE8MHT8k3bseyD
c258Nt08NucrcX0ntHydabTlfBXewwv8fy7vWi7/wiu8wgd4++S+n6F/9Qqv
8AHefnPfz9C/eoX38AIv8QYD71H6
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, -5.265165042944956}, {
       5.3247595264191645`, -5.1875}, {
       5.404942744332997, -5.404942744332997}, {
       5.265165042944956, -5.265165042944956}}], 
      PolygonBox[{{5.437344993353523, -5.230251642536255}, {
       5.404942744332997, -5.404942744332997}, {
       5.3247595264191645`, -5.1875}, {
       5.437344993353523, -5.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, -5.1875}, {
       5.362222184858401, -5.097057141913445}, {
       5.437344993353523, -5.230251642536255}, {
       5.3247595264191645`, -5.1875}}], 
      PolygonBox[{{5.437499981032941, -5.084292589556062}, {
       5.437344993353523, -5.230251642536255}, {
       5.362222184858401, -5.097057141913445}, {
       5.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{5.362222184858401, -5.097057141913445}, {5.375, -5.}, {
       5.437499981032941, -5.084292589556062}, {
       5.362222184858401, -5.097057141913445}}], 
      PolygonBox[{{5.4375, -5.}, {5.437499981032941, -5.084292589556062}, {
       5.375, -5.}, {5.4375, -5.}}], 
      PolygonBox[{{5.375, -5.}, {5.362222184858401, -4.902942858086555}, {
       5.4375, -5.}, {5.375, -5.}}], 
      PolygonBox[{{5.437499981032941, -4.915707410443939}, {5.4375, -5.}, {
       5.362222184858401, -4.902942858086555}, {
       5.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{5.362222184858401, -4.902942858086555}, {
       5.3247595264191645`, -4.8125}, {
       5.437499981032941, -4.915707410443939}, {
       5.362222184858401, -4.902942858086555}}], 
      PolygonBox[{{5.437344993353523, -4.769748357463745}, {
       5.437499981032941, -4.915707410443939}, {
       5.3247595264191645`, -4.8125}, {
       5.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{5.3247595264191645`, -4.8125}, {
       5.265165042944956, -4.734834957055044}, {
       5.437344993353523, -4.769748357463745}, {
       5.3247595264191645`, -4.8125}}], 
      PolygonBox[{{5.404942744332997, -4.595057255667003}, {
       5.437344993353523, -4.769748357463745}, {
       5.265165042944956, -4.734834957055044}, {
       5.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{5.265165042944956, -4.734834957055044}, {
       5.1875, -4.6752404735808355`}, {
       5.404942744332997, -4.595057255667003}, {
       5.265165042944956, -4.734834957055044}}], 
      PolygonBox[{{5.230251642536255, -4.562655006646477}, {
       5.404942744332997, -4.595057255667003}, {
       5.1875, -4.6752404735808355`}, {
       5.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{5.1875, -4.6752404735808355`}, {
       5.097057141913445, -4.637777815141599}, {
       5.230251642536255, -4.562655006646477}, {
       5.1875, -4.6752404735808355`}}], 
      PolygonBox[{{5.0842925895560604`, -4.562500018967059}, {
       5.230251642536255, -4.562655006646477}, {
       5.097057141913445, -4.637777815141599}, {
       5.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{5.097057141913445, -4.637777815141599}, {5., -4.625}, {
       5.0842925895560604`, -4.562500018967059}, {
       5.097057141913445, -4.637777815141599}}], 
      PolygonBox[{{5.000105527220487, -4.5625}, {
       5.0842925895560604`, -4.562500018967059}, {5., -4.625}, {
       5.000105527220487, -4.5625}}], 
      PolygonBox[{{5., -4.625}, {4.902942858086555, -4.637777815141599}, {
       5.000105527220487, -4.5625}, {5., -4.625}}], 
      PolygonBox[{{4.915707410443943, -4.562500018967059}, {
       5.000105527220487, -4.5625}, {4.902942858086555, -4.637777815141599}, {
       4.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{4.902942858086555, -4.637777815141599}, {
       4.8125, -4.6752404735808355`}, {
       4.915707410443943, -4.562500018967059}, {
       4.902942858086555, -4.637777815141599}}], 
      PolygonBox[{{4.769748357463745, -4.562655006646477}, {
       4.915707410443943, -4.562500018967059}, {
       4.8125, -4.6752404735808355`}, {
       4.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{4.8125, -4.6752404735808355`}, {
       4.734834957055044, -4.734834957055044}, {
       4.769748357463745, -4.562655006646477}, {
       4.8125, -4.6752404735808355`}}], 
      PolygonBox[{{4.595057255667003, -4.595057255667003}, {
       4.769748357463745, -4.562655006646477}, {
       4.734834957055044, -4.734834957055044}, {
       4.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{4.734834957055044, -4.734834957055044}, {
       4.6752404735808355`, -4.8125}, {
       4.595057255667003, -4.595057255667003}, {
       4.734834957055044, -4.734834957055044}}], 
      PolygonBox[{{4.562655006646477, -4.769748357463745}, {
       4.595057255667003, -4.595057255667003}, {
       4.6752404735808355`, -4.8125}, {
       4.562655006646477, -4.769748357463745}}], 
      PolygonBox[{{4.6752404735808355`, -4.8125}, {
       4.637777815141599, -4.902942858086554}, {
       4.562655006646477, -4.769748357463745}, {
       4.6752404735808355`, -4.8125}}], 
      PolygonBox[{{4.562500018967059, -4.915707410443938}, {
       4.562655006646477, -4.769748357463745}, {
       4.637777815141599, -4.902942858086554}, {
       4.562500018967059, -4.915707410443938}}], 
      PolygonBox[{{4.637777815141599, -4.902942858086554}, {4.625, -5.}, {
       4.562500018967059, -4.915707410443938}, {
       4.637777815141599, -4.902942858086554}}], 
      PolygonBox[{{4.5625, -4.999876821937004}, {
       4.562500018967059, -4.915707410443938}, {4.625, -5.}, {
       4.5625, -4.999876821937004}}], 
      PolygonBox[{{4.625, -5.}, {4.637777815141599, -5.097057141913445}, {
       4.5625, -4.999876821937004}, {4.625, -5.}}], 
      PolygonBox[{{4.562500018967059, -5.084292589556055}, {
       4.5625, -4.999876821937004}, {4.637777815141599, -5.097057141913445}, {
       4.562500018967059, -5.084292589556055}}], 
      PolygonBox[{{4.637777815141599, -5.097057141913445}, {
       4.6752404735808355`, -5.1875}, {
       4.562500018967059, -5.084292589556055}, {
       4.637777815141599, -5.097057141913445}}], 
      PolygonBox[{{4.562655006646477, -5.230251642536254}, {
       4.562500018967059, -5.084292589556055}, {
       4.6752404735808355`, -5.1875}, {
       4.562655006646477, -5.230251642536254}}], 
      PolygonBox[{{4.6752404735808355`, -5.1875}, {
       4.734834957055044, -5.265165042944956}, {
       4.562655006646477, -5.230251642536254}, {
       4.6752404735808355`, -5.1875}}], 
      PolygonBox[{{4.595057255667003, -5.404942744332997}, {
       4.562655006646477, -5.230251642536254}, {
       4.734834957055044, -5.265165042944956}, {
       4.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{4.734834957055044, -5.265165042944956}, {
       4.8125, -5.3247595264191645`}, {
       4.595057255667003, -5.404942744332997}, {
       4.734834957055044, -5.265165042944956}}], 
      PolygonBox[{{4.769748357463745, -5.437344993353523}, {
       4.595057255667003, -5.404942744332997}, {
       4.8125, -5.3247595264191645`}, {
       4.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{4.8125, -5.3247595264191645`}, {
       4.902942858086554, -5.362222184858401}, {
       4.769748357463745, -5.437344993353523}, {
       4.8125, -5.3247595264191645`}}], 
      PolygonBox[{{4.915707410443936, -5.437499981032941}, {
       4.769748357463745, -5.437344993353523}, {
       4.902942858086554, -5.362222184858401}, {
       4.915707410443936, -5.437499981032941}}], 
      PolygonBox[{{4.902942858086554, -5.362222184858401}, {5., -5.375}, {
       4.915707410443936, -5.437499981032941}, {
       4.902942858086554, -5.362222184858401}}], 
      PolygonBox[{{5.000134841831043, -5.4375}, {
       4.915707410443936, -5.437499981032941}, {5., -5.375}, {
       5.000134841831043, -5.4375}}], 
      PolygonBox[{{5., -5.375}, {5.097057141913445, -5.362222184858401}, {
       5.000134841831043, -5.4375}, {5., -5.375}}], 
      PolygonBox[{{5.084292589556053, -5.437499981032941}, {
       5.000134841831043, -5.4375}, {5.097057141913445, -5.362222184858401}, {
       5.084292589556053, -5.437499981032941}}], 
      PolygonBox[{{5.097057141913445, -5.362222184858401}, {
       5.1875, -5.3247595264191645`}, {
       5.084292589556053, -5.437499981032941}, {
       5.097057141913445, -5.362222184858401}}], 
      PolygonBox[{{5.230251642536254, -5.437344993353523}, {
       5.084292589556053, -5.437499981032941}, {
       5.1875, -5.3247595264191645`}, {
       5.230251642536254, -5.437344993353523}}], 
      PolygonBox[{{5.1875, -5.3247595264191645`}, {
       5.265165042944956, -5.265165042944956}, {
       5.230251642536254, -5.437344993353523}, {
       5.1875, -5.3247595264191645`}}], 
      PolygonBox[{{5.404942744332997, -5.404942744332997}, {
       5.230251642536254, -5.437344993353523}, {
       5.265165042944956, -5.265165042944956}, {
       5.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{5.265165042944956, -5.265165042944956}, {
       5.265165042944956, -5.265165042944956}, {
       5.404942744332997, -5.404942744332997}, {
       5.265165042944956, -5.265165042944956}}], 
      PolygonBox[{{5.404942744332997, -5.404942744332997}, {
       5.404942744332997, -5.404942744332997}, {
       5.265165042944956, -5.265165042944956}, {
       5.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{5.404942744332997, -5.404942744332997}, {
       5.437344993353523, -5.230251642536255}, {5.5, -5.5}, {
       5.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{5.5, -5.357662782649368}, {5.5, -5.5}, {
       5.437344993353523, -5.230251642536255}, {5.5, -5.357662782649368}}], 
      PolygonBox[{{5.437344993353523, -5.230251642536255}, {
       5.437499981032941, -5.084292589556062}, {5.5, -5.357662782649368}, {
       5.437344993353523, -5.230251642536255}}], 
      PolygonBox[{{5.5, -5.20590900530174}, {5.5, -5.357662782649368}, {
       5.437499981032941, -5.084292589556062}, {5.5, -5.20590900530174}}], 
      PolygonBox[{{5.437499981032941, -5.084292589556062}, {5.4375, -5.}, {
       5.5, -5.20590900530174}, {5.437499981032941, -5.084292589556062}}], 
      PolygonBox[{{5.5, -5.}, {5.5, -5.20590900530174}, {5.4375, -5.}, {
       5.5, -5.}}], 
      PolygonBox[{{5.4375, -5.}, {5.437499981032941, -4.915707410443939}, {
       5.5, -5.}, {5.4375, -5.}}], 
      PolygonBox[{{5.5, -4.79409099469826}, {5.5, -5.}, {
       5.437499981032941, -4.915707410443939}, {5.5, -4.79409099469826}}], 
      PolygonBox[{{5.437499981032941, -4.915707410443939}, {
       5.437344993353523, -4.769748357463745}, {5.5, -4.79409099469826}, {
       5.437499981032941, -4.915707410443939}}], 
      PolygonBox[{{5.5, -4.642337217350632}, {5.5, -4.79409099469826}, {
       5.437344993353523, -4.769748357463745}, {5.5, -4.642337217350632}}], 
      PolygonBox[{{5.437344993353523, -4.769748357463745}, {
       5.404942744332997, -4.595057255667003}, {5.5, -4.642337217350632}, {
       5.437344993353523, -4.769748357463745}}], 
      PolygonBox[{{5.491446564961186, -4.508553435038814}, {
       5.5, -4.642337217350632}, {5.404942744332997, -4.595057255667003}, {
       5.491446564961186, -4.508553435038814}}], 
      PolygonBox[{{5.404942744332997, -4.595057255667003}, {
       5.230251642536255, -4.562655006646477}, {
       5.491446564961186, -4.508553435038814}, {
       5.404942744332997, -4.595057255667003}}], 
      PolygonBox[{{5.357662782649368, -4.5}, {
       5.491446564961186, -4.508553435038814}, {
       5.230251642536255, -4.562655006646477}, {5.357662782649368, -4.5}}], 
      PolygonBox[{{5.230251642536255, -4.562655006646477}, {
       5.0842925895560604`, -4.562500018967059}, {5.357662782649368, -4.5}, {
       5.230251642536255, -4.562655006646477}}], 
      PolygonBox[{{5.205909005373256, -4.5}, {5.357662782649368, -4.5}, {
       5.0842925895560604`, -4.562500018967059}, {5.205909005373256, -4.5}}], 
      PolygonBox[{{5.0842925895560604`, -4.562500018967059}, {
       5.000105527220487, -4.5625}, {5.205909005373256, -4.5}, {
       5.0842925895560604`, -4.562500018967059}}], 
      PolygonBox[{{5.07794195802689, -4.5}, {5.205909005373256, -4.5}, {
       5.000105527220487, -4.5625}, {5.07794195802689, -4.5}}], 
      PolygonBox[{{5.000105527220487, -4.5625}, {
       4.915707410443943, -4.562500018967059}, {5.07794195802689, -4.5}, {
       5.000105527220487, -4.5625}}], 
      PolygonBox[{{4.794090994695554, -4.5}, {5.07794195802689, -4.5}, {
       4.915707410443943, -4.562500018967059}, {4.794090994695554, -4.5}}], 
      PolygonBox[{{4.915707410443943, -4.562500018967059}, {
       4.769748357463745, -4.562655006646477}, {4.794090994695554, -4.5}, {
       4.915707410443943, -4.562500018967059}}], 
      PolygonBox[{{4.642337217350634, -4.5}, {4.794090994695554, -4.5}, {
       4.769748357463745, -4.562655006646477}, {4.642337217350634, -4.5}}], 
      PolygonBox[{{4.769748357463745, -4.562655006646477}, {
       4.595057255667003, -4.595057255667003}, {4.642337217350634, -4.5}, {
       4.769748357463745, -4.562655006646477}}], 
      PolygonBox[{{5.5, -4.5}, {4.642337217350634, -4.5}, {
       4.595057255667003, -4.595057255667003}, {5.5, -4.5}}], 
      PolygonBox[{{4.595057255667003, -4.595057255667003}, {
       4.562655006646477, -4.769748357463745}, {5.5, -4.5}, {
       4.595057255667003, -4.595057255667003}}], 
      PolygonBox[{{4.5, -4.642337217350631}, {5.5, -4.5}, {
       4.562655006646477, -4.769748357463745}, {4.5, -4.642337217350631}}], 
      PolygonBox[{{4.562655006646477, -4.769748357463745}, {
       4.562500018967059, -4.915707410443938}, {4.5, -4.642337217350631}, {
       4.562655006646477, -4.769748357463745}}], 
      PolygonBox[{{4.5, -4.794090994717101}, {4.5, -4.642337217350631}, {
       4.562500018967059, -4.915707410443938}, {4.5, -4.794090994717101}}], 
      PolygonBox[{{4.562500018967059, -4.915707410443938}, {
       4.5625, -4.999876821937004}, {4.5, -4.794090994717101}, {
       4.562500018967059, -4.915707410443938}}], 
      PolygonBox[{{4.5, -4.9193213332412995`}, {4.5, -4.794090994717101}, {
       4.5625, -4.999876821937004}, {4.5, -4.9193213332412995`}}], 
      PolygonBox[{{4.5625, -4.999876821937004}, {
       4.562500018967059, -5.084292589556055}, {4.5, -4.9193213332412995`}, {
       4.5625, -4.999876821937004}}], 
      PolygonBox[{{4.5, -5.205909005145278}, {4.5, -4.9193213332412995`}, {
       4.562500018967059, -5.084292589556055}, {4.5, -5.205909005145278}}], 
      PolygonBox[{{4.562500018967059, -5.084292589556055}, {
       4.562655006646477, -5.230251642536254}, {4.5, -5.205909005145278}, {
       4.562500018967059, -5.084292589556055}}], 
      PolygonBox[{{4.5, -5.357662782649365}, {4.5, -5.205909005145278}, {
       4.562655006646477, -5.230251642536254}, {4.5, -5.357662782649365}}], 
      PolygonBox[{{4.562655006646477, -5.230251642536254}, {
       4.595057255667003, -5.404942744332997}, {4.5, -5.357662782649365}, {
       4.562655006646477, -5.230251642536254}}], 
      PolygonBox[{{4.5, -4.5}, {4.5, -5.357662782649365}, {
       4.595057255667003, -5.404942744332997}, {4.5, -4.5}}], 
      PolygonBox[{{4.595057255667003, -5.404942744332997}, {
       4.769748357463745, -5.437344993353523}, {4.5, -4.5}, {
       4.595057255667003, -5.404942744332997}}], 
      PolygonBox[{{4.5, -5.5}, {4.5, -4.5}, {
       4.769748357463745, -5.437344993353523}, {4.5, -5.5}}], 
      PolygonBox[{{4.769748357463745, -5.437344993353523}, {
       4.915707410443936, -5.437499981032941}, {4.5, -5.5}, {
       4.769748357463745, -5.437344993353523}}], 
      PolygonBox[{{4.794090994433172, -5.5}, {4.5, -5.5}, {
       4.915707410443936, -5.437499981032941}, {4.794090994433172, -5.5}}], 
      PolygonBox[{{4.915707410443936, -5.437499981032941}, {
       5.000134841831043, -5.4375}, {4.794090994433172, -5.5}, {
       4.915707410443936, -5.437499981032941}}], 
      PolygonBox[{{5.082323870401062, -5.5}, {4.794090994433172, -5.5}, {
       5.000134841831043, -5.4375}, {5.082323870401062, -5.5}}], 
      PolygonBox[{{5.000134841831043, -5.4375}, {
       5.084292589556053, -5.437499981032941}, {5.082323870401062, -5.5}, {
       5.000134841831043, -5.4375}}], 
      PolygonBox[{{5.205909005360398, -5.5}, {5.082323870401062, -5.5}, {
       5.084292589556053, -5.437499981032941}, {5.205909005360398, -5.5}}], 
      PolygonBox[{{5.084292589556053, -5.437499981032941}, {
       5.230251642536254, -5.437344993353523}, {5.205909005360398, -5.5}, {
       5.084292589556053, -5.437499981032941}}], 
      PolygonBox[{{5.3576627826493715`, -5.5}, {5.205909005360398, -5.5}, {
       5.230251642536254, -5.437344993353523}, {5.3576627826493715`, -5.5}}], 
      PolygonBox[{{5.230251642536254, -5.437344993353523}, {
       5.404942744332997, -5.404942744332997}, {5.3576627826493715`, -5.5}, {
       5.230251642536254, -5.437344993353523}}], 
      PolygonBox[{{5.5, -5.5}, {5.3576627826493715`, -5.5}, {
       5.404942744332997, -5.404942744332997}, {5.5, -5.5}}], 
      PolygonBox[{{5.404942744332997, -5.404942744332997}, {
       5.404942744332997, -5.404942744332997}, {5.5, -5.5}, {
       5.404942744332997, -5.404942744332997}}], 
      PolygonBox[{{5.5, -5.5}, {5.5, -5.5}, {
       5.404942744332997, -5.404942744332997}, {5.5, -5.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, -4.}, {4.520833333333333, -4.}, {
       4.541666666666667, -4.}, {4.5625, -4.}, {4.583333333333333, -4.}, {
       4.604166666666667, -4.}, {4.625, -4.}, {4.625, -4.}, {
       4.604166666666667, -4.}, {4.583333333333333, -4.}, {4.5625, -4.}, {
       4.541666666666667, -4.}, {4.520833333333333, -4.}, {4.5, -4.}, {
       4.5, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, -4.}, {5.395833333333333, -4.}, {
       5.416666666666667, -4.}, {5.4375, -4.}, {5.458333333333333, -4.}, {
       5.479166666666667, -4.}, {5.5, -4.}, {5.5, -4.}, {
       5.479166666666667, -4.}, {5.458333333333333, -4.}, {5.4375, -4.}, {
       5.416666666666667, -4.}, {5.395833333333333, -4.}, {5.375, -4.}, {
       5.375, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -4.5}, {5., -4.479166666666667}, {
       5., -4.458333333333333}, {5., -4.4375}, {5., -4.416666666666667}, {
       5., -4.395833333333333}, {5., -4.375}, {5., -4.375}, {
       5., -4.395833333333333}, {5., -4.416666666666667}, {5., -4.4375}, {
       5., -4.458333333333333}, {5., -4.479166666666667}, {5., -4.5}, {
       5., -4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -3.625}, {5., -3.6041666666666665`}, {
       5., -3.5833333333333335`}, {5., -3.5625}, {5., -3.5416666666666665`}, {
       5., -3.5208333333333335`}, {5., -3.5}, {5., -3.5}, {
       5., -3.5208333333333335`}, {5., -3.5416666666666665`}, {5., -3.5625}, {
       5., -3.5833333333333335`}, {5., -3.6041666666666665`}, {5., -3.625}, {
       5., -3.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, -4.}, {4.75, -4.}, {4.875, -4.}, {5., -4.}, {
       5.125, -4.}, {5.25, -4.}, {5.375, -4.}, {5.375, -4.}, {5.25, -4.}, {
       5.125, -4.}, {5., -4.}, {4.875, -4.}, {4.75, -4.}, {4.625, -4.}, {
       4.625, -4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -4.375}, {5., -4.25}, {5., -4.125}, {5., -4.}, {
       5., -3.875}, {5., -3.75}, {5., -3.625}, {5., -3.625}, {5., -3.75}, {
       5., -3.875}, {5., -4.}, {5., -4.125}, {5., -4.25}, {5., -4.375}, {
       5., -4.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4QhsCBrxnh8a+KRB02Sr+VsrLkPzBD+cmh
Xh+ofAPfgXPfzua084s6pAqlqH18wHsALH5AxOHCDvOqJ2m8B9SLOj8lJYs4
iOkFOmpLQeUZRKDm8x642VvGO3eOMKq8gzBcvxGn0eSKD0Jw8zPuSNsWbRaC
2889fcUC0V4huPsg4kJw98PkIe4QQNV/QABu/lmwPwTh9kP8KXjgBtR9kHAQ
RHV/gyDcfyjyQP/D9MPC5xzUfJTwO4AIXw2o+9DDHwBGPoIa
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhCa50AoGIjC+atXgYAInA+hRdDUC6OpF0JT
T5gPMYcXzoeYw4emXgBNXgBNvyCaeiEMPqr7hNDcD1MvgqZeBE29KJp6MYJ8
VPeJobkfpl4ATZ4Pzg9DCR9EfAEAimxRdQ==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, -4.265165042944956}, {
       5.3247595264191645`, -4.1875}, {
       5.404942744332997, -4.404942744332997}, {
       5.265165042944956, -4.265165042944956}}], 
      PolygonBox[{{5.437344993353523, -4.230251642536255}, {
       5.404942744332997, -4.404942744332997}, {
       5.3247595264191645`, -4.1875}, {
       5.437344993353523, -4.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, -4.1875}, {
       5.362222184858401, -4.097057141913445}, {
       5.437344993353523, -4.230251642536255}, {
       5.3247595264191645`, -4.1875}}], 
      PolygonBox[{{5.437499981032941, -4.084292589556062}, {
       5.437344993353523, -4.230251642536255}, {
       5.362222184858401, -4.097057141913445}, {
       5.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{5.362222184858401, -4.097057141913445}, {5.375, -4.}, {
       5.437499981032941, -4.084292589556062}, {
       5.362222184858401, -4.097057141913445}}], 
      PolygonBox[{{5.4375, -4.}, {5.437499981032941, -4.084292589556062}, {
       5.375, -4.}, {5.4375, -4.}}], 
      PolygonBox[{{5.375, -4.}, {5.362222184858401, -3.9029428580865546`}, {
       5.4375, -4.}, {5.375, -4.}}], 
      PolygonBox[{{5.437499981032941, -3.915707410443938}, {5.4375, -4.}, {
       5.362222184858401, -3.9029428580865546`}, {
       5.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{5.362222184858401, -3.9029428580865546`}, {
       5.3247595264191645`, -3.8125}, {
       5.437499981032941, -3.915707410443938}, {
       5.362222184858401, -3.9029428580865546`}}], 
      PolygonBox[{{5.437344993353523, -3.769748357463745}, {
       5.437499981032941, -3.915707410443938}, {
       5.3247595264191645`, -3.8125}, {
       5.437344993353523, -3.769748357463745}}], 
      PolygonBox[{{5.3247595264191645`, -3.8125}, {
       5.265165042944956, -3.7348349570550448`}, {
       5.437344993353523, -3.769748357463745}, {
       5.3247595264191645`, -3.8125}}], 
      PolygonBox[{{5.404942744332997, -3.595057255667003}, {
       5.437344993353523, -3.769748357463745}, {
       5.265165042944956, -3.7348349570550448`}, {
       5.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{5.265165042944956, -3.7348349570550448`}, {
       5.1875, -3.6752404735808355`}, {
       5.404942744332997, -3.595057255667003}, {
       5.265165042944956, -3.7348349570550448`}}], 
      PolygonBox[{{5.230251642536255, -3.5626550066464766`}, {
       5.404942744332997, -3.595057255667003}, {
       5.1875, -3.6752404735808355`}, {
       5.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{5.1875, -3.6752404735808355`}, {
       5.097057141913445, -3.6377778151415994`}, {
       5.230251642536255, -3.5626550066464766`}, {
       5.1875, -3.6752404735808355`}}], 
      PolygonBox[{{5.0842925895560604`, -3.562500018967059}, {
       5.230251642536255, -3.5626550066464766`}, {
       5.097057141913445, -3.6377778151415994`}, {
       5.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{5.097057141913445, -3.6377778151415994`}, {5., -3.625}, {
       5.0842925895560604`, -3.562500018967059}, {
       5.097057141913445, -3.6377778151415994`}}], 
      PolygonBox[{{5.000105527220487, -3.5625}, {
       5.0842925895560604`, -3.562500018967059}, {5., -3.625}, {
       5.000105527220487, -3.5625}}], 
      PolygonBox[{{5., -3.625}, {4.902942858086555, -3.6377778151415994`}, {
       5.000105527220487, -3.5625}, {5., -3.625}}], 
      PolygonBox[{{4.915707410443943, -3.562500018967059}, {
       5.000105527220487, -3.5625}, {
       4.902942858086555, -3.6377778151415994`}, {
       4.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{4.902942858086555, -3.6377778151415994`}, {
       4.8125, -3.6752404735808355`}, {
       4.915707410443943, -3.562500018967059}, {
       4.902942858086555, -3.6377778151415994`}}], 
      PolygonBox[{{4.769748357463745, -3.5626550066464766`}, {
       4.915707410443943, -3.562500018967059}, {
       4.8125, -3.6752404735808355`}, {
       4.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{4.8125, -3.6752404735808355`}, {
       4.734834957055044, -3.7348349570550448`}, {
       4.769748357463745, -3.5626550066464766`}, {
       4.8125, -3.6752404735808355`}}], 
      PolygonBox[{{4.595057255667003, -3.595057255667003}, {
       4.769748357463745, -3.5626550066464766`}, {
       4.734834957055044, -3.7348349570550448`}, {
       4.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{4.734834957055044, -3.7348349570550448`}, {
       4.6752404735808355`, -3.8125}, {
       4.595057255667003, -3.595057255667003}, {
       4.734834957055044, -3.7348349570550448`}}], 
      PolygonBox[{{4.562655006646477, -3.7697483574637447`}, {
       4.595057255667003, -3.595057255667003}, {
       4.6752404735808355`, -3.8125}, {
       4.562655006646477, -3.7697483574637447`}}], 
      PolygonBox[{{4.6752404735808355`, -3.8125}, {
       4.637777815141599, -3.9029428580865546`}, {
       4.562655006646477, -3.7697483574637447`}, {
       4.6752404735808355`, -3.8125}}], 
      PolygonBox[{{4.562500018967059, -3.9157074104439378`}, {
       4.562655006646477, -3.7697483574637447`}, {
       4.637777815141599, -3.9029428580865546`}, {
       4.562500018967059, -3.9157074104439378`}}], 
      PolygonBox[{{4.637777815141599, -3.9029428580865546`}, {4.625, -4.}, {
       4.562500018967059, -3.9157074104439378`}, {
       4.637777815141599, -3.9029428580865546`}}], 
      PolygonBox[{{4.5625, -3.9998768219370047`}, {
       4.562500018967059, -3.9157074104439378`}, {4.625, -4.}, {
       4.5625, -3.9998768219370047`}}], 
      PolygonBox[{{4.625, -4.}, {4.637777815141599, -4.097057141913445}, {
       4.5625, -3.9998768219370047`}, {4.625, -4.}}], 
      PolygonBox[{{4.562500018967059, -4.084292589556055}, {
       4.5625, -3.9998768219370047`}, {
       4.637777815141599, -4.097057141913445}, {
       4.562500018967059, -4.084292589556055}}], 
      PolygonBox[{{4.637777815141599, -4.097057141913445}, {
       4.6752404735808355`, -4.1875}, {
       4.562500018967059, -4.084292589556055}, {
       4.637777815141599, -4.097057141913445}}], 
      PolygonBox[{{4.562655006646477, -4.230251642536254}, {
       4.562500018967059, -4.084292589556055}, {
       4.6752404735808355`, -4.1875}, {
       4.562655006646477, -4.230251642536254}}], 
      PolygonBox[{{4.6752404735808355`, -4.1875}, {
       4.734834957055044, -4.265165042944956}, {
       4.562655006646477, -4.230251642536254}, {
       4.6752404735808355`, -4.1875}}], 
      PolygonBox[{{4.595057255667003, -4.404942744332997}, {
       4.562655006646477, -4.230251642536254}, {
       4.734834957055044, -4.265165042944956}, {
       4.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{4.734834957055044, -4.265165042944956}, {
       4.8125, -4.3247595264191645`}, {
       4.595057255667003, -4.404942744332997}, {
       4.734834957055044, -4.265165042944956}}], 
      PolygonBox[{{4.769748357463745, -4.437344993353523}, {
       4.595057255667003, -4.404942744332997}, {
       4.8125, -4.3247595264191645`}, {
       4.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{4.8125, -4.3247595264191645`}, {
       4.902942858086554, -4.362222184858401}, {
       4.769748357463745, -4.437344993353523}, {
       4.8125, -4.3247595264191645`}}], 
      PolygonBox[{{4.915707410443936, -4.437499981032941}, {
       4.769748357463745, -4.437344993353523}, {
       4.902942858086554, -4.362222184858401}, {
       4.915707410443936, -4.437499981032941}}], 
      PolygonBox[{{4.902942858086554, -4.362222184858401}, {5., -4.375}, {
       4.915707410443936, -4.437499981032941}, {
       4.902942858086554, -4.362222184858401}}], 
      PolygonBox[{{5.000134841831043, -4.4375}, {
       4.915707410443936, -4.437499981032941}, {5., -4.375}, {
       5.000134841831043, -4.4375}}], 
      PolygonBox[{{5., -4.375}, {5.097057141913445, -4.362222184858401}, {
       5.000134841831043, -4.4375}, {5., -4.375}}], 
      PolygonBox[{{5.084292589556053, -4.437499981032941}, {
       5.000134841831043, -4.4375}, {5.097057141913445, -4.362222184858401}, {
       5.084292589556053, -4.437499981032941}}], 
      PolygonBox[{{5.097057141913445, -4.362222184858401}, {
       5.1875, -4.3247595264191645`}, {
       5.084292589556053, -4.437499981032941}, {
       5.097057141913445, -4.362222184858401}}], 
      PolygonBox[{{5.230251642536254, -4.437344993353523}, {
       5.084292589556053, -4.437499981032941}, {
       5.1875, -4.3247595264191645`}, {
       5.230251642536254, -4.437344993353523}}], 
      PolygonBox[{{5.1875, -4.3247595264191645`}, {
       5.265165042944956, -4.265165042944956}, {
       5.230251642536254, -4.437344993353523}, {
       5.1875, -4.3247595264191645`}}], 
      PolygonBox[{{5.404942744332997, -4.404942744332997}, {
       5.230251642536254, -4.437344993353523}, {
       5.265165042944956, -4.265165042944956}, {
       5.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{5.265165042944956, -4.265165042944956}, {
       5.265165042944956, -4.265165042944956}, {
       5.404942744332997, -4.404942744332997}, {
       5.265165042944956, -4.265165042944956}}], 
      PolygonBox[{{5.404942744332997, -4.404942744332997}, {
       5.404942744332997, -4.404942744332997}, {
       5.265165042944956, -4.265165042944956}, {
       5.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{5.404942744332997, -4.404942744332997}, {
       5.437344993353523, -4.230251642536255}, {5.5, -4.5}, {
       5.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{5.5, -4.357662782649368}, {5.5, -4.5}, {
       5.437344993353523, -4.230251642536255}, {5.5, -4.357662782649368}}], 
      PolygonBox[{{5.437344993353523, -4.230251642536255}, {
       5.437499981032941, -4.084292589556062}, {5.5, -4.357662782649368}, {
       5.437344993353523, -4.230251642536255}}], 
      PolygonBox[{{5.5, -4.20590900530174}, {5.5, -4.357662782649368}, {
       5.437499981032941, -4.084292589556062}, {5.5, -4.20590900530174}}], 
      PolygonBox[{{5.437499981032941, -4.084292589556062}, {5.4375, -4.}, {
       5.5, -4.20590900530174}, {5.437499981032941, -4.084292589556062}}], 
      PolygonBox[{{5.5, -4.}, {5.5, -4.20590900530174}, {5.4375, -4.}, {
       5.5, -4.}}], 
      PolygonBox[{{5.4375, -4.}, {5.437499981032941, -3.915707410443938}, {
       5.5, -4.}, {5.4375, -4.}}], 
      PolygonBox[{{5.5, -3.79409099469826}, {5.5, -4.}, {
       5.437499981032941, -3.915707410443938}, {5.5, -3.79409099469826}}], 
      PolygonBox[{{5.437499981032941, -3.915707410443938}, {
       5.437344993353523, -3.769748357463745}, {5.5, -3.79409099469826}, {
       5.437499981032941, -3.915707410443938}}], 
      PolygonBox[{{5.5, -3.6423372173506325`}, {5.5, -3.79409099469826}, {
       5.437344993353523, -3.769748357463745}, {5.5, -3.6423372173506325`}}], 
      PolygonBox[{{5.437344993353523, -3.769748357463745}, {
       5.404942744332997, -3.595057255667003}, {5.5, -3.6423372173506325`}, {
       5.437344993353523, -3.769748357463745}}], 
      PolygonBox[{{5.491446564961186, -3.508553435038814}, {
       5.5, -3.6423372173506325`}, {5.404942744332997, -3.595057255667003}, {
       5.491446564961186, -3.508553435038814}}], 
      PolygonBox[{{5.404942744332997, -3.595057255667003}, {
       5.230251642536255, -3.5626550066464766`}, {
       5.491446564961186, -3.508553435038814}, {
       5.404942744332997, -3.595057255667003}}], 
      PolygonBox[{{5.357662782649368, -3.5}, {
       5.491446564961186, -3.508553435038814}, {
       5.230251642536255, -3.5626550066464766`}, {5.357662782649368, -3.5}}], 
      PolygonBox[{{5.230251642536255, -3.5626550066464766`}, {
       5.0842925895560604`, -3.562500018967059}, {5.357662782649368, -3.5}, {
       5.230251642536255, -3.5626550066464766`}}], 
      PolygonBox[{{5.205909005373256, -3.5}, {5.357662782649368, -3.5}, {
       5.0842925895560604`, -3.562500018967059}, {5.205909005373256, -3.5}}], 
      PolygonBox[{{5.0842925895560604`, -3.562500018967059}, {
       5.000105527220487, -3.5625}, {5.205909005373256, -3.5}, {
       5.0842925895560604`, -3.562500018967059}}], 
      PolygonBox[{{5.07794195802689, -3.5}, {5.205909005373256, -3.5}, {
       5.000105527220487, -3.5625}, {5.07794195802689, -3.5}}], 
      PolygonBox[{{5.000105527220487, -3.5625}, {
       4.915707410443943, -3.562500018967059}, {5.07794195802689, -3.5}, {
       5.000105527220487, -3.5625}}], 
      PolygonBox[{{4.794090994695554, -3.5}, {5.07794195802689, -3.5}, {
       4.915707410443943, -3.562500018967059}, {4.794090994695554, -3.5}}], 
      PolygonBox[{{4.915707410443943, -3.562500018967059}, {
       4.769748357463745, -3.5626550066464766`}, {4.794090994695554, -3.5}, {
       4.915707410443943, -3.562500018967059}}], 
      PolygonBox[{{4.642337217350634, -3.5}, {4.794090994695554, -3.5}, {
       4.769748357463745, -3.5626550066464766`}, {4.642337217350634, -3.5}}], 
      PolygonBox[{{4.769748357463745, -3.5626550066464766`}, {
       4.595057255667003, -3.595057255667003}, {4.642337217350634, -3.5}, {
       4.769748357463745, -3.5626550066464766`}}], 
      PolygonBox[{{5.5, -3.5}, {4.642337217350634, -3.5}, {
       4.595057255667003, -3.595057255667003}, {5.5, -3.5}}], 
      PolygonBox[{{4.595057255667003, -3.595057255667003}, {
       4.562655006646477, -3.7697483574637447`}, {5.5, -3.5}, {
       4.595057255667003, -3.595057255667003}}], 
      PolygonBox[{{4.5, -3.642337217350631}, {5.5, -3.5}, {
       4.562655006646477, -3.7697483574637447`}, {4.5, -3.642337217350631}}], 
      PolygonBox[{{4.562655006646477, -3.7697483574637447`}, {
       4.562500018967059, -3.9157074104439378`}, {4.5, -3.642337217350631}, {
       4.562655006646477, -3.7697483574637447`}}], 
      PolygonBox[{{4.5, -3.794090994717101}, {4.5, -3.642337217350631}, {
       4.562500018967059, -3.9157074104439378`}, {4.5, -3.794090994717101}}], 
      PolygonBox[{{4.562500018967059, -3.9157074104439378`}, {
       4.5625, -3.9998768219370047`}, {4.5, -3.794090994717101}, {
       4.562500018967059, -3.9157074104439378`}}], 
      PolygonBox[{{4.5, -3.9193213332413}, {4.5, -3.794090994717101}, {
       4.5625, -3.9998768219370047`}, {4.5, -3.9193213332413}}], 
      PolygonBox[{{4.5625, -3.9998768219370047`}, {
       4.562500018967059, -4.084292589556055}, {4.5, -3.9193213332413}, {
       4.5625, -3.9998768219370047`}}], 
      PolygonBox[{{4.5, -4.205909005145278}, {4.5, -3.9193213332413}, {
       4.562500018967059, -4.084292589556055}, {4.5, -4.205909005145278}}], 
      PolygonBox[{{4.562500018967059, -4.084292589556055}, {
       4.562655006646477, -4.230251642536254}, {4.5, -4.205909005145278}, {
       4.562500018967059, -4.084292589556055}}], 
      PolygonBox[{{4.5, -4.357662782649365}, {4.5, -4.205909005145278}, {
       4.562655006646477, -4.230251642536254}, {4.5, -4.357662782649365}}], 
      PolygonBox[{{4.562655006646477, -4.230251642536254}, {
       4.595057255667003, -4.404942744332997}, {4.5, -4.357662782649365}, {
       4.562655006646477, -4.230251642536254}}], 
      PolygonBox[{{4.5, -3.5}, {4.5, -4.357662782649365}, {
       4.595057255667003, -4.404942744332997}, {4.5, -3.5}}], 
      PolygonBox[{{4.595057255667003, -4.404942744332997}, {
       4.769748357463745, -4.437344993353523}, {4.5, -3.5}, {
       4.595057255667003, -4.404942744332997}}], 
      PolygonBox[{{4.5, -4.5}, {4.5, -3.5}, {
       4.769748357463745, -4.437344993353523}, {4.5, -4.5}}], 
      PolygonBox[{{4.769748357463745, -4.437344993353523}, {
       4.915707410443936, -4.437499981032941}, {4.5, -4.5}, {
       4.769748357463745, -4.437344993353523}}], 
      PolygonBox[{{4.794090994433172, -4.5}, {4.5, -4.5}, {
       4.915707410443936, -4.437499981032941}, {4.794090994433172, -4.5}}], 
      PolygonBox[{{4.915707410443936, -4.437499981032941}, {
       5.000134841831043, -4.4375}, {4.794090994433172, -4.5}, {
       4.915707410443936, -4.437499981032941}}], 
      PolygonBox[{{5.082323870401062, -4.5}, {4.794090994433172, -4.5}, {
       5.000134841831043, -4.4375}, {5.082323870401062, -4.5}}], 
      PolygonBox[{{5.000134841831043, -4.4375}, {
       5.084292589556053, -4.437499981032941}, {5.082323870401062, -4.5}, {
       5.000134841831043, -4.4375}}], 
      PolygonBox[{{5.205909005360398, -4.5}, {5.082323870401062, -4.5}, {
       5.084292589556053, -4.437499981032941}, {5.205909005360398, -4.5}}], 
      PolygonBox[{{5.084292589556053, -4.437499981032941}, {
       5.230251642536254, -4.437344993353523}, {5.205909005360398, -4.5}, {
       5.084292589556053, -4.437499981032941}}], 
      PolygonBox[{{5.3576627826493715`, -4.5}, {5.205909005360398, -4.5}, {
       5.230251642536254, -4.437344993353523}, {5.3576627826493715`, -4.5}}], 
      PolygonBox[{{5.230251642536254, -4.437344993353523}, {
       5.404942744332997, -4.404942744332997}, {5.3576627826493715`, -4.5}, {
       5.230251642536254, -4.437344993353523}}], 
      PolygonBox[{{5.5, -4.5}, {5.3576627826493715`, -4.5}, {
       5.404942744332997, -4.404942744332997}, {5.5, -4.5}}], 
      PolygonBox[{{5.404942744332997, -4.404942744332997}, {
       5.404942744332997, -4.404942744332997}, {5.5, -4.5}, {
       5.404942744332997, -4.404942744332997}}], 
      PolygonBox[{{5.5, -4.5}, {5.5, -4.5}, {
       5.404942744332997, -4.404942744332997}, {5.5, -4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, -3.}, {4.520833333333333, -3.}, {
       4.541666666666667, -3.}, {4.5625, -3.}, {4.583333333333333, -3.}, {
       4.604166666666667, -3.}, {4.625, -3.}, {4.625, -3.}, {
       4.604166666666667, -3.}, {4.583333333333333, -3.}, {4.5625, -3.}, {
       4.541666666666667, -3.}, {4.520833333333333, -3.}, {4.5, -3.}, {
       4.5, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, -3.}, {5.395833333333333, -3.}, {
       5.416666666666667, -3.}, {5.4375, -3.}, {5.458333333333333, -3.}, {
       5.479166666666667, -3.}, {5.5, -3.}, {5.5, -3.}, {
       5.479166666666667, -3.}, {5.458333333333333, -3.}, {5.4375, -3.}, {
       5.416666666666667, -3.}, {5.395833333333333, -3.}, {5.375, -3.}, {
       5.375, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -3.5}, {5., -3.4791666666666665`}, {
       5., -3.4583333333333335`}, {5., -3.4375}, {5., -3.4166666666666665`}, {
       5., -3.3958333333333335`}, {5., -3.375}, {5., -3.375}, {
       5., -3.3958333333333335`}, {5., -3.4166666666666665`}, {5., -3.4375}, {
       5., -3.4583333333333335`}, {5., -3.4791666666666665`}, {5., -3.5}, {
       5., -3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -2.625}, {5., -2.6041666666666665`}, {
       5., -2.5833333333333335`}, {5., -2.5625}, {5., -2.5416666666666665`}, {
       5., -2.5208333333333335`}, {5., -2.5}, {5., -2.5}, {
       5., -2.5208333333333335`}, {5., -2.5416666666666665`}, {5., -2.5625}, {
       5., -2.5833333333333335`}, {5., -2.6041666666666665`}, {5., -2.625}, {
       5., -2.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, -3.}, {4.75, -3.}, {4.875, -3.}, {5., -3.}, {
       5.125, -3.}, {5.25, -3.}, {5.375, -3.}, {5.375, -3.}, {5.25, -3.}, {
       5.125, -3.}, {5., -3.}, {4.875, -3.}, {4.75, -3.}, {4.625, -3.}, {
       4.625, -3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -3.375}, {5., -3.25}, {5., -3.125}, {5., -3.}, {
       5., -2.875}, {5., -2.75}, {5., -2.625}, {5., -2.625}, {5., -2.75}, {
       5., -2.875}, {5., -3.}, {5., -3.125}, {5., -3.25}, {5., -3.375}, {
       5., -3.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4QBseBrxnh8a+KRB02Sr+VsrJkPzBD+cmh
Xh+ofAPbgXPfzua084s6pAqlqH18wHoALH5AxOHCDvOqJ2msB9SLOj8lJYs4
iOkFOmpLQeUZRKDmsx642VvGO3eOMKq8gzBcvxGn0eSKD0Jw8zPuSNsWbRaC
2889fcUC0V4huPsg4kJw98Pk/Z4IPT16jANNPyfc/NlvZ9/kk+eC22/gfqJV
eibXgRtQ9726uG7fladcaO7nhvsPRR7of5h+WPjAzEcNP054+PpD3Yce/gAv
zIKd
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhCa5UAoGIjC+atXgYAInA+hRdDUC6OpF0JT
T5gPMYcVzoeYw4amngNNPSecD1a+igtNPQ8GH9V9PGjuh6kXQVMvgqZeFE29
GEH+ahT3iaG5H6aeA009G5wfhhI+iPgCANiRUKo=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, -3.2651650429449552`}, {
       5.3247595264191645`, -3.1875}, {
       5.404942744332997, -3.404942744332997}, {
       5.265165042944956, -3.2651650429449552`}}], 
      PolygonBox[{{5.437344993353523, -3.2302516425362553`}, {
       5.404942744332997, -3.404942744332997}, {
       5.3247595264191645`, -3.1875}, {
       5.437344993353523, -3.2302516425362553`}}], 
      PolygonBox[{{5.3247595264191645`, -3.1875}, {
       5.362222184858401, -3.0970571419134454`}, {
       5.437344993353523, -3.2302516425362553`}, {
       5.3247595264191645`, -3.1875}}], 
      PolygonBox[{{5.437499981032941, -3.084292589556062}, {
       5.437344993353523, -3.2302516425362553`}, {
       5.362222184858401, -3.0970571419134454`}, {
       5.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{5.362222184858401, -3.0970571419134454`}, {5.375, -3.}, {
       5.437499981032941, -3.084292589556062}, {
       5.362222184858401, -3.0970571419134454`}}], 
      PolygonBox[{{5.4375, -3.}, {5.437499981032941, -3.084292589556062}, {
       5.375, -3.}, {5.4375, -3.}}], 
      PolygonBox[{{5.375, -3.}, {5.362222184858401, -2.9029428580865546`}, {
       5.4375, -3.}, {5.375, -3.}}], 
      PolygonBox[{{5.437499981032941, -2.915707410443938}, {5.4375, -3.}, {
       5.362222184858401, -2.9029428580865546`}, {
       5.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{5.362222184858401, -2.9029428580865546`}, {
       5.3247595264191645`, -2.8125}, {
       5.437499981032941, -2.915707410443938}, {
       5.362222184858401, -2.9029428580865546`}}], 
      PolygonBox[{{5.437344993353523, -2.769748357463745}, {
       5.437499981032941, -2.915707410443938}, {
       5.3247595264191645`, -2.8125}, {
       5.437344993353523, -2.769748357463745}}], 
      PolygonBox[{{5.3247595264191645`, -2.8125}, {
       5.265165042944956, -2.7348349570550448`}, {
       5.437344993353523, -2.769748357463745}, {
       5.3247595264191645`, -2.8125}}], 
      PolygonBox[{{5.404942744332997, -2.595057255667003}, {
       5.437344993353523, -2.769748357463745}, {
       5.265165042944956, -2.7348349570550448`}, {
       5.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{5.265165042944956, -2.7348349570550448`}, {
       5.1875, -2.6752404735808355`}, {
       5.404942744332997, -2.595057255667003}, {
       5.265165042944956, -2.7348349570550448`}}], 
      PolygonBox[{{5.230251642536255, -2.5626550066464766`}, {
       5.404942744332997, -2.595057255667003}, {
       5.1875, -2.6752404735808355`}, {
       5.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{5.1875, -2.6752404735808355`}, {
       5.097057141913445, -2.6377778151415994`}, {
       5.230251642536255, -2.5626550066464766`}, {
       5.1875, -2.6752404735808355`}}], 
      PolygonBox[{{5.0842925895560604`, -2.562500018967059}, {
       5.230251642536255, -2.5626550066464766`}, {
       5.097057141913445, -2.6377778151415994`}, {
       5.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{5.097057141913445, -2.6377778151415994`}, {5., -2.625}, {
       5.0842925895560604`, -2.562500018967059}, {
       5.097057141913445, -2.6377778151415994`}}], 
      PolygonBox[{{5.000105527220487, -2.5625}, {
       5.0842925895560604`, -2.562500018967059}, {5., -2.625}, {
       5.000105527220487, -2.5625}}], 
      PolygonBox[{{5., -2.625}, {4.902942858086555, -2.6377778151415994`}, {
       5.000105527220487, -2.5625}, {5., -2.625}}], 
      PolygonBox[{{4.915707410443943, -2.562500018967059}, {
       5.000105527220487, -2.5625}, {
       4.902942858086555, -2.6377778151415994`}, {
       4.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{4.902942858086555, -2.6377778151415994`}, {
       4.8125, -2.6752404735808355`}, {
       4.915707410443943, -2.562500018967059}, {
       4.902942858086555, -2.6377778151415994`}}], 
      PolygonBox[{{4.769748357463745, -2.5626550066464766`}, {
       4.915707410443943, -2.562500018967059}, {
       4.8125, -2.6752404735808355`}, {
       4.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{4.8125, -2.6752404735808355`}, {
       4.734834957055044, -2.7348349570550448`}, {
       4.769748357463745, -2.5626550066464766`}, {
       4.8125, -2.6752404735808355`}}], 
      PolygonBox[{{4.595057255667003, -2.595057255667003}, {
       4.769748357463745, -2.5626550066464766`}, {
       4.734834957055044, -2.7348349570550448`}, {
       4.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{4.734834957055044, -2.7348349570550448`}, {
       4.6752404735808355`, -2.8125}, {
       4.595057255667003, -2.595057255667003}, {
       4.734834957055044, -2.7348349570550448`}}], 
      PolygonBox[{{4.562655006646477, -2.7697483574637447`}, {
       4.595057255667003, -2.595057255667003}, {
       4.6752404735808355`, -2.8125}, {
       4.562655006646477, -2.7697483574637447`}}], 
      PolygonBox[{{4.6752404735808355`, -2.8125}, {
       4.637777815141599, -2.9029428580865546`}, {
       4.562655006646477, -2.7697483574637447`}, {
       4.6752404735808355`, -2.8125}}], 
      PolygonBox[{{4.562500018967059, -2.9157074104439378`}, {
       4.562655006646477, -2.7697483574637447`}, {
       4.637777815141599, -2.9029428580865546`}, {
       4.562500018967059, -2.9157074104439378`}}], 
      PolygonBox[{{4.637777815141599, -2.9029428580865546`}, {4.625, -3.}, {
       4.562500018967059, -2.9157074104439378`}, {
       4.637777815141599, -2.9029428580865546`}}], 
      PolygonBox[{{4.5625, -2.9998768219370047`}, {
       4.562500018967059, -2.9157074104439378`}, {4.625, -3.}, {
       4.5625, -2.9998768219370047`}}], 
      PolygonBox[{{4.625, -3.}, {4.637777815141599, -3.097057141913445}, {
       4.5625, -2.9998768219370047`}, {4.625, -3.}}], 
      PolygonBox[{{4.562500018967059, -3.084292589556055}, {
       4.5625, -2.9998768219370047`}, {
       4.637777815141599, -3.097057141913445}, {
       4.562500018967059, -3.084292589556055}}], 
      PolygonBox[{{4.637777815141599, -3.097057141913445}, {
       4.6752404735808355`, -3.1875}, {
       4.562500018967059, -3.084292589556055}, {
       4.637777815141599, -3.097057141913445}}], 
      PolygonBox[{{4.562655006646477, -3.230251642536255}, {
       4.562500018967059, -3.084292589556055}, {
       4.6752404735808355`, -3.1875}, {
       4.562655006646477, -3.230251642536255}}], 
      PolygonBox[{{4.6752404735808355`, -3.1875}, {
       4.734834957055044, -3.2651650429449552`}, {
       4.562655006646477, -3.230251642536255}, {
       4.6752404735808355`, -3.1875}}], 
      PolygonBox[{{4.595057255667003, -3.404942744332997}, {
       4.562655006646477, -3.230251642536255}, {
       4.734834957055044, -3.2651650429449552`}, {
       4.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{4.734834957055044, -3.2651650429449552`}, {
       4.8125, -3.3247595264191645`}, {
       4.595057255667003, -3.404942744332997}, {
       4.734834957055044, -3.2651650429449552`}}], 
      PolygonBox[{{4.769748357463745, -3.4373449933535234`}, {
       4.595057255667003, -3.404942744332997}, {
       4.8125, -3.3247595264191645`}, {
       4.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{4.8125, -3.3247595264191645`}, {
       4.902942858086554, -3.3622221848584006`}, {
       4.769748357463745, -3.4373449933535234`}, {
       4.8125, -3.3247595264191645`}}], 
      PolygonBox[{{4.915707410443936, -3.437499981032941}, {
       4.769748357463745, -3.4373449933535234`}, {
       4.902942858086554, -3.3622221848584006`}, {
       4.915707410443936, -3.437499981032941}}], 
      PolygonBox[{{4.902942858086554, -3.3622221848584006`}, {5., -3.375}, {
       4.915707410443936, -3.437499981032941}, {
       4.902942858086554, -3.3622221848584006`}}], 
      PolygonBox[{{5.000134841831043, -3.4375}, {
       4.915707410443936, -3.437499981032941}, {5., -3.375}, {
       5.000134841831043, -3.4375}}], 
      PolygonBox[{{5., -3.375}, {5.097057141913445, -3.3622221848584006`}, {
       5.000134841831043, -3.4375}, {5., -3.375}}], 
      PolygonBox[{{5.084292589556053, -3.437499981032941}, {
       5.000134841831043, -3.4375}, {
       5.097057141913445, -3.3622221848584006`}, {
       5.084292589556053, -3.437499981032941}}], 
      PolygonBox[{{5.097057141913445, -3.3622221848584006`}, {
       5.1875, -3.3247595264191645`}, {
       5.084292589556053, -3.437499981032941}, {
       5.097057141913445, -3.3622221848584006`}}], 
      PolygonBox[{{5.230251642536254, -3.4373449933535234`}, {
       5.084292589556053, -3.437499981032941}, {
       5.1875, -3.3247595264191645`}, {
       5.230251642536254, -3.4373449933535234`}}], 
      PolygonBox[{{5.1875, -3.3247595264191645`}, {
       5.265165042944956, -3.2651650429449552`}, {
       5.230251642536254, -3.4373449933535234`}, {
       5.1875, -3.3247595264191645`}}], 
      PolygonBox[{{5.404942744332997, -3.404942744332997}, {
       5.230251642536254, -3.4373449933535234`}, {
       5.265165042944956, -3.2651650429449552`}, {
       5.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{5.265165042944956, -3.2651650429449552`}, {
       5.265165042944956, -3.2651650429449552`}, {
       5.404942744332997, -3.404942744332997}, {
       5.265165042944956, -3.2651650429449552`}}], 
      PolygonBox[{{5.404942744332997, -3.404942744332997}, {
       5.404942744332997, -3.404942744332997}, {
       5.265165042944956, -3.2651650429449552`}, {
       5.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{5.404942744332997, -3.404942744332997}, {
       5.437344993353523, -3.2302516425362553`}, {5.5, -3.5}, {
       5.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{5.5, -3.357662782649368}, {5.5, -3.5}, {
       5.437344993353523, -3.2302516425362553`}, {5.5, -3.357662782649368}}], 
      PolygonBox[{{5.437344993353523, -3.2302516425362553`}, {
       5.437499981032941, -3.084292589556062}, {5.5, -3.357662782649368}, {
       5.437344993353523, -3.2302516425362553`}}], 
      PolygonBox[{{5.5, -3.20590900530174}, {5.5, -3.357662782649368}, {
       5.437499981032941, -3.084292589556062}, {5.5, -3.20590900530174}}], 
      PolygonBox[{{5.437499981032941, -3.084292589556062}, {5.4375, -3.}, {
       5.5, -3.20590900530174}, {5.437499981032941, -3.084292589556062}}], 
      PolygonBox[{{5.5, -3.}, {5.5, -3.20590900530174}, {5.4375, -3.}, {
       5.5, -3.}}], 
      PolygonBox[{{5.4375, -3.}, {5.437499981032941, -2.915707410443938}, {
       5.5, -3.}, {5.4375, -3.}}], 
      PolygonBox[{{5.5, -2.79409099469826}, {5.5, -3.}, {
       5.437499981032941, -2.915707410443938}, {5.5, -2.79409099469826}}], 
      PolygonBox[{{5.437499981032941, -2.915707410443938}, {
       5.437344993353523, -2.769748357463745}, {5.5, -2.79409099469826}, {
       5.437499981032941, -2.915707410443938}}], 
      PolygonBox[{{5.5, -2.6423372173506325`}, {5.5, -2.79409099469826}, {
       5.437344993353523, -2.769748357463745}, {5.5, -2.6423372173506325`}}], 
      PolygonBox[{{5.437344993353523, -2.769748357463745}, {
       5.404942744332997, -2.595057255667003}, {5.5, -2.6423372173506325`}, {
       5.437344993353523, -2.769748357463745}}], 
      PolygonBox[{{5.491446564961186, -2.508553435038814}, {
       5.5, -2.6423372173506325`}, {5.404942744332997, -2.595057255667003}, {
       5.491446564961186, -2.508553435038814}}], 
      PolygonBox[{{5.404942744332997, -2.595057255667003}, {
       5.230251642536255, -2.5626550066464766`}, {
       5.491446564961186, -2.508553435038814}, {
       5.404942744332997, -2.595057255667003}}], 
      PolygonBox[{{5.357662782649368, -2.5}, {
       5.491446564961186, -2.508553435038814}, {
       5.230251642536255, -2.5626550066464766`}, {5.357662782649368, -2.5}}], 
      PolygonBox[{{5.230251642536255, -2.5626550066464766`}, {
       5.0842925895560604`, -2.562500018967059}, {5.357662782649368, -2.5}, {
       5.230251642536255, -2.5626550066464766`}}], 
      PolygonBox[{{5.205909005373256, -2.5}, {5.357662782649368, -2.5}, {
       5.0842925895560604`, -2.562500018967059}, {5.205909005373256, -2.5}}], 
      PolygonBox[{{5.0842925895560604`, -2.562500018967059}, {
       5.000105527220487, -2.5625}, {5.205909005373256, -2.5}, {
       5.0842925895560604`, -2.562500018967059}}], 
      PolygonBox[{{5.07794195802689, -2.5}, {5.205909005373256, -2.5}, {
       5.000105527220487, -2.5625}, {5.07794195802689, -2.5}}], 
      PolygonBox[{{5.000105527220487, -2.5625}, {
       4.915707410443943, -2.562500018967059}, {5.07794195802689, -2.5}, {
       5.000105527220487, -2.5625}}], 
      PolygonBox[{{4.794090994695554, -2.5}, {5.07794195802689, -2.5}, {
       4.915707410443943, -2.562500018967059}, {4.794090994695554, -2.5}}], 
      PolygonBox[{{4.915707410443943, -2.562500018967059}, {
       4.769748357463745, -2.5626550066464766`}, {4.794090994695554, -2.5}, {
       4.915707410443943, -2.562500018967059}}], 
      PolygonBox[{{4.642337217350634, -2.5}, {4.794090994695554, -2.5}, {
       4.769748357463745, -2.5626550066464766`}, {4.642337217350634, -2.5}}], 
      PolygonBox[{{4.769748357463745, -2.5626550066464766`}, {
       4.595057255667003, -2.595057255667003}, {4.642337217350634, -2.5}, {
       4.769748357463745, -2.5626550066464766`}}], 
      PolygonBox[{{5.5, -2.5}, {4.642337217350634, -2.5}, {
       4.595057255667003, -2.595057255667003}, {5.5, -2.5}}], 
      PolygonBox[{{4.595057255667003, -2.595057255667003}, {
       4.562655006646477, -2.7697483574637447`}, {5.5, -2.5}, {
       4.595057255667003, -2.595057255667003}}], 
      PolygonBox[{{4.5, -2.642337217350631}, {5.5, -2.5}, {
       4.562655006646477, -2.7697483574637447`}, {4.5, -2.642337217350631}}], 
      PolygonBox[{{4.562655006646477, -2.7697483574637447`}, {
       4.562500018967059, -2.9157074104439378`}, {4.5, -2.642337217350631}, {
       4.562655006646477, -2.7697483574637447`}}], 
      PolygonBox[{{4.5, -2.794090994717101}, {4.5, -2.642337217350631}, {
       4.562500018967059, -2.9157074104439378`}, {4.5, -2.794090994717101}}], 
      PolygonBox[{{4.562500018967059, -2.9157074104439378`}, {
       4.5625, -2.9998768219370047`}, {4.5, -2.794090994717101}, {
       4.562500018967059, -2.9157074104439378`}}], 
      PolygonBox[{{4.5, -2.9193213332413}, {4.5, -2.794090994717101}, {
       4.5625, -2.9998768219370047`}, {4.5, -2.9193213332413}}], 
      PolygonBox[{{4.5625, -2.9998768219370047`}, {
       4.562500018967059, -3.084292589556055}, {4.5, -2.9193213332413}, {
       4.5625, -2.9998768219370047`}}], 
      PolygonBox[{{4.5, -3.2059090051452785`}, {4.5, -2.9193213332413}, {
       4.562500018967059, -3.084292589556055}, {4.5, -3.2059090051452785`}}], 
      PolygonBox[{{4.562500018967059, -3.084292589556055}, {
       4.562655006646477, -3.230251642536255}, {4.5, -3.2059090051452785`}, {
       4.562500018967059, -3.084292589556055}}], 
      PolygonBox[{{4.5, -3.3576627826493652`}, {4.5, -3.2059090051452785`}, {
       4.562655006646477, -3.230251642536255}, {4.5, -3.3576627826493652`}}], 
      PolygonBox[{{4.562655006646477, -3.230251642536255}, {
       4.595057255667003, -3.404942744332997}, {4.5, -3.3576627826493652`}, {
       4.562655006646477, -3.230251642536255}}], 
      PolygonBox[{{4.5, -2.5}, {4.5, -3.3576627826493652`}, {
       4.595057255667003, -3.404942744332997}, {4.5, -2.5}}], 
      PolygonBox[{{4.595057255667003, -3.404942744332997}, {
       4.769748357463745, -3.4373449933535234`}, {4.5, -2.5}, {
       4.595057255667003, -3.404942744332997}}], 
      PolygonBox[{{4.5, -3.5}, {4.5, -2.5}, {
       4.769748357463745, -3.4373449933535234`}, {4.5, -3.5}}], 
      PolygonBox[{{4.769748357463745, -3.4373449933535234`}, {
       4.915707410443936, -3.437499981032941}, {4.5, -3.5}, {
       4.769748357463745, -3.4373449933535234`}}], 
      PolygonBox[{{4.794090994433172, -3.5}, {4.5, -3.5}, {
       4.915707410443936, -3.437499981032941}, {4.794090994433172, -3.5}}], 
      PolygonBox[{{4.915707410443936, -3.437499981032941}, {
       5.000134841831043, -3.4375}, {4.794090994433172, -3.5}, {
       4.915707410443936, -3.437499981032941}}], 
      PolygonBox[{{5.082323870401062, -3.5}, {4.794090994433172, -3.5}, {
       5.000134841831043, -3.4375}, {5.082323870401062, -3.5}}], 
      PolygonBox[{{5.000134841831043, -3.4375}, {
       5.084292589556053, -3.437499981032941}, {5.082323870401062, -3.5}, {
       5.000134841831043, -3.4375}}], 
      PolygonBox[{{5.205909005360398, -3.5}, {5.082323870401062, -3.5}, {
       5.084292589556053, -3.437499981032941}, {5.205909005360398, -3.5}}], 
      PolygonBox[{{5.084292589556053, -3.437499981032941}, {
       5.230251642536254, -3.4373449933535234`}, {5.205909005360398, -3.5}, {
       5.084292589556053, -3.437499981032941}}], 
      PolygonBox[{{5.3576627826493715`, -3.5}, {5.205909005360398, -3.5}, {
       5.230251642536254, -3.4373449933535234`}, {
       5.3576627826493715`, -3.5}}], 
      PolygonBox[{{5.230251642536254, -3.4373449933535234`}, {
       5.404942744332997, -3.404942744332997}, {5.3576627826493715`, -3.5}, {
       5.230251642536254, -3.4373449933535234`}}], 
      PolygonBox[{{5.5, -3.5}, {5.3576627826493715`, -3.5}, {
       5.404942744332997, -3.404942744332997}, {5.5, -3.5}}], 
      PolygonBox[{{5.404942744332997, -3.404942744332997}, {
       5.404942744332997, -3.404942744332997}, {5.5, -3.5}, {
       5.404942744332997, -3.404942744332997}}], 
      PolygonBox[{{5.5, -3.5}, {5.5, -3.5}, {
       5.404942744332997, -3.404942744332997}, {5.5, -3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, -2.}, {4.520833333333333, -2.}, {
       4.541666666666667, -2.}, {4.5625, -2.}, {4.583333333333333, -2.}, {
       4.604166666666667, -2.}, {4.625, -2.}, {4.625, -2.}, {
       4.604166666666667, -2.}, {4.583333333333333, -2.}, {4.5625, -2.}, {
       4.541666666666667, -2.}, {4.520833333333333, -2.}, {4.5, -2.}, {
       4.5, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, -2.}, {5.395833333333333, -2.}, {
       5.416666666666667, -2.}, {5.4375, -2.}, {5.458333333333333, -2.}, {
       5.479166666666667, -2.}, {5.5, -2.}, {5.5, -2.}, {
       5.479166666666667, -2.}, {5.458333333333333, -2.}, {5.4375, -2.}, {
       5.416666666666667, -2.}, {5.395833333333333, -2.}, {5.375, -2.}, {
       5.375, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -2.5}, {5., -2.4791666666666665`}, {
       5., -2.4583333333333335`}, {5., -2.4375}, {5., -2.4166666666666665`}, {
       5., -2.3958333333333335`}, {5., -2.375}, {5., -2.375}, {
       5., -2.3958333333333335`}, {5., -2.4166666666666665`}, {5., -2.4375}, {
       5., -2.4583333333333335`}, {5., -2.4791666666666665`}, {5., -2.5}, {
       5., -2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -1.625}, {5., -1.6041666666666667`}, {
       5., -1.5833333333333333`}, {5., -1.5625}, {5., -1.5416666666666667`}, {
       5., -1.5208333333333335`}, {5., -1.5}, {5., -1.5}, {
       5., -1.5208333333333333`}, {5., -1.5416666666666667`}, {5., -1.5625}, {
       5., -1.5833333333333333`}, {5., -1.6041666666666665`}, {5., -1.625}, {
       5., -1.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, -2.}, {4.75, -2.}, {4.875, -2.}, {5., -2.}, {
       5.125, -2.}, {5.25, -2.}, {5.375, -2.}, {5.375, -2.}, {5.25, -2.}, {
       5.125, -2.}, {5., -2.}, {4.875, -2.}, {4.75, -2.}, {4.625, -2.}, {
       4.625, -2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -2.375}, {5., -2.25}, {5., -2.125}, {5., -2.}, {
       5., -1.875}, {5., -1.75}, {5., -1.625}, {5., -1.625}, {5., -1.75}, {
       5., -1.875}, {5., -2.}, {5., -2.125}, {5., -2.25}, {5., -2.375}, {
       5., -2.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog5Q1oGvGeHxr4pEHZLMb5mWFP3bP0P5yaFe
H5j83/3nvp3NaecXdTilcsLn0cHf+yG6RBwWFOZ/OXH21371os5PSckiDjox
i5rCTH5B5BlEoPp/7b/ZW8Y7d44wqryDMFy/EafR5IoPQnDzM+5I2xZtFoLb
zz19xQLRXiG4+yDuh8kzHIDJ+z0Renr0GMMBFP0NjAdg5s9+O/smnzzTAZj9
Bu4nWqVnMh24AXXfq4vr9l15CpWHu5/5AMx/KPJA/8P0w8IHZj5K+AHth4Wv
P9R96OEPAAcqkSs=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhD6x/5QMBCF81evAgEROB9Ci6CpF0ZTL4Sm
njAfrG3VLzgfYu5fNPUMB1DlGQ+g6mc6gKqeBYOP6j6WA6juh6kXQVMvgqZe
FE29GEH+ahT3iaG5H6aeAc4PQ/E/TP+v/ajqf+wHADDWXJA=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, -2.2651650429449552`}, {
       5.3247595264191645`, -2.1875}, {
       5.404942744332997, -2.404942744332997}, {
       5.265165042944956, -2.2651650429449552`}}], 
      PolygonBox[{{5.437344993353523, -2.2302516425362553`}, {
       5.404942744332997, -2.404942744332997}, {
       5.3247595264191645`, -2.1875}, {
       5.437344993353523, -2.2302516425362553`}}], 
      PolygonBox[{{5.3247595264191645`, -2.1875}, {
       5.362222184858401, -2.0970571419134454`}, {
       5.437344993353523, -2.2302516425362553`}, {
       5.3247595264191645`, -2.1875}}], 
      PolygonBox[{{5.437499981032941, -2.084292589556062}, {
       5.437344993353523, -2.2302516425362553`}, {
       5.362222184858401, -2.0970571419134454`}, {
       5.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{5.362222184858401, -2.0970571419134454`}, {5.375, -2.}, {
       5.437499981032941, -2.084292589556062}, {
       5.362222184858401, -2.0970571419134454`}}], 
      PolygonBox[{{5.4375, -2.}, {5.437499981032941, -2.084292589556062}, {
       5.375, -2.}, {5.4375, -2.}}], 
      PolygonBox[{{5.375, -2.}, {5.362222184858401, -1.9029428580865548`}, {
       5.4375, -2.}, {5.375, -2.}}], 
      PolygonBox[{{5.437499981032941, -1.9157074104439382`}, {5.4375, -2.}, {
       5.362222184858401, -1.9029428580865548`}, {
       5.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{5.362222184858401, -1.9029428580865548`}, {
       5.3247595264191645`, -1.8125}, {
       5.437499981032941, -1.9157074104439382`}, {
       5.362222184858401, -1.9029428580865548`}}], 
      PolygonBox[{{5.437344993353523, -1.769748357463745}, {
       5.437499981032941, -1.9157074104439382`}, {
       5.3247595264191645`, -1.8125}, {
       5.437344993353523, -1.769748357463745}}], 
      PolygonBox[{{5.3247595264191645`, -1.8125}, {
       5.265165042944956, -1.7348349570550448`}, {
       5.437344993353523, -1.769748357463745}, {
       5.3247595264191645`, -1.8125}}], 
      PolygonBox[{{5.404942744332997, -1.5950572556670028`}, {
       5.437344993353523, -1.769748357463745}, {
       5.265165042944956, -1.7348349570550448`}, {
       5.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{5.265165042944956, -1.7348349570550448`}, {
       5.1875, -1.6752404735808355`}, {
       5.404942744332997, -1.5950572556670028`}, {
       5.265165042944956, -1.7348349570550448`}}], 
      PolygonBox[{{5.230251642536255, -1.5626550066464766`}, {
       5.404942744332997, -1.5950572556670028`}, {
       5.1875, -1.6752404735808355`}, {
       5.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{5.1875, -1.6752404735808355`}, {
       5.097057141913445, -1.6377778151415994`}, {
       5.230251642536255, -1.5626550066464766`}, {
       5.1875, -1.6752404735808355`}}], 
      PolygonBox[{{5.0842925895560604`, -1.5625000189670593`}, {
       5.230251642536255, -1.5626550066464766`}, {
       5.097057141913445, -1.6377778151415994`}, {
       5.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{5.097057141913445, -1.6377778151415994`}, {5., -1.625}, {
       5.0842925895560604`, -1.5625000189670593`}, {
       5.097057141913445, -1.6377778151415994`}}], 
      PolygonBox[{{5.000105527220487, -1.5625}, {
       5.0842925895560604`, -1.5625000189670593`}, {5., -1.625}, {
       5.000105527220487, -1.5625}}], 
      PolygonBox[{{5., -1.625}, {4.902942858086555, -1.6377778151415994`}, {
       5.000105527220487, -1.5625}, {5., -1.625}}], 
      PolygonBox[{{4.915707410443943, -1.5625000189670593`}, {
       5.000105527220487, -1.5625}, {
       4.902942858086555, -1.6377778151415994`}, {
       4.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{4.902942858086555, -1.6377778151415994`}, {
       4.8125, -1.6752404735808355`}, {
       4.915707410443943, -1.5625000189670593`}, {
       4.902942858086555, -1.6377778151415994`}}], 
      PolygonBox[{{4.769748357463745, -1.5626550066464766`}, {
       4.915707410443943, -1.5625000189670593`}, {
       4.8125, -1.6752404735808355`}, {
       4.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{4.8125, -1.6752404735808355`}, {
       4.734834957055044, -1.7348349570550448`}, {
       4.769748357463745, -1.5626550066464766`}, {
       4.8125, -1.6752404735808355`}}], 
      PolygonBox[{{4.595057255667003, -1.5950572556670028`}, {
       4.769748357463745, -1.5626550066464766`}, {
       4.734834957055044, -1.7348349570550448`}, {
       4.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{4.734834957055044, -1.7348349570550448`}, {
       4.6752404735808355`, -1.8125}, {
       4.595057255667003, -1.5950572556670028`}, {
       4.734834957055044, -1.7348349570550448`}}], 
      PolygonBox[{{4.562655006646477, -1.7697483574637447`}, {
       4.595057255667003, -1.5950572556670028`}, {
       4.6752404735808355`, -1.8125}, {
       4.562655006646477, -1.7697483574637447`}}], 
      PolygonBox[{{4.6752404735808355`, -1.8125}, {
       4.637777815141599, -1.9029428580865546`}, {
       4.562655006646477, -1.7697483574637447`}, {
       4.6752404735808355`, -1.8125}}], 
      PolygonBox[{{4.562500018967059, -1.9157074104439376`}, {
       4.562655006646477, -1.7697483574637447`}, {
       4.637777815141599, -1.9029428580865546`}, {
       4.562500018967059, -1.9157074104439376`}}], 
      PolygonBox[{{4.637777815141599, -1.9029428580865546`}, {
       4.625, -1.9999999999999998`}, {
       4.562500018967059, -1.9157074104439376`}, {
       4.637777815141599, -1.9029428580865546`}}], 
      PolygonBox[{{4.5625, -1.9998768219370047`}, {
       4.562500018967059, -1.9157074104439376`}, {
       4.625, -1.9999999999999998`}, {4.5625, -1.9998768219370047`}}], 
      PolygonBox[{{4.625, -1.9999999999999998`}, {
       4.637777815141599, -2.097057141913445}, {
       4.5625, -1.9998768219370047`}, {4.625, -1.9999999999999998`}}], 
      PolygonBox[{{4.562500018967059, -2.084292589556055}, {
       4.5625, -1.9998768219370047`}, {
       4.637777815141599, -2.097057141913445}, {
       4.562500018967059, -2.084292589556055}}], 
      PolygonBox[{{4.637777815141599, -2.097057141913445}, {
       4.6752404735808355`, -2.1875}, {
       4.562500018967059, -2.084292589556055}, {
       4.637777815141599, -2.097057141913445}}], 
      PolygonBox[{{4.562655006646477, -2.230251642536255}, {
       4.562500018967059, -2.084292589556055}, {
       4.6752404735808355`, -2.1875}, {
       4.562655006646477, -2.230251642536255}}], 
      PolygonBox[{{4.6752404735808355`, -2.1875}, {
       4.734834957055044, -2.2651650429449552`}, {
       4.562655006646477, -2.230251642536255}, {
       4.6752404735808355`, -2.1875}}], 
      PolygonBox[{{4.595057255667003, -2.404942744332997}, {
       4.562655006646477, -2.230251642536255}, {
       4.734834957055044, -2.2651650429449552`}, {
       4.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{4.734834957055044, -2.2651650429449552`}, {
       4.8125, -2.3247595264191645`}, {
       4.595057255667003, -2.404942744332997}, {
       4.734834957055044, -2.2651650429449552`}}], 
      PolygonBox[{{4.769748357463745, -2.4373449933535234`}, {
       4.595057255667003, -2.404942744332997}, {
       4.8125, -2.3247595264191645`}, {
       4.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{4.8125, -2.3247595264191645`}, {
       4.902942858086554, -2.3622221848584006`}, {
       4.769748357463745, -2.4373449933535234`}, {
       4.8125, -2.3247595264191645`}}], 
      PolygonBox[{{4.915707410443936, -2.437499981032941}, {
       4.769748357463745, -2.4373449933535234`}, {
       4.902942858086554, -2.3622221848584006`}, {
       4.915707410443936, -2.437499981032941}}], 
      PolygonBox[{{4.902942858086554, -2.3622221848584006`}, {5., -2.375}, {
       4.915707410443936, -2.437499981032941}, {
       4.902942858086554, -2.3622221848584006`}}], 
      PolygonBox[{{5.000134841831043, -2.4375}, {
       4.915707410443936, -2.437499981032941}, {5., -2.375}, {
       5.000134841831043, -2.4375}}], 
      PolygonBox[{{5., -2.375}, {5.097057141913445, -2.3622221848584006`}, {
       5.000134841831043, -2.4375}, {5., -2.375}}], 
      PolygonBox[{{5.084292589556053, -2.437499981032941}, {
       5.000134841831043, -2.4375}, {
       5.097057141913445, -2.3622221848584006`}, {
       5.084292589556053, -2.437499981032941}}], 
      PolygonBox[{{5.097057141913445, -2.3622221848584006`}, {
       5.1875, -2.3247595264191645`}, {
       5.084292589556053, -2.437499981032941}, {
       5.097057141913445, -2.3622221848584006`}}], 
      PolygonBox[{{5.230251642536254, -2.4373449933535234`}, {
       5.084292589556053, -2.437499981032941}, {
       5.1875, -2.3247595264191645`}, {
       5.230251642536254, -2.4373449933535234`}}], 
      PolygonBox[{{5.1875, -2.3247595264191645`}, {
       5.265165042944956, -2.2651650429449552`}, {
       5.230251642536254, -2.4373449933535234`}, {
       5.1875, -2.3247595264191645`}}], 
      PolygonBox[{{5.404942744332997, -2.404942744332997}, {
       5.230251642536254, -2.4373449933535234`}, {
       5.265165042944956, -2.2651650429449552`}, {
       5.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{5.265165042944956, -2.2651650429449552`}, {
       5.265165042944956, -2.2651650429449552`}, {
       5.404942744332997, -2.404942744332997}, {
       5.265165042944956, -2.2651650429449552`}}], 
      PolygonBox[{{5.404942744332997, -2.404942744332997}, {
       5.404942744332997, -2.404942744332997}, {
       5.265165042944956, -2.2651650429449552`}, {
       5.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{5.404942744332997, -2.404942744332997}, {
       5.437344993353523, -2.2302516425362553`}, {5.5, -2.5}, {
       5.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{5.5, -2.357662782649368}, {5.5, -2.5}, {
       5.437344993353523, -2.2302516425362553`}, {5.5, -2.357662782649368}}], 
      PolygonBox[{{5.437344993353523, -2.2302516425362553`}, {
       5.437499981032941, -2.084292589556062}, {5.5, -2.357662782649368}, {
       5.437344993353523, -2.2302516425362553`}}], 
      PolygonBox[{{5.5, -2.20590900530174}, {5.5, -2.357662782649368}, {
       5.437499981032941, -2.084292589556062}, {5.5, -2.20590900530174}}], 
      PolygonBox[{{5.437499981032941, -2.084292589556062}, {5.4375, -2.}, {
       5.5, -2.20590900530174}, {5.437499981032941, -2.084292589556062}}], 
      PolygonBox[{{5.5, -2.}, {5.5, -2.20590900530174}, {5.4375, -2.}, {
       5.5, -2.}}], 
      PolygonBox[{{5.4375, -2.}, {5.437499981032941, -1.9157074104439382`}, {
       5.5, -2.}, {5.4375, -2.}}], 
      PolygonBox[{{5.5, -1.7940909946982602`}, {5.5, -2.}, {
       5.437499981032941, -1.9157074104439382`}, {
       5.5, -1.7940909946982602`}}], 
      PolygonBox[{{5.437499981032941, -1.9157074104439382`}, {
       5.437344993353523, -1.769748357463745}, {5.5, -1.7940909946982602`}, {
       5.437499981032941, -1.9157074104439382`}}], 
      PolygonBox[{{5.5, -1.6423372173506325`}, {5.5, -1.7940909946982602`}, {
       5.437344993353523, -1.769748357463745}, {5.5, -1.6423372173506325`}}], 
      PolygonBox[{{5.437344993353523, -1.769748357463745}, {
       5.404942744332997, -1.5950572556670028`}, {
       5.5, -1.6423372173506325`}, {5.437344993353523, -1.769748357463745}}], 
      PolygonBox[{{5.491446564961186, -1.508553435038814}, {
       5.5, -1.6423372173506325`}, {
       5.404942744332997, -1.5950572556670028`}, {
       5.491446564961186, -1.508553435038814}}], 
      PolygonBox[{{5.404942744332997, -1.5950572556670028`}, {
       5.230251642536255, -1.5626550066464766`}, {
       5.491446564961186, -1.508553435038814}, {
       5.404942744332997, -1.5950572556670028`}}], 
      PolygonBox[{{5.357662782649368, -1.5}, {
       5.491446564961186, -1.508553435038814}, {
       5.230251642536255, -1.5626550066464766`}, {5.357662782649368, -1.5}}], 
      PolygonBox[{{5.230251642536255, -1.5626550066464766`}, {
       5.0842925895560604`, -1.5625000189670593`}, {
       5.357662782649368, -1.5}, {5.230251642536255, -1.5626550066464766`}}], 
      PolygonBox[{{5.205909005373256, -1.5}, {5.357662782649368, -1.5}, {
       5.0842925895560604`, -1.5625000189670593`}, {
       5.205909005373256, -1.5}}], 
      PolygonBox[{{5.0842925895560604`, -1.5625000189670593`}, {
       5.000105527220487, -1.5625}, {5.205909005373256, -1.5}, {
       5.0842925895560604`, -1.5625000189670593`}}], 
      PolygonBox[{{5.07794195802689, -1.5}, {5.205909005373256, -1.5}, {
       5.000105527220487, -1.5625}, {5.07794195802689, -1.5}}], 
      PolygonBox[{{5.000105527220487, -1.5625}, {
       4.915707410443943, -1.5625000189670593`}, {5.07794195802689, -1.5}, {
       5.000105527220487, -1.5625}}], 
      PolygonBox[{{4.794090994695554, -1.5}, {5.07794195802689, -1.5}, {
       4.915707410443943, -1.5625000189670593`}, {4.794090994695554, -1.5}}], 
      PolygonBox[{{4.915707410443943, -1.5625000189670593`}, {
       4.769748357463745, -1.5626550066464766`}, {4.794090994695554, -1.5}, {
       4.915707410443943, -1.5625000189670593`}}], 
      PolygonBox[{{4.642337217350634, -1.5}, {4.794090994695554, -1.5}, {
       4.769748357463745, -1.5626550066464766`}, {4.642337217350634, -1.5}}], 
      PolygonBox[{{4.769748357463745, -1.5626550066464766`}, {
       4.595057255667003, -1.5950572556670028`}, {4.642337217350634, -1.5}, {
       4.769748357463745, -1.5626550066464766`}}], 
      PolygonBox[{{5.5, -1.5}, {4.642337217350634, -1.5}, {
       4.595057255667003, -1.5950572556670028`}, {5.5, -1.5}}], 
      PolygonBox[{{4.595057255667003, -1.5950572556670028`}, {
       4.562655006646477, -1.7697483574637447`}, {5.5, -1.5}, {
       4.595057255667003, -1.5950572556670028`}}], 
      PolygonBox[{{4.5, -1.642337217350631}, {5.5, -1.5}, {
       4.562655006646477, -1.7697483574637447`}, {4.5, -1.642337217350631}}], 
      PolygonBox[{{4.562655006646477, -1.7697483574637447`}, {
       4.562500018967059, -1.9157074104439376`}, {4.5, -1.642337217350631}, {
       4.562655006646477, -1.7697483574637447`}}], 
      PolygonBox[{{4.5, -1.794090994717101}, {4.5, -1.642337217350631}, {
       4.562500018967059, -1.9157074104439376`}, {4.5, -1.794090994717101}}], 
      PolygonBox[{{4.562500018967059, -1.9157074104439376`}, {
       4.5625, -1.9998768219370047`}, {4.5, -1.794090994717101}, {
       4.562500018967059, -1.9157074104439376`}}], 
      PolygonBox[{{4.5, -1.9193213332412997`}, {4.5, -1.794090994717101}, {
       4.5625, -1.9998768219370047`}, {4.5, -1.9193213332412997`}}], 
      PolygonBox[{{4.5625, -1.9998768219370047`}, {
       4.562500018967059, -2.084292589556055}, {4.5, -1.9193213332412997`}, {
       4.5625, -1.9998768219370047`}}], 
      PolygonBox[{{4.5, -2.2059090051452785`}, {4.5, -1.9193213332412997`}, {
       4.562500018967059, -2.084292589556055}, {4.5, -2.2059090051452785`}}], 
      PolygonBox[{{4.562500018967059, -2.084292589556055}, {
       4.562655006646477, -2.230251642536255}, {4.5, -2.2059090051452785`}, {
       4.562500018967059, -2.084292589556055}}], 
      PolygonBox[{{4.5, -2.3576627826493652`}, {4.5, -2.2059090051452785`}, {
       4.562655006646477, -2.230251642536255}, {4.5, -2.3576627826493652`}}], 
      PolygonBox[{{4.562655006646477, -2.230251642536255}, {
       4.595057255667003, -2.404942744332997}, {4.5, -2.3576627826493652`}, {
       4.562655006646477, -2.230251642536255}}], 
      PolygonBox[{{4.5, -1.5}, {4.5, -2.3576627826493652`}, {
       4.595057255667003, -2.404942744332997}, {4.5, -1.5}}], 
      PolygonBox[{{4.595057255667003, -2.404942744332997}, {
       4.769748357463745, -2.4373449933535234`}, {4.5, -1.5}, {
       4.595057255667003, -2.404942744332997}}], 
      PolygonBox[{{4.5, -2.5}, {4.5, -1.5}, {
       4.769748357463745, -2.4373449933535234`}, {4.5, -2.5}}], 
      PolygonBox[{{4.769748357463745, -2.4373449933535234`}, {
       4.915707410443936, -2.437499981032941}, {4.5, -2.5}, {
       4.769748357463745, -2.4373449933535234`}}], 
      PolygonBox[{{4.794090994433172, -2.5}, {4.5, -2.5}, {
       4.915707410443936, -2.437499981032941}, {4.794090994433172, -2.5}}], 
      PolygonBox[{{4.915707410443936, -2.437499981032941}, {
       5.000134841831043, -2.4375}, {4.794090994433172, -2.5}, {
       4.915707410443936, -2.437499981032941}}], 
      PolygonBox[{{5.082323870401062, -2.5}, {4.794090994433172, -2.5}, {
       5.000134841831043, -2.4375}, {5.082323870401062, -2.5}}], 
      PolygonBox[{{5.000134841831043, -2.4375}, {
       5.084292589556053, -2.437499981032941}, {5.082323870401062, -2.5}, {
       5.000134841831043, -2.4375}}], 
      PolygonBox[{{5.205909005360398, -2.5}, {5.082323870401062, -2.5}, {
       5.084292589556053, -2.437499981032941}, {5.205909005360398, -2.5}}], 
      PolygonBox[{{5.084292589556053, -2.437499981032941}, {
       5.230251642536254, -2.4373449933535234`}, {5.205909005360398, -2.5}, {
       5.084292589556053, -2.437499981032941}}], 
      PolygonBox[{{5.3576627826493715`, -2.5}, {5.205909005360398, -2.5}, {
       5.230251642536254, -2.4373449933535234`}, {
       5.3576627826493715`, -2.5}}], 
      PolygonBox[{{5.230251642536254, -2.4373449933535234`}, {
       5.404942744332997, -2.404942744332997}, {5.3576627826493715`, -2.5}, {
       5.230251642536254, -2.4373449933535234`}}], 
      PolygonBox[{{5.5, -2.5}, {5.3576627826493715`, -2.5}, {
       5.404942744332997, -2.404942744332997}, {5.5, -2.5}}], 
      PolygonBox[{{5.404942744332997, -2.404942744332997}, {
       5.404942744332997, -2.404942744332997}, {5.5, -2.5}, {
       5.404942744332997, -2.404942744332997}}], 
      PolygonBox[{{5.5, -2.5}, {5.5, -2.5}, {
       5.404942744332997, -2.404942744332997}, {5.5, -2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, -1.}, {4.520833333333333, -1.}, {
       4.541666666666667, -1.}, {4.5625, -1.}, {4.583333333333333, -1.}, {
       4.604166666666667, -1.}, {4.625, -1.}, {4.625, -1.}, {
       4.604166666666667, -1.}, {4.583333333333333, -1.}, {4.5625, -1.}, {
       4.541666666666667, -1.}, {4.520833333333333, -1.}, {4.5, -1.}, {
       4.5, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, -1.}, {5.395833333333333, -1.}, {
       5.416666666666667, -1.}, {5.4375, -1.}, {5.458333333333333, -1.}, {
       5.479166666666667, -1.}, {5.5, -1.}, {5.5, -1.}, {
       5.479166666666667, -1.}, {5.458333333333333, -1.}, {5.4375, -1.}, {
       5.416666666666667, -1.}, {5.395833333333333, -1.}, {5.375, -1.}, {
       5.375, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -1.5}, {5., -1.4791666666666667`}, {
       5., -1.4583333333333333`}, {5., -1.4375}, {5., -1.4166666666666667`}, {
       5., -1.3958333333333335`}, {5., -1.375}, {5., -1.375}, {
       5., -1.3958333333333333`}, {5., -1.4166666666666667`}, {5., -1.4375}, {
       5., -1.4583333333333333`}, {5., -1.4791666666666665`}, {5., -1.5}, {
       5., -1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -0.625}, {5., -0.6041666666666667}, {
       5., -0.5833333333333333}, {5., -0.5625}, {5., -0.5416666666666667}, {
       5., -0.5208333333333334}, {5., -0.5}, {5., -0.5}, {
       5., -0.5208333333333333}, {5., -0.5416666666666667}, {5., -0.5625}, {
       5., -0.5833333333333333}, {5., -0.6041666666666666}, {5., -0.625}, {
       5., -0.625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, -1.}, {4.75, -1.}, {4.875, -1.}, {5., -1.}, {
       5.125, -1.}, {5.25, -1.}, {5.375, -1.}, {5.375, -1.}, {5.25, -1.}, {
       5.125, -1.}, {5., -1.}, {4.875, -1.}, {4.75, -1.}, {4.625, -1.}, {
       4.625, -1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -1.375}, {5., -1.25}, {5., -1.125}, {5., -1.}, {
       5., -0.875}, {5., -0.75}, {5., -0.625}, {5., -0.625}, {5., -0.75}, {
       5., -0.875}, {5., -1.}, {5., -1.125}, {5., -1.25}, {5., -1.375}, {
       5., -1.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4Qxof9XzPC418ViToczduS/eLJm/0zlJ8c
6vWByb/af+7b2Zx2flGHKZ4TZh5pfr4fLHxAxMHh8b0XE2c/3a9e1PkpKVnE
IWKHC+vajCcQeQYRqP4n+2/2lvHOnSOMKu8gDNdvxGk0ueKDkMNkqPkZd6Rt
izYLOfwHg5f7uaevWCDaK+RwBOo+iPuF4O6Hyc89oXqqu/cjXD9E/jPcfLPb
5ptl7b7A7U/om8BtbvR1/w2o+64sjq1deformvu/wf2HIg/0P0w/LHxg5sPC
jxFqPyx850Pdhx7+AFp0n/E=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhD6wf5QMBCF81evAgEROB9Ci6CpF0ZTL4Sm
njAfYs5TOB9szKpXaOo/oMl/QtP/FU39Dww+qvt+oLn/B5r/fqD5/wda+MDU
ixHkh6G4T8xhNYr7Yeo/oMm/QtP/FE39g/0A28Bplg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, -1.2651650429449552`}, {
       5.3247595264191645`, -1.1875}, {
       5.404942744332997, -1.4049427443329972`}, {
       5.265165042944956, -1.2651650429449552`}}], 
      PolygonBox[{{5.437344993353523, -1.230251642536255}, {
       5.404942744332997, -1.4049427443329972`}, {
       5.3247595264191645`, -1.1875}, {
       5.437344993353523, -1.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, -1.1875}, {
       5.362222184858401, -1.0970571419134454`}, {
       5.437344993353523, -1.230251642536255}, {
       5.3247595264191645`, -1.1875}}], 
      PolygonBox[{{5.437499981032941, -1.0842925895560618`}, {
       5.437344993353523, -1.230251642536255}, {
       5.362222184858401, -1.0970571419134454`}, {
       5.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{5.362222184858401, -1.0970571419134454`}, {5.375, -1.}, {
       5.437499981032941, -1.0842925895560618`}, {
       5.362222184858401, -1.0970571419134454`}}], 
      PolygonBox[{{5.4375, -1.}, {5.437499981032941, -1.0842925895560618`}, {
       5.375, -1.}, {5.4375, -1.}}], 
      PolygonBox[{{5.375, -1.}, {5.362222184858401, -0.9029428580865547}, {
       5.4375, -1.}, {5.375, -1.}}], 
      PolygonBox[{{5.437499981032941, -0.9157074104439382}, {5.4375, -1.}, {
       5.362222184858401, -0.9029428580865547}, {
       5.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{5.362222184858401, -0.9029428580865547}, {
       5.3247595264191645`, -0.8125}, {
       5.437499981032941, -0.9157074104439382}, {
       5.362222184858401, -0.9029428580865547}}], 
      PolygonBox[{{5.437344993353523, -0.7697483574637449}, {
       5.437499981032941, -0.9157074104439382}, {
       5.3247595264191645`, -0.8125}, {
       5.437344993353523, -0.7697483574637449}}], 
      PolygonBox[{{5.3247595264191645`, -0.8125}, {
       5.265165042944956, -0.7348349570550448}, {
       5.437344993353523, -0.7697483574637449}, {
       5.3247595264191645`, -0.8125}}], 
      PolygonBox[{{5.404942744332997, -0.5950572556670028}, {
       5.437344993353523, -0.7697483574637449}, {
       5.265165042944956, -0.7348349570550448}, {
       5.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{5.265165042944956, -0.7348349570550448}, {
       5.1875, -0.6752404735808355}, {
       5.404942744332997, -0.5950572556670028}, {
       5.265165042944956, -0.7348349570550448}}], 
      PolygonBox[{{5.230251642536255, -0.5626550066464766}, {
       5.404942744332997, -0.5950572556670028}, {
       5.1875, -0.6752404735808355}, {
       5.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{5.1875, -0.6752404735808355}, {
       5.097057141913445, -0.6377778151415994}, {
       5.230251642536255, -0.5626550066464766}, {
       5.1875, -0.6752404735808355}}], 
      PolygonBox[{{5.0842925895560604`, -0.5625000189670593}, {
       5.230251642536255, -0.5626550066464766}, {
       5.097057141913445, -0.6377778151415994}, {
       5.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{5.097057141913445, -0.6377778151415994}, {5., -0.625}, {
       5.0842925895560604`, -0.5625000189670593}, {
       5.097057141913445, -0.6377778151415994}}], 
      PolygonBox[{{5.000105527220487, -0.5625}, {
       5.0842925895560604`, -0.5625000189670593}, {5., -0.625}, {
       5.000105527220487, -0.5625}}], 
      PolygonBox[{{5., -0.625}, {4.902942858086555, -0.6377778151415994}, {
       5.000105527220487, -0.5625}, {5., -0.625}}], 
      PolygonBox[{{4.915707410443943, -0.5625000189670593}, {
       5.000105527220487, -0.5625}, {
       4.902942858086555, -0.6377778151415994}, {
       4.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{4.902942858086555, -0.6377778151415994}, {
       4.8125, -0.6752404735808355}, {
       4.915707410443943, -0.5625000189670593}, {
       4.902942858086555, -0.6377778151415994}}], 
      PolygonBox[{{4.769748357463745, -0.5626550066464766}, {
       4.915707410443943, -0.5625000189670593}, {
       4.8125, -0.6752404735808355}, {
       4.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{4.8125, -0.6752404735808355}, {
       4.734834957055044, -0.7348349570550446}, {
       4.769748357463745, -0.5626550066464766}, {
       4.8125, -0.6752404735808355}}], 
      PolygonBox[{{4.595057255667003, -0.5950572556670028}, {
       4.769748357463745, -0.5626550066464766}, {
       4.734834957055044, -0.7348349570550446}, {
       4.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{4.734834957055044, -0.7348349570550446}, {
       4.6752404735808355`, -0.8124999999999999}, {
       4.595057255667003, -0.5950572556670028}, {
       4.734834957055044, -0.7348349570550446}}], 
      PolygonBox[{{4.562655006646477, -0.7697483574637446}, {
       4.595057255667003, -0.5950572556670028}, {
       4.6752404735808355`, -0.8124999999999999}, {
       4.562655006646477, -0.7697483574637446}}], 
      PolygonBox[{{4.6752404735808355`, -0.8124999999999999}, {
       4.637777815141599, -0.9029428580865546}, {
       4.562655006646477, -0.7697483574637446}, {
       4.6752404735808355`, -0.8124999999999999}}], 
      PolygonBox[{{4.562500018967059, -0.9157074104439377}, {
       4.562655006646477, -0.7697483574637446}, {
       4.637777815141599, -0.9029428580865546}, {
       4.562500018967059, -0.9157074104439377}}], 
      PolygonBox[{{4.637777815141599, -0.9029428580865546}, {
       4.625, -0.9999999999999998}, {
       4.562500018967059, -0.9157074104439377}, {
       4.637777815141599, -0.9029428580865546}}], 
      PolygonBox[{{4.5625, -0.9998768219370047}, {
       4.562500018967059, -0.9157074104439377}, {
       4.625, -0.9999999999999998}, {4.5625, -0.9998768219370047}}], 
      PolygonBox[{{4.625, -0.9999999999999998}, {
       4.637777815141599, -1.0970571419134452`}, {
       4.5625, -0.9998768219370047}, {4.625, -0.9999999999999998}}], 
      PolygonBox[{{4.562500018967059, -1.084292589556055}, {
       4.5625, -0.9998768219370047}, {
       4.637777815141599, -1.0970571419134452`}, {
       4.562500018967059, -1.084292589556055}}], 
      PolygonBox[{{4.637777815141599, -1.0970571419134452`}, {
       4.6752404735808355`, -1.1874999999999998`}, {
       4.562500018967059, -1.084292589556055}, {
       4.637777815141599, -1.0970571419134452`}}], 
      PolygonBox[{{4.562655006646477, -1.2302516425362549`}, {
       4.562500018967059, -1.084292589556055}, {
       4.6752404735808355`, -1.1874999999999998`}, {
       4.562655006646477, -1.2302516425362549`}}], 
      PolygonBox[{{4.6752404735808355`, -1.1874999999999998`}, {
       4.734834957055044, -1.2651650429449552`}, {
       4.562655006646477, -1.2302516425362549`}, {
       4.6752404735808355`, -1.1874999999999998`}}], 
      PolygonBox[{{4.595057255667003, -1.4049427443329972`}, {
       4.562655006646477, -1.2302516425362549`}, {
       4.734834957055044, -1.2651650429449552`}, {
       4.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{4.734834957055044, -1.2651650429449552`}, {
       4.8125, -1.3247595264191645`}, {
       4.595057255667003, -1.4049427443329972`}, {
       4.734834957055044, -1.2651650429449552`}}], 
      PolygonBox[{{4.769748357463745, -1.4373449933535234`}, {
       4.595057255667003, -1.4049427443329972`}, {
       4.8125, -1.3247595264191645`}, {
       4.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{4.8125, -1.3247595264191645`}, {
       4.902942858086554, -1.3622221848584006`}, {
       4.769748357463745, -1.4373449933535234`}, {
       4.8125, -1.3247595264191645`}}], 
      PolygonBox[{{4.915707410443936, -1.4374999810329407`}, {
       4.769748357463745, -1.4373449933535234`}, {
       4.902942858086554, -1.3622221848584006`}, {
       4.915707410443936, -1.4374999810329407`}}], 
      PolygonBox[{{4.902942858086554, -1.3622221848584006`}, {5., -1.375}, {
       4.915707410443936, -1.4374999810329407`}, {
       4.902942858086554, -1.3622221848584006`}}], 
      PolygonBox[{{5.000134841831043, -1.4375}, {
       4.915707410443936, -1.4374999810329407`}, {5., -1.375}, {
       5.000134841831043, -1.4375}}], 
      PolygonBox[{{5., -1.375}, {5.097057141913445, -1.3622221848584006`}, {
       5.000134841831043, -1.4375}, {5., -1.375}}], 
      PolygonBox[{{5.084292589556053, -1.4374999810329407`}, {
       5.000134841831043, -1.4375}, {
       5.097057141913445, -1.3622221848584006`}, {
       5.084292589556053, -1.4374999810329407`}}], 
      PolygonBox[{{5.097057141913445, -1.3622221848584006`}, {
       5.1875, -1.3247595264191645`}, {
       5.084292589556053, -1.4374999810329407`}, {
       5.097057141913445, -1.3622221848584006`}}], 
      PolygonBox[{{5.230251642536254, -1.4373449933535234`}, {
       5.084292589556053, -1.4374999810329407`}, {
       5.1875, -1.3247595264191645`}, {
       5.230251642536254, -1.4373449933535234`}}], 
      PolygonBox[{{5.1875, -1.3247595264191645`}, {
       5.265165042944956, -1.2651650429449552`}, {
       5.230251642536254, -1.4373449933535234`}, {
       5.1875, -1.3247595264191645`}}], 
      PolygonBox[{{5.404942744332997, -1.4049427443329972`}, {
       5.230251642536254, -1.4373449933535234`}, {
       5.265165042944956, -1.2651650429449552`}, {
       5.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{5.265165042944956, -1.2651650429449552`}, {
       5.265165042944956, -1.2651650429449552`}, {
       5.404942744332997, -1.4049427443329972`}, {
       5.265165042944956, -1.2651650429449552`}}], 
      PolygonBox[{{5.404942744332997, -1.4049427443329972`}, {
       5.404942744332997, -1.4049427443329972`}, {
       5.265165042944956, -1.2651650429449552`}, {
       5.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{5.404942744332997, -1.4049427443329972`}, {
       5.437344993353523, -1.230251642536255}, {5.5, -1.5}, {
       5.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{5.5, -1.3576627826493677`}, {5.5, -1.5}, {
       5.437344993353523, -1.230251642536255}, {5.5, -1.3576627826493677`}}], 
      PolygonBox[{{5.437344993353523, -1.230251642536255}, {
       5.437499981032941, -1.0842925895560618`}, {
       5.5, -1.3576627826493677`}, {5.437344993353523, -1.230251642536255}}], 
      PolygonBox[{{5.5, -1.20590900530174}, {5.5, -1.3576627826493677`}, {
       5.437499981032941, -1.0842925895560618`}, {5.5, -1.20590900530174}}], 
      PolygonBox[{{5.437499981032941, -1.0842925895560618`}, {5.4375, -1.}, {
       5.5, -1.20590900530174}, {5.437499981032941, -1.0842925895560618`}}], 
      PolygonBox[{{5.5, -1.}, {5.5, -1.20590900530174}, {5.4375, -1.}, {
       5.5, -1.}}], 
      PolygonBox[{{5.4375, -1.}, {5.437499981032941, -0.9157074104439382}, {
       5.5, -1.}, {5.4375, -1.}}], 
      PolygonBox[{{5.5, -0.79409099469826}, {5.5, -1.}, {
       5.437499981032941, -0.9157074104439382}, {5.5, -0.79409099469826}}], 
      PolygonBox[{{5.437499981032941, -0.9157074104439382}, {
       5.437344993353523, -0.7697483574637449}, {5.5, -0.79409099469826}, {
       5.437499981032941, -0.9157074104439382}}], 
      PolygonBox[{{5.5, -0.6423372173506324}, {5.5, -0.79409099469826}, {
       5.437344993353523, -0.7697483574637449}, {5.5, -0.6423372173506324}}], 
      PolygonBox[{{5.437344993353523, -0.7697483574637449}, {
       5.404942744332997, -0.5950572556670028}, {5.5, -0.6423372173506324}, {
       5.437344993353523, -0.7697483574637449}}], 
      PolygonBox[{{5.491446564961186, -0.508553435038814}, {
       5.5, -0.6423372173506324}, {5.404942744332997, -0.5950572556670028}, {
       5.491446564961186, -0.508553435038814}}], 
      PolygonBox[{{5.404942744332997, -0.5950572556670028}, {
       5.230251642536255, -0.5626550066464766}, {
       5.491446564961186, -0.508553435038814}, {
       5.404942744332997, -0.5950572556670028}}], 
      PolygonBox[{{5.357662782649368, -0.5}, {
       5.491446564961186, -0.508553435038814}, {
       5.230251642536255, -0.5626550066464766}, {5.357662782649368, -0.5}}], 
      PolygonBox[{{5.230251642536255, -0.5626550066464766}, {
       5.0842925895560604`, -0.5625000189670593}, {5.357662782649368, -0.5}, {
       5.230251642536255, -0.5626550066464766}}], 
      PolygonBox[{{5.205909005373256, -0.5}, {5.357662782649368, -0.5}, {
       5.0842925895560604`, -0.5625000189670593}, {5.205909005373256, -0.5}}],
       PolygonBox[{{5.0842925895560604`, -0.5625000189670593}, {
       5.000105527220487, -0.5625}, {5.205909005373256, -0.5}, {
       5.0842925895560604`, -0.5625000189670593}}], 
      PolygonBox[{{5.07794195802689, -0.5}, {5.205909005373256, -0.5}, {
       5.000105527220487, -0.5625}, {5.07794195802689, -0.5}}], 
      PolygonBox[{{5.000105527220487, -0.5625}, {
       4.915707410443943, -0.5625000189670593}, {5.07794195802689, -0.5}, {
       5.000105527220487, -0.5625}}], 
      PolygonBox[{{4.794090994695554, -0.5}, {5.07794195802689, -0.5}, {
       4.915707410443943, -0.5625000189670593}, {4.794090994695554, -0.5}}], 
      PolygonBox[{{4.915707410443943, -0.5625000189670593}, {
       4.769748357463745, -0.5626550066464766}, {4.794090994695554, -0.5}, {
       4.915707410443943, -0.5625000189670593}}], 
      PolygonBox[{{4.642337217350634, -0.5}, {4.794090994695554, -0.5}, {
       4.769748357463745, -0.5626550066464766}, {4.642337217350634, -0.5}}], 
      PolygonBox[{{4.769748357463745, -0.5626550066464766}, {
       4.595057255667003, -0.5950572556670028}, {4.642337217350634, -0.5}, {
       4.769748357463745, -0.5626550066464766}}], 
      PolygonBox[{{5.5, -0.5}, {4.642337217350634, -0.5}, {
       4.595057255667003, -0.5950572556670028}, {5.5, -0.5}}], 
      PolygonBox[{{4.595057255667003, -0.5950572556670028}, {
       4.562655006646477, -0.7697483574637446}, {5.5, -0.5}, {
       4.595057255667003, -0.5950572556670028}}], 
      PolygonBox[{{4.5, -0.642337217350631}, {5.5, -0.5}, {
       4.562655006646477, -0.7697483574637446}, {4.5, -0.642337217350631}}], 
      PolygonBox[{{4.562655006646477, -0.7697483574637446}, {
       4.562500018967059, -0.9157074104439377}, {4.5, -0.642337217350631}, {
       4.562655006646477, -0.7697483574637446}}], 
      PolygonBox[{{4.5, -0.7940909947171011}, {4.5, -0.642337217350631}, {
       4.562500018967059, -0.9157074104439377}, {4.5, -0.7940909947171011}}], 
      PolygonBox[{{4.562500018967059, -0.9157074104439377}, {
       4.5625, -0.9998768219370047}, {4.5, -0.7940909947171011}, {
       4.562500018967059, -0.9157074104439377}}], 
      PolygonBox[{{4.5, -0.9193213332412997}, {4.5, -0.7940909947171011}, {
       4.5625, -0.9998768219370047}, {4.5, -0.9193213332412997}}], 
      PolygonBox[{{4.5625, -0.9998768219370047}, {
       4.562500018967059, -1.084292589556055}, {4.5, -0.9193213332412997}, {
       4.5625, -0.9998768219370047}}], 
      PolygonBox[{{4.5, -1.2059090051452785`}, {4.5, -0.9193213332412997}, {
       4.562500018967059, -1.084292589556055}, {4.5, -1.2059090051452785`}}], 
      PolygonBox[{{4.562500018967059, -1.084292589556055}, {
       4.562655006646477, -1.2302516425362549`}, {
       4.5, -1.2059090051452785`}, {4.562500018967059, -1.084292589556055}}], 
      PolygonBox[{{4.5, -1.3576627826493652`}, {4.5, -1.2059090051452785`}, {
       4.562655006646477, -1.2302516425362549`}, {
       4.5, -1.3576627826493652`}}], 
      PolygonBox[{{4.562655006646477, -1.2302516425362549`}, {
       4.595057255667003, -1.4049427443329972`}, {
       4.5, -1.3576627826493652`}, {
       4.562655006646477, -1.2302516425362549`}}], 
      PolygonBox[{{4.5, -0.5}, {4.5, -1.3576627826493652`}, {
       4.595057255667003, -1.4049427443329972`}, {4.5, -0.5}}], 
      PolygonBox[{{4.595057255667003, -1.4049427443329972`}, {
       4.769748357463745, -1.4373449933535234`}, {4.5, -0.5}, {
       4.595057255667003, -1.4049427443329972`}}], 
      PolygonBox[{{4.5, -1.5}, {4.5, -0.5}, {
       4.769748357463745, -1.4373449933535234`}, {4.5, -1.5}}], 
      PolygonBox[{{4.769748357463745, -1.4373449933535234`}, {
       4.915707410443936, -1.4374999810329407`}, {4.5, -1.5}, {
       4.769748357463745, -1.4373449933535234`}}], 
      PolygonBox[{{4.794090994433172, -1.5}, {4.5, -1.5}, {
       4.915707410443936, -1.4374999810329407`}, {4.794090994433172, -1.5}}], 
      PolygonBox[{{4.915707410443936, -1.4374999810329407`}, {
       5.000134841831043, -1.4375}, {4.794090994433172, -1.5}, {
       4.915707410443936, -1.4374999810329407`}}], 
      PolygonBox[{{5.082323870401062, -1.5}, {4.794090994433172, -1.5}, {
       5.000134841831043, -1.4375}, {5.082323870401062, -1.5}}], 
      PolygonBox[{{5.000134841831043, -1.4375}, {
       5.084292589556053, -1.4374999810329407`}, {5.082323870401062, -1.5}, {
       5.000134841831043, -1.4375}}], 
      PolygonBox[{{5.205909005360398, -1.5}, {5.082323870401062, -1.5}, {
       5.084292589556053, -1.4374999810329407`}, {5.205909005360398, -1.5}}], 
      PolygonBox[{{5.084292589556053, -1.4374999810329407`}, {
       5.230251642536254, -1.4373449933535234`}, {5.205909005360398, -1.5}, {
       5.084292589556053, -1.4374999810329407`}}], 
      PolygonBox[{{5.3576627826493715`, -1.5}, {5.205909005360398, -1.5}, {
       5.230251642536254, -1.4373449933535234`}, {
       5.3576627826493715`, -1.5}}], 
      PolygonBox[{{5.230251642536254, -1.4373449933535234`}, {
       5.404942744332997, -1.4049427443329972`}, {
       5.3576627826493715`, -1.5}, {
       5.230251642536254, -1.4373449933535234`}}], 
      PolygonBox[{{5.5, -1.5}, {5.3576627826493715`, -1.5}, {
       5.404942744332997, -1.4049427443329972`}, {5.5, -1.5}}], 
      PolygonBox[{{5.404942744332997, -1.4049427443329972`}, {
       5.404942744332997, -1.4049427443329972`}, {5.5, -1.5}, {
       5.404942744332997, -1.4049427443329972`}}], 
      PolygonBox[{{5.5, -1.5}, {5.5, -1.5}, {
       5.404942744332997, -1.4049427443329972`}, {5.5, -1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, 0.}, {4.520833333333333, 0.}, {4.541666666666667, 0.}, {
       4.5625, 0.}, {4.583333333333333, 0.}, {4.604166666666667, 0.}, {4.625, 
       0.}, {4.625, 0.}, {4.604166666666667, 0.}, {4.583333333333333, 0.}, {
       4.5625, 0.}, {4.541666666666667, 0.}, {4.520833333333333, 0.}, {4.5, 
       0.}, {4.5, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, 0.}, {5.395833333333333, 0.}, {5.416666666666667, 
       0.}, {5.4375, 0.}, {5.458333333333333, 0.}, {5.479166666666667, 0.}, {
       5.5, 0.}, {5.5, 0.}, {5.479166666666667, 0.}, {5.458333333333333, 
       0.}, {5.4375, 0.}, {5.416666666666667, 0.}, {5.395833333333333, 0.}, {
       5.375, 0.}, {5.375, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -0.5}, {5., -0.4791666666666667}, {
       5., -0.4583333333333333}, {5., -0.4375}, {5., -0.4166666666666667}, {
       5., -0.39583333333333337`}, {5., -0.375}, {5., -0.375}, {
       5., -0.3958333333333333}, {5., -0.4166666666666667}, {5., -0.4375}, {
       5., -0.4583333333333333}, {5., -0.47916666666666663`}, {5., -0.5}, {
       5., -0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 0.375}, {5., 0.3958333333333333}, {5., 
       0.4166666666666667}, {5., 0.4375}, {5., 0.4583333333333333}, {5., 
       0.47916666666666663`}, {5., 0.5}, {5., 0.5}, {5., 
       0.4791666666666667}, {5., 0.4583333333333333}, {5., 0.4375}, {5., 
       0.4166666666666667}, {5., 0.39583333333333337`}, {5., 0.375}, {5., 
       0.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, 0.}, {4.75, 0.}, {4.875, 0.}, {5., 0.}, {5.125, 0.}, {
       5.25, 0.}, {5.375, 0.}, {5.375, 0.}, {5.25, 0.}, {5.125, 0.}, {5., 
       0.}, {4.875, 0.}, {4.75, 0.}, {4.625, 0.}, {4.625, 0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -0.375}, {5., -0.25}, {5., -0.125}, {5., 0.}, {5., 
       0.125}, {5., 0.25}, {5., 0.375}, {5., 0.375}, {5., 0.25}, {5., 
       0.125}, {5., 0.}, {5., -0.125}, {5., -0.25}, {5., -0.375}, {
       5., -0.375}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4w5teM8PhXRaIONzpjFu25scN+hvKTQ70+
og7/weC4/blvZ3Pa+UUdbubcP1P244I9WNMBEYcGSye9Oyeu2KsXdX5KShZx
8O8v+7pU7zpEnkEEav4N+5u9Zbxz5wg7BCDLOwjD9RtxGk2u+CDkcAtqfsYd
aduizUIOLGCFJ+y5p69YINor5PAA6j6I+4UcuLrm+VhWdtnA5M9B5PfD9P+B
uH8/zPzrEPP3w+yvg9i//wbUfX4Q9+1Hc/9+mP8CkOWB/m+C6oeFD9T9+2Hh
xwZx/35Y+L6Dug8W/hD3z9oDAGvqpUA=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhD6gX0oGIjC+atXgYAInA+hRdDUC6OpF0JT
T5gfBjbnKhr/KJp6GBByCIHI70flX92Pqv4BBh/NffvR3L8fzX/70fy/Hy18
oOrFCPLDUNwH4x9FUw8DYjD/2aPyr9qjqn9gDwBANVXg
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, -0.2651650429449553}, {
       5.3247595264191645`, -0.1875}, {
       5.404942744332997, -0.4049427443329971}, {
       5.265165042944956, -0.2651650429449553}}], 
      PolygonBox[{{5.437344993353523, -0.23025164253625516`}, {
       5.404942744332997, -0.4049427443329971}, {
       5.3247595264191645`, -0.1875}, {
       5.437344993353523, -0.23025164253625516`}}], 
      PolygonBox[{{5.3247595264191645`, -0.1875}, {
       5.362222184858401, -0.0970571419134453}, {
       5.437344993353523, -0.23025164253625516`}, {
       5.3247595264191645`, -0.1875}}], 
      PolygonBox[{{5.437499981032941, -0.08429258955606181}, {
       5.437344993353523, -0.23025164253625516`}, {
       5.362222184858401, -0.0970571419134453}, {
       5.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{5.362222184858401, -0.0970571419134453}, {5.375, 0.}, {
       5.437499981032941, -0.08429258955606181}, {
       5.362222184858401, -0.0970571419134453}}], 
      PolygonBox[{{5.4375, 0.}, {5.437499981032941, -0.08429258955606181}, {
       5.375, 0.}, {5.4375, 0.}}], 
      PolygonBox[{{5.375, 0.}, {5.362222184858401, 0.09705714191344525}, {
       5.4375, 0.}, {5.375, 0.}}], 
      PolygonBox[{{5.437499981032941, 0.08429258955606177}, {5.4375, 0.}, {
       5.362222184858401, 0.09705714191344525}, {5.437499981032941, 
       0.08429258955606177}}], 
      PolygonBox[{{5.362222184858401, 0.09705714191344525}, {
       5.3247595264191645`, 0.18749999999999994`}, {5.437499981032941, 
       0.08429258955606177}, {5.362222184858401, 0.09705714191344525}}], 
      PolygonBox[{{5.437344993353523, 0.23025164253625502`}, {
       5.437499981032941, 0.08429258955606177}, {5.3247595264191645`, 
       0.18749999999999994`}, {5.437344993353523, 0.23025164253625502`}}], 
      PolygonBox[{{5.3247595264191645`, 0.18749999999999994`}, {
       5.265165042944956, 0.2651650429449553}, {5.437344993353523, 
       0.23025164253625502`}, {5.3247595264191645`, 0.18749999999999994`}}], 
      PolygonBox[{{5.404942744332997, 0.40494274433299715`}, {
       5.437344993353523, 0.23025164253625502`}, {5.265165042944956, 
       0.2651650429449553}, {5.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{5.265165042944956, 0.2651650429449553}, {5.1875, 
       0.3247595264191645}, {5.404942744332997, 0.40494274433299715`}, {
       5.265165042944956, 0.2651650429449553}}], 
      PolygonBox[{{5.230251642536255, 0.4373449933535234}, {5.404942744332997,
        0.40494274433299715`}, {5.1875, 0.3247595264191645}, {
       5.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{5.1875, 0.3247595264191645}, {5.097057141913445, 
       0.3622221848584006}, {5.230251642536255, 0.4373449933535234}, {5.1875, 
       0.3247595264191645}}], 
      PolygonBox[{{5.0842925895560604`, 0.4374999810329408}, {
       5.230251642536255, 0.4373449933535234}, {5.097057141913445, 
       0.3622221848584006}, {5.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{5.097057141913445, 0.3622221848584006}, {5., 0.375}, {
       5.0842925895560604`, 0.4374999810329408}, {5.097057141913445, 
       0.3622221848584006}}], 
      PolygonBox[{{5.000105527220487, 0.4375}, {5.0842925895560604`, 
       0.4374999810329408}, {5., 0.375}, {5.000105527220487, 0.4375}}], 
      PolygonBox[{{5., 0.375}, {4.902942858086555, 0.36222218485840063`}, {
       5.000105527220487, 0.4375}, {5., 0.375}}], 
      PolygonBox[{{4.915707410443943, 0.4374999810329408}, {5.000105527220487,
        0.4375}, {4.902942858086555, 0.36222218485840063`}, {
       4.915707410443943, 0.4374999810329408}}], 
      PolygonBox[{{4.902942858086555, 0.36222218485840063`}, {4.8125, 
       0.3247595264191645}, {4.915707410443943, 0.4374999810329408}, {
       4.902942858086555, 0.36222218485840063`}}], 
      PolygonBox[{{4.769748357463745, 0.4373449933535234}, {4.915707410443943,
        0.4374999810329408}, {4.8125, 0.3247595264191645}, {4.769748357463745,
        0.4373449933535234}}], 
      PolygonBox[{{4.8125, 0.3247595264191645}, {4.734834957055044, 
       0.26516504294495535`}, {4.769748357463745, 0.4373449933535234}, {
       4.8125, 0.3247595264191645}}], 
      PolygonBox[{{4.595057255667003, 0.40494274433299715`}, {
       4.769748357463745, 0.4373449933535234}, {4.734834957055044, 
       0.26516504294495535`}, {4.595057255667003, 0.40494274433299715`}}], 
      PolygonBox[{{4.734834957055044, 0.26516504294495535`}, {
       4.6752404735808355`, 0.1875000000000001}, {4.595057255667003, 
       0.40494274433299715`}, {4.734834957055044, 0.26516504294495535`}}], 
      PolygonBox[{{4.562655006646477, 0.2302516425362554}, {4.595057255667003,
        0.40494274433299715`}, {4.6752404735808355`, 0.1875000000000001}, {
       4.562655006646477, 0.2302516425362554}}], 
      PolygonBox[{{4.6752404735808355`, 0.1875000000000001}, {
       4.637777815141599, 0.09705714191344539}, {4.562655006646477, 
       0.2302516425362554}, {4.6752404735808355`, 0.1875000000000001}}], 
      PolygonBox[{{4.562500018967059, 0.08429258955606238}, {
       4.562655006646477, 0.2302516425362554}, {4.637777815141599, 
       0.09705714191344539}, {4.562500018967059, 0.08429258955606238}}], 
      PolygonBox[{{4.637777815141599, 0.09705714191344539}, {4.625, 
       2.1245770866179924`*^-16}, {4.562500018967059, 0.08429258955606238}, {
       4.637777815141599, 0.09705714191344539}}], 
      PolygonBox[{{4.5625, 0.00012317806299537147`}, {4.562500018967059, 
       0.08429258955606238}, {4.625, 2.1245770866179924`*^-16}, {4.5625, 
       0.00012317806299537147`}}], 
      PolygonBox[{{4.625, 2.1245770866179924`*^-16}, {
       4.637777815141599, -0.09705714191344514}, {4.5625, 
       0.00012317806299537147`}, {4.625, 2.1245770866179924`*^-16}}], 
      PolygonBox[{{4.562500018967059, -0.084292589556055}, {4.5625, 
       0.00012317806299537147`}, {4.637777815141599, -0.09705714191344514}, {
       4.562500018967059, -0.084292589556055}}], 
      PolygonBox[{{4.637777815141599, -0.09705714191344514}, {
       4.6752404735808355`, -0.18749999999999978`}, {
       4.562500018967059, -0.084292589556055}, {
       4.637777815141599, -0.09705714191344514}}], 
      PolygonBox[{{4.562655006646477, -0.23025164253625477`}, {
       4.562500018967059, -0.084292589556055}, {
       4.6752404735808355`, -0.18749999999999978`}, {
       4.562655006646477, -0.23025164253625477`}}], 
      PolygonBox[{{4.6752404735808355`, -0.18749999999999978`}, {
       4.734834957055044, -0.2651650429449553}, {
       4.562655006646477, -0.23025164253625477`}, {
       4.6752404735808355`, -0.18749999999999978`}}], 
      PolygonBox[{{4.595057255667003, -0.4049427443329971}, {
       4.562655006646477, -0.23025164253625477`}, {
       4.734834957055044, -0.2651650429449553}, {
       4.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{4.734834957055044, -0.2651650429449553}, {
       4.8125, -0.3247595264191644}, {
       4.595057255667003, -0.4049427443329971}, {
       4.734834957055044, -0.2651650429449553}}], 
      PolygonBox[{{4.769748357463745, -0.4373449933535234}, {
       4.595057255667003, -0.4049427443329971}, {
       4.8125, -0.3247595264191644}, {
       4.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{4.8125, -0.3247595264191644}, {
       4.902942858086554, -0.3622221848584005}, {
       4.769748357463745, -0.4373449933535234}, {
       4.8125, -0.3247595264191644}}], 
      PolygonBox[{{4.915707410443936, -0.4374999810329408}, {
       4.769748357463745, -0.4373449933535234}, {
       4.902942858086554, -0.3622221848584005}, {
       4.915707410443936, -0.4374999810329408}}], 
      PolygonBox[{{4.902942858086554, -0.3622221848584005}, {5., -0.375}, {
       4.915707410443936, -0.4374999810329408}, {
       4.902942858086554, -0.3622221848584005}}], 
      PolygonBox[{{5.000134841831043, -0.4375}, {
       4.915707410443936, -0.4374999810329408}, {5., -0.375}, {
       5.000134841831043, -0.4375}}], 
      PolygonBox[{{5., -0.375}, {5.097057141913445, -0.36222218485840063`}, {
       5.000134841831043, -0.4375}, {5., -0.375}}], 
      PolygonBox[{{5.084292589556053, -0.4374999810329408}, {
       5.000134841831043, -0.4375}, {
       5.097057141913445, -0.36222218485840063`}, {
       5.084292589556053, -0.4374999810329408}}], 
      PolygonBox[{{5.097057141913445, -0.36222218485840063`}, {
       5.1875, -0.3247595264191646}, {
       5.084292589556053, -0.4374999810329408}, {
       5.097057141913445, -0.36222218485840063`}}], 
      PolygonBox[{{5.230251642536254, -0.4373449933535234}, {
       5.084292589556053, -0.4374999810329408}, {
       5.1875, -0.3247595264191646}, {
       5.230251642536254, -0.4373449933535234}}], 
      PolygonBox[{{5.1875, -0.3247595264191646}, {
       5.265165042944956, -0.26516504294495535`}, {
       5.230251642536254, -0.4373449933535234}, {
       5.1875, -0.3247595264191646}}], 
      PolygonBox[{{5.404942744332997, -0.40494274433299715`}, {
       5.230251642536254, -0.4373449933535234}, {
       5.265165042944956, -0.26516504294495535`}, {
       5.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{5.265165042944956, -0.26516504294495535`}, {
       5.265165042944956, -0.2651650429449553}, {
       5.404942744332997, -0.40494274433299715`}, {
       5.265165042944956, -0.26516504294495535`}}], 
      PolygonBox[{{5.404942744332997, -0.4049427443329971}, {
       5.404942744332997, -0.40494274433299715`}, {
       5.265165042944956, -0.2651650429449553}, {
       5.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{5.404942744332997, -0.4049427443329971}, {
       5.437344993353523, -0.23025164253625516`}, {5.5, -0.5}, {
       5.404942744332997, -0.4049427443329971}}], 
      PolygonBox[{{5.5, -0.3576627826493677}, {5.5, -0.5}, {
       5.437344993353523, -0.23025164253625516`}, {
       5.5, -0.3576627826493677}}], 
      PolygonBox[{{5.437344993353523, -0.23025164253625516`}, {
       5.437499981032941, -0.08429258955606181}, {5.5, -0.3576627826493677}, {
       5.437344993353523, -0.23025164253625516`}}], 
      PolygonBox[{{5.5, -0.20590900530173997`}, {5.5, -0.3576627826493677}, {
       5.437499981032941, -0.08429258955606181}, {
       5.5, -0.20590900530173997`}}], 
      PolygonBox[{{5.437499981032941, -0.08429258955606181}, {5.4375, 0.}, {
       5.5, -0.20590900530173997`}, {
       5.437499981032941, -0.08429258955606181}}], 
      PolygonBox[{{5.5, 0.}, {5.5, -0.20590900530173997`}, {5.4375, 0.}, {5.5,
        0.}}], PolygonBox[{{5.4375, 0.}, {5.437499981032941, 
       0.08429258955606177}, {5.5, 0.}, {5.4375, 0.}}], 
      PolygonBox[{{5.5, 0.20590900530173992`}, {5.5, 0.}, {5.437499981032941, 
       0.08429258955606177}, {5.5, 0.20590900530173992`}}], 
      PolygonBox[{{5.437499981032941, 0.08429258955606177}, {
       5.437344993353523, 0.23025164253625502`}, {5.5, 
       0.20590900530173992`}, {5.437499981032941, 0.08429258955606177}}], 
      PolygonBox[{{5.5, 0.35766278264936757`}, {5.5, 0.20590900530173992`}, {
       5.437344993353523, 0.23025164253625502`}, {5.5, 
       0.35766278264936757`}}], 
      PolygonBox[{{5.437344993353523, 0.23025164253625502`}, {
       5.404942744332997, 0.40494274433299715`}, {5.5, 
       0.35766278264936757`}, {5.437344993353523, 0.23025164253625502`}}], 
      PolygonBox[{{5.491446564961186, 0.491446564961186}, {5.5, 
       0.35766278264936757`}, {5.404942744332997, 0.40494274433299715`}, {
       5.491446564961186, 0.491446564961186}}], 
      PolygonBox[{{5.404942744332997, 0.40494274433299715`}, {
       5.230251642536255, 0.4373449933535234}, {5.491446564961186, 
       0.491446564961186}, {5.404942744332997, 0.40494274433299715`}}], 
      PolygonBox[{{5.357662782649368, 0.5}, {5.491446564961186, 
       0.491446564961186}, {5.230251642536255, 0.4373449933535234}, {
       5.357662782649368, 0.5}}], 
      PolygonBox[{{5.230251642536255, 0.4373449933535234}, {
       5.0842925895560604`, 0.4374999810329408}, {5.357662782649368, 0.5}, {
       5.230251642536255, 0.4373449933535234}}], 
      PolygonBox[{{5.205909005373256, 0.5}, {5.357662782649368, 0.5}, {
       5.0842925895560604`, 0.4374999810329408}, {5.205909005373256, 0.5}}], 
      PolygonBox[{{5.0842925895560604`, 0.4374999810329408}, {
       5.000105527220487, 0.4375}, {5.205909005373256, 0.5}, {
       5.0842925895560604`, 0.4374999810329408}}], 
      PolygonBox[{{5.07794195802689, 0.5}, {5.205909005373256, 0.5}, {
       5.000105527220487, 0.4375}, {5.07794195802689, 0.5}}], 
      PolygonBox[{{5.000105527220487, 0.4375}, {4.915707410443943, 
       0.4374999810329408}, {5.07794195802689, 0.5}, {5.000105527220487, 
       0.4375}}], 
      PolygonBox[{{4.794090994695554, 0.5}, {5.07794195802689, 0.5}, {
       4.915707410443943, 0.4374999810329408}, {4.794090994695554, 0.5}}], 
      PolygonBox[{{4.915707410443943, 0.4374999810329408}, {4.769748357463745,
        0.4373449933535234}, {4.794090994695554, 0.5}, {4.915707410443943, 
       0.4374999810329408}}], 
      PolygonBox[{{4.642337217350634, 0.5}, {4.794090994695554, 0.5}, {
       4.769748357463745, 0.4373449933535234}, {4.642337217350634, 0.5}}], 
      PolygonBox[{{4.769748357463745, 0.4373449933535234}, {4.595057255667003,
        0.40494274433299715`}, {4.642337217350634, 0.5}, {4.769748357463745, 
       0.4373449933535234}}], 
      PolygonBox[{{5.5, 0.5}, {4.642337217350634, 0.5}, {4.595057255667003, 
       0.40494274433299715`}, {5.5, 0.5}}], 
      PolygonBox[{{4.595057255667003, 0.40494274433299715`}, {
       4.562655006646477, 0.2302516425362554}, {5.5, 0.5}, {4.595057255667003,
        0.40494274433299715`}}], 
      PolygonBox[{{4.5, 0.357662782649369}, {5.5, 0.5}, {4.562655006646477, 
       0.2302516425362554}, {4.5, 0.357662782649369}}], 
      PolygonBox[{{4.562655006646477, 0.2302516425362554}, {4.562500018967059,
        0.08429258955606238}, {4.5, 0.357662782649369}, {4.562655006646477, 
       0.2302516425362554}}], 
      PolygonBox[{{4.5, 0.20590900528289896`}, {4.5, 0.357662782649369}, {
       4.562500018967059, 0.08429258955606238}, {4.5, 0.20590900528289896`}}],
       PolygonBox[{{4.562500018967059, 0.08429258955606238}, {4.5625, 
       0.00012317806299537147`}, {4.5, 0.20590900528289896`}, {
       4.562500018967059, 0.08429258955606238}}], 
      PolygonBox[{{4.5, 0.08067866675870025}, {4.5, 0.20590900528289896`}, {
       4.5625, 0.00012317806299537147`}, {4.5, 0.08067866675870025}}], 
      PolygonBox[{{4.5625, 0.00012317806299537147`}, {
       4.562500018967059, -0.084292589556055}, {4.5, 0.08067866675870025}, {
       4.5625, 0.00012317806299537147`}}], 
      PolygonBox[{{4.5, -0.20590900514527852`}, {4.5, 0.08067866675870025}, {
       4.562500018967059, -0.084292589556055}, {4.5, -0.20590900514527852`}}],
       PolygonBox[{{4.562500018967059, -0.084292589556055}, {
       4.562655006646477, -0.23025164253625477`}, {
       4.5, -0.20590900514527852`}, {4.562500018967059, -0.084292589556055}}],
       PolygonBox[{{4.5, -0.35766278264936535`}, {
       4.5, -0.20590900514527852`}, {
       4.562655006646477, -0.23025164253625477`}, {
       4.5, -0.35766278264936535`}}], 
      PolygonBox[{{4.562655006646477, -0.23025164253625477`}, {
       4.595057255667003, -0.4049427443329971}, {
       4.5, -0.35766278264936535`}, {
       4.562655006646477, -0.23025164253625477`}}], 
      PolygonBox[{{4.5, 0.5}, {4.5, -0.35766278264936535`}, {
       4.595057255667003, -0.4049427443329971}, {4.5, 0.5}}], 
      PolygonBox[{{4.595057255667003, -0.4049427443329971}, {
       4.769748357463745, -0.4373449933535234}, {4.5, 0.5}, {
       4.595057255667003, -0.4049427443329971}}], 
      PolygonBox[{{4.5, -0.5}, {4.5, 0.5}, {
       4.769748357463745, -0.4373449933535234}, {4.5, -0.5}}], 
      PolygonBox[{{4.769748357463745, -0.4373449933535234}, {
       4.915707410443936, -0.4374999810329408}, {4.5, -0.5}, {
       4.769748357463745, -0.4373449933535234}}], 
      PolygonBox[{{4.794090994433172, -0.5}, {4.5, -0.5}, {
       4.915707410443936, -0.4374999810329408}, {4.794090994433172, -0.5}}], 
      PolygonBox[{{4.915707410443936, -0.4374999810329408}, {
       5.000134841831043, -0.4375}, {4.794090994433172, -0.5}, {
       4.915707410443936, -0.4374999810329408}}], 
      PolygonBox[{{5.082323870401062, -0.5}, {4.794090994433172, -0.5}, {
       5.000134841831043, -0.4375}, {5.082323870401062, -0.5}}], 
      PolygonBox[{{5.000134841831043, -0.4375}, {
       5.084292589556053, -0.4374999810329408}, {5.082323870401062, -0.5}, {
       5.000134841831043, -0.4375}}], 
      PolygonBox[{{5.205909005360398, -0.5}, {5.082323870401062, -0.5}, {
       5.084292589556053, -0.4374999810329408}, {5.205909005360398, -0.5}}], 
      PolygonBox[{{5.084292589556053, -0.4374999810329408}, {
       5.230251642536254, -0.4373449933535234}, {5.205909005360398, -0.5}, {
       5.084292589556053, -0.4374999810329408}}], 
      PolygonBox[{{5.3576627826493715`, -0.5}, {5.205909005360398, -0.5}, {
       5.230251642536254, -0.4373449933535234}, {5.3576627826493715`, -0.5}}],
       PolygonBox[{{5.230251642536254, -0.4373449933535234}, {
       5.404942744332997, -0.40494274433299715`}, {
       5.3576627826493715`, -0.5}, {5.230251642536254, -0.4373449933535234}}],
       PolygonBox[{{5.5, -0.5}, {5.3576627826493715`, -0.5}, {
       5.404942744332997, -0.40494274433299715`}, {5.5, -0.5}}], 
      PolygonBox[{{5.404942744332997, -0.40494274433299715`}, {
       5.404942744332997, -0.4049427443329971}, {5.5, -0.5}, {
       5.404942744332997, -0.40494274433299715`}}], 
      PolygonBox[{{5.5, -0.5}, {5.5, -0.5}, {
       5.404942744332997, -0.4049427443329971}, {
       5.5, -0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, 1.}, {4.520833333333333, 1.}, {4.541666666666667, 1.}, {
       4.5625, 1.}, {4.583333333333333, 1.}, {4.604166666666667, 1.}, {4.625, 
       1.}, {4.625, 1.}, {4.604166666666667, 1.}, {4.583333333333333, 1.}, {
       4.5625, 1.}, {4.541666666666667, 1.}, {4.520833333333333, 1.}, {4.5, 
       1.}, {4.5, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, 1.}, {5.395833333333333, 1.}, {5.416666666666667, 
       1.}, {5.4375, 1.}, {5.458333333333333, 1.}, {5.479166666666667, 1.}, {
       5.5, 1.}, {5.5, 1.}, {5.479166666666667, 1.}, {5.458333333333333, 
       1.}, {5.4375, 1.}, {5.416666666666667, 1.}, {5.395833333333333, 1.}, {
       5.375, 1.}, {5.375, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 0.5}, {5., 0.5208333333333333}, {5., 
       0.5416666666666667}, {5., 0.5625}, {5., 0.5833333333333333}, {5., 
       0.6041666666666666}, {5., 0.625}, {5., 0.625}, {5., 
       0.6041666666666667}, {5., 0.5833333333333333}, {5., 0.5625}, {5., 
       0.5416666666666667}, {5., 0.5208333333333334}, {5., 0.5}, {5., 0.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 1.375}, {5., 1.3958333333333333`}, {5., 
       1.4166666666666667`}, {5., 1.4375}, {5., 1.4583333333333333`}, {5., 
       1.4791666666666665`}, {5., 1.5}, {5., 1.5}, {5., 
       1.4791666666666667`}, {5., 1.4583333333333333`}, {5., 1.4375}, {5., 
       1.4166666666666667`}, {5., 1.3958333333333335`}, {5., 1.375}, {5., 
       1.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, 1.}, {4.75, 1.}, {4.875, 1.}, {5., 1.}, {5.125, 1.}, {
       5.25, 1.}, {5.375, 1.}, {5.375, 1.}, {5.25, 1.}, {5.125, 1.}, {5., 
       1.}, {4.875, 1.}, {4.75, 1.}, {4.625, 1.}, {4.625, 1.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 0.625}, {5., 0.75}, {5., 0.875}, {5., 1.}, {5., 1.125}, {
       5., 1.25}, {5., 1.375}, {5., 1.375}, {5., 1.25}, {5., 1.125}, {5., 
       1.}, {5., 0.875}, {5., 0.75}, {5., 0.625}, {5., 0.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4Qxgf7rxnh8a+KRB3mnVA91d370X6G8pND
vT4w+c/2576dzWnnF3Uwu22+Wdbuiz1Y+ICIQ0LfBG5zo6/26kWdn5KSRRyu
LI6tXXn6K0SeQQSq/5v9zd4y3rlzhFHlHYTh+o04jSZXfBCCm59xR9q2aLMQ
3H7u6SsWiPYKwd0HcT9M/gNc/ljeluwXT97A9TOC5V/BzZ/iOWHmkebncPsd
H997MXH2U/sbUPdF7nBhXZvxBM39T+D+i0CWB/rfHqofFj6ToebDwu/ffxB4
CQ/fQ1D3wcIfLP3/vT0AUEqZaQ==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhD6h30oGIjC+atXgYAInA+hRdDUC6OpF0JT
T5gfBjbnK5wPMecTmvoPaPKv0PQ/RVP/AIOP6r4HaO5/gOa/B2j+f4AWPjD1
YgT5oSjuE3NYheJ+mPoPaPKf0PR/RVP/wx4Ak5tblg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, 0.7348349570550448}, {
       5.3247595264191645`, 0.8125}, {5.404942744332997, 
       0.5950572556670028}, {5.265165042944956, 0.7348349570550448}}], 
      PolygonBox[{{5.437344993353523, 0.7697483574637448}, {5.404942744332997,
        0.5950572556670028}, {5.3247595264191645`, 0.8125}, {
       5.437344993353523, 0.7697483574637448}}], 
      PolygonBox[{{5.3247595264191645`, 0.8125}, {5.362222184858401, 
       0.9029428580865547}, {5.437344993353523, 0.7697483574637448}, {
       5.3247595264191645`, 0.8125}}], 
      PolygonBox[{{5.437499981032941, 0.9157074104439382}, {5.437344993353523,
        0.7697483574637448}, {5.362222184858401, 0.9029428580865547}, {
       5.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{5.362222184858401, 0.9029428580865547}, {5.375, 1.}, {
       5.437499981032941, 0.9157074104439382}, {5.362222184858401, 
       0.9029428580865547}}], 
      PolygonBox[{{5.4375, 1.}, {5.437499981032941, 0.9157074104439382}, {
       5.375, 1.}, {5.4375, 1.}}], 
      PolygonBox[{{5.375, 1.}, {5.362222184858401, 1.0970571419134452`}, {
       5.4375, 1.}, {5.375, 1.}}], 
      PolygonBox[{{5.437499981032941, 1.0842925895560618`}, {5.4375, 1.}, {
       5.362222184858401, 1.0970571419134452`}, {5.437499981032941, 
       1.0842925895560618`}}], 
      PolygonBox[{{5.362222184858401, 1.0970571419134452`}, {
       5.3247595264191645`, 1.1875}, {5.437499981032941, 
       1.0842925895560618`}, {5.362222184858401, 1.0970571419134452`}}], 
      PolygonBox[{{5.437344993353523, 1.230251642536255}, {5.437499981032941, 
       1.0842925895560618`}, {5.3247595264191645`, 1.1875}, {
       5.437344993353523, 1.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, 1.1875}, {5.265165042944956, 
       1.2651650429449552`}, {5.437344993353523, 1.230251642536255}, {
       5.3247595264191645`, 1.1875}}], 
      PolygonBox[{{5.404942744332997, 1.4049427443329972`}, {
       5.437344993353523, 1.230251642536255}, {5.265165042944956, 
       1.2651650429449552`}, {5.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{5.265165042944956, 1.2651650429449552`}, {5.1875, 
       1.3247595264191645`}, {5.404942744332997, 1.4049427443329972`}, {
       5.265165042944956, 1.2651650429449552`}}], 
      PolygonBox[{{5.230251642536255, 1.4373449933535234`}, {
       5.404942744332997, 1.4049427443329972`}, {5.1875, 
       1.3247595264191645`}, {5.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{5.1875, 1.3247595264191645`}, {5.097057141913445, 
       1.3622221848584006`}, {5.230251642536255, 1.4373449933535234`}, {
       5.1875, 1.3247595264191645`}}], 
      PolygonBox[{{5.0842925895560604`, 1.4374999810329407`}, {
       5.230251642536255, 1.4373449933535234`}, {5.097057141913445, 
       1.3622221848584006`}, {5.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{5.097057141913445, 1.3622221848584006`}, {5., 1.375}, {
       5.0842925895560604`, 1.4374999810329407`}, {5.097057141913445, 
       1.3622221848584006`}}], 
      PolygonBox[{{5.000105527220487, 1.4375}, {5.0842925895560604`, 
       1.4374999810329407`}, {5., 1.375}, {5.000105527220487, 1.4375}}], 
      PolygonBox[{{5., 1.375}, {4.902942858086555, 1.3622221848584006`}, {
       5.000105527220487, 1.4375}, {5., 1.375}}], 
      PolygonBox[{{4.915707410443943, 1.4374999810329407`}, {
       5.000105527220487, 1.4375}, {4.902942858086555, 1.3622221848584006`}, {
       4.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{4.902942858086555, 1.3622221848584006`}, {4.8125, 
       1.3247595264191645`}, {4.915707410443943, 1.4374999810329407`}, {
       4.902942858086555, 1.3622221848584006`}}], 
      PolygonBox[{{4.769748357463745, 1.4373449933535234`}, {
       4.915707410443943, 1.4374999810329407`}, {4.8125, 
       1.3247595264191645`}, {4.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{4.8125, 1.3247595264191645`}, {4.734834957055044, 
       1.2651650429449552`}, {4.769748357463745, 1.4373449933535234`}, {
       4.8125, 1.3247595264191645`}}], 
      PolygonBox[{{4.595057255667003, 1.4049427443329972`}, {
       4.769748357463745, 1.4373449933535234`}, {4.734834957055044, 
       1.2651650429449552`}, {4.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{4.734834957055044, 1.2651650429449552`}, {
       4.6752404735808355`, 1.1875}, {4.595057255667003, 
       1.4049427443329972`}, {4.734834957055044, 1.2651650429449552`}}], 
      PolygonBox[{{4.562655006646477, 1.2302516425362553`}, {
       4.595057255667003, 1.4049427443329972`}, {4.6752404735808355`, 
       1.1875}, {4.562655006646477, 1.2302516425362553`}}], 
      PolygonBox[{{4.6752404735808355`, 1.1875}, {4.637777815141599, 
       1.0970571419134454`}, {4.562655006646477, 1.2302516425362553`}, {
       4.6752404735808355`, 1.1875}}], 
      PolygonBox[{{4.562500018967059, 1.0842925895560624`}, {
       4.562655006646477, 1.2302516425362553`}, {4.637777815141599, 
       1.0970571419134454`}, {4.562500018967059, 1.0842925895560624`}}], 
      PolygonBox[{{4.637777815141599, 1.0970571419134454`}, {4.625, 
       1.0000000000000002`}, {4.562500018967059, 1.0842925895560624`}, {
       4.637777815141599, 1.0970571419134454`}}], 
      PolygonBox[{{4.5625, 1.0001231780629953`}, {4.562500018967059, 
       1.0842925895560624`}, {4.625, 1.0000000000000002`}, {4.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{4.625, 1.0000000000000002`}, {4.637777815141599, 
       0.9029428580865548}, {4.5625, 1.0001231780629953`}, {4.625, 
       1.0000000000000002`}}], 
      PolygonBox[{{4.562500018967059, 0.915707410443945}, {4.5625, 
       1.0001231780629953`}, {4.637777815141599, 0.9029428580865548}, {
       4.562500018967059, 0.915707410443945}}], 
      PolygonBox[{{4.637777815141599, 0.9029428580865548}, {
       4.6752404735808355`, 0.8125000000000002}, {4.562500018967059, 
       0.915707410443945}, {4.637777815141599, 0.9029428580865548}}], 
      PolygonBox[{{4.562655006646477, 0.7697483574637453}, {4.562500018967059,
        0.915707410443945}, {4.6752404735808355`, 0.8125000000000002}, {
       4.562655006646477, 0.7697483574637453}}], 
      PolygonBox[{{4.6752404735808355`, 0.8125000000000002}, {
       4.734834957055044, 0.7348349570550448}, {4.562655006646477, 
       0.7697483574637453}, {4.6752404735808355`, 0.8125000000000002}}], 
      PolygonBox[{{4.595057255667003, 0.5950572556670028}, {4.562655006646477,
        0.7697483574637453}, {4.734834957055044, 0.7348349570550448}, {
       4.595057255667003, 0.5950572556670028}}], 
      PolygonBox[{{4.734834957055044, 0.7348349570550448}, {4.8125, 
       0.6752404735808356}, {4.595057255667003, 0.5950572556670028}, {
       4.734834957055044, 0.7348349570550448}}], 
      PolygonBox[{{4.769748357463745, 0.5626550066464766}, {4.595057255667003,
        0.5950572556670028}, {4.8125, 0.6752404735808356}, {4.769748357463745,
        0.5626550066464766}}], 
      PolygonBox[{{4.8125, 0.6752404735808356}, {4.902942858086554, 
       0.6377778151415995}, {4.769748357463745, 0.5626550066464766}, {4.8125, 
       0.6752404735808356}}], 
      PolygonBox[{{4.915707410443936, 0.5625000189670593}, {4.769748357463745,
        0.5626550066464766}, {4.902942858086554, 0.6377778151415995}, {
       4.915707410443936, 0.5625000189670593}}], 
      PolygonBox[{{4.902942858086554, 0.6377778151415995}, {5., 0.625}, {
       4.915707410443936, 0.5625000189670593}, {4.902942858086554, 
       0.6377778151415995}}], 
      PolygonBox[{{5.000134841831043, 0.5625}, {4.915707410443936, 
       0.5625000189670593}, {5., 0.625}, {5.000134841831043, 0.5625}}], 
      PolygonBox[{{5., 0.625}, {5.097057141913445, 0.6377778151415994}, {
       5.000134841831043, 0.5625}, {5., 0.625}}], 
      PolygonBox[{{5.084292589556053, 0.5625000189670593}, {5.000134841831043,
        0.5625}, {5.097057141913445, 0.6377778151415994}, {5.084292589556053, 
       0.5625000189670593}}], 
      PolygonBox[{{5.097057141913445, 0.6377778151415994}, {5.1875, 
       0.6752404735808354}, {5.084292589556053, 0.5625000189670593}, {
       5.097057141913445, 0.6377778151415994}}], 
      PolygonBox[{{5.230251642536254, 0.5626550066464766}, {5.084292589556053,
        0.5625000189670593}, {5.1875, 0.6752404735808354}, {5.230251642536254,
        0.5626550066464766}}], 
      PolygonBox[{{5.1875, 0.6752404735808354}, {5.265165042944956, 
       0.7348349570550446}, {5.230251642536254, 0.5626550066464766}, {5.1875, 
       0.6752404735808354}}], 
      PolygonBox[{{5.404942744332997, 0.5950572556670028}, {5.230251642536254,
        0.5626550066464766}, {5.265165042944956, 0.7348349570550446}, {
       5.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{5.265165042944956, 0.7348349570550446}, {5.265165042944956,
        0.7348349570550448}, {5.404942744332997, 0.5950572556670028}, {
       5.265165042944956, 0.7348349570550446}}], 
      PolygonBox[{{5.404942744332997, 0.5950572556670028}, {5.404942744332997,
        0.5950572556670028}, {5.265165042944956, 0.7348349570550448}, {
       5.404942744332997, 0.5950572556670028}}], 
      PolygonBox[{{5.404942744332997, 0.5950572556670028}, {5.437344993353523,
        0.7697483574637448}, {5.5, 0.5}, {5.404942744332997, 
       0.5950572556670028}}], 
      PolygonBox[{{5.5, 0.6423372173506323}, {5.5, 0.5}, {5.437344993353523, 
       0.7697483574637448}, {5.5, 0.6423372173506323}}], 
      PolygonBox[{{5.437344993353523, 0.7697483574637448}, {5.437499981032941,
        0.9157074104439382}, {5.5, 0.6423372173506323}, {5.437344993353523, 
       0.7697483574637448}}], 
      PolygonBox[{{5.5, 0.79409099469826}, {5.5, 0.6423372173506323}, {
       5.437499981032941, 0.9157074104439382}, {5.5, 0.79409099469826}}], 
      PolygonBox[{{5.437499981032941, 0.9157074104439382}, {5.4375, 1.}, {5.5,
        0.79409099469826}, {5.437499981032941, 0.9157074104439382}}], 
      PolygonBox[{{5.5, 1.}, {5.5, 0.79409099469826}, {5.4375, 1.}, {5.5, 
       1.}}], PolygonBox[{{5.4375, 1.}, {5.437499981032941, 
       1.0842925895560618`}, {5.5, 1.}, {5.4375, 1.}}], 
      PolygonBox[{{5.5, 1.2059090053017398`}, {5.5, 1.}, {5.437499981032941, 
       1.0842925895560618`}, {5.5, 1.2059090053017398`}}], 
      PolygonBox[{{5.437499981032941, 1.0842925895560618`}, {
       5.437344993353523, 1.230251642536255}, {5.5, 1.2059090053017398`}, {
       5.437499981032941, 1.0842925895560618`}}], 
      PolygonBox[{{5.5, 1.3576627826493675`}, {5.5, 1.2059090053017398`}, {
       5.437344993353523, 1.230251642536255}, {5.5, 1.3576627826493675`}}], 
      PolygonBox[{{5.437344993353523, 1.230251642536255}, {5.404942744332997, 
       1.4049427443329972`}, {5.5, 1.3576627826493675`}, {5.437344993353523, 
       1.230251642536255}}], 
      PolygonBox[{{5.491446564961186, 1.491446564961186}, {5.5, 
       1.3576627826493675`}, {5.404942744332997, 1.4049427443329972`}, {
       5.491446564961186, 1.491446564961186}}], 
      PolygonBox[{{5.404942744332997, 1.4049427443329972`}, {
       5.230251642536255, 1.4373449933535234`}, {5.491446564961186, 
       1.491446564961186}, {5.404942744332997, 1.4049427443329972`}}], 
      PolygonBox[{{5.357662782649368, 1.5}, {5.491446564961186, 
       1.491446564961186}, {5.230251642536255, 1.4373449933535234`}, {
       5.357662782649368, 1.5}}], 
      PolygonBox[{{5.230251642536255, 1.4373449933535234`}, {
       5.0842925895560604`, 1.4374999810329407`}, {5.357662782649368, 1.5}, {
       5.230251642536255, 1.4373449933535234`}}], 
      PolygonBox[{{5.205909005373256, 1.5}, {5.357662782649368, 1.5}, {
       5.0842925895560604`, 1.4374999810329407`}, {5.205909005373256, 1.5}}], 
      PolygonBox[{{5.0842925895560604`, 1.4374999810329407`}, {
       5.000105527220487, 1.4375}, {5.205909005373256, 1.5}, {
       5.0842925895560604`, 1.4374999810329407`}}], 
      PolygonBox[{{5.07794195802689, 1.5}, {5.205909005373256, 1.5}, {
       5.000105527220487, 1.4375}, {5.07794195802689, 1.5}}], 
      PolygonBox[{{5.000105527220487, 1.4375}, {4.915707410443943, 
       1.4374999810329407`}, {5.07794195802689, 1.5}, {5.000105527220487, 
       1.4375}}], 
      PolygonBox[{{4.794090994695554, 1.5}, {5.07794195802689, 1.5}, {
       4.915707410443943, 1.4374999810329407`}, {4.794090994695554, 1.5}}], 
      PolygonBox[{{4.915707410443943, 1.4374999810329407`}, {
       4.769748357463745, 1.4373449933535234`}, {4.794090994695554, 1.5}, {
       4.915707410443943, 1.4374999810329407`}}], 
      PolygonBox[{{4.642337217350634, 1.5}, {4.794090994695554, 1.5}, {
       4.769748357463745, 1.4373449933535234`}, {4.642337217350634, 1.5}}], 
      PolygonBox[{{4.769748357463745, 1.4373449933535234`}, {
       4.595057255667003, 1.4049427443329972`}, {4.642337217350634, 1.5}, {
       4.769748357463745, 1.4373449933535234`}}], 
      PolygonBox[{{5.5, 1.5}, {4.642337217350634, 1.5}, {4.595057255667003, 
       1.4049427443329972`}, {5.5, 1.5}}], 
      PolygonBox[{{4.595057255667003, 1.4049427443329972`}, {
       4.562655006646477, 1.2302516425362553`}, {5.5, 1.5}, {
       4.595057255667003, 1.4049427443329972`}}], 
      PolygonBox[{{4.5, 1.357662782649369}, {5.5, 1.5}, {4.562655006646477, 
       1.2302516425362553`}, {4.5, 1.357662782649369}}], 
      PolygonBox[{{4.562655006646477, 1.2302516425362553`}, {
       4.562500018967059, 1.0842925895560624`}, {4.5, 1.357662782649369}, {
       4.562655006646477, 1.2302516425362553`}}], 
      PolygonBox[{{4.5, 1.205909005282899}, {4.5, 1.357662782649369}, {
       4.562500018967059, 1.0842925895560624`}, {4.5, 1.205909005282899}}], 
      PolygonBox[{{4.562500018967059, 1.0842925895560624`}, {4.5625, 
       1.0001231780629953`}, {4.5, 1.205909005282899}, {4.562500018967059, 
       1.0842925895560624`}}], 
      PolygonBox[{{4.5, 1.0806786667587003`}, {4.5, 1.205909005282899}, {
       4.5625, 1.0001231780629953`}, {4.5, 1.0806786667587003`}}], 
      PolygonBox[{{4.5625, 1.0001231780629953`}, {4.562500018967059, 
       0.915707410443945}, {4.5, 1.0806786667587003`}, {4.5625, 
       1.0001231780629953`}}], 
      PolygonBox[{{4.5, 0.7940909948547215}, {4.5, 1.0806786667587003`}, {
       4.562500018967059, 0.915707410443945}, {4.5, 0.7940909948547215}}], 
      PolygonBox[{{4.562500018967059, 0.915707410443945}, {4.562655006646477, 
       0.7697483574637453}, {4.5, 0.7940909948547215}, {4.562500018967059, 
       0.915707410443945}}], 
      PolygonBox[{{4.5, 0.6423372173506346}, {4.5, 0.7940909948547215}, {
       4.562655006646477, 0.7697483574637453}, {4.5, 0.6423372173506346}}], 
      PolygonBox[{{4.562655006646477, 0.7697483574637453}, {4.595057255667003,
        0.5950572556670028}, {4.5, 0.6423372173506346}, {4.562655006646477, 
       0.7697483574637453}}], 
      PolygonBox[{{4.5, 1.5}, {4.5, 0.6423372173506346}, {4.595057255667003, 
       0.5950572556670028}, {4.5, 1.5}}], 
      PolygonBox[{{4.595057255667003, 0.5950572556670028}, {4.769748357463745,
        0.5626550066464766}, {4.5, 1.5}, {4.595057255667003, 
       0.5950572556670028}}], 
      PolygonBox[{{4.5, 0.5}, {4.5, 1.5}, {4.769748357463745, 
       0.5626550066464766}, {4.5, 0.5}}], 
      PolygonBox[{{4.769748357463745, 0.5626550066464766}, {4.915707410443936,
        0.5625000189670593}, {4.5, 0.5}, {4.769748357463745, 
       0.5626550066464766}}], 
      PolygonBox[{{4.794090994433172, 0.5}, {4.5, 0.5}, {4.915707410443936, 
       0.5625000189670593}, {4.794090994433172, 0.5}}], 
      PolygonBox[{{4.915707410443936, 0.5625000189670593}, {5.000134841831043,
        0.5625}, {4.794090994433172, 0.5}, {4.915707410443936, 
       0.5625000189670593}}], 
      PolygonBox[{{5.082323870401062, 0.5}, {4.794090994433172, 0.5}, {
       5.000134841831043, 0.5625}, {5.082323870401062, 0.5}}], 
      PolygonBox[{{5.000134841831043, 0.5625}, {5.084292589556053, 
       0.5625000189670593}, {5.082323870401062, 0.5}, {5.000134841831043, 
       0.5625}}], 
      PolygonBox[{{5.205909005360398, 0.5}, {5.082323870401062, 0.5}, {
       5.084292589556053, 0.5625000189670593}, {5.205909005360398, 0.5}}], 
      PolygonBox[{{5.084292589556053, 0.5625000189670593}, {5.230251642536254,
        0.5626550066464766}, {5.205909005360398, 0.5}, {5.084292589556053, 
       0.5625000189670593}}], 
      PolygonBox[{{5.3576627826493715`, 0.5}, {5.205909005360398, 0.5}, {
       5.230251642536254, 0.5626550066464766}, {5.3576627826493715`, 0.5}}], 
      PolygonBox[{{5.230251642536254, 0.5626550066464766}, {5.404942744332997,
        0.5950572556670028}, {5.3576627826493715`, 0.5}, {5.230251642536254, 
       0.5626550066464766}}], 
      PolygonBox[{{5.5, 0.5}, {5.3576627826493715`, 0.5}, {5.404942744332997, 
       0.5950572556670028}, {5.5, 0.5}}], 
      PolygonBox[{{5.404942744332997, 0.5950572556670028}, {5.404942744332997,
        0.5950572556670028}, {5.5, 0.5}, {5.404942744332997, 
       0.5950572556670028}}], 
      PolygonBox[{{5.5, 0.5}, {5.5, 0.5}, {5.404942744332997, 
       0.5950572556670028}, {5.5, 0.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, 2.}, {4.520833333333333, 2.}, {4.541666666666667, 2.}, {
       4.5625, 2.}, {4.583333333333333, 2.}, {4.604166666666667, 2.}, {4.625, 
       2.}, {4.625, 2.}, {4.604166666666667, 2.}, {4.583333333333333, 2.}, {
       4.5625, 2.}, {4.541666666666667, 2.}, {4.520833333333333, 2.}, {4.5, 
       2.}, {4.5, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, 2.}, {5.395833333333333, 2.}, {5.416666666666667, 
       2.}, {5.4375, 2.}, {5.458333333333333, 2.}, {5.479166666666667, 2.}, {
       5.5, 2.}, {5.5, 2.}, {5.479166666666667, 2.}, {5.458333333333333, 
       2.}, {5.4375, 2.}, {5.416666666666667, 2.}, {5.395833333333333, 2.}, {
       5.375, 2.}, {5.375, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 1.5}, {5., 1.5208333333333333`}, {5., 
       1.5416666666666667`}, {5., 1.5625}, {5., 1.5833333333333333`}, {5., 
       1.6041666666666665`}, {5., 1.625}, {5., 1.625}, {5., 
       1.6041666666666667`}, {5., 1.5833333333333333`}, {5., 1.5625}, {5., 
       1.5416666666666667`}, {5., 1.5208333333333335`}, {5., 1.5}, {5., 
       1.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 2.375}, {5., 2.3958333333333335`}, {5., 
       2.4166666666666665`}, {5., 2.4375}, {5., 2.4583333333333335`}, {5., 
       2.4791666666666665`}, {5., 2.5}, {5., 2.5}, {5., 
       2.4791666666666665`}, {5., 2.4583333333333335`}, {5., 2.4375}, {5., 
       2.4166666666666665`}, {5., 2.3958333333333335`}, {5., 2.375}, {5., 
       2.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, 2.}, {4.75, 2.}, {4.875, 2.}, {5., 2.}, {5.125, 2.}, {
       5.25, 2.}, {5.375, 2.}, {5.375, 2.}, {5.25, 2.}, {5.125, 2.}, {5., 
       2.}, {4.875, 2.}, {4.75, 2.}, {4.625, 2.}, {4.625, 2.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 1.625}, {5., 1.75}, {5., 1.875}, {5., 2.}, {5., 2.125}, {
       5., 2.25}, {5., 2.375}, {5., 2.375}, {5., 2.25}, {5., 2.125}, {5., 
       2.}, {5., 1.875}, {5., 1.75}, {5., 1.625}, {5., 1.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog5QlsPXjPD4V0WiDv5PhJ4ePcbgMEP5yaFe
H6h8A6PDuW9nc9r5RR1mv519k0+eCSJ+QMTBwP1Eq/RMJgf1os5PSckiDq8u
rtt35SlUnkEESjM73Owt4507RxhV3kEYrt+I02hyxQchuPkZd6RtizYLwe3n
nr5igWivENx9EHEhuPth8snmt0xLiv7Zo+hn+GsPM/+UygmfRwd/28PsX1CY
/+XE2V/2N6Du04lZ1BRm8sse1f2/7GH+Q5EH+h+mHxY+MPNh4fcfDP7Yw8I3
Eeo+9PAHANutiqU=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhCaxSEUDETh/NWrQEAEzofQImjqhdHUC6Gp
J8yH6GOC8yHmMqKpZ4Dzw8Dyf+1R9f+yR1X/A4OP6r4f9qjuh6kXQVMvgqZe
FE29GEH+KhT3iUH99xdNPcx/Ymj+h+lnckBVz+IAAIQITpA=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, 1.7348349570550448`}, {
       5.3247595264191645`, 1.8125}, {5.404942744332997, 
       1.5950572556670028`}, {5.265165042944956, 1.7348349570550448`}}], 
      PolygonBox[{{5.437344993353523, 1.769748357463745}, {5.404942744332997, 
       1.5950572556670028`}, {5.3247595264191645`, 1.8125}, {
       5.437344993353523, 1.769748357463745}}], 
      PolygonBox[{{5.3247595264191645`, 1.8125}, {5.362222184858401, 
       1.9029428580865546`}, {5.437344993353523, 1.769748357463745}, {
       5.3247595264191645`, 1.8125}}], 
      PolygonBox[{{5.437499981032941, 1.9157074104439382`}, {
       5.437344993353523, 1.769748357463745}, {5.362222184858401, 
       1.9029428580865546`}, {5.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{5.362222184858401, 1.9029428580865546`}, {5.375, 2.}, {
       5.437499981032941, 1.9157074104439382`}, {5.362222184858401, 
       1.9029428580865546`}}], 
      PolygonBox[{{5.4375, 2.}, {5.437499981032941, 1.9157074104439382`}, {
       5.375, 2.}, {5.4375, 2.}}], 
      PolygonBox[{{5.375, 2.}, {5.362222184858401, 2.0970571419134454`}, {
       5.4375, 2.}, {5.375, 2.}}], 
      PolygonBox[{{5.437499981032941, 2.084292589556062}, {5.4375, 2.}, {
       5.362222184858401, 2.0970571419134454`}, {5.437499981032941, 
       2.084292589556062}}], 
      PolygonBox[{{5.362222184858401, 2.0970571419134454`}, {
       5.3247595264191645`, 2.1875}, {5.437499981032941, 2.084292589556062}, {
       5.362222184858401, 2.0970571419134454`}}], 
      PolygonBox[{{5.437344993353523, 2.230251642536255}, {5.437499981032941, 
       2.084292589556062}, {5.3247595264191645`, 2.1875}, {5.437344993353523, 
       2.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, 2.1875}, {5.265165042944956, 
       2.2651650429449552`}, {5.437344993353523, 2.230251642536255}, {
       5.3247595264191645`, 2.1875}}], 
      PolygonBox[{{5.404942744332997, 2.404942744332997}, {5.437344993353523, 
       2.230251642536255}, {5.265165042944956, 2.2651650429449552`}, {
       5.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{5.265165042944956, 2.2651650429449552`}, {5.1875, 
       2.3247595264191645`}, {5.404942744332997, 2.404942744332997}, {
       5.265165042944956, 2.2651650429449552`}}], 
      PolygonBox[{{5.230251642536255, 2.4373449933535234`}, {
       5.404942744332997, 2.404942744332997}, {5.1875, 2.3247595264191645`}, {
       5.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{5.1875, 2.3247595264191645`}, {5.097057141913445, 
       2.3622221848584006`}, {5.230251642536255, 2.4373449933535234`}, {
       5.1875, 2.3247595264191645`}}], 
      PolygonBox[{{5.0842925895560604`, 2.437499981032941}, {
       5.230251642536255, 2.4373449933535234`}, {5.097057141913445, 
       2.3622221848584006`}, {5.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{5.097057141913445, 2.3622221848584006`}, {5., 2.375}, {
       5.0842925895560604`, 2.437499981032941}, {5.097057141913445, 
       2.3622221848584006`}}], 
      PolygonBox[{{5.000105527220487, 2.4375}, {5.0842925895560604`, 
       2.437499981032941}, {5., 2.375}, {5.000105527220487, 2.4375}}], 
      PolygonBox[{{5., 2.375}, {4.902942858086555, 2.3622221848584006`}, {
       5.000105527220487, 2.4375}, {5., 2.375}}], 
      PolygonBox[{{4.915707410443943, 2.437499981032941}, {5.000105527220487, 
       2.4375}, {4.902942858086555, 2.3622221848584006`}, {4.915707410443943, 
       2.437499981032941}}], 
      PolygonBox[{{4.902942858086555, 2.3622221848584006`}, {4.8125, 
       2.3247595264191645`}, {4.915707410443943, 2.437499981032941}, {
       4.902942858086555, 2.3622221848584006`}}], 
      PolygonBox[{{4.769748357463745, 2.4373449933535234`}, {
       4.915707410443943, 2.437499981032941}, {4.8125, 2.3247595264191645`}, {
       4.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{4.8125, 2.3247595264191645`}, {4.734834957055044, 
       2.2651650429449552`}, {4.769748357463745, 2.4373449933535234`}, {
       4.8125, 2.3247595264191645`}}], 
      PolygonBox[{{4.595057255667003, 2.404942744332997}, {4.769748357463745, 
       2.4373449933535234`}, {4.734834957055044, 2.2651650429449552`}, {
       4.595057255667003, 2.404942744332997}}], 
      PolygonBox[{{4.734834957055044, 2.2651650429449552`}, {
       4.6752404735808355`, 2.1875}, {4.595057255667003, 2.404942744332997}, {
       4.734834957055044, 2.2651650429449552`}}], 
      PolygonBox[{{4.562655006646477, 2.2302516425362553`}, {
       4.595057255667003, 2.404942744332997}, {4.6752404735808355`, 2.1875}, {
       4.562655006646477, 2.2302516425362553`}}], 
      PolygonBox[{{4.6752404735808355`, 2.1875}, {4.637777815141599, 
       2.0970571419134454`}, {4.562655006646477, 2.2302516425362553`}, {
       4.6752404735808355`, 2.1875}}], 
      PolygonBox[{{4.562500018967059, 2.0842925895560622`}, {
       4.562655006646477, 2.2302516425362553`}, {4.637777815141599, 
       2.0970571419134454`}, {4.562500018967059, 2.0842925895560622`}}], 
      PolygonBox[{{4.637777815141599, 2.0970571419134454`}, {4.625, 2.}, {
       4.562500018967059, 2.0842925895560622`}, {4.637777815141599, 
       2.0970571419134454`}}], 
      PolygonBox[{{4.5625, 2.0001231780629953`}, {4.562500018967059, 
       2.0842925895560622`}, {4.625, 2.}, {4.5625, 2.0001231780629953`}}], 
      PolygonBox[{{4.625, 2.}, {4.637777815141599, 1.9029428580865548`}, {
       4.5625, 2.0001231780629953`}, {4.625, 2.}}], 
      PolygonBox[{{4.562500018967059, 1.915707410443945}, {4.5625, 
       2.0001231780629953`}, {4.637777815141599, 1.9029428580865548`}, {
       4.562500018967059, 1.915707410443945}}], 
      PolygonBox[{{4.637777815141599, 1.9029428580865548`}, {
       4.6752404735808355`, 1.8125000000000002`}, {4.562500018967059, 
       1.915707410443945}, {4.637777815141599, 1.9029428580865548`}}], 
      PolygonBox[{{4.562655006646477, 1.7697483574637451`}, {
       4.562500018967059, 1.915707410443945}, {4.6752404735808355`, 
       1.8125000000000002`}, {4.562655006646477, 1.7697483574637451`}}], 
      PolygonBox[{{4.6752404735808355`, 1.8125000000000002`}, {
       4.734834957055044, 1.7348349570550448`}, {4.562655006646477, 
       1.7697483574637451`}, {4.6752404735808355`, 1.8125000000000002`}}], 
      PolygonBox[{{4.595057255667003, 1.5950572556670028`}, {
       4.562655006646477, 1.7697483574637451`}, {4.734834957055044, 
       1.7348349570550448`}, {4.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{4.734834957055044, 1.7348349570550448`}, {4.8125, 
       1.6752404735808355`}, {4.595057255667003, 1.5950572556670028`}, {
       4.734834957055044, 1.7348349570550448`}}], 
      PolygonBox[{{4.769748357463745, 1.5626550066464766`}, {
       4.595057255667003, 1.5950572556670028`}, {4.8125, 
       1.6752404735808355`}, {4.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{4.8125, 1.6752404735808355`}, {4.902942858086554, 
       1.6377778151415994`}, {4.769748357463745, 1.5626550066464766`}, {
       4.8125, 1.6752404735808355`}}], 
      PolygonBox[{{4.915707410443936, 1.5625000189670593`}, {
       4.769748357463745, 1.5626550066464766`}, {4.902942858086554, 
       1.6377778151415994`}, {4.915707410443936, 1.5625000189670593`}}], 
      PolygonBox[{{4.902942858086554, 1.6377778151415994`}, {5., 1.625}, {
       4.915707410443936, 1.5625000189670593`}, {4.902942858086554, 
       1.6377778151415994`}}], 
      PolygonBox[{{5.000134841831043, 1.5625}, {4.915707410443936, 
       1.5625000189670593`}, {5., 1.625}, {5.000134841831043, 1.5625}}], 
      PolygonBox[{{5., 1.625}, {5.097057141913445, 1.6377778151415994`}, {
       5.000134841831043, 1.5625}, {5., 1.625}}], 
      PolygonBox[{{5.084292589556053, 1.5625000189670593`}, {
       5.000134841831043, 1.5625}, {5.097057141913445, 1.6377778151415994`}, {
       5.084292589556053, 1.5625000189670593`}}], 
      PolygonBox[{{5.097057141913445, 1.6377778151415994`}, {5.1875, 
       1.6752404735808355`}, {5.084292589556053, 1.5625000189670593`}, {
       5.097057141913445, 1.6377778151415994`}}], 
      PolygonBox[{{5.230251642536254, 1.5626550066464766`}, {
       5.084292589556053, 1.5625000189670593`}, {5.1875, 
       1.6752404735808355`}, {5.230251642536254, 1.5626550066464766`}}], 
      PolygonBox[{{5.1875, 1.6752404735808355`}, {5.265165042944956, 
       1.7348349570550448`}, {5.230251642536254, 1.5626550066464766`}, {
       5.1875, 1.6752404735808355`}}], 
      PolygonBox[{{5.404942744332997, 1.5950572556670028`}, {
       5.230251642536254, 1.5626550066464766`}, {5.265165042944956, 
       1.7348349570550448`}, {5.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{5.265165042944956, 1.7348349570550448`}, {
       5.265165042944956, 1.7348349570550448`}, {5.404942744332997, 
       1.5950572556670028`}, {5.265165042944956, 1.7348349570550448`}}], 
      PolygonBox[{{5.404942744332997, 1.5950572556670028`}, {
       5.404942744332997, 1.5950572556670028`}, {5.265165042944956, 
       1.7348349570550448`}, {5.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{5.404942744332997, 1.5950572556670028`}, {
       5.437344993353523, 1.769748357463745}, {5.5, 1.5}, {5.404942744332997, 
       1.5950572556670028`}}], 
      PolygonBox[{{5.5, 1.6423372173506323`}, {5.5, 1.5}, {5.437344993353523, 
       1.769748357463745}, {5.5, 1.6423372173506323`}}], 
      PolygonBox[{{5.437344993353523, 1.769748357463745}, {5.437499981032941, 
       1.9157074104439382`}, {5.5, 1.6423372173506323`}, {5.437344993353523, 
       1.769748357463745}}], 
      PolygonBox[{{5.5, 1.79409099469826}, {5.5, 1.6423372173506323`}, {
       5.437499981032941, 1.9157074104439382`}, {5.5, 1.79409099469826}}], 
      PolygonBox[{{5.437499981032941, 1.9157074104439382`}, {5.4375, 2.}, {
       5.5, 1.79409099469826}, {5.437499981032941, 1.9157074104439382`}}], 
      PolygonBox[{{5.5, 2.}, {5.5, 1.79409099469826}, {5.4375, 2.}, {5.5, 
       2.}}], PolygonBox[{{5.4375, 2.}, {5.437499981032941, 
       2.084292589556062}, {5.5, 2.}, {5.4375, 2.}}], 
      PolygonBox[{{5.5, 2.20590900530174}, {5.5, 2.}, {5.437499981032941, 
       2.084292589556062}, {5.5, 2.20590900530174}}], 
      PolygonBox[{{5.437499981032941, 2.084292589556062}, {5.437344993353523, 
       2.230251642536255}, {5.5, 2.20590900530174}, {5.437499981032941, 
       2.084292589556062}}], 
      PolygonBox[{{5.5, 2.3576627826493675`}, {5.5, 2.20590900530174}, {
       5.437344993353523, 2.230251642536255}, {5.5, 2.3576627826493675`}}], 
      PolygonBox[{{5.437344993353523, 2.230251642536255}, {5.404942744332997, 
       2.404942744332997}, {5.5, 2.3576627826493675`}, {5.437344993353523, 
       2.230251642536255}}], 
      PolygonBox[{{5.491446564961186, 2.491446564961186}, {5.5, 
       2.3576627826493675`}, {5.404942744332997, 2.404942744332997}, {
       5.491446564961186, 2.491446564961186}}], 
      PolygonBox[{{5.404942744332997, 2.404942744332997}, {5.230251642536255, 
       2.4373449933535234`}, {5.491446564961186, 2.491446564961186}, {
       5.404942744332997, 2.404942744332997}}], 
      PolygonBox[{{5.357662782649368, 2.5}, {5.491446564961186, 
       2.491446564961186}, {5.230251642536255, 2.4373449933535234`}, {
       5.357662782649368, 2.5}}], 
      PolygonBox[{{5.230251642536255, 2.4373449933535234`}, {
       5.0842925895560604`, 2.437499981032941}, {5.357662782649368, 2.5}, {
       5.230251642536255, 2.4373449933535234`}}], 
      PolygonBox[{{5.205909005373256, 2.5}, {5.357662782649368, 2.5}, {
       5.0842925895560604`, 2.437499981032941}, {5.205909005373256, 2.5}}], 
      PolygonBox[{{5.0842925895560604`, 2.437499981032941}, {
       5.000105527220487, 2.4375}, {5.205909005373256, 2.5}, {
       5.0842925895560604`, 2.437499981032941}}], 
      PolygonBox[{{5.07794195802689, 2.5}, {5.205909005373256, 2.5}, {
       5.000105527220487, 2.4375}, {5.07794195802689, 2.5}}], 
      PolygonBox[{{5.000105527220487, 2.4375}, {4.915707410443943, 
       2.437499981032941}, {5.07794195802689, 2.5}, {5.000105527220487, 
       2.4375}}], 
      PolygonBox[{{4.794090994695554, 2.5}, {5.07794195802689, 2.5}, {
       4.915707410443943, 2.437499981032941}, {4.794090994695554, 2.5}}], 
      PolygonBox[{{4.915707410443943, 2.437499981032941}, {4.769748357463745, 
       2.4373449933535234`}, {4.794090994695554, 2.5}, {4.915707410443943, 
       2.437499981032941}}], 
      PolygonBox[{{4.642337217350634, 2.5}, {4.794090994695554, 2.5}, {
       4.769748357463745, 2.4373449933535234`}, {4.642337217350634, 2.5}}], 
      PolygonBox[{{4.769748357463745, 2.4373449933535234`}, {
       4.595057255667003, 2.404942744332997}, {4.642337217350634, 2.5}, {
       4.769748357463745, 2.4373449933535234`}}], 
      PolygonBox[{{5.5, 2.5}, {4.642337217350634, 2.5}, {4.595057255667003, 
       2.404942744332997}, {5.5, 2.5}}], 
      PolygonBox[{{4.595057255667003, 2.404942744332997}, {4.562655006646477, 
       2.2302516425362553`}, {5.5, 2.5}, {4.595057255667003, 
       2.404942744332997}}], 
      PolygonBox[{{4.5, 2.357662782649369}, {5.5, 2.5}, {4.562655006646477, 
       2.2302516425362553`}, {4.5, 2.357662782649369}}], 
      PolygonBox[{{4.562655006646477, 2.2302516425362553`}, {
       4.562500018967059, 2.0842925895560622`}, {4.5, 2.357662782649369}, {
       4.562655006646477, 2.2302516425362553`}}], 
      PolygonBox[{{4.5, 2.205909005282899}, {4.5, 2.357662782649369}, {
       4.562500018967059, 2.0842925895560622`}, {4.5, 2.205909005282899}}], 
      PolygonBox[{{4.562500018967059, 2.0842925895560622`}, {4.5625, 
       2.0001231780629953`}, {4.5, 2.205909005282899}, {4.562500018967059, 
       2.0842925895560622`}}], 
      PolygonBox[{{4.5, 2.0806786667587}, {4.5, 2.205909005282899}, {4.5625, 
       2.0001231780629953`}, {4.5, 2.0806786667587}}], 
      PolygonBox[{{4.5625, 2.0001231780629953`}, {4.562500018967059, 
       1.915707410443945}, {4.5, 2.0806786667587}, {4.5625, 
       2.0001231780629953`}}], 
      PolygonBox[{{4.5, 1.7940909948547215`}, {4.5, 2.0806786667587}, {
       4.562500018967059, 1.915707410443945}, {4.5, 1.7940909948547215`}}], 
      PolygonBox[{{4.562500018967059, 1.915707410443945}, {4.562655006646477, 
       1.7697483574637451`}, {4.5, 1.7940909948547215`}, {4.562500018967059, 
       1.915707410443945}}], 
      PolygonBox[{{4.5, 1.6423372173506348`}, {4.5, 1.7940909948547215`}, {
       4.562655006646477, 1.7697483574637451`}, {4.5, 1.6423372173506348`}}], 
      PolygonBox[{{4.562655006646477, 1.7697483574637451`}, {
       4.595057255667003, 1.5950572556670028`}, {4.5, 1.6423372173506348`}, {
       4.562655006646477, 1.7697483574637451`}}], 
      PolygonBox[{{4.5, 2.5}, {4.5, 1.6423372173506348`}, {4.595057255667003, 
       1.5950572556670028`}, {4.5, 2.5}}], 
      PolygonBox[{{4.595057255667003, 1.5950572556670028`}, {
       4.769748357463745, 1.5626550066464766`}, {4.5, 2.5}, {
       4.595057255667003, 1.5950572556670028`}}], 
      PolygonBox[{{4.5, 1.5}, {4.5, 2.5}, {4.769748357463745, 
       1.5626550066464766`}, {4.5, 1.5}}], 
      PolygonBox[{{4.769748357463745, 1.5626550066464766`}, {
       4.915707410443936, 1.5625000189670593`}, {4.5, 1.5}, {
       4.769748357463745, 1.5626550066464766`}}], 
      PolygonBox[{{4.794090994433172, 1.5}, {4.5, 1.5}, {4.915707410443936, 
       1.5625000189670593`}, {4.794090994433172, 1.5}}], 
      PolygonBox[{{4.915707410443936, 1.5625000189670593`}, {
       5.000134841831043, 1.5625}, {4.794090994433172, 1.5}, {
       4.915707410443936, 1.5625000189670593`}}], 
      PolygonBox[{{5.082323870401062, 1.5}, {4.794090994433172, 1.5}, {
       5.000134841831043, 1.5625}, {5.082323870401062, 1.5}}], 
      PolygonBox[{{5.000134841831043, 1.5625}, {5.084292589556053, 
       1.5625000189670593`}, {5.082323870401062, 1.5}, {5.000134841831043, 
       1.5625}}], 
      PolygonBox[{{5.205909005360398, 1.5}, {5.082323870401062, 1.5}, {
       5.084292589556053, 1.5625000189670593`}, {5.205909005360398, 1.5}}], 
      PolygonBox[{{5.084292589556053, 1.5625000189670593`}, {
       5.230251642536254, 1.5626550066464766`}, {5.205909005360398, 1.5}, {
       5.084292589556053, 1.5625000189670593`}}], 
      PolygonBox[{{5.3576627826493715`, 1.5}, {5.205909005360398, 1.5}, {
       5.230251642536254, 1.5626550066464766`}, {5.3576627826493715`, 1.5}}], 
      PolygonBox[{{5.230251642536254, 1.5626550066464766`}, {
       5.404942744332997, 1.5950572556670028`}, {5.3576627826493715`, 1.5}, {
       5.230251642536254, 1.5626550066464766`}}], 
      PolygonBox[{{5.5, 1.5}, {5.3576627826493715`, 1.5}, {5.404942744332997, 
       1.5950572556670028`}, {5.5, 1.5}}], 
      PolygonBox[{{5.404942744332997, 1.5950572556670028`}, {
       5.404942744332997, 1.5950572556670028`}, {5.5, 1.5}, {
       5.404942744332997, 1.5950572556670028`}}], 
      PolygonBox[{{5.5, 1.5}, {5.5, 1.5}, {5.404942744332997, 
       1.5950572556670028`}, {5.5, 1.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, 3.}, {4.520833333333333, 3.}, {4.541666666666667, 3.}, {
       4.5625, 3.}, {4.583333333333333, 3.}, {4.604166666666667, 3.}, {4.625, 
       3.}, {4.625, 3.}, {4.604166666666667, 3.}, {4.583333333333333, 3.}, {
       4.5625, 3.}, {4.541666666666667, 3.}, {4.520833333333333, 3.}, {4.5, 
       3.}, {4.5, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, 3.}, {5.395833333333333, 3.}, {5.416666666666667, 
       3.}, {5.4375, 3.}, {5.458333333333333, 3.}, {5.479166666666667, 3.}, {
       5.5, 3.}, {5.5, 3.}, {5.479166666666667, 3.}, {5.458333333333333, 
       3.}, {5.4375, 3.}, {5.416666666666667, 3.}, {5.395833333333333, 3.}, {
       5.375, 3.}, {5.375, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 2.5}, {5., 2.5208333333333335`}, {5., 
       2.5416666666666665`}, {5., 2.5625}, {5., 2.5833333333333335`}, {5., 
       2.6041666666666665`}, {5., 2.625}, {5., 2.625}, {5., 
       2.6041666666666665`}, {5., 2.5833333333333335`}, {5., 2.5625}, {5., 
       2.5416666666666665`}, {5., 2.5208333333333335`}, {5., 2.5}, {5., 
       2.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 3.375}, {5., 3.3958333333333335`}, {5., 
       3.4166666666666665`}, {5., 3.4375}, {5., 3.4583333333333335`}, {5., 
       3.4791666666666665`}, {5., 3.5}, {5., 3.5}, {5., 
       3.4791666666666665`}, {5., 3.4583333333333335`}, {5., 3.4375}, {5., 
       3.4166666666666665`}, {5., 3.3958333333333335`}, {5., 3.375}, {5., 
       3.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, 3.}, {4.75, 3.}, {4.875, 3.}, {5., 3.}, {5.125, 3.}, {
       5.25, 3.}, {5.375, 3.}, {5.375, 3.}, {5.25, 3.}, {5.125, 3.}, {5., 
       3.}, {4.875, 3.}, {4.75, 3.}, {4.625, 3.}, {4.625, 3.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 2.625}, {5., 2.75}, {5., 2.875}, {5., 3.}, {5., 3.125}, {
       5., 3.25}, {5., 3.375}, {5., 3.375}, {5., 3.25}, {5., 3.125}, {5., 
       3.}, {5., 2.875}, {5., 2.75}, {5., 2.625}, {5., 2.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4QBofD14zw+FdFog7+T4SeHj3G4TBD+cmh
Xh+ofAOnw7lvZ3Pa+UUdZr+dfZNPngsifkDEwcD9RKv0TC4H9aLOT0nJIg6v
Lq7bd+UpVJ5BBEpzO9zsLeOdO0cYVd5BGK7fiNNocsUHIbj5GXekbYs2C8Ht
556+YoForxDcfRBxIbj7YfKbpN9KWVmyo+lng5ufKpSi9vEBK9z+CzvMq56k
sTrcgLpPTC/QUVuKFc39rHD/ocgD/Q/TDwsfmPmo4ccGD9+NUPehhz8ApY92
Hw==
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhCaxyEUDETh/NWrQEAEzofQImjqhdHUC6Gp
J8yH6OOC8yHmcqKp50BTzwbnh4HVs6KpZ8Hgo7qPBc39MPUiaOpF0NSLoqkX
I8gPRXGfGJr7Yeo50NRzwvmrUMIHEV8ALKxCqg==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, 2.7348349570550448`}, {
       5.3247595264191645`, 2.8125}, {5.404942744332997, 2.595057255667003}, {
       5.265165042944956, 2.7348349570550448`}}], 
      PolygonBox[{{5.437344993353523, 2.7697483574637447`}, {
       5.404942744332997, 2.595057255667003}, {5.3247595264191645`, 2.8125}, {
       5.437344993353523, 2.7697483574637447`}}], 
      PolygonBox[{{5.3247595264191645`, 2.8125}, {5.362222184858401, 
       2.9029428580865546`}, {5.437344993353523, 2.7697483574637447`}, {
       5.3247595264191645`, 2.8125}}], 
      PolygonBox[{{5.437499981032941, 2.915707410443938}, {5.437344993353523, 
       2.7697483574637447`}, {5.362222184858401, 2.9029428580865546`}, {
       5.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{5.362222184858401, 2.9029428580865546`}, {5.375, 3.}, {
       5.437499981032941, 2.915707410443938}, {5.362222184858401, 
       2.9029428580865546`}}], 
      PolygonBox[{{5.4375, 3.}, {5.437499981032941, 2.915707410443938}, {
       5.375, 3.}, {5.4375, 3.}}], 
      PolygonBox[{{5.375, 3.}, {5.362222184858401, 3.0970571419134454`}, {
       5.4375, 3.}, {5.375, 3.}}], 
      PolygonBox[{{5.437499981032941, 3.084292589556062}, {5.4375, 3.}, {
       5.362222184858401, 3.0970571419134454`}, {5.437499981032941, 
       3.084292589556062}}], 
      PolygonBox[{{5.362222184858401, 3.0970571419134454`}, {
       5.3247595264191645`, 3.1875}, {5.437499981032941, 3.084292589556062}, {
       5.362222184858401, 3.0970571419134454`}}], 
      PolygonBox[{{5.437344993353523, 3.230251642536255}, {5.437499981032941, 
       3.084292589556062}, {5.3247595264191645`, 3.1875}, {5.437344993353523, 
       3.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, 3.1875}, {5.265165042944956, 
       3.2651650429449552`}, {5.437344993353523, 3.230251642536255}, {
       5.3247595264191645`, 3.1875}}], 
      PolygonBox[{{5.404942744332997, 3.404942744332997}, {5.437344993353523, 
       3.230251642536255}, {5.265165042944956, 3.2651650429449552`}, {
       5.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{5.265165042944956, 3.2651650429449552`}, {5.1875, 
       3.3247595264191645`}, {5.404942744332997, 3.404942744332997}, {
       5.265165042944956, 3.2651650429449552`}}], 
      PolygonBox[{{5.230251642536255, 3.4373449933535234`}, {
       5.404942744332997, 3.404942744332997}, {5.1875, 3.3247595264191645`}, {
       5.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{5.1875, 3.3247595264191645`}, {5.097057141913445, 
       3.3622221848584006`}, {5.230251642536255, 3.4373449933535234`}, {
       5.1875, 3.3247595264191645`}}], 
      PolygonBox[{{5.0842925895560604`, 3.437499981032941}, {
       5.230251642536255, 3.4373449933535234`}, {5.097057141913445, 
       3.3622221848584006`}, {5.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{5.097057141913445, 3.3622221848584006`}, {5., 3.375}, {
       5.0842925895560604`, 3.437499981032941}, {5.097057141913445, 
       3.3622221848584006`}}], 
      PolygonBox[{{5.000105527220487, 3.4375}, {5.0842925895560604`, 
       3.437499981032941}, {5., 3.375}, {5.000105527220487, 3.4375}}], 
      PolygonBox[{{5., 3.375}, {4.902942858086555, 3.3622221848584006`}, {
       5.000105527220487, 3.4375}, {5., 3.375}}], 
      PolygonBox[{{4.915707410443943, 3.437499981032941}, {5.000105527220487, 
       3.4375}, {4.902942858086555, 3.3622221848584006`}, {4.915707410443943, 
       3.437499981032941}}], 
      PolygonBox[{{4.902942858086555, 3.3622221848584006`}, {4.8125, 
       3.3247595264191645`}, {4.915707410443943, 3.437499981032941}, {
       4.902942858086555, 3.3622221848584006`}}], 
      PolygonBox[{{4.769748357463745, 3.4373449933535234`}, {
       4.915707410443943, 3.437499981032941}, {4.8125, 3.3247595264191645`}, {
       4.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{4.8125, 3.3247595264191645`}, {4.734834957055044, 
       3.2651650429449552`}, {4.769748357463745, 3.4373449933535234`}, {
       4.8125, 3.3247595264191645`}}], 
      PolygonBox[{{4.595057255667003, 3.404942744332997}, {4.769748357463745, 
       3.4373449933535234`}, {4.734834957055044, 3.2651650429449552`}, {
       4.595057255667003, 3.404942744332997}}], 
      PolygonBox[{{4.734834957055044, 3.2651650429449552`}, {
       4.6752404735808355`, 3.1875}, {4.595057255667003, 3.404942744332997}, {
       4.734834957055044, 3.2651650429449552`}}], 
      PolygonBox[{{4.562655006646477, 3.2302516425362553`}, {
       4.595057255667003, 3.404942744332997}, {4.6752404735808355`, 3.1875}, {
       4.562655006646477, 3.2302516425362553`}}], 
      PolygonBox[{{4.6752404735808355`, 3.1875}, {4.637777815141599, 
       3.0970571419134454`}, {4.562655006646477, 3.2302516425362553`}, {
       4.6752404735808355`, 3.1875}}], 
      PolygonBox[{{4.562500018967059, 3.0842925895560622`}, {
       4.562655006646477, 3.2302516425362553`}, {4.637777815141599, 
       3.0970571419134454`}, {4.562500018967059, 3.0842925895560622`}}], 
      PolygonBox[{{4.637777815141599, 3.0970571419134454`}, {4.625, 3.}, {
       4.562500018967059, 3.0842925895560622`}, {4.637777815141599, 
       3.0970571419134454`}}], 
      PolygonBox[{{4.5625, 3.0001231780629953`}, {4.562500018967059, 
       3.0842925895560622`}, {4.625, 3.}, {4.5625, 3.0001231780629953`}}], 
      PolygonBox[{{4.625, 3.}, {4.637777815141599, 2.902942858086555}, {
       4.5625, 3.0001231780629953`}, {4.625, 3.}}], 
      PolygonBox[{{4.562500018967059, 2.915707410443945}, {4.5625, 
       3.0001231780629953`}, {4.637777815141599, 2.902942858086555}, {
       4.562500018967059, 2.915707410443945}}], 
      PolygonBox[{{4.637777815141599, 2.902942858086555}, {
       4.6752404735808355`, 2.8125}, {4.562500018967059, 2.915707410443945}, {
       4.637777815141599, 2.902942858086555}}], 
      PolygonBox[{{4.562655006646477, 2.769748357463745}, {4.562500018967059, 
       2.915707410443945}, {4.6752404735808355`, 2.8125}, {4.562655006646477, 
       2.769748357463745}}], 
      PolygonBox[{{4.6752404735808355`, 2.8125}, {4.734834957055044, 
       2.7348349570550448`}, {4.562655006646477, 2.769748357463745}, {
       4.6752404735808355`, 2.8125}}], 
      PolygonBox[{{4.595057255667003, 2.595057255667003}, {4.562655006646477, 
       2.769748357463745}, {4.734834957055044, 2.7348349570550448`}, {
       4.595057255667003, 2.595057255667003}}], 
      PolygonBox[{{4.734834957055044, 2.7348349570550448`}, {4.8125, 
       2.6752404735808355`}, {4.595057255667003, 2.595057255667003}, {
       4.734834957055044, 2.7348349570550448`}}], 
      PolygonBox[{{4.769748357463745, 2.5626550066464766`}, {
       4.595057255667003, 2.595057255667003}, {4.8125, 2.6752404735808355`}, {
       4.769748357463745, 2.5626550066464766`}}], 
      PolygonBox[{{4.8125, 2.6752404735808355`}, {4.902942858086554, 
       2.6377778151415994`}, {4.769748357463745, 2.5626550066464766`}, {
       4.8125, 2.6752404735808355`}}], 
      PolygonBox[{{4.915707410443936, 2.562500018967059}, {4.769748357463745, 
       2.5626550066464766`}, {4.902942858086554, 2.6377778151415994`}, {
       4.915707410443936, 2.562500018967059}}], 
      PolygonBox[{{4.902942858086554, 2.6377778151415994`}, {5., 2.625}, {
       4.915707410443936, 2.562500018967059}, {4.902942858086554, 
       2.6377778151415994`}}], 
      PolygonBox[{{5.000134841831043, 2.5625}, {4.915707410443936, 
       2.562500018967059}, {5., 2.625}, {5.000134841831043, 2.5625}}], 
      PolygonBox[{{5., 2.625}, {5.097057141913445, 2.6377778151415994`}, {
       5.000134841831043, 2.5625}, {5., 2.625}}], 
      PolygonBox[{{5.084292589556053, 2.562500018967059}, {5.000134841831043, 
       2.5625}, {5.097057141913445, 2.6377778151415994`}, {5.084292589556053, 
       2.562500018967059}}], 
      PolygonBox[{{5.097057141913445, 2.6377778151415994`}, {5.1875, 
       2.6752404735808355`}, {5.084292589556053, 2.562500018967059}, {
       5.097057141913445, 2.6377778151415994`}}], 
      PolygonBox[{{5.230251642536254, 2.5626550066464766`}, {
       5.084292589556053, 2.562500018967059}, {5.1875, 2.6752404735808355`}, {
       5.230251642536254, 2.5626550066464766`}}], 
      PolygonBox[{{5.1875, 2.6752404735808355`}, {5.265165042944956, 
       2.7348349570550448`}, {5.230251642536254, 2.5626550066464766`}, {
       5.1875, 2.6752404735808355`}}], 
      PolygonBox[{{5.404942744332997, 2.595057255667003}, {5.230251642536254, 
       2.5626550066464766`}, {5.265165042944956, 2.7348349570550448`}, {
       5.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{5.265165042944956, 2.7348349570550448`}, {
       5.265165042944956, 2.7348349570550448`}, {5.404942744332997, 
       2.595057255667003}, {5.265165042944956, 2.7348349570550448`}}], 
      PolygonBox[{{5.404942744332997, 2.595057255667003}, {5.404942744332997, 
       2.595057255667003}, {5.265165042944956, 2.7348349570550448`}, {
       5.404942744332997, 2.595057255667003}}], 
      PolygonBox[{{5.404942744332997, 2.595057255667003}, {5.437344993353523, 
       2.7697483574637447`}, {5.5, 2.5}, {5.404942744332997, 
       2.595057255667003}}], 
      PolygonBox[{{5.5, 2.642337217350632}, {5.5, 2.5}, {5.437344993353523, 
       2.7697483574637447`}, {5.5, 2.642337217350632}}], 
      PolygonBox[{{5.437344993353523, 2.7697483574637447`}, {
       5.437499981032941, 2.915707410443938}, {5.5, 2.642337217350632}, {
       5.437344993353523, 2.7697483574637447`}}], 
      PolygonBox[{{5.5, 2.79409099469826}, {5.5, 2.642337217350632}, {
       5.437499981032941, 2.915707410443938}, {5.5, 2.79409099469826}}], 
      PolygonBox[{{5.437499981032941, 2.915707410443938}, {5.4375, 3.}, {5.5, 
       2.79409099469826}, {5.437499981032941, 2.915707410443938}}], 
      PolygonBox[{{5.5, 3.}, {5.5, 2.79409099469826}, {5.4375, 3.}, {5.5, 
       3.}}], PolygonBox[{{5.4375, 3.}, {5.437499981032941, 
       3.084292589556062}, {5.5, 3.}, {5.4375, 3.}}], 
      PolygonBox[{{5.5, 3.20590900530174}, {5.5, 3.}, {5.437499981032941, 
       3.084292589556062}, {5.5, 3.20590900530174}}], 
      PolygonBox[{{5.437499981032941, 3.084292589556062}, {5.437344993353523, 
       3.230251642536255}, {5.5, 3.20590900530174}, {5.437499981032941, 
       3.084292589556062}}], 
      PolygonBox[{{5.5, 3.3576627826493675`}, {5.5, 3.20590900530174}, {
       5.437344993353523, 3.230251642536255}, {5.5, 3.3576627826493675`}}], 
      PolygonBox[{{5.437344993353523, 3.230251642536255}, {5.404942744332997, 
       3.404942744332997}, {5.5, 3.3576627826493675`}, {5.437344993353523, 
       3.230251642536255}}], 
      PolygonBox[{{5.491446564961186, 3.491446564961186}, {5.5, 
       3.3576627826493675`}, {5.404942744332997, 3.404942744332997}, {
       5.491446564961186, 3.491446564961186}}], 
      PolygonBox[{{5.404942744332997, 3.404942744332997}, {5.230251642536255, 
       3.4373449933535234`}, {5.491446564961186, 3.491446564961186}, {
       5.404942744332997, 3.404942744332997}}], 
      PolygonBox[{{5.357662782649368, 3.5}, {5.491446564961186, 
       3.491446564961186}, {5.230251642536255, 3.4373449933535234`}, {
       5.357662782649368, 3.5}}], 
      PolygonBox[{{5.230251642536255, 3.4373449933535234`}, {
       5.0842925895560604`, 3.437499981032941}, {5.357662782649368, 3.5}, {
       5.230251642536255, 3.4373449933535234`}}], 
      PolygonBox[{{5.205909005373256, 3.5}, {5.357662782649368, 3.5}, {
       5.0842925895560604`, 3.437499981032941}, {5.205909005373256, 3.5}}], 
      PolygonBox[{{5.0842925895560604`, 3.437499981032941}, {
       5.000105527220487, 3.4375}, {5.205909005373256, 3.5}, {
       5.0842925895560604`, 3.437499981032941}}], 
      PolygonBox[{{5.07794195802689, 3.5}, {5.205909005373256, 3.5}, {
       5.000105527220487, 3.4375}, {5.07794195802689, 3.5}}], 
      PolygonBox[{{5.000105527220487, 3.4375}, {4.915707410443943, 
       3.437499981032941}, {5.07794195802689, 3.5}, {5.000105527220487, 
       3.4375}}], 
      PolygonBox[{{4.794090994695554, 3.5}, {5.07794195802689, 3.5}, {
       4.915707410443943, 3.437499981032941}, {4.794090994695554, 3.5}}], 
      PolygonBox[{{4.915707410443943, 3.437499981032941}, {4.769748357463745, 
       3.4373449933535234`}, {4.794090994695554, 3.5}, {4.915707410443943, 
       3.437499981032941}}], 
      PolygonBox[{{4.642337217350634, 3.5}, {4.794090994695554, 3.5}, {
       4.769748357463745, 3.4373449933535234`}, {4.642337217350634, 3.5}}], 
      PolygonBox[{{4.769748357463745, 3.4373449933535234`}, {
       4.595057255667003, 3.404942744332997}, {4.642337217350634, 3.5}, {
       4.769748357463745, 3.4373449933535234`}}], 
      PolygonBox[{{5.5, 3.5}, {4.642337217350634, 3.5}, {4.595057255667003, 
       3.404942744332997}, {5.5, 3.5}}], 
      PolygonBox[{{4.595057255667003, 3.404942744332997}, {4.562655006646477, 
       3.2302516425362553`}, {5.5, 3.5}, {4.595057255667003, 
       3.404942744332997}}], 
      PolygonBox[{{4.5, 3.357662782649369}, {5.5, 3.5}, {4.562655006646477, 
       3.2302516425362553`}, {4.5, 3.357662782649369}}], 
      PolygonBox[{{4.562655006646477, 3.2302516425362553`}, {
       4.562500018967059, 3.0842925895560622`}, {4.5, 3.357662782649369}, {
       4.562655006646477, 3.2302516425362553`}}], 
      PolygonBox[{{4.5, 3.205909005282899}, {4.5, 3.357662782649369}, {
       4.562500018967059, 3.0842925895560622`}, {4.5, 3.205909005282899}}], 
      PolygonBox[{{4.562500018967059, 3.0842925895560622`}, {4.5625, 
       3.0001231780629953`}, {4.5, 3.205909005282899}, {4.562500018967059, 
       3.0842925895560622`}}], 
      PolygonBox[{{4.5, 3.0806786667587}, {4.5, 3.205909005282899}, {4.5625, 
       3.0001231780629953`}, {4.5, 3.0806786667587}}], 
      PolygonBox[{{4.5625, 3.0001231780629953`}, {4.562500018967059, 
       2.915707410443945}, {4.5, 3.0806786667587}, {4.5625, 
       3.0001231780629953`}}], 
      PolygonBox[{{4.5, 2.7940909948547215`}, {4.5, 3.0806786667587}, {
       4.562500018967059, 2.915707410443945}, {4.5, 2.7940909948547215`}}], 
      PolygonBox[{{4.562500018967059, 2.915707410443945}, {4.562655006646477, 
       2.769748357463745}, {4.5, 2.7940909948547215`}, {4.562500018967059, 
       2.915707410443945}}], 
      PolygonBox[{{4.5, 2.6423372173506348`}, {4.5, 2.7940909948547215`}, {
       4.562655006646477, 2.769748357463745}, {4.5, 2.6423372173506348`}}], 
      PolygonBox[{{4.562655006646477, 2.769748357463745}, {4.595057255667003, 
       2.595057255667003}, {4.5, 2.6423372173506348`}, {4.562655006646477, 
       2.769748357463745}}], 
      PolygonBox[{{4.5, 3.5}, {4.5, 2.6423372173506348`}, {4.595057255667003, 
       2.595057255667003}, {4.5, 3.5}}], 
      PolygonBox[{{4.595057255667003, 2.595057255667003}, {4.769748357463745, 
       2.5626550066464766`}, {4.5, 3.5}, {4.595057255667003, 
       2.595057255667003}}], 
      PolygonBox[{{4.5, 2.5}, {4.5, 3.5}, {4.769748357463745, 
       2.5626550066464766`}, {4.5, 2.5}}], 
      PolygonBox[{{4.769748357463745, 2.5626550066464766`}, {
       4.915707410443936, 2.562500018967059}, {4.5, 2.5}, {4.769748357463745, 
       2.5626550066464766`}}], 
      PolygonBox[{{4.794090994433172, 2.5}, {4.5, 2.5}, {4.915707410443936, 
       2.562500018967059}, {4.794090994433172, 2.5}}], 
      PolygonBox[{{4.915707410443936, 2.562500018967059}, {5.000134841831043, 
       2.5625}, {4.794090994433172, 2.5}, {4.915707410443936, 
       2.562500018967059}}], 
      PolygonBox[{{5.082323870401062, 2.5}, {4.794090994433172, 2.5}, {
       5.000134841831043, 2.5625}, {5.082323870401062, 2.5}}], 
      PolygonBox[{{5.000134841831043, 2.5625}, {5.084292589556053, 
       2.562500018967059}, {5.082323870401062, 2.5}, {5.000134841831043, 
       2.5625}}], 
      PolygonBox[{{5.205909005360398, 2.5}, {5.082323870401062, 2.5}, {
       5.084292589556053, 2.562500018967059}, {5.205909005360398, 2.5}}], 
      PolygonBox[{{5.084292589556053, 2.562500018967059}, {5.230251642536254, 
       2.5626550066464766`}, {5.205909005360398, 2.5}, {5.084292589556053, 
       2.562500018967059}}], 
      PolygonBox[{{5.3576627826493715`, 2.5}, {5.205909005360398, 2.5}, {
       5.230251642536254, 2.5626550066464766`}, {5.3576627826493715`, 2.5}}], 
      PolygonBox[{{5.230251642536254, 2.5626550066464766`}, {
       5.404942744332997, 2.595057255667003}, {5.3576627826493715`, 2.5}, {
       5.230251642536254, 2.5626550066464766`}}], 
      PolygonBox[{{5.5, 2.5}, {5.3576627826493715`, 2.5}, {5.404942744332997, 
       2.595057255667003}, {5.5, 2.5}}], 
      PolygonBox[{{5.404942744332997, 2.595057255667003}, {5.404942744332997, 
       2.595057255667003}, {5.5, 2.5}, {5.404942744332997, 
       2.595057255667003}}], 
      PolygonBox[{{5.5, 2.5}, {5.5, 2.5}, {5.404942744332997, 
       2.595057255667003}, {5.5, 2.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, 4.}, {4.520833333333333, 4.}, {4.541666666666667, 4.}, {
       4.5625, 4.}, {4.583333333333333, 4.}, {4.604166666666667, 4.}, {4.625, 
       4.}, {4.625, 4.}, {4.604166666666667, 4.}, {4.583333333333333, 4.}, {
       4.5625, 4.}, {4.541666666666667, 4.}, {4.520833333333333, 4.}, {4.5, 
       4.}, {4.5, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, 4.}, {5.395833333333333, 4.}, {5.416666666666667, 
       4.}, {5.4375, 4.}, {5.458333333333333, 4.}, {5.479166666666667, 4.}, {
       5.5, 4.}, {5.5, 4.}, {5.479166666666667, 4.}, {5.458333333333333, 
       4.}, {5.4375, 4.}, {5.416666666666667, 4.}, {5.395833333333333, 4.}, {
       5.375, 4.}, {5.375, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 3.5}, {5., 3.5208333333333335`}, {5., 
       3.5416666666666665`}, {5., 3.5625}, {5., 3.5833333333333335`}, {5., 
       3.6041666666666665`}, {5., 3.625}, {5., 3.625}, {5., 
       3.6041666666666665`}, {5., 3.5833333333333335`}, {5., 3.5625}, {5., 
       3.5416666666666665`}, {5., 3.5208333333333335`}, {5., 3.5}, {5., 
       3.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 4.375}, {5., 4.395833333333333}, {5., 
       4.416666666666667}, {5., 4.4375}, {5., 4.458333333333333}, {5., 
       4.479166666666667}, {5., 4.5}, {5., 4.5}, {5., 4.479166666666667}, {5.,
        4.458333333333333}, {5., 4.4375}, {5., 4.416666666666667}, {5., 
       4.395833333333333}, {5., 4.375}, {5., 4.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, 4.}, {4.75, 4.}, {4.875, 4.}, {5., 4.}, {5.125, 4.}, {
       5.25, 4.}, {5.375, 4.}, {5.375, 4.}, {5.25, 4.}, {5.125, 4.}, {5., 
       4.}, {4.875, 4.}, {4.75, 4.}, {4.625, 4.}, {4.625, 4.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 3.625}, {5., 3.75}, {5., 3.875}, {5., 4.}, {5., 4.125}, {
       5., 4.25}, {5., 4.375}, {5., 4.375}, {5., 4.25}, {5., 4.125}, {5., 
       4.}, {5., 3.875}, {5., 3.75}, {5., 3.625}, {5., 3.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4QhoDD14zw+FdFog7qRZ2fkpIFHGYoPznU
6wOVPyDgcO7b2Zx2flEoLQgVF4GqE4TqE4GaA5VnEIHQDYION3vLeOfOEUaV
dxCG6zfiNJpc8UEIbn7GHWnbos1CcPu5p69YINor5KABdR/EXCG4+2Hym6Tf
SllZ8qPqb+CDm58qlKL28QEv3P4LO8yrnqTxOtyAuk9ML9BRW4oX1f0MvHD/
ocgD/Q/TDwsfmPko4Qe0Hxa+G6HuQw9/AMOSdZw=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDhBayCEUDETh/NWrQEAEzofQImjqhdHUC6Gp
J0xDzBFEM0cATZ0AmjwfnB8G1s+Lpp4Hg4/qPh4098PUi6CpF0FTL4qmXowg
PxTFfWJo7oepF0CTF0DTL4imXsgBANFYQ3U=
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, 3.7348349570550448`}, {
       5.3247595264191645`, 3.8125}, {5.404942744332997, 3.595057255667003}, {
       5.265165042944956, 3.7348349570550448`}}], 
      PolygonBox[{{5.437344993353523, 3.7697483574637447`}, {
       5.404942744332997, 3.595057255667003}, {5.3247595264191645`, 3.8125}, {
       5.437344993353523, 3.7697483574637447`}}], 
      PolygonBox[{{5.3247595264191645`, 3.8125}, {5.362222184858401, 
       3.9029428580865546`}, {5.437344993353523, 3.7697483574637447`}, {
       5.3247595264191645`, 3.8125}}], 
      PolygonBox[{{5.437499981032941, 3.915707410443938}, {5.437344993353523, 
       3.7697483574637447`}, {5.362222184858401, 3.9029428580865546`}, {
       5.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{5.362222184858401, 3.9029428580865546`}, {5.375, 4.}, {
       5.437499981032941, 3.915707410443938}, {5.362222184858401, 
       3.9029428580865546`}}], 
      PolygonBox[{{5.4375, 4.}, {5.437499981032941, 3.915707410443938}, {
       5.375, 4.}, {5.4375, 4.}}], 
      PolygonBox[{{5.375, 4.}, {5.362222184858401, 4.097057141913445}, {
       5.4375, 4.}, {5.375, 4.}}], 
      PolygonBox[{{5.437499981032941, 4.084292589556061}, {5.4375, 4.}, {
       5.362222184858401, 4.097057141913445}, {5.437499981032941, 
       4.084292589556061}}], 
      PolygonBox[{{5.362222184858401, 4.097057141913445}, {
       5.3247595264191645`, 4.1875}, {5.437499981032941, 4.084292589556061}, {
       5.362222184858401, 4.097057141913445}}], 
      PolygonBox[{{5.437344993353523, 4.230251642536255}, {5.437499981032941, 
       4.084292589556061}, {5.3247595264191645`, 4.1875}, {5.437344993353523, 
       4.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, 4.1875}, {5.265165042944956, 
       4.265165042944956}, {5.437344993353523, 4.230251642536255}, {
       5.3247595264191645`, 4.1875}}], 
      PolygonBox[{{5.404942744332997, 4.404942744332997}, {5.437344993353523, 
       4.230251642536255}, {5.265165042944956, 4.265165042944956}, {
       5.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{5.265165042944956, 4.265165042944956}, {5.1875, 
       4.3247595264191645`}, {5.404942744332997, 4.404942744332997}, {
       5.265165042944956, 4.265165042944956}}], 
      PolygonBox[{{5.230251642536255, 4.437344993353523}, {5.404942744332997, 
       4.404942744332997}, {5.1875, 4.3247595264191645`}, {5.230251642536255, 
       4.437344993353523}}], 
      PolygonBox[{{5.1875, 4.3247595264191645`}, {5.097057141913445, 
       4.362222184858401}, {5.230251642536255, 4.437344993353523}, {5.1875, 
       4.3247595264191645`}}], 
      PolygonBox[{{5.0842925895560604`, 4.437499981032941}, {
       5.230251642536255, 4.437344993353523}, {5.097057141913445, 
       4.362222184858401}, {5.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{5.097057141913445, 4.362222184858401}, {5., 4.375}, {
       5.0842925895560604`, 4.437499981032941}, {5.097057141913445, 
       4.362222184858401}}], 
      PolygonBox[{{5.000105527220487, 4.4375}, {5.0842925895560604`, 
       4.437499981032941}, {5., 4.375}, {5.000105527220487, 4.4375}}], 
      PolygonBox[{{5., 4.375}, {4.902942858086555, 4.362222184858401}, {
       5.000105527220487, 4.4375}, {5., 4.375}}], 
      PolygonBox[{{4.915707410443943, 4.437499981032941}, {5.000105527220487, 
       4.4375}, {4.902942858086555, 4.362222184858401}, {4.915707410443943, 
       4.437499981032941}}], 
      PolygonBox[{{4.902942858086555, 4.362222184858401}, {4.8125, 
       4.3247595264191645`}, {4.915707410443943, 4.437499981032941}, {
       4.902942858086555, 4.362222184858401}}], 
      PolygonBox[{{4.769748357463745, 4.437344993353523}, {4.915707410443943, 
       4.437499981032941}, {4.8125, 4.3247595264191645`}, {4.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{4.8125, 4.3247595264191645`}, {4.734834957055044, 
       4.265165042944956}, {4.769748357463745, 4.437344993353523}, {4.8125, 
       4.3247595264191645`}}], 
      PolygonBox[{{4.595057255667003, 4.404942744332997}, {4.769748357463745, 
       4.437344993353523}, {4.734834957055044, 4.265165042944956}, {
       4.595057255667003, 4.404942744332997}}], 
      PolygonBox[{{4.734834957055044, 4.265165042944956}, {
       4.6752404735808355`, 4.1875}, {4.595057255667003, 4.404942744332997}, {
       4.734834957055044, 4.265165042944956}}], 
      PolygonBox[{{4.562655006646477, 4.230251642536255}, {4.595057255667003, 
       4.404942744332997}, {4.6752404735808355`, 4.1875}, {4.562655006646477, 
       4.230251642536255}}], 
      PolygonBox[{{4.6752404735808355`, 4.1875}, {4.637777815141599, 
       4.097057141913446}, {4.562655006646477, 4.230251642536255}, {
       4.6752404735808355`, 4.1875}}], 
      PolygonBox[{{4.562500018967059, 4.084292589556062}, {4.562655006646477, 
       4.230251642536255}, {4.637777815141599, 4.097057141913446}, {
       4.562500018967059, 4.084292589556062}}], 
      PolygonBox[{{4.637777815141599, 4.097057141913446}, {4.625, 4.}, {
       4.562500018967059, 4.084292589556062}, {4.637777815141599, 
       4.097057141913446}}], 
      PolygonBox[{{4.5625, 4.000123178062996}, {4.562500018967059, 
       4.084292589556062}, {4.625, 4.}, {4.5625, 4.000123178062996}}], 
      PolygonBox[{{4.625, 4.}, {4.637777815141599, 3.902942858086555}, {
       4.5625, 4.000123178062996}, {4.625, 4.}}], 
      PolygonBox[{{4.562500018967059, 3.915707410443945}, {4.5625, 
       4.000123178062996}, {4.637777815141599, 3.902942858086555}, {
       4.562500018967059, 3.915707410443945}}], 
      PolygonBox[{{4.637777815141599, 3.902942858086555}, {
       4.6752404735808355`, 3.8125}, {4.562500018967059, 3.915707410443945}, {
       4.637777815141599, 3.902942858086555}}], 
      PolygonBox[{{4.562655006646477, 3.769748357463745}, {4.562500018967059, 
       3.915707410443945}, {4.6752404735808355`, 3.8125}, {4.562655006646477, 
       3.769748357463745}}], 
      PolygonBox[{{4.6752404735808355`, 3.8125}, {4.734834957055044, 
       3.7348349570550448`}, {4.562655006646477, 3.769748357463745}, {
       4.6752404735808355`, 3.8125}}], 
      PolygonBox[{{4.595057255667003, 3.595057255667003}, {4.562655006646477, 
       3.769748357463745}, {4.734834957055044, 3.7348349570550448`}, {
       4.595057255667003, 3.595057255667003}}], 
      PolygonBox[{{4.734834957055044, 3.7348349570550448`}, {4.8125, 
       3.6752404735808355`}, {4.595057255667003, 3.595057255667003}, {
       4.734834957055044, 3.7348349570550448`}}], 
      PolygonBox[{{4.769748357463745, 3.5626550066464766`}, {
       4.595057255667003, 3.595057255667003}, {4.8125, 3.6752404735808355`}, {
       4.769748357463745, 3.5626550066464766`}}], 
      PolygonBox[{{4.8125, 3.6752404735808355`}, {4.902942858086554, 
       3.6377778151415994`}, {4.769748357463745, 3.5626550066464766`}, {
       4.8125, 3.6752404735808355`}}], 
      PolygonBox[{{4.915707410443936, 3.562500018967059}, {4.769748357463745, 
       3.5626550066464766`}, {4.902942858086554, 3.6377778151415994`}, {
       4.915707410443936, 3.562500018967059}}], 
      PolygonBox[{{4.902942858086554, 3.6377778151415994`}, {5., 3.625}, {
       4.915707410443936, 3.562500018967059}, {4.902942858086554, 
       3.6377778151415994`}}], 
      PolygonBox[{{5.000134841831043, 3.5625}, {4.915707410443936, 
       3.562500018967059}, {5., 3.625}, {5.000134841831043, 3.5625}}], 
      PolygonBox[{{5., 3.625}, {5.097057141913445, 3.6377778151415994`}, {
       5.000134841831043, 3.5625}, {5., 3.625}}], 
      PolygonBox[{{5.084292589556053, 3.562500018967059}, {5.000134841831043, 
       3.5625}, {5.097057141913445, 3.6377778151415994`}, {5.084292589556053, 
       3.562500018967059}}], 
      PolygonBox[{{5.097057141913445, 3.6377778151415994`}, {5.1875, 
       3.6752404735808355`}, {5.084292589556053, 3.562500018967059}, {
       5.097057141913445, 3.6377778151415994`}}], 
      PolygonBox[{{5.230251642536254, 3.5626550066464766`}, {
       5.084292589556053, 3.562500018967059}, {5.1875, 3.6752404735808355`}, {
       5.230251642536254, 3.5626550066464766`}}], 
      PolygonBox[{{5.1875, 3.6752404735808355`}, {5.265165042944956, 
       3.7348349570550448`}, {5.230251642536254, 3.5626550066464766`}, {
       5.1875, 3.6752404735808355`}}], 
      PolygonBox[{{5.404942744332997, 3.595057255667003}, {5.230251642536254, 
       3.5626550066464766`}, {5.265165042944956, 3.7348349570550448`}, {
       5.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{5.265165042944956, 3.7348349570550448`}, {
       5.265165042944956, 3.7348349570550448`}, {5.404942744332997, 
       3.595057255667003}, {5.265165042944956, 3.7348349570550448`}}], 
      PolygonBox[{{5.404942744332997, 3.595057255667003}, {5.404942744332997, 
       3.595057255667003}, {5.265165042944956, 3.7348349570550448`}, {
       5.404942744332997, 3.595057255667003}}], 
      PolygonBox[{{5.404942744332997, 3.595057255667003}, {5.437344993353523, 
       3.7697483574637447`}, {5.5, 3.5}, {5.404942744332997, 
       3.595057255667003}}], 
      PolygonBox[{{5.5, 3.642337217350632}, {5.5, 3.5}, {5.437344993353523, 
       3.7697483574637447`}, {5.5, 3.642337217350632}}], 
      PolygonBox[{{5.437344993353523, 3.7697483574637447`}, {
       5.437499981032941, 3.915707410443938}, {5.5, 3.642337217350632}, {
       5.437344993353523, 3.7697483574637447`}}], 
      PolygonBox[{{5.5, 3.79409099469826}, {5.5, 3.642337217350632}, {
       5.437499981032941, 3.915707410443938}, {5.5, 3.79409099469826}}], 
      PolygonBox[{{5.437499981032941, 3.915707410443938}, {5.4375, 4.}, {5.5, 
       3.79409099469826}, {5.437499981032941, 3.915707410443938}}], 
      PolygonBox[{{5.5, 4.}, {5.5, 3.79409099469826}, {5.4375, 4.}, {5.5, 
       4.}}], PolygonBox[{{5.4375, 4.}, {5.437499981032941, 
       4.084292589556061}, {5.5, 4.}, {5.4375, 4.}}], 
      PolygonBox[{{5.5, 4.20590900530174}, {5.5, 4.}, {5.437499981032941, 
       4.084292589556061}, {5.5, 4.20590900530174}}], 
      PolygonBox[{{5.437499981032941, 4.084292589556061}, {5.437344993353523, 
       4.230251642536255}, {5.5, 4.20590900530174}, {5.437499981032941, 
       4.084292589556061}}], 
      PolygonBox[{{5.5, 4.357662782649368}, {5.5, 4.20590900530174}, {
       5.437344993353523, 4.230251642536255}, {5.5, 4.357662782649368}}], 
      PolygonBox[{{5.437344993353523, 4.230251642536255}, {5.404942744332997, 
       4.404942744332997}, {5.5, 4.357662782649368}, {5.437344993353523, 
       4.230251642536255}}], 
      PolygonBox[{{5.491446564961186, 4.491446564961186}, {5.5, 
       4.357662782649368}, {5.404942744332997, 4.404942744332997}, {
       5.491446564961186, 4.491446564961186}}], 
      PolygonBox[{{5.404942744332997, 4.404942744332997}, {5.230251642536255, 
       4.437344993353523}, {5.491446564961186, 4.491446564961186}, {
       5.404942744332997, 4.404942744332997}}], 
      PolygonBox[{{5.357662782649368, 4.5}, {5.491446564961186, 
       4.491446564961186}, {5.230251642536255, 4.437344993353523}, {
       5.357662782649368, 4.5}}], 
      PolygonBox[{{5.230251642536255, 4.437344993353523}, {
       5.0842925895560604`, 4.437499981032941}, {5.357662782649368, 4.5}, {
       5.230251642536255, 4.437344993353523}}], 
      PolygonBox[{{5.205909005373256, 4.5}, {5.357662782649368, 4.5}, {
       5.0842925895560604`, 4.437499981032941}, {5.205909005373256, 4.5}}], 
      PolygonBox[{{5.0842925895560604`, 4.437499981032941}, {
       5.000105527220487, 4.4375}, {5.205909005373256, 4.5}, {
       5.0842925895560604`, 4.437499981032941}}], 
      PolygonBox[{{5.07794195802689, 4.5}, {5.205909005373256, 4.5}, {
       5.000105527220487, 4.4375}, {5.07794195802689, 4.5}}], 
      PolygonBox[{{5.000105527220487, 4.4375}, {4.915707410443943, 
       4.437499981032941}, {5.07794195802689, 4.5}, {5.000105527220487, 
       4.4375}}], 
      PolygonBox[{{4.794090994695554, 4.5}, {5.07794195802689, 4.5}, {
       4.915707410443943, 4.437499981032941}, {4.794090994695554, 4.5}}], 
      PolygonBox[{{4.915707410443943, 4.437499981032941}, {4.769748357463745, 
       4.437344993353523}, {4.794090994695554, 4.5}, {4.915707410443943, 
       4.437499981032941}}], 
      PolygonBox[{{4.642337217350634, 4.5}, {4.794090994695554, 4.5}, {
       4.769748357463745, 4.437344993353523}, {4.642337217350634, 4.5}}], 
      PolygonBox[{{4.769748357463745, 4.437344993353523}, {4.595057255667003, 
       4.404942744332997}, {4.642337217350634, 4.5}, {4.769748357463745, 
       4.437344993353523}}], 
      PolygonBox[{{5.5, 4.5}, {4.642337217350634, 4.5}, {4.595057255667003, 
       4.404942744332997}, {5.5, 4.5}}], 
      PolygonBox[{{4.595057255667003, 4.404942744332997}, {4.562655006646477, 
       4.230251642536255}, {5.5, 4.5}, {4.595057255667003, 
       4.404942744332997}}], 
      PolygonBox[{{4.5, 4.357662782649369}, {5.5, 4.5}, {4.562655006646477, 
       4.230251642536255}, {4.5, 4.357662782649369}}], 
      PolygonBox[{{4.562655006646477, 4.230251642536255}, {4.562500018967059, 
       4.084292589556062}, {4.5, 4.357662782649369}, {4.562655006646477, 
       4.230251642536255}}], 
      PolygonBox[{{4.5, 4.205909005282899}, {4.5, 4.357662782649369}, {
       4.562500018967059, 4.084292589556062}, {4.5, 4.205909005282899}}], 
      PolygonBox[{{4.562500018967059, 4.084292589556062}, {4.5625, 
       4.000123178062996}, {4.5, 4.205909005282899}, {4.562500018967059, 
       4.084292589556062}}], 
      PolygonBox[{{4.5, 4.0806786667587005`}, {4.5, 4.205909005282899}, {
       4.5625, 4.000123178062996}, {4.5, 4.0806786667587005`}}], 
      PolygonBox[{{4.5625, 4.000123178062996}, {4.562500018967059, 
       3.915707410443945}, {4.5, 4.0806786667587005`}, {4.5625, 
       4.000123178062996}}], 
      PolygonBox[{{4.5, 3.7940909948547215`}, {4.5, 4.0806786667587005`}, {
       4.562500018967059, 3.915707410443945}, {4.5, 3.7940909948547215`}}], 
      PolygonBox[{{4.562500018967059, 3.915707410443945}, {4.562655006646477, 
       3.769748357463745}, {4.5, 3.7940909948547215`}, {4.562500018967059, 
       3.915707410443945}}], 
      PolygonBox[{{4.5, 3.6423372173506348`}, {4.5, 3.7940909948547215`}, {
       4.562655006646477, 3.769748357463745}, {4.5, 3.6423372173506348`}}], 
      PolygonBox[{{4.562655006646477, 3.769748357463745}, {4.595057255667003, 
       3.595057255667003}, {4.5, 3.6423372173506348`}, {4.562655006646477, 
       3.769748357463745}}], 
      PolygonBox[{{4.5, 4.5}, {4.5, 3.6423372173506348`}, {4.595057255667003, 
       3.595057255667003}, {4.5, 4.5}}], 
      PolygonBox[{{4.595057255667003, 3.595057255667003}, {4.769748357463745, 
       3.5626550066464766`}, {4.5, 4.5}, {4.595057255667003, 
       3.595057255667003}}], 
      PolygonBox[{{4.5, 3.5}, {4.5, 4.5}, {4.769748357463745, 
       3.5626550066464766`}, {4.5, 3.5}}], 
      PolygonBox[{{4.769748357463745, 3.5626550066464766`}, {
       4.915707410443936, 3.562500018967059}, {4.5, 3.5}, {4.769748357463745, 
       3.5626550066464766`}}], 
      PolygonBox[{{4.794090994433172, 3.5}, {4.5, 3.5}, {4.915707410443936, 
       3.562500018967059}, {4.794090994433172, 3.5}}], 
      PolygonBox[{{4.915707410443936, 3.562500018967059}, {5.000134841831043, 
       3.5625}, {4.794090994433172, 3.5}, {4.915707410443936, 
       3.562500018967059}}], 
      PolygonBox[{{5.082323870401062, 3.5}, {4.794090994433172, 3.5}, {
       5.000134841831043, 3.5625}, {5.082323870401062, 3.5}}], 
      PolygonBox[{{5.000134841831043, 3.5625}, {5.084292589556053, 
       3.562500018967059}, {5.082323870401062, 3.5}, {5.000134841831043, 
       3.5625}}], 
      PolygonBox[{{5.205909005360398, 3.5}, {5.082323870401062, 3.5}, {
       5.084292589556053, 3.562500018967059}, {5.205909005360398, 3.5}}], 
      PolygonBox[{{5.084292589556053, 3.562500018967059}, {5.230251642536254, 
       3.5626550066464766`}, {5.205909005360398, 3.5}, {5.084292589556053, 
       3.562500018967059}}], 
      PolygonBox[{{5.3576627826493715`, 3.5}, {5.205909005360398, 3.5}, {
       5.230251642536254, 3.5626550066464766`}, {5.3576627826493715`, 3.5}}], 
      PolygonBox[{{5.230251642536254, 3.5626550066464766`}, {
       5.404942744332997, 3.595057255667003}, {5.3576627826493715`, 3.5}, {
       5.230251642536254, 3.5626550066464766`}}], 
      PolygonBox[{{5.5, 3.5}, {5.3576627826493715`, 3.5}, {5.404942744332997, 
       3.595057255667003}, {5.5, 3.5}}], 
      PolygonBox[{{5.404942744332997, 3.595057255667003}, {5.404942744332997, 
       3.595057255667003}, {5.5, 3.5}, {5.404942744332997, 
       3.595057255667003}}], 
      PolygonBox[{{5.5, 3.5}, {5.5, 3.5}, {5.404942744332997, 
       3.595057255667003}, {5.5, 3.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5, 5.}, {4.520833333333333, 5.}, {4.541666666666667, 5.}, {
       4.5625, 5.}, {4.583333333333333, 5.}, {4.604166666666667, 5.}, {4.625, 
       5.}, {4.625, 5.}, {4.604166666666667, 5.}, {4.583333333333333, 5.}, {
       4.5625, 5.}, {4.541666666666667, 5.}, {4.520833333333333, 5.}, {4.5, 
       5.}, {4.5, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.375, 5.}, {5.395833333333333, 5.}, {5.416666666666667, 
       5.}, {5.4375, 5.}, {5.458333333333333, 5.}, {5.479166666666667, 5.}, {
       5.5, 5.}, {5.5, 5.}, {5.479166666666667, 5.}, {5.458333333333333, 
       5.}, {5.4375, 5.}, {5.416666666666667, 5.}, {5.395833333333333, 5.}, {
       5.375, 5.}, {5.375, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 4.5}, {5., 4.520833333333333}, {5., 4.541666666666667}, {
       5., 4.5625}, {5., 4.583333333333333}, {5., 4.604166666666667}, {5., 
       4.625}, {5., 4.625}, {5., 4.604166666666667}, {5., 
       4.583333333333333}, {5., 4.5625}, {5., 4.541666666666667}, {5., 
       4.520833333333333}, {5., 4.5}, {5., 4.5}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 5.375}, {5., 5.395833333333333}, {5., 
       5.416666666666667}, {5., 5.4375}, {5., 5.458333333333333}, {5., 
       5.479166666666667}, {5., 5.5}, {5., 5.5}, {5., 5.479166666666667}, {5.,
        5.458333333333333}, {5., 5.4375}, {5., 5.416666666666667}, {5., 
       5.395833333333333}, {5., 5.375}, {5., 5.375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625, 5.}, {4.75, 5.}, {4.875, 5.}, {5., 5.}, {5.125, 5.}, {
       5.25, 5.}, {5.375, 5.}, {5.375, 5.}, {5.25, 5.}, {5.125, 5.}, {5., 
       5.}, {4.875, 5.}, {4.75, 5.}, {4.625, 5.}, {4.625, 5.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., 4.625}, {5., 4.75}, {5., 4.875}, {5., 5.}, {5., 5.125}, {
       5., 5.25}, {5., 5.375}, {5., 5.375}, {5., 5.25}, {5., 5.125}, {5., 
       5.}, {5., 4.875}, {5., 4.75}, {5., 4.625}, {5., 4.625}}]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYNog4QhojD14zw+FdFog7qRZ2fkpJFHGYoPznU
6wOVPyDicO7b2Zx2flE4DROHqYPpg5kDMxdmz83eMt65c4RR5R2E4fqNOI0m
V3wQgpufcUfatmizENwe7ukrFoj2CjloQO2BmCsEtwcmD7MHRT/QHpj5xlAa
Jg5TdwOqD2YOqvuF4P5DkQe6C6Yf5m6YPSjh54DwN8we9PAHAPMleEo=
      "]], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQFiDjA6FAxE4fzVq0BAxAFVnQiaemE09UJo6gnz
Ue0VQrMXpl4ETb0wmnohNPWYNLo6dHPQ7UF3B7o7ifUnerighxuqvZjhjh4v
MBoAPbtD+g==
      "]], 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{5.265165042944956, 4.734834957055044}, {
       5.3247595264191645`, 4.8125}, {5.404942744332997, 4.595057255667003}, {
       5.265165042944956, 4.734834957055044}}], 
      PolygonBox[{{5.437344993353523, 4.769748357463745}, {5.404942744332997, 
       4.595057255667003}, {5.3247595264191645`, 4.8125}, {5.437344993353523, 
       4.769748357463745}}], 
      PolygonBox[{{5.3247595264191645`, 4.8125}, {5.362222184858401, 
       4.902942858086555}, {5.437344993353523, 4.769748357463745}, {
       5.3247595264191645`, 4.8125}}], 
      PolygonBox[{{5.437499981032941, 4.915707410443938}, {5.437344993353523, 
       4.769748357463745}, {5.362222184858401, 4.902942858086555}, {
       5.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{5.362222184858401, 4.902942858086555}, {5.375, 5.}, {
       5.437499981032941, 4.915707410443938}, {5.362222184858401, 
       4.902942858086555}}], 
      PolygonBox[{{5.4375, 5.}, {5.437499981032941, 4.915707410443938}, {
       5.375, 5.}, {5.4375, 5.}}], 
      PolygonBox[{{5.375, 5.}, {5.362222184858401, 5.097057141913445}, {
       5.4375, 5.}, {5.375, 5.}}], 
      PolygonBox[{{5.437499981032941, 5.084292589556061}, {5.4375, 5.}, {
       5.362222184858401, 5.097057141913445}, {5.437499981032941, 
       5.084292589556061}}], 
      PolygonBox[{{5.362222184858401, 5.097057141913445}, {
       5.3247595264191645`, 5.1875}, {5.437499981032941, 5.084292589556061}, {
       5.362222184858401, 5.097057141913445}}], 
      PolygonBox[{{5.437344993353523, 5.230251642536255}, {5.437499981032941, 
       5.084292589556061}, {5.3247595264191645`, 5.1875}, {5.437344993353523, 
       5.230251642536255}}], 
      PolygonBox[{{5.3247595264191645`, 5.1875}, {5.265165042944956, 
       5.265165042944956}, {5.437344993353523, 5.230251642536255}, {
       5.3247595264191645`, 5.1875}}], 
      PolygonBox[{{5.404942744332997, 5.404942744332997}, {5.437344993353523, 
       5.230251642536255}, {5.265165042944956, 5.265165042944956}, {
       5.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{5.265165042944956, 5.265165042944956}, {5.1875, 
       5.3247595264191645`}, {5.404942744332997, 5.404942744332997}, {
       5.265165042944956, 5.265165042944956}}], 
      PolygonBox[{{5.230251642536255, 5.437344993353523}, {5.404942744332997, 
       5.404942744332997}, {5.1875, 5.3247595264191645`}, {5.230251642536255, 
       5.437344993353523}}], 
      PolygonBox[{{5.1875, 5.3247595264191645`}, {5.097057141913445, 
       5.362222184858401}, {5.230251642536255, 5.437344993353523}, {5.1875, 
       5.3247595264191645`}}], 
      PolygonBox[{{5.0842925895560604`, 5.437499981032941}, {
       5.230251642536255, 5.437344993353523}, {5.097057141913445, 
       5.362222184858401}, {5.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{5.097057141913445, 5.362222184858401}, {5., 5.375}, {
       5.0842925895560604`, 5.437499981032941}, {5.097057141913445, 
       5.362222184858401}}], 
      PolygonBox[{{5.000105527220487, 5.4375}, {5.0842925895560604`, 
       5.437499981032941}, {5., 5.375}, {5.000105527220487, 5.4375}}], 
      PolygonBox[{{5., 5.375}, {4.902942858086555, 5.362222184858401}, {
       5.000105527220487, 5.4375}, {5., 5.375}}], 
      PolygonBox[{{4.915707410443943, 5.437499981032941}, {5.000105527220487, 
       5.4375}, {4.902942858086555, 5.362222184858401}, {4.915707410443943, 
       5.437499981032941}}], 
      PolygonBox[{{4.902942858086555, 5.362222184858401}, {4.8125, 
       5.3247595264191645`}, {4.915707410443943, 5.437499981032941}, {
       4.902942858086555, 5.362222184858401}}], 
      PolygonBox[{{4.769748357463745, 5.437344993353523}, {4.915707410443943, 
       5.437499981032941}, {4.8125, 5.3247595264191645`}, {4.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{4.8125, 5.3247595264191645`}, {4.734834957055044, 
       5.265165042944956}, {4.769748357463745, 5.437344993353523}, {4.8125, 
       5.3247595264191645`}}], 
      PolygonBox[{{4.595057255667003, 5.404942744332997}, {4.769748357463745, 
       5.437344993353523}, {4.734834957055044, 5.265165042944956}, {
       4.595057255667003, 5.404942744332997}}], 
      PolygonBox[{{4.734834957055044, 5.265165042944956}, {
       4.6752404735808355`, 5.1875}, {4.595057255667003, 5.404942744332997}, {
       4.734834957055044, 5.265165042944956}}], 
      PolygonBox[{{4.562655006646477, 5.230251642536255}, {4.595057255667003, 
       5.404942744332997}, {4.6752404735808355`, 5.1875}, {4.562655006646477, 
       5.230251642536255}}], 
      PolygonBox[{{4.6752404735808355`, 5.1875}, {4.637777815141599, 
       5.097057141913446}, {4.562655006646477, 5.230251642536255}, {
       4.6752404735808355`, 5.1875}}], 
      PolygonBox[{{4.562500018967059, 5.084292589556062}, {4.562655006646477, 
       5.230251642536255}, {4.637777815141599, 5.097057141913446}, {
       4.562500018967059, 5.084292589556062}}], 
      PolygonBox[{{4.637777815141599, 5.097057141913446}, {4.625, 5.}, {
       4.562500018967059, 5.084292589556062}, {4.637777815141599, 
       5.097057141913446}}], 
      PolygonBox[{{4.5625, 5.000123178062996}, {4.562500018967059, 
       5.084292589556062}, {4.625, 5.}, {4.5625, 5.000123178062996}}], 
      PolygonBox[{{4.625, 5.}, {4.637777815141599, 4.902942858086555}, {
       4.5625, 5.000123178062996}, {4.625, 5.}}], 
      PolygonBox[{{4.562500018967059, 4.915707410443945}, {4.5625, 
       5.000123178062996}, {4.637777815141599, 4.902942858086555}, {
       4.562500018967059, 4.915707410443945}}], 
      PolygonBox[{{4.637777815141599, 4.902942858086555}, {
       4.6752404735808355`, 4.8125}, {4.562500018967059, 4.915707410443945}, {
       4.637777815141599, 4.902942858086555}}], 
      PolygonBox[{{4.562655006646477, 4.769748357463746}, {4.562500018967059, 
       4.915707410443945}, {4.6752404735808355`, 4.8125}, {4.562655006646477, 
       4.769748357463746}}], 
      PolygonBox[{{4.6752404735808355`, 4.8125}, {4.734834957055044, 
       4.734834957055044}, {4.562655006646477, 4.769748357463746}, {
       4.6752404735808355`, 4.8125}}], 
      PolygonBox[{{4.595057255667003, 4.595057255667003}, {4.562655006646477, 
       4.769748357463746}, {4.734834957055044, 4.734834957055044}, {
       4.595057255667003, 4.595057255667003}}], 
      PolygonBox[{{4.734834957055044, 4.734834957055044}, {4.8125, 
       4.6752404735808355`}, {4.595057255667003, 4.595057255667003}, {
       4.734834957055044, 4.734834957055044}}], 
      PolygonBox[{{4.769748357463745, 4.562655006646477}, {4.595057255667003, 
       4.595057255667003}, {4.8125, 4.6752404735808355`}, {4.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{4.8125, 4.6752404735808355`}, {4.902942858086554, 
       4.637777815141599}, {4.769748357463745, 4.562655006646477}, {4.8125, 
       4.6752404735808355`}}], 
      PolygonBox[{{4.915707410443936, 4.562500018967059}, {4.769748357463745, 
       4.562655006646477}, {4.902942858086554, 4.637777815141599}, {
       4.915707410443936, 4.562500018967059}}], 
      PolygonBox[{{4.902942858086554, 4.637777815141599}, {5., 4.625}, {
       4.915707410443936, 4.562500018967059}, {4.902942858086554, 
       4.637777815141599}}], 
      PolygonBox[{{5.000134841831043, 4.5625}, {4.915707410443936, 
       4.562500018967059}, {5., 4.625}, {5.000134841831043, 4.5625}}], 
      PolygonBox[{{5., 4.625}, {5.097057141913445, 4.637777815141599}, {
       5.000134841831043, 4.5625}, {5., 4.625}}], 
      PolygonBox[{{5.084292589556053, 4.562500018967059}, {5.000134841831043, 
       4.5625}, {5.097057141913445, 4.637777815141599}, {5.084292589556053, 
       4.562500018967059}}], 
      PolygonBox[{{5.097057141913445, 4.637777815141599}, {5.1875, 
       4.6752404735808355`}, {5.084292589556053, 4.562500018967059}, {
       5.097057141913445, 4.637777815141599}}], 
      PolygonBox[{{5.230251642536254, 4.562655006646477}, {5.084292589556053, 
       4.562500018967059}, {5.1875, 4.6752404735808355`}, {5.230251642536254, 
       4.562655006646477}}], 
      PolygonBox[{{5.1875, 4.6752404735808355`}, {5.265165042944956, 
       4.734834957055044}, {5.230251642536254, 4.562655006646477}, {5.1875, 
       4.6752404735808355`}}], 
      PolygonBox[{{5.404942744332997, 4.595057255667003}, {5.230251642536254, 
       4.562655006646477}, {5.265165042944956, 4.734834957055044}, {
       5.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{5.265165042944956, 4.734834957055044}, {5.265165042944956, 
       4.734834957055044}, {5.404942744332997, 4.595057255667003}, {
       5.265165042944956, 4.734834957055044}}], 
      PolygonBox[{{5.404942744332997, 4.595057255667003}, {5.404942744332997, 
       4.595057255667003}, {5.265165042944956, 4.734834957055044}, {
       5.404942744332997, 4.595057255667003}}], 
      PolygonBox[{{5.404942744332997, 4.595057255667003}, {5.437344993353523, 
       4.769748357463745}, {5.5, 4.5}, {5.404942744332997, 
       4.595057255667003}}], 
      PolygonBox[{{5.5, 4.642337217350632}, {5.5, 4.5}, {5.437344993353523, 
       4.769748357463745}, {5.5, 4.642337217350632}}], 
      PolygonBox[{{5.437344993353523, 4.769748357463745}, {5.437499981032941, 
       4.915707410443938}, {5.5, 4.642337217350632}, {5.437344993353523, 
       4.769748357463745}}], 
      PolygonBox[{{5.5, 4.79409099469826}, {5.5, 4.642337217350632}, {
       5.437499981032941, 4.915707410443938}, {5.5, 4.79409099469826}}], 
      PolygonBox[{{5.437499981032941, 4.915707410443938}, {5.4375, 5.}, {5.5, 
       4.79409099469826}, {5.437499981032941, 4.915707410443938}}], 
      PolygonBox[{{5.5, 5.}, {5.5, 4.79409099469826}, {5.4375, 5.}, {5.5, 
       5.}}], PolygonBox[{{5.4375, 5.}, {5.437499981032941, 
       5.084292589556061}, {5.5, 5.}, {5.4375, 5.}}], 
      PolygonBox[{{5.5, 5.20590900530174}, {5.5, 5.}, {5.437499981032941, 
       5.084292589556061}, {5.5, 5.20590900530174}}], 
      PolygonBox[{{5.437499981032941, 5.084292589556061}, {5.437344993353523, 
       5.230251642536255}, {5.5, 5.20590900530174}, {5.437499981032941, 
       5.084292589556061}}], 
      PolygonBox[{{5.5, 5.357662782649368}, {5.5, 5.20590900530174}, {
       5.437344993353523, 5.230251642536255}, {5.5, 5.357662782649368}}], 
      PolygonBox[{{5.437344993353523, 5.230251642536255}, {5.404942744332997, 
       5.404942744332997}, {5.5, 5.357662782649368}, {5.437344993353523, 
       5.230251642536255}}], 
      PolygonBox[{{5.491446564961186, 5.491446564961186}, {5.5, 
       5.357662782649368}, {5.404942744332997, 5.404942744332997}, {
       5.491446564961186, 5.491446564961186}}], 
      PolygonBox[{{5.404942744332997, 5.404942744332997}, {5.230251642536255, 
       5.437344993353523}, {5.491446564961186, 5.491446564961186}, {
       5.404942744332997, 5.404942744332997}}], 
      PolygonBox[{{5.357662782649368, 5.5}, {5.491446564961186, 
       5.491446564961186}, {5.230251642536255, 5.437344993353523}, {
       5.357662782649368, 5.5}}], 
      PolygonBox[{{5.230251642536255, 5.437344993353523}, {
       5.0842925895560604`, 5.437499981032941}, {5.357662782649368, 5.5}, {
       5.230251642536255, 5.437344993353523}}], 
      PolygonBox[{{5.205909005373256, 5.5}, {5.357662782649368, 5.5}, {
       5.0842925895560604`, 5.437499981032941}, {5.205909005373256, 5.5}}], 
      PolygonBox[{{5.0842925895560604`, 5.437499981032941}, {
       5.000105527220487, 5.4375}, {5.205909005373256, 5.5}, {
       5.0842925895560604`, 5.437499981032941}}], 
      PolygonBox[{{5.07794195802689, 5.5}, {5.205909005373256, 5.5}, {
       5.000105527220487, 5.4375}, {5.07794195802689, 5.5}}], 
      PolygonBox[{{5.000105527220487, 5.4375}, {4.915707410443943, 
       5.437499981032941}, {5.07794195802689, 5.5}, {5.000105527220487, 
       5.4375}}], 
      PolygonBox[{{4.794090994695554, 5.5}, {5.07794195802689, 5.5}, {
       4.915707410443943, 5.437499981032941}, {4.794090994695554, 5.5}}], 
      PolygonBox[{{4.915707410443943, 5.437499981032941}, {4.769748357463745, 
       5.437344993353523}, {4.794090994695554, 5.5}, {4.915707410443943, 
       5.437499981032941}}], 
      PolygonBox[{{4.642337217350634, 5.5}, {4.794090994695554, 5.5}, {
       4.769748357463745, 5.437344993353523}, {4.642337217350634, 5.5}}], 
      PolygonBox[{{4.769748357463745, 5.437344993353523}, {4.595057255667003, 
       5.404942744332997}, {4.642337217350634, 5.5}, {4.769748357463745, 
       5.437344993353523}}], 
      PolygonBox[{{5.5, 5.5}, {4.642337217350634, 5.5}, {4.595057255667003, 
       5.404942744332997}, {5.5, 5.5}}], 
      PolygonBox[{{4.595057255667003, 5.404942744332997}, {4.562655006646477, 
       5.230251642536255}, {5.5, 5.5}, {4.595057255667003, 
       5.404942744332997}}], 
      PolygonBox[{{4.5, 5.357662782649369}, {5.5, 5.5}, {4.562655006646477, 
       5.230251642536255}, {4.5, 5.357662782649369}}], 
      PolygonBox[{{4.562655006646477, 5.230251642536255}, {4.562500018967059, 
       5.084292589556062}, {4.5, 5.357662782649369}, {4.562655006646477, 
       5.230251642536255}}], 
      PolygonBox[{{4.5, 5.205909005282899}, {4.5, 5.357662782649369}, {
       4.562500018967059, 5.084292589556062}, {4.5, 5.205909005282899}}], 
      PolygonBox[{{4.562500018967059, 5.084292589556062}, {4.5625, 
       5.000123178062996}, {4.5, 5.205909005282899}, {4.562500018967059, 
       5.084292589556062}}], 
      PolygonBox[{{4.5, 5.0806786667587005`}, {4.5, 5.205909005282899}, {
       4.5625, 5.000123178062996}, {4.5, 5.0806786667587005`}}], 
      PolygonBox[{{4.5625, 5.000123178062996}, {4.562500018967059, 
       4.915707410443945}, {4.5, 5.0806786667587005`}, {4.5625, 
       5.000123178062996}}], 
      PolygonBox[{{4.5, 4.794090994854722}, {4.5, 5.0806786667587005`}, {
       4.562500018967059, 4.915707410443945}, {4.5, 4.794090994854722}}], 
      PolygonBox[{{4.562500018967059, 4.915707410443945}, {4.562655006646477, 
       4.769748357463746}, {4.5, 4.794090994854722}, {4.562500018967059, 
       4.915707410443945}}], 
      PolygonBox[{{4.5, 4.642337217350635}, {4.5, 4.794090994854722}, {
       4.562655006646477, 4.769748357463746}, {4.5, 4.642337217350635}}], 
      PolygonBox[{{4.562655006646477, 4.769748357463746}, {4.595057255667003, 
       4.595057255667003}, {4.5, 4.642337217350635}, {4.562655006646477, 
       4.769748357463746}}], 
      PolygonBox[{{4.5, 5.5}, {4.5, 4.642337217350635}, {4.595057255667003, 
       4.595057255667003}, {4.5, 5.5}}], 
      PolygonBox[{{4.595057255667003, 4.595057255667003}, {4.769748357463745, 
       4.562655006646477}, {4.5, 5.5}, {4.595057255667003, 
       4.595057255667003}}], 
      PolygonBox[{{4.5, 4.5}, {4.5, 5.5}, {4.769748357463745, 
       4.562655006646477}, {4.5, 4.5}}], 
      PolygonBox[{{4.769748357463745, 4.562655006646477}, {4.915707410443936, 
       4.562500018967059}, {4.5, 4.5}, {4.769748357463745, 
       4.562655006646477}}], 
      PolygonBox[{{4.794090994433172, 4.5}, {4.5, 4.5}, {4.915707410443936, 
       4.562500018967059}, {4.794090994433172, 4.5}}], 
      PolygonBox[{{4.915707410443936, 4.562500018967059}, {5.000134841831043, 
       4.5625}, {4.794090994433172, 4.5}, {4.915707410443936, 
       4.562500018967059}}], 
      PolygonBox[{{5.082323870401062, 4.5}, {4.794090994433172, 4.5}, {
       5.000134841831043, 4.5625}, {5.082323870401062, 4.5}}], 
      PolygonBox[{{5.000134841831043, 4.5625}, {5.084292589556053, 
       4.562500018967059}, {5.082323870401062, 4.5}, {5.000134841831043, 
       4.5625}}], 
      PolygonBox[{{5.205909005360398, 4.5}, {5.082323870401062, 4.5}, {
       5.084292589556053, 4.562500018967059}, {5.205909005360398, 4.5}}], 
      PolygonBox[{{5.084292589556053, 4.562500018967059}, {5.230251642536254, 
       4.562655006646477}, {5.205909005360398, 4.5}, {5.084292589556053, 
       4.562500018967059}}], 
      PolygonBox[{{5.3576627826493715`, 4.5}, {5.205909005360398, 4.5}, {
       5.230251642536254, 4.562655006646477}, {5.3576627826493715`, 4.5}}], 
      PolygonBox[{{5.230251642536254, 4.562655006646477}, {5.404942744332997, 
       4.595057255667003}, {5.3576627826493715`, 4.5}, {5.230251642536254, 
       4.562655006646477}}], 
      PolygonBox[{{5.5, 4.5}, {5.3576627826493715`, 4.5}, {5.404942744332997, 
       4.595057255667003}, {5.5, 4.5}}], 
      PolygonBox[{{5.404942744332997, 4.595057255667003}, {5.404942744332997, 
       4.595057255667003}, {5.5, 4.5}, {5.404942744332997, 
       4.595057255667003}}], 
      PolygonBox[{{5.5, 4.5}, {5.5, 4.5}, {5.404942744332997, 
       4.595057255667003}, {5.5, 4.5}}], {}, {}, {}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404669645441*^9, 3.566101161985291*^9, 
  3.614727722067503*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->
  "During evaluation of \
In[256]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[plot = TurboPlot[
\t{PointOfRays[{10,10}, NumberOfRays->33, BirthPoint->{-100,10,10}],
\tlenslet,
\tMove[Screen[{15,15}, GraphicDesign->Off],2.3]}, PlotType->Full3D, \
ReportedSurfaces->All, CreateClones -> positions, \
RunningCommentary->TurboTrace, CloneSortLength->2, \
PlotRange->{{-5,3},{-6.5,6.5},{-6.5,6.5}}]][[1]]\
\>", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[257]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722423603*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277224276533`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277224296293`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277224313726`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "5.`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "5.`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "2"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`PlotType -> Optica`Optica`Full3D, 
     Optica`Optica`ReportedSurfaces -> All, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJx1lsFNQzEQRC24cMwhDVCJXQMlIHHmTHX8klJCOOysxJsdS9GXnxb/2ckQ
7/vn98fXy1rr5+/zurju1/8n+S3wt8BX4I/fUB/0PHaoP0FP4LfA7+Dqk7rE
6YP29KHrAqcPPNfq98zpQ+sJnD50v+Dqhz6IU684feh94PSBf2/1e+b0ofUE
Th+6X3DptpzqnMCtjwtPcPpgdazfM6cPrSdw+tD9gksffRCnD+L0ofsMnD6Y
L6zfM6cPrSdw+tD9gmul3630f5xynb7n1HdalgetM2PLQy3LQy3LQ73P8lDc
8lDc8iDdgVseQp9dzzxof4KewC0P6hdc51oeilseilsedG7glgfqYD19OnhS
T+CWh9rbfSF+zdzuC703cLsvitt9QX2s532h+jNzuy9qb/dF7W1+EL9mbvOD
3hu4zQ/FbX6ADqvn/KD6M3ObH878nu4XXHubJ3VO4DZP6tzAbZ6EDqvnPKn6
M3ObJ2tv8+TR8wlCC6DM
      "], Optica`Optica`RunningCommentary -> 
     Optica`Optica`TurboTrace, Optica`Optica`CloneSortLength -> 2, 
     PlotRange -> {{-5, 3}, {-6.5, 6.5}, {-6.5, 6.5}}, 
     RuntimeAttributes -> {Listable}, Parallelization -> False, 
     CompilationTarget -> "MVM", RuntimeOptions -> "Speed", 
     Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`PlotType -> 
     Optica`Optica`Full3D, Optica`Optica`ReportedSurfaces -> All, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJx1lsFNQzEQRC24cMwhDVCJXQMlIHHmTHX8klJCOOysxJsdS9GXnxb/2ckQ
7/vn98fXy1rr5+/zurju1/8n+S3wt8BX4I/fUB/0PHaoP0FP4LfA7+Dqk7rE
6YP29KHrAqcPPNfq98zpQ+sJnD50v+Dqhz6IU684feh94PSBf2/1e+b0ofUE
Th+6X3DptpzqnMCtjwtPcPpgdazfM6cPrSdw+tD9gksffRCnD+L0ofsMnD6Y
L6zfM6cPrSdw+tD9gmul3630f5xynb7n1HdalgetM2PLQy3LQy3LQ73P8lDc
8lDc8iDdgVseQp9dzzxof4KewC0P6hdc51oeilseilsedG7glgfqYD19OnhS
T+CWh9rbfSF+zdzuC703cLsvitt9QX2s532h+jNzuy9qb/dF7W1+EL9mbvOD
3hu4zQ/FbX6ADqvn/KD6M3ObH878nu4XXHubJ3VO4DZP6tzAbZ6EDqvnPKn6
M3ObJ2tv8+TR8wlCC6DM
      "], Optica`Optica`RunningCommentary -> 
     Optica`Optica`TurboTrace, Optica`Optica`CloneSortLength -> 2, 
     PlotRange -> {{-5, 3}, {-6.5, 6.5}, {-6.5, 6.5}}, 
     RuntimeAttributes -> {Listable}, Parallelization -> False, 
     CompilationTarget -> "MVM", RuntimeOptions -> "Speed", 
     Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722442452*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277224574203`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722459661*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.10840299999999999935873518097650958225`5.055641214535656", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.10840299999999999935873518097650958225`5.055641214535656, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722496663*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722499426*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722502261*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722505204*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.61472772250813*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277226173973`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722619089*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.61472772262075*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722622848*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722853469*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722855191*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277228568697`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727722858594*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"PointOfRays", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"10", ",", "10"}], "}"}], ",", 
             RowBox[{"NumberOfRays", "\[Rule]", "33"}], ",", 
             RowBox[{"BirthPoint", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "100"}], ",", "10", ",", "10"}], "}"}]}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "10", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.9901475429766743`", ",", 
              RowBox[{"-", "0.09901475429766744`"}], ",", 
              RowBox[{"-", "0.09901475429766744`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.09950371902099892`", ",", "0.9950371902099892`", ",", "0.`"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09852336290568345`", ",", 
              RowBox[{"-", "0.009852336290568343`"}], ",", 
              "0.9950859653474028`"}], "}"}]}], "}"}]}], "}"}]}], "}"}], 
      "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`PointOfRays[{
           Optica`Optica`Ray[]}, {10, 10}, Optica`Optica`NumberOfRays -> 33, 
          Optica`Optica`BirthPoint -> {-100, 10, 10}, 
          Optica`Optica`SourceTransformation -> {{0., 0., 0.}, {{1., 0., 
            0.}, {0., 1., 0.}, {0., 0., 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-100, 10, 10}, {{
         0.9901475429766743, -0.09901475429766744, -0.09901475429766744}, {
         0.09950371902099892, 0.9950371902099892, 0.}, {
         0.09852336290568345, -0.009852336290568343, 0.9950859653474028}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-100, 10, 
         10}, {{5 
           Rational[2, 51]^Rational[1, 2], -102^Rational[-1, 2], -102^
            Rational[-1, 2]}, {
          101^Rational[-1, 2], 10 101^Rational[-1, 2], 0}, {
          5 Rational[2, 5151]^Rational[1, 2], -10302^Rational[-1, 2], 
           Rational[101, 102]^Rational[1, 2]}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 33, 
       Optica`Optica`BirthPoint :> {-100, 10, 10}, 
       Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 65797, 
       Optica`Optica`SourceFraction :> {1, 1}, 
       Optica`Optica`SourceOffset :> {0, 0}, 
       Optica`Optica`GridSpacing :> {#& , #& }, Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues :> {}], False, False, False, 
      False, {{-100, 10, 10}, {{
       0.9901475429766743, -0.09901475429766744, -0.09901475429766744}, {
       0.09950371902099892, 0.9950371902099892, 0.}, {
       0.09852336290568345, -0.009852336290568343, 0.9950859653474028}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277228608227`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277231230183`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727723124938*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727723126602*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727723285022*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277233366413`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727723339653*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727723342114*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727723344805*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "2"}],
  SequenceForm["maximum used clone sort position = ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724033546*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1017", ",", "72"}], "}"}]}],
  SequenceForm["Histogram of used sort positions: ", {1017, 72}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277240354633`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({1017, 72}\\)\\), \
\\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] All\\)\\)\\)\\)]\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727724088682*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You may wish to set CloneSortLength -> \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["You may wish to set CloneSortLength -> ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.61472772409761*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "0.83959499999999998021138480908120982349`5.944669756864505", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "2087",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   0.83959499999999998021138480908120982349`5.944669756864505, 
   " seconds with ", 2087, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.61472772415532*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277241584473`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277241619596`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277241641483`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724165762*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"DrawSurfaceWithHole:1 called for rectangle and circle \
boundaries.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724167325*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"RectCirc called.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724168888*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"DrawSurfaceWithHole:1 called for rectangle and circle \
boundaries.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724170434*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"RectCirc called.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277241719847`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"getSurfaceNetRectCirc called.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277241746063`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277241775093`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724249531*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727724808506*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.6147277250921926`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[257]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJy03X+UXmV19/9JMgTCjJAMyVhLXfWrYBAQbEQoViRtoRTll9KFgvBEASsW
BKFAqV2lAX88Igs0gl/EaB4aC0griAKVx/ptbihIGgyiAoYQJQ2hxSCUqsDw
I+Qb5zp7yN7XeV/77Gvu9B+7Zn3W63NYOefc596z77n/nxPPePcHpw0MDBy0
98DA4Ob//c3//+bx//vxgfNmzLvsvKdGevc8s/K0/73jnJ78/JQ1Ox9w1k0j
vYHf/F9v9sTPTzz2zBuP+cBIb8k1lx553ZKX8+R897F3Ld1t/kjv4j13H73r
cd+hXnIoP3TF166ac8lIb+5ZF/3yxJPqnamrD54ysDn/TO+Ju486xneolxzK
jx/HwuZ4BibpzO/uUC85lJfjefCSc1/xlS/vVO3IcQ4dOLLPN67zHeolh/Lq
fJhf78h5cs6P7//578/2Heolh/JyPcr/1jpyncr/eg71kkN5OQ45rlpHjk+O
13OolxzKy3kg50WtM9ycH3K+eA71kkN5ua7kuqx1fme3Nx2zftNOPblePYd6
yaG83Ae7Hg85TzX3R3uc5FAvOZQfdze/DtnzIerI65M9T8ihXnIoL88B9nqM
OvJ8YK9TcqiXHMp/8XXrb7/ksDnZ/TDqHPTKG074ybI52X2SHOolh/JPn/Ke
BRvOmtNbZV6Pos5Lu37npU2b89ub1ylyqJccyqfrcE72+l7l9Ob0vr/xa7c8
vMk/Huolh/JyPK3PYwFHjvPJtue0Fod6yaG8Oh969Y6cJ58xz8nkUC85lJfr
0b4fiTpyndr3KeRQLzmUl+OQ46p15D4px+s51EsO5XdrzgM5L2qdseb8kPPF
c6iXHMrr54F65/QXNlyzRp4Ter5DveRQXp7Huh4PObOb+6M9TnKolxzKy+uQ
PR+izrnN65M9T8ihXnIoT/OQqENzEnKoNzq36ZdD+a3t0HwmnecyNxh1Hcmv
/M8Zcw88Pf+5dbxe61C+OJ8JOJLfd/3pP3jwR77j9VqnmKc5T9QZ6O54va0/
L8zHWudOAUfyK3Ze9KbXv9F3vF7rUJ7mM1FH8m9+1TOreovs++Xc8XqtQ/ni
fCbgfHj7I//g9u1GevK/nkO95FCe5jNRR45v4ngdh3rJoTzNZ6LOH/3HZ8fP
D5snh3rJoTzNZ6LO/nP/vxf2vjHPk0O95FCe5jNR59VPpfujzZNDveRQnuYz
Uefu5vXJ5smhXnIoT/OZqCM5myeHesmhPM1nok7Kjfbmwf3fOuXe3KF8cT4T
cCR/7eltr7+54/Vap5inOU/U2Zx//65Hf/7E6zv+dxV6W53CfKx17hRwJD+6
z2ktz5+54/Vah/I0n4k6kl/R+vyfO16vdShfnM8EHMnb65Qcr5fuGzZfnPME
HJ0fdZ1uvaNuvjyf6e7MOesvt3idouMfdXvJoTzNZ6LOdisue8dN/7RTlieH
esmhPM1nos4PXvW5LZ7TRl2HesmhPM1nos7e6jl51HWolxzK0zwk6sj1afPk
eHOYrvl+OZTvl6PnXbMmfq73kWaCP8t19FzId6iXHMrrfaR6R8+FfId6yaH8
+HEslH+vSTrzuzvUSw7l5Xi+ufMTv/3W/XesduQ455y/yyn/62jfoV5yKK/O
h4U7VDtynjx+zT/9+MzdfId6yaG8XI8fHDn59f+z9hXVjlynd3xr3fuvv33Y
daiXHMqnf9+devfeut/H1v95vSPvx8774VcPetfCYdehXnIoL78PGt3rXX+4
x2/XOzIXGrz54qkDW+TJoV5yKJ+uK3m+qnfUXGiLPDnUSw7lZQ+g6/GQI3Mh
e5zkUC85lB93e7Oz8yHqyPsCe56QQ73kUF5+f2avx6gjzzH2OiWHesmhvNrH
2OJ+GHXkeXSDuU+SQ73kUF5+D21fj6KOvB+YbV6nyKFeciifjkPmkzMn52x+
P3blC+86ddkm/3iolxzK632kekfPhXyHesmhvN5Hqnf0XMh3qJccyut9pFnV
jp4L+Q71kkN5uR+m46p39FzId6iXHMrrfaR6R8+FfId6yaG8eh5YWO/ouZDv
UC85lNf7SPWOngv5DvWSQ/lxd2Ifqd7RcyHfoV5yKE/zkKhDcxJyqDc6t+mX
Q/mt7dB8Jp3n+e8NyZFc2lPKf24dr9c6lC/OZwKO5NOeku94vdYp5mnOE3UG
ujteb+vPC/Ox1rlTwJH8Zfu99gOHHbeD63i91qE8zWeijuQ/NO8X37zgdXY+
kDter3UoX5zPBBzZT/rR7CXnfmKW71AvOZSn+UzU0XtKvkO95FCe5jNRR+8p
+Q71kkN5ms9EHb2n5DvUSw7laT4TdfSeku9QLzmUp/lM1NF7Sr5DveRQnuYz
UUfuMzZPDvWSQ3maz0SdlBvtnQz3f+uUe3OH8sX5TMCR/OE/bXv9zR2v1zrF
PM15os7m/G3vuGaXO4/zHa+31SnMx1rnTgFH8mlPyXe8XutQnuYzUUfyK1qf
/3PH67UO5YvzmYAjeXudkuP10n3D5otznoCj8/n+mHW69dK+Vtf5THdH7ynR
8Y+4veRQnuYzUUfvKY24DvWSQ3maz0Qdvac04jrUSw7laT4TdfaGzymQQ73k
UJ7mIVFHcjZPjjeH6Zrvl0P5fjky71r8xOIHd/jd7Sd+rvcxZmT+2w5/9f95
9wFDriPvi0eP/bM9L/2J71AvOZSXfZgj1488euf3tqt2ZC7x+AUPXfH3X/cd
6iWH8uk45N9rks787g71kkN5vY+0bbWj50K+Q73kUF6fD9OrHT0X8h3qJYfy
eh9pm2pHz4UGXYd6yaF8+veVfaR6R8+FBl2HesmhvN5Hqnf0XGjQdaiXHMqn
60qer+odPRcadB3qJYfyeh+p3tFzoUHXoV5yKD/uTuwj1Tt6LjToOtRLDuX1
PlK9o+dCg65DveRQXu8jTa929FzId6iXHMrrfaRtqx09F/Id6iWH8uk4ZD65
3eScibmQfzzUSw7l5XiOaHseCzhynGvantNaHOolh/L6fJhR7ch5Msc8J5ND
veRQXq5H+34k6sh1at+nkEO95FBe7odvOmT5J3e+st6R++Sn9zr+X274uyHX
oV5yKC/7SBt+eMO/3vdovSNzoRffefbGTVvkyaFeciivnweGqh01F1roO9RL
DuXleazr8ZAjcyF7nORQLzmUH3c3Pw/b8yHqyFzInifkUC85lKd5SNShOQk5
1Bud2/TLofzWdmg+k87v/PeG5Ej+Syt3OuL8Nfb+kDter3UoX5zPBBzJf2T5
T5fcdLV/PF6vdYp5mvNEnYHujtfb+vPCfKx17hRwJJ/2lKa7jtdrHcrTfCbq
SD7tKdn5QO54vdahfHE+E3D0npLvUC85lKf5TNTRe0q+Q73kUJ7mM1FH7yn5
DvWSQ3maz0QdvafkO9RLDuVpPhN19J6S71AvOZSn+UzU0XtKvkO95FCe5jNR
R+4zNk8O9ZJDeZrPRJ2Ukz2l/P5vnXJv7lC+OJ8JOJJPe0r+8Xi91inmac4T
dSb2lHzH6211CvOx1rlTwJH8G09Z1fL8mTter3UoT/OZqCP5y1uf/3PH67UO
5YvzmYAjeXudkuP10n3D5otznoCj8/n+mHW69eb7WjZfns90d/SeEh3/sNtL
DuVpPhN19J7SsOtQLzmUp/lM1NF7SsOuQ73kUJ7mM1Fnb/icAjnUSw7laR4S
dVIuz5PjzWG65vvlUL5fjp53TZ34ud7HmAL+NNfRcyHfoV5yKK/3kQaqHT0X
8h3qJYfy6Tjk32uSzvzuDvWSQ3k5npP2W/2Ws896aVmtI8e5+4t/eu93r/Ed
6iWH8up8GNhY7ch5cv/h77n2kaNedB3qJYfycj2u2GX5Yetue6Hakev00x+8
87bjPvmc61AvOZRP/7479a4684xfL1/5fLUjc6Gnlh5y0dKB51yHesmhvPw+
aM/jl154zD71jsyFZpzyym0GtsiTQ73kUD6dB/J8Ve+oudAWeXKolxzKyz5S
1+MhR+ZC9jjJoV5yKJ/uarOz8yHqyPsCe56QQ73kUF72Aez1GHXkfZm9Tsmh
XnIor/YxtrgfRh15X3yfuU+SQ73kUF72YU40r0dRR+YSc83rFDnUSw7lxw9j
4ZzepvR/k3N6c3rznv3qA+d3cKiXHMrrfSTznBNw9FzId6iXHMrrfaQp1Y6e
C/kO9ZJDeb2PNLXa0XOhaa5DveRQXu6HaR+j3tFzoWmuQ73kUF7vI9U7ei40
zXWolxzK6+eBadWOngv5DvWSQ3m9j+QfDzl6LuQfD/WSQ/lxd2Ifqd7RcyH/
v4t6yaE8zUOiDs1JyKHe6NymXw7lt7ZD85l0fue/NyRH8mlPyd4fcsfrtQ7l
i/OZgCP5tKfkH4/Xa51inuY8UWegu+P1tv68MB9rnTsFHMnPPeOg279484uu
4/Vah/I0n4k6kr/n5FUnTTvEzgdyx+u1DuWL85mAI3tK//CGtz2x3evGXId6
yaE8zWeijt5TGnMd6iWH8jSfiTp6T2nMdaiXHMrTfCbq6D2lMdehXnIoT/OZ
qKP3lMZch3rJoTzNZ6KO3lMacx3qJYfyNJ+JOnKfsXlyqJccytN8Juqk3Gjv
Lrj/W6fcmzuUL85nAo7kF3/n4JbX39zxeq1TzNOcJ+pszl/whcMO/cwt/vF4
va1OYT7WOncKOJJPe0r2+TN3vF7rUJ7mM1FH8pe3Pv/njtdrHcoX5zMBR/L2
OiXH66X7hs0X5zwBR+fz/THrdOulfa2u85nujt5TouMfdHvJoTzNZ6KO3lMa
dB3qJYfyNJ+JOnpPadB1qJccytN8JursDZ9TIId6yaE8zUOiTsrleXK8OUzX
fL8cyvfLkXnXvg/td9Or3/7rifuY3sf4VfY+8bwvvfXtV3/smWWeI++L9/jW
1977O9/wHeolh/KyD7Nk+a4rLr7kf6odmUs8MO3be//xsb5DveRQPt1H5Hie
mpwzv7tDveRQXo7nztNvPvWx9b+oduQ4/2xs0VV/ffgTrkO95FBenw8bqh05
T/5x8Q1H3PX3j7kO9ZJDebkeLz/0c1fe8fH/qnbkOp1592c+fsv2j7gO9ZJD
+fTvu1Nv/iM/e2zR4kerHZkLrT34syMHT1nnOtRLDuXl90HvvfWgba4/ZX21
I3OhkXv32n5gYJ3rUC85lE/ngTxf1Tt6LrTOdaiXHMrLPlLX4yFH5kL2OMmh
XnIoP872ZmfnQ9SR9wX2PCGHesmhvOwDXGaux6gj78vsdUoO9ZJDednHSOsw
P6925H3xteY+SQ71kkN52Ye5w7weRR2ZSxxpXqfIoV5yKJ+eB+b0Xho/nv+e
nNOb0zv5yUOu3/iS71AvOZSX4/lK2/NYwJHj/Hbbc1qLQ73kUF6fD7+sduQ8
2d08J5NDveRQXq5H+34k6sh1at+nkEO95FBe7ofvv/RzQ/vNe7rakfvkzBNu
PfeETc+4DvWSQ3nZR7rvqyf87XV31zsyF3r2isee37RFnhzqJYfy+nngmWpH
zYUGnnUd6iWH8vI81vV4yJG5kD1OcqiXHMqPs5ufh+35EHVkLmTPE3KolxzK
0zwk6tCchBzqjc5t+uVQfms7NJ9J52v+e0NyJP/mxXO//OKt9v6QO16vdShf
nM8EHMmv/ty/HPChd/rH4/Vap5inOU/UGejueL2tPy/Mx1rnTgFH8of/7NOf
+L0P/9x1vF7rUJ7mM1FH8ov//ca7pl9q5wO54/Vah/LF+UzAkT2lQ48+b/Ws
P1nrOtRLDuVpPhN19J7SWtehXnIoT/OZqKP3lNa6DvWSQ3maz0Qdvae01nWo
lxzK03wm6ug9pbWuQ73kUJ7mM1FH7ymtdR3qJYfyNJ+JOnKfsXlyqJccytN8
Juqk3GjvUrj/W6fcmzuUL85nAo7k9z3n4pbX39zxeq1TzNOcJ+pszk/d48rP
zz7VPx6vt9UpzMda504BR/LH3Xtjy/Nn7ni91qE8zWeijuR3a33+zx2v1zqU
L85nAo7k7XVKjtdL9w2bL855Ao7O5/tj1unWm+9r2Xx5PtPd0XtKdPxjbi85
lKf5TNTRe0pjrkO95FCe5jNRR+8pjbkO9ZJDeZrPRJ294XMK5FAvOZSneUjU
Sbk8T443h+ma75dD+X45Mu968LSHv3/u2L0TP9f7GMsz/+EPbxi7fMODriPv
i9+36OA715230nWolxzKyz7M6ouOX/rdVbdWOzKXOPGAj74w7/JbXId6yaH8
+GFM7CMNDEzKmd/doV5yKC/H80A6ngNrHTnOBek4XYd6yaG8nA/p96F3VTty
nhyTzhPXoV5yKG+ux2pHrtO16Tp1Heolh/Lp33en3sL9/2ivNcvvq3ZkLjT/
7P9Yfc7Gh1yHesmhvPw+6MjPnvv01Xv9pNqRudBPFyx9fNOmh1yHesmhfLqq
5PlqVbWj50JrXId6yaG87CMd1fF4yJG5kD1OcqiXHMqPs73Z2fkQdeR9gT1P
yKFecigv+wCrzfUYdeR9mb1OyaFecigv+xiD4we2vNqR98Unm/skOdRLDuVl
H2ateT2KOjKXuNi8TpFDveRQPj0PzOl9fOnco49YcsPbJuX05vS+cOerLthj
19e4x0O95FBejueetuexgCPH+Vd/0PKc1uJQLzmUl/NhLD0PVDtynhxunpPJ
oV5yKC/Xo30/EnXkOrXvU8ihXnIoL/fD89P9sNox90nXoV5yKC/7SEek16Nq
Z0y/TrkO9ZJDefM8UO3oudAa16Fecigvz2NHdTwecmbr5zTXoV5yKD/Obn4e
vtCcD1HnXP2c7DrUSw7l5f3IanM9Rh3zPsV1qJccytM8J+rQnMdzqJcc+3Oa
z6TzNf+9ITmS//5pSz76y0cecB2v1zqUL85nAo7kV35qzRP7v2+F63i91inm
ac4TdQa6O15v688L87HWuVPAkfzd6Thdx+u1DuVpPhN1JL8inSeu4/Vah/LF
+UzAkT2l04/d8Z1r/vJh16FecihP85moY/aUXId6yaE8zWeijtlTch3qJYfy
NJ+JOmZPyXWolxzK03wm6pg9JdehXnIoT/OZqGP2lFyHesmhPM1noo7cZ2ye
HOolh/I0n4k6KTfaWw/3f+uUe3OH8sX5TMCR/O57/Kjl9Td3vF7rFPM054k6
m/NPXrvvqe+79uZu/12F3lanMB9rnTsFHMn/4MJPtTx/5o7Xax3K03wm6kh+
aevzf+54vdahfHE+E3Akb69Tcrxeum/YfHHOE3BM3nU69rrHWZ7PdHf0nhIe
v9tLDuVpPhN19J7SWtehXnIoT/OZqKP3lNa6DvWSQ3maz0SdveFzCuRQLzmU
p/lM1Em5PE8O9ZJDeW+eM9lez+naa/5uzMR9zPw9nAOt3+zJH+g58r74urSX
7jrUSw7lzd8jqnbM58Jch3rJofz4YUzsIz01OWd+d4d6yaG8HE/z9xCqHfO5
SNehXnIob/4eWrVjPpfqOtRLDuXN54irHbPP6TrUSw7l07/vxOfBq51z9F6u
61AvOZQ3n8evdob1XrTrUC85lE/nwcTfQ6h29FzoWdehXnIoP1f/PYpq5yn9
uQDXoV5yKD/Ovvz3QKod87kM16Fecihv/h5LtWM+F+M61EsO5fX38f2q2pH3
xXua+yQ51EsO5WUfZol5PYo6Mpd40LxOkUO95FB+/DAWzulNMa/vVU5vTu+e
7Y5/wwUdHOolh/JyPN9rex4LOHKci9qe01oc6iWH8nI+TB0v2lDtyHlyvXlO
Jod6yaG8XI/2/UjUMZ8Ldh3qJYfycj/8w/T3AKsd87ls16Fecigv+0jHpr/H
WO2M6c/Fuw71kkN5/TxQ7+i50DrXoV5yKG/+Hmm1M1v/XQjXoV5yKD/Obn4e
PtCcD1HnXP13OVyHesmhvLwfucxcj1GH5iTkUK83t7F5mudEHcpH50hRh+Yz
6XzNf29IjuS/lP5Ogut4vdahfHE+E3Ak3/ydItfxeq1TzNOcJ+oMdHe83taf
F+ZjrXOngCP5B9Pf6XIdr9c6lKf5TNSR/Lz0dxJcx+u1DuWL85mAI3tKxz/w
byPPrrHv93OHesmhPM1noo75nj7XoV5yKE/zmahjvqfPdaiXHMrTfCbqmO/p
cx3qJYfyNJ+JOuZ7+lyHesmhPM1noo75nj7XoV5yKE/zmagj9xmbJ4d6yaE8
zWeiTsqN9vaH+791yr25Q/nifCbgSP6DB3+n5fU3d7xe6xTzNOeJOpvzf/cX
N/3zOe/wj8frbXUK87HWuVPAkfxhC5a0PH/mjtdrHcrTfCbqSP4brc//ueP1
WofyxflMwJG8vU7J8XrpvmHzxTlPwNH5fH/MOt16830tmy/PZ7o7Zk/JdaiX
HMrTfCbqmD0l16FecihP85moY/aUXId6yaE8zWeizt7wOQVyqJccytM8JOqk
XJ4nx5vDdM33y6F8vxyZd63YZflh6257YeLneh9jY+Y33xPtOvK++P70vcyu
Q73kUF72YU7cb/Vbzj7rpWpH5hK7p+9ldh3qJYfy44cxsY80MH9SzvzuDvWS
Q3k5niPXjzx65/fqHTnOx9P3MrsO9ZJDeXU+LJxS7ch50nwvs+tQLzmUl+tx
8ROLH9zhd6dWO+b7TF2HesmhfPpX3an3pkOWf3LnK+sdmQs130vrOtRLDuXl
90EbfnjDv973aL0jc6Hme4Fdh3rJoXy6rOT5alq1o+ZCC32HesmhvOwjdT0e
cmQuZI+THOolh/Ljbm92dj5EHfO95K5DveRQXvYB7PUYdcz3wrsO9ZJDebWP
tMX9MOrI++JRc58kh3rJobzsw9jXo6gjc4lfmNcpcqiXHMqn45D55CSd3pze
hwZvuHx+B4d6yaG8HM9Jbc9jAUeO89C257QWh3rJobycD2kfbGO1I+fJA+Y5
mRzqJYfycj3a9yNRR65T+z6FHOolh/JyP7zqzDN+vXzl89WO3CefWnrIRUsH
nnMd6iWH8rKPtOfxSy88Zp96R+ZCM0555TYDW+TJoV5yKK+fB+odPRd6znWo
lxzKy/NY1+MhR+ZC9jjJoV5yKJ/ugjtl50PUkbmQPU/IoV5yKE/zkKhDcxJy
qDc6t+mXQ/mt7dB8Jp2v+e8NyZH8ypNXnTTtEHt/yB2v1zqUL85nAo7kX3/G
Qbd/8Wb/eLxe6xTzNOeJOgPdHa+39eeF+Vjr3CngSP4jy3+65Karp7iO12sd
ytN8JupI/sqVOx1x/ho7H8gdr9c6lC/OZwKO7Cnt9fgHLvqbJ32HesmhPM1n
oo7eUxp0Heolh/I0n4k6ek9p0HWolxzK03wm6ug9pUHXoV5yKE/zmaij95QG
XYd6yaE8zWeijt5TGnQd6iWH8jSfiTpyn7F5cqiXHMrTfCbqpNxo78tw/7dO
uTd3KF+czwQcyd/02rbX39zxeq1TzNOcJ+pszh94y7EPvfVq3/F6W53CfKx1
7hRwJH/N3ke2PH/mjtdrHcrTfCbqSH5V6/N/7ni91qF8cT4TcCRvr1NyvF66
b9h8cc4TcHQ+3x+zTrfefF/L5svzme6O+Z4+16FecihP85moY76nz3WolxzK
03wm6pjv6XMd6iWH8jSfiTp7w+cUyKFecihP85Cok3J5nhxvDtM13y+H8v1y
ZN71wZGTX/8/a7eZuI/pfYzp2fvEO7617v3X3/7yfY8ceV+84Zp/+vGZu/kO
9ZJDedmH+ebOT/z2W/ffttqRucSc83c55X8d7TvUSw7l03HIv9d2k3Pmd3eo
lxzK632kekfPhXyHesmhvD4fZlQ7ei7kO9RLDuX1PtL21Y6eCw25DvWSQ/n0
7yv7SPWOngsNuQ71kkN5vY9U7+i50JDrUC85lE/XlTxfDVU7ei7kO9RLDuX1
PpJ/POTouZB/PNRLDuXH3Yl9pHpHz4X8/y7qJYfyeh+p3tFzoSHXoV5yKK/3
kWZUO3ou5DvUSw7l9T7SdtWOngv5DvWSQ/l0HDKfnKQzMRfyHeolh/JyPN9q
ex4LOHKcu7Q9p7U41EsO5fX5ML3akfPkcfOcTA71kkN5uR7t+5GoI9epfZ9C
DvWSQ3m5H957634fW//n9Y7cJ8/74VcPetfCfN5lHeolh/KyjzS617v+cI/f
rndkLjR488VTBxbmczbrUC85lNfPA/WOmgttkSeHesmhvDyPdT0ecmQuZI+T
HOolh/Lj7ubnYXs+RB2ZC9nzhBzqJYfyNA+JOjQnIYd6o3ObfjmU39oOzWfS
+Z3/3pAcyf/5vF9884LX2ftD7ni91qF8cT4TcCR/2X6v/cBhx/nH4/Vap5in
OU/UGejueL2tPy/Mx1rnTgFH8mlPaYbreL3WoTzNZ6KO5NOekp0P5I7Xax3K
F+czAUfvKfkO9ZJDeZrPRB29pzTsOtRLDuVpPhN19J7SsOtQLzmUp/lM1NF7
SsOuQ73kUJ7mM1FH7ykNuw71kkN5ms9EHb2nNOw61EsO5Wk+E3XkPmPz5FAv
OZSn+UzUSTnZU8rv/9Yp9+YO5YvzmYAj+bSn5B+P12udYp7mPFFnYk/Jd7ze
VqcwH2udOwUcyf/4irktz5+54/Vah/I0n4k6kj+t9fk/d7xe61C+OJ8JOJK3
1yk5Xi/dN2y+OOcJODrvO916/eMsz2e6O3pPyXeolxzK03wm6ug9Jd+hXnIo
T/OZqKP3lHyHesmhPM1nos7e8DkFcqiXHMrTPCTqpFyeJ8ebw3TN98uhfL8c
Pe96xcTP9T7GDuAPu46eC/kO9ZJDeb2PtGO1o+dCvkO95FA+HYf8e82cnDO/
u0O95FBejiftBdQ7cpxPj78++A71kkN5dT706h05T9Lrs+9QLzmUl+sx/V5u
VrUj12l6PvId6iWH8unfd6de+r1ovSNzofR86jvUSw7l5fdB6ffS9Y7MhdL7
A9+hXnIon66r5vlqYb2j5kI936Fecigv+0hdj4ccmQvZ4ySHesmhfHJnZ+dD
1JH3BfY8IYd6yaG87APY6zHqyPsye52SQ73kUF7tY2xxP4w68r7Y3ifJoV5y
KC/7MLuZ16OoI3OJZ8zrFDnUSw7l03Uo88lJOr05vX2mvucdr+ngUC85lNf7
SDtWO3ou5DvUSw7l9T7SDtWOngv5DvWSQ3m9j/SKakfPhfI5s3WolxzKy/0w
7WPUO3ouRPOuYbeXHMrrfaR6R8+FaM427PaSQ3n1PDBQ7+i50LDrUC85lNf7
SPWOngsNuw71kkP5cXdiH6ne0XOhYdehXnIoT/OQqENzEnKoNzq36ZdD+a3t
0Hwmnd/57w3JkXzaU7L3h9zxeq1D+eJ8JuBIPu0p+cfj9VqnmKc5T9QZ6O54
va0/L8zHWudOAUfy+67/zb6A73i91qE8zWeijuRXju8L2PfLueP1WofyxflM
wJE9pSuevvGOA571Heolh/I0n4k6ek9pxHWolxzK03wm6ug9pRHXoV5yKE/z
maij95RGXId6yaE8zWeijt5TGnEd6iWH8jSfiTp6T2nEdaiXHMrTfCbqyH3G
5smhXnIoT/OZqJNyo7174P5vnXJv7lC+OJ8JOJI/dlHb62/ueL3WKeZpzhN1
NuevWv31j3zl3R3/uwq9rU5hPtY6dwo4kk97Svb5M3e8XutQnuYzUUfyp7U+
/+eO12sdyhfnMwFH8vY6JcfrpfuGzRfnPAFH532nW69/nOX5THdH7yn5DvWS
Q3maz0QdvafkO9RLDuVpPhN19J6S71AvOZSn+UzU2Rs+p0AO9ZJDeZqHRJ3m
+szy5HhzmK75fjmU75cj867mfyd+rvYx5u+U+c3/uo68L27en7kO9ZJDedmH
aeay1Y7MJbZP14frUC85lE/3Efn3mj05Z353h3rJobzeR6p39FzId6iXHMrr
faR6R8+FfId6yaG83keaU+3ouZDvUC85lG+uw2Yfo97RcyHfoV5yKK/3keod
PRfyHeolh/LNdZXOh4X1jp4L+Q71kkN5vY9U7+i5kO9QLzmUb67D7HyIOnou
5DvUSw7l9T5SvaPnQr5DveRQXu8jza529FzId6iXHMrrfaR6R8+FfId6yaF8
cx1mr+9VzsRcyHeolxzKy/G0Po8FHDnOkbbntBaHesmhvDof5tc7cp6ca56T
yaFecigv16N9PxJ15Dq171PIoV5yKC/3w+a5rNqR+2TzvOY61EsO5WUfqXku
rnZkLtQ8L7sO9ZJDef08UO+oudB836Fecigvz2Ndj4ccmQvZ4ySHesmhfHMd
ZudD1JG5kD1PyKFecihP85CoQ3MScqg3Orfpl0P5re3QfCad5/nvDcmRfLMv
4Dper3UoX5zPBBzJr9h50W/mta7j9VqnmKc5T9QZ6O54va0/L8zHWudOAUfy
aU/Jd7xe61Ce5jNRR/JpT8m+X84dr9c6lC/OZwKO3lPyHeolh/I0n4k6ek9p
1HWolxzK03wm6ug9pVHXoV5yKE/zmaij95RGXYd6yaE8zWeijt5TGnUd6iWH
8jSfiTp6T2nUdaiXHMrTfCbqyH3G5smhXnIoT/OZqNPkmj0l/3jKvblD+eJ8
JuBIPu0p+Y7Xa51inuY8UWdiT6njf1eht9UpzMda504BR/Ib7r6s5fkzd7xe
61Ce5jNRR/L7tj7/547Xax3KF+czAUfy9jolx+ul+4bNF+c8AUfnfadbr3+c
5flMd0fvKfkO9ZJDeZrPRB29p+Q71EsO5Wk+E3X0npLvUC85lKf5TNTZGz6n
QA71kkN5modEnSaX5cnx5jBd8/1yKN8vp/mcofzesCc/bz6HmfK92RM/b/a6
5Dmt5znNPpw8F7kO9ZJD+eZzsLIPU+00+4jyXOQ61EsO5dO/U3M8A5N0Nue7
OtRLDuXleGQuXuvIcQ419yfPoV5yKK/Oh/n1jpwnMp/wHOolh/JyPco8u9aR
61TuK55DveRQPv377iC/j6h2ms8Dy+uC61AvOZRv/g6d/D6o2vmt9HkMeV12
Heolh/LpupqZzoeF9c5+R73/68s37dicV75DveRQvvk7dJ2Ph5w0F5qZHSc5
1EsO5cfd3szsfIg6zefBsvOEHOolh/LN34HKrseo03weL7tOyaFecijf/B2u
7H4YdZrPQ2b3SXKolxzKN38HrbfKvB5FnebzqPJ7MdehXnIon67DWdnre5XT
m9X7/sav3fLwJv94qJccysvxtD6PBRw5zifbntNaHOolh/LqfOjVO3KefMY8
J5NDveRQXq5H+34k6sh1at+nkEO95FBe7oeyF1bryH1S5nOeQ73kUL75O3Sy
D1ztjDWvUzIf9RzqJYfy+nmg3lnzzP2H/195Tuj5DvWSQ/nm79B1Ph5ydmue
0+xxkkO95FB+yvhx7JCfV0Gn+Txwfp6AQ73kUJ7mIVGH5iTkUG90btMvh/Jb
26H5TDrPZW4w6jqSb/Y0XMfrtQ7ly/OZ7o7kmz0Z1/F6rVPM45wn6Ax0d7ze
1p8X5mOtc6eAI/lmT8x1vF7rUJ7mM1FH8rIv4zler3UoX5zPBJwfzV5y7idm
DfdkX8lzqJccytN8Juo0f5+uOU98h3rJoTzNZ6LOJ27/3d/8fZAsTw71kkN5
ms9EnbOO+NizC96/Y5Ynh3rJoTzNZ6JO2lOameXJoV5yKE/zmaiT9pRmZXly
qJccytN8JurIfcbmyaFecihP85moI7l5cP+3Trk3dyhfnM8EHMlfe3rb62/u
eL3WKeZpzhN1Nuffv+vRnz/x+o7/XYXeVqcwH2udOwUcyY/uc1rL82fueL3W
oTzNZ6KO5Fe0Pv/njtdrHcoX5zMBR/L2OiXH66X7hs0X5zwBR+dHXadb76ib
L89nujtpT2mmc/yjbi85lKf5TNSZdfncL/z5e3bM8uRQLzmUp/lM1Fny5tds
8Zw26jrUSw7laT4TdRao5+RR16FecihP85Cok3L5nIQcbw7TNd8vh/L9cvS8
a9bEz/U+0kzwZ7mOngv5DvWSQ3m9j1Tv6LmQ71AvOZRP/05yfk7SmZgL+Q71
kkN5OR7Zy6h15Dibv0vvOtRLDuXV+bBwh2pHzhO5P3kO9ZJDebke5X9rHblO
5X89h3rJobwchxxXrSNzITlez6Fecigv54GcF7WOzIXkfPEc6iWH8nJdyXVZ
66i50BZ5cqiXHMrLfbDr8ZAjcyF7nORQLzmUH3c3vw7Z8yHqyOuTPU/IoV5y
KC/PAfZ6jDryfGCvU3KolxzKq32MLe6HUUfeF28w90lyqJccyss+jH09ijoy
l5htXqfIoV5yKJ+OQ+aTMyfn9Gb1rnzhXacu2+QfD/WSQ3m9j1Tv6LmQ71Av
OZTX+0j1jp4L+Q71kkN5vY80q9rRcyHfoV5yKC/HIcdV6+i5kO9QLzmU1/tI
9Y6eC/kO9ZJDefU8sLDe0XMh36Feciiv95HqHT0X8h3qJYfyeh+p3tFzId+h
XnIoT/OQqENzEnKoNzq36ZdD+a3t0Hwmnef57w3JkXzzPWWu4/Vah/Ll+Ux3
R/LN98S5jtdrnWIe5zxBZ6C74/W2/rwwH2udOwUcyTffk+g6Xq91KE/zmagj
+Q8183LP8XqtQ/nifCbgyJ6S/K/nUC85lKf5TNTRe0q+Q73kUJ7mM1FH7yn5
DvWSQ3maz0QdvafkO9RLDuVpPhN19J6S71AvOZSn+UzU0XtKvkO95FCe5jNR
R3I2Tw71kkN5ms9EnZQb6Z0M93/rlHtzh/LF+UzAkfzhP217/c0dr9c6xTzN
eaLO5vxt77hmlzuP8x2vt9UpzMda504BR/JpT8l3vF7rUJ7mM1FH8itan/9z
x+u1DuWL85mAI3l7nZLj9dJ9w+aLc56Ao/P5/ph1uvXSvlbX+Ux3R+8p0fGP
uL3kUJ7mM1FH7ymNuA71kkN5ms9EHb2nNOI61EsO5Wk+E3UWwOcUyKFecihP
85CoI9enzZPjzWG65vvlUL5fjsy7Fj+x+MEdfnf7iZ/rfYwZmf+2w1/9f959
wJDryPPo6LF/tuelP/Ed6iWH8vJ76CPXjzx65/e2q3bk/cDjFzx0xd9/3Xeo
lxzKp38nOT8n6UzMhXyHesmhvN5H2rba0XMh36Feciivz4fp1Y6eC/kO9ZJD
eb2PtE21o+dCg65DveRQPh2H7CPVO3ouNOg61EsO5fU+Ur2j50KDrkO95FA+
XVfyfFXv6LnQoOtQLzmU1/tI9Y6eCw26DvWSQ/lxd2Ifqd7Rc6FB16Feciiv
95HqHT0XGnQd6iWH8nofaXq1o+dCvkO95FBe7yNtW+3ouZDvUC85lE/HIfPJ
7SbnTMyF/OOhXnIoL8dzRNvzWMCR41zT9pzW4lAvOZTX58OMakfOkznmOZkc
6iWH8nI92vcjUUeuU/s+hRzqJYfycj980yHLP7nzlfWO3Cc/vdfx/3LD3w25
DvWSQ3nZR9rwwxv+9b5H6x2ZC734zrM3btoiTw71kkN5/TwwVO2oudBC36Fe
cigv+0hdj4ccmQvZ4ySHesmhvOwjZedV0JG5UHaegEO95FCe5iFRh+Yk5FBv
dG7TL4fyW9uh+Uw6v/PfG5IjuS+t3OmI89fY+0PueL3WoXx5PtPdkfxHlv90
yU1X+8fj9VqnmMc5T9AZ6O54va0/L8zHWudOAUfyaU9puut4vdahPM1noo7k
056SnQ/kjtdrHcoX5zMBR+8p+Q71kkN5ms9EHb2n5DvUSw7laT4TdfSeku9Q
LzmUp/lM1NF7Sr5DveRQnuYzUUfvKfkO9ZJDeZrPRB29p+Q71EsO5Wk+E3Xk
PmPz5FAvOZSn+UzUSTnZU8rv/9Yp9+YO5YvzmYAj+bSn5B+P12udYp7mPFFn
Yk/Jd7zeVqcwH2udOwUcyb/xlFUtz5+54/Vah/I0n4k6kr+89fk/d7xe61C+
OJ8JOJK31yk5Xi/dN2y+OOcJODqf749Zp1tvvq9l8+X5THdH7ynR8Q+7veRQ
nuYzUUfvKQ27DvWSQ3maz0Qdvac07DrUSw7laT4TdRbA5xTIoV5yKE/zkKgj
OZsnx5vDdM33y6F8vxw975o68XO9jzEF/Gmuo+dCvkO95FBe7yMNVDt6LuQ7
1EsO5dO/k5yfk3Qm5kK+Q73kUF6O56T9Vr/l7LNeWlbryHHu/uKf3vvda3yH
esmhvDofBjZWO3Ke3H/4e6595KgXXYd6yaG8XI8rdll+2LrbXqh25Dr99Afv
vO24Tz7nOtRLDuXTv+8OvavOPOPXy1c+X+3IXOippYdctHTgOdehXnIoL/tI
ex6/9MJj9ql3ZC4045RXbjOwRZ4c6iWH8uk8kOerekfNhbbIk0O95FBe9pG6
Hg85Mheyx0kO9ZJD+XRXm5mdD1FH3hfY84Qc6iWH8rIPYK/HqCPvy+x1Sg71
kkN5tY+xxf0w6sj74vvMfZIc6iWH8rIPc6J5PYo6MpeYa16nyKFeciif7oez
epvS/03O6c3qzXv2qw+c38GhXnIor/eRzHNOwNFzId+hXnIor/eRplQ7ei7k
O9RLDuX1PtLUakfPhaa5DvWSQ3m5H6Z9jHpHz4WmuQ71kkN5vY9U7+i50DTX
oV5yKK+fB6ZVO3ou5DvUSw7l9T6Sfzzk6LmQfzzUSw7l9T5SvaPnQv5/F/WS
Q3mah0QdmpOQQ73RuU2/HMpvbYfmM+n8zn9vSI7k056SvT/kjtdrHcqX5zPd
HcmnPSX/eLxe6xTzOOcJOgPdHa+39eeF+Vjr3CngSH7uGQfd/sWbX3Qdr9c6
lKf5TNSR/D0nrzpp2iF2PpA7Xq91KF+czwQc2VP6hze87YntXjfmOtRLDuVp
PhN19J7SmOtQLzmUp/lM1NF7SmOuQ73kUJ7mM1FH7ymNuQ71kkN5ms9EHb2n
NOY61EsO5Wk+E3X0ntKY61AvOZSn+UzUkfuMzZNDveRQnuYzUSflRnp3wf3f
OuXe3KF8cT4TcCS/+DsHt7z+5o7Xa51inuY8UWdz/oIvHHboZ27xj8frbXUK
87HWuVPAkXzaU7LPn7nj9VqH8jSfiTqSv7z1+T93vF7rUL44nwk4krfXKTle
L903bL445wk4Op/vj1mnWy/ta3Wdz3R39J4SHf+g20sO5Wk+E3X0ntKg61Av
OZSn+UzU0XtKg65DveRQnuYzUWcBfE6BHOolh/I0D4k6KZfPScjx5jBd8/1y
KN8vR+Zd+z60302vfvuvJ+5jeh/jV9n7xPO+9Na3X/2xZ5Z5jrwv3uNbX3vv
73zDd6iXHMrLPsyS5buuuPiS/6l2ZC7xwLRv7/3Hx/oO9ZJD+XQccjxPTc6Z
mAv5DvWSQ3k5njtPv/nUx9b/otqR4/yzsUVX/fXhT7gO9ZJDeX0+bKh25Dz5
x8U3HHHX3z/mOtRLDuXlerz80M9decfH/6vaket05t2f+fgt2z/iOtRLDuXT
v+8OvfmP/OyxRYsfrXZkLrT24M+OHDxlnetQLzmUl32k99560DbXn7K+2pG5
0Mi9e20/MLDOdaiXHMqn80Cer+odPRda5zrUSw7lZR+p6/GQI3Mhe5zkUC85
lB9nezOz8yHqyPsCe56QQ73kUF72AS4z12PUkfdl9jolh3rJobzsY6R1mJ9X
O/K++FpznySHesmhvOzD3GFej6KOzCWONK9T5FAvOZRP98NZvZfGj+e/J+f0
ZvVOfvKQ6ze+5DvUSw7l5Xi+0vY8FnDkOL/d9pzW4lAvOZTX58Mvqx05T3Y3
z8nkUC85lJfr0b4fiTpyndr3KeRQLzmUl/vh+y/93NB+856uduQ+OfOEW889
YdMzrkO95FBe9pHu++oJf3vd3fWOzIWeveKx5zdtkSeHesmhvH4eeKbaUXOh
gWddh3rJobzsI3U9HnJkLmSPkxzqJYfyso+UnVdBR+ZC2XkCDvWSQ3mah0Qd
mpOQQ73RuU2/HMpvbYfmM+l8zX9vSI7k37x47pdfvNXeH3LH67UO5cvzme6O
5Fd/7l8O+NA7/ePxeq1TzOOcJ+gMdHe83tafF+ZjrXOngCP5w3/26U/83od/
7jper3UoT/OZqCP5xf9+413TL7Xzgdzxeq1D+eJ8JuDIntKhR5+3etafrHUd
6iWH8jSfiTp6T2mt61AvOZSn+UzU0XtKa12HesmhPM1noo7eU1rrOtRLDuVp
PhN19J7SWtehXnIoT/OZqKP3lNa6DvWSQ3maz0Qduc/YPDnUSw7laT4TdVJu
pHcp3P+tU+7NHcoX5zMBR/L7nnNxy+tv7ni91inmac4TdTbnp+5x5ednn+of
j9fb6hTmY61zp4Aj+ePuvbHl+TN3vF7rUJ7mM1FH8ru1Pv/njtdrHcoX5zMB
R/L2OiXH66X7hs0X5zwBR+fz/THrdOvN97Vsvjyf6e7oPSU6/jG3lxzK03wm
6ug9pTHXoV5yKE/zmaij95TGXId6yaE8zWeizgL4nAI51EsO5WkeEnVSLp+T
kOPNYbrm++VQvl+OzLsePO3h7587du/Ez/U+xvLMf/jDG8Yu3/Cg68j74vct
OvjOdeetdB3qJYfysg+z+qLjl3531a3VjswlTjzgoy/Mu/wW16FeciifjmPi
70ENTMp5+XN5rkO95FBejueBdDwH1jpynAvScboO9ZJDeTkf0u9D76p25Dw5
Jp0nrkO95FDeXI/Vjlyna9N16jrUSw7l07/vDr2F+//RXmuW31ftyFxo/tn/
sfqcjQ+5DvWSQ3nZRzrys+c+ffVeP6l2ZC700wVLH9+06SHXoV5yKJ+uKnm+
WlXt6LnQGtehXnIoL/tIR3U8HnJkLmSPkxzqJYfy42xvZnY+RB15X2DPE3Ko
lxzKyz7AanM9Rh15X2avU3KolxzKyz7G4PiBLa925H3xyeY+SQ71kkN52YdZ
a16Poo7MJS42r1PkUC85lE/3w1m9jy+de/QRS25426Sc3qzeF+581QV77Poa
93iolxzKy/Hc0/Y8FnDkOP/qD1qe01oc6iWH8nI+jKXngWpHzpPDzXMyOdRL
DuXlerTvR6KOXKf2fQo51EsO5eV+eH66H1Y75j7pOtRLDuVlH+mI9HpU7Yzp
1ynXoV5yKG+eB6odPRda4zrUSw7lZR/pqI7HQ85u+jnNdaiXHMrLPtKF9rwK
Oo/r52TXoV5yKC/vR1ab6zHqmPcprkO95FCe5jlRh+Y8nkO95Nif03wmna/5
7w3Jkfz3T1vy0V8+8oDreL3WoXx5PtPdkfzKT615Yv/3rXAdr9c6xTzOeYLO
QHfH6239eWE+1jp3CjiSvzsdp+t4vdahPM1noo7kV6TzxHW8XutQvjifCTiy
p3T6sTu+c81fPuw61EsO5Wk+E3XMnpLrUC85lKf5TNQxe0quQ73kUJ7mM1HH
7Cm5DvWSQ3maz0Qds6fkOtRLDuVpPhN1zJ6S61AvOZSn+UzUkfuMzZNDveRQ
nuYzUSflRnrr4f5vnXJv7lC+OJ8JOJLffY8ftbz+5o7Xa51inuY8UWdz/slr
9z31fdfe3O2/q9Db6hTmY61zp4Aj+R9c+KmW58/c8XqtQ3maz0QdyS9tff7P
Ha/XOpQvzmcCjuTtdUqO10v3DZsvznkCjsm7Tsde9zjL85nujt5TwuN3e8mh
PM1noo7eU1rrOtRLDuVpPhN19J7SWtehXnIoT/OZqLMAPqdADvWSQ3maz0Sd
lMvnJORQLzmU9+Y5k+31nK695u/GTNzHzN/DOdD6zZ78gZ4j74uvS3vprkO9
5FDe/D2iasd8Lsx1qJccyqfjmPh7UJNzXv5cnutQLzmUl+Np/h5CtWM+F+k6
1EsO5c3fQ6t2zOdSXYd6yaG8+RxxtWP2OV2HesmhfPr3nfg8eLWzQe/lug71
kkP5b+rP41c7v6X3ol2HesmhfDoPJv4eQrWj50LPug71kkP5ufrvUVQ7T+nP
BbgO9ZJD+XH25b8HUu2Yz2W4DvWSQ3nz91iqHfO5GNehXnIor7+P71fVjrwv
3tPcJ8mhXnIoL/swS8zrUdSRucSD5nWKHOolh/LpfjirN8W8vlc5vVm9e7Y7
/g0XdHColxzKy/F8r+15LODIcS5qe05rcaiXHMrL+TB1vGhDtSPnyfXmOZkc
6iWH8nI92vcjUcd8Lth1qJccysv98A/T3wOsdsznsl2HesmhvOwjHZv+HmO1
M6Y/F+861EsO5fXzQL2j50LrXId6yaH8t/TfI612dtN/F8J1qJccyss+0oH2
vAo6j+u/y+E61EsO5eX9yGXmeow6NCchh3q9uY3N0zwn6lA+OkeKOjSfSedr
/ntDciT/pfR3ElzH67UO5cvzme6O5Ju/U+Q6Xq91inmc8wSdge6O19v688J8
rHXuFHAk/2D6O12u4/Vah/I0n4k6kp+X/k6C63i91qF8cT4TcGRP6fgH/m3k
2TX2/X7uUC85lKf5TNQx39PnOtRLDuVpPhN1zPf0uQ71kkN5ms9EHfM9fa5D
veRQnuYzUcd8T5/rUC85lKf5TNQx39PnOtRLDuVpPhN15D5j8+RQLzmUp/lM
1Em5kd7+cP+3Trk3dyhfnM8EHMl/8ODvtLz+5o7Xa51inuY8UWdz/u/+4qZ/
Pucd/vF4va1OYT7WOncKOJI/bMGSlufP3PF6rUN5ms9EHcl/o/X5P3e8XutQ
vjifCTiSt9cpOV4v3TdsvjjnCTg6n++PWadbb76vZfPl+Ux3x+wpuQ71kkN5
ms9EHbOn5DrUSw7laT4TdcyekutQLzmUp/lM1FkAn1Mgh3rJoTzNQ6JOyuVz
EnK8OUzXfL8cyvfLkXnXil2WH7buthcmfq73MTZmfvM90a4j74vvT9/L7DrU
Sw7lZR/mxP1Wv+Xss16qdmQusXv6XmbXoV5yKJ+OY+LvQc2flPPy5/Jch3rJ
obwcz5HrRx6983v1jhzn4+l7mV2HesmhvDofFk6pduQ8ab6X2XWolxzKy/W4
+InFD+7wu1OrHfN9pq5DveRQPh3HDr03HbL8kztfWe/IXKj5XlrXoV5yKC/7
SBt+eMO/3vdovSNzoeZ7gV2HesmhfLqs5PlqWrWj5kILfYd6yaG87CN1PR5y
ZC5kj5Mc6iWH8uNub2Z2PkQd873krkO95FBe9gHs9Rh1zPfCuw71kkN5tY+0
xf0w6sj74lFznySHesmhvOzD2NejqCNziV+Y1ylyqJccyqfjkPnkJJ3erN6H
Bm+4fH4Hh3rJobwcz0ltz2MBR47z0LbntBaHesmhvJwPaR9sY7Uj58kD5jmZ
HOolh/JyPdr3I1FHrlP7PoUc6iWH8nI/vOrMM369fOXz1Y7cJ59aeshFSwee
cx3qJYfyso+05/FLLzxmn3pH5kIzTnnlNgNb5MmhXnIor58H6h09F3rOdaiX
HMrLPlLX4yFH5kL2OMmhXnIoL/tI2XkVdGQulJ0n4FAvOZSneUjUoTkJOdQb
ndv0y6H81nZoPpPO1/z3huRIfuXJq06adoi9P+SO12sdypfnM90dyb/+jINu
/+LN/vF4vdYp5nHOE3QGujteb+vPC/Ox1rlTwJH8R5b/dMlNV09xHa/XOpSn
+UzUkfyVK3c64vw1dj6QO16vdShfnM8EHNlT2uvxD1z0N0/6DvWSQ3maz0Qd
vac06DrUSw7laT4TdfSe0qDrUC85lKf5TNTRe0qDrkO95FCe5jNRR+8pDboO
9ZJDeZrPRB29pzToOtRLDuVpPhN15D5j8+RQLzmUp/lM1Em5kd6X4f5vnXJv
7lC+OJ8JOJK/6bVtr7+54/Vap5inOU/U2Zw/8JZjH3rr1b7j9bY6hflY69wp
4Ej+mr2PbHn+zB2v1zqUp/lM1JH8qtbn/9zxeq1D+eJ8JuBI3l6n5Hi9dN+w
+eKcJ+DofL4/Zp1uvfm+ls2X5zPdHfM9fa5DveRQnuYzUcd8T5/rUC85lKf5
TNQx39PnOtRLDuVpPhN1FsDnFMihXnIoT/OQqJNy+ZyEHG8O0zXfL4fy/XJk
3pX+d5uJ+5jex5ievU9M//vyfY8ceV+c3p/5DvWSQ3nZh0l7AdtWOzKXmDN+
ffgO9ZJD+fTvJOfndpNzJuZCvkO95FBe7yPVO3ou5DvUSw7l9fkwo9rRcyHf
oV5yKK/3kbavdvRcaMh1qJccyqfjkH2kekfPhYZch3rJobzeR6p39FxoyHWo
lxzKp+tKnq+Gqh09F/Id6iWH8nofyT8ecvRcyD8e6iWH8uPuxD5SvaPnQv5/
F/WSQ3m9j1Tv6LnQkOtQLzmU1/tIM6odPRfyHeolh/J6H2m7akfPhXyHesmh
fDoOmU9O0pmYC/kO9ZJDeTmeb7U9jwUcOc5d2p7TWhzqJYfy+nyYXu3IefK4
eU4mh3rJobxcj/b9SNSR69S+TyGHesmhvNwP03NZvSP3yfS8ls+7rEO95FBe
9pHSc3G9I3Oh9Lycz9msQ73kUF4/D9Q7ai60RZ4c6iWH8rKP1PV4yJG5kD1O
cqiXHMrLPlJ2XgUdmQtl5wk41EsO5WkeEnVoTkIO9UbnNv1yKL+1HZrPpPM7
/70hOZJP+wL2/pA7Xq91KF+ez3R3JH/Zfq/9wGHH+cfj9VqnmMc5T9AZ6O54
va0/L8zHWudOAUfyaU9phut4vdahPM1noo7k056SnQ/kjtdrHcoX5zMBR+8p
+Q71kkN5ms9EHb2nNOw61EsO5Wk+E3X0ntKw61AvOZSn+UzU0XtKw65DveRQ
nuYzUUfvKQ27DvWSQ3maz0Qdvac07DrUSw7laT4TdeQ+Y/PkUC85lKf5TNRJ
OdlTyu//1in35g7li/OZgCP5tKfkH4/Xa51inuY8UWdiT8l3vN5WpzAfa507
BRzJ//iKuS3Pn7nj9VqH8jSfiTqSP631+T93vF7rUL44nwk4krfXKTleL903
bL445wk4Ou873Xr94yzPZ7o7ek/Jd6iXHMrTfCbq6D0l36FecihP85moo/eU
fId6yaE8zWeizgL4nAI51EsO5WkeEnWa6zPLk+PNYbrm++VQvl+Onne9YuLn
eh9jB/CHXUfPhXyHesmhvN5H2rHa0XMh36Feciif/p3k/Jw5OWdiLuQ71EsO
5eV4mr2AakeO8+n0+uA61EsO5dX50Kt35DxpXp9dh3rJobxcj83v5aoduU6b
5yPXoV5yKN9ch73m96LVjsyFmudT16Fecigv+0jN76WrHZkLNe8PXId6yaF8
c10198N6R82Fer5DveRQXvaRuh4POTIXssdJDvWSQ/nmOszOh6gj7wvseUIO
9ZJDedkHsNdj1JH3ZfY6JYd6yaG82sfY4n4YdeR9sb1PkkO95FBe9mF2M69H
UUfmEs+Y1ylyqJccyjfXYfb6XuX0ZvX2mfqed7ymg0O95FBe7yPtWO3ouZDv
UC85lNf7SDtUO3ou5DvUSw7l9T7SK6odPRfK58zWoV5yKC/3w+a5rNrRcyGa
dw27veRQXu8j1Tt6LkRztmG3lxzKq+eBgXpHz4WGXYd6yaG83keqd/RcaNh1
qJccyut9pHpHz4WGXYd6yaE8zUOiDs1JyKHe6NymXw7lt7ZD85l0fue/NyRH
8s2+gOt4vdahfHk+092RfNpT8o/H67VOMY9znqAz0N3xelt/XpiPtc6dAo7k
910/vi/gOl6vdShP85moI/mVaV/Adbxe61C+OJ8JOLKndMXTN95xwLO+Q73k
UJ7mM1FH7ymNuA71kkN5ms9EHb2nNOI61EsO5Wk+E3X0ntKI61AvOZSn+UzU
0XtKI65DveRQnuYzUUfvKY24DvWSQ3maz0Qduc/YPDnUSw7laT4TdZpc7x64
/1un3Js7lC/OZwKO5I9d1Pb6mzter3WKeZrzRJ3N+atWf/0jX3l3x/+uQm+r
U5iPtc6dAo7k056Sff7MHa/XOpSn+UzUkfxprc//ueP1WofyxflMwJG8vU7J
8XrpvmHzxTlPwNF53+nW6x9neT7T3dF7Sr5DveRQnuYzUUfvKfkO9ZJDeZrP
RB29p+Q71EsO5Wk+E3UWwOcUyKFecihP85Co0+SyPDneHKZrvl8O5fvlyLxr
3ox5l5331Mv3MbWPMX+nzD/x2DNvPOYDI64j74vP+fH9P//92b5DveRQXvZh
Hrzk3Fd85cv1jswltj9wZJ9vXOc71EsO5dO/k5yfsyfnTMyFfId6yaG83keq
d/RcyHeolxzK632kekfPhXyHesmhvN5HmlPt6LmQ71AvOZRP/76yj1Tv6LmQ
71AvOZTX+0j1jp4L+Q71kkP5dF3JPlK9o+dCvkO95FBe7yPVO3ou5DvUSw7l
kzszOx+ijp4L+Q71kkN5vY9U7+i5kO9QLzmU1/tIs6sdPRfyHeolh/J6H6ne
0XMh36FeciifrkOZT07SmZgL+Q71kkN5OZ7W57GAI8c50vac1uJQLzmUV+fD
/HpHzpNzzXMyOdRLDuXlerTvR6KOXKf2fQo51EsO5eV+eMqanQ8466Z6R+6T
333sXUt3m+871EsO5WUfaeiKr10155J6R+ZCU1cfPGVgvu9QLzmU188D9Y6a
C833Heolh/Kyj9T1eMiRuZA9TnKolxzKyz5Sdl4FHZkLZecJONRLDuVpHhJ1
aE5CDvVG5zb9cii/tR2az6TzPP+9ITmSf/OrnlnVW5T/3Dper3UoX57PdHck
v2LnRW96/Rt9x+u1TjGPc56gM9Dd8Xpbf16Yj7XOnQKO5NOeku94vdahPM1n
oo7k056Sfb+cO16vdShfnM8EHL2n5DvUSw7laT4TdfSe0qjrUC85lKf5TNTR
e0qjrkO95FCe5jNRR+8pjboO9ZJDeZrPRB29pzTqOtRLDuVpPhN19J7SqOtQ
LzmUp/lM1JH7jM2TQ73kUJ7mM1En5WRPyT+ecm/uUL44nwk4kk97Sr7j9Vqn
mKc5T9SZ2FPq+N9V6G11CvOx1rlTwJH8hrsva3n+zB2v1zqUp/lM1JH8vq3P
/7nj9VqH8sX5TMCRvL1OyfF66b5h88U5T8DRed/p1usfZ3k+093Re0q+Q73k
UJ7mM1FH7yn5DvWSQ3maz0QdvafkO9RLDuVpPhN1FsDnFMihXnIoT/OQqJNy
+ZyEHG8O0zXfL4fy/XKav/Muvzfsyc+bv4Of8r3ZPe0PynNaz3Oav0cmz0Wu
Q73kUL75HgLZh6l2mr8HJ89FrkO95FA+/Ts1xzMwSWdzvqtDveRQXo6n+X1c
tSPHOZSei1yHesmhvDof5tc7cp40c1HXoV5yKC/XYzPHrnbkOm3uJ65DveRQ
Pv37TpffR1Q7zfcxyOuC61AvOZRvvgdUfh9U7aS50Lbyuuw61EsO5dN1tV06
HxbWO2kutG1zXvkO9ZJD+SPS95B1Ph5y1qa/B50dJznUSw7l03HMyM6HqNN8
H0N2npBDveRQvvkevux6jDrN30PPrlNyqJccyjffg5jdD6NO8/fos/skOdRL
DuWb76HsrTKvR1Gn+T4A+b2Y61AvOZRP1+NQ9vpe5Swc6n1/49dueXiTfzzU
Sw7l5Xjan8e6O3KcT7Y9p7U41EsO5dX50Kt35Dz5jHlOJod6yaG8XI/2/UjU
kevUvk8hh3rJobzcD5t91GpH7pPN7wVch3rJoXzzPaCyD1ztPNW8TjW/l3Ed
6iWH8vp5oN5Jc6HmOaHnO9RLDuWb7wHtfDzk7NY8p9njJId6yaF82keanp0P
Uaf5PobsPCGHesmhPM1Dog7NScih3ujcpl8O5be2Q/OZdJ7L3GDUdSTf7Gm4
jtdrHcqX5zPdHck3ezKu4/Vap5jHOU/QGejueL2tPy/Mx1rnTgFH8s2emOt4
vdahPM1noo7kmz091/F6rUP54nwm4KQ9pcHeh7c/8g9u3853qJccytN8Juo0
3w/anCe+Q73kUJ7mM1En7SlNz/LkUC85lKf5TNRJe0rbZnlyqJccytN8Jurs
v3b8+8myPDnUSw7laT4Tdf7f9P1wWZ4c6iWH8jSfiTpyn7F5cqiXHMrTfCbq
pNxwbx7c/61T7s0dypfnM90dyV97etvrb+54vdYp5nHOE3Q259+/69GfP/H6
jv9dhd5WpzAfa507BRzJj+5zWsvzZ+54vdahPM1noo7kV7Q+/+eO12sdyhfn
MwFH8vY6JcfrpfuGzRfnPAFH50ddp1vvqJsvz2e6O7uv/88tXqfo+EfdXnIo
T/OZqJP2lLbN8uRQLzmUp/lM1El7StOzPDnUSw7laT4TdRao5+RR16FecihP
85Cok3L5nIQcbw7TNd8vh/L9cvS8a9bEz/U+0kzwZ7mOngv5DvWSQ3m9j1Tv
6LmQ71AvOZRP/05yfk7SmZgL+Q71kkN5OR75uzi1jhxn83fpXYd6yaG8Oh8W
7lDtyHki+6GeQ73kUF6uR/k8ca0j16nsdXoO9ZJD+XQc0+X7OKodmQvJ5yM9
h3rJobzsI8nfRat1ZC4kn0/1HOolh/Lpump+HzdQ76i50BZ5cqiXHMrLPlLX
4yFH5kL2OMmhXnIon9wZ2fkQdeR9gT1PyKFecigv+wD2eow68r7MXqfkUC85
lFf7GFvcD6OOvC/eYO6T5FAvOZSXfRj7ehR1ZC4x27xOkUO95FA+XYeyjzRz
cs7Cod6VL7zr1GWb/OOhXnIor/eR6h09F/Id6iWH8nofqd7RcyHfoV5yKK/3
kWZVO3ou5DvUSw7l5X4of5er1tFzId+hXnIor/eR6h09F/Id6iWH8up5YGG9
o+dCvkO95FBe7yPVO3ou5DvUSw7l9T5SvaPnQr5DveRQnuYhUYfmJORQb3Ru
0y+H8lvboflMOs/z3xuSI/nme8pcx+u1DuXL85nujuSb74lzHa/XOsU8znmC
zkB3x+tt/XlhPtY6dwo4km++J9F1vF7rUJ7mM1FH8h9qPq/sOV6vdShfnM8E
HNlTkr8X5TnUSw7laT4TdfSeku9QLzmUp/lM1NF7Sr5DveRQnuYzUUfvKfkO
9ZJDeZrPRB29p+Q71EsO5Wk+E3X0npLvUC85lKf5TNSR+4zNk0O95FCe5jNR
R3Inw/3fOuXe3KF8eT7T3ZH84T9te/3NHa/XOsU8znmCzub8be+4Zpc7j/Md
r7fVKczHWudOAUfyaU/Jd7xe61Ce5jNRR/IrWp//c8frtQ7li/OZgCN5e52S
4/XSfcPmi3OegKPz+f6Ydbr10r5W1/lMd0fvKdHxj7i95FCe5jNRR+8pjbgO
9ZJDeZrPRB29pzTiOtRLDuVpPhN1FsDnFMihXnIoT/OQqJNy+ZyEHG8O0zXf
L4fy/XJk3iXze/m53seYkflyv/QceV882tyfPId6yaG87MPIXLzWkbnE4839
yXOolxzKp38nOT8n6UzMhXyHesmhvN5H2rba0XMh36Feciivz4fp1Y6eC/kO
9ZJDeb2PtE21o+dCg65DveRQXo5DjqvW0XOhQdehXnIor/eR6h09Fxp0Heol
h/JyXcl1WevoudCg61AvOZTX+0j1jp4LDboO9ZJD+eTOyM6HqKPnQoOuQ73k
UF7vI9U7ei406DrUSw7l9T7S9GpHz4V8h3rJobzeR9q22tFzId+hXnIon65D
2UfabnLOxFzIPx7qJYfycjxHtD6PdXfkONe0Pae1ONRLDuX1+TCj2pHzZI55
TiaHesmhvFyP9v1I1JHr1L5PIYd6yaG8HIccV60jxyfH6znUSw7l5X2InBe1
jsyF5HzxHOolh/L6eWCo2lFzoYW+Q73kUF72kboeDzkyF7LHSQ71kkN52Uey
50PUkfcn9jwhh3rJoTzNQ6IOzUnIod7o3KZfDuW3tkPzmXR+5783JEfyX2p+
X+o5Xq91KF+ez3R3JP+R5en31Z7j9VqnmMc5T9AZ6O54va0/L8zHWudOAUfy
aU9puut4vdahPM1noo7kP9TMyz3H67UO5YvzmYCj95R8h3rJoTzNZ6KO3lPy
Heolh/I0n4k6ek/Jd6iXHMrTfCbq6D0l36FecihP85moo/eUfId6yaE8zWei
jt5T8h3qJYfyNJ+JOpKzeXKolxzK03wm6qSc7Cnl93/rlHtzh/Ll+Ux3R/Jp
T8k/Hq/XOsU8znmCzsSeku94va1OYT7WOncKOJJ/4ymrWp4/c8frtQ7laT4T
dSR/eevzf+54vdahfHE+E3Akb69Tcrxeum/YfHHOE3B0Pt8fs0633nxfy+bL
85nujt5TouMfdnvJoTzNZ6KO3lMadh3qJYfyNJ+JOnpPadh1qJccytN8Juos
gM8pkEO95FCe5iFRR65PmyfHm8N0zffLoXy/HD3vmjrxc72PMQX8aa6j50K+
Q73kUF7vIw1UO3ou5DvUSw7l07+TnJ+TdCbmQr5DveRQXo7npP1Wv+Xss15a
VuvIce7+4p/e+91rfId6yaG8Oh8GNlY7cp7cf/h7rn3kqBddh3rJobxcjyt2
WX7YutteqHbkOv30B++87bhPPuc61EsO5dO/7/TeVWee8evlK5+vduT92FNL
D7lo6cBzrkO95FBe9gD2PH7phcfsU+/IXGjGKa/cZmCLPDnUSw7l03kgv4+r
d9RcaIs8OdRLDuVlD6Dr8ZAjcyF7nORQLzmUT+fDjOx8iDryvsCeJ+RQLzmU
l9+f2esx6shzjL1OyaFeciiv9jG2uB9GHXkevc/cJ8mhXnIoL7+HPtG8HkUd
eT8w17xOkUO95FA+HcdQb1P6v8k5m9+PzXv2qw+c38GhXnIor/eR7HNUd0fP
hXyHesmhvN5HmlLt6LmQ71AvOZTX+0hTqx09F5rmOtRLDuXlfpiOq97Rc6Fp
rkO95FBe7yPVO3ouNM11qJccyuvngWnVjp4L+Q71kkN5vY/kHw85ei7kHw/1
kkN5vY9U7+i5kP/fRb3kUJ7mIVGH5iTkUG90btMvh/Jb26H5TDq/898bkiO5
tKdk7w+54/Vah/Ll+Ux3R/JpT8k/Hq/XOsU8znmCzkB3x+tt/XlhPtY6dwo4
kp97xkG3f/HmF13H67UO5Wk+E3Ukf8/Jq06adoidD+SO12sdyhfnMwFH9pP+
4Q1ve2K71425DvWSQ3maz0Qdvac05jrUSw7laT4TdfSe0pjrUC85lKf5TNTR
e0pjrkO95FCe5jNRR+8pjbkO9ZJDeZrPRB29pzTmOtRLDuVpPhN15D5j8+RQ
LzmUp/lM1Em54d5dcP+3Trk3dyhfns90dyS/+DsHt7z+5o7Xa51iHuc8QWdz
/oIvHHboZ27xj8frbXUK87HWuVPAkXzaU7LPn7nj9VqH8jSfiTqSv7z1+T93
vF7rUL44nwk4krfXKTleL903bL445wk4Op/vj1mnWy/ta3Wdz3R39J4SHf+g
20sO5Wk+E3X0ntKg61AvOZSn+UzU0XtKg65DveRQnuYzUWcBfE6BHOolh/I0
D4k6krN5crw5TNd8vxzK98uRede+D+1306vf/uuJ+5jex/hV9j7xvC+99e1X
f+yZZZ4j74v3+NbX3vs73/Ad6iWH8rIPs2T5risuvuR/qh2ZSzww7dt7//Gx
vkO95FA+HYccz1OTcybmQr5DveRQXo7nztNvPvWx9b+oduQ4/2xs0VV/ffgT
rkO95FBenw8bqh05T/5x8Q1H3PX3j7kO9ZJDebkeLz/0c1fe8fH/qnbkOp15
92c+fsv2j7gO9ZJD+fTvO703/5GfPbZo8aPVjsyF1h782ZGDp6xzHeolh/Ky
j/TeWw/a5vpT1lc7MhcauXev7QcG1rkO9ZJD+XQeyO/j6h09F1rnOtRLDuVl
H6nr8ZAjcyF7nORQLzmUT+fDjOx8iDryvsCeJ+RQLzmUl32Ay8z1GHXkfZm9
TsmhXnIoL/sYaR3m59WOvC++1twnyaFecigv+zB3mNejqCNziSPN6xQ51EsO
5dN1NdR7afx4/ntyzsKh3slPHnL9xpd8h3rJobwcz1dan8e6O3Kc3257Tmtx
qJccyuvz4ZfVjpwnu5vnZHKolxzKy/Vo349EHblO7fsUcqiXHMrL/fD9l35u
aL95T1c7cp+cecKt556w6RnXoV5yKC/7SPd99YS/ve7uekfmQs9e8djzm7bI
k0O95FBePw88U+2oudDAs65DveRQXvaRuh4POTIXssdJDvWSQ3nZR7LnQ9SR
uZA9T8ihXnIoT/OQqENzEnKoNzq36ZdD+a3t0Hwmna/57w3JkfybF8/98ou3
2vtD7ni91qF8eT7T3ZH86s/9ywEfeqd/PF6vdYp5nPMEnYHujtfb+vPCfKx1
7hRwJH/4zz79id/78M9dx+u1DuVpPhN1JL/432+8a/qldj6QO16vdShfnM8E
HNlTOvTo81bP+pO1rkO95FCe5jNRR+8prXUd6iWH8jSfiTp6T2mt61AvOZSn
+UzU0XtKa12HesmhPM1noo7eU1rrOtRLDuVpPhN19J7SWtehXnIoT/OZqCP3
GZsnh3rJoTzNZ6JOyg33LoX7v3XKvblD+fJ8prsj+X3Pubjl9Td3vF7rFPM4
5wk6m/NT97jy87NP9Y/H6211CvOx1rlTwJH8cffe2PL8mTter3UoT/OZqCP5
3Vqf/3PH67UO5YvzmYAjeXudkuP10n3D5otznoCj8/n+mHW69eb7WjZfns90
d/SeEh3/mNtLDuVpPhN19J7SmOtQLzmUp/lM1NF7SmOuQ73kUJ7mM1FnAXxO
gRzqJYfyNA+JOimXz0nI8eYwXfP9cijfL0fmXQ+e9vD3zx27d+Lneh9jeeY/
/OENY5dveNB15H3x+xYdfOe681a6DvWSQ3nZh1l90fFLv7vq1mpH5hInHvDR
F+ZdfovrUC85lE/HMfH3oAYm5UzMhXyHesmhvBzPA+l4Dqx15DgXpON0Heol
h/JyPqTfh95V7ch5ckw6T1yHesmhvLkeqx25Ttem69R1qJccyqd/3+m9hfv/
0V5rlt9X7chcaP7Z/7H6nI0PuQ71kkN52Uc68rPnPn31Xj+pdmQu9NMFSx/f
tOkh16Feciifrir5fdyqakfPhda4DvWSQ3nZRzqq4/GQI3Mhe5zkUC85lE/n
w4zsfIg68r7AnifkUC85lJd9gNXmeow68r7MXqfkUC85lJd9jMHxA1te7cj7
4pPNfZIc6iWH8rIPs9a8HkUdmUtcbF6nyKFeciifrquh3seXzj36iCU3vG1S
zsKh3hfufNUFe+z6Gvd4qJccysvx3NP6PNbdkeP8qz9oeU5rcaiXHMrL+TCW
ngeqHTlPDjfPyeRQLzmUl+vRvh+JOnKd2vcp5FAvOZSX++H56X5Y7Zj7pOtQ
LzmUl32kI9LrUbXzlH6dch3qJYfy5nmg2tFzoTWuQ73kUF72kY7qeDzk7Kaf
01yHesmhvOwjXWjOh6jzuH5Odh3qJYfy8n5ktbkeo455n+I61EsO5WmeE3Vo
zuM51EuO/TnNZ9L5mv/ekBzJf/+0JR/95SMPuI7Xax3Kl+cz3R3Jr/zUmif2
f98K1/F6rVPM45wn6Ax0d7ze1p8X5mOtc6eAI/m703G6jtdrHcrTfCbqSH5F
Ok9cx+u1DuWL85mAI3tKpx+74zvX/OXDrkO95FCe5jNRx+wpuQ71kkN5ms9E
HbOn5DrUSw7laT4TdcyekutQLzmUp/lM1DF7Sq5DveRQnuYzUcfsKbkO9ZJD
eZrPRB25z9g8OdRLDuVpPhN1Um64tx7u/9Yp9+YO5cvzme6O5Hff40ctr7+5
4/Vap5jHOU/Q2Zx/8tp9T33ftTd3++8q9LY6hflY69wp4Ej+Bxd+quX5M3e8
XutQnuYzUUfyS1uf/3PH67UO5YvzmYAjeXudkuP10n3D5otznoBj8q7Tsdc9
zvJ8pruj95Tw+N1ecihP85moo/eU1roO9ZJDeZrPRB29p7TWdaiXHMrTfCbq
LIDPKZBDveRQnuYzUSfl8jkJOdRLDuW9ec5kez2na6/5uzET9zHz93AOtH6z
J3+g58j74uvSXrrrUC85lDd/j6jaMZ8Lcx3qJYfy6Tgm/h7U5JyXP5fnOtRL
DuXleJq/h1DtmM9Fug71kkN58/fQqh3zuVTXoV5yKG8+R1ztmH1O16Feciif
/n0nPg9e7WzQe7muQ73kUP6b+vP41c5v6b1o16FeciifzoOJv4dQ7ei50LOu
Q73kUP4I/fcoqp21+nMBrkO95FA+nQ8zsvMh6pjPZbgO9ZJDefP3WKod87kY
16Feciivv4/vV9WOvC/e09wnyaFecigv+zBLzOtR1JG5xIPmdYoc6iWH8uk4
hnrjv5fe4vW9ylk41Ltnu+PfcEEHh3rJobwcz/dan8e6O3Kci9qe01oc6iWH
8nI+TB0v2lDtyHlyvXlOJod6yaG8XI/2/UjUMZ8Ldh3qJYfycj/8w/T3AKsd
87ls16Fecigv+0jHpr/HWO08pT8X7zrUSw7l9fNAvaPnQutch3rJofy39N8j
rXZ2038XwnWolxzKyz7SgeZ8iDqP67/L4TrUSw7l5f3IZeZ6jDo0JyGHer25
jc3TPCfqUD46R4o6NJ9J52v+e0NyJP+l9HcSXMfrtQ7ly/OZ7o7km79T5Dpe
r3WKeZzzBJ2B7o7X2/rzwnysde4UcCT/YPo7Xa7j9VqH8jSfiTqSn5f+ToLr
eL3WoXxxPhNwZE/p+Af+beTZNfb9fu5QLzmUp/lM1DHf0+c61EsO5Wk+E3XM
9/S5DvWSQ3maz0Qd8z19rkO95FCe5jNRx3xPn+tQLzmUp/lM1DHf0+c61EsO
5Wk+E3XkPmPz5FAvOZSn+UzUSbnh3v5w/7dOuTd3KF+ez3R3JP/Bg7/T8vqb
O16vdYp5nPMEnc35v/uLm/75nHf4x+P1tjqF+Vjr3CngSP6wBUtanj9zx+u1
DuVpPhN1JP+N1uf/3PF6rUP54nwm4EjeXqfkeL1037D54pwn4Oh8vj9mnW69
+b6WzZfnM90ds6fkOtRLDuVpPhN1zJ6S61AvOZSn+UzUMXtKrkO95FCe5jNR
ZwF8ToEc6iWH8jQPiTopl89JyPHmMF3z/XIo3y9H5l0rdll+2LrbXpj4ud7H
2Jj5zfdEu468L74/fS+z61AvOZSXfZgT91v9lrPPeqnakbnE7ul7mV2Hesmh
fDqOib8HNX9Szsufy3Md6iWH8nI86fcS9Y4c5+Ppe5ldh3rJobw6HxZOqXbk
PGm+l9l1qJccysv1mH4vN7XaMd9n6jrUSw7l03FM76Xfi9Y7MhdqvpfWdaiX
HMrLPlL6vXS9I3Oh5nuBXYd6yaF8uqzk93HTqh01F1roO9RLDuVlH6nr8ZAj
cyF7nORQLzmUT+6M7HyIOuZ7yV2HesmhvOwD2Osx6pjvhXcd6iWH8mofaYv7
YdSR98Wj5j5JDvWSQ3nZh7GvR1FH5hK/MK9T5FAvOZRP1+FQ9vpe5Swc6n1o
8IbL53dwqJccysvxnNT6PNbdkeM8tO05rcWhXnIoL+dD2gfbWO3IefKAeU4m
h3rJobxcj/b9SNSR69S+TyGHesmhvNwPrzrzjF8vX/l8tSP3yaeWHnLR0oHn
XId6yaG87CPtefzSC4/Zp96RudCMU165zcAWeXKolxzK6+eBekfPhZ5zHeol
h/Kyj9T1eMiRuZA9TnKolxzKyz6SPR+ijsyF7HlCDvWSQ3mah0QdmpOQQ73R
uU2/HMpvbYfmM+l8zX9vSI7kV5686qRph9j7Q+54vdahfHk+092R/OvPOOj2
L97sH4/Xa51iHuc8QWegu+P1tv68MB9rnTsFHMl/ZPlv9gWmuI7Xax3K03wm
6kj+yvF9ATsfyB2v1zqUL85nAo7sKe31+Acu+psnfYd6yaE8zWeijt5TGnQd
6iWH8jSfiTp6T2nQdaiXHMrTfCbq6D2lQdehXnIoT/OZqKP3lAZdh3rJoTzN
Z6KO3lMadB3qJYfyNJ+JOnKfsXlyqJccytN8Juqk3HDvy3D/t065N3coX57P
dHckf9Nr215/c8frtU4xj3OeoLM5f+Atxz701qt9x+ttdQrzsda5U8CR/DV7
H9ny/Jk7Xq91KE/zmagj+VWtz/+54/Vah/LF+UzAkby9Tsnxeum+YfPFOU/A
0fl8f8w63XrzfS2bL89nujvme/pch3rJoTzNZ6KO+Z4+16FecihP85moY76n
z3WolxzK03wm6iyAzymQQ73kUJ7mIVEn5fI5CTneHKZrvl8O5fvlyLyr+d+J
+5jex5ievU9s/ne+58j74ub9metQLzmUl32YZi+g2pG5xJx0fbgO9ZJD+fTv
JOfndpNzJuZCvkO95FBe7yPVO3ou5DvUSw7l9fkwo9rRcyHfoV5yKK/3kbav
dvRcaMh1qJccyjfXYbOPUe/oudCQ61AvOZTX+0j1jp4LDbkO9ZJD+ea6aq6v
oWpHz4V8h3rJobzeR/KPhxw9F/KPh3rJoXxzHWbnQ9TRcyH/v4t6yaG83keq
d/RcaMh1qJccyut9pBnVjp4L+Q71kkN5vY+0XbWj50K+Q73kUL65DrPX9ypn
Yi7kO9RLDuXleL7V+jzW3ZHj3KXtOa3FoV5yKK/Ph+nVjpwnj5vnZHKolxzK
y/Vo349EHblO7fsUcqiXHMrL/bB5Lqt25D7ZPK+5DvWSQ3nZR2qei6sdmQs1
z8uuQ73kUF4/D9Q7ai60RZ4c6iWH8rKP1PV4yJG5kD1OcqiXHMrLPpI9H6KO
zIXseUIO9ZJDeZqHRB2ak5BDvdG5Tb8cym9th+Yz6fzOf29IjuSbfQHX8Xqt
Q/nyfKa7I/nL9nvtb+a1ruP1WqeYxzlP0Bno7ni9rT8vzMda504BR/JpT2mG
63i91qE8zWeijuTTnpKdD+SO12sdyhfnMwFH7yn5DvWSQ3maz0Qdvac07DrU
Sw7laT4TdfSe0rDrUC85lKf5TNTRe0rDrkO95FCe5jNRR+8pDbsO9ZJDeZrP
RB29pzTsOtRLDuVpPhN15D5j8+RQLzmUp/lM1GlyzZ5Sfv+3Trk3dyhfns90
dySf9pT84/F6rVPM45wn6EzsKfmO19vqFOZjrXOngCP5H18xt+X5M3e8XutQ
nuYzUUfyp7U+/+eO12sdyhfnMwFH8vY6JcfrpfuGzRfnPAFH532nW69/nOX5
THdH7yn5DvWSQ3maz0QdvafkO9RLDuVpPhN19J6S71AvOZSn+UzUWQCfUyCH
esmhPM1Dok6Ty/LkeHOYrvl+OZTvl6PnXa+Y+Lnex9gB/GHX0XMh36Feciiv
95F2rHb0XMh3qJccyqd/Jzk/Z07OmZgL+Q71kkN5OZ65Z130yxNPqnfkOJ/u
PXH3Ucf4DvWSQ3l1PvTqHTlPLt5z99G7Hvcd6iWH8nI93vPMytP+946zqh25
Tpdcc+mR1y3xHeolh/Lp33d674uvW3/7JYfVOzIXOuiVN5zwk2W+Q73kUF72
kZ4+5T0LNpxV78hc6KVdv/PSpmW+Q73kUD5dV83v4xbWO2ou1PMd6iWH8rKP
1PV4yJG5kD1OcqiXHMqn45iRnQ9RR94X2POEHOolh/KyD2Cvx6gj78vsdUoO
9ZJDebWPscX9MOrI+2J7nySHesmhvOzD7GZej6KOzCWeMa9T5FAvOZRP16Ps
I03SWTjU22fqe97xmg4O9ZJDeb2PZJ/Hujt6LuQ71EsO5fU+0g7Vjp4L+Q71
kkN5vY/0impHz4XyObN1qJccysv9MD2X1Tt6LkTzrmG3lxzK632kekfPhWjO
Nuz2kkN59TwwUO/oudCw61AvOZTX+0j1jp4LDbsO9ZJDeb2PVO/oudCw61Av
OZSneUjUoTkJOdQbndv0y6H81nZoPpPO7/z3huRIPu0L2PtD7ni91qF8eT7T
3ZF82lPyj8frtU4xj3OeoDPQ3fF6W39emI+1zp0CjuT3XX/6Dx78ke94vdah
PM1noo7kV/7njLkHnm7fL+eO12sdyhfnMwFH9pSuePrGOw541neolxzK03wm
6ug9pRHXoV5yKE/zmaij95RGXId6yaE8zWeijt5TGnEd6iWH8jSfiTp6T2nE
daiXHMrTfCbq6D2lEdehXnIoT/OZqCP3GZsnh3rJoTzNZ6JOyg337oH7v3XK
vblD+fJ8prsj+WMXtb3+5o7Xa51iHuc8QWdz/qrVX//IV97d8b+r0NvqFOZj
rXOngCP5tKdknz9zx+u1DuVpPhN1JH9a6/N/7ni91qF8cT4TcCRvr1NyvF66
b9h8cc4TcHTed7r1+sdZns90d/Seku9QLzmUp/lM1NF7Sr5DveRQnuYzUUfv
KfkO9ZJDeZrPRJ0F8DkFcqiXHMrTPCTqpFw+JyHHm8N0zffLoXy/HJl3zZsx
77Lznnr5Pqb2MebvlPknHnvmjcd8YMR15H3xOT++/+e/P9t3qJccyss+zIOX
nPuKr3y53pG5xPYHjuzzjet8h3rJoXz6d5Lzc/bknIm5kO9QLzmU1/tI9Y6e
C/kO9ZJDeb2PVO/ouZDvUC85lNf7SHOqHT0X8h3qJYfy6d9X9pHqHT0X8h3q
JYfyeh+p3tFzId+hXnIon64r2Ueqd/RcyHeolxzK632kekfPhXyHesmhfDqO
Gdn5EHX0XMh3qJccyut9pHpHz4V8h3rJobzeR5pd7ei5kO9QLzmU1/tI9Y6e
C/kO9ZJD+XQ9yj7SJJ2JuZDvUC85lJfjaX8e6+7IcY60Pae1ONRLDuXV+TC/
3pHz5FzznEwO9ZJDebke7fuRqCPXqX2fQg71kkN5uR+esmbnA866qd6R++R3
H3vX0t3m+w71kkN52UcauuJrV825pN6RudDU1QdPGZjvO9RLDuX180C9o+ZC
832HesmhvOwjdT0ecmQuZI+THOolh/Kyj2TPh6gjcyF7npBDveRQnuYhUYfm
JORQb3Ru0y+H8lvboflMOs/z3xuSI/k3v+qZVb1F+c+t4/Vah/Ll+Ux3R/Ir
dl70pte/0Xe8XusU8zjnCToD3R2vt/XnhflY69wp4Eg+7Sn5jtdrHcrTfCbq
SD7tKdn3y7nj9VqH8sX5TMDRe0q+Q73kUJ7mM1FH7ymNug71kkN5ms9EHb2n
NOo61EsO5Wk+E3X0ntKo61AvOZSn+UzU0XtKo65DveRQnuYzUUfvKY26DvWS
Q3maz0Qduc/YPDnUSw7laT4TdVJO9pT84yn35g7ly/OZ7o7k056S73i91inm
cc4TdCb2lDr+dxV6W53CfKx17hRwJL/h7stanj9zx+u1DuVpPhN1JL9v6/N/
7ni91qF8cT4TcCRvr1NyvF66b9h8cc4TcHTed7r1+sdZns90d/Seku9QLzmU
p/lM1NF7Sr5DveRQnuYzUUfvKfkO9ZJDeZrPRJ0F8DkFcqiXHMrTPCTqpFw+
JyHHm8N0zffLoXy/nBW7LD9s3W0vLGt+b9iTn1915hm/Xr7y+WXj8d7siZ83
32u4rHlO63lO832Qy5rnItehXnIov+fxSy88Zp/nlzX7MNVO832cy5rnIteh
XnIon/6dmuMZmKzzXGeHesmhvBxP8/u4akeOcyg9F7kO9ZJDeXU+zK935Dxp
5qKuQ73kUF6ux2aOXe3IddrcT1yHesmhfPp33bis+X1EtXN/+j7sZc3rgutQ
LzmUP3G/1W85+6yXljW/D6p23pS+j3xZ87rsOtRLDuXT8Qyk14uF9c7pV/Xe
u2jTpua88h3qJYfyaR9poNf1eMhJc6GBnj1OcqiXHMqn45jSs+dD1EnvC6b0
7HlCDvWSQ/m0DzC1Z6/HqJPel03r2euUHOolh/JpH2Nqz94Po056XzytZ++T
5FAvOZRP+zBTe6vM61HUSXOJafJ7MdehXnIony7HaT37+l7lLJzW+/7Gr93y
8Cb/eKiXHMrL8bQ+jwUcOc4n257TWhzqJYfy6nzo1TtynnzGPCeTQ73kUF6u
R/t+JOrIdWrfp5BDveRQXu6HzT5qtSP3yeb3Aq5DveRQ/sjm9ajZB652nmpe
p5rfy7gO9ZJDef08UO/83yf+afFZ8pzQ8x3q/f9pu/tou+rq3v95OCAkUeEI
x1Fpx+1VEARFSylcVEzawuWiPEh1oChcFLDiBbFSpdRaDdj2FhmgSPpDjObS
WEDagg9AZVgH+0hBcsEgVcQQopyG2GIQiiLJQYX8uFlrxsy51nt9vvN7jv3H
Mfb49PVZjKy19trzzHM2OZQ/tX0eKz0eco5rn9PicZJDveRQfus+0jPPw/F8
yDrfbZ+T43lCDvWSQ3mah2QdmpOQQ73Zuc1sOZT/VTs0n2lO8+l2bjAhHcu3
exrSUb3RofzwfKbcsXy7JyMd1Rud4TzNebLOdLGjevtf5/lY/9yp3LF8uycm
HdUbHcrTfCbrWL7d05OO6o0O5YfnM+XO373k1Y/s9KLp0bsWHPuqW3bSDvWS
Q3maz2SdO09bc+r8I2wuqh3qJYfyNJ/JOjv95eJbPnnDLzp5cqiXHMrTfCbr
PPjpnz46mny6kyeHesmhPM1nsk6zpzR3MubJoV5yKE/zmazT7CnN6+TJoV5y
KE/zmaxj95mYJ4d6yaE8zWeyTpMbmzwA7v/RGe7tOpQfns+UO5a/+qy+99+u
o3qjM5jHOU/SeSb/tr3e8IlTri387xro7XUG5mO9c6eEY/mJA8/seU7rOqo3
OpSn+UzWsfwdvc//XUf1Rofyg/OZhGP5eJ2So3rpvhHzg3OehOPzE9Ip652Q
+eH5TLnT7CnNFcc/IXvJoTzNZ7LOC/c5dt/V19lzwoR0qJccytN8Jusc+s4l
2z2nTUiHesmhPM1nss7N7jl5QjrUSw7laR6SdZpcd05CjprDlOZny6H8bDl+
3rXrttf9PtIu4O8qHT8X0g71kkN5v49U7/i5kHaolxzKN/9Odn7O1Hmy2KFe
cihvx9N+H2K1Y8fZ/l166VAvOZR358PS51Q7dp60fxdUOtRLDuXtemy/x6Ha
seu0/Xt60qFecijf/Ls+NWq/j6PasblQ+3cRpUO95FDe9pHa70Opdmwu1P5d
SulQLzmUb46n/XncnHrHzYW2y5NDveRQ3vaRSo+HHJsLxeMkh3rJoXzjzp2M
50PWsc8F8Twhh3rJobztA8TrMevY57J4nZJDveRQ3u1jbHc/zDr2uXhjuE+S
Q73kUN72YeL7UdaxucRu4X2KHOolh/LNdWj7SLvMzFk6f/Lynx93xmiLPh7q
JYfyfh+p3vFzIe1QLzmU9/tI9Y6fC2mHesmhvN9H2rXa8XMh7VAvOZS3+2H7
fazVjp8LaYd6yaG830eqd/xcSDvUSw7l3fPA0nrHz4W0Q73kUN7vI9U7fi6k
Heolh/J+H6ne8XMh7VAvOZSneUjWoTkJOdSbndvMlkP5X7VD85nmNO/5uSE4
lm+/p0w6qjc6lB+ez5Q7lm+/J046qjc6w3ma82Sd6WJH9fa/zvOx/rlTuWP5
9nsSpaN6o0N5ms9kHcu/s/meGumo3uhQfng+U+7YnlLz96K0Q73kUJ7mM1nH
7ylph3rJoTzNZ7KO31PSDvWSQ3maz2Qdv6ekHeolh/I0n8k6fk9JO9RLDuVp
PpN1/J6SdqiXHMrTfCbr2H0m5smhXnIoT/OZrNPkxiZPg/t/dIZ7uw7lh+cz
5Y7lj/5e3/tv11G90RnM45wn6TyT/9prr9rztrdoR/X2OgPzsd65U8KxfLOn
pB3VGx3K03wm61j+jt7n/66jeqND+cH5TMKxfLxOyVG9dN+I+cE5T8Lx+e7+
WHTKemlfq3Q+U+74PSU6/nHZSw7laT6Tdfye0rh0qJccytN8Juv4PaVx6VAv
OZSn+UzWuRl+T4Ec6iWH8jQPyTpNrjsnIUfNYUrzs+VQfrYcm3fZ91fY634f
Y+eOb38vUDn2uXii/ft8yqFecihv+zD2vRC1js0lHm7/Pp9yqJccyjf/TnZ+
ztR5stihXnIo7/eRnlXt+LmQdqiXHMr782HHasfPhbRDveRQ3u8j7VDt+LnQ
mHSolxzKN/+uto9U7/i50Jh0qJccyvt9pHrHz4XGpEO95FC+OR7bR6p3/Fxo
TDrUSw7l/T5SvePnQmPSoV5yKN+4to9U7/i50Jh0qJccyvt9pHrHz4XGpEO9
5FDe7yPtWO34uZB2qJccyvt9pGdVO34upB3qJYfyzXVo+0g7zczZNhfSx0O9
5FDejueYvuexhGPHua7vOa3HoV5yKO/Ph52rHTtPdg/PyeRQLzmUt+sxfh7J
Onadxs8p5FAvOZS3+6F9L2KtY/dJ+/v0yqFecihv+0j2vZS1js2F7PsBlEO9
5FDePw8srHbcXGipdqiXHMrbPlLp8ZBjc6F4nORQLzmUt32keD5kHZsLxfOE
HOolh/I0D8k6NCchh3qzc5vZcij/q3ZoPtOc3z0/NwTH8p9qvy9IOao3OpQf
ns+UO5Z/96rm+5qUo3qjM5ynOU/WmS52VG//6zwf6587lTuWb/aUdpSO6o0O
5Wk+k3Us/872+yKUo3qjQ/nh+Uy54/eUtEO95FCe5jNZx+8paYd6yaE8zWey
jt9T0g71kkN5ms9kHb+npB3qJYfyNJ/JOn5PSTvUSw7laT6TdfyeknaolxzK
03wm69h9JubJoV5yKE/zmaxjudPg/h+d4d6uQ/nh+Uy5Y/lmT0kfj+qNzmAe
5zxJZ9ueknZUb68zMB/rnTslHMu/7PQ1Pc9pXUf1RofyNJ/JOpZf1vv833VU
b3QoPzifSTiWj9cpOaqX7hsxPzjnSTg+390fi05Zb3dfK+aH5zPljt9TouNf
JHvJoTzNZ7KO31NaJB3qJYfyNJ/JOn5PaZF0qJccytN8JuvcDL+nQA71kkN5
modknSbXnZOQo+YwpfnZcig/W46fd83b9rrfx5gL/nzp+LmQdqiXHMr7faQ5
1Y6fC2mHesmhfPPvZOfnTJ0nix3qJYfydjw2F6917Dj3be9PyqFecijvzoc5
T1U7dp7YfEI51EsO5e16tP+tdew6tf9VDvWSQ3k7DjuuWseOz45XOdRLDuVt
H8nOi1rH5kJ2viiHesmhvF1Xdl3WOm4utF2eHOolh/K2j1R6POTYXCgeJznU
Sw7lt7LPvA/F8yHr2OeCeJ6QQ73kUN6eA+L1mHXs+SBep+RQLzmUd/sY290P
s459Lr4n3CfJoV5yKG/7MKeE96OsY3OJvcP7FDnUSw7lm+OYP7ml+b+ZOUvn
Tx6w+bP3fqjAoV5yKO/3kcJzTsLxcyHtUC85lPf7SHOrHT8X0g71kkN5v480
r9rxc6H50qFecihvx2HHVev4udB86VAvOZT3+0j1jp8LzZcO9ZJDef88ML/a
8XMh7VAvOZT3+0j6eMjxcyF9PNRLDuX9PlK94+dC+r+LesmhPM1Dsg7NScih
3uzcZrYcyv+qHZrPNOd3z88NwbH8p9qflypH9UaH8sPzmXLH8s2ekj4e1Rud
4TzNebLOdLGjevtf5/lY/9yp3LH83u85bOu8XDmqNzqUp/lM1rH8Xe28XDmq
NzqUH57PlDu2p2T/qxzqJYfyNJ/JOn5PaVo61EsO5Wk+k3X8ntK0dKiXHMrT
fCbr+D2laelQLzmUp/lM1vF7StPSoV5yKE/zmazj95SmpUO95FCe5jNZx3Ix
Tw71kkN5ms9knSY3Nnk73P+jM9zbdSg/PJ8pdyy//CuH97z/dh3VG53BPM55
ks4z+fP+5qgjP3qjPh7V2+sMzMd6504Jx/LNnlJ8Tus6qjc6lKf5TNax/LLe
5/+uo3qjQ/nB+UzCsXy8TslRvXTfiPnBOU/C8fnu/lh0ynppX6t0PlPu+D0l
Ov4x2UsO5Wk+k3X8ntKYdKiXHMrTfCbr+D2lMelQLzmUp/lM1rkZfk+BHOol
h/I0D8k6dn3GPDlqDlOany2H8rPl2LzroPsPvv43XvPTbfcxv4/xeOdz4rmf
euVrrvzAppFy7Hl0vy997s2//nntUC85lLefQ69YtdcdF17042rHPg/cO//L
L//9E7RDveRQvjkOO57HZug8WexQLzmUt+O57awbznhow4+qHTvON05fcsWf
Hv2IdKiXHMr782FjtWPnyd8vv+6Y2//2IelQLzmUt+tx2ZEfv/zWj/xHtWPX
6S53fvQjNy54UDrUSw7lm+N4arTkwe8/dMnyH1Q7NheaOvxj44fPXS8d6iWH
8rYH8OabDtvh2tM3VDs2Fxq/e/8Fc+aslw71kkP55njs53H1jp8LrZcO9ZJD
edsDKD0ecmwuFI+THOolh/Jb2aVzJ+P5kHXsc0E8T8ihXnIobz8/uzRcj1nH
nmPidUoO9ZJDefs5aLMO88Nqx55Hrw73SXKolxzK28+hbw3vR1nHPg8cG96n
yKFecijfXFfzJ5/eejz/OTPnmc9jpz16xLVPPa0d6iWH8nY8n+l7Hks4dpxf
7ntO63GolxzK+/PhJ9WOnSf7hudkcqiXHMrb9Rg/j2Qdu07j5xRyqJccytv9
8G0Xf3zhwQc8Ue3YfXKXk24656Qtm6RDveRQ3vaR7vnsSX9+zZ31js2FNl/2
0M+2bJcnh3rJobx/HthU7bi50JzN0qFecihv+0ilx0OOzYXicZJDveRQ3vaR
4vmQdWwuFM8TcqiXHMrTPCTr0JyEHOrNzm1my6H8r9qh+Uxzvvb83BCcbbnl
e3/6FzfF+0PXUb3RofzwfKbcsfzaj//zoe98nT4e1Rud4TzNebLOdLGjevtf
5/lY/9yp3LH80d//67/4rXf9UDqqNzqUp/lM1rH88v/7hdt3vDjOB7qO6o0O
5YfnM+WO7Scd+YZz1+7636ekQ73kUJ7mM1nH7ylNSYd6yaE8zWeyjt9TmpIO
9ZJDeZrPZB2/pzQlHeolh/I0n8k6fk9pSjrUSw7laT6Tdfye0pR0qJccytN8
JuvYfSbmyaFecihP85ms0+TGJi+G+390hnu7DuWH5zPljuUPev+FPe+/XUf1
Rmcwj3OepPNMft5+l39itzP08ajeXmdgPtY7d0o4ln/L3V/oeU7rOqo3OpSn
+UzWsfw+vc//XUf1Rofyg/OZhGP5eJ2So3rpvhHzg3OehOPz3f2x6JT1dve1
Yn54PlPu+D0lOv5p2UsO5Wk+k3X8ntK0dKiXHMrTfCbr+D2laelQLzmUp/lM
1rkZfk+BHOolh/I0D8k6lot5ctQcpjQ/Ww7lZ8uxedd9Zz7wjXOm7972ut/H
WNXxH3jXxullG++Tjn0ufuslh9+2/tzV0qFecihv+zBrLzhx5VfX3FTt2Fzi
lEP/6OcHLLtROtRLDuWb49j296DmzMx5stihXnIob8dzb3M8i2sdO86Tm+OU
DvWSQ3k7H5qfh95e7dh5cnxznkiHesmhfLgeqx27Tqea61Q61EsO5Zt/1adG
Sw/5vf3Xrbqn2rG50JL3/dva9z91v3SolxzK2z7SsR8754kr9/9utWNzoe+d
vPLhLVvulw71kkP59rKabP5nTbXj50LrpEO95FDe9pFeX3g85NhcKB4nOdRL
DuW3skvnTsbzIevY54J4npBDveRQ3vYB1obrMevY57J4nZJDveRQ3vYxxrYe
2Kpqxz4Xnxbuk+RQLzmUt32YqfB+lHVsLnFheJ8ih3rJoXxzXc2f/MjKvd9w
zIrrXj0jZ+n8yb+57dfO22+v35THQ73kUN6O566+57GEY8f5J6/qeU7rcaiX
HMrb+TDdPA9UO3aeHB2ek8mhXnIob9dj/DySdew6jZ9TyKFecihv98MPNffD
aifcJ6VDveRQ3vaRjmnej6qdx/z7lHSolxzKh+eBasfPhdZJh3rJobztI72+
8HjIOc4/p0mHesmhvO0jnR/Oh6zzXf+cLB3qJYfy9nlkbbges074nCId6iWH
8jTPyTo051EO9ZITX6f5THO+9vzcEBzLf+PMFX/0kwfvlY7qjQ7lh+cz5Y7l
V//VukcOeesd0lG90RnO05wn60wXO6q3/3Wej/XPncody9/ZHKd0VG90KE/z
maxj+Tua80Q6qjc6lB+ez5Q7tqd01gnPfd26P35AOtRLDuVpPpN1wp6SdKiX
HMrTfCbrhD0l6VAvOZSn+UzWCXtK0qFecihP85msE/aUpEO95FCe5jNZJ+wp
SYd6yaE8zWeyjt1nYp4c6iWH8jSfyTpNbmxyA9z/ozPc23UoPzyfKXcsv+9+
3+p5/+06qjc6g3mc8ySdZ/KPXn3QGW+9+oay/66B3l5nYD7WO3dKOJb/5vl/
1fOc1nVUb3QoT/OZrGP5lb3P/11H9UaH8oPzmYRj+XidkqN66b4R84NznoQT
8tIp7JXHOTyfKXf8nhIev+wlh/I0n8k6fk9pSjrUSw7laT6Tdfye0pR0qJcc
ytN8JuvcDL+nQA71kkN5ms9knSbXnZOQQ73kUF7Nc2baq5zS3vB3Y7bdx8Lf
w1kc/XZPfrFy7HPxNc1eunSolxzKh79HVO2E3wuTDvWSQ/nmOLb9PagZOk8W
O9RLDuXteNq/h1DthN+LlA71kkP58PfQqp3we6nSoV5yKB9+j7jaCfuc0qFe
cijfHMe23wevdr7j93KlQ73kUP4U//v41c4r/F60dKiXHMo3x7Pt7yFUO34u
tFk61EsO5Y/xf4+i2pnyvxcgHeolh/Jb2V/+PZBqJ/xehnSolxzKh7/HUu2E
34uRDvWSQ3n/fXyPVzv2ufil4T5JDvWSQ3nbh1kR3o+yjs0l7gvvU+RQLzmU
b45j/uTc8P5e5SydP3nXTie+5LwCh3rJobwdz9f7nscSjh3nJX3PaT0O9ZJD
eTsf5m0t2ljt2HlybXhOJod6yaG8XY/x80jWCb8XLB3qJYfydj/83ebvAVY7
4feypUO95FDe9pFOaP4eY7XzmP+9eOlQLzmU988D9Y6fC62XDvWSQ/lT/d8j
rXaO838XQjrUSw7lbR9pcTgfss53/d/lkA71kkN5+zxyabgesw7NScihXjW3
iXma52QdymfnSFmH5jPN+drzc0NwLP+p5u8kSEf1Rofyw/OZcsfy7d8pko7q
jc5wnuY8WWe62FG9/a/zfKx/7lTuWP6+5u90SUf1RofyNJ/JOpY/oPk7CdJR
vdGh/PB8ptyxPaUT7/2X8c3r4uf9rkO95FCe5jNZJ3xPn3SolxzK03wm64Tv
6ZMO9ZJDeZrPZJ3wPX3SoV5yKE/zmawTvqdPOtRLDuVpPpN1wvf0SYd6yaE8
zWeyjt1nYp4c6iWH8jSfyTpNbmzyELj/R2e4t+tQfng+U+5Y/h2Hf6Xn/bfr
qN7oDOZxzpN0nsl/+H9d/0/vf60+HtXb6wzMx3rnTgnH8kedvKLnOa3rqN7o
UJ7mM1nH8p/vff7vOqo3OpQfnM8kHMvH65Qc1Uv3jZgfnPMkHJ/v7o9Fp6y3
u68V88PzmXIn7ClJh3rJoTzNZ7JO2FOSDvWSQ3maz2SdsKckHeolh/I0n8k6
N8PvKZBDveRQnuYhWae9Pjt5ctQcpjQ/Ww7lZ8uxeVf7v9te9/sYT3X89n+l
Y5+L289n0qFecihv+zDtXkC1Y3OJfZvrQzrUSw7lm+PY9veglszMebLYoV5y
KG/H0/5cotqx43y4eX+QDvWSQ3l3PiydW+3YedK+P0uHesmhvF2P7c/lqp3w
fabSoV5yKN9eh6P256LVjs2F2udT6VAvOZS3faT259LVjs2F2s8H0qFecijf
XleTzf/Mr3bcXGipdqiXHMrbPlLp8ZBjc6F4nORQLzmUb6/DyXg+ZJ3wveTS
oV5yKG/7APF6zDrhe+GlQ73kUN7tI213P8w69rl4ItwnyaFecihv+zDx/Sjr
2FziR+F9ihzqJYfy7XU4Gd/fq5yl8yffOXbdsiUFDvWSQ3k7nlP7nscSjh3n
kX3PaT0O9ZJDeTsf2r2AasfOk3vDczI51EsO5e16jJ9Hso5dp/FzCjnUSw7l
7X7YPpdVO3afbJ/XpEO95FDe9pHa5+Jqx+ZC7fOydKiXHMr754F6x8+FnpQO
9ZJDedtHKj0ecmwuFI+THOolh/K2jxTPh6xjc6F4npBDveRQnuYhWYfmJORQ
b3ZuM1sO5X/VDs1nmvO15+eG4Fh+dTMvlI7qjQ7lh+cz5Y7lX/yew/7fvFY6
qjc6w3ma82Sd6WJH9fa/zvOx/rlTuWP5d6/aui8gHdUbHcrTfCbrWP7yZl9A
Oqo3OpQfns+UO7antP/Db7/gzx7VDvWSQ3maz2Qdv6c0Jh3qJYfyNJ/JOn5P
aUw61EsO5Wk+k3X8ntKYdKiXHMrTfCbr+D2lMelQLzmUp/lM1vF7SmPSoV5y
KE/zmaxj95mYJ4d6yaE8zWeyTpub/DTc/6Mz3Nt1KD88nyl3LH/9C/vef7uO
6o3OYB7nPEnnmfziG0+4/5VXakf19joD87HeuVPCsfxVLz+25zmt66je6FCe
5jNZx/Jrep//u47qjQ7lB+czCcfy8TolR/XSfSPmB+c8Ccfnu/tj0Snr7e5r
xfzwfKbcCd/TJx3qJYfyNJ/JOuF7+qRDveRQnuYzWSd8T590qJccytN8Juvc
DL+nQA71kkN5modknTbXyZOj5jCl+dlyKD9bjs273jF+2ot/PLXDtvuY38fY
sfM58dYvrX/btbf88r5Hjn0u3njVP3z7vftoh3rJobztw3xxj0de8MpDnlXt
2Fxi9w/tefr/fIN2qJccyjf/TnZ+7jRD58lih3rJobzfR6p3/FxIO9RLDuX9
+bBztePnQtqhXnIo7/eRFlQ7fi60UDrUSw7lm39X20eqd/xcaKF0qJccyvt9
pHrHz4UWSod6yaF8czz287iF1Y6fC2mHesmhvN9H0sdDjp8L6eOhXnIo37i2
j1Tv+LmQ/u+iXnIo7/eR6h0/F1ooHeolh/J+H2nnasfPhbRDveRQ3u8j7VTt
+LmQdqiXHMo316HtI83Q2TYX0g71kkN5O54v9T2PJRw7zj37ntN6HOolh/L+
fNix2rHz5OHwnEwO9ZJDebse4+eRrGPXafycQg71kkN5ux/efdPBH9jwh/WO
3SfP/dfPHnbc0u68KzrUSw7lbR9pYv/jfne/F9Q7Nhcau+HCeXOWduds0aFe
cijvnwfqHTcX2i5PDvWSQ3nbRyo9HnJsLhSPkxzqJYfyto8Uz4esY3OheJ6Q
Q73kUJ7mIVmH5iTkUG92bjNbDuV/1Q7NZ5rzu+fnhuBY/g8P+NEXz3tRvD90
HdUbHcoPz2fKHctfevAL337UW/TxqN7oDOdpzpN1posd1dv/Os/H+udO5Y7l
mz2lnaWjeqNDeZrPZB3LN3tKcT7QdVRvdCg/PJ8pd/yeknaolxzK03wm6/g9
pUXSoV5yKE/zmazj95QWSYd6yaE8zWeyjt9TWiQd6iWH8jSfyTp+T2mRdKiX
HMrTfCbr+D2lRdKhXnIoT/OZrGP3mZgnh3rJoTzNZ7JOk7M9pe79PzrDvV2H
8sPzmXLH8s2ekj4e1RudwTzOeZLOtj0l7ajeXmdgPtY7d0o4lv/2ZXv3PKd1
HdUbHcrTfCbrWP7M3uf/rqN6o0P5wflMwrF8vE7JUb1034j5wTlPwvF57ZT1
6uMcns+UO35PSTvUSw7laT6TdfyeknaolxzK03wm6/g9Je1QLzmUp/lM1rkZ
fk+BHOolh/I0D8k6Ta47JyFHzWFK87PlUH62HD/veva21/0+xnPAXyQdPxfS
DvWSQ3m/j/TcasfPhbRDveRQvvl3svNzlxk6TxY71EsO5e149j77gp+ccmq9
Y8f5xOQjd77+eO1QLzmUd+fDZL1j58mFL9134vaHtUO95FDerse7Nq0+838/
d9dqx67TFVddfOw1K7RDveRQvvl3fWr0yRdtuOWio+odmwsd9vzrTvruSDvU
Sw7lbR/pidPfdPLGs+sdmws9vddXnt4y0g71kkP55njan8ctrXfcXGhSO9RL
DuVtH6n0eMixuVA8TnKolxzKN8cxdzKeD1nHPhfE84Qc6iWH8rYPEK/HrGOf
y+J1Sg71kkN5t4+x3f0w69jn4nifJId6yaG87cPsE96Pso7NJTaF9ylyqJcc
yjeXo+0jzdBZOn/ywHlveu1vFjjUSw7l/T7Sc6sdPxfSDvWSQ3m/j/ScasfP
hbRDveRQ3u8jPbva8XOh7pw5OtRLDuXtftjsY9Q7fi5E865Fspccyvt9pHrH
z4VozrZI9pJDefc8MKfe8XOhRdKhXnIo7/eR6h0/F1okHeolh/J+H6ne8XOh
RdKhXnIoT/OQrENzEnKoNzu3mS2H8r9qh+Yzzfnd83NDcCzf7CnF+0PXUb3R
ofzwfKbcsXyzp6SPR/VGZzhPc56sM13sqN7+13k+1j93Kncsf9CGs75537e0
o3qjQ3maz2Qdy6/+9533XnxW/LzcdVRvdCg/PJ8pd2xP6bInvnDroZu1Q73k
UJ7mM1nH7ymNS4d6yaE8zWeyjt9TGpcO9ZJDeZrPZB2/pzQuHeolh/I0n8k6
fk9pXDrUSw7laT6Tdfye0rh0qJccytN8JuvYfSbmyaFecihP85ms0+TGJu+C
+390hnu7DuWH5zPljuVPuKTv/bfrqN7oDOZxzpN0nslfsfYf3/2ZPyj87xro
7XUG5mO9c6eEY/lmTyk+p3Ud1RsdytN8JutY/sze5/+uo3qjQ/nB+UzCsXy8
TslRvXTfiPnBOU/C8XntlPXq4xyez5Q7fk9JO9RLDuVpPpN1/J6SdqiXHMrT
fCbr+D0l7VAvOZSn+UzWuRl+T4Ec6iWH8jQPyTpNrjsnIUfNYUrzs+VQfrYc
m3cdsPMBl5772C/vY24fY8nzOv4pJ7z3C8e/fVw69rn4/d/+zg//227aoV5y
KG/7MPdddM6zP/PpesfmEgsWjx/4+Wu0Q73kUL75d7Lzc7cZOk8WO9RLDuX9
PlK94+dC2qFecijv95HqHT8X0g71kkN5v4+0e7Xj50LaoV5yKN/8u9o+Ur3j
50LaoV5yKO/3keodPxfSDvWSQ/nmeGwfqd7xcyHtUC85lPf7SPWOnwtph3rJ
oXxzHLaPVO/4uZB2qJccyvt9pHrHz4W0Q73kUN7vI+1W7fi5kHaolxzK+32k
esfPhbRDveRQvrkcbR9phs62uZB2qJccytvx9D6PJRw7zvG+57Qeh3rJobw7
H5bUO3aenBOek8mhXnIob9dj/DySdew6jZ9TyKFecihv98PT1+1x6NnX1zt2
n/zqQ8et3GeJdqiXHMrbPtLCyz53xe4X1Ts2F5q39vC5c5Zoh3rJobx/Hqh3
3FxoiXaolxzK2z5S6fGQY3OheJzkUC85lLd9pHg+ZB2bC8XzhBzqJYfyNA/J
OjQnIYd6s3Ob2XIo/6t2aD7TnOY9PzcEx/K//Wub1kxe0n09Oqo3OpQfns+U
O5a/Y49LXvHil2lH9UZnOE9znqwzXeyo3v7XeT7WP3cqdyzf7ClpR/VGh/I0
n8k6lm/2lOLn5a6jeqND+eH5TLnj95S0Q73kUJ7mM1nH7ylNSId6yaE8zWey
jt9TmpAO9ZJDeZrPZB2/pzQhHeolh/I0n8k6fk9pQjrUSw7laT6Tdfye0oR0
qJccytN8JuvYfSbmyaFecihP85ms0+RsT0kfz3Bv16H88Hym3LF8s6ekHdUb
ncE8znmSzrY9pcL/roHeXmdgPtY7d0o4lt9456U9z2ldR/VGh/I0n8k6lj+o
9/m/66je6FB+cD6TcCwfr1NyVC/dN2J+cM6TcHxeO2W9+jiH5zPljt9T0g71
kkN5ms9kHb+npB3qJYfyNJ/JOn5PSTvUSw7laT6TdW6G31Mgh3rJoTzNQ7JO
k+vOSchRc5jS/Gw5lJ8t59IjP375rR/5D9tbmLTXlzz4/YcuWf6D9nl+t22v
73LnRz9y44IH7XPipHKmDv/Y+OFz19vnYulQLzmUf/NNh+1w7ekbbB+m2hm/
e/8Fc+asH7XPRdKhXnIo3/w7bbD5zAyd9cUO9ZJDeTue9udx1Y4d58LmuUg6
1EsO5d35sKTesfOknYtKh3rJobxdj+0cu9qx67S9n0iHesmhfPPvutF+HlHt
XLP8umNu/9uH7H1BOtRLDuVvPeuGMx7a8CP7eVC1c/L0JVf86dGP2PuydKiX
HMo3x/NYcz4srXfWLTnviy/c8p/2XCQd6iWH8p9ZtdcdF1704+LjIWdy/pdf
/vsn/LhznORQLzmUb47n8c75kHX2+9Ln3vzrn3+8c56QQ73kUP6g+w++/jde
89PO9Zh1zv3UK19z5Qc2da5TcqiXHMq/7eKPLzz4gCc698Oss8tJN51z0pZN
nfskOdRLDuXv+exJf37NnU+M1oT3o6yz+bKHfrblmfyC8D5FDvWSQ/nmfNjU
eX+vczaPvvHU5258YIs+Huolh/J2PP3PY+WOHeejvc9pXYd6yaG8Ox8m6x07
Tz4anpPJoV5yKG/XY/w8knXsOo2fU8ihXnIoP7e9H7b7qNWO3SfbnwtIh3rJ
ofz/ad+P2n3gauff2vep9ucy0qFecii/Zev/te/vS+uds+9/08E/eLp1JrVD
veRQ/uvt81jp8ZCzsn1Oi8dJDvWSQ/l5W+GNnfMh61zbPifH84Qc6iWH8stg
HpJ1aE5CDvWSQ3ma52QdymfnSFmH5jPN++ZU+z47IR3Lt3sa0lG90aH88Hym
3LF8uycjHdUbneE8zXmyzlSxo3r7X+f5WP/cqdyxfLsnJh3VGx3K03wm61i+
3dOTjuqNDuWH5zPlzpFvOHftrv99avSuBce+6padtEO95FCe5jNZ5//7v1+4
fceLbS6qHeolh/I0n8k6z13w4b/4rXf9sJMnh3rJoTzNZ7LO1w/54fc+fN4j
nTw51EsO5Wk+k3X+ePKfD33n6x7v5MmhXnIoT/OZrPPS5Xt/+hc3PdHJk0O9
5FCe5jNZx9/ntUO95FCe5jNZp8lNjw6A+390hnu7DuWH5zPljuWvPqvv/bfr
qN7oDOdpzpN1pkdv2+sNnzjl2tL/Lu7td3g+1j93KncsP3HgmT3PaV1H9UaH
8jSfyTqWv6P3+b/rqN7oUJ7mM1nH8vE6JUf10n0j5mk+k3V8fkI6Zb0TMk/z
mazzxlWrt3ufouOfkL3kUJ7mM1nnsNeveOOnTnqkkyeHesmhPM1nss4H7lq6
3XPahHSolxzK03wm63zQPSdPSId6yaE8zUOyTpPrzknIUXOY0vxsOZSfLcfP
u3bd9rrfR9oF/F2l4+dC2qFecijv95HqHT8X0g71kkP55t/Jzs+ZOuuLHeol
h/J2PO33IVY7dpzt36WXDvWSQ3l3Pix9TrVj50n7d0GlQ73kUN6ux/Z7HKod
u07bv6cnHeolh/LNv+tG+z6OasfmQu3fRZQO9ZJDedtHar8PpdqxuVD7dyml
Q73kUL45nnYfaU694+ZC2+XJoV5yKG/7SKXHQ47NheJxkkO95FC+OY7HO+dD
1rHPBfE8IYd6yaG87QPE6zHr2OeyeJ2SQ73kUN7tY2x3P8w69rl4Y7hPkkO9
5FDe9mHi+1HWsbnEbuF9ihzqJYfyzfmwqfP+XudsHl3+8+POGG3Rx0O95FDe
7yPVO34upB3qJYfyfh+p3vFzIe1QLzmU9/tIu1Y7fi6kHeolh/J+H6ne8XMh
7VAvOZT3+0j1jp8LaYd6yaG830eqd/xcSDvUSw7l/T5SvePnQtqhXnIo7/eR
6h0/F9IO9ZJD+WUwD8k6NCchh3rJoTzNc7IO5bNzpKxD85nmfbPn54bgWL79
njLpqN7oUH54PlPuWL79njjpqN7oDOdpzpN1pood1dv/Os/H+udO5Y7l2+9J
lI7qjQ7laT6TdSz/zuZ7aqSjeqND+eH5TLlje0rf2m3FOX+xq3aolxzK03wm
6/g9Je1QLzmUp/lM1vF7StqhXnIoT/OZrOP3lLRDveRQnuYzWcfvKWmHesmh
PM1nso7fU9IO9ZJDeZrPZB1/n9cO9ZJDeZrPZJ0mNz06De7/0Rnu7TqUH57P
lDuWP/p7fe+/XUf1Rmc4T3OerDM9+tprr9rztrdoR/X2Ozwf6587lTuWb/aU
tKN6o0N5ms9kHcvf0fv833VUb3QoT/OZrGP5eJ2So3rpvhHzNJ/JOj7f3R+L
Tlkv7Wvp+UzW8XtKdPzjspccytN8Juv4PaVx6VAvOZSn+UzW8XtK49KhXnIo
T/OZrPNB+D0FcqiXHMrTPCTrNLnunIQcNYcpzc+WQ/nZcmze1Xx/xYJtr/t9
jJ07fvP3AhdKxz4XT2z9+3zaoV5yKG/7MM33QuxU7dhc4uGtf59PO9RLDuWb
fyc7P2fqrC92qJccyvt9pGdVO34upB3qJYfy/nzYsdrxcyHtUC85lPf7SDtU
O34uNCYd6iWH8s2/q+0j1Tt+LjQmHeolh/J+H6ne8XOhMelQLzmUb47H9pHq
HT8XGpMO9ZJDeb+PVO/4udCYdKiXHMo3x/F453zIOn4uNCYd6iWH8n4fqd7x
c6Ex6VAvOZT3+0g7Vjt+LqQd6iWH8n4f6VnVjp8LaYd6yaF8cz5s6ry/1zk2
F9LHQ73kUN6O55je57Fyx45zXe9zWtehXnIo78+HnasdO092D8/J5FAvOZS3
6zF+Hsk6dp3GzynkUC85lLd9pOZ7Eesdu082f59+oXSolxzK2z5S872U9Y7N
hZrvB1goHeolh/JuH2nOwmrHzYWWaod6yaG87SOVHg85NheKx0kO9ZJDedtH
iudD1rG5UDxPyKFecii/DOYhWYfmJORQLzmUp3lO1qF8do6UdWg+05zfPT83
BMfyn9r6fUELpKN6o0P54flMuWP5d6/6f9/XpI9H9UZnOE9znqwzVeyo3v7X
eT7WP3cqdyzf7CntKB3VGx3K03wm61i+2VOKn0+7juqNDuWH5zPljt9T0g71
kkN5ms9kHb+npB3qJYfyNJ/JOn5PSTvUSw7laT6TdfyeknaolxzK03wm6/g9
Je1QLzmUp/lM1vF7StqhXnIoT/OZrOPv89qhXnIoT/OZrNPkbE+pe/+PznBv
16H88Hym3LF8s6ekj0f1Rmc4T3OerGN7StpRvf0Oz8f6507ljuVfdvqanue0
rqN6o0N5ms9kHcsv633+7zqqNzqUp/lM1rF8vE7JUb1034h5ms9kHZ/v7o9F
p6y3u68V8zSfyTp+T4mOf5HsJYfyNJ/JOn5PaZF0qJccytN8Juv4PaVF0qFe
cihP85ms80H4PQVyqJccytM8JOs0ue6chBw1hynNz5ZD+dly/Lxr3rbX/T7G
XPDnS8fPhbRDveRQ3u8jzal2/FxIO9RLDuWbfyc7P2fqrC92qJccytvxnHrw
2t9539lPj2odO8592+9HVQ71kkN5dz7MearasfPkO+33oyqHesmhvF2Pd+y5
6qj1X/t5tWPXqX2vqXKolxzKN8excXTFe9/z01Wrf1bt2FzosZVHXLByzpPS
oV5yKG/7SC89ceX5xx9Y79hcaOfTn7/DnO3y5FAvOZRvjsf2keodNxfaLk8O
9ZJDedtHKj0ecmwuFI+THOolh/KN+3jnfMg69rkgnifkUC85lLd9gHg9Zh37
XBavU3KolxzKu32M7e6HWcc+F98T7pPkUC85lLd9mFPC+1HWsbnE3uF9ihzq
JYfyzXFsGjV7AVtm6GweHbD5s/d+qMChXnIo7/eR4nNOuePnQtqhXnIo7/eR
5lY7fi6kHeolh/J+H2letePnQvOlQ73kUN7vI9U7fi40XzrUSw7l/T5SvePn
QvOlQ73kUN7vI82vdvxcSDvUSw7l/T6SPh5y/FxIHw/1kkN5v49U7/i5kP7v
ol5yKL8M5iFZh+Yk5FAvOZSneU7WoXx2jpR1aD7TnN89PzcEx/LNntI86aje
6FB+eD5T7li+2VPSx6N6ozOcpzlP1pkqdlRv/+s8H+ufO5U7lt/7PYfd8skb
fiEd1RsdytN8JutY/q7T1pw6/4j4+bTrqN7oUH54PlPu2J7S373k1Y/s9KJp
6VAvOZSn+UzW8XtK09KhXnIoT/OZrOP3lKalQ73kUJ7mM1nH7ylNS4d6yaE8
zWeyjt9TmpYO9ZJDeZrPZB2/pzQtHeolh/I0n8k6dp+JeXKolxzK03wm61ju
drj/R2e4t+tQfng+U+5YfvlXDu95/+06qjc6w3ma82Sd6dF5f3PUkR+9UR+P
6u13eD7WP3cqdyzf7CnF57Suo3qjQ3maz2Qdyy/rff7vOqo3OpSn+UzWsXy8
TslRvXTfiHmaz2Qdn+/uj0WnrJf2tfR8Juv4PSU6/jHZSw7laT6Tdfye0ph0
qJccytN8Juv4PaUx6VAvOZSn+UzW+SD8ngI51EsO5WkeknWaXHdOQo6aw5Tm
Z8uh/Gw5Nu+y+b297vcxHu98TrT7pXLsc7Hdn5RDveRQ3vZhVrRz8VrH5hL3
tvcn5VAvOZRvjsPOz8dm6KwvdqiXHMrb8dzWzsVrHTvON7b3J+VQLzmU9+fD
xmrHzpO/b+9PyqFecihv16PNxWsdu07tf5VDveRQ3o7DjqvWsbmQHa9yqJcc
yts+kp0XtY7Nhex8UQ71kkN5u67suqx1/FxovXSolxzK2z5S6fGQY3OheJzk
UC85lG/cxzvnQ9ax96d4npBDveRQ3p4DLg3XY9ax54N4nZJDveRQ3vYxmp9L
/7Dasc/FV4f7JDnUSw7lbR/m1vB+lHVsLnFseJ8ih3rJoXxzPmwaPd3uBczM
2Tw67dEjrn3qae1QLzmUt+P5TO/zWLljx/nl3ue0rkO95FDenw8/qXbsPNk3
PCeTQ73kUN6ux/h5JOvYdRo/p5BDveRQ3vaR7LhqHbtP2vEqh3rJobztI9l5
UevYXMjOF+VQLzmU9/tIm6odNxd65npVDvWSQ3nbRyo9HnJsLhSPkxzqJYfy
to8Uz4esY3OheJ6QQ73kUH4ZzEOyDs1JyKFecihP85ysQ/nsHCnr0HymOV97
fm4IjuV/u/15qXJUb3QoPzyfKXcsv/bjzc+rlaN6ozOcpzlP1pkqdlRv/+s8
H+ufO5U7lj/6+3+9dV6uHNUbHcrTfCbrWH55Oy9XjuqNDuWH5zPlju0p2f8q
h3rJoTzNZ7KO31Oakg71kkN5ms9kHb+nNCUd6iWH8jSfyTp+T2lKOtRLDuVp
PpN1/J7SlHSolxzK03wm6/g9pSnpUC85lKf5TNbx9/kp6VAvOZSn+UzWaXLT
o4vh/h+d4d6uQ/nh+Uy5Y/mD3n9hz/tv11G90RnO05wn60yP5u13+Sd2O0Mf
j+rtd3g+1j93Kncs/5a7v9DznNZ1VG90KE/zmaxj+X16n/+7juqNDuVpPpN1
LB+vU3JUL903Yp7mM1nH57v7Y9Ep6+3ua8U8zWeyjt9TouOflr3kUJ7mM1nH
7ylNS4d6yaE8zWeyjt9TmpYO9ZJDeZrPZJ0Pwu8pkEO95FCe5iFZx67PmCdH
zWFK87PlUH62HJt33XfmA984Z/ruba/7fYxVHf+Bd22cXrbxPunY8+hbLzn8
tvXnrpYO9ZJDefs59NoLTlz51TU3VTv2eeCUQ//o5wcsu1E61EsO5Zvj2Pb3
oObMzFlf7FAvOZS347m3OZ7FtY4d58nNcUqHesmhvJ0Pzc9Db6927Dw5vjlP
pEO95FA+XI/Vjl2nU811Kh3qJYfyzb/qxtHSQ35v/3Wr7ql2bC605H3/tvb9
T90vHeolh/K2B3Dsx8554sr9v1vt2FzoeyevfHjLlvulQ73kUL45HttHWlPt
+LnQOulQLzmUtz2A1xceDzk2F4rHSQ71kkP5xn28cz5kHftcEM8TcqiXHMrb
z8/Whusx69hzTLxOyaFecihvPwcd23pcq6odex49LdwnyaFecihvP4eeCu9H
Wcc+D1wY3qfIoV5yKN+cD5tGH1m59xuOWXHdq2fmbB79zW2/dt5+e/2mPB7q
JYfydjx39T6PlTt2nH/yqr7ntK5DveRQ3s6H6eZ5oNqx8+To8JxMDvWSQ3m7
HuPnkaxj12n8nEIO9ZJDedtH+lBzP6x2wn1SOtRLDuVtH+mY5v2o2vk3/z4l
Heolh/J+H2lNtePnQuukQ73kUN72kV5feDzkrPTPadKhXnIob/tI54fzIetc
65+TpUO95FDe9pHWhusx64TPKdKhXnIoT/OcrENzHnJULznxdZrPNOdrz88N
wbHcN85c8Uc/efBe6aje6FB+eD5T7lh+9V+te+SQt94hHdUbneE8zXmyzlSx
o3r7X+f5WP/cqdyx/J3NcUpH9UaH8jSfyTqWv6M5T6SjeqND+eH5TLlj+0ln
nfDc16374wekQ73kUJ7mM1kn7ClJh3rJoTzNZ7JO2FOSDvWSQ3maz2SdsKck
Heolh/I0n8k6YU9JOtRLDuVpPpN1wp6SdKiXHMrTfCbr2H0m5smhXnIoT/OZ
rNPkpkcb4P4fneHerkP54flMuWP5fff7Vs/7b9dRvdEZztOcJ+tMjx69+qAz
3nr1DYX/Xdzb7/B8rH/uVO5Y/pvn/1XPc1rXUb3RoTzNZ7KO5Vf2Pv93HdUb
HcrTfCbrWD5ep+SoXrpvxDzNZ7JOyEunsFceJ81nso7fU8Ljl73kUJ7mM1nH
7ylNSYd6yaE8zWeyjt9TmpIO9ZJDeZrPZJ0Pwu8pkEO95FCe5jNZx3IxTw71
kkN5Nc+Zaa9ySnvD343Zdh8Lfw9ncfTb/12sHPtc3H4+kw71kkP58PeIqp3w
e2HSoV5yKN8cx7a/BzVDZ32xQ73kUN6Op90LqHbC70VKh3rJoXz4e2jVTvi9
VOlQLzmUD79HXO2EfU7pUC85lG+vQ/t98GrnGr+XKx3qJYfyt/rfx692TvZ7
0dKhXnIo315X7fmwqdrxc6HN0qFecij/Gf/3KKqdSf97AdKhXnIo316HnfMh
64Tfy5AO9ZJD+fD3WKqd8Hsx0qFecijvv4/v8WrHPhe/NNwnyaFecihv+zAr
wvtR1rG5xH3hfYoc6iWH8u11OJob3t/rnM2ju3Y68SXnFTjUSw7l7Xi+3vs8
Vu7YcV7S+5zWdaiXHMrb+dDuBVQ7dp5cG56TyaFecihv12P8PJJ1wu8FS4d6
yaG87SP9bvNcVu2E38uWDvWSQ3nbRzqheS6udmwu1D4vS4d6yaG830eqd/xc
aL10qJccyn/d/z3SasfmQvE4yaFecihv+0iLw/mQdWwuFM8TcqiXHMrbPtKl
4XrMOjQnIYd6yaE8zXOyDuWzc6SsQ/OZ5nzt+bkhOJb/VDMvlI7qjQ7lh+cz
5Y7l279TJB3VG53hPM15ss5UsaN6+1/n+Vj/3Kncsfx9zd/pko7qjQ7laT6T
dSx/QLMvIB3VGx3KD89nyh3bUzrx3n8Z37wuft7vOtRLDuVpPpN1wvf0SYd6
yaE8zWeyTviePulQLzmUp/lM1gnf0ycd6iWH8jSfyTrhe/qkQ73kUJ7mM1kn
fE+fdKiXHMrTfCbr+Pv8tHSolxzK03wm67S50SFw/4/OcG/XofzwfKbcsfw7
Dv9Kz/tv11G90RnO05wn60yPPvy/rv+n979WH4/q7Xd4PtY/dyp3LH/UySt6
ntO6juqNDuVpPpN1LP/53uf/rqN6o0N5ms9kHcvH65Qc1Uv3jZin+UzW8fnu
/lh0ynq7+1oxT/OZrBP2lKRDveRQnuYzWSfsKUmHesmhPM1nsk7YU5IO9ZJD
eZrPZJ0Pwu8pkEO95FCe5iFZp8118uSoOUxpfrYcys+WY/OuO/ZcddT6r/18
2+t+H+Opjt9+T7R07HPxd5rvZZYO9ZJDeduHOeXgtb/zvrOfrnZsLrFv873M
0qFecijfHMe2vwe1ZGbO+mKHesmhvB3PsRvGf3Db1+sdO86Hm+9llg71kkN5
dz4snVvt2HnSfi+zdKiXHMrb9bj8keX3Pee/zKt2wveZSod6yaF888+6cfSK
I1b95R6X1zs2F2q/l1Y61EsO5W0faeO/XnfzPT+od2wu1H4vsHSolxzKN8dj
+0jzqx03F1qqHeolh/K2j1R6POTYXCgeJznUSw7lm+N4vHM+ZJ3wveTSoV5y
KG/7APF6zDrhe+GlQ73kUN7tI213P8w69rl4ItwnyaFecihv+zDx/Sjr2Fzi
R+F9ihzqJYfyzfmwqfP+XudsHr1z7LplSwoc6iWH8nY8p/Y+j5U7dpxH9j6n
dR3qJYfydj40ezFPVTt2ntwbnpPJoV5yKG/XY/w8knXsOo2fU8ihXnIob/tI
V7z3PT9dtfpn1Y7dJx9becQFK+c8KR3qJYfyto/00hNXnn/8gfWOzYV2Pv35
O8zZLk8O9ZJDeb+PVO/4udCT0qFecihv+0ilx0OOzYXicZJDveRQ3vaR4vmQ
dWwuFM8TcqiXHMovg3lI1qE5CTnUSw7laZ6TdSifnSNlHZrPNOdrz88NwbH8
6tPWnDr/iJ9JR/VGh/LD85lyx/Ivfs9ht3zyBn08qjc6w3ma82SdqWJH9fa/
zvOx/rlTuWP5d6/63orrr5wrHdUbHcrTfCbrWP7y1c875kPr4ufTrqN6o0P5
4flMuWN7Svs//PYL/uxR7VAvOZSn+UzW8XtKY9KhXnIoT/OZrOP3lMakQ73k
UJ7mM1nH7ymNSYd6yaE8zWeyjt9TGpMO9ZJDeZrPZB2/pzQmHeolh/I0n8k6
/j4/Jh3qJYfyNJ/JOk1uevRpuP9HZ7i361B+eD5T7lj++hf2vf92HdUbneE8
zXmyzvRo8Y0n3P/KK7Wjevsdno/1z53KHctf9fJje57Tuo7qjQ7laT6TdSy/
pvf5v+uo3uhQnuYzWcfy8TolR/XSfSPmaT6TdXy+uz8WnbLe7r5WzNN8JuuE
7+mTDvWSQ3maz2Sd8D190qFecihP85msE76nTzrUSw7laT6TdT4Iv6dADvWS
Q3mah2SdJtedk5Cj5jCl+dlyKD9bjs273jF+2ot/PLXDtvuY38fYsfM58dYv
rX/btbf88r5Hjn0u3njVP3z7vftoh3rJobztw3xxj0de8MpDnlXt2Fxi9w/t
efr/fIN2qJccyjf/TnZ+7jRDZ32xQ73kUN7vI9U7fi6kHeolh/L+fNi52vFz
Ie1QLzmU9/tIC6odPxdaKB3qJYfyzb+r7SPVO34utFA61EsO5f0+Ur3j50IL
pUO95FC+OR7bR1pY7fi5kHaolxzK+30kfTzk+LmQPh7qJYfyzXE83jkfso6f
C+n/Luolh/J+H6ne8XOhhdKhXnIo7/eRdq52/FxIO9RLDuX9PtJO1Y6fC2mH
esmhfHM+bOq8v9c5NhfSDvWSQ3k7ni/1Po+VO3ace/Y+p3Ud6iWH8v582LHa
sfPk4fCcTA71kkN5ux7j55GsY9dp/JxCDvWSQ3nbR7r7poM/sOEP6x27T577
r5897Lil3XlXdKiXHMrbPtLE/sf97n4vqHdsLjR2w4Xz5iztztmiQ73kUN7v
I9U7bi60XZ4c6iWH8raPVHo85NhcKB4nOdRLDuVtHymeD1nH5kLxPCGHesmh
/DKYh2QdmpOQQ73kUJ7mOVmH8tk5Utah+Uxzfvf83BAcy//hAT/64nkv2kE6
qjc6lB+ez5Q7lr/04Be+/ai36ONRvdEZztOcJ+tMFTuqt/91no/1z53KHcs3
e0o7S0f1RofyNJ/JOpZv9pTi59Ouo3qjQ/nh+Uy54/eUtEO95FCe5jNZx+8p
LZIO9ZJDeZrPZB2/p7RIOtRLDuVpPpN1/J7SIulQLzmUp/lM1vF7SoukQ73k
UJ7mM1nH7yktkg71kkN5ms9kHX+fXyQd6iWH8jSfyTpNzvaUuvf/6Az3dh3K
D89nyh3LN3tK+nhUb3SG8zTnyTq2p6Qd1dvv8Hysf+5U7lj+25ft3fOc1nVU
b3QoT/OZrGP5M3uf/7uO6o0O5Wk+k3UsH69TclQv3TdinuYzWcfntVPWq4+T
5jNZx+8paYd6yaE8zWeyjt9T0g71kkN5ms9kHb+npB3qJYfyNJ/JOh+E31Mg
h3rJoTzNQ7JOk+vOSchRc5jS/Gw5lJ8tx8+7nr3tdb+P8RzwF0nHz4W0Q73k
UN7vIz232vFzIe1QLzmUb/6d7PzcZYbO+mKHesmhvB3P3mdf8JNTTq137Dif
mHzkztcfrx3qJYfy7nyYrHfsPLnwpftO3P6wdqiXHMrb9XjXptVn/u/n7lrt
2HW64qqLj71mhXaolxzKN/+uG0effNGGWy46qt6xudBhz7/upO+OtEO95FDe
9pGeOP1NJ288u96xudDTe33l6S0j7VAvOZRvjqfdR1pa77i50KR2qJccyts+
UunxkGNzoXic5FAvOZRvjufxzvmQdexzQTxPyKFecihv+wDxesw69rksXqfk
UC85lHf7GNvdD7OOfS6O90lyqJccyts+zD7h/Sjr2FxiU3ifIod6yaF8cz5s
6ry/1zmbRwfOe9Nrf7PAoV5yKO/3keLzVbnj50LaoV5yKO/3kZ5T7fi5kHao
lxzK+32kZ1c7fi7UnTNHh3rJobzfR6p3/FyI5l2LZC85lPf7SPWOnwvRnG2R
7CWH8n4fqd7xc6FF0qFecijv95HqHT8XWiQd6iWH8n4fqd7xc6FF0qFecii/
DOYhWYfmJORQLzmUp3lO1qF8do6UdWg+05zfPT83BMfyzZ7Ss6WjeqND+eH5
TLlj+WZPSR+P6o3OcJ7mPFlnqthRvf2v83ysf+5U7lj+oA1nffO+b2lH9UaH
8jSfyTqWX/3vO++9+Kz4ea3rqN7oUH54PlPu2J7SZU984dZDN2uHesmhPM1n
so7fUxqXDvWSQ3maz2Qdv6c0Lh3qJYfyNJ/JOn5PaVw61EsO5Wk+k3X8ntK4
dKiXHMrTfCbr+D2lcelQLzmUp/lM1vH3+XHpUC85lKf5TNZpctOju+D+H53h
3q5D+eH5TLlj+RMu6Xv/7TqqNzrDeZrzZJ3p0RVr//Hdn/mD0v8u7u13eD7W
P3cqdyzf7CnF57Suo3qjQ3maz2Qdy5/Z+/zfdVRvdChP85msY/l4nZKjeum+
EfM0n8k6Pq+dsl59nDSfyTp+T0k71EsO5Wk+k3X8npJ2qJccytN8Juv4PSXt
UC85lKf5TNb5IPyeAjnUSw7laR6SdZpcd05CjprDlOZny6H8bDk27zpg5wMu
PfexX97H3D7Gkud1/FNOeO8Xjn/7uHTsc/H7v/2dH/633bRDveRQ3vZh7rvo
nGd/5tP1js0lFiweP/Dz12iHesmhfPPvZOfnbjN01hc71EsO5f0+Ur3j50La
oV5yKO/3keodPxfSDvWSQ3m/j7R7tePnQtqhXnIo3/y72j5SvePnQtqhXnIo
7/eR6h0/F9IO9ZJD+eZ4bB+p3vFzIe1QLzmU9/tI9Y6fC2mHesmhfHM8j3fO
h6zj50LaoV5yKO/3keodPxfSDvWSQ3m/j7RbtePnQtqhXnIo7/eR6h0/F9IO
9ZJD+eZ82NR5f69zbC6kHeolh/J2PP3PY+WOHed473Na16Fecijvzocl9Y6d
J+eE52RyqJccytv1GD+PZB27TuPnFHKolxzK2z7S6ev2OPTs6+sdu09+9aHj
Vu6zRDvUSw7lbR9p4WWfu2L3i+odmwvNW3v43DlLtEO95FDe7SMtrXfcXGiJ
dqiXHMrbPlLp8ZBjc6F4nORQLzmUt32keD5kHZsLxfOEHOolh/LLYB6SdWhO
Qg71kkN5mudkHcpn50hZh+Yzzftmz88NwbH8b//apjWTl3Rfj47qjQ7lh+cz
5Y7l79jjkle8+GXaUb3RGc7TnCfrTBU7qrf/dZ6P9c+dyh3LN3tK2lG90aE8
zWeyjuWbPaX4ea3rqN7oUH54PlPu+D0l7VAvOZSn+UzW8XtKE9KhXnIoT/OZ
rOP3lCakQ73kUJ7mM1nH7ylNSId6yaE8zWeyjt9TmpAO9ZJDeZrPZB2/pzQh
Heolh/I0n8k6/j4/IR3qJYfyNJ/JOk3O9pT08Qz3dh3KD89nyh3LN3tK2lG9
0RnO05wn69ieUul/F/f2Ozwf6587lTuW33jnpT3PaV1H9UaH8jSfyTqWP6j3
+b/rqN7oUJ7mM1nH8vE6JUf10n0j5mk+k3V8Xjtlvfo4aT6TdfyeknaolxzK
03wm6/g9Je1QLzmUp/lM1vF7StqhXnIoT/OZrPNB+D0FcqiXHMrTPCTrNLnu
nIQcNYcpzc+WQ/nZctae+cA3zpm+e3H7c8NJe33pIb+3/7pV9zT/f5O7bXt9
6l0bp5dtvG9x+5w2qZwl7/u3te9/6v7F7XORdKiXHMq//mPnPHHl/t9d3O7D
VDvfO3nlw1u23L+4fS6SDvWSQ/nm32lN+78zddYVO9RLDuXteNqfx1U7dpwL
m+ci6VAvOZR358OSesfOk3YuKh3qJYfydj22c+xq54H2Om3vJ9KhXnIo3/w8
YtXi9ucR1c5bLzn8tvXnrl7cvi9Ih3rJofz3Lzhx5VfX3LS4/XlQtbPjoX/0
8wOW3bi4fV+WDvWSQ/kFH11x1CF/+oFXbz2spfXOa9+34bvfvGaP9rzSDvWS
Q/lvNsczKj0ecn7xqq3HOYrHSQ71kkP5p7b+PPT2UTwfss7xzXkyiucJOdRL
DuXva67HUbwes057nY7idUoO9ZJD+Q8398MR3A+LnfY+OYr3SXKolxzKH9u8
H43W9L8fFTvt+5T9XEw61EsO5dvngRE8DySddaNvPPW5Gx/Yoo+HesmhfPs8
MILnsWLHjvPR3ue0rkO95FD+/O3Ph+7zcLFj58lHw3MyOdRLDuXb54ERfB4p
dtrPKaP4OYUc6iWH8js2zwO2j1rtvKm9T7Y/F5AO9ZJD+Ufa96N2H7ja2eU1
zftU+3MZ6VAvOZT/6/8458mNay9tnwfqneUb/sf5H/3H/9p+rtQO9ZJD+W+0
z2Olx0POj1/ZPKfF4ySHesmh/ObmeWBxPB+yzuva5+R4npBDveRQfg3MQ7LO
AzAnIYd6yaE8zXOyDs15yKFecuh1ms8075tT7f9OSMfy7Z6GdFRvdCg/PJ8p
dyzf7slIR/VGZzhPc56sM1XsqN7+13k+1j93Kncs3+6JSUf1RofyNJ/JOpZv
9/Sko3qjQ3maz2Sds0547uvW/fEDi9+14NhX3bKTdqiXHMrTfCbrfPvMFX/0
kwfvbY9XO9RLDuVpPpN1bv3u/EcPeesdnTw51EsO5Wk+k3VW/9Y/7TL3p9d3
8uRQLzmUp/lM1rls/vcfeeY4RzFPDvWSQ3maz2SdLzXnSSdPDvWSQ3maz2Qd
f5/XDvWSQ3maz2SdNj86AO7/0RG9HYfyw/OZcsfyV5/V+/7bcVRvdIbzNOfJ
OlOjt+31hk+ccm3pfxf39js8H+ufO5U7lp848My+58+Oo3qjQ3maz2Qdy9/R
//zfcVRvdChP85msY/l4nZKjeqNDeZrPZB2fn5BOWe+EzNN8Juus/L2zHv3l
+xQd/4TsJYfyNJ/JOlN//uy3vux5N3Y+55JDveRQnuYzWecFX//FI798TpuQ
DvWSQ3maz2Sdnd+9/XPyhHSolxzK03wm67TneSdPDvWSQ3k1z5lpL72e7fXz
rl23ve73kXYBf1fp+LmQdqiXHMr7faR6x8+FtEO95FC++XeyfaSZOuuKHeol
h/J2PO33IVY7dpzt36WXDvWSQ3l3Pix9TrVj50n7d0GlQ73kUN6ux/Z7HKod
uy+1f09POtRLDuVtH6n9Po5qx+ZC7d9FlA71kkN520dqvw+l2rG5UPt3KaVD
veRQ3u0jzal33Fxouzw51EsO5W0fqfR4yLG5UDxOcqiXHMrbPlI8H7KOzYXi
eUIO9ZJDedtHitdj1rG5ULxOyaFecijv9pG698Nixz4Xbwz3SXKolxzK2z4S
vB8VOzaX2C28T5FDveRQvn0eGMHzQNJZN7r858edMdqij4d6yaG830eqd/xc
SDvUSw7l/T5SvePnQtqhXnIo7/eROp9Hih0/F9IO9ZJDeb+PVO/4uZB2qJcc
yvt9pHrHz4W0Q73kUN7vI9U7fi6kHeolh/J+H6ne8XMh7VAvOZT3+0j1jp8L
aYd6yaH8GpiHZJ0HYE5CDvWSQ3ma52QdmvOQQ73k0Os0n2neN7s/NyTH8u33
lElH9UaH8sPzmXLH8u33xElH9UZnOE9znqwzVeyo3v7XeT7WP3cqdyzffk+i
dFRvdChP85msY/l3Nt9TIx3VGx3K03wm69ie0rd2W3HOX+yqHeolh/I0n8k6
fk9JO9RLDuVpPpN1/J6SdqiXHMrTfCbr+D0l7VAvOZSn+UzW8XtK2qFecihP
85ms4/eUtEO95FCe5jNZx9/ntUO95FCe5jNZp82PToP7f3REb8eh/PB8ptyx
/NHf633/7TiqNzrDeZrzZJ2p0ddee9Wet71FO6q33+H5WP/cqdyxfLOnpB3V
Gx3K03wm61j+jv7n/46jeqNDeZrPZB3Lx+uUHNUbHcrTfCbr+Hx3fyw6Zb20
r6XnM1nH7ynR8Y/LXnIoT/OZrOP3lMalQ73kUJ7mM1nH7ymNS4d6yaE8zWey
jt9TGpcO9ZJDeZrPZJ32PO/kyaFeciiv5jkz7aXXs70271r+yPL7nvNfFmx7
3e9j7NzxX330b/yfPzh0oXTsc/HECW986cXf1Q71kkN524c5dsP4D277+k7V
js0lHj7v/sv+9h+1Q73kUL75d7J9pJk664od6iWH8n4f6VnVjp8LaYd6yaG8
Px92rHb8XEg71EsO5f0+0g7Vjp8LjUmHesmhvN9Hqnf8XGhMOtRLDuX9PlK9
4+dCY9KhXnIo7/eR6h0/FxqTDvWSQ3m/j1Tv+LnQmHSolxzK+32kesfPhcak
Q73kUN7vI9U7fi40Jh3qJYfyfh+pcz8sdvxcSDvUSw7l/T5S5/2o2PFzIe1Q
LzmUb58HRvA8kHRsLqSPh3rJobztIx3T/zxW7Nhxrut9Tus61EsO5d0+Uvd5
uNix82T38JxMDvWSQ3nbR4LPI8WOzYXi5xRyqJccyts+0iuOWPWXe1xe79hc
6K/3P/Gfr/vwQulQLzmUt32kjf963c33/KDesbnQL173vqe2bJcnh3rJobzb
R5qzsNpxc6Gl2qFecihv+0ilx0OOzYXicZJDveRQ3vaR4vmQdWwuFM8TcqiX
HMqvgXlI1nkA5iTkUC85lKd5TtahOQ851EsOvU7zmeb87v7ckBzLf2r18475
0LoF0lG90aH88Hym3LH8u1d9b8X1V+rjUb3RGc7TnCfrTBU7qrf/dZ6P9c+d
yh3LN3tKO0pH9UaH8jSfyTqWb/aUdpCO6o0O5Wk+k3X8npJ2qJccytN8Juv4
PSXtUC85lKf5TNbxe0raoV5yKE/zmazj95S0Q73kUJ7mM1nH7ylph3rJoTzN
Z7KO31PSDvWSQ3maz2Qdf5/XDvWSQ3maz2SdNt/uKXXv/9ERvR2H8sPzmXLH
8s2ekj4e1Rud4TzNebKO7SlpR/X2Ozwf6587lTuWf9npa/qePzuO6o0O5Wk+
k3Usv6z/+b/jqN7oUJ7mM1nH8vE6JUf1RofyNJ/JOj7f3R+LTllvd18r5mk+
k3X8nhId/yLZSw7laT6Tdfye0iLpUC85lKf5TNbxe0qLpEO95FCe5jNZx+8p
LZIO9ZJDeZrPZJ32PO/kyaFeciiv5jkz7aXXs71+3jVv2+t+H2Mu+POl4+dC
2qFecijv95HmVDt+LqQd6iWH8s2/k+0jzdRZV+xQLzmUt+M59eC1v/O+s58e
1Tp2nPv+4n/c/dWrtEO95FDenQ9znqp27Dz5ztFvuvrB1/9COtRLDuXterxj
z1VHrf/az6sduy/99Ttu+9pb/vJJ6VAvOZS3faQr3vuen65a/bNqx+ZCj608
4oKVc56UDvWSQ3nbR3rpiSvPP/7AesfmQjuf/vwd5myXJ4d6yaG830eqd9xc
aLs8OdRLDuVtH6n0eMixuVA8TnKolxzK2z5SPB+yjs2F4nlCDvWSQ3nbR4rX
Y9axuVC8TsmhXnIo7/aRuvfDYsc+F98T7pPkUC85lLd9pFP634+KHZtL7B3e
p8ihXnIo3z4PjLY0/zdDZ93ogM2fvfdDBQ71kkN5v4/UeY4qdvxcSDvUSw7l
/T5S53m42PFzIe1QLzmU9/tInc8jxY6fC82XDvWSQ3m/j1Tv+LnQfOlQLzmU
9/tI9Y6fC82XDvWSQ3m/jzS/2vFzIe1QLzmU9/tI+njI8XMhfTzUSw7l/T5S
vePnQvq/i3rJofwamIdknQdgTkIO9ZJDeZrnZB2a85BDveTQ6zSfac7v7s8N
ybF8s6c0TzqqNzqUH57PlDuWb/aU9PGo3ugM52nOk3Wmih3V2/86z8f6507l
juX3fs9ht3zyhl9IR/VGh/I0n8k6lr/rtDWnzj/iZ9JRvdGhPM1nso7tKf3d
S179yE4vmpYO9ZJDeZrPZB2/pzQtHeolh/I0n8k6fk9pWjrUSw7laT6Tdfye
0rR0qJccytN8Juv4PaVp6VAvOZSn+UzW8XtK09KhXnIoT/OZrGP3mZgnh3rJ
oTzNZ7JOmx/dDvf/6IjejkP54flMuWP55V85vO/9t+Oo3ugM52nOk3WmRuf9
zVFHfvRGfTyqt9/h+Vj/3KncsXyzp9R5/uw4qjc6lKf5TNax/LL+5/+Oo3qj
Q3maz2Qdy8frlBzVGx3K03wm6/h8d38sOmW9tK+l5zNZx+8p0fGPyV5yKE/z
mazj95TGpEO95FCe5jNZx+8pjUmHesmhPM1nso7fUxqTDvWSQ3maz2Sd9jzv
5MmhXnIor+Y5M+2l17O9Nu866P6Dr/+N1/x0233M72M8Hu+Ti8/91Ctfc+UH
No2UY5+L9/vS597865/XDvWSQ3nbh1mxaq87Lrzox9WOzSXunf/ll//+Cdqh
XnIo3xyH7SM9NkNnXbFDveRQ3o7ntrNuOOOhDT+qduw43zh9yRV/evQj0qFe
cijvz4eN1Y6dJ3+//Lpjbv/bh6RDveRQ3q7HZUd+/PJbP/If1Y7dl3a586Mf
uXHBg9KhXnIob/tISx78/kOXLP9BtWNzoanDPzZ++Nz10qFecihv+0hvvumw
Ha49fUO1Y3Oh8bv3XzBnznrpUC85lPf7SPWOnwutlw71kkN520cqPR5ybC4U
j5Mc6iWH8raPFM+HrGNzoXiekEO95FDe9pEuDddj1rG5ULxOyaFecihv+0jN
OswPqx37XHx1uE+SQ73kUN72kW7tfz8qdmwucWx4nyKHesmhfPs8MHp66/H8
5wyddaPTHj3i2qee1g71kkN520f6TP/zWLFjx/nl3ue0rkO95FD+fHc+/KTa
sfNk3/CcTA71kkN520eCzyPFjs2F4ucUcqiXHMrbPtLbLv74woMPeKLasbnQ
LifddM5JWzZJh3rJobztI93z2ZP+/Jo76x2bC22+7KGfbdkuTw71kkN5v4+0
qdpxc6E5m6VDveRQ3vaRSo+HHJsLxeMkh3rJobztI8XzIevYXCieJ+RQLzmU
XwPzkKzzAMxJyKFecihP85ysQ3MecqiXHHqd5jPN+dr9uSE5lv/t5Xt/+hc3
PSEd1Rsdyg/PZ8ody6/9+D8f+s7X6eNRvdEZztOcJ+tMFTuqt/91no/1z53K
Hcsf/f2//ovfetcPpaN6o0N5ms9kHcsv/79fuH3HizdIR/VGh/I0n8k6tqd0
5BvOXbvrf5+SDvWSQ3maz2Qdv6c0JR3qJYfyNJ/JOn5PaUo61EsO5Wk+k3X8
ntKUdKiXHMrTfCbr+D2lKelQLzmUp/lM1vF7SlPSoV5yKE/zmazj7/NT0qFe
cihP85msY7mL4f4fHdHbcSg/PJ8pdyx/0Psv7Hv/7TiqNzrDeZrzZJ2p0bz9
Lv/Ebmfo41G9/Q7Px/rnTuWO5d9y9xf6nj87juqNDuVpPpN1LL9P//N/x1G9
0aE8zWeyjuXjdUqO6o0O5Wk+k3V8vrs/Fp2y3u6+VszTfCbr+D0lOv5p2UsO
5Wk+k3X8ntK0dKiXHMrTfCbr+D2laelQLzmUp/lM1vF7StPSoV5yKE/zmazT
nuedPDnUSw7l1Txnpr30erbX5l3280N73e9jrOr49rymHPtc3H4+kw71kkN5
24dZ287Fax2bS5zSfD6TDvWSQ/nmOLb9Pag5M3PWFTvUSw7l7XjubefitY4d
58nt52PlUC85lLfz4el2Ll7r2HnSfj6TDvWSQ/lwPVY7dl+y61U51EsO5W0f
yY6r1rG5kB2vcqiXHMrbPlK7F1Dt2FzIzhflUC85lPf7SGuqHT8XWicd6iWH
8raP9PrC4yHH5kLxOMmhXnIob/tI8XzIOjYXiucJOdRLDuXtOWBtuB6zjj0f
xOuUHOolh/K2jzTWXpe1jn0uPi3cJ8mhXnIob/tIU/3vR8WOzSUuDO9T5FAv
OZRvr8PRR1bu/YZjVlz36pk560Z/c9uvnbffXr8pj4d6yaG87SPd1f88VuzY
cf7Jq/qe07oO9ZJDedtHmm6vy1rHzpOjw3MyOdRLDuVtHwk+jxQ7NheKn1PI
oV5yKG/7SB9qj6vWeZO/T0qHesmhvO0jHdOeF7WOzYXsfFEO9ZJDeb+PtKba
8XOhddKhXnIob/tIry88HnJsLhSPkxzqJYfyto90fjgfss7r/HOydKiXHMrb
PtLacD1mnfA5RTrUSw7laZ6TdWjOQw71kkOv03ymOV+7Pzckx/LfaH9eqhzV
Gx3KD89nyh3Lr/6rdVt/Xq0c1Rud4TzNebLOVLGjevtf5/lY/9yp3LH8nc1x
Skf1RofyNJ/JOpa/o92XUY7qjQ7laT6TdWxPyf5XOdRLDuVpPpN1wp6SdKiX
HMrTfCbrhD0l6VAvOZSn+UzWCXtK0qFecihP85msE/aUpEO95FCe5jNZJ+wp
SYd6yaE8zWeyjuVinhzqJYfyNJ/JOm1utAHu/9ERvR2H8sPzmXLH8vvu962+
99+Oo3qjM5ynOU/WmRo9evVBZ7z16hsK/7u4t9/h+Vj/3Kncsfw3z/+rvufP
jqN6o0N5ms9kHcuv7H/+7ziqNzqUp/lM1rF8vE7JUb3RoTzNZ7JOyEunsFce
J81nso7fU8Ljl73kUJ7mM1nH7ylNSYd6yaE8zWeyjt9TmpIO9ZJDeZrPZB2/
pzQlHeolh/I0n8k6dn3GPDnUSw7l1Txnpr30erY3/N2Ybfex8Pdw4n3Sfk9n
sXLsefSaZi9dOtRLDuXD3yOqdsLvhUmHesmhfHMc2/4e1AyddcUO9ZJDeTue
9u8hVDvh9yKlQ73kUD78PbRqJ/xeqnSolxzKh98jrnbCXqh0qJccyts+Uvv7
4NWOzYXavVzpUC85lLd9pPb38asdmwu1e9HSoV5yKO/3kTZVO34utFk61EsO
5W0fqfR4yLG5UDxOcqiXHMrbPlI8H7KOzYXieUIO9ZJDefv5Wbwes449x8Tr
lBzqJYfy/vv4OvfDYseeR18a7pPkUC85lLd9pBX970fFjn0euC+8T5FDveRQ
vn0eGM3tfx5IOutGd+104kvOK3ColxzK2x7A1/ufx4odO85Lep/Tug71kkN5
2wNo3pc6z8PFjp0n14bnZHKolxzK2x4AfB4pduzzWPycQg71kkN520f63ebv
AVY7Nhdqfy9bOtRLDuVtH+mE5u8xVjs2F2p/L1461EsO5f0+Ur3j50LrpUO9
5FDe9pHeXHg85NhcKB4nOdRLDuVtH2lxOB+yjs2F4nlCDvWSQ3nbR7o0XI9Z
5wGYk5BDveRQnuY5WYfmPORQLzn0Os1nmvO1+3NDciz3qebvJEhH9UaH8sPz
mXLH8u3fKZKO6o3OcJ7mPFlnqthRvf2v83ysf+5U7lj+vubvdElH9UaH8jSf
yTqWP6D5OwnSUb3RoTzNZ7KO7SedeO+/jG9et1k61EsO5Wk+k3XC9/RJh3rJ
oTzNZ7JO+J4+6VAvOZSn+UzWCd/TJx3qJYfyNJ/JOuF7+qRDveRQnuYzWSd8
T590qJccytN8Juv4+/y0dKiXHMrTfCbrtPnRIXD/j47o7TiUH57PlDuWf8fh
X+l7/+04qjc6w3ma82SdqdGH/9f1//T+1+rjUb39Ds/H+udO5Y7ljzp5Rd/z
Z8dRvdGhPM1nso7lP9///N9xVG90KE/zmaxj+XidkqN6o0N5ms9kHZ/v7o9F
p6y3u68V8zSfyTphT0k61EsO5Wk+k3XCnpJ0qJccytN8JuuEPSXpUC85lKf5
TNYJe0rSoV5yKE/zmaxjuZgnh3rJobya58y0l17P9tq86449Vx21/ms/3/a6
38d4quO33xMtHftc/J3me5mlQ73kUN72YU45eO3vvO/sp6sdm0vs23wvs3So
lxzKN8ex7e9BLZmZs67YoV5yKG/Hc+yG8R/c9vV6x47z4eZ7maVDveRQ3p0P
S+dWO3aetN/LLB3qJYfydj0uf2T5fc/5L/OqnfC9qNKhXnIob/tIrzhi1V/u
cXm9Y3Oh9ntppUO95FDe9pE2/ut1N9/zg3rH5kLt9wJLh3rJobzfR5pf7bi5
0FLtUC85lLd9pNLjIcfmQvE4yaFecihv+0jxfMg6NheK5wk51EsO5W0fKV6P
WcfmQvE6JYd6yaG820fq3g+LHftcPBHuk+RQLzmUt30keD8qdmwu8aPwPkUO
9ZJD+fZ5YATPA0ln3eidY9ctW1LgUC85lLd9pFP7n8eKHTvOI3uf07oO9ZJD
edtHavbBOs/DxY6dJ/eG52RyqJccyts+EnweKXZsLhQ/p5BDveRQ3vaRrnjv
e366avXPqh2bCz228ogLVs55UjrUSw7lbR/ppSeuPP/4A+sdmwvtfPrzd5iz
XZ4c6iWH8n4fqd7xc6EnpUO95FDe9pFKj4ccmwvF4ySHesmhvO0jxfMh69hc
KJ4n5FAvOZRfA/OQrPMAzEnIoV5yKE/znKxDcx5yqJccep3mM8352v25ITmW
X33amlPnH/Ez6aje6FB+eD5T7lj+xe857JZP3qCPR/VGZzhPc56sM1XsqN7+
13k+1j93Kncs/+5V31tx/ZVzpaN6o0N5ms9kHctfvvp5x3xo3TzpqN7oUJ7m
M1nH9pT2f/jtF/zZo9qhXnIoT/OZrOP3lMakQ73kUJ7mM1nH7ymNSYd6yaE8
zWeyjt9TGpMO9ZJDeZrPZB2/pzQmHeolh/I0n8k6fk9pTDrUSw7laT6Tdfx9
fkw61EsO5Wk+k3Xa/OjTcP+PjujtOJQfns+UO5a//oW9778dR/VGZzhPc56s
MzVafOMJ97/ySu2o3n6H52P9c6dyx/JXvfzYvufPjqN6o0N5ms9kHcuv6X/+
7ziqNzqUp/lM1rF8vE7JUb3RoTzNZ7KOz3f3x6JT1tvd14p5ms9knfA9fdKh
XnIoT/OZrBO+p0861EsO5Wk+k3XC9/RJh3rJoTzNZ7JO+J4+6VAvOZSn+UzW
ac/zTp4c6iWH8mqeM9Neej3ba/Oud4yf9uIfT+2w7T7m9zF2jPfJxbd+af3b
rr3ll/c9cuxz8car/uHb791HO9RLDuVtH+aLezzyglce8qxqx+YSu39oz9P/
5xu0Q73kUL75d7J9pJ1m6KwrdqiXHMr7faR6x8+FtEO95FDenw87Vzt+LqQd
6iWH8n4faUG14+dCC6VDveRQ3u8j1Tt+LrRQOtRLDuX9PlK94+dCC6VDveRQ
3u8jLax2/FxIO9RLDuX9PpI+HnL8XEgfD/WSQ3m/j1Tv+LmQ/u+iXnIo7/eR
6h0/F1ooHeolh/J+H6lzPyx2/FxIO9RLDuX9PlLn/ajY8XMh7VAvOZRvnwdG
8DyQdGwupB3qJYfyto/0pf7nsWLHjnPP3ue0rkO95FD+fHc+dJ6Hix07Tx4O
z8nkUC85lLd9JPg8UuzYXCh+TiGHesmhvO0j3X3TwR/Y8If1js2Fzv3Xzx52
3NLuvCs61EsO5W0faWL/4353vxfUOzYXGrvhwnlzlnbnbNGhXnIo7/eR6h03
F9ouTw71kkN520cqPR5ybC4Uj5Mc6iWH8raPFM+HrGNzoXiekEO95FB+DcxD
ss4DMCchh3rJoTzNc7IOzXnIoV5y6HWazzTnd/fnhuRY/g8P+NEXz3vRDtJR
vdGh/PB8ptyx/KUHv/DtR71FH4/qjc5wnuY8WWeq2FG9/a/zfKx/7lTuWL7Z
U9pZOqo3OpSn+UzWsXyzp7RAOqo3OpSn+UzW8XtK2qFecihP85ms4/eUFkmH
esmhPM1nso7fU1okHeolh/I0n8k6fk9pkXSolxzK03wm6/g9pUXSoV5yKE/z
mazj95QWSYd6yaE8zWeyjr/PL5IO9ZJDeZrPZJ023+4pde//0RG9HYfyw/OZ
csfyzZ6SPh7VG53hPM15so7tKWlH9fY7PB/rnzuVO5b/9mV79z1/dhzVGx3K
03wm61j+zP7n/46jeqNDeZrPZB3Lx+uUHNUbHcrTfCbr+Lx2ynr1cdJ8Juv4
PSXtUC85lKf5TNbxe0raoV5yKE/zmazj95S0Q73kUJ7mM1nH7ylph3rJoTzN
Z7JOe5538uRQLzmUV/OcmfbS69leP+969rbX/T7Gc8BfJB0/F9IO9ZJDeb+P
9Nxqx8+FtEO95FC++XeyfaRdZuisK3aolxzK2/HsffYFPznl1HrHjvOJyUfu
fP3x2qFecijvzofJesfOkwtfuu/E7Q9rh3rJobxdj3dtWn3m/37urtWO3ZdW
XHXxsdes0A71kkN520f65Is23HLRUfWOzYUOe/51J313pB3qJYfyto/0xOlv
Onnj2fWOzYWe3usrT28ZaYd6yaG820daWu+4udCkdqiXHMrbPlLp8ZBjc6F4
nORQLzmUt32keD5kHZsLxfOEHOolh/K2jxSvx6xjc6F4nZJDveRQ3u0jde+H
xY59Lo73SXKolxzK2z7SPv3vR8WOzSU2hfcpcqiXHMq3zwMjeB5IOutGB857
02t/s8ChXnIo7/eROs9jxY6fC2mHesmhvN9H6jwPFzt+LqQd6iWH8n4fqfN5
pNjxc6HunDk61EsO5f0+Ur3j50I071oke8mhvN9Hqnf8XIjmbItkLzmU9/tI
9Y6fCy2SDvWSQ3m/j1Tv+LnQIulQLzmU9/tI9Y6fCy2SDvWSQ/k1MA/JOg/A
nIQc6iWH8jTPyTo05yGHesmh12k+05zf3Z8bkmP5Zk/p2dJRvdGh/PB8ptyx
fLOnpI9H9UZnOE9znqwzVeyo3v7XeT7WP3cqdyx/0Iazvnnft7SjeqNDeZrP
ZB3Lr/73nfdefNau0lG90aE8zWeyju0pXfbEF249dLN2qJccytN8Juv4PaVx
6VAvOZSn+UzW8XtK49KhXnIoT/OZrOP3lMalQ73kUJ7mM1nH7ymNS4d6yaE8
zWeyjt9TGpcO9ZJDeZrPZB1/nx+XDvWSQ3maz2SdNj+6C+7/0RG9HYfyw/OZ
csfyJ1zS+/7bcVRvdIbzNOfJOlOjK9b+47s/8wel/13c2+/wfKx/7lTuWL7Z
U+o8f3Yc1RsdytN8JutY/sz+5/+Oo3qjQ3maz2Qdy8frlBzVGx3K03wm6/i8
dsp69XHSfCbr+D0l7VAvOZSn+UzW8XtK2qFecihP85ms4/eUtEO95FCe5jNZ
x+8paYd6yaE8zWeyTnued/LkUC85lFfznJn20uvZXpt3HbDzAZee+9gv72Nu
H2PJ8zr+KSe89wvHv31cOva5+P3f/s4P/9tu2qFecihv+zD3XXTOsz/z6XrH
5hILFo8f+PlrtEO95FC++XeyfaTdZuisK3aolxzK+32kesfPhbRDveRQ3u8j
1Tt+LqQd6iWH8n4fafdqx8+FtEO95FDe7yPVO34upB3qJYfyfh+p3vFzIe1Q
LzmU9/tI9Y6fC2mHesmhvN9Hqnf8XEg71EsO5f0+Ur3j50LaoV5yKO/3keod
PxfSDvWSQ3m/j9S5HxY7fi6kHeolh/J+H6ne8XMh7VAvOZRvnwdG8DyQdGwu
pB3qJYfyto8Ez2PFjh3neO9zWtehXnIo7/aRus/DxY6dJ+eE52RyqJccyts+
EnweKXZsLhQ/p5BDveRQ3vaRTl+3x6FnX1/v2Fzoqw8dt3KfJdqhXnIob/tI
Cy/73BW7X1Tv2Fxo3trD585Zoh3qJYfybh9pab3j5kJLtEO95FDe9pFKj4cc
mwvF4ySHesmhvO0jxfMh69hcKJ4n5FAvOZRfA/OQrPMAzEnIoV5yKE/znKxD
cx5yqJccep3mM837ZvfnhuRY/rd/bdOayUu6r0dH9UaH8sPzmXLH8nfscckr
Xvwy7aje6Aznac6TdaaKHdXb/zrPx/rnTuWO5Zs9Je2o3uhQnuYzWcfyzZ7S
7tJRvdGhPM1nso7fU9IO9ZJDeZrPZB2/pzQhHeolh/I0n8k6fk9pQjrUSw7l
aT6Tdfye0oR0qJccytN8Juv4PaUJ6VAvOZSn+UzW8XtKE9KhXnIoT/OZrOPv
8xPSoV5yKE/zmazT5ts9JX08orfjUH54PlPuWL7ZU9KO6o3OcJ7mPFnH9pRK
/7u4t9/h+Vj/3KncsfzGOy/te/7sOKo3OpSn+UzWsfxB/c//HUf1RofyNJ/J
OpaP1yk5qjc6lKf5TNbxee2U9erjpPlM1vF7StqhXnIoT/OZrOP3lLRDveRQ
nuYzWcfvKWmHesmhPM1nso7fU9IO9ZJDeZrPZJ32PO/kyaFeciiv5jkz7aXX
s70H3X/w9b/xmp/a3sKkvf62iz++8OADnmif53fb9vq5n3rla678wCb7nDip
nF1Ouumck7Zsss/F0qFecih/z2dP+vNr7nzC9mGqnc2XPfSzLc/k2+ci6VAv
OZRv/p022Xxmhs7mYod6yaG8HU/787hqx45zYfNcJB3qJYfy7nxYUu/YedLO
RaVDveRQ3q7Hdo5d7dh12t5PpEO95FC++Xd93H4eUe3s96XPvfnXP/+4vS9I
h3rJofyKVXvdceFFP7afB1U7d8//8st//4Qf2/uydKiXHMo3x/NY879L651P
nLz46rPMWaId6iWH8l8/64YzHtrwo+LjIWfp9CVX/OnRj3SOkxzqJYfyc7fC
GzvnQ9b5++XXHXP73z7UOU/IoV5yKL/syI9ffutH/qNzPWadXe786EduXPBg
5zolh3rJofySB7//0CXLf9C9DyedqcM/Nn743PWd+yQ51EsO5d9802E7XHv6
hsVrwvtR1hm/e/8Fc+ast5+LSYd6yaF8cz1u6Ly/1znrF3/jqc/d+MAWfTzU
Sw7l7Xj6n8fKHTvOR3uf07oO9ZJD+cXbnw+T9Y6dJx8Nz8nkUC85lL+0vR7j
55GsY9dp/JxCDvWSQ/mnt+5j/ND2sasdu0+2PxeQDvWSQ/lb2vejdh+42nlN
+z7V/lxGOtRLDuX980C9c8T4G0+7yJxJ7VAvOZT/TPs8Vno85Hy+fU6Lx0kO
9ZJD+a2nw5afdM6HrPOS9jk5nifkUC85lKd5SNahOQk51Jud28yWQ/lftUPz
meY8n27/d0I6lm/3NKSjeqND+eH5TLlj+XZPRjqqNzrDeZrzZJ3pYkf19r/O
87H+uVO5Y/l2T0w6qjc6lKf5TNaxfLunJx3VGx3KD89nyp0T7/2X8c3rNi9+
14JjX3XLTtqhXnIoT/OZrPM7y/f+9C9uesLm9tKhXnIoT/OZrDP9gf+ftruP
8qsu772fhyESEhGmYVyW01tXBVFA2kaE+kBn5EA5Kg9SurAoHhSwoiAoFcrp
fR8d1NoqCyqCCxFNSSwg5xSkAq3LukqkImkQxCcMIcg0xh4MYlWEDGDIzeG7
rzHXtfd7f/b1nYn/uNasz3p9dpi992//rrlmfqsPecfrH2nlyaFecihP85ms
81unLNl9YvznrTw51EsO5Wk+k3V+8wN//eHfe+ePW3lyqJccytN8Jutc8283
3L7ook2tPDnUSw7laT6Tdfx9XjvUSw7laT6TdUpuanw53P+j09/bdijfP58Z
7lj+mjO7Xn/bjuqNTn+e5jxZZ2r8rXsf94mTrxv67+LebofnY91zp+GO5ccO
PKPjOa3tqN7oUJ7mM1nH8ms7n//bjuqNDuVpPpN1LB+vU3JUL903Yp7mM1nH
58ekM6x3TOb75zPDnT8569TtXqfo+MdkLzmUp/lM1vnB92/43vJjf97Kk0O9
5FCe5jNZ518/dct2z2lj0qFecihP85msc6h7Th6TDvWSQ3mah2SdkmvPSchR
c5ih+blyKD9Xjp937T7zdb+PtBv4u0vHz4W0Q73kUN7vI9U7fi6kHeolh/Ll
+2T7SLN1tgx2qJccytvxNJ+HWO3YcTZ/l1461EsO5d35MLlrtWPnSfN3QaVD
veRQ3q7H5nMcqh27Tpu/pycd6iWH8uX7+oh9Hke1Y3Oh5u8iSod6yaG87SM1
n4dS7dhcqPm7lNKhXnIoX46neZ6ZV++4udB2eXKolxzK2z7S0OMhx+ZC8TjJ
oV5yKG/7SPF8yDr2viCeJ+RQLzmUt32keD1mHXtfFq9TcqiXHMq7faTt78NJ
x94Xbw73SXKolxzK2z5MfD3KOjaXWBZep8ihXnIoX67DTa3X9zpn4/jlTx57
+i3b9PFQLzmU9/tI9Y6fC2mHesmhvN9Hqnf8XEg71EsO5f0+0u7Vjp8LaYd6
yaG830eqd/xcSDvUSw7l/T5SvePnQtqhXnIo754HJusdPxfSDvWSQ3m/j1Tv
+LmQdqiXHMr7faR6x8+FtEO95FCe5iFZh+Yk5FBvdm4zVw7ld7RD85lynrd/
bkiO5ZvPKZOO6o0O5fvnM8MdyzefEycd1Rud/jzNebLO9GBH9XZ/nedj3XOn
4Y7lm89JlI7qjQ7laT6TdSz/jvI5NdJRvdGhfP98Zrhje0rfXrbi3A/vrh3q
JYfyNJ/JOn5PSTvUSw7laT6TdfyeknaolxzK03wm6/g9Je1QLzmUp/lM1vF7
StqhXnIoT/OZrOP3lLRDveRQnuYzWcff57VDveRQnuYzWafkpsZPhft/dPp7
2w7l++czwx3LH3V/1+tv21G90enP05wn60yNf/V1V+9125u0o3q7HZ6Pdc+d
hjuWL3tK2lG90aE8zWeyjuXXdj7/tx3VGx3K03wm61g+XqfkqF66b8Q8zWey
js+398eiM6yX9rWGzmeGO35PiY5/VPaSQ3maz2Qdv6c0Kh3qJYfyNJ/JOn5P
aVQ61EsO5Wk+k3UOhd9TIId6yaE8zUOyTsm15yTkqDnM0PxcOZSfK8fmXVc8
fMW9uz5/l5mv+32MxS3/1Uf91t/+0SFLpGPvi8dO+OP9L/q+dqiXHMrbPswx
m0Z/dNvXd652bC7x0Pn3Xbby77VDveRQvnyfbB9pts6WwQ71kkN5v4/0rGrH
z4W0Q73kUN6fD4uqHT8X0g71kkN5v4+0U7Xj50Ij0qFecihfvq+2j1Tv+LnQ
iHSolxzK+32kesfPhUakQ73kUL4cj+0j1Tt+LjQiHeolh/J+H6ne8XOhEelQ
LzmU9/tI9Y6fC41Ih3rJobzfR6p3/FxoRDrUSw7l/T7SomrHz4W0Q73kUN7v
Iz2r2vFzIe1QLzmUL9fhptbre51jcyF9PNRLDuXteI7ufB4b7thxbuh8Tms7
1EsO5d0+0nbPw1nHzpM9wnMyOdRLDuVtHym+H8k6dp3G9ynkUC85lLd9pN89
Ys1f7nl5vWP3yb8+4MR/vv4DS6RDveRQ3vaRNn/r+n/57o/qHZsL/er179u6
bbs8OdRLDuX988CSasfNhSa1Q73kUN72kYYeDzk2F4rHSQ71kkN520eK50PW
sblQPE/IoV5yKE/zkKxDcxJyqDc7t5krh/I72qH5TDm/2z83JMfyn77zN45+
/4Z4f+j4OabojQ7l++czwx3Lv3vN/StuvEofj+qNTn+e5jxZZ3qwo3q7v87z
se6503DH8mVPaZF0VG90KE/zmaxj+bKnFOcDbUf1Rofy/fOZ4Y7fU9IO9ZJD
eZrPZB2/p6Qd6iWH8jSfyTp+T0k71EsO5Wk+k3X8npJ2qJccytN8Juv4PSXt
UC85lKf5TNbxe0raoV5yKE/zmazj7/PaoV5yKE/zmaxTcran1L7/R6e/t+1Q
vn8+M9yxfNlT0sejeqPTn6c5T9axPSXtqN5uh+dj3XOn4Y7lX3rauo7ntLaj
eqNDeZrPZB3LX9r5/N92VG90KE/zmaxj+XidkqN66b4R8zSfyTo+394fi86w
3va+Vsz3z2eGO35PiY5/qewlh/I0n8k6fk9pqXSolxzK03wm6/g9paXSoV5y
KE/zmaxzKPyeAjnUSw7laR6SdUquPSchR81hhubnyqH8XDl+3rVg5ut+H2M+
+Aul4+dC2qFecijv95HmVTt+LqQd6iWH8uX7ZPtIs3W2DHaolxzK2/GccvD6
l7/v7KduqXXsOPf91X+7+ytXa4d6yaG8Ox/mba127Dz53lFvvOaHb/iVdKiX
HMrb9bh2rzVHbvzqk9WOXad//fbbvvqmv3xcOtRLDuXLcTwyfuV7z/rlmjuf
qHZsLvSzVUd8dNW8x6VDveRQ3vaR9j9x1QePP7DesbnQ4tOeu9O87fLkUC85
lC/HYz+Pq3fcXGi7PDnUSw7lbR9p6PGQY3OheJzkUC85lLd9pHg+ZB17XxDP
E3KolxzK2z5SvB6zjr0vi9cpOdRLDuXdPtL29+GkY++Lvxvuk+RQLzmUt32Y
k8PrUdaxucQ+4XWKHOolh/LlODY1P5feNktn4/jyLZ+75/0DHOolh/J+Hyk+
5wx3/FxIO9RLDuX9PtL8asfPhbRDveRQ3u8jLah2/FxooXSolxzK+32kesfP
hRZKh3rJobzfR6p3/FxooXSolxzK++eBhdWOnwtph3rJobzfR9LHQ46fC+nj
oV5yKO/3keodPxfS/y7qJYfyNA/JOjQnIYd6s3ObuXIov6Mdms+U87v9c0Ny
LF/2lOL9oePnmKI3OpTvn88Mdyxf9pT08aje6PTnac6TdaYHO6q3++s8H+ue
Ow13LL/PWYfd+qmbfiUd1RsdytN8JutY/q5T152y8Ig4H2g7qjc6lO+fzwx3
bE/p717y6od3fuG0dKiXHMrTfCbr+D2laelQLzmUp/lM1vF7StPSoV5yKE/z
mazj95SmpUO95FCe5jNZx+8pTUuHesmhPM1nso7fU5qWDvWSQ3maz2Qdu8/E
PDnUSw7laT6TdUpuavx2uP9Hp7+37VC+fz4z3LH8FV8+vOP1t+2o3uj052nO
k3Wmxs//5JGv/djN+nhUb7fD87HuudNwx/JlTyk+p7Ud1RsdytN8JutY/tLO
5/+2o3qjQ3maz2Qdy8frlBzVS/eNmKf5TNbx+fb+WHSG9dK+1tD5zHDH7ynR
8Y/IXnIoT/OZrOP3lEakQ73kUJ7mM1nH7ymNSId6yaE8zWeyzqHwewrkUC85
lKd5SNZprs9Wnhw1hxmanyuH8nPl2Lyr+f+Z+5jfx3ik9T6x+f9blGPvi5v3
Z9KhXnIob/swzV5AtWNziXvK9SEd6iWH8uU4bB/pZ7N0tgx2qJccytvx3FZ+
LlHt2HH+cXl9kA71kkN5fz5srnbsPGlen6VDveRQ3q7HZi+g2rHrtHk+kg71
kkP55jq0vYBqx+ZCzfOpdKiXHMrbPlLzc+lqx+ZCzfsD6VAvOZRvrqvm/+sd
PxfaKB3qJYfyto809HjIsblQPE5yqJccyts+Ujwfso69L4jnCTnUSw7lbR/p
knA9Zh17XxavU3KolxzK2z5S+bnoj6sde198TbhPkkO95FDe9mG+Fl6Pso7N
JY4Jr1PkUC85lG+uw2Yv4z9n6WwcP/WnR1y39SntUC85lLfj+Wzn89hwx47z
nzqf09oO9ZJD+XF3Pvyi2rHzZN/wnEwO9ZJDedtHiu9Hso5dp/F9CjnUSw7l
bR+peS6rduw+2TyvSYd6yaG87SM1z8XVjs2Fmudl6VAvOZT3zwOPVTtuLjRv
i3SolxzK2z7S0OMhx+ZC8TjJoV5yKG/7SPF8yDo2F4rnCTnUSw7laR6SdWhO
Qg71Zuc2c+VQfkc7NJ8p52v754bkWP5lZV4oHdUbHcr3z2eGO5Zf//F//r/z
Wumo3uj052nOk3WmBzuqt/vrPB/rnjsNdyx/1A+e2ReQjuqNDuVpPpN1LH9F
2ReQjuqNDuX75zPDHdtTeu1x563f/Q+npEO95FCe5jNZx+8pTUmHesmhPM1n
so7fU5qSDvWSQ3maz2Qdv6c0JR3qJYfyNJ/JOn5PaUo61EsO5Wk+k3X8ntKU
dKiXHMrTfCbr+Pv8lHSolxzK03wm6zS58Yvg/h+d/t62Q/n++cxwx/IHnXNB
x+tv21G90enP05wn60yNL9jv8k8sO10fj+rtdng+1j13Gu5Y/k1339DxnNZ2
VG90KE/zmaxj+Rd3Pv+3HdUbHcrTfCbrWD5ep+SoXrpvxDzNZ7KOz7f3x6Iz
rLe9rxXz/fOZ4Y7fU6Ljn5a95FCe5jNZx+8pTUuHesmhPM1nso7fU5qWDvWS
Q3maz2SdQ+H3FMihXnIoT/OQrNPkWnly1BxmaH6uHMrPlWPzrnvPeOAb507f
PfN1v4+xpuU/8M7N05duvlc69r74zRcfftvG8+6UDvWSQ3nbh1n/0RNXfWXd
l6odm0ucfMh7nlx+6c3SoV5yKF+OY+bvQc2bnbNlsEO95FDejueecjzjtY4d
50nlOKVDveRQ3s6H8nOh26sdO0+OL+eJdKiXHMqH67Haset0qlyn0qFecihf
vquPjE++4tADNqz5brVjc6GJ9/37+nO23icd6iWH8raPdMzfnPvoVQd8v9qx
udD9J616aNu2+6RDveRQvhyPPc+sq3b8XGiDdKiXHMrbPtIbBh4POTYXisdJ
DvWSQ3nbR4rnQ9ax9wXxPCGHesmhvO0jrQ/XY9ax92XxOiWHesmhvO0jjTxz
XGuqHXtffGq4T5JDveRQ3vZhpsLrUdaxucQF4XWKHOolh/Lluto0/qFV+xx3
9IrrXz07Z+P4J2973vn77f0CeTzUSw7l7Xju6nweG+7Ycf75q7qe09oO9ZJD
edtHmi7PA9WOnSdHhedkcqiXHMrbPlJ8P5J17DqN71PIoV5yKG/7SO8v98Nq
J9wnpUO95FDe9pGOLq9H1c4f+Ncp6VAvOZQPzwPVjp8LbZAO9ZJDedtHesPA
4yHnC/45TTrUSw7lbR/pg+F8yDov8c/J0qFecihv70fWh+sx64T3KdKhXnIo
T/OcrENzHuVQLznx6zSfKedr++eG5Fj+G2eseM8vfniPdFRvdCjfP58Z7lj+
zo9sePgVb14rHdUbnf48zXmyzvRgR/V2f53nY91zp+GO5e8oxykd1RsdytN8
JutYfm05T6SjeqND+f75zHDH9pTOPOE5r9/wZw9Ih3rJoTzNZ7JO2FOSDvWS
Q3maz2SdsKckHeolh/I0n8k6YU9JOtRLDuVpPpN1wp6SdKiXHMrTfCbrhD0l
6VAvOZSn+UzWsftMzJNDveRQnuYzWcdym+D+H53+3rZD+f75zHDH8vvu9+2O
19+2o3qj05+nOU/WmRr/6TUHnf7ma24a+O/i3m6H52Pdc6fhjuW/+cGPdDyn
tR3VGx3K03wm61h+Vefzf9tRvdGhPM1nso7l43VKjuql+0bM03wm64S8dAb2
yuPsn88Md/yeEh6/7CWH8jSfyTp+T2lKOtRLDuVpPpN1/J7SlHSolxzK03wm
6xwKv6dADvWSQ3maz2SdkmvPScihXnIor+Y5s+1VztDe8HdjZu5j4e/hjEff
7pfKsffF1zb3J+VQLzmUD3+PqNoJvxcmHeolh/LlOGb+HtQsnS2DHeolh/J2
PDYXr3XC70VKh3rJoXz4e2jVTvi9VOlQLzmUD79HXO2EfU7pUC85lLfjsOOq
dfbze7nSoV5yKL/C/z5+tXO334uWDvWSQ3m7ruy6rHX8XGiLdKiXHMp/3f89
impn0v9egHSolxzK2z5SPB+yTvi9DOlQLzmUv9T/PZZqJ/xejHSolxzK+8/j
e6TasffF+4f7JDnUSw7lbR9mRXg9yjo2l7g3vE6RQ73kUL4cx6bmvPjZLJ2N
43ftfOJLzh/gUC85lLfj+Xrn89hwx47z4s7ntLZDveRQ3vaRFjTXZa1j58l1
4TmZHOolh/K2jxTfj2Sd8HvB0qFecihv+0ivaY6r1gm/ly0d6iWH8raPdEJz
XtQ6Nhey80U51EsO5f3zQL3j50IbpUO95FD+s/7vkVY7NheKx0kO9ZJDedtH
Gg/nQ9axuVA8T8ihXnIob88Bl4TrMevQnIQc6lVzm5ineU7WoXx2jpR1aD5T
ztf2zw3Jsfynm5+XKkf1Rofy/fOZ4Y7lm79TJB3VG53+PM15ss70YEf1dn+d
52Pdc6fhjuXvLX+nSzqqNzqUp/lM1rH88mZerhzVGx3K989nhju2p2T/rxzq
JYfyNJ/JOuFz+qRDveRQnuYzWSd8Tp90qJccytN8JuuEz+mTDvWSQ3maz2Sd
8Dl90qFecihP85msEz6nTzrUSw7laT6Tdfx9flo61EsO5Wk+k3VKbmr8FXD/
j05/b9uhfP98Zrhj+bcf/uWO19+2o3qj05+nOU/WmRr/wLtu/MdzXqePR/V2
Ozwf6547DXcsf+RJKzqe09qO6o0O5Wk+k3Us/4XO5/+2o3qjQ3maz2Qdy8fr
lBzVS/eNmKf5TNbx+fb+WHSG9bb3tWK+fz4z3Al7StKhXnIoT/OZrBP2lKRD
veRQnuYzWSfsKUmHesmhPM1nss6h8HsK5FAvOZSneUjWsesz5slRc5ih+bly
KD9Xjs271u615siNX31y5ut+H2Nry28+J1o69jz6vfK5zNKhXnIobz+HPvng
9S9/39lPVTv2fmDf8rnM0qFecihfjmPm70FNzM7ZMtihXnIob8dzzKbRH932
9XrHjvOh8rnM0qFecijvzofJ+dWOnSfN5zJLh3rJobxdj1c8fMW9uz5/QbUT
Ps9UOtRLDuXLt/WR8d89Ys1f7nl5vWNzoeZzaaVDveRQ3vYANn/r+n/57o/q
HZsLNZ8LLB3qJYfy5XjseWZhtePmQpPaoV5yKG97AEOPhxybC8XjJId6yaG8
7SPF8yHrhM8llw71kkN5+/lZvB6zTvhceOlQLzmUd/tI29+Hk449j46F+yQ5
1EsO5e3n0PH1KOvY+4GfhNcpcqiXHMqX69Dmk7N1No6/Y+T6SycGONRLDuXt
eE7pfB4b7thxvrbzOa3tUC85lLc9gHJdbq127Dy5Jzwnk0O95FDe9gDi+5Gs
Y9dpfJ9CDvWSQ3nbR7ryvWf9cs2dT1Q7dp/82aojPrpq3uPSoV5yKG/7SPuf
uOqDxx9Y79hcaPFpz91p3nZ5cqiXHMr754F6x8+FHpcO9ZJDedtHGno85Nhc
KB4nOdRLDuVtHymeD1nH5kLxPCGHesmhPM1Dsg7NScih3uzcZq4cyu9oh+Yz
5Xxt/9yQHMvdeeq6UxYeEe8PHT/HFL3RoXz/fGa4Y/kXnXXYrZ+6SR+P6o1O
f57mPFlnerCjeru/zvOx7rnTcMfy715z/4obr5ovHdUbHcrTfCbrWP7yO3/j
6PdviPOBtqN6o0P5/vnMcMf2kw546G0f/X9/qh3qJYfyNJ/JOn5PaUQ61EsO
5Wk+k3X8ntKIdKiXHMrTfCbr+D2lEelQLzmUp/lM1vF7SiPSoV5yKE/zmazj
95RGpEO95FCe5jNZx9/nR6RDveRQnuYzWafkpsY/A/f/6PT3th3K989nhjuW
v/G3u15/247qjU5/nuY8WWdqfPzmE+575VXaUb3dDs/HuudOwx3LX/07x3Q8
p7Ud1RsdytN8JutYfl3n83/bUb3RoTzNZ7KO5eN1So7qpftGzNN8Juv4fHt/
LDrDetv7WjHfP58Z7oTP6ZMO9ZJDeZrPZJ3wOX3SoV5yKE/zmawTPqdPOtRL
DuVpPpN1DoXfUyCHesmhPM1Dso7lYp4cNYcZmp8rh/Jz5di86+2jp77o51M7
zdzH/D7Gotb7xK99ceNbr7v11/c9cux98ear//d33vti7VAvOZS3fZh/2PPh
33zlK55V7dhcYo/373Xafz9OO9RLDuXL98n2kXaepbNlsEO95FDe7yPVO34u
pB3qJYfy/nxYXO34uZB2qJccyvt9pF2qHT8XWiId6iWH8uX7avtI9Y6fCy2R
DvWSQ3m/j1Tv+LnQEulQLzmUL8djzzNLqh0/F9IO9ZJDeb+PpI+HHD8X0sdD
veRQ3u8j1Tt+LqT/XdRLDuX9PlK94+dCS6RDveRQ3u8jLa52/FxIO9RLDuX9
PtLO1Y6fC2mHesmhfLkON7Ve3+scmwtph3rJobwdzxc7n8eGO3ace3U+p7Ud
6iWH8uPufFhU7dh58lB4TiaHesmhvO0jxfcjWceu0/g+hRzqJYfyto9095cO
/otNf1rv2H3yvG997rBjJ9vzruhQLzmUt32ksQOOfc1+v1nv2Fxo5KYLFsyb
bM/ZokO95FDePw/UO24utF2eHOolh/K2jzT0eMixuVA8TnKolxzK2z5SPB+y
js2F4nlCDvWSQ3mah2QdmpOQQ73Zuc1cOZTf0Q7NZ8r53f65ITmW/9PlP/mH
818Y7w8dP8cUvdGhfP98Zrhj+UsO/u23HfkmfTyqNzr9eZrzZJ3pwY7q7f46
z8e6507DHcuXPaXF0lG90aE8zWeyjuXLnlKcD7Qd1RsdyvfPZ4Y7fk9JO9RL
DuVpPpN1/J7SUulQLzmUp/lM1vF7SkulQ73kUJ7mM1nH7yktlQ71kkN5ms9k
Hb+ntFQ61EsO5Wk+k3X8ntJS6VAvOZSn+UzW8ff5pdKhXnIoT/OZrFNytqfU
vv9Hp7+37VC+fz4z3LF82VPSx6N6o9OfpzlP1rE9Je2o3m6H52Pdc6fhjuW/
c9k+Hc9pbUf1RofyNJ/JOpY/o/P5v+2o3uhQnuYzWcfy8TolR/XSfSPmaT6T
dXxeO8N69XH2z2eGO35PSTvUSw7laT6TdfyeknaolxzK03wm6/g9Je1QLzmU
p/lM1jkUfk+BHOolh/I0D8k6Jdeek5Cj5jBD83PlUH6uHD/vevbM1/0+xq7g
L5WOnwtph3rJobzfR3pOtePnQtqhXnIoX75Pto+02yydLYMd6iWH8nY8+5z9
0V+cfEq9Y8f56OqH73jD8dqhXnIo786H1fWOnScX7L/v2O0PaYd6yaG8XY93
PXbnGX/1nN2rHbtOV1x90THXrtAO9ZJD+fJ9fWT8Uy/cdOuFR9Y7Nhc67LnX
v+X7t2iHesmhvO0jPXraG0/afHa9Y3Ohp/b+8lPbbtEO9ZJD+XI89jxT77i5
0GrtUC85lLd9pKHHQ47NheJxkkO95FDe9pHi+ZB17H1BPE/IoV5yKG/7SPF6
zDr2vixep+RQLzmUd/tI29+Hk469L473SXKolxzK2z7Mi8PrUdaxucRj4XWK
HOolh/LletzUen2vczaOH7jgja97wQCHesmhvN9His9Xwx0/F9IO9ZJDeb+P
tGu14+dC2qFecijv95GeXe34uVB7zhwd6iWH8n4fqd7xcyGady2VveRQ3u8j
1Tt+LkRztqWylxzKu+eBefWOnwstlQ71kkN5v49U7/i50FLpUC85lPf7SPWO
nwstlQ71kkN5modkHZqTkEO92bnNXDmU39EOzWfK+d3+uSE5li97SvH+0PFz
TNEbHcr3z2eGO5Yve0r6eFRvdPrzNOfJOtODHdXb/XWej3XPnYY7lj9o05nf
vPfb2lG90aE8zWeyjuXv/I/F+4yfGd8vtx3VGx3K989nhju2p3TZozd87ZAt
2qFecihP85ms4/eURqVDveRQnuYzWcfvKY1Kh3rJoTzNZ7KO31MalQ71kkN5
ms9kHb+nNCod6iWH8jSfyTp+T2lUOtRLDuVpPpN1/H1+VDrUSw7laT6TdUpu
avwuuP9Hp7+37VC+fz4z3LH8CRd3vf62HdUbnf48zXmyztT4lev//t2f/aOh
/y7u7XZ4PtY9dxruWL7sKcXntLajeqNDeZrPZB3Ln9H5/N92VG90KE/zmaxj
+XidkqN66b4R8zSfyTo+r51hvfo4++czwx2/p6Qd6iWH8jSfyTp+T0k71EsO
5Wk+k3X8npJ2qJccytN8JuscCr+nQA71kkN5modknZJrz0nIUXOYofm5cig/
V47Nu5YvXn7JeT/79X3M7WNM/EbLP/mE995w/NtGpWPvi8/5zvd+/PvLtEO9
5FDe9mHuvfDcZ3/2M/WOzSV2GR898AvXaod6yaF8+T7ZPtKyWTpbBjvUSw7l
/T5SvePnQtqhXnIo7/eR6h0/F9IO9ZJDeb+PtEe14+dC2qFecihfvq+2j1Tv
+LmQdqiXHMr7faR6x8+FtEO95FC+HI89z9Q7fi6kHeolh/J+H6ne8XMh7VAv
OZT3+0j1jp8LaYd6yaG830eqd/xcSDvUSw7l/T7SsmrHz4W0Q73kUN7vI9U7
fi6kHeolh/LletzUen2vc2wupB3qJYfydjzdz2PDHTvO0c7ntLZDveRQ3u0j
TdQ7dp6cG56TyaFecihv+0jx/UjWses0vk8hh3rJobztI522Yc9Dzr6x3rH7
5FcePHbViye0Q73kUN72kZZc9vkr97iw3rG50IL1h8+fN6Ed6iWH8v55oN5x
c6EJ7VAvOZS3faShx0OOzYXicZJDveRQ3vaR4vmQdWwuFM8TcqiXHMrTPCTr
0JyEHOrNzm3myqH8jnZoPlPO8/bPDcmx/Mue99i61Re3vx4d1RsdyvfPZ4Y7
ll+758W/+6KXakf1Rqc/T3OerDM92FG93V/n+Vj33Gm4Y/myp6Qd1RsdytN8
JutYvuwpxffLbUf1Rofy/fOZ4Y7fU9IO9ZJDeZrPZB2/pzQmHeolh/I0n8k6
fk9pTDrUSw7laT6Tdfye0ph0qJccytN8Juv4PaUx6VAvOZSn+UzW8XtKY9Kh
XnIoT/OZrOPv82PSoV5yKE/zmaxTcranpI+nv7ftUL5/PjPcsXzZU9KO6o1O
f57mPFnH9pSG/ru4t9vh+Vj33Gm4Y/nNd1zS8ZzWdlRvdChP85msY/mDOp//
247qjQ7laT6TdSwfr1NyVC/dN2Ke5jNZx+e1M6xXH2f/fGa44/eUtEO95FCe
5jNZx+8paYd6yaE8zWeyjt9T0g71kkN5ms9knUPh9xTIoV5yKE/zkKxTcu05
CTlqDjM0P1cO5efKKZ+Xs2Ci+bnhavt6+RygBRPPxFcvm/m6fT5085y2Wjn2
edjNc5F0qJccypfPYVow0ezDVDv2eeTNc5F0qJccypfv08JyPPNm6UwOd6iX
HMrb8TQ/j6t27DiXlOci6VAvOZR358NEvWPnSTMXlQ71kkN5ux6bOXa1Y9dp
cz+RDvWSQ/ny/Z0/0fw8otqxz4NvXhekQ73kUL58Dta8iebnQdXOg83nwTev
y9KhXnIoX66reeV8mKx3/u0Lf3vcweZMaId6yaH8KQevf/n7zn5qfOjxkDPR
fB58PE5yqJccypfD2Toez4es873m8+DjeUIO9ZJD+bV7rTly41efHI/XY9ax
z1GO1yk51EsO5a9871m/XHPnE+Ot+3DSsc/DjvdJcqiXHMrvf+KqDx5/4BPj
68LrUdaxzyPfJbxOkUO95FC+nA/N8Wz3+l7nPD7+ja2fv/mBbfp4qJccytvx
dD/XDXfsOH/a+ZzWdqiXHMq782F1vWPnycfCczI51EsO5e16jO9Hso5dp/F9
CjnUSw7lyz7Gr2wftdqx+2TzcwHpUC85lH9b83rU7ANXO89vXqean8tIh3rJ
obx/Hqh39lq87xf/0JzV2qFecih/dPM8NvR4yFnXPKfF4ySHesmh/DOnwwfm
T8TzIevs0Twnx/OEHOolh/I0D8k6NCchh3qzc5u5cii/ox2az5TTfKSct/PG
pGP5Zk9DOqo3OpTvn88Mdyzf7MlIR/VGpzePc56kM/PfeeC/q6e38+s987HO
uVPCsXyzJyYd1RsdytN8JutYvtnTk47qjQ7le+czCad8Pt/CiXfucsyrbt1Z
O9RLDuVpPpN1Pv3M52MtaM4T7VAvOZSn+UzW+f8OmVpx41XzW3lyqJccytN8
Jutc9A9/ufOVfzuvlSeHesmhPM1nss6F44fd+qmbfjUe8+RQLzmUp/lM1vnu
qetOWXjEE608OdRLDuVpPpN17D4T8+RQLzmUp/lM1im56fHlcP+PTn9v26F8
/3xmuGP5a87sev1tO6o3Ov15mvNknenxt+593CdOvm7ov4t7ux2ej3XPnYY7
lh878IyO58+2o3qjQ3maz2Qdy6/tfP5vO6o3OpSn+UzWsXy8TslRvXTfiHma
z2Qdnx+TzrDeMZnvn88Md/7+4OXbvU7R8Y/JXnIoT/OZrPOfp6971+Wft+eE
MelQLzmUp/lM1jn5Gw9s95w2Jh3qJYfyNJ/JOivdc/KYdKiXHMrTPCTrlFx7
TkKOmsMMzc+VQ/m5cvy8a/eZr/t9pN3A3106fi6kHeolh/J+H6ne8XMh7VAv
OZQv3yeb58zSmRzuUC85lLfjaT4Psdqx42z+Lr10qJccyrvzYXLXasfOk+bv
gkqHesmhvF2Pzec4VDt2nTZ/T0861EsO5ctxzJ9oPo+j2rG5UPN3EaVDveRQ
3vaRms9DqXZsLtT8XUrpUC85lC/XlT2f1DtuLrRdnhzqJYfyto809HjIsblQ
PE5yqJccypfj2Doez4esY+8L4nlCDvWSQ3nbB4jXY9ax92XxOiWHesmhvNvH
2P4+nHTsffHmcJ8kh3rJobztw8TXo6xjc4ll4XWKHOolh/LlfLD55G6zdB4f
v/zJY0+/ZZs+Huolh/J+H6ne8XMh7VAvOZT3+0j1jp8LaYd6yaG830favdrx
cyHtUC85lPf7SPWOnwtph3rJobzfR6p3/FxIO9RLDuXd88BkvePnQtqhXnIo
7/eR6h0/F9IO9ZJDeb+PVO/4uZB2qJccytM8JOvQnIQc6s3ObebKofyOdmg+
U07z9s8NybF88zll0lG90aF8/3xmuGP55nPipKN6o9ObxzlP0pn57zzw39XT
2/n1nvlY59wp4Vi++ZxE6aje6FCe5jNZx/LvKJ9TIx3VGx3K985nEo7tKX17
2YpzP7y7dqiXHMrTfCbr+D0l7VAvOZSn+UzW8XtK2qFecihP85ms4/eUtEO9
5FCe5jNZx+8paYd6yaE8zWeyjt9T0g71kkN5ms9kHbvPxDw51EsO5Wk+k3VK
bnr8VLj/R6e/t+1Qvn8+M9yx/FH3d73+th3VG53+PM15ss70+Fdfd/Vet71J
O6q32+H5WPfcabhj+bKnpB3VGx3K03wm61h+befzf9tRvdGhPM1nso7l43VK
juql+0bM03wm6/h8e38sOsN6aV9r6HxmuOP3lOj4R2UvOZSn+UzW8XtKo9Kh
XnIoT/OZrOP3lEalQ73kUJ7mM1lnJfyeAjnUSw7laR6SdUquPSchR81hhubn
yqH8XDk27yr/v8vM1/0+xuKWX/5/iXTsfXF5f6Yd6iWH8rYPU/YCdq52bC7x
0DPXh3aolxzKl++TzXNm6UwOd6iXHMr7faRnVTt+LqQd6iWH8v58WFTt+LmQ
dqiXHMr7faSdqh0/FxqRDvWSQ/lyHLaPVO/4udCIdKiXHMr7faR6x8+FRqRD
veRQvlxX9nxS7/i50Ih0qJccyvt9pHrHz4VGpEO95FC+HIftI9U7fi40Ih3q
JYfyfh+p3vFzoRHpUC85lPf7SIuqHT8X0g71kkN5v4/0rGrHz4W0Q73kUL6c
Dzaf3HmWjs2F9PFQLzmUt+M5uvO5brhjx7mh8zmt7VAvOZT358PiasfOkz3C
czI51EsO5e16jO9Hso5dp/F9CjnUSw7lbR+pPJfVO3afLM9rS6RDveRQ3vaR
ynNxvWNzofK8vEQ61EsO5f3zwJJqx82FJrVDveRQ3vaRhh4POTYXisdJDvWS
Q3nbR4rnQ9axuVA8T8ihXnIoT/OQrENzEnKoNzu3mSuH8jvaoflMOb/bPzck
x/JlXyDeHzp+jil6o0P5/vnMcMfy715z/4obr9LHo3qj05vHOU/SmfnvrB3V
2/n1nvlY59wp4Vi+7Cktko7qjQ7laT6TdSxf9pTi+9O2o3qjQ/ne+UzC8XtK
2qFecihP85ms4/eUtEO95FCe5jNZx+8paYd6yaE8zWeyjt9T0g71kkN5ms9k
Hb+npB3qJYfyNJ/JOn5PSTvUSw7laT6Tdew+E/PkUC85lKf5TNYpOdtTat//
o9Pf23Yo3z+fGe5Yvuwp6eNRvdHpz9OcJ+vYnpJ2VG+3w/Ox7rnTcMfyLz1t
XcfzZ9tRvdGhPM1nso7lL+18/m87qjc6lKf5TNaxfLxOyVG9dN+IeZrPZB2f
b++PRWdYb3tfK+b75zPDHb+nRMe/VPaSQ3maz2Qdv6e0VDrUSw7laT6Tdfye
0lLpUC85lKf5TNZZCb+nQA71kkN5modkneb6bOXJUXOYofm5cig/V46fdy2Y
+brfx5gP/kLp+LmQdqiXHMr7faR51Y6fC2mHesmhfPk+2Txnls7kcId6yaG8
HU+zF3BLrWPHuW95fZAO9ZJDeXc+zNta7dh50rw+S4d6yaG8XY/Nz+WqHbtO
m+cj6VAvOZRvrsOJ5uei1Y7NhZrnU+lQLzmUt32k5ufS1Y7NhZr3B9KhXnIo
31xXzflQ77i50HZ5cqiXHMrbPtLQ4yHH5kLxOMmhXnIo31yH4/F8yDr2viCe
J+RQLzmUt32AeD1mHXtfFq9TcqiXHMq7fYzt78NJx94XfzfcJ8mhXnIob/sw
J4fXo6xjc4l9wusUOdRLDuWb67DZy9g2S+fx8eVbPnfP+wc41EsO5f0+UnzO
Ge74uZB2qJccyvt9pPnVjp8LaYd6yaG830daUO34udBC6VAvOZT3+0j1jp8L
LZQO9ZJDeb+PVO/4udBC6VAvOZT3zwMLqx0/F9IO9ZJDeb+PpI+HHD8X0sdD
veRQ3u8j1Tt+LqT/XdRLDuVpHpJ1aE5CDvVm5zZz5VB+Rzs0nynnd/vnhuRY
vtkXkI7qjQ7l++czwx3Llz0lfTyqNzq9eZzzJJ2Z/87aUb2dX++Zj3XOnRKO
5fc565l9Aemo3uhQnuYzWcfyd5V9Aemo3uhQvnc+k3BsT+nvXvLqh3d+4bR0
qJccytN8Juv4PaVp6VAvOZSn+UzW8XtK09KhXnIoT/OZrOP3lKalQ73kUJ7m
M1nH7ylNS4d6yaE8zWeyjt9TmpYO9ZJDeZrPZB27z8Q8OdRLDuVpPpN1mtz4
7XD/j05/b9uhfP98Zrhj+Su+fHjH62/bUb3R6c/TnCfrTI+f/8kjX/uxm/Xx
qN5uh+dj3XOn4Y7ly55SfP5sO6o3OpSn+UzWsfylnc//bUf1RofyNJ/JOpaP
1yk5qpfuGzFP85ms4/Pt/bHoDOulfa2h85nhjt9TouMfkb3kUJ7mM1nH7ymN
SId6yaE8zWeyjt9TGpEO9ZJDeZrPZJ2V8HsK5FAvOZSneUjWaXKtPDlqDjM0
P1cO5efKsXnXQfcdfONv/cEvZ+5jfh/jkdb7xPM+/co/uOovHrtFOfa+eL8v
fv5P/ssXtEO95FDe9mFWrNl77QUX/rzasbnEPQv/6Xf+6wnaoV5yKF+Ow+Y5
P5udMzncoV5yKG/Hc9uZN53+4KafVDt2nH88ffGV/+Ooh6VDveRQ3p8Pm6sd
O0/+1xXXH337ygelQ73kUN6ux0tf+/HLv/ah/1Pt2HW62x0f+9DNu/xQOtRL
DuXL93f+xMQPf/DgxVf8qNqxudDU4X8zevj8jdKhXnIob/tIf/Klw3a67rRN
1Y7NhUbvPmCXefM2Sod6yaF8OQ/s+aTe8XOhjdKhXnIob/tIQ4+HHJsLxeMk
h3rJoXxxt47H8yHr2PuCeJ6QQ73kUN72AS4J12PWsfdl8Tolh3rJobztY5S9
gB9XO/a++JpwnySHesmhvO3DfC28HmUdm0scE16nyKFecihfzocnxp965nj+
c5bO4+On/vSI67Y+pR3qJYfydjyf7XyuG+7Ycf5T53Na26Fecijvz4dfVDt2
nuwbnpPJoV5yKG/XY3w/knXsOo3vU8ihXnIob/tIb73o40sOXv5otWP3yd3e
8qVz37LtMelQLzmUt32k737uLf/z2jvqHZsLbbnswSe2bZcnh3rJobx/Hnis
2nFzoXlbpEO95FDe9pGGHg85NheKx0kO9ZJDedtHiudD1rG5UDxPyKFecihP
85CsQ3MScqg3O7eZK4fyO9qh+Uw5X9s/NyTH8i+7Yp/P/OpL8f7Q8XNM0Rsd
yvfPZ4Y7ll//8X8+5B2v18ejeqPTm8c5T9KZ+e+sHdXb+fWe+Vjn3CnhWP6o
H/z1h3/vnT+WjuqNDuVpPpN1LH/Fv91w+6KL4vvTtqN6o0P53vlMwrE9pdce
d9763f9wSjrUSw7laT6Tdfye0pR0qJccytN8Juv4PaUp6VAvOZSn+UzW8XtK
U9KhXnIoT/OZrOP3lKakQ73kUJ7mM1nH7ylNSYd6yaE8zWeyjt1nYp4c6iWH
8jSfyTolNz1+Edz/o9Pf23Yo3z+fGe5Y/qBzLuh4/W07qjc6/Xma82Sd6fEF
+13+iWWn6+NRvd0Oz8e6507DHcu/6e4bOp4/247qjQ7laT6TdSz/4s7n/7aj
eqNDeZrPZB3Lx+uUHNVL942Yp/lM1vH59v5YdIb1tve1Yr5/PjPc8XtKdPzT
spccytN8Juv4PaVp6VAvOZSn+UzW8XtK09KhXnIoT/OZrLMSfk+BHOolh/I0
D8k6Jdeek5Cj5jBD83PlUH6uHJt33XvGA984d/ruma/7fYw1Lf+Bd26evnTz
vdKx98Vvvvjw2zaed6d0qJccyts+zPqPnrjqK+u+VO3YXOLkQ97z5PJLb5YO
9ZJD+XIcM79PN29WzuRwh3rJobwdzz3leMZrHTvOk8pxSod6yaG8nQ/l56G3
Vzt2nhxfzhPpUC85lA/XY7Vj1+lUuU6lQ73kUL58f+dPTL7i0AM2rPlutWNz
oYn3/fv6c7beJx3qJYfyto90zN+c++hVB3y/2rG50P0nrXpo27b7pEO95FC+
uaya62tdtePnQhukQ73kUN72kd4w8HjIsblQPE5yqJccyhd363g8H7KOvS+I
5wk51EsO5W0fYH24HrOOvS+L1yk51EsO5W0fY+SZ41pT7dj74lPDfZIc6iWH
8rYPMxVej7KOzSUuCK9T5FAvOZQv58MT4x9atc9xR6+4/tWzcx4f/+Rtzzt/
v71fII+HesmhvB3PXZ3PdcMdO84/f1XXc1rboV5yKG/nw3R5Hqh27Dw5Kjwn
k0O95FDersf4fiTr2HUa36eQQ73kUN72kd5f7ofVTrhPSod6yaG87SMdXV6P
qp3n+9cp6VAvOZQPzwPVjp8LbZAO9ZJDedtHesPA4yFnnX9Okw71kkN520f6
YDgfss4e/jlZOtRLDuXt/cj6cD1mnfA+RTrUSw7laZ6TdWjOoxzqJSd+neYz
5Xxt/9yQHMt/44wV7/nFD++RjuqNDuX75zPDHcvf+ZEND7/izWulo3qj05vH
OU/S+fXfiZKO6u38es98rHPulHAsf0c5Tumo3uhQnuYzWcfya8t5Ih3VGx3K
985nEo7tKZ15wnNev+HPHpAO9ZJDeZrPZJ2wpyQd6iWH8jSfyTphT0k61EsO
5Wk+k3XCnpJ0qJccytN8JuuEPSXpUC85lKf5TNYJe0rSoV5yKE/zmaxj95mY
J4d6yaE8zWeyTslNj2+C+390+nvbDuX75zPDHcvvu9+3O15/247qjU5/nuY8
WWd6/KfXHHT6m6+5aeC/i3u7HZ6Pdc+dhjuW/+YHP9Lx/Nl2VG90KE/zmaxj
+VWdz/9tR/VGh/I0n8k6lo/XKTmql+4bMU/zmawT8tIZ2CuPs38+M9zxe0p4
/LKXHMrTfCbr+D2lKelQLzmUp/lM1vF7SlPSoV5yKE/zmayzEn5PgRzqJYfy
NJ/JOiXXnpOQQ73kUF7Nc2bbq5yhveHvxszcx8LfwxmPfrMnP64ce198bdlL
lw71kkP58PeIqp3we2HSoV5yKF+OY+b36WbnTA53qJccytvxNH8PodoJvxcp
Heolh/Lh76FVO+H3UqVDveRQPvwecbUT9jmlQ73kUL58f2d+H7zaGfN7udKh
XnIof4z/ffxq50G/Fy0d6iWH8uU8mPl7CNWOnwttkQ71kkP5U/zfo6h2Jvzv
BUiHesmhfHG3jsfzIeuE38uQDvWSQ/nw91iqnfB7MdKhXnIo7z+P75Fqx94X
7x/uk+RQLzmUt32YFeH1KOvYXOLe8DpFDvWSQ/lyHE+Mz3/m/382S+fx8bt2
PvEl5w9wqJccytvxfL3zuW64Y8d5cedzWtuhXnIob+fDgmd6Nlc7dp5cF56T
yaFecihv12N8P5J1wu8FS4d6yaG87SO9pvw9wGon/F62dKiXHMrbPtIJ5e8x
VjvP978XLx3qJYfy/nmg3vFzoY3SoV5yKH+0/3uk1c46/3chpEO95FDe9pHG
w/mQdfbwf5dDOtRLDuXt/cgl4XrMOjQnIYd61dwm5mmek3Uon50jZR2az5Tz
tf1zQ3Is/+nydxKko3qjQ/n++cxwx/LN3ymSjuqNTm8e5zxJ59d/J2rYv6un
t/PrPfOxzrlTwrH8veXvdElH9UaH8jSfyTqWX17+ToJ0VG90KN87n0k4tqd0
4j3/OrplQ3y/33aolxzK03wm64TP6ZMO9ZJDeZrPZJ3wOX3SoV5yKE/zmawT
PqdPOtRLDuVpPpN1wuf0SYd6yaE8zWeyTvicPulQLzmUp/lM1rH7TMyTQ73k
UJ7mM1nHcq+A+390+nvbDuX75zPDHcu//fAvd7z+th3VG53+PM15ss70+Afe
deM/nvM6fTyqt9vh+Vj33Gm4Y/kjT1rR8fzZdlRvdChP85msY/kvdD7/tx3V
Gx3K03wm61g+XqfkqF66b8Q8zWeyjs+398eiM6y3va8V8/3zmeFO2FOSDvWS
Q3maz2SdsKckHeolh/I0n8k6YU9JOtRLDuVpPpN1VsLvKZBDveRQnuYhWafk
2nMSctQcZmh+rhzKz5Vj8y6b39vX/T7G1pZv90vl2Ptiuz8ph3rJobztw5zc
zMVrHZtL7Nvcn5RDveRQvhzHzO/TTczKmRzuUC85lLfjsb2MWseO86Hm/qQc
6iWH8u58mJxf7dh5Yvcn5VAvOZS369H+v9YJn2cqHeolh/J2HHZctY7Nhex4
lUO95FDezgM7L2odmwvZ+aIc6iWH8nZd2XVZ67i50KR2qJccyts+0tDjIcfm
QvE4yaFecihfjmPreDwfsk74XHLpUC85lLfngHg9Zp3wufDSoV5yKO/2kba/
Dycde188Fu6T5FAvOZS3fZj4epR1bC7xk/A6RQ71kkP5cj48MXNdzs55fPwd
I9dfOjHAoV5yKG/Hc0rnc91wx47ztZ3PaW2HesmhvJ0P85vrstax8+Se8JxM
DvWSQ3m7HuP7kaxj12l8n0IO9ZJDedtHsuOqdew+acerHOolh/K2j2TnRa1j
cyE7X5RDveRQ3j8P1Dt+LvS4dKiXHMrbPtLQ4yHH5kLxOMmhXnIob/tI8XzI
Ovb+JJ4n5FAvOZSneUjWoTkJOdSbndvMlUP5He3QfKacr+2fG5Jj+Tubn5cq
R/VGh/L985nhjuVfdFb5ebVyVG90evM450k6v/47UdJRvZ1f75mPdc6dEo7l
373m/mfm5cpRvdGhPM1nso7lL2/m5cpRvdGhfO98JuHYnpL9v3KolxzK03wm
6/g9pRHpUC85lKf5TNbxe0oj0qFecihP85ms4/eURqRDveRQnuYzWcfvKY1I
h3rJoTzNZ7KO31MakQ71kkN5ms9kHcvFPDnUSw7laT6TdUpuevwzcP+PTn9v
26F8/3xmuGP5G3+76/W37aje6PTnac6TdabHx28+4b5XXqUd1dvt8Hyse+40
3LH81b9zTMfzZ9tRvdGhPM1nso7l13U+/7cd1RsdytN8JutYPl6n5Kheum/E
PM1nso7Pt/fHojOst72vFfP985nhTvicPulQLzmUp/lM1gmf0ycd6iWH8jSf
yTrhc/qkQ73kUJ7mM1lnJfyeAjnUSw7laR6Sdez6jHly1BxmaH6uHMrPlWPz
rrePnvqin0/tNHMf8/sYi1rvE7/2xY1vve7WX9/3yLHn0c1X/+/vvPfF2qFe
cihvP4f+hz0f/s1XvuJZ1Y69H9jj/Xud9t+P0w71kkP58n2yec7Os3MmhzvU
Sw7l/T5SvePnQtqhXnIo78+HxdWOnwtph3rJobzfR9ql2vFzoSXSoV5yKF+O
w/aR6h0/F1oiHeolh/J+H6ne8XOhJdKhXnIoX64rez5ZUu34uZB2qJccyvt9
JH085Pi5kD4e6iWH8uU4bB+p3vFzIf3vol5yKO/3keodPxdaIh3qJYfyfh9p
cbXj50LaoV5yKO/3kXaudvxcSDvUSw7ly/lg88nZOjYX0g71kkN5O54vdj7X
DXfsOPfqfE5rO9RLDuX9+bCo2rHz5KHwnEwO9ZJDebse4/uRrGPXaXyfQg71
kkN520e6+0sH/8WmP6137D553rc+d9ixk+15V3SolxzK2z7S2AHHvma/36x3
bC40ctMFC+ZNtuds0aFecijvnwfqHTcX2i5PDvWSQ3nbRxp6POTYXCgeJznU
Sw7lbR8png9Zx+ZC8Twhh3rJoTzNQ7IOzUnIod7s3GauHMrvaIfmM+X8bv/c
kBzL/enyn/zD+S+M94eOn2OK3uhQvn8+M9yx/CUH//bbjnyTPh7VG53ePM55
ks7Mf2ftqN7Or/fMxzrnTgnH8mVPabF0VG90KE/zmaxj+bKnFN+fth3VGx3K
985nEo7fU9IO9ZJDeZrPZB2/p7RUOtRLDuVpPpN1/J7SUulQLzmUp/lM1vF7
SkulQ73kUJ7mM1nH7yktlQ71kkN5ms9kHb+ntFQ61EsO5Wk+k3XsPhPz5FAv
OZSn+UzWKTnbU2rf/6PT39t2KN8/nxnuWL7sKenjUb3R6c/TnCfr2J6SdlRv
t8Pzse6503DH8t+5bJ+O58+2o3qjQ3maz2Qdy5/R+fzfdlRvdChP85msY/l4
nZKjeum+EfM0n8k6Pq+dYb36OPvnM8Mdv6ekHeolh/I0n8k6fk9JO9RLDuVp
PpN1/J6SdqiXHMrTfCbrrITfUyCHesmhPM1Dso7lYp4cNYcZmp8rh/Jz5fh5
17Nnvu73MXYFf6l0/FxIO9RLDuX9PtJzqh0/F9IO9ZJD+fJ9snnObrNzJoc7
1EsO5e149jn7o784+ZR6x47z0dUP3/GG47VDveRQ3p0Pq+sdO08u2H/fsdsf
0g71kkN5ux7veuzOM/7qObtXO3adrrj6omOuXaEd6iWH8uX7O3/iUy/cdOuF
R9Y7Nhc67LnXv+X7t2iHesmhvO0jPXraG0/afHa9Y3Ohp/b+8lPbbtEO9ZJD
+XJd2fNMvePmQqu1Q73kUN72kYYeDzk2F4rHSQ71kkP5cjhbx+P5kHXsfUE8
T8ihXnIob/sA8XrMOva+LF6n5FAvOZR3+xjb34eTjr0vjvdJcqiXHMrbPsyL
w+tR1rG5xGPhdYoc6iWH8uV8sPnkbJ3Hxw9c8MbXvWCAQ73kUN7vI8Xnq+GO
nwtph3rJobzfR9q12vFzIe1QLzmU9/tIz652/FyoPWeODvWSQ3m/j1Tv+LkQ
zbuWyl5yKO/3keodPxeiOdtS2UsO5d3zwLx6x8+FlkqHesmhvN9Hqnf8XGip
dKiXHMr7faR6x8+FlkqHesmhPM1Dsg7NScih3uzcZq4cyu9oh+Yz5fxu/9yQ
HMuXPaV4f+j4OabojQ7l++czwx3Llz0lfTyqNzq9eZzzJJ2Z/87aUb2dX++Z
j3XOnRKO5Q/adOY37/22dlRvdChP85msY/k7/2PxPuNnxvdrbUf1RofyvfOZ
hGN7Spc9esPXDtmiHeolh/I0n8k6fk9pVDrUSw7laT6Tdfye0qh0qJccytN8
Juv4PaVR6VAvOZSn+UzW8XtKo9KhXnIoT/OZrOP3lEalQ73kUJ7mM1nH7jMx
Tw71kkN5ms9knZKbHr8L7v/R6e9tO5Tvn88Mdyx/wsVdr79tR/VGpz9Pc56s
Mz1+5fq/f/dn/2jov4t7ux2ej3XPnYY7li97SvH5s+2o3uhQnuYzWcfyZ3Q+
/7cd1RsdytN8JutYPl6n5Kheum/EPM1nso7Pa2dYrz7O/vnMcMfvKWmHesmh
PM1nso7fU9IO9ZJDeZrPZB2/p6Qd6iWH8jSfyTor4fcUyKFecihP85CsU3Lt
OQk5ag4zND9XDuXnyrF51/LFyy8572e/vo+5fYyJ32j5J5/w3huOf9uodOx9
8Tnf+d6Pf3+ZdqiXHMrbPsy9F5777M9+pt6xucQu46MHfuFa7VAvOZQv3yeb
5yybnTM53KFecijv95HqHT8X0g71kkN5v49U7/i5kHaolxzK+32kPaodPxfS
DvWSQ/ny/bV9pHrHz4W0Q73kUN7vI9U7fi6kHeolh/LlurLnmXrHz4W0Q73k
UN7vI9U7fi6kHeolh/LlcGwfqd7xcyHtUC85lPf7SPWOnwtph3rJobzfR1pW
7fi5kHaolxzK+32kesfPhbRDveRQvpwPNp+crWNzIe1QLzmUt+Ppfq4b7thx
jnY+p7Ud6iWH8u58mKh37Dw5Nzwnk0O95FDersf4fiTr2HUa36eQQ73kUN72
kU7bsOchZ99Y79h98isPHrvqxRPaoV5yKG/7SEsu+/yVe1xY79hcaMH6w+fP
m9AO9ZJDef88UO+4udCEdqiXHMrbPtLQ4yHH5kLxOMmhXnIob/tI8XzIOjYX
iucJOdRLDuVpHpJ1aE5CDvVm5zZz5VB+Rzs0nymnefvnhuRY/mXPe2zd6ovb
X4+O6o0O5fvnM8Mdy6/d8+LffdFLtaN6o9ObxzlP0pn576wd1dv59Z75WOfc
KeFYvuwpaUf1RofyNJ/JOpYve0rx/VrbUb3RoXzvfCbh+D0l7VAvOZSn+UzW
8XtKY9KhXnIoT/OZrOP3lMakQ73kUJ7mM1nH7ymNSYd6yaE8zWeyjt9TGpMO
9ZJDeZrPZB2/pzQmHeolh/I0n8k6dp+JeXKolxzK03wm65Sc7Snp4+nvbTuU
75/PDHcsX/aUtKN6o9OfpzlP1rE9paH/Lu7tdng+1j13Gu5YfvMdl3Q8f7Yd
1RsdytN8JutY/qDO5/+2o3qjQ3maz2Qdy8frlBzVS/eNmKf5TNbxee0M69XH
2T+fGe74PSXtUC85lKf5TNbxe0raoV5yKE/zmazj95S0Q73kUJ7mM1lnJfye
AjnUSw7laR6SdUquPSchR81hhubnyqH8XDn2eTnNzw1X29ftc4Ceia9ettr7
S+x94mrl2N9jbZ6LpEO95FDePoep2Yepduzv4TbPRdKhXnIoX75PS5rv1yyd
yeEO9ZJDeTue5udx1Y4d55LyXCQd6iWH8u58mKh37Dxp5qLSoV5yKG/XYzPH
rnbsOm3uJ9KhXnIoX76/i+3nEdWO/T3i5nVBOtRLDuXtc7CanwdVOw82f4+4
eV2WDvWSQ/lyXe1czofJeqfMhRpnQjvUSw7l7XOwhh4POS9o/h5xPE5yqJcc
ypfjWNQ6H7KO/T3ieJ6QQ73kUN4+PyZej1nH/o5nvE7JoV5yKG+fAxTvh1nH
/h5rvE+SQ73kUN4+h2ldeD3KOvb3cHcJr1PkUC85lC/X406t1/cq5+n8N7Z+
/uYHtunjoV5yKG/H0/08Ntyx4/xp13Nah0O95FDenQ+r6x07Tz4WnpPJoV5y
KG/XY3w/knXsOo3vU8ihXnIob/fDZh+12rH7ZPNzAelQLzmUt89Bb/aBq53d
mtep5ucy0qFecijvnwfqnTIXapzV2qFecih/dPM8NvR4yFnXPKfF4ySHesmh
fNlHWtw6H7KOfR5VPE/IoV5yKE/zkKxDcxJyqDc7t5krh/I72qH5TDnPlzav
s2PSsXyzpyEd1RsdyvfPZ4Y7lm/2ZKSjeqPTm8c5T9KZ+e888N/V09v59Z75
WOfcKeFYvtkTk47qjQ7laT6TdSzf7OlJR/VGh/K985mEY5/P985djnnVrTtr
h3rJoTzNZ7LOp5vPxyrHqx3qJYfyNJ/JOmVPaXErTw71kkN5ms9knbKntHMr
Tw71kkN5ms9kndufXz6fNebJoV5yKE/zmazzrubzsWKeHOolh/I0n8k6dp+J
eXKolxzK03wm65TcyMRyuP9Hp7+37VC+fz4z3LH8NWd2vf62HdUbnd48znmS
ztP5t+593CdOvm7gv6unt9PpmY91zp0SjuXHDjyj4/mz7aje6FCe5jNZx/Jr
O5//247qjQ7le+czCcfy8TolR/XSfSPme+c8Ccfnx6QzrHdM5vvnM8Ode/Z8
3navU3T8Y7KXHMrTfCbrlD2lnVt5cqiXHMrTfCbrlD2lxa08OdRLDuVpPpN1
Vrrn5DHpUC85lKd5SNYpufachBw1hxmanyuH8nPl+HnX7jNf9/tIu4G/u3T8
XEg71EsO5f0+Ur3j50LaoV5yKF++TzbPmaUzOdyhXnIob8fTfB5itWPH2fxd
eulQLzmUd+fD5K7Vjp0nzd8FlQ71kkN5ux6bz3Goduw6bf6ennSolxzKl+NY
bJ/HUe3YXKj5u4jSoV5yKG/7SM3noVQ7Nhdq/i6ldKiXHMqX68qeT+odNxfa
Lk8O9ZJDedtHGno85NhcKB4nOdRLDuWLu6h1PmQde18QzxNyqJccyts+QLwe
s469L4vXKTnUSw7l3T7GdvfDrGPvizeH+yQ51EsO5W0fJr4eZR2bSywLr1Pk
UC85lC/Xoc0nd5ud83T+8iePPf2Wbfp4qJccyvt9pHrHz4W0Q73kUN7vI9U7
fi6kHeolh/J+H2n3asfPhbRDveRQ3u6HzeexVjt+LqQd6iWH8n4fqd7xcyHt
UC85lHfPA5P1jp8LaYd6yaG830eqd/xcSDvUSw7l/T5SvePnQtqhXnIoT/OQ
rENzEnKoNzu3mSuH8jvaoflMOc/bPzckx/LN55RJR/VGh/L985nhjuWbz4mT
juqNTm8e5zxJZ+a/88B/V09v59d75mOdc6eEY/nmcxKlo3qjQ3maz2Qdy7+j
fE6NdFRvdCjfO59JOLan9O1lK8798O7aoV5yKE/zmazj95S0Q73kUJ7mM1nH
7ylph3rJoTzNZ7KO31PSDvWSQ3maz2Qdv6ekHeolh/I0n8k6fk9JO9RLDuVp
PpN17D4T8+RQLzmUp/lM1im5kYlT4f4fnf7etkP5/vnMcMfyR93f9frbdlRv
dHrzOOdJOk/nv/q6q/e67U3aUb2dTs98rHPulHAsX/aUtKN6o0N5ms9kHcuv
7Xz+bzuqNzqU753PJBzLx+uUHNVL942Y753zJByfb++PRWdYL+1rDZ3PDHf8
nhId/6jsJYfyNJ/JOn5PaVQ61EsO5Wk+k3X8ntKodKiXHMrTfCbrrITfUyCH
esmhPM1Dsk5zfbby5Kg5zND8XDmUnyvH5l3N/8983e9jLG75zf9Lx94XN+/P
pEO95FDe9mGavYBqx+YSD5XrQzrUSw7ly/fJ5jmzdCaHO9RLDuX9PtKzqh0/
F9IO9ZJDeX8+LKp2/FxIO9RLDuX9PtJO1Y6fC41Ih3rJoXxzHTb7GPWOnwuN
SId6yaG830eqd/xcaEQ61EsO5Zvrqrm+6h0/FxqRDvWSQ3m/j1Tv+LnQiHSo
lxzKN9dh63zIOn4uNCId6iWH8n4fqd7xc6ER6VAvOZT3+0iLqh0/F9IO9ZJD
eb+P9Kxqx8+FtEO95FC+uQ5br+9VzsxcSB8P9ZJDeTueozufx4Y7dpwbup7T
OhzqJYfy/nxYXO3YebJHeE4mh3rJobxdj/H9SNax6zS+TyGHesmhvN0Pm+ey
asfuk83zmnSolxzK2z5S81xc7dhcqHlelg71kkN5/zywpNpxc6FJ7VAvOZS3
faShx0OOzYXicZJDveRQ3vaR4vmQdWwuFM8TcqiXHMrTPCTr0JyEHOrNzm3m
yqH8jnZoPlPO7/bPDcmxfLMvIB3VGx3K989nhjuWf/ea+//vvFY6qjc6vXmc
8ySdmf/O2lG9nV/vmY91zp0SjuXLntIi6aje6FCe5jNZx/JlTynOB9qO6o0O
5XvnMwnH7ylph3rJoTzNZ7KO31PSDvWSQ3maz2Qdv6ekHeolh/I0n8k6fk9J
O9RLDuVpPpN1/J6SdqiXHMrTfCbr+D0l7VAvOZSn+UzWsftMzJNDveRQnuYz
WafJNXtK7ft/dPp72w7l++czwx3Llz0lfTyqNzq9eZzzJJ2ZPSXtqN5Op2c+
1jl3SjiWf+lp6zqeP9uO6o0O5Wk+k3Usf2nn83/bUb3RoXzvfCbhWD5ep+So
XrpvxHzvnCfh+Hx7fyw6w3rb+1ox3z+fGe74PSU6/qWylxzK03wm6/g9paXS
oV5yKE/zmazj95SWSod6yaE8zWeyzkr4PQVyqJccytM8JOs0uVaeHDWHGZqf
K4fyc+X4edeCma/7fYz54C+Ujp8LaYd6yaG830eaV+34uZB2qJccypfvk81z
ZulMDneolxzK2/GccvD6l7/v7KduqXXsOPctn08rHeolh/LufJi3tdqx86T5
fGDpUC85lLfrce1ea47c+NUnqx27TpvPZ5YO9ZJD+fL9XTxx5XvP+uWaO5+o
dmwu1Hw+tnSolxzK2z7S/ieu+uDxB9Y7NhdqPp9cOtRLDuXLeWDPJ/WOmwtt
lyeHesmhvO0jDT0ecmwuFI+THOolh/LlfFjUOh+yjr0viOcJOdRLDuVtHyBe
j1nH3pfF65Qc6iWH8m4fY7v7Ydax98XfDfdJcqiXHMrbPszJ4fUo69hcYp/w
OkUO9ZJD+XIcO01sK/+bnfN0fvmWz93z/gEO9ZJDeb+PFJ+jhjt+LqQd6iWH
8n4faX614+dC2qFecijv95EWVDt+LrRQOtRLDuXtfliey+odPxdaKB3qJYfy
fh+p3vFzoYXSoV5yKO+fBxZWO34upB3qJYfyfh9JHw85fi6kj4d6yaG830eq
d/xcSP+7qJccytM8JOvQnIQc6s3ObebKofyOdmg+U87v9s8NybF82ReI94e2
o3qjQ/n++cxwx/JlT0kfj+qNTm8e5zxJZ+a/s3ZUb+fXe+ZjnXOnhGP5fc46
7NZP3fQr6aje6FCe5jNZx/J3nbrulIVHxPlA21G90aF873wm4die0t+95NUP
7/zCaelQLzmUp/lM1vF7StPSoV5yKE/zmazj95SmpUO95FCe5jNZx+8pTUuH
esmhPM1nso7fU5qWDvWSQ3maz2Qdv6c0LR3qJYfyNJ/JOnafiXlyqJccytN8
JuuU3MjE7XD/j05/b9uhfP98Zrhj+Su+fHjH62/bUb3R6c3jnCfpPJ0//5NH
vvZjN+vjUb2dTs98rHPulHAsX/aU4vNn21G90aE8zWeyjuUv7Xz+bzuqNzqU
753PJBzLx+uUHNVL942Y753zJByfb++PRWdYL+1rDZ3PDHf8nhId/4jsJYfy
NJ/JOn5PaUQ61EsO5Wk+k3X8ntKIdKiXHMrTfCbrrITfUyCHesmhPM1Dsk7J
teck5Kg5zND8XDmUnyvH5l0H3Xfwjb/1B7+cuY/5fYxHWu8Tz/v0K//gqr94
7Bbl2Pvi/b74+T/5L1/QDvWSQ3nbh1mxZu+1F1z482rH5hL3LPyn3/mvJ2iH
esmhfDkOm+f8bHbO5HCHesmhvB3PbWfedPqDm35S7dhx/vH0xVf+j6Melg71
kkN5fz5srnbsPPlfV1x/9O0rH5QO9ZJDebseL33txy//2of+T7Vj1+lud3zs
Qzfv8kPpUC85lC/f38UTEz/8wYMXX/GjasfmQlOH/83o4fM3Sod6yaG87SP9
yZcO2+m60zZVOzYXGr37gF3mzdsoHeolh/LlPLDnk3rHz4U2Sod6yaG87SMN
PR5ybC4Uj5Mc6iWH8uV8WNQ6H7KOvS+I5wk51EsO5W0f4JJwPWYde18Wr1Ny
qJccyts+RlmH+XG1Y++Lrwn3SXKolxzK2z7M18LrUdaxucQx4XWKHOolh/Ll
utpp4qlnjuc/Z+c8nT/1p0dct/Up7VAvOZS34/ls5/PYcMeO85+6ntM6HOol
h/L+fPhFtWPnyb7hOZkc6iWH8nY9xvcjWceu0/g+hRzqJYfydj9860UfX3Lw
8kerHbtP7vaWL537lm2PSYd6yaG87SN993Nv+Z/X3lHv2Fxoy2UPPrFtuzw5
1EsO5f3zwGPVjpsLzdsiHeolh/K2jzT0eMixuVA8TnKolxzK2z5SPB+yjs2F
4nlCDvWSQ3mah2QdmpOQQ73Zuc1cOZTf0Q7NZ8r52v65ITmWf9kV+3zmV1+K
94e2o3qjQ/n++cxwx/LrP/7Ph7zj9fp4VG90evM450k6M/+dtaN6O7/eMx/r
nDslHMsf9YO//vDvvfPH0lG90aE8zWeyjuWv+Lcbbl90UZwPtB3VGx3K985n
Eo7tKb32uPPW7/6HU9KhXnIoT/OZrOP3lKakQ73kUJ7mM1nH7ylNSYd6yaE8
zWeyjt9TmpIO9ZJDeZrPZB2/pzQlHeolh/I0n8k6fk9pSjrUSw7laT6Tdew+
E/PkUC85lKf5TNYpuZGJi+D+H53+3rZD+f75zHDH8gedc0HH62/bUb3R6c3j
nCfpPJ1fsN/ln1h2uj4e1dvp9MzHOudOCcfyb7r7ho7nz7ajeqNDeZrPZB3L
v7jz+b/tqN7oUL53PpNwLB+vU3JUL903Yr53zpNwfL69PxadYb3tfa2Y75/P
DHf8nhId/7TsJYfyNJ/JOn5PaVo61EsO5Wk+k3X8ntK0dKiXHMrTfCbrrITf
UyCHesmhPM1Dsk7Jteck5Kg5zND8XDmUnyvH5l33nvHAN86dvnvm634fY03L
f+Cdm6cv3XyvdOx98ZsvPvy2jefdKR3qJYfytg+z/qMnrvrKui9VOzaXOPmQ
9zy5/NKbpUO95FC+HMfM79PNm5UzOdyhXnIob8dzTzme8VrHjvOkcpzSoV5y
KG/nQ/l56O3Vjp0nx5fzRDrUSw7lw/VY7dh1OlWuU+lQLzmUL9/fxROTrzj0
gA1rvlvt2Fxo4n3/vv6crfdJh3rJobztIx3zN+c+etUB3692bC50/0mrHtq2
7T7pUC85lC9XlT2frKt2/Fxog3SolxzK2z7SGwYeDzk2F4rHSQ71kkP5cj4s
ap0PWcfeF8TzhBzqJYfytg+wPlyPWcfel8XrlBzqJYfyto8x8syBral27H3x
qeE+SQ71kkN524eZCq9HWcfmEheE1ylyqJccypfraqeJD63a57ijV1z/6lk5
T+c/edvzzt9v7xfI46Fecihvx3NX5/PYcMeO889f1fGc1uFQLzmUt/NhujwP
VDt2nhwVnpPJoV5yKG/XY3w/knXsOo3vU8ihXnIob/fD95f7YbUT7pPSoV5y
KG/7SEeX16NqZzf/OiUd6iWH8uF5oNrxc6EN0qFecihv+0hvGHg85Kzzz2nS
oV5yKG/7SB8M50PW2cM/J0uHesmhvL0fWR+ux6wT3qdIh3rJoTzNc7IOzXmU
Q73kxK/TfKacr+2fG5Jj+W+cseI9v/jhPdJRvdGhfP98Zrhj+Ts/suHhV7x5
rXRUb3R68zjnSTq//jtR0lG9nV/vmY91zp0SjuXvKMcpHdUbHcrTfCbrWH5t
OU+ko3qjQ/ne+UzCsT2lM094zus3/NkD0qFecihP85msE/aUpEO95FCe5jNZ
J+wpSYd6yaE8zWeyTthTkg71kkN5ms9knbCnJB3qJYfyNJ/JOmFPSTrUSw7l
aT6Tdew+E/PkUC85lKf5TNYpuZGJTXD/j05/b9uhfP98Zrhj+X33+3bH62/b
Ub3R6c3jnCfpPJ3/6TUHnf7ma24a9u/q6e10euZjnXOnhGP5b37wIx3Pn21H
9UaH8jSfyTqWX9X5/N92VG90KN87n0k4lo/XKTmql+4bMd8750k4IS+dgb3y
OPvnM8Mdv6eExy97yaE8zWeyjt9TmpIO9ZJDeZrPZB2/pzQlHeolh/I0n8k6
K+H3FMihXnIoT/OZrFNy7TkJOdRLDuXVPGe2vcoZ2hv+bszMfSz8PZzx6Dd7
8uPKsffF15a9dOlQLzmUD3+PqNoJvxcmHeolh/LlOGZ+n252zuRwh3rJobwd
T/P3EKqd8HuR0qFecigf/h5atRN+L1U61EsO5cPvEVc7YZ9TOtRLDuXL93fm
98GrnTG/lysd6iWH8sf438evdh70e9HSoV5yKF/Og5m/h1Dt+LnQFulQLzmU
/6L/exTVzgv87wVIh3rJoXw5Hxa1zoesE34vQzrUSw7lw99jqXbC78VIh3rJ
obz/PL5Hqh17X7x/uE+SQ73kUN72YVaE16OsY3OJe8PrFDnUSw7ly3HsNDE/
vL5XOU/n79r5xJecP8ChXnIob8fz9c7nseGOHefFXc9pHQ71kkN5Ox8WPFO0
udqx8+S68JxMDvWSQ3m7HuP7kawTfi9YOtRLDuXtfvia8vcAq53we9nSoV5y
KG/7SCeUv8dY7ezmfy9eOtRLDuX980C94+dCG6VDveRQ/mj/90irnXX+70JI
h3rJobztI42H8yHr7OH/Lod0qJccytv7kUvC9Zh1aE5CDvWquU3M0zwn61A+
O0fKOjSfKedr++eG5Fj+0+XvJEhH9UaH8v3zmeGO5Zu/UyQd1Rud3jzOeZLO
r/9O1LB/V09v59d75mOdc6eEY/l7y9/pko7qjQ7laT6TdSy/vPydBOmo3uhQ
vnc+k3BsT+nEe/51dMuG+H6/7VAvOZSn+UzWCZ/TJx3qJYfyNJ/JOuFz+qRD
veRQnuYzWSd8Tp90qJccytN8JuuEz+mTDvWSQ3maz2Sd8Dl90qFecihP85ms
Y/eZmCeHesmhPM1nsk7JjUy8Au7/0envbTuU75/PDHcs//bDv9zx+tt2VG90
evM450k6T+c/8K4b//Gc1+njUb2dTs98rHPulHAsf+RJKzqeP9uO6o0O5Wk+
k3Us/4XO5/+2o3qjQ/ne+UzCsXy8TslRvXTfiPneOU/C8fn2/lh0hvW297Vi
vn8+M9wJe0rSoV5yKE/zmawT9pSkQ73kUJ7mM1kn7ClJh3rJoTzNZ7LOSvg9
BXKolxzK0zwk65Rce05CjprDDM3PlUP5uXJs3rV2rzVHbvzqkzNf9/sYW1t+
8znR0rH3xd8rn8ssHeolh/K2D3Pywetf/r6zn6p2bC6xb/lcZulQLzmUL8cx
8/t0E7NyJoc71EsO5e14yl5GvWPH+VD5XGbpUC85lHfnw+T8asfOk+ZzmaVD
veRQ3q7H8v8Lqp3weabSoV5yKF+OY/FEOa56x+ZCzefSSod6yaG87SOV86Le
sblQ87nA0qFecihfLit7PllY7bi50KR2qJccyts+0tDjIcfmQvE4yaFecihf
3EWt8yHrhM8llw71kkN52weI12PWCZ8LLx3qJYfybh9pu/th1rH3xWPhPkkO
9ZJDeduHia9HWcfmEj8Jr1PkUC85lC/Xoc0nZ+k8nX/HyPWXTgxwqJccytvx
nNL5PDbcseN8bddzWodDveRQ3s6Hsg+2tdqx8+Se8JxMDvWSQ3m7HuP7kaxj
12l8n0IO9ZJDebsfXvnes3655s4nqh27T/5s1REfXTXvcelQLzmUt32k/U9c
9cHjD6x3bC60+LTn7jRvuzw51EsO5f3zQL3j50KPS4d6yaG87SMNPR5ybC4U
j5Mc6iWH8raPFM+HrGNzoXiekEO95FCe5iFZh+Yk5FBvdm4zVw7ld7RD85ly
vrZ/bkiO5e88dd0pC4+I94e2o3qjQ/n++cxwx/IvOuuwWz91kz4e1Rud3jzO
eZLOr/9OlHRUb+fXe+ZjnXOnhGP5d6+5f8WNV82XjuqNDuVpPpN1LH/5M/Py
OB9oO6o3OpTvnc8kHNtTKv+vHeolh/I0n8k6fk9pRDrUSw7laT6Tdfye0oh0
qJccytN8Juv4PaUR6VAvOZSn+UzW8XtKI9KhXnIoT/OZrOP3lEakQ73kUJ7m
M1nH7jMxTw71kkN5ms9kHct9Bu7/0envbTuU75/PDHcsf+Nvd73+th3VG53e
PM55ks7T+fGbT7jvlVdpR/V2Oj3zsc65U8Kx/NW/c0zH82fbUb3RoTzNZ7KO
5dd1Pv+3HdUbHcr3zmcSjuXjdUqO6qX7Rsz3znkSjs+398eiM6y3va8V8/3z
meFO+Jw+6VAvOZSn+UzWCZ/TJx3qJYfyNJ/JOuFz+qRDveRQnuYzWWcl/J4C
OdRLDuVpHpJ1Sq49JyFHzWGG5ufKofxcOTbvsvm9fd3vYyxqvU+0+6Vy7H3x
5ub+pBzqJYfytg9jc/Fax+YSezT3J+VQLzmUL98nm+fsPDtncrhDveRQ3u8j
1Tt+LqQd6iWH8v58WFzt+LmQdqiXHMr7faRdqh0/F1oiHeolh/J2HHZctY6f
Cy2RDvWSQ3m/j1Tv+LnQEulQLzmUt+vKrstax8+FtEO95FDe7yPp4yHHz4X0
8VAvOZQv7qLW+ZB1/FxI/7uolxzK+32kesfPhZZIh3rJobzfR1pc7fi5kHao
lxzK+32knasdPxfSDvWSQ/lyHdp8cpbOzFxIO9RLDuXteL7Y+Tw23LHj3Kvr
Oa3DoV5yKO/Ph0XVjp0nD4XnZHKolxzK2/UY349kHbtO4/sUcqiXHMrbcdhx
1Tp2fHa8yqFecihv70PsvKh1bC5k54tyqJccyvvngXrHzYW2y5NDveRQ3vaR
hh4POTYXisdJDvWSQ3nbR4rnQ9ax9yfxPCGHesmhPM1Dsg7NScih3uzcZq4c
yu9oh+Yz5fxu/9yQHMv/afPzUuWo3uhQvn8+M9yx/CUHl59XK0f1Rqc3j3Oe
pDPz31k7qrfz6z3zsc65U8KxfNlTWiwd1RsdytN8JutY/vJmXq4c1RsdyvfO
ZxKO31PSDvWSQ3maz2Qdv6e0VDrUSw7laT6Tdfye0lLpUC85lKf5TNbxe0pL
pUO95FCe5jNZx+8pLZUO9ZJDeZrPZB2/p7RUOtRLDuVpPpN1LBfz5FAvOZSn
+UzWKTnbU2rf/6PT39t2KN8/nxnuWL7sKenjUb3R6c3jnCfpzOwpaUf1djo9
87HOuVPCsfx3Ltun4/mz7aje6FCe5jNZx/JndD7/tx3VGx3K985nEo7l43VK
juql+0bM9855Eo7Pa2dYrz7O/vnMcMfvKWmHesmhPM1nso7fU9IO9ZJDeZrP
ZB2/p6Qd6iWH8jSfyTor4fcUyKFecihP85CsY9dnzJOj5jBD83PlUH6uHD/v
evbM1/0+xq7gL5WOnwtph3rJobzfR3pOtePnQtqhXnIoX75PNs/ZbXbO5HCH
esmhvB3PPmd/9Bcnn1Lv2HE+uvrhO95wvHaolxzKu/Nhdb1j58kF++87dvtD
2qFecihv1+Ndj915xl89Z/dqx67TFVdfdMy1K7RDveRQvnx/F0986oWbbr3w
yHrH3o8d9tzr3/L9W7RDveRQ3vYAHj3tjSdtPrvesbnQU3t/+altt2iHesmh
fLmu7Hmm3nFzodXaoV5yKG97AEOPhxybC8XjJId6yaF8OY5FrfMh69j7gnie
kEO95FDefn4Wr8esY88x8Tolh3rJobzbx9jufph17Hk03ifJoV5yKG8/h35x
eD3KOvZ+4LHwOkUO9ZJD+XI92nxyls7T+QMXvPF1LxjgUC85lPf7SPF5bLjj
50LaoV5yKO/3kXatdvxcSDvUSw7l/T7Ss6sdPxdqz5mjQ73kUN7uh+W46h0/
F6J511LZSw7l/T5SvePnQjRnWyp7yaG8ex6YV+/4udBS6VAvOZT3+0j1jp8L
LZUO9ZJDeb+PVO/4udBS6VAvOZSneUjWoTkJOdSbndvMlUP5He3QfKac3+2f
G5JjubKnFO8PbUf1Rofy/fOZ4Y7ly56SPh7VG53ePM55ks7Mf2ftqN7Or/fM
xzrnTgnH8gdtOvOb935bO6o3OpSn+UzWsfyd/7F4n/Ez4/vltqN6o0P53vlM
wrH9pMseveFrh2zRDvWSQ3maz2Qdv6c0Kh3qJYfyNJ/JOn5PaVQ61EsO5Wk+
k3X8ntKodKiXHMrTfCbr+D2lUelQLzmUp/lM1vF7SqPSoV5yKE/zmaxj95mY
J4d6yaE8zWeyTsmNTNwF9//o9Pe2Hcr3z2eGO5Y/4eKu19+2o3qj05vHOU/S
eTp/5fq/f/dn/2jgv6unt9PpmY91zp0SjuXLnlJ8/mw7qjc6lKf5TNax/Bmd
z/9tR/VGh/K985mEY/l4nZKjeum+EfO9c56E4/PaGdarj7N/PjPc8XtK2qFe
cihP85ms4/eUtEO95FCe5jNZx+8paYd6yaE8zWeyzkr4PQVyqJccytM8JOtY
LubJUXOYofm5cig/V47Nu5YvXn7JeT/79X3M7WNM/EbLP/mE995w/NtGpWPv
i8/5zvd+/PvLtEO95FDe9mHuvfDcZ3/2M/WOzSV2GR898AvXaod6yaF8+T7Z
PGfZ7JzJ4Q71kkN5v49U7/i5kHaolxzK+32kesfPhbRDveRQ3u8j7VHt+LmQ
dqiXHMqX76/tI9U7fi6kHeolh/J+H6ne8XMh7VAvOZQv15U9z9Q7fi6kHeol
h/J+H6ne8XMh7VAvOZQvx7GodT5kHT8X0g71kkN5v49U7/i5kHaolxzK+32k
ZdWOnwtph3rJobzfR6p3/FxIO9RLDuXL9WjzyVk6M3Mh7VAvOZS34+l+Hhvu
2HGOdj2ndTjUSw7l3fkwUe/YeXJueE4mh3rJobxdj/H9SNax6zS+TyGHesmh
vN0PT9uw5yFn31jv2H3yKw8eu+rFE9qhXnIob/tISy77/JV7XFjv2FxowfrD
58+b0A71kkN5/zxQ77i50IR2qJccyts+0tDjIcfmQvE4yaFecihv+0jxfMg6
NheK5wk51EsO5WkeknVoTkIO9WbnNnPlUH5HOzSfKed5++eG5Fj+Zc97bN3q
i9tfj47qjQ7l++czwx3Lr93z4t990Uu1o3qj05vHOU/SmfnvrB3V2/n1nvlY
59wp4Vi+7ClpR/VGh/I0n8k6li97SvH9cttRvdGhfO98JuH4PSXtUC85lKf5
TNbxe0pj0qFecihP85ms4/eUxqRDveRQnuYzWcfvKY1Jh3rJoTzNZ7KO31Ma
kw71kkN5ms9kHb+nNCYd6iWH8jSfyTp2n4l5cqiXHMrTfCbrlJztKenj6e9t
O5Tvn88Mdyxf9pS0o3qj05vHOU/SmdlTGvjv6untdHrmY51zp4Rj+c13XNLx
/Nl2VG90KE/zmaxj+YM6n//bjuqNDuV75zMJx/LxOiVH9dJ9I+Z75zwJx+e1
M6xXH2f/fGa44/eUtEO95FCe5jNZx+8paYd6yaE8zWeyjt9T0g71kkN5ms9k
nZXwewrkUC85lKd5SNYpufachBw1hxmanyuH8nPl2N9raH5uuNq+bn+H4pn4
6mUzX7f9+OY5bbVy7PcBmuci6VAvOZS3vwPS7MNUO/b7GM1zkXSolxzKP3Mc
k83xzJuls3q4Q73kUN6Op/l5XLVjx7mkPBdJh3rJobw7HybqHTtPmrmodKiX
HMrb9djMsasdu06b+4l0qJccypfv727284hqx34fpnldkA71kkN5+ztozc+D
qp1fNr8P07wuS4d6yaF8ua52K+fDZL2z6fvfvHZPcya0Q73kUN7+DsvQ4yHn
Bc3vw8TjJId6yaF8OY5dW+dD1rHfh4nnCTnUSw7l7e8XxOsx69geebxOyaFe
cihvf4ci3g+zjv0+QLxPkkO95FDe/g7IuvB6lHXs9zF2Ca9T5FAvOZQv1+Oz
W6/vVc7T+W9s/fzND2zTx0O95FDejqf7uW64Y8f5087ntLZDveRQ3p0Pq+sd
O08+Fp6TyaFecihv12N8P5J17DqN71PIoV5yKG/3w2Yftdqx+2TzcwHpUC85
lLe/w9vsA1c7uzWvU83PZaRDveRQ3j8P1DufGNnjhBeas1o71EsO5e15bOjx
kPOT5jktHic51EsO5Yu7W+t8yDofa56T43lCDvWSQ3mah2QdmpOQQ73Zuc1c
OZTf0Q7NZ8p5Ptq8zo5Jx/LNnoZ0VG90KN87n0k4lm/2ZKSjeqPTm6c5T9aZ
+e888N/V09v59Z75WOfcKeFYvtkTk47qjQ7laT6TdSzf7OlJR/VGh/K985mE
Y38f6p27HPOqW3fWDvWSQ3maz2Qd+/tczfFKh3rJoTzNZ7LOv/w/73nm77PE
PDnUSw7laT6TdW5fd+jI3ce08+RQLzmUp/lM1il7Sru28uRgLziUp/lM1nlX
8/dZWscPDvWSQ3maz2Qdu8/EPDnUSw7laT6TdUpu6cRyuP9Hp7+37VC+fz4z
3LH8NWd2vf62HdUbnd48znmSztP5t+593CdOvm7gv6unt9PpmY91zp0SjuXH
Djyj4/mz7aje6FCe5jNZx/JrO5//247qjQ7le+czCcfy8TolR/XSfSPme+c8
Ccfnx6QzrHdM5vvnM8Odsqe0qzj+MdlLDuVpPpN1pl9+xs1H/vFurTw51EsO
5Wk+k3V+7z/O2u45bUw61EsO5Wk+k3W+5Z6Tx6RDveRQnuYhWae5Plt5ctQc
Zmh+rhzKz5Xj5127z3zd7yPtBv7u0vFzIe1QLzmU9/tI9Y6fC2mHesmh/DPH
MbOPNEtn9XCHesmhvB1P83OJaseOs/m79NKhXnIo786HyV2rHTtPmtdn6VAv
OZS367H5uVy1Y9dp83wkHeolh/LNdWifx1Ht2FyoeT6VDvWSQ3n7eVDzc+lq
x+ZCzfsD6VAvOZRvrqvm+qp33Fxouzw51EsO5W0faejxkGNzoXic5FAvOZRv
rsPW+ZB17H1BPE/IoV5yKG/7APF6zDr2vixep+RQLzmUd/sY290Ps469L94c
7pPkUC85lLd9mPh6lHVsLrEsvE6RQ73kUL65Dluv71XO0/nLnzz29Fu26eOh
XnIo7/eR6h0/F9IO9ZJDeb+PVO/4uZB2qJccyvt9pN2rHT8X0g71kkN5ux82
z2XVjp8LaYd6yaG830eqd/xcSDvUSw7l3fPAZL3j50LaoV5yKO/3keodPxfS
DvWSQ/nmOmydD1nHz4W0Q73kUJ7mIVmH5iTkUG92bjNXDuV3tEPzmXKet39u
SI7lm30B6aje6FC+dz6TcCzffE6cdFRvdHrzNOfJOjP/nQf+u3p6O7/eMx/r
nDslHMs3n5MoHdUbHcrTfCbrWP4dZV9AOqo3OpTvnc8kHNtT+vayFed+eHft
UC85lKf5TNbxe0raoV5yKE/zmazj95S0Q73kUJ7mM1nH7ylph3rJoTzNZ7KO
31PSDvaCQ3maz2Qdv6ekHeolh/I0n8k6dp+JeXKolxzK03wm6zS5iVPh/h+d
/t62Q/n++cxwx/JH3d/1+tt2VG90evM450k6T+e/+rqr97rtTdpRvZ1Oz3ys
c+6UcCxf9pS0o3qjQ3maz2Qdy6/tfP5vO6o3OpTvnc8kHMvH65Qc1Uv3jZjv
nfMkHJ9v749FZ1gv7WsNnc8Md/yeEh3/qOwlh/I0n8k6fk9pVDrUSw7laT6T
dfye0qh0qJccytN8Jut8C35PgRzqJYfyNA/JOk2ulSdHzWGG5ufKofxcOTbv
av7u+8zX/T7G/1/buQfbVVX5+iQ5QEIOIRxCLJu2tBQFAdGOCBcV2XZDp1Fe
ioWGx0UBFZuX2EDTdjUGfJTAFUFiIQZzMTagfQVtHi2llh5oI+lgkCjGJARJ
h1CN4dGoPA7P3NNn7rGTMeb65lhjnh3+oerUV99vJplr7bl+e5y9p2X+7uds
uR55Lu5+PrHroVzyEC/zMN3vxar2SC/xaPp8ONdDueQhPq1D9ucEPSPtPZRL
HuL1PNJ21R7dC/keyiUP8Xo/bFvt0b2Q76Fc8hCv55G2qfboXmjQ9VAueYhP
/74yj1Tv0b3QoOuhXPIQr+eR6j26Fxp0PZRLHuLTdSWv7/Ue3QsNuh7KJQ/x
eh6p3qN7oUHXQ7nkIT55Z2T7IerRvdCg66Fc8hCv55HqPboXGnQ9lEse4vU8
0rbVHt0L+R7KJQ/xeh5pu2qP7oV8D+WSh/h0HUo/OXVinl4v5K+HcslDvKzn
iMZzXXuPrHNt4zkt91AueYjX+2FatUf2yS7mnEweyiUP8XI92ueRqEeuU/uc
Qh7KJQ/xcj/sfi90tUfuk93v53E9lEse4mUeqfu93NUe6YW634/keiiXPMTr
88D0ao/qheb7HsolD/FyHmu7HvJIL2TXSR7KJQ/x496x87DdD1GP9EJ2n5CH
cslDPPUhUQ/1JOSh3Ghv0y8P8VvbQ/1M2t/5+4bkEb77fVmux8u1HuKL/UzA
I/wZSx/4n+8rcD1ervUUeep5op7e37Pv8XIbf17oxxp7p4BH+DSntK3r8XKt
h3jqZ6Ie4dOcku0Hco+Xaz3EF/uZgEfPKfkeyiUP8dTPRD16Tsn3UC55iKd+
JurRc0q+h3LJQzz1M1GPnlPyPZRLHuKpn4l69JyS78Fc8BBP/UzUo+eUfA/l
kod46meiHrnPWJ48lEse4qmfiXoSJ3NK+f3fesq5uYf4cj/T3iN8mlPy1+Pl
Wk+Rx54n6OnNKfkeL7fRU+jHGnungEf4N526quH8mXu8XOshnvqZqEf4BY3n
/9zj5VoP8cV+JuAR3l6n5PFy6b5h+WLPE/BoPp8fs552ufm8luXL/Ux7j55T
ovUPubnkIZ76mahHzykNuR7KJQ/x1M9EPXpOacj1UC55iKd+JupZAb+nQB7K
JQ/x1IdEPYnLexLyeD1MW75fHuL75dF91+Tez/U8xiTwT3E9uhfyPZRLHuL1
PNJAtUf3Qr6HcslDfFqH7M8JekbaeyiXPMTLek7ef83bzvnUyz+t9cg693zx
b+798fW+h3LJQ7zaDwMvVXtkn/zm8A/e8NBRL7oeyiUP8XI9Lttt6WHr73ih
2iPX6Rc/uuSOYz//nOuhXPIQn/5VZ3auPfusp5Yuf77aI73Qk4vnXrx44DnX
Q7nkIV7eD9r7+MUXHbNvvUd6oWmnvmKbgS148lAueYhP+0Be3+s9qhfagicP
5ZKHeJlHarse8kgvZNdJHsolD/Hpfjgj2w9RjzwX2H1CHsolD/EyD2Cvx6hH
nsvsdUoeyiUP8WoeY4v7YdQjz8X3mfskeSiXPMTLPMxJ5vUo6pFeYnfzOkUe
yiUP8WkdO3Q2pf8m5hnj5zz7rZUXtPBQLnmI1/NI9pzT3qN7Id9DueQhXs8j
Tar26F7I91AueYjX80iTqz26F5rieiiXPMTL/TDNY9R7dC80xfVQLnmI1/NI
9R7dC01xPZRLHuL1eWBKtUf3Qr6HcslDvJ5H8tdDHt0L+euhXPIQP+7tzSPV
e3Qv5P+5KJc8xFMfEvVQT0Ieyo32Nv3yEL+1PdTPpP2dv29IHuHTnJK9P+Qe
L9d6iC/2MwGP8GlOyV+Pl2s9RZ56nqin9/fse7zcxp8X+rHG3ingEX73sw6+
82u3vuh6vFzrIZ76mahH+HtOWXXylLm2H8g9Xq71EF/sZwIemVP65ze+8/Gp
rxt1PZRLHuKpn4l69JzSqOuhXPIQT/1M1KPnlEZdD+WSh3jqZ6IePac06noo
lzzEUz8T9eg5pVHXg7ngIZ76mahHzymNuh7KJQ/x1M9EPXKfsTx5KJc8xFM/
E/UkbqhzF9z/raecm3uIL/cz7T3CL/zhIQ2vv7nHy7WeIo89T9Azxl/41cMO
veQ2fz1ebqOn0I819k4Bj/BpTsmeP3OPl2s9xFM/E/UIv6Dx/J97vFzrIb7Y
zwQ8wtvrlDxeLt03LF/seQIezefzY9bTLpfmtdr2M+09ek6J1j/o5pKHeOpn
oh49pzToeiiXPMRTPxP16DmlQddDueQhnvqZqGcF/J4CeSiXPMRTHxL1JC7v
Scjj9TBt+X55iO+XR/qu/e7f/5ZXveup3n1Mz2P8KXtOPP/rb3/XdZ9+5qee
R56L97r52x/68+/5HsolD/EyD7No6euXXfqlP1R7pJdYOeUHb/6reb6HcslD
fLqPyHqenJhnpL2HcslDvKxnyZm3nvbIhseqPbLOD4xece0/HP6466Fc8hCv
98PGao/sk39ZeNMRd33zEddDueQhXq7HBYdefvXPPvtf1R65Tmfefclnb9v+
IddDueQhPv37zux0HvrdI1csfLjaI73QukO+PHzIpPWuh3LJQ7y8H/Sh2w/e
5sZTN1R7pBcavnef7QcG1rseyiUP8WkfyOt7vUf3QutdD+WSh3iZR2q7HvJI
L2TXSR7KJQ/x6X44I9sPUY88F9h9Qh7KJQ/xMg9wpbkeox55LrPXKXkolzzE
yzxGGof5fbVHnotvMPdJ8lAueYiXeZifmdejqEd6iSPN6xR5KJc8xKfraofO
y+Pr+e+Jecb4U56Ye+NLL/seyiUP8bKebzSe69p7ZJ0/aDyn5R7KJQ/xej/8
sdoj+2RPc04mD+WSh3i5Hu3zSNQj16l9TiEP5ZKHeLkffviyy6fvP+fpao/c
J2eecPt5J2x6xvVQLnmIl3mk+751wj995+56j/RCz171yPObtuDJQ7nkIV6f
B56p9qheaOBZ10O55CFezmNt10Me6YXsOslDueQhflw7dh62+yHqkV7I7hPy
UC55iKc+JOqhnoQ8lBvtbfrlIX5re6ifSfs1f9+QPMK/deHu17x4u70/5B4v
13qIL/YzAY/way7/0YEff6+/Hi/Xeoo89TxRT+/v2fd4uY0/L/Rjjb1TwCP8
4b/74uf+4hO/dz1ervUQT/1M1CP8wv/4/l3bXmb7gdzj5VoP8cV+JuCROaVD
jz5/zU5/vc71UC55iKd+JurRc0rrXA/lkod46meiHj2ntM71UC55iKd+JurR
c0rrXA/lkod46meiHj2ntM71YC54iKd+JurRc0rrXA/lkod46meiHrnPWJ48
lEse4qmfiXoSN9S5DO7/1lPOzT3El/uZ9h7h9zv30obX39zj5VpPkceeJ+gZ
4yfvdfVXZp3mr8fLbfQU+rHG3ingEf7Ye7/fcP7MPV6u9RBP/UzUI/wejef/
3OPlWg/xxX4m4BHeXqfk8XLpvmH5Ys8T8Gg+nx+znna5+byW5cv9THuPnlOi
9Y+6ueQhnvqZqEfPKY26HsolD/HUz0Q9ek5p1PVQLnmIp34m6lkBv6dAHsol
D/HUh0Q9ict7EvJ4PUxbvl8e4vvlkb5r9ekP/uK80Xt7P9fzGEsz/4Of2Di6
YONq1yPPxcddcciS9ecvdz2USx7iZR5mzcXHL/7xqturPdJLnHTgJ1+Ys+A2
10O55CF+fBmbPw9qYEKekfYeyiUP8bKelWk9B9V6ZJ0npnW6HsolD/GyH9L7
oXdVe2SfHJP2ieuhXPIQb67Hao9cp+vSdep6KJc8xKd/35md+Qf85T5rl95X
7ZFeqHPOf64596X7XQ/lkod4eT/oyC+f9/R1+/y22iO90AMnLn5006b7XQ/l
kof4dFXJ6/uqao/uhda6HsolD/Eyj3RUy/WQR3ohu07yUC55iE/3wxnZfoh6
5LnA7hPyUC55iJd5gDXmeox65LnMXqfkoVzyEC/zGIPjC1ta7ZHn4lPMfZI8
lEse4mUeZp15PYp6pJe41LxOkYdyyUN8uq526Hx28e5HH7HopndOyDPGf3XJ
Ky/c6/WvcddDueQhXtZzT+O5rr1H1vn372g6p+UeyiUP8bIfRtN5oNoj++Rw
c04mD+WSh3i5Hu3zSNQj16l9TiEP5ZKHeLkfXpDuh9Uec590PZRLHuJlHumI
9HpU7ZmpX6dcD+WSh3hzHqj26F5oreuhXPIQL+exo1quhzyP6XOa66Fc8hA/
rh07D19k9kPUc4k+J7seyiUP8fI8ssZcj1GPeU5xPZRLHuKpz4l6qOfxPJRL
Hvtz6mfSfs3fNySP8L84fdEn//jQStfj5VoP8cV+JuARfvkX1j5+wHHLXI+X
az1FnnqeqGfz50S5Hi+38eeFfqyxdwp4hL87rdP1eLnWQzz1M1GP8MvSPnE9
Xq71EF/sZwIemVM6c96O7137dw+6HsolD/HUz0Q9Zk7J9VAueYinfibqMXNK
rodyyUM89TNRj5lTcj2USx7iqZ+JesyckuvBXPAQT/1M1GPmlFwP5ZKHeOpn
oh65z1iePJRLHuKpn4l6EjfU2QD3f+sp5+Ye4sv9THuP8Hvu9auG19/c4+Va
T5HHnifoGeOfuGG/04674dZ2f65CbqOn0I819k4Bj/C/vOgLDefP3OPlWg/x
1M9EPcIvbjz/5x4v13qIL/YzAY/w9jolj5dL9w3LF3uegMfwrqdlrrvOcj/T
3qPnlHD9bi55iKd+JurRc0rrXA/lkod46meiHj2ntM71UC55iKd+JupZAb+n
QB7KJQ/x1M9EPYnLexLyUC55iPf6nInmep62ueZzY3r3MfN5OAdZf3dO/iDP
I8/F30lz6a6HcslDvPk8omqP+b0w10O55CF+fBmbPw9qYp6R9h7KJQ/xsp7u
5yFUe8zvRboeyiUP8ebz0Ko95vdSXQ/lkod483vE1R4zz+l6KJc8xKd/397v
g1d7LtVzua6HcslDvPl9/GrPU3ou2vVQLnmIT/ug93kI1R7dCz3reiiXPMTf
rD+PotrzGv17Aa6HcslDfLofzsj2Q9Rjfi/D9VAueYg3n8dS7TG/F+N6KJc8
xOvv4/tTtUeei/c290nyUC55iJd5mEXm9SjqkV5itXmdIg/lkof4tI4dOpPM
63uVZ4y/Z+rxb7ywhYdyyUO8rOfnjee69h5Z5xWN57TcQ7nkIV72w+TxoI3V
HtknN5pzMnkolzzEy/Von0eiHvN7wa6HcslDvNwP350+D7DaY34v2/VQLnmI
l3mkeenzGKs9M/XvxbseyiUP8fo8UO/RvdB610O55CHefB5ptecx/bkQrody
yUP8uHbsPHyQ2Q9RzyX6czlcD+WSh3h5HrnSXI9RD/Uk5KFcr7exPPU5UQ/x
0R4p6qF+Ju3X/H1D8gj/9fQ5Ca7Hy7Ue4ov9TMAjfPdzilyPl2s9RZ56nqhn
8+dEtftzFXIbf17oxxp7p4BH+NXpc7pcj5drPcRTPxP1CD8nfU6C6/FyrYf4
Yj8T8Mic0vEr/3342bX2eT/3UC55iKd+Juox39PneiiXPMRTPxP1mO/pcz2U
Sx7iqZ+Jesz39LkeyiUP8dTPRD3me/pcD+aCh3jqZ6Ie8z19rodyyUM89TNR
j9xnLE8eyiUP8dTPRD2JG+ocAPd/6ynn5h7iy/1Me4/wHz3khw2vv7nHy7We
Io89T9Azxn/mb2/5t3Pf46/Hy230FPqxxt4p4BH+sBMXNZw/c4+Xaz3EUz8T
9Qj/vcbzf+7xcq2H+GI/E/AIb69T8ni5dN+wfLHnCXg0n8+PWU+73Hxey/Ll
fqa9x8wpuR7KJQ/x1M9EPWZOyfVQLnmIp34m6jFzSq6HcslDPPUzUc8K+D0F
8lAueYinPiTqSVzek5DH62Ha8v3yEN8vj/Rdy3Zbetj6O17o/VzPY7yU+bvf
E+165Ln4N+l7mV0P5ZKHeJmHOWn/NW8751MvV3ukl9gzfS+z66Fc8hA/vozN
nwfVmZBnpL2HcslDvKznyA3DDy/5eb1H1vlo+l5m10O55CFe7Yf5k6o9sk+6
38vseiiXPMTL9bjw8YWrZ7x6crXHfJ+p66Fc8hCf/n1ndt4yd+nnd7263iO9
UPd7aV0P5ZKHeHk/aOOKm35y38P1HumFut8L7HoolzzEp8tKXt+nVHtULzTf
91AueYiXeaS26yGP9EJ2neShXPIQn7wzsv0Q9ZjvJXc9lEse4mUewF6PUY/5
XnjXQ7nkIV7NI21xP4x65Ll4trlPkodyyUO8zMPY16OoR3qJx8zrFHkolzzE
p+tQ+skJesb4jw/etKDTwkO55CFe1nNy47muvUfWeWjjOS33UC55iJf9kObB
Xqr2yD5Zac7J5KFc8hAv16N9Hol65Dq1zynkoVzyEC/3w2vPPuuppcufr/bI
ffLJxXMvXjzwnOuhXPIQL/NIex+/+KJj9q33SC807dRXbDOwBU8eyiUP8fo8
UO/RvdBzrodyyUO8nMfaroc80gvZdZKHcslD/Lh27Dxs90PUI72Q3SfkoVzy
EE99SNRDPQl5KDfa2/TLQ/zW9lA/k/Zr/r4heYRffsqqk6fMtfeH3OPlWg/x
xX4m4BH+DWcdfOfXbvXX4+VaT5Gnnifq2fw5Ua7Hy238eaEfa+ydAh7hz1j6
wKJbrpvkerxc6yGe+pmoR/irl+98xAVrbT+Qe7xc6yG+2M8EPDKntM+jH7n4
H5/wPZRLHuKpn4l69JzSoOuhXPIQT/1M1KPnlAZdD+WSh3jqZ6IePac06Hoo
lzzEUz8T9eg5pUHXg7ngIZ76mahHzykNuh7KJQ/x1M9EPXKfsTx5KJc8xFM/
E/UkbqhzDdz/raecm3uIL/cz7T3C3/Laptff3OPlWk+Rx54n6BnjD7pt3v1v
v873eLmNnkI/1tg7BTzCX//mIxvOn7nHy7Ue4qmfiXqEX9V4/s89Xq71EF/s
ZwIe4e11Sh4vl+4bli/2PAGP5vP5Metpl5vPa1m+3M+095jv6XM9lEse4qmf
iXrM9/S5HsolD/HUz0Q95nv6XA/lkod46meinhXwewrkoVzyEE99SNSTuLwn
IY/Xw7Tl++Uhvl8e6btSf79N7z6m5zG2zZ4T0/1y832PPPJcvHH8/uR7KJc8
xMs8TOrFt6v2SC+xy/j9yfdQLnmIT+uQ/Tl1Yp6R9h7KJQ/xeh6p3qN7Id9D
ueQhXu+HadUe3Qv5HsolD/F6Hmn7ao/uhaa7HsolD/Hp31fmkeo9uhea7noo
lzzE63mkeo/uhaa7HsolD/HpupLX9+nVHt0L+R7KJQ/xeh7JXw95dC/kr4dy
yUN88s7I9kPUo3sh/89FueQhXs8j1Xt0LzTd9VAueYjX80jTqj26F/I9lEse
4vU80tRqj+6FfA/lkof4dB1KPzlBT68X8j2USx7iZT03N57r2ntknbs1ntNy
D+WSh3i9H7at9sg+edSck8lDueQhXq5H+zwS9ch1ap9TyEO55CFe7odpXfUe
uU+m9eZ9l/VQLnmIl3mktC/qPdILpf2S92zWQ7nkIV6fB+o9qhfagicP5ZKH
eDmPtV0PeaQXsuskD+WSh/hx79h52O6HqEd6IbtPyEO55CGe+pCoh3oS8lBu
tLfpl4f4re2hfibt7/x9Q/II/7Hx90vt/SH3eLnWQ3yxnwl4hL9y//95v9pf
j5drPUWeep6op/f37Hu83MafF/qxxt4p4BE+zSlNcz1ervUQT/1M1CN8mlOy
/UDu8XKth/hiPxPw6Dkl30O55CGe+pmoR88pDbkeyiUP8dTPRD16TmnI9VAu
eYinfibq0XNKQ66HcslDPPUzUY+eUxpyPZgLHuKpn4l69JzSkOuhXPIQT/1M
1CP3GcuTh3LJQzz1M1GPcNfA/d96yrm5h/hyP9PeI3yaU/LX4+VaT5HHnifo
6c0p+R4vt9FT6Mcae6eAR/hfX7V7w/kz93i51kM89TNRj/CnN57/c4+Xaz3E
F/uZgEd4e52Sx8ul+4bliz1PwKN539Mu119nuZ9p79FzSr6HcslDPPUzUY+e
U/I9lEse4qmfiXr0nJLvoVzyEE/9TNSzAn5PgTyUSx7iqQ+JehKX9yTk8XqY
tny/PMT3y6P7rh16P9fzGDPAP+R6dC/keyiXPMTreaQdqz26F/I9lEse4tM6
ZH/OnJhnpL2HcslDvKxHevFaj6zz6e79yfNQLnmIV/thpN4j+0T6Cc9DueQh
Xq5H+X+tR65T+b/noVzyEC/rkHXVemR9sl7PQ7nkIV72geyLWo/0QrJfPA/l
kod4ua7kuqz1qF5oxPdQLnmIl3mktushj/RCdp3koVzyEJ/WMSPbD1GPPBfY
fUIeyiUP8XIOsNdj1CPnA3udkodyyUO8msfY4n4Y9chzsb1PkodyyUO8zMPs
YV6Poh7pJZ4xr1PkoVzyEJ+uR+knJ+gZ4/ed/MH3vKaFh3LJQ7yeR7Lnq/Ye
3Qv5HsolD/F6HmlGtUf3Qr6HcslDvJ5H2qHao3uhvGe2HsolD/GyDllXrUf3
QtR3Dbm55CFezyPVe3QvRD3bkJtLHuLVeWCg3qN7oSHXQ7nkIV7PI9V7dC80
5HoolzzEj3t780j1Ht0LDbkeyiUP8dSHRD3Uk5CHcqO9Tb88xG9tD/UzaX/n
7xuSR/iPdd8v9TxervUQX+xnAh7h05ySvx4v13qKPPU8UU/v79n3eLmNPy/0
Y429U8Aj/H4bzhzvyz2Pl2s9xFM/E/UIL/MynsfLtR7ii/1MwCNzSvJ/z0O5
5CGe+pmoR88pDbseyiUP8dTPRD16TmnY9VAueYinfibq0XNKw66HcslDPPUz
UY+eUxp2PZgLHuKpn4l69JzSsOuhXPIQT/1M1COc5clDueQhnvqZqCdxQ517
4P5vPeXc3EN8uZ9p7xF+3hVNr7+5x8u1niKPPU/QM8Zfu+a7Z3zj/S3/XIXc
Rk+hH2vsnQIe4dOckj1/5h4v13qIp34m6hH+9Mbzf+7xcq2H+GI/E/AIb69T
8ni5dN+wfLHnCXg073va5frrLPcz7T16Tsn3UC55iKd+JurRc0q+h3LJQzz1
M1GPnlPyPZRLHuKpn4l6VsDvKZCHcslDPPUhUY9cn5Ynj9fDtOX75SG+Xx7p
u+ZMm3Pl+U9uvo+peYzOzpn/pHlnf/+Yjwy7HjmPnvvr3/z+f83yPZRLHuLl
fejVXzpvh29cU++R54HtDxre93vf8T2USx7i031E9uesiXlG2nsolzzE63mk
eo/uhXwP5ZKHeD2PVO/RvZDvoVzyEK/nkXap9uheyPdQLnmIT+uQeaR6j+6F
fA/lkod4PY9U79G9kO+hXPIQn64rOc/Ue3Qv5HsolzzE63mkeo/uhXwP5ZKH
+LSOGdl+iHp0L+R7KJc8xOt5pHqP7oV8D+WSh3g9jzSr2qN7Id9DueQhXs8j
1Xt0L+R7KJc8xKfrUfrJCXp6vZDvoVzyEC/raT7XtffIOocbz2m5h3LJQ7za
D516j+yT88w5mTyUSx7i5Xq0zyNRj1yn9jmFPJRLHuLlfnjq2l0P/NQt9R65
T/74kfct3qPjeyiXPMTLPNL0q7597S5fqvdILzR5zSGTBjq+h3LJQ7w+D9R7
VC/U8T2USx7i5TzWdj3kkV7IrpM8lEse4tPr0MxsP0Q90gvZfUIeyiUP8dSH
RD3Uk5CHcqO9Tb88xG9tD/UzaZ/n7xuSp8e98plVI1fkP7ceL9d6iC/2MwGP
8Mt2veItb3iT7/FyrafIU88T9fT+nn2Pl9v480I/1tg7BTzCpzkl3+PlWg/x
1M9EPcKneRn7vJx7vFzrIb7YzwQ8ek7J91AueYinfibq0XNKs10P5ZKHeOpn
oh49pzTb9VAueYinfibq0XNKs10P5ZKHeOpnoh49pzTb9WAueIinfibq0XNK
s10P5ZKHeOpnoh65z1iePJRLHuKpn4l6EidzSv56yrm5h/hyP9PeI3yaU/I9
Xq71FHnseYKe3pxSyz9XIbfRU+jHGnungEf4jXdf2XD+zD1ervUQT/1M1CP8
fo3n/9zj5VoP8cV+JuAR3l6n5PFy6b5h+WLPE/Bo3ve0y/XXWe5n2nv0nJLv
oVzyEE/9TNSj55R8D+WSh3jqZ6IePafkeyiXPMRTPxP1rIDfUyAP5ZKHeOpD
oh7hLE8er4dpy/fLQ3y/PPJ+Yff/I/JzeR90HB+ZNaL9u8g5bcTzyHm0ey5y
PZRLHuLlfejuPEy1R54Huuci10O55CF+fB3zu+sZmKBnpL2HcslDvKyn+35c
tUfWOT2di1wP5ZKHeLUfOvUe2SfdXtT1UC55iJfrsdtjV3vkOu3eT1wP5ZKH
+O51KO9HVHvkeaz7uuB6KJc8xMscXvf9oGrPU93nse7rsuuhXPIQ372u0n6Y
X+9JvVDX0/E9lEse4mUOoO16yDOz+zxm10keyiUP8d3rMNsPUY+8H2P3CXko
lzzEy/tn9nqMeuQcY69T8lAueYiX90Ht/TDqkfOovU+Sh3LJQ7y8D73KvB5F
PfI8sL15nSIP5ZKH+O51mL2+V3nG+F+89O3bHtzkr4dyyUO8rKfxPBbwyDqf
aDqnNXgolzzEq/0wUu+RfXKJOSeTh3LJQ7xcj/Z5JOqR69Q+p5CHcslDvNwP
u+eyao/cJ7vnNddDueQhvnsdyjxwtWdq93Wqe152PZRLHuL1eaDek3qhrmfE
91AueYiX81jb9ZDnse45za6TPJRLHuK712G2H6Ke7vWZ7RPyUC55iKc+JOqh
noQ8lBvtbfrlIX5re6ifSft8dvd1drbrEb47p+F6vFzrIb7YzwQ8wnfnZFyP
l2s9RZ56nqin9/fc8s9VyG38eaEfa+ydAh7hu3NirsfLtR7iqZ+JeoTvzum5
Hi/Xeogv9jMBj8wnfWL7I99x51TfQ7nkIZ76mahH5sPSen0P5ZKHeOpnop40
pzQr48lDueQhnvqZqCfNKeU8eSiXPMRTPxP1PLRjmk+1PHkolzzEUz8T9byt
Ox9gefJQLnmIp34m6pH7jOXJQ7nkIZ76mainy3XmwP3fesq5uYf4Yj8T8Ah/
w5lNr7+5x8u1niJPPU/UM8Z/+PVHf+WkG1v+uQq5jZ5CP9bYOwU8ws/e9/SG
82fu8XKth3jqZ6Ie4Zc1nv9zj5drPcQX+5mAR3h7nZLHy6X7huWLPU/Ao/nZ
rqdd7myXL/cz7T2Pfun/bPE6Reuf7eaSh3jqZ6KeNKc0K+PJQ7nkIZ76magn
zSnlPHkolzzEUz8T9axQ5+TZrodyyUM89SFRT5fLePJ4PUxbvl8e4vvl0X3X
Tr2f63mkmeDfyfXoXsj3UC55iNfzSPUe3Qv5HsolD/Hj6+jNI03QM9LeQ7nk
IV7W0/298GqPrLP7ufSuh3LJQ7zaD/NnVHtkn3Tno10P5ZKHeLkeu5+LUO2R
67Q7n+56KJc8xKd/31nyfRzVHumFur8f4HoolzzEy/tB3c8FqfZIL9T9/QzX
Q7nkIT5dV/L6Xu9RvdAWPHkolzzEyzxS2/WQR3ohu07yUC55iB/3dnbO9kPU
I88Fdp+Qh3LJQ7zMA9jrMeqR5zJ7nZKHcslDvJrH2OJ+GPXIc/FGc58kD+WS
h3iZh7GvR1GP9BKzzOsUeSiXPMSndfS+n2VinjH+6hfed9pPN/nroVzyEK/n
keo9uhfyPZRLHuL1PFK9R/dCvodyyUO8nkfaqdqjeyHfQ7nkIV7uh93PJa32
6F7I91AueYjX80j1Ht0L+R7KJQ/x6jwwv96jeyHfQ7nkIV7PI9V7dC/keyiX
PMQn76xsP0Q9uhfyPZRLHuKpD4l6qCchD+VGe5t+eYjf2h7qZ9I+z983JI/w
3c9rcT1ervUQX+xnAh7hu98T53q8XOsp8tTzRD29v+eWf65CbuPPC/1YY+8U
8Ajf/Z5E1+PlWg/x1M9EPcJ/PH1ei+vxcq2H+GI/E/DInNKvZi0673M7+R7K
JQ/x1M9EPXpOyfdQLnmIp34m6tFzSr6HcslDPPUzUY+eU/I9lEse4qmfiXr0
nJLvoVzyEE/9TNSj55R8D+WSh3jqZ6Ieuc9YnjyUSx7iqZ+JehI33DkF7v/W
U87NPcQX+5mAR/jDH2h6/c09Xq71FHnqeaKeMf6O91y/25JjfY+X2+gp9GON
vVPAI3yaU/I9Xq71EE/9TNQj/LLG83/u8XKth/hiPxPwCG+vU/J4uXTfsHyx
5wl4NJ/Pj1lPu1ya12rbz7T36DklWv+wm0se4qmfiXr0nNKw66Fc8hBP/UzU
o+eUhl0P5ZKHeOpnop4V8HsK5KFc8hBPfUjUk7i8JyGP18O05fvlIb5fHum7
Fj6+cPWMV2/f+7mex5iW+d95+Kv+7/sPnO565Ll49rwP7H3Zb30P5ZKHeJmH
OXLD8MNLfj612iO9xKMX3n/VN7/reyiXPMSndcj+nKBnpL2HcslDvJ5H2q7a
o3sh30O55CFe74dtqz26F/I9lEse4vU80jbVHt0LDboeyiUP8enfV+aR6j26
Fxp0PZRLHuL1PFK9R/dCg66HcslDfLqu5PW93qN7oUHXQ7nkIV7PI9V7dC80
6HoolzzEj3t780j1Ht0LDboeyiUP8Xoeqd6je6FB10O55CFezyNtW+3RvZDv
oVzyEK/nkbar9uheyPdQLnmIT+uQ59OpE/P0eiF/PZRLHuJlPUc0nccCHlnn
2qZzWoOHcslDvN4P06o9sk92Medk8lAueYiX69E+j0Q9cp3a5xTyUC55iJf7
4VvmLv38rlfXe+Q++cV9jv/RTZ+Z7noolzzEyzzSxhU3/eS+h+s90gu9+N5z
Xtq0BU8eyiUP8fo8ML3ao3qh+b6HcslDvJzH2q6HPNIL2XWSh3LJQ/y4d+w8
bPdD1CO9kN0n5KFc8hBPfUjUQz0JeSg32tv0y0P81vZQP5P2d/6+IXmE//ry
nY+4YK29P+QeL9d6iC/2MwGP8GcsfWDRLdf56/FyrafIU88T9fT+nn2Pl9v4
80I/1tg7BTzCpzmlbV2Pl2s9xFM/E/UIn+aUbD+Qe7xc6yG+2M8EPHpOyfdQ
LnmIp34m6tFzSr6HcslDPPUzUY+eU/I9lEse4qmfiXr0nJLvoVzyEE/9TNSj
55R8D+WSh3jqZ6IePafkeyiXPMRTPxP1yH3G8uShXPIQT/1M1JM4mVPK7//W
U87NPcQX+5mAR/g0p+Svx8u1niJPPU/U05tT8j1ebqOn0I819k4Bj/BvOnVV
w/kz93i51kM89TNRj/ALGs//ucfLtR7ii/1MwCO8vU7J4+XSfcPyxZ4n4NF8
Pj9mPe1y83kty5f7mfYePadE6x9yc8lDPPUzUY+eUxpyPZRLHuKpn4l69JzS
kOuhXPIQT/1M1LMCfk+BPJRLHuKpD4l6Epf3JOTxepi2fL88xPfLo/uuyb2f
63mMSeCf4np0L+R7KJc8xOt5pIFqj+6FfA/lkof4tA7ZnxP0jLT3UC55iJf1
nLz/mred86mXf1rrkXXu+eLf3Pvj630P5ZKHeLUfBl6q9sg++c3hH7zhoaNe
dD2USx7i5XpcttvSw9bf8UK1R67TL350yR3Hfv4510O55CE+/avO6lx79llP
LV3+fLVHeqEnF8+9ePHAc66HcslDvLwftPfxiy86Zt96j/RC0059xTYDW/Dk
oVzyEJ/2gby+13tUL7QFTx7KJQ/xMo/Udj3kkV7IrpM8lEse4se1nZ2z/RD1
yHOB3SfkoVzyEC/zAPZ6jHrkucxep+ShXPIQr+YxtrgfRj3yXHyfuU+Sh3LJ
Q7zMw5xkXo+iHukldjevU+ShXPIQP76M+cOdTem/iXnG+DnPfmvlBS08lEse
4vU8kjnnBDy6F/I9lEse4vU80qRqj+6FfA/lkod4PY80udqje6EprodyyUO8
3A/TPEa9R/dCU1wP5ZKHeD2PVO/RvdAU10O55CFenwemVHt0L+R7KJc8xOt5
JH895NG9kL8eyiUP8ePe3jxSvUf3Qv6fi3LJQzz1IVEP9STkodxob9MvD/Fb
20P9TNrf+fuG5BE+zSnZ+0Pu8XKth/hiPxPwCJ/mlPz1eLnWU+Sp54l6en/P
vsfLbfx5oR9r7J0CHuF3P+vgO79264uux8u1HuKpn4l6hL/nlFUnT5lr+4Hc
4+VaD/HFfibgkTmlf37jOx+f+rpR10O55CGe+pmoR88pjboeyiUP8dTPRD16
TmnU9VAueYinfibq0XNKo66HcslDPPUzUY+eUxp1PZRLHuKpn4l69JzSqOuh
XPIQT/1M1CP3GcuTh3LJQzz1M1FP4oY7d8H933rKubmH+GI/E/AIv/CHhzS8
/uYeL9d6ijz1PFHPGH/hVw879JLb/PV4uY2eQj/W2DsFPMKnOSV7/sw9Xq71
EE/9TNQj/ILG83/u8XKth/hiPxPwCG+vU/J4uXTfsHyx5wl4NJ/Pj1lPu1ya
12rbz7T36DklWv+gm0se4qmfiXr0nNKg66Fc8hBP/UzUo+eUBl0P5ZKHeOpn
op4V8HsK5KFc8hBPfUjUk7i8JyGP18O05fvlIb5fHum79rt//1te9a6nevcx
PY/xp+w58fyvv/1d1336mZ96Hnku3uvmb3/oz7/neyiXPMTLPMyipa9fdumX
/lDtkV5i5ZQfvPmv5vkeyiUP8ek+Iut5cmKekfYeyiUP8bKeJWfeetojGx6r
9sg6PzB6xbX/cPjjrodyyUO83g8bqz2yT/5l4U1H3PXNR1wP5ZKHeLkeFxx6
+dU/++x/VXvkOp159yWfvW37h1wP5ZKH+PTvO6vTeeh3j1yx8OFqj/RC6w75
8vAhk9a7HsolD/HyftCHbj94mxtP3VDtkV5o+N59th8YWO96KJc8xKd9IK/v
9R7dC613PZRLHuJlHqntesgjvZBdJ3kolzzEj2s7O2f7IeqR5wK7T8hDueQh
XuYBrjTXY9Qjz2X2OiUP5ZKHeJnHSOMwv6/2yHPxDeY+SR7KJQ/xMg/zM/N6
FPVIL3GkeZ0iD+WSh/h0HhjuvDy+nv+emGeMP+WJuTe+9LLvoVzyEC/r+UbT
eSzgkXX+oOmc1uChXPIQr/fDH6s9sk/2NOdk8lAueYiX69E+j0Q9cp3a5xTy
UC55iJf74Ycvu3z6/nOervbIfXLmCbefd8KmZ1wP5ZKHeJlHuu9bJ/zTd+6u
90gv9OxVjzy/aQuePJRLHuL1eeCZao/qhQaedT2USx7i5TzWdj3kkV7IrpM8
lEse4se1Y+dhux+iHumF7D4hD+WSh3jqQ6Ie6knIQ7nR3qZfHuK3tof6mbRf
8/cNySP8Wxfufs2Lt9v7Q+7xcq2H+GI/E/AIv+byHx348ff66/FyrafIU88T
9fT+nn2Pl9v480I/1tg7BTzCH/67L37uLz7xe9fj5VoP8dTPRD3CL/yP79+1
7WW2H8g9Xq71EF/sZwIemVM69Ojz1+z01+tcD+WSh3jqZ6IePae0zvVQLnmI
p34m6tFzSutcD+WSh3jqZ6IePae0zvVQLnmIp34m6tFzSutcD+WSh3jqZ6Ie
Pae0zvVQLnmIp34m6pH7jOXJQ7nkIZ76magnccOdy+D+bz3l3NxDfLGfCXiE
3+/cSxtef3OPl2s9RZ56nqhnjJ+819VfmXWavx4vt9FT6Mcae6eAR/hj7/1+
w/kz93i51kM89TNRj/B7NJ7/c4+Xaz3EF/uZgEd4e52Sx8ul+4bliz1PwKP5
fH7Metrl5vNali/3M+09ek6J1j/q5pKHeOpnoh49pzTqeiiXPMRTPxP16Dml
UddDueQhnvqZqGcF/J4CeSiXPMRTHxL1JC7vScjj9TBt+X55iO+XR/qu1ac/
+IvzRu/t/VzPYyzN/A9+YuPogo2rXY88Fx93xSFL1p+/3PVQLnmIl3mYNRcf
v/jHq26v9kgvcdKBn3xhzoLbXA/lkof48WVs/jyogQl5Rtp7KJc8xMt6Vqb1
HFTrkXWemNbpeiiXPMTLfkjvh95V7ZF9ckzaJ66HcslDvLkeqz1yna5L16nr
oVzyEJ/+fWd15h/wl/usXXpftUd6oc45/7nm3Jfudz2USx7i5f2gI7983tPX
7fPbao/0Qg+cuPjRTZvudz2USx7i01Ulr++rqj26F1rreiiXPMTLPNJRLddD
HumF7DrJQ7nkIX5c29k52w9RjzwX2H1CHsolD/EyD7DGXI9RjzyX2euUPJRL
HuJlHmNwfGFLqz3yXHyKuU+Sh3LJQ7zMw6wzr0dRj/QSl5rXKfJQLnmIT+eB
4c5nF+9+9BGLbnrnhDxj/FeXvPLCvV7/Gnc9lEse4mU99zSdxwIeWeffv6Ph
nNbgoVzyEC/7YTSdB6o9sk8ON+dk8lAueYiX69E+j0Q9cp3a5xTyUC55iJf7
4QXpfljtMfdJ10O55CFe5pGOSK9H1Z6p+nXK9VAueYg354Fqj+6F1roeyiUP
8XIeO6rlesjzmD6nuR7KJQ/x49qx8/BFZj9EPZfoc7LroVzyEC/PI2vM9Rj1
mOcU10O55CGe+pyoh3oez0O55LE/p34m7df8fUPyCP+L0xd98o8PrXQ9Xq71
EF/sZwIe4Zd/Ye3jBxy3zPV4udZT5KnniXo2f06U6/FyG39e6Mcae6eAR/i7
0zpdj5drPcRTPxP1CL8s7RPX4+VaD/HFfibgkTmlM+ft+N61f/eg66Fc8hBP
/UzUY+aUXA/lkod46meiHjOn5HoolzzEUz8T9Zg5JddDueQhnvqZqMfMKbke
yiUP8dTPRD1mTsn1UC55iKd+JuqR+4zlyUO55CGe+pmoJ3HDnQ1w/7eecm7u
Ib7YzwQ8wu+5168aXn9zj5drPUWeep6oZ4x/4ob9Tjvuhlvb/bkKuY2eQj/W
2DsFPML/8qIvNJw/c4+Xaz3EUz8T9Qi/uPH8n3u8XOshvtjPBDzC2+uUPF4u
3TcsX+x5Ah7Du56Wue46y/1Me4+eU8L1u7nkIZ76mahHzymtcz2USx7iqZ+J
evSc0jrXQ7nkIZ76mahnBfyeAnkolzzEUz8T9SQu70nIQ7nkId7rcyaa63na
5prPjendx8zn4Rxk/d05+YM8jzwXfyfNpbseyiUP8ebziKo95vfCXA/lkof4
8WVs/jyoiXlG2nsolzzEy3q6n4dQ7TG/F+l6KJc8xJvPQ6v2mN9LdT2USx7i
ze8RV3vMPKfroVzyEJ/+fXu/D17tuVTP5boeyiUP8eb38as9T+m5aNdDueQh
Pu2D3uchVHt0L/Ss66Fc8hC/Wn8eRbVnpv69ANdDueQhfly7+fNAqj3m9zJc
D+WSh3jzeSzVHvN7Ma6HcslDvP4+vj9Ve+S5eG9znyQP5ZKHeJmHWWRej6Ie
6SVWm9cp8lAueYgfX8b84c4k8/pe5Rnj75l6/BsvbOGhXPIQL+v5edN5LOCR
dV7RdE5r8FAueYiX/TB5PGhjtUf2yY3mnEweyiUP8XI92ueRqMf8XrDroVzy
EC/3w3enzwOs9pjfy3Y9lEse4mUeaV76PMZqz1T9e/Guh3LJQ7w+D9R7dC+0
3vVQLnmIN59HWu15TH8uhOuhXPIQP64dOw8fZPZD1HOJ/lwO10O55CFenkeu
NNdj1EM9CXko1+ttLE99TtRDfLRHinqon0n7NX/fkDzCfz19ToLr8XKth/hi
PxPwCN/9nCLX4+VaT5Gnnifq2fw5Ue3+XIXcxp8X+rHG3ingEX51+pwu1+Pl
Wg/x1M9EPcLPSZ+T4Hq8XOshvtjPBDwyp3T8yn8ffnatfd7PPZRLHuKpn4l6
zPf0uR7KJQ/x1M9EPeZ7+lwP5ZKHeOpnoh7zPX2uh3LJQzz1M1GP+Z4+10O5
5CGe+pmox3xPn+uhXPIQT/1M1CP3GcuTh3LJQzz1M1FP4oY7B8D933rKubmH
+GI/E/AI/9FDftjw+pt7vFzrKfLU80Q9Y/xn/vaWfzv3Pf56vNxGT6Efa+yd
Ah7hDztxUcP5M/d4udZDPPUzUY/w32s8/+ceL9d6iC/2MwGP8PY6JY+XS/cN
yxd7noBH8/n8mPW0y83ntSxf7mfae8yckuuhXPIQT/1M1GPmlFwP5ZKHeOpn
oh4zp+R6KJc8xFM/E/WsgN9TIA/lkod46kOinsTlPQl5vB6mLd8vD/H98kjf
tWy3pYetv+OF3s/1PMZLmb/7PdGuR56Lf5O+l9n1UC55iJd5mJP2X/O2cz71
crVHeok90/cyux7KJQ/x48vY/HlQnQl5Rtp7KJc8xMt6jtww/PCSn9d7ZJ2P
pu9ldj2USx7i1X6YP6naI/uk+73MrodyyUO8XI8LH1+4esarJ1d7zPeZuh7K
JQ/x6d93Vuctc5d+fter6z3SC3W/l9b1UC55iJf3gzauuOkn9z1c75FeqPu9
wK6HcslDfLqs5PV9SrVH9ULzfQ/lkod4mUdqux7ySC9k10keyiUP8emutnO2
H6Ie873krodyyUO8zAPY6zHqMd8L73oolzzEq3mkLe6HUY88F88290nyUC55
iJd5GPt6FPVIL/GYeZ0iD+WSh/i0Dnk+naBnjP/44E0LOi08lEse4mU9Jzed
xwIeWeehTee0Bg/lkod42Q9pHuylao/sk5XmnEweyiUP8XI92ueRqEeuU/uc
Qh7KJQ/xcj+89uyznlq6/Plqj9wnn1w89+LFA8+5HsolD/Eyj7T38YsvOmbf
eo/0QtNOfcU2A1vw5KFc8hCvzwP1Ht0LPed6KJc8xMt5rO16yCO9kF0neSiX
PMSPa8fOw3Y/RD3SC9l9Qh7KJQ/x1IdEPdSTkIdyo71NvzzEb20P9TNpv+bv
G5JH+OWnrDp5ylx7f8g9Xq71EF/sZwIe4d9w1sF3fu1Wfz1ervUUeep5op7N
nxPlerzcxp8X+rHG3ingEf6MpQ8suuW6Sa7Hy7Ue4qmfiXqEv3r5zkdcsNb2
A7nHy7Ue4ov9TMAjc0r7PPqRi//xCd9DueQhnvqZqEfPKQ26HsolD/HUz0Q9
ek5p0PVQLnmIp34m6tFzSoOuh3LJQzz1M1GPnlMadD2USx7iqZ+JevSc0qDr
oVzyEE/9TNQj9xnLk4dyyUM89TNRT+KGO9fA/d96yrm5h/hiPxPwCH/La5te
f3OPl2s9RZ56nqhnjD/otnn3v/063+PlNnoK/Vhj7xTwCH/9m49sOH/mHi/X
eoinfibqEX5V4/k/93i51kN8sZ8JeIS31yl5vFy6b1i+2PMEPJrP58esp11u
Pq9l+XI/095jvqfP9VAueYinfibqMd/T53oolzzEUz8T9Zjv6XM9lEse4qmf
iXpWwO8pkIdyyUM89SFRT+LynoQ8Xg/Tlu+Xh/h+eaTv+ujwKW/4w7ptevcx
PY+xbfac+LOb13/4xjs33/fII8/FG6//f78+ew/fQ7nkIV7mYf5118f/7O0H
bFftkV5ilwt2O/V/H+17KJc8xKd1yP6cOjHPSHsP5ZKHeD2PVO/RvZDvoVzy
EK/3w7Rqj+6FfA/lkod4PY+0fbVH90LTXQ/lkof49O8r80j1Ht0LTXc9lEse
4vU8Ur1H90LTXQ/lkof4dF3J6/v0ao/uhXwP5ZKHeD2P5K+HPLoX8tdDueQh
ftzbm0eq9+heyP9zUS55iNfzSPUe3QtNdz2USx7i9TzStGqP7oV8D+WSh3g9
jzS12qN7Id9DueQhPq1Dnk8n6On1Qr6HcslDvKzn5qbzWMAj69yt6ZzW4KFc
8hCv98O21R7ZJ4+aczJ5KJc8xMv1aJ9Hoh65Tu1zCnkolzzEy/3w3tv3//SG
j9V75D55/opvHfy++XnfZT2USx7iZR5p9j7ve/def1bvkV5o8NZLJw/Mz3s2
66Fc8hCvzwP1HtULbcGTh3LJQ7ycx9quhzzSC9l1kodyyUP8uHfsPGz3Q9Qj
vZDdJ+ShXPIQT31I1EM9CXkoN9rb9MtD/Nb2UD+T9nf+viF5hP/YnMf+9cLX
2ftD7vFyrYf4Yj8T8Ah/5f6v/chhx/rr8XKtp8hTzxP19P6efY+X2/jzQj/W
2DsFPMKnOaVprsfLtR7iqZ+JeoRPc0q2H8g9Xq71EF/sZwIePafkeyiXPMRT
PxP16DmlIddDueQhnvqZqEfPKQ25HsolD/HUz0Q9ek5pyPVQLnmIp34m6tFz
SkOuh3LJQzz1M1GPnlMacj2USx7iqZ+JeuQ+Y3nyUC55iKd+JupJnMwp5fd/
6ynn5h7ii/1MwCN8mlPy1+PlWk+Rp54n6unNKfkeL7fRU+jHGnungEf4X1+1
e8P5M/d4udZDPPUzUY/wpzee/3OPl2s9xBf7mYBHeHudksfLpfuG5Ys9T8Cj
ed/TLtdfZ7mfae/Rc0q+h3LJQzz1M1GPnlPyPZRLHuKpn4l69JyS76Fc8hBP
/UzUswJ+T4E8lEse4qkPiXoSl/ck5PF6mLZ8vzzE98uj+64dej/X8xgzwD/k
enQv5HsolzzE63mkHas9uhfyPZRLHuLTOmR/zpyYZ6S9h3LJQ7ysJ/Xi9R5Z
59Pj9yffQ7nkIV7th5F6j+yT1E/4HsolD/FyPab/71Ttkes0/d/3UC55iE/r
mNVJ66r3SC+U1ut7KJc8xMv7QWlf1HukF0r7xfdQLnmIT9eVnGfqPaoXGvE9
lEse4mUeqe16yCO9kF0neSiXPMSPezs7Z/sh6pHnArtPyEO55CFe5gHs9Rj1
yHOZvU7JQ7nkIV7NY2xxP4x65LnY3ifJQ7nkIV7mYfYwr0dRj/QSz5jXKfJQ
LnmIT9ehPJ9O0DPG7zv5g+95TQsP5ZKHeD2PtGO1R/dCvodyyUO8nkeaUe3R
vZDvoVzyEK/nkXao9uheKO+ZrYdyyUO83A/TPEa9R/dC1HcNubnkIV7PI9V7
dC9EPduQm0se4tV5YKDeo3uhIddDueQhXs8j1Xt0LzTkeiiXPMSn16FZ2X6I
enQvNOR6KJc8xFMfEvVQT0Ieyo32Nv3yEL+1PdTPpP2dv29IHuHTnJK9P+Qe
L9d6iC/2MwGP8GlOyV+Pl2s9RZ56nqin9/fse7zcxp8X+rHG3ingEX6/DWf+
cvWvfI+Xaz3EUz8T9Qif5mXs83Lu8XKth/hiPxPwyJxS+r/voVzyEE/9TNSj
55SGXQ/lkod46meiHj2nNOx6KJc8xFM/E/XoOaVh10O55CGe+pmoR88pDbse
yiUP8dTPRD16TmnY9VAueYinfibqkfuM5clDueQhnvqZqEe4e+D+bz3l3NxD
fLGfCXiEn3dF0+tv7vFyrafIU88T9Yzx16757hnfeH/LP1cht9FT6Mcae6eA
R/g0p2TPn7nHy7Ue4qmfiXqEP73x/J97vFzrIb7YzwQ8wtvrlDxeLt03LF/s
eQIezfuedrn+Osv9THuPnlPyPZRLHuKpn4l69JyS76Fc8hBP/UzUo+eUfA/l
kod46meinhXwewrkoVzyEE99SNSTuLwnIY/Xw7Tl++Uhvl8e6bukv5efq3mM
zs6ZX+6Xnkeei+X+5HkolzzEyzyMvC9d65FeYvvu/cnzUC55iE/3Edmfsybm
GWnvoVzyEK/nkeo9uhfyPZRLHuL1PFK9R/dCvodyyUO8nkfapdqjeyHfQ7nk
IV7WIeuq9eheyPdQLnmI1/NI9R7dC/keyiUP8XJdyXVZ69G9kO+hXPIQr+eR
6j26F/I9lEse4se9vXmkeo/uhXwP5ZKHeD2PVO/RvZDvoVzyEK/nkWZVe3Qv
5HsolzzE63mkeo/uhXwP5ZKH+HQdyvPpBD29Xsj3UC55iJf1NJ7HAh5Z53DT
Oa3BQ7nkIV7th069R/bJeeacTB7KJQ/xcj3a55GoR65T+5xCHsolD/GyDllX
rUfuk7Jez0O55CFe5pFkX9R6pBeS/eJ5KJc8xOvzQL1H9UId30O55CFezmNt
10Me6YXsOslDueQhXl6H7H6IeqQXsvuEPJRLHuKpD4l6qCchD+VGe5t+eYjf
2h7qZ9I+z983JI/wb+2+X+p5vFzrIb7YzwQ8wi/bNb1f7Xm8XOsp8tTzRD29
v2ff4+U2/rzQjzX2TgGP8GlOyfd4udZDPPUzUY/wMi/jebxc6yG+2M8EPHpO
yfdQLnmIp34m6tFzSrNdD+WSh3jqZ6IePac02/VQLnmIp34m6tFzSrNdD+WS
h3jqZ6IePac02/VQLnmIp34m6tFzSrNdD+WSh3jqZ6Ie4SxPHsolD/HUz0Q9
iZM5JX895dzcQ3yxnwl4hE9zSr7Hy7WeIk89T9TTm1Nq+ecq5DZ6Cv1YY+8U
8Ai/8e4rG86fucfLtR7iqZ+JeoTfr/H8n3u8XOshvtjPBDzC2+uUPF4u3Tcs
X+x5Ah7N+552uf46y/1Me4+eU/I9lEse4qmfiXr0nJLvoVzyEE/9TNSj55R8
D+WSh3jqZ6KeFfB7CuShXPIQT31I1CPXp+XJ4/Uwbfl+eYifqOf/A6W1CDY=

    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoUUOwMRXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEADFd50Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZRA7AxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OADXLdSE=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAocUOoIuvXgUEr0QxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAKFh50Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAphqEDqCLr14FBFmY4qFg
gCkOphxwmKOFwxxRHOYwEC+Oyxxc9uJyJy5/4QoHXOEGEwcAd0x1IQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMIgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwDDMUY6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiBwAUw2iBxou8LEW+c1HFWcQ
PcBwwT3O8msdmnqYPAzA+CI41AvjMF/4AHb3CB0wBoPLxIkDzcGuHoc4kMau
Hoc4MBywqxfF4X7RAwCfSUY6
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZRA7AxLmnr1gg2it0
4GZvGe/cOcJw8Yw70rZFm6HqHRDiRpxGkys+CB2A0SjmA9XB9MHEYebC7EFR
D3QHzF0wcfWizk9JySLY1R8QwTD/3LezOe38ohjumaH85FCvjyiG+79mhMe/
KhI9cAPNvxB3iGKED0w9zF1YzT8gguGes1Aa3f0wfTBxDai5MHuwh48oRnhi
VQ/0J7r5sHA5h+YelPg9gJkeNND8i55+AFOKAJI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAo2Hiq1eBAKZ4KBgIY4hD
+CI4zMEUh5gjisMcMZLFYe5FF4e5F7s5IjjMwRSHuRe7OWIExVH9K4YjfNDN
wRRHDX90c4RwmEO6OHb/CuEIH5g5mOLYw18IR3wh0hsAhircjw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoQUOwMRXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEA5HB5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZBA7AxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OAA3zdOU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoYUOoIuvXgUErwQxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAAIB5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoXkPoIuHgsBVHgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwBOBXXK
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMAgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwCbWUX+
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiBwAUw2CBxou8LEW+c1HFWcQ
PMBwwT3O8msdmnoBqDwMwNQLYFfPwI/DfL4DWN3DwHvAGAwuEynOh0OcH4e4
AHbxBhziwHDArl4Qu/uB4gAGikP6
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZBA7AxLmnr1gg2it0
YKP0WykrS364eMYdaduizVD1DXxwcSNOo8kVH4QOpAqlqH18wHsAxXwH4QMX
dphXPUlDiN/sLeOdO0f4gJheoKO2FJp6BhGoexDi6kWdn5KSRbCrPyCCYf65
b2dz2vlFMdwzQ/nJoV4fUQz3f80Ij39VJIrhX4g6UYzwgamHuEsAu/kHBDDc
cxZMC2K4H6IPIa4B9S/EHkHs4dMgiBGeWNUDwx/dfFh8nUNzD0r8HsBMDxpo
/kVPPwD80/3V
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoXkOwMRXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJItDzOPFEIfYz4fDHAEc6jHFIeYL4jBHiKA4qn+F
cIQPujmY4qjhj26OEA5zSBfH7l8hHOEDMwdTHHv4Cx0IwxpfiPQGANBv3Ao=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoTkOwMRXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAlMB5HQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZOA7AxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OAL40dG0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoXkOoIuHgsBVbgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwBED3W7
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoVkPoIuHgsBVFgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwD+RnVS
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMHAcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwBLqUWG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0NwHGi7wsRb5zUcT5zrA
cME9zvJrHZo4J5SGAZg4Bw717DjMZzuA3T2sB4zB4DKR4mw4xNlxiHPgEOfE
Ic6FQ5wbh/u5DwAATPBBDA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZOA7AxLmnr1gg2it0
YKP0WykrS3a4eMYdaduizVD1DWxwcSNOo8kVH4QOpAqlqH18wHoAxXwH4QMX
dphXPUlDiN/sLeOdO0f4gJheoKO2FJp6BhGoexDi6kWdn5KSRbCrPyCCYf65
b2dz2vlFMdwzQ/nJoV4fUQz3f80Ij39VJIrhX4g6UYzwgan3eyL09OgxDhzm
c2K4Z/bb2Tf55Lkw3G/gfqJVeiZCXAPq31cX1+278pQLR/hwY4QnVvXA8Ec3
HxZf6O5BjV9OjPTgj+Zf9PQDANmJ/lg=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoVkOwMRXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJItDzGPFEIfYz4bDHA4c5nBiiIONWcWFwxweguKo
/uXBET7o5mCKo4Y/ujlCOMwhXXw1Vv8K4QgfmDno4SmEI/yFDoRhjS9EegMA
xnzbPw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoRkOwMRXrwKCV6IY4qEg
cBVTHMLDFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRu6OABFEHil
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6wAABB2Diq1cBQRameCgY
YIqDeQ44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnBDFwcAboRz9Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoVkOoIuHgsBVZgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwD0UHVD
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoX/tRxdfvQoEfmKIh4IB
pjiExhSHmPMDQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAMK4gpg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeYICAAw0X+FiL/OZDxBkQ
4gwX3OMsv9ZB1YsgxFGACA71wjjMR4ijukcILm4MBpfxiyOZg6oehziSO1HV
4xBHCgdU9QhxXOEJAPvqRQ4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0MwHGi7wsRb5zUcTZzrA
cME9zvJrHZo4I5SGAZg4Aw71//ZjN//Pfuzu+bXfGAwuEyn+B4f4PxziDAew
izPiEGfCIc58AFd4AgA0tkaC
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6wAABB2Di3NNXLBDtFTqQ
ZH7LtKTo336YeMYdaduizTD1f+HiRpxGkys+CB04pXLC59HB3/tRzHcQPrCg
MP/LibO/4OI3e8t4584RPqATs6gpzOQXqnoGEaj5CHH1os5PScki2NUfEMEw
/9y3sznt/KIY7pmh/ORQr48ohvu/ZoTHvyoSxfAvJHxg6hHhA1Pv90To6dFj
CHEU8xsYD6C7Z/bb2Tf55JkOoLvfwP1Eq/RMhLgG1L+vLq7bd+Upmnp4+DAf
QA9PrOqB4Y9uPiy+0N2DEr9I7oelB380/6KnHwAGzgz1
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoX/sh4mvXgUCmOKhYCCM
IQ7hi+AwB1McYo4oDnPESBYHW7PqF4Y4xJ6/OMxhOIBdPSOGOMR8JgxxCM1C
UBzVvwhx1PBBNwdTHDX80c0RwmEO6eKrsfpXCEf4wMxBD0+hA2FYwx9mPnp8
IdIbAL7r5yU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoT/sh4mvXgUEr0QxxENB
4CqmOJh7AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVu6OIAklCGpg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZPuyHia9eBQRZmOKh
YIApDuY64DBHC4c5ojjMYSBeHJc5uOzF5U5c/sIVDrjCDV0cALvEgfY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoX/sRxdfvQoEvmOIh4IB
pjiExhSHmPMNQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAK7Mgno=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoZ/sRxcPCwWBxxjiq8Dg
EYY4hMYUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRtMHADdkYFA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMH/Y3XOBjLfKbDxFn
QIgzXHCPs/xaB1UvghBHASI41AvjMB8hjuoeIbi4MRhcxi+OZA6qehziSO5E
VY9DHCkcUNUjxHGFJwBJOVMP
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0N/2N1zgYy3ym48m/mU/
wwX3OMuvdWjin/YzoACY+Acc6t/gMP/FfuzuebLfGAwuEyn+Aof4GxziH3CI
f8Ih/gWH+Dcc7v+2HwA5dk6A
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZPuyHiXNPX7FAtFfo
wNG8LdkvnryBi2fckbYt2gxT/woubsRpNLnig9CBKZ4TZh5pfr4fxXwH4QMO
j++9mDj7KVz8Zm8Z79w5wgcidriwrs14gqqeQQRqPkJcvajzU1KyCHb1B0Qw
zD/37WxOO7/ogclo7pmh/ORQr4/ogf9g8BIu/jUjPP5VkeiBI2j+hYSPKEb4
wNTPPaF6qrv3I4b5EPWfMdxjdtt8s6zdFwz3J/RN4DY3+goX14D698ri2NqV
p7/iCJ9vGOGJVT0w/NHNh8UXuntg8cuI5n5YepiP5l/09AMA7Ssbuw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoR/sh4mvXgUCmOKhYCCM
IQ7hi+AwB1McYo4oDnPESBaHmPcUQxxs/apXOMz5gEP9Jxzmf8Vhzg+C4qj+
/YEjfNDNwRRHDX90c4RwmEO6eBhW/wodWI01fGDmoIcnTD16+MPMR48vRHoD
ADJQ9Cs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDvAAAUw8dWrgOCVKIZ4KAhc
xRQHcw5gioPNWYXDnKk4zGkgXhyXObjsxeVOXP7CFQ64wg1dHADXWG1l
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6wAAFMPHVq4AgC1M8FAww
xcEcBxzmaOEwRxSHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwAA22i1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoR/sRxdfvQoE7mGIh4LB
XQxxCH0Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7jBxAGh0YDo

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoW/Yo4uHgsFNDPHVq0Dg
FoY4hL6Dw5y7GOJgY1bdw2HOA6LFV+MwB5e9uNyJy19hOMIBV7jBxAGspnlg

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeYICChgt8rEV+8yHiDAhx
hgvucZZf66DqRRDiKEAEh3phHOYjxFHdIwQXNwaDy/jFkcxBVY9DHMmdqOpx
iCOFA6p6hDiu8AQAjkE5zg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0Df2N1zgYy3ym48mfmE/
wwX3OMuvdWjiB/YzoACYOEgLVvX2OMy3x+Eee2MwuEyk+AUc4gdwiDMw4FC/
H4f5OMRv7McVngCf2kZ8
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6wAAFMHHu6SsWiPYKHbjR
GbNoz40d9jDxjDvStkWbhQ78B4PjcHEjTqPJFR+EDtzMuX+m7McFexTzHYQP
NFg66d05cQUufrO3jHfuHOED/v1lX5fqXUdVzyACdc8NuLh6UeenpGSRAwHY
1B8QwTD/3LezOe38ogduoblnhvKTQ70+ogdYwBpPwMW/ZoTHvyoSPfAAzb+Q
8BE9wNU1z8eysssGXf05iPr96Ob/gYTPfnT3XIe4Zz+6++sg7oeLa0D96wfx
734c4bMfPTwDsKkHhn8Tmvmw+LqF5h5Y/LJBwmc/enp4h+ZfWPqBhM+sPQDn
OSEK
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoR/Yw8RXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJIuHgc27ikP8KA5z0MNB7EAIRP1+7OJXMcSh7iEo
jubf/TjCZz+O8NyPI/z344iv/Tjil2jxMKz+hYmjhw/MHMx0FYI1/GHi6PGF
SG8A5p7gdQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoT/Yw8RXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAnoV/Jg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZPtjDxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OAMf5enY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoR/Yo4uvAgNM8bBQEHiI
IQ6hH+EwB1McbEzoYxzmPCFaPAyHObjsxeVOXP5ajSMccIUbTBwA6G55vA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAob/Zo4uHggGm+OpVIIAp
DqG/4zAHUxxszCpMcQj9g2jx1TjMwWUvLnfi8lcYjnDAFW4wcQC5rXr4
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMH+wbLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwBVbkuP
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0E/sGy7wsRb5zUcTf2HP
cME9zvJrHZr4GygfBmDiH3Co/4TD/C/22N3zzd4YDC4TKf4Fh/gnHOIfcIi/
wSH+Aof4Exzuf2IPAEWHRu4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZPtjDxLmnr1gg2it0
YN4J1VPdvR/h4hl3pG2LNsPUf4aLG3EaTa74IHTA7Lb5Zlm7L/Yo5jsIH0jo
m8BtbvQVLn6zt4x37hzhA1cWx9auPP0VVT2DCNT8b3Bx9aLOT0nJItjVHxDB
MP/ct7M57fyiGO6ZofzkUK+PKIb7v2aEx78qEsXwLyR8YOo/YKg/lrcl+8WT
NxjmM4LVv8JwzxTPCTOPND/HcL/j43svJs5+ChfXgPo3cocL69qMJzjC5wlG
eEZgUw8Mf3s082HxNRnNPbD4/fcfBF5ipIdDaP6FpR+w8v/v7QFTyRUz
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoX/Yw8RXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJIuHgc37iiEOsf8TDnM+4FD/Cof5T3GY84CgOKp/
H+AIH3RzMMVRwx/dHCEc5pAuHorVv0IHVmENH5g56OEJU48e/jDz0eMLkd4A
TRHmKw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoRkcYOKrVwHBK1EM8VAQ
uIopDuYdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAUUVxJQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6wAABDjDx1auAIAtTPBQM
MMUhPBzmaOEwRxSHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwB6uWx1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoX/Yo4uHggGm+OpVIIAp
DqF/4jAHUxxszCpMcQj9i2jx1TjMwWUvLnfi8lcYjnDAFW4wcQDNmXsW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoZkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINJg4AAJJtwg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeYIAAh4YLfKxFfvMh4gwI
cYYL7nGWX+ug6kUQ4ihABId6YRzmI8RR3SMEFzcGg8v4xZHMQVWPQxzJnajq
cYgjhQOqeoQ4rvAEAAguPY4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0L/sGy7wsRb5zUcT/2PP
cME9zvJrHZr4PygfBmDiDA7Y1TM6YDefyQG7e5gdjMHgMpHiTDjEGXGIM+AQ
/2ePXfwPDvFf9rjCEwBC2D/4
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6wAABDjBx7ukrFoj2Ch3w
fyL09OgxhHjGHWnbos1Q9Q2McHEjTqPJFR+EDsx+O/smnzyTA4r5DsIHDNxP
tErPRIjf7C3jnTtH+MCri+v2XXmKpp5BBOoeZri4elHnp6RkEezqD4hgmH/u
29mcdn5RDPfMUH5yqNdHFMP9XzPC418ViWL4F6JOFCN8YOqTzW+ZlhT9s8dq
PsNfe3T3nFI54fPo4G97dPcvKMz/cuLsL7i4BtS/OjGLmsJMftljDx+EOCw8
saoHhj+6+bD4QncPLH7/g8Efe/T0kIjmX/T0AwA7bwZv
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoVkcYOKrV4EApngoGAhj
iEP4IjjMwRSHmCOKwxwxksUh9jBhiEPsYcRhDgOGeBhY/V977Ob/whCH0D8I
iqP6FyGOGj7o5mCKo4Y/ujlCOMwhXXwVVv8KQcMTPXxg5qCHpxCO8IeZjx5f
iPQGAELF2SU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoTkcYOKrVwHBK1EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAoPVxnQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZOBxg4qtXAUEWpngo
GGCKg7kOOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wQxcHAMppbO0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoVkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINJg4ACoht0Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAobkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINJg4AUEJuOg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMHA4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdWLIMRRgAgO9cI4zEeIo7pHCC5uDAaX8YsjmYOqHoc4kjtR
1eMQRwoHVPUIcVzhCQBX3j4G
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0KwODRf4WIv85qOJszkw
XHCPs/xahybO7sCAAmDiHDjUc+Iwn8sBu3u4HYzB4DKR4lw4xDlxiHPgEGfH
Ic6GQ5wVh/tZHQBZGTmG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZOBxg4tzTVywQ7RU6
4P9E6OnRYwjxjDvStkWboeobOOHiRpxGkys+CB2Y/Xb2TT55LgcU8x2EDxi4
n2iVnokQv9lbxjt3jvCBVxfX7bvyFE09gwjUPdxwcfWizk9JySLY1R8QwTD/
3LezOe38ohjumaH85FCvjyiG+79mhMe/KhLF8C9EnShG+MDUb5J+K2VlyY7D
fDYM96QKpah9fMCK4f4LO8yrnqQhxDWg/hXTC3TUlmLFET6sGOGJVT0w/NHN
h8UXuntQ45cNIz1sRPMvevoBABB88do=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoXkcYOKrV4EApngoGAhj
iEP4IjjMwRSHmCOKwxwxksUh9nBhiEPs4cRhDgcOc9gwxMPA5rDiMIeFoDiq
f1lwhA+6OZjiqOGPbo4QDnNIFw/F6l8hHOEDMwc9PIVwhL/QgVVY4wuR3gBL
nc0/
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoQUcYOKrVwHBK1EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgA8KVyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZBBxg4qtXAUEWpngo
GGCKg7kOOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wQxcHABoobWU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoXkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINJg4AWjhuSQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAphoEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYhocVzm4LIXlztx+QtXOOAKN5g4AA4zcpQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMAg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdWLIMRRgAgO9cI4zEeIo7pHCC5uDAaX8YsjmYOqHoc4kjtR
1eMQRwoHVPUIcVzhCQCnjj5+
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0LwODRf4WIv85qOJ8zkw
XHCPs/xahybO78CAAmDiAtjVNwjgMF/QAat7GgQdjMHgMnHiDLjUC+BQj0uc
H4c4Hw5xXuzuB4oDABE3O/Y=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZBBxg4tzTVywQ7RU6
oF7U+SkpGSGecUfatmgzVP0BhLgRp9Hkig9CB859O5vTzi/ogGK+g/CBGcpP
DvX6IMRv9pbxzp0jfOBrRnj8qyI09QwiEPMbEOIQd4hgV39ABMN8iDtEMdwD
USeK4X6IuaIHNND8C3GHKEb4wNRvkn4rZWXJj938Bj4M96QKpah9fMCL4f4L
O8yrnqQhxDWg/hXTC3TUluLFHj4MvBjhiVU9MPzRzYfFF7p7UOIXyf2w9LAR
zb/o6QcAvxjxVw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoApR1g4qtXgQCmeCgYCGOI
Q/giOMzBFIeYI4rDHDGSxSHmCWKIQ+wXwGEOpjhEPR+GeBjYfF4c5vAQFEf1
Lw+O8EE3B1McNfzRzRHCYQ7p4qFY/SuEI3xg5qCHpxCO8BfCEV+I9AYAQeDO
Cg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoUUcYOKrVwHBK1EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAGIxyUQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZRBxg4qtXAUEWpngo
GGCKg7kOOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wQxcHAEIAbaE=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoYUc0MVDQUAUU3z1KiDQ
whQHUw44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnCDiQMAggFtIQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAphpEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYxocVzm4LIXlztx+QtXOOAKN5g4ADYLctA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMIg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdWLIMRRgAgO9cI4zEeIo7pHCC5uDAaX8YsjmYOqHoc4kjtR
1eMQRwoHVPUIcVzhCQDPZj66
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiBwAUw1CDg0X+FiL/OajijMI
OzBccI+z/FqHph4ojgJg6kVwqBfBYb6oA3b3iDoYg8Fl4sQZcKkXwaEehzjQ
X9jV4xAHhhuu8AQAq3g+tw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZRBxg4tzTVywQ7RU6
oF7U+SkpGSGecUfatmgzVP0BhLgRp9Hkig9CB859O5vTzi/qgGK+g/CBGcpP
DvX6IMRv9pbxzp0jfOBrRnj8qyI09QwiEPMbEOJQd2BXf0AEw3yoOzDcA1WH
4X6ouQc00PwLdQdG+MDUQ/2B3XwHYQz3GEPCCcP90HCFi0PdcQAaDzjCRwgj
PLGqB4Y/uvmw+DJCcw9K/CK5H5YebqD5Fz39AACCMvQF
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAocUcYOKrV4EApngoGAhj
iEP4IjjMwRSHmCOKwxwxksWh5mGIQ+3HYQ6mONR/OMwRwmEOYXFU/wrhCB90
czDFUcMf3RwhHOaQLo7dv0I4wgdmDnp4CuEIfyEc8YVIbwDj3M6P
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoUUOwMRXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEA4pB5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoUUOwMRDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwARzHXK
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAocUOoIuvXgUEr0QxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgA/pF5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAphqEDqCLr14FBFmY4qFg
gCkOphxwmKOFwxxRHOYwEC+Oyxxc9uJyJy5/4QoHXOEGEwcATZR05Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMIgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeABhyQ/o=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCBwAUw2iBxou8LEW+c1HFWcQ
PcBwwT3O8msdmnoRqDwMwNSL4FAvjMN84QPY3SN0wBgMLhMnDjQHu3oc4kB3
YlePQxwYDtjVi+Jwv+gBAHWRRf4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoUUOwMTF9AIdtaV4D9zs
LeOdO0cYLn5hh3nVkzSoegeEeKpQitrHB7wHjDiNJld8EDqAYn4D34GMO9K2
RZsR4hul30pZWfIf4J6+YoFoL5p6BgGI+Q0IcfWizk9JyQLY1R8QwDD/3Lez
Oe38ghjumaH85FCvjyCG+79mhMe/KhI8cAPNvxB3CGKED0w9xF0i2M0/IILh
nrNgWhTD/RB9CHENqH8h9ojiCB+E+CZoeKKrZ4SGP7r5sPg6h+YelPg9gJke
NND8i55+AJqo/VU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoYUOwMRDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFIfZgikPsEcZhjggOczDFIeaI4jBHjKA4qn/F
cIQPujmY4qjhjxAPQ4kvdHN4SBbH7l8eHOEDMwdTHHv48+CIL0Q6BADjP9wK

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoQUOwMRXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAurh5WQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoQUOwMRDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwDp5XWO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoYUOoIuvXgUErwQxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgA1rl5WQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoXkPoIuHgsBVHgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwAkTXWO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMAgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeAPCLQ74=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCBwAUw2CBxou8LEW+c1HFWcQ
PMBwwT3O8msdmnqYPAzA+ALY1TPw4zCf7wBW9zDwHjAGg8tEivPhEOfHIS6A
XbwBhzgwHLCrF8TufqA4ANzDQ74=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoQUOwMTF9AIdtaV4D2yU
fitlZckPF7+ww7zqSRpUfQMfXDxVKEXt4wPeAzAaxXygOpg+mDjMXJg9qO4R
OABzF0xcvajzU1KyAHb1BwQwzD/37WxOO78ghntmKD851OsjiOH+rxnh8a+K
BDH8C1EniBE+MPUwd2E1/4AAhnvOQml098P0wcQ1oObC7MEaPg0I8U1Qd6Or
Z4T6E918WLicQ3MPSvwewEwPGmj+RU8/AEQA+qc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAo2HioWDAiyG+ehUI8GGI
Q/gCONRjikPMF8RhjhDJ4jD3oovD3IvdHAEc6jHFYe7Fbo4QQXFU/wrhCB90
czDFUcMfIR6GEl/o5vCQLI7dvzw4wgdmDqY49vDnORCGNb4Q6RAALZPbhQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoTkOwMRXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAawh44Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoTkOwMRDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCaNXUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoXkOoIuHgsBVbgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwAaV3V/
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoVkPoIuHgsBVFgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDUjnUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMHAcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeAKDbQ0Y=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0NwHGi7wsRb5zUcT5zrA
cME9zvJrHZo4J5SGAZg4Bw717DjMZzuA3T2sB4zB4DKR4mw4xNlxiHPgEOfE
Ic6FQ5wbh/u5DwAAIzhA0A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoTkOwMTF9AIdtaV4D2yU
fitlZckOF7+ww7zqSRpUfQMbXDxVKEXt4wPeAxCa9QCK+Q18ByD6EOIQc/kP
QOxBU88gAHUPQly9qPNTUrIAdvUHBDDMP/ftbE47vyCGe2YoPznU6yOI4f6v
GeHxr4oEMfwLUSeIET4w9X5PhJ4ePcaBw3xODPfMfjv7Jp88F4b7DdxPtErP
RIhrQP376uK6fVeecuEIH264+CZoeKKrZ4SGP7r5sPhCdw9q/HJipAd/NP+i
px8AILb7Kg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoVkOwMRDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFIeaxYohD7GfDYQ4HDnM4McTBxqziwmEOD0Fx
VP/y4AgfdHMwxVHDHyEehhJf6ObwkCy+Gqt/eXCED8wc9PDkwRH+PAfCsMYX
Ih0CACOg2ro=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoRkOwMRXrwKCV4IY4qEg
cBVTHMLDFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRu6OAAbWHhp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoRkOwMRDQeAqD4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBKhXSe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoVkOoIuHgsBVZgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDKmHUH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoX/tRxdfvQoEfmKIh4IB
pjiExhSHmPMDQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAJkAglw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeYICAAw0X+FiL/OZDxBkQ
4gwX3OMsv9ZB1QsgxFGAAHb1DPw4zOeDi6O4h4EXLm4MBpcJiPPhEOfHIS6A
XbwBhzhSOKCqR4jjCk8AUStCzg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0MwHGi7wsRb5zUcTZzrA
cME9zvJrHZo4I5SGAZg4Aw71//ZjN//Pfuzu+bXfGAwuEyn+B4f4PxziDAew
izPiEGfCIc58AFd4AgAK/kZG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoRkOwMTF9AIdtaV4DySZ
3zItKfq3HyZ+YYd51ZM0mPq/cPFUoRS1jw94D5xSOeHz6ODv/SjmN/AdWFCY
/+XE2V9w8Y3Sb6WsLPkP6MQsagoz+YWqnkEAaj5CXL2o81NSsgB29QcEMMw/
9+1sTju/IIZ7Zig/OdTrI4jh/q8Z4fGvigQx/AtxP0w9Inxg6v2eCD09egwh
jmJ+A+MBdPfMfjv7Jp880wF09xu4n2iVnokQ14D699XFdfuuPEVTDw8fZrj4
Jmh4oqtnhIY/uvmw+EJ3D0r8Irkflh780fyLnn4ATewJxw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoX/sh4mHggEvhvjqVSDA
hyEO4QvgUI8pDjFfEIc5QiSLg61Z9QtDHGLPXxzmMBzArp4RQxxiPhOGOIRm
ISiO6l+EOGr4oJuDKY4a/gjxMJT4QjeHh2Tx1Vj9y4MjfGDmoIcnz4EwrOEP
Mx89vhDpEAAcD+ag
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoT/sh4mvXgUErwQxxENB
4CqmOJh7AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVu6OIAaJiGag==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoT/sh4mHgsBVHgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgCXxYKf
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoX/sRxdfvQoEvmOIh4IB
pjiExhSHmPMNQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAIUUgj4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoZ/sRxcPCwWBxxjiq8Dg
EYY4hMYUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRtMHACz2YEE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMH/Y3XOBjLfKbDxFn
QIgzXHCPs/xaB1UvgBBHAQLY1TPw4zCfDy6O4h4GXri4MRhcJiDOh0OcH4e4
AHbxBhziSOGAqh4hjis8AZ5rUM8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0N/2N1zgYy3ym48m/mU/
wwX3OMuvdWjin/YzoACY+Acc6t/gMP/FfuzuebLfGAwuEyn+Aof4GxziH3CI
f8Ih/gWH+Dcc7v+2HwAPvk5E
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoT/sh4mL6QU6akvxHjia
tyX7xZM3cPELO8yrnqTB1L+Ci6cKpah9fMB7YIrnhJlHmp/vRzG/ge+Aw+N7
LybOfgoX3yj9VsrKkv9AxA4X1rUZT1DVMwhAzUeIqxd1fkpKFsCu/oAAhvnn
vp3NaecXPDAZzT0zlJ8c6vURPPAfDF7Cxb9mhMe/KhI8cATNvxD3C2KED0z9
3BOqp7p7P2KYD1H/GcM9ZrfNN8vafcFwf0LfBG5zo69wcQ2of68sjq1defor
jvD5BhffBA1PdPWM0PBHNx8WX+jugcUvI5r7YelhPpp/0dMPADRYGI0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoR/sh4mHggEvhvjqVSDA
hyEO4QvgUI8pDjFfEIc5QiSLQ8x7iiEOtn7VKxzmfMCh/hMO87/iMOcHQXFU
//7AET7o5mCKo4Y/QjwMJb7QzeEhWTwMq395DqzGGj4wc9DDE6YePfxh5qPH
FyIdAgCPZfOm
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDrAAAUw8dWrgOCVIIZ4KAhc
xRQHcw5gioPNWYXDnKk4zGkgXhyXObjsxeVOXP7CFQ64wg1dHACtoG0p
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D3AAAUw8VAQuMqDIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUB3M1pXg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoR/sRxdfvQoE7mGIh4LB
XQxxCH0Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7jBxAF4GYCs

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoW/Yo4uHgsFNDPHVq0Dg
FoY4hL6Dw5y7GOJgY1bdw2HOA6LFV+MwB5e9uNyJy19hOMIBV7jBxAGC7nkk

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeYICChgt8rEV+8yHiDAhx
hgvucZZf66DqBRDiKEAAu3oGfhzm88HFUdzDwAsXNwaDywTE+XCI8+MQF8Au
3oBDHCkcUNUjxHGFJwDjczeO
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0Df2N1zgYy3ym48mfmE/
wwX3OMuvdWjiB/YzoACYOEgLVvX2OMy3x+Eee2MwuEyk+AUc4gdwiDMw4FC/
H4f5OMRv7McVngB2IkZA
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D3AAAUwcTG9QEdtKd4DNzpj
Fu25scMeJn5hh3nVkzTeA//B4DhcPFUoRe3jA94DN3Punyn7ccEexfwGvgMN
lk56d05cgYtvlH4rZWXJf8C/v+zrUr3rqOoZBKDuuQEXVy/q/JSULHAgAJv6
AwIY5p/7djannV/wwC0098xQfnKo10fwAAtY4wm4+NeM8PhXRYIHHqD5F+J+
wQNcXfN8LCu7bNDVn4Oo349u/h9I+OxHd891iHv2o7u/DuJ+uLgG1L9+EP/u
xxE+cPFN0PAMQFPPCA3/JjTzYfF1C809sPhlg4TPfvT08A7Nv7D0AwmfWXsA
LmYd3A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoR/Yw8RDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFw8DmXcUhfhSHOejhIHQgBKJ+P3bxqxjiUPcQ
FEfz734c4bMfR3juxxH+cPEw1PjajyN+iRYPw+pfmDh6+MDMwUxXIVjDHyaO
Hl+IdAgAQ8Lf8A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoT/Yw8RXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAdM1+6g==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoT/Yw8RDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCj+nsf
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoR/Yo4uvAgNM8bBQEHiI
IQ6hH+EwB1McbEzoYxzmPCFaPAyHObjsxeVOXP5ajSMccIUbTBwAvrZ5gA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAob/Zo4uHggGm+OpVIIAp
DqG/4zAHUxxszCpMcQj9g2jx1TjMwWUvLnfi8lcYjnDAFW4wcQCP9Xq8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMH+wbLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeAKqgSU8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0E/sGy7wsRb5zUcTf2HP
cME9zvJrHZr4GygfBmDiH3Co/4TD/C/22N3zzd4YDC4TKf4Fh/gnHOIfcIi/
wSH+Aof4Exzuf2IPABvPRrI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoT/Yw8TF9AIdtaV4D8w7
oXqqu/cjXPzCDvOqJ2kw9Z/h4qlCKWofH/AeMLttvlnW7os9ivkNfAcS+iZw
mxt9hYtvlH4rZWXJf+DK4tjalae/oqpnEICa/w0url7U+SkpWQC7+gMCGOaf
+3Y2p51fEMM9M5SfHOr1EcRw/9eM8PhXRYIY/oW4H6b+A4b6Y3lbsl88eYNh
PiNY/SsM90zxnDDzSPNzDPc7Pr73YuLsp3BxDah/I3e4sK7NeIIjfBDim6Dh
GYGmnhEa/vZo5sPiazKae2Dx++8/CLzESA+H0PwLSz9g5f/f2wMAmucSBQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoX/Yw8RDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFw8DmfcUQh9j/CYc5H3Cof4XD/Kc4zHlAUBzV
vw9whA+6OZjiqOGPEA9DiS90c3hIFg/F6l+eA6uwhg/MHPTwhKlHD3+Y+ejx
hUiHAKom5aY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoRkcYOKrVwHBK0EM8VAQ
uIopDuYdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAJ41w6Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoRkcYOKhIHCVB0N89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBWum0e
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoX/Yo4uHggGm+OpVIIAp
DqF/4jAHUxxszCpMcQj9i2jx1TjMwWUvLnfi8lcYjnDAFW4wcQCj4Xra
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoZkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINJg4A1stthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeYIAAh4YLfKxFfvMh4gwI
cYYL7nGWX+ug6gUQ4ihAALt6Bn4c5vPBxVHcw8ALFzcGg8sExPlwiPPjEBfA
Lt6AQxwpHFDVI8RxhScAXWA7Tg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0L/sGy7wsRb5zUcT/2PP
cME9zvJrHZr4PygfBmDiDA7Y1TM6YDefyQG7e5gdjMHgMpHiTDjEGXGIM+AQ
/2ePXfwPDvFf9rjCEwAZID+8
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoRkcYOJieoGO2lK8B/yf
CD09egwhfmGHedWTNKj6Bka4eKpQitrHB7wHZr+dfZNPnskBxfwGvgMG7ida
pWcixDdKv5WysuQ/8Oriun1XnqKpZxCAuocZLq5e1PkpKVkAu/oDAhjmn/t2
NqedXxDDPTOUnxzq9RHEcP/XjPD4V0WCGP6FqBPECB+Y+mTzW6YlRf/ssZrP
8Nce3T2nVE74PDr42x7d/QsK87+cOPsLLq4B9a9OzKKmMJNf9tjDByG+CRqe
6OoZoeGPbj4svtDdA4vf/2Dwxx49PSSi+Rc9/QAAgo0DQQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoVkcYOKhYMCLIb56FQjw
YYhD+AI41GOKQ8wXxGGOEMniEHuYMMQh9jDiMIcBQzwMrP6vPXbzf2GIQ+gf
BMVR/YsQRw0fdHMwxVHDHyEehhJf6ObwkCy+Cqt/eaDhiR4+MHPQw5MHR/jD
zEePL0Q6BACf2tig
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoTkcYOKrVwHBK0EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAdz1xYQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoTkcYOKhIHCVB0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCmam2W
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoVkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINJg4A4MFtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAobkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINJg4AJopt/g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMHA4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdULIMRRgAB29Qz8OMzng4ujuIeBFy5uDAaXCYjz4RDnxyEu
gF28AYc4UjigqkeI4wpPAK0QO8Y=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0KwODRf4WIv85qOJszkw
XHCPs/xahybO7sCAAmDiHDjUc+Iwn8sBu3u4HYzB4DKR4lw4xDlxiHPgEGfH
Ic6GQ5wVh/tZHQAvYTlK
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoTkcYOJieoGO2lK8B/yf
CD09egwhfmGHedWTNKj6Bk64eKpQitrHB7wHZr+dfZNPnssBxfwGvgMG7ida
pWcixDdKv5WysuQ/8Oriun1XnqKpZxCAuocbLq5e1PkpKVkAu/oDAhjmn/t2
NqedXxDDPTOUnxzq9RHEcP/XjPD4V0WCGP6FqBPECB+Y+k1gf7DjMJ8Nwz2Q
cGLFcD8kXBHiGlD/QuKBFUf4IMQ3QcMTXT0jNPzRzYfFF7p7UOOXDSM9bETz
L3r6AQBXmu6s
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkApR1g4qFgwIshvnoVCPBh
iEP4AjjUY4pDzBfEYY4QyeIQe7gwxCH2cOIwhwOHOWwY4mFgc1hxmMNCUBzV
vyw4wgfdHExx1PBHiIehxBe6OTwki4di9S8PjvCBmYMenjw4wp/nwCqs8YVI
hwCossy6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoQUcYOKrVwHBK0EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAxu1x2Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoQUcYOKhIHCVB0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwD2Gm4O
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoXkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINJg4AMIBuDQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAphoEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYhocVzm4LIXlztx+QtXOOAKN5g4AORsclg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMAg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdULIMRRgAB29Qz8OMzng4ujuIeBFy5uDAaXCYjz4RDnxyEu
gF28AYc4UjigqkeI4wpPAPzAPD4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0LwODRf4WIv85qOJ8zkw
XHCPs/xahybO78CAAmDiAtjVNwjgMF/QAat7GgQdjMHgMnHiDLjUC+BQj0uc
H4c4Hw5xXuzuB4oDAOdwO7o=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoQUcYOJieoGO2lK8B9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB74Fz387mtPMLOqCY38B3YIbyk0O9
PgjxjdJvpaws+Q98zQiPf1WEpp5BAGJ+A0Ic6g7s6g8IYJgPdQeGe6DqMNwP
NfeABpp/oe7ACB+Y+k0Qf2A3v4EPwz3QcMJwPzRc4eJQdxyAxgP28GFAiEPd
gaGeERr+6ObD4gvdPSjxi+R+WHrYiOZf9PQDAAZF7ik=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoYUcYOKhYMCLIb56FQjw
YYhD+AI41GOKQ8wXxGGOEMniUPMwxKH24zAHUxzqPwzxMEh44DCHh6A4qn95
cIQPujmY4qjhjxAPQ4kvdHN4SBYPxepfHhzhAzMHPTx5cIQ/D474QqRDAJ71
zYU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoUUcYOKrVwHBK0EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgA7sVyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoUUcYOKhIHCVB0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwAeAW5K
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoYUc0MVDQUAUU3z1KiDQ
whQHUw44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnCDiQMAWEls5Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAphpEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYxocVzm4LIXlztx+QtXOOAKN5g4AAxTcpQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMIg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdULIMRRgAB29Qz8OMzng4ujuIeBFy5uDAaXCYjz4RDnxyEu
gF28AYc4UjigqkeI4wpPACSnPHo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCBwAUw1CDg0X+FiL/OajijMI
OzBccI+z/FqHph4ojgJg6kVwqBfBYb6oA3b3iDoYg8Fl4sQZcKkXwaEehzjQ
X9jV4xAHhhuu8AQAgcA+ew==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoUUcYOJieoGO2lK8B9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB74Fz387mtPOLOqCY38B3YIbyk0O9
PgjxjdJvpaws+Q98zQiPf1WEpp5BAGJ+A0Ic4g4B7OoPCGCYD3GHIIZ7IOoE
MdwPMVfwgAaafyHuEMQIH5j6m71lvHPnCGM330EYwz3GnEaTKz4IYbg/4460
bdFmhLgG1L/c01csEO0VwhE+CPFN0PBEV88IDX9082HxZYTmHpT4RXI/LD3c
QPMvevoBAMlQ8Nc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAocUcYOKhYMCLIb56FQjw
YYhD+AI41GOKQ8wXxGGOEMniEPNEMcQh9ovgMAdTHGKOMA5zhHCYQ1gc1b9C
OMIH3RxMcdTwR4iHocQXujk8JItj9y8PjvCBmYMenjw4wp8HR3wh0iEAQQDO
Cg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoUUOwMRDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwAHXnW7
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoUUOwMRDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwC+TXVS
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAocUOoIuvXgUEr0QxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAqyF5HQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAphqEDqCLr14FBFmY4qFg
gCkOphxwmKOFwxxRHOYwEC+Oyxxc9uJyJy5/4QoHXOEGEwcA+hV0bQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0CIHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwBHaEEM
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcBwAUw2iBxou8LEW+c1HFWcQ
PcBwwT3O8msdmnoRqDwMwNSL4FAvjMN84QPY3SN0wBgMLhMnDjQHu3oc4kB3
YlePQxwYDtjVi+Jwv+gBACIhRYY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoUUOwMTF9AIdtaVYD9zs
LeOdO0cYLn5hh3nVkzSoegeEeKpQitrHB6wHjDiNJld8EDqAYn4D24GMO9K2
RZsR4hul30pZWbIf4J6+YoFoL5p6Bg6I+Q0Icf8nQk+PHuPArr6BE8P82W9n
3+ST58Jwj4H7iVbpmVwY7n91cd2+K0+5DtxA8y/EPdwY4QNTr17U+SkpWQS7
+QcQ4nOg7jn77WxOO78ohvtnKD851OsjiuHfrxnh8a+KRHGED0J8EzQ80dUz
QsMf3XxYfJ1Dcw9K/B7ATA8aaP5FTz8ANs392Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoYUOwMRDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBaHuAtTHGK/MA5zRHCYgykOMUcUhzliBMVX
o/hXDEf4oJvDgcMcNgzxMJT4QjeHhWRx7P5lwRE+MHMwxbGHPwuO+EKkQwDg
vNs/
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoQUOwMRDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwDfd3V/
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoQUOwMRDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCWdXUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoYUOoIuvXgUErwQxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAg0l44Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoXkPoIuHgsBVHgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDQznUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AIHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwAfkEDQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcBwAUw2CBxou8LEW+c1HFWcQ
PMBwwT3O8msdmnoBqDwMwNQLYFfPwI/DfL4DWN3DwHvAGAwuEynOh0OcH4e4
AHbxBhziwHDArl4Qu/uB4gCJU0NG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoQUOwMTF9AIdtaVYD2yU
fitlZckPF7+ww7zqSRpUfQMfXDxVKEXt4wPWAxCa9wCK+Q1sByD6EOIQc9kP
QOxBU8/AAXUPQtz/idDTo8c4sKtv4MQwf/bb2Tf55Lkw3GPgfqJVeiYXhvtf
XVy378pTLgz/QtzBjRE+MPXqRZ2fkpIFsJt/ACE+B+qes9/O5rTzC2K4f4by
k0O9PoIY/v2aER7/qkgQe/g0IMQ3QcMTXT0jNPzRzYfF1zk096DE7wHM9KCB
5l/09AMA4Bb7Kw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoXkOwMRDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBaH2MOLIQ5xLx8OcwRwqMcUh5gviMMcIYLi
q1H8K4QjfNDN4cBhDhuGeBhKfKGbw0KyOHb/suAIH5g5mOLYw5/lQBjW+EKk
QwArENq6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoTkOwMRDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCPx3UH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoTkOwMRDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBGxXSe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoXkOoIuHgsBVbgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDG2HUH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoVkPoIuHgsBVFgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwCBHnSe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0BwHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwDP0UBY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0NwHGi7wsRb5zUcT5zrA
cME9zvJrHZo4J5SGAZg4Bw717DjMZzuA3T2sB4zB4DKR4mw4xNlxiHPgEOfE
Ic6FQ5wbh/u5DwAAz7lAWA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoTkOwMTF9AIdtaVYD2yU
fitlZckOF7+ww7zqSRpUfQMbXDxVKEXt4wPWAzAaxXygOpg+mDjMXJg9qO7h
OABzF0zc/4nQ06PHOLCrb+DEMH/229k3+eS5MNxj4H6iVXomF4b7X11ct+/K
Uy4M/0LcwY0RPjD1flB3YTefEy4+B+oemLvQ3Q/Th+5fmD3Yw4cbLr4J6m50
9YxQf6KbDwsXdPegxi8nRnrwR/MvevoBALzM+64=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAo2HioWDAiiG+ehUIsGGI
Q/gcOMzhxBAHG7OKC4c5PCSLw9yLLg5zL3ZzOHCYw4khDnMvdnN4CIqvRvEv
D47wQTeHA4c5bBjiYSjxhW4OC8niq7H6lwVH+MDMQQ9PFhzhz3IgDGt8IdIh
ACEd2e8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoRkOwMRDQeAqN4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBAF3SP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoRkOwMRDQeAqC4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwD3BnQm
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoVkOoIuHgsBVZgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwB3KHSP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoX/tRxdfvQoEfmKIh4IB
pjiExhSHmPMDQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAEWQgeQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AwHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwCAIT/g
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0MwHGi7wsRb5zUcTZzrA
cME9zvJrHZo4I5SGAZg4Aw71//ZjN//Pfuzu+bXfGAwuEyn+B4f4PxziDAew
izPiEGfCIc58AFd4AgC3f0XO
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoRkOwMTF9AIdtaVYDySZ
3zItKfq3HyZ+YYd51ZM0mPq/cPFUoRS1jw9YD5xSOeHz6ODv/SjmN7AdWFCY
/+XE2V9w8Y3Sb6WsLNkP6MQsagoz+YWqnoEDaj5C3P+J0NOjxziwq2/gxDB/
9tvZN/nkuTDcY+B+olV6JheG+19dXLfvylMuDP9C1HFjhA9MvR/YXQhxFPMb
GOHic6DugbiL6QC6+yH6EOIw/0LsQVMPDx9muPgmaHiiq2eEhj+6+bD4QncP
SvwiuR+WHvzR/IuefgDqAgpL
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoX/sh4mHggErhvjqVSDA
hiEO4XPgMIcTQxxszCouHObwkCwOMe8XhjjE/r84zGE4gF09I4Y4xHwmDHFY
+BESX43iX4Q4avigm8OBwxw2DPEwlPhCN4eFZPHVWP3LgiN8YOaghyfLgTCs
4Q8zHz2+EOkQABmM5dU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoT/sh4mHgsBVbgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgCNV4KQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoT/sh4mHgsBVFgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgBEVYIn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoX/sRxdfvQoEvmOIh4IB
pjiExhSHmPMNQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcADGkgcY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoZ/sRxcPCwWBxxjiq8Dg
EYY4hMYUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRtMHABgaYCM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0B/2N1zgYy3ymw8V54KL
M1xwj7P8WgcV50SIowAOHOrZcZjPBhdHdQ8rXNwYDC4TEGfDIc6OQ5wDhzgn
DnEuHOKIcMMVngDNYU3h
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0N/2N1zgYy3ym48m/mU/
wwX3OMuvdWjin/YzoACY+Acc6t/gMP/FfuzuebLfGAwuEyn+Aof4GxziH3CI
f8Ih/gWH+Dcc7v+2HwC8P03M
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoT/sh4mL6QU6akuxHjia
tyX7xZM3cPELO8yrnqTB1L+Ci6cKpah9fMB6YIrnhJlHmp/vRzG/ge2Aw+N7
LybOfgoX3yj9VsrKkv1AxA4X1rUZT1DVM3BAzUeI+z8Renr0GAd29Q2cGObP
fjv7Jp8814HJaO4xcD/RKj2T68B/MHgJF391cd2+K0+5DhxB8y/EHdwY4QNT
P/eE6qnu3o8Y5kPUf4aLz4G6x+y2+WZZuy8Y7k/om8BtbvQVw79XFsfWrjz9
FUf4fIOLb4KGJ7p6Rmj4o5sPiy9098DilxHN/bD0MB/Nv+jpBwDQbhkR
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoR/sh4mHggErhvjqVSDA
hiEO4XPgMIcTQxxszCouHObwkCwOsecphjjEnlc4zPmAQ/0nHOZ/xWHOD4Li
q1H8+wNH+KCbw4HDHDYM8TCU+EI3h4Vk8TCs/mU5sBpr+MDMQQ9PmHr08IeZ
jx5fiHQIAIzi8ts=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DnAAAUw8VAQuMqNIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUB0l9pTw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD3AAAUw8VAQuMqCIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUBiV1o5g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoR/sRxdfvQoE7mGIh4LB
XQxxCH0Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7jBxAEkqYA0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoW/Yo4uHgsFNDPHVq0Dg
FoY4hL6Dw5y7GOJgY1bdw2HOA6LFV+MwB5e9uNyJy19hOMIBV7jBxAEvfnis

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB9ggIKGC3ysRX7zoeJccHGG
C+5xll/roOKcCHEUwIFDPTsO89ng4qjuYYWLG4PBZQLibDjE2XGIc+AQ58Qh
zoVDHBFuuMITABJ4NKA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0Df2N1zgYy3ym48mfmE/
wwX3OMuvdWjiB/YzoACYOEgLVvX2OMy3x+Eee2MwuEyk+AUc4gdwiDMw4FC/
H4f5OMRv7McVngAiskXI
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD3AAAUwcTG9QEdtKdYDNzpj
Fu25scMeJn5hh3nVkzTWA//B4DhcPFUoRe3jA9YDN3Punyn7ccEexfwGtgMN
lk56d05cgYtvlH4rZWXJfsC/v+zrUr3rqOoZOKDuuQEX938i9PToMY4DAdjU
N3BimD/77eybfPJcB26hucfA/USr9EyuAyxgjSfg4q8urtt35SnXgQdo/oW4
g/sAV9c8H8vKLht09ecg6vejm/8HEj5w8TlQ91yHuGc/uvvrIO7fj+5fP4h/
9+MIH7j4Jmh4BqCpZ4SGfxOa+bD4uoXmHlj8skHCZz96eniH5l9Y+oGEz6w9
AMp8HmA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoR/Yw8RDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBYPA9tzFYf4URzmoIcDz4EQiPr92MWvYohD
3UNQfDWqf/fjCJ/9OMJzP47wh4uHocbXfhzxS7R4GFb/wsTRwwdmDma6CsEa
/jBx9PhCpEMAQT/fJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoT/Yw8RDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCZjHsQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoT/Yw8RDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBQinqn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoR/Yo4uvAgNM8bBQEHiI
IQ6hH+EwB1McbEzoYxzmPCFaPAyHObjsxeVOXP5ajSMccIUbTBwAa0Z5CA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAob/Zo4uHggGm+OpVIIAp
DqG/4zAHUxxszCpMcQj9g2jx1TjMwWUvLnfi8lcYjnDAFW4wcQA8hXpE
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0B/sGy7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwDZlkZh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0E/sGy7wsRb5zUcTf2HP
cME9zvJrHZr4GygfBmDiH3Co/4TD/C/22N3zzd4YDC4TKf4Fh/gnHOIfcIi/
wSH+Aof4Exzuf2IPAMhQRjo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoT/Yw8TF9AIdtaVYD8w7
oXqqu/cjXPzCDvOqJ2kw9Z/h4qlCKWofH7AeMLttvlnW7os9ivkNbAcS+iZw
mxt9hYtvlH4rZWXJfuDK4tjalae/oqpn4ICa/w0u7v9E6OnRYxzY1TdwYpg/
++3sm3zyXBjuMXA/0So9kwvD/a8urtt35SkXhn8h6rgxwgem/ljeluwXT95g
mM8IVv8KLj4H6p4pnhNmHml+juF+x8f3Xkyc/RTDv5E7XFjXZjzBET4I8U3Q
8IxAU88IDX97NPNh8TUZzT2w+P33HwReYqSHQ2j+haUfsPL/7+0BNwwSiQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoX/Yw8RDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBYPA9vzFUMc4t5POMz5gEP9KxzmP8VhzgOC
4qtR/PsAR/igm8OBwxw2DPEwlPhCN4eFZPFQrP5lObAKa/jAzEEPT5h69PCH
mY8eX4h0CACno+Tb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoRkcYOKhIHCVG0N89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBMTG0P
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoRkcYOKhIHCVBUN89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwADSmym
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoX/Yo4uHggGm+OpVIIAp
DqF/4jAHUxxszCpMcQj9i2jx1TjMwWUvLnfi8lcYjnDAFW4wcQBQcXpi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoZkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINJg4Ag1ttDg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AwODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwCMVjhg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0L/sGy7wsRb5zUcT/2PP
cME9zvJrHZr4PygfBmDiDA7Y1TM6YDefyQG7e5gdjMHgMpHiTDjEGXGIM+AQ
/2ePXfwPDvFf9rjCEwDFoT9E
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoRkcYOJieoGO2lKsB/yf
CD09egwhfmGHedWTNKj6Bka4eKpQitrHB6wHZr+dfZNPnskBxfwGtgMG7ida
pWcixDdKv5WysmQ/8Oriun1XnqKpZ+CAuocZLg5xBwd29Q2cGOZD3MGF4R6I
Oi4M90PM5cLwL8Qd3BjhA1OfbH7LtKTonz1W8xn+wsXnQN1zSuWEz6ODv+3R
3b+gMP/LibO/7NH9qxOzqCnM5Jc99vBBiG+Chie6ekZo+KObD4svdPfA4vc/
GPyxR08PiWj+RU8/AB6yA8U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkApR1g4qFgwIohvnoVCLBh
iEP4HDjM4cQQBxuziguHOTwki0PcxYQhDrGfEYc5DBjiYWD1f+2xm/8LQxxC
/yAovhrFvwhx1PBBN4cDhzlsGOJhKPGFbg4LyeKrsPqXBRqe6OEDMwc9PFlw
hD/MfPT4QqRDAJ1X19U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoTkcYOKhIHCVG0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCb/G2H
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoTkcYOKhIHCVBUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBS+m0e
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoVkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINJg4AjVFtHQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAobkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINJg4A0wtthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0BwODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwDcBjjY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0KwODRf4WIv85qOJszkw
XHCPs/xahybO7sCAAmDiHDjUc+Iwn8sBu3u4HYzB4DKR4lw4xDlxiHPgEGfH
Ic6GQ5wVh/tZHQDb4jjS
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoTkcYOJieoGO2lKsB/yf
CD09egwhfmGHedWTNKj6Bk64eKpQitrHB6wHZr+dfZNPnssBxfwGtgMG7ida
pWcixDdKv5WysmQ/8Oriun1XnqKpZ+CAuocbLg51B3b1DZwY5kPdgeEeqDoM
90PNxfAv1B0Y4QNTvwniDxzms8HF50DdAw0nDPdDwxXDv9B4wBE+CHGoOzDU
M0LDH918WHyhuwc1ftkw0sNGNP+ipx8A87DvMA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoXkcYOKhYMCKIb56FQiw
YYhD+Bw4zOHEEAcbs4oLhzk8JItD3MWFIQ61H4c5HDjMYcMQD4OEBw5zWAiK
r0bxLwuO8EE3hwOHOWwY4mEo8YVuDgvJ4qFY/cuCI3xg5qCHJwuO8Gc5sApr
fCHSIQCmL8vv
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoQUcYOKhIHCVG0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwDrrG3/
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoQUcYOKhIHCVBUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCiqm2W
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoXkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINJg4A3QFtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAphoEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYhocVzm4LIXlztx+QtXOOAKN5g4AJD8ceA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AIODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwArxTlQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0LwODRf4WIv85qOJ8zkw
XHCPs/xahybO78CAAmDiAtjVNwjgMF/QAat7GgQdjMHgMnHiDLjUC+BQj0uc
H4c4Hw5xXuzuB4oDAJQAO0I=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoQUcYOJieoGO2lKsB9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB64Fz387mtPMLOqCY38B2YIbyk0O9
PgjxjdJvpaws2Q98zQiPf1WEpp6BA2J+A0Lc/4nQ06PHOLCrb+DEMH/229k3
+eS5MNxj4H6iVXomF4b7X11ct+/KU64DGmj+hbiHGyN8YOo3gf3Bj938Bj64
+ByoeyDhxIvhfki48mL4FxIPvNjDhwEhvgkanujqGaHhj24+LL7Q3YMSv0ju
h6WHjWj+RU8/AKJb7q0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoYUcYOKhYMCKIb56FQiw
YYhD+Bw4zOHEEAcbs4oLhzk8JItD7BHEEIe4VwCHOZjiEPV8GOJhYPN5cZjD
Q1B8NYp/eXCED7o5HDjMYcMQD0OJL3RzWEgWD8XqXxYc4QMzBz08WXCEPwuO
+EKkQwCccsy6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoUUcYOKhIHCVG0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwATk247
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoUUcYOKhIHCVBUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwDKgm3S
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoYUc0MVDQUAUU3z1KiDQ
whQHUw44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnCDiQMABNlsbQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAphpEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYxocVzm4LIXlztx+QtXOOAKN5g4ALjUchw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0CIODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwBTnTmM
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcBwAUw1CDg0X+FiL/OajijMI
OzBccI+z/FqHph4ojgJg6kVwqBfBYb6oA3b3iDoYg8Fl4sQZcKkXwaEehzjQ
X9jV4xAHhhuu8AQALlA+Aw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoUUcYOJieoGO2lKsB9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB64Fz387mtPOLOqCY38B2YIbyk0O9
PgjxjdJvpaws2Q98zQiPf1WEpp6BA2J+A0Lc/4nQ06PHOLCrb+DEMH/229k3
+eS5MNxj4H6iVXomF4b7X11ct+/KU64DGmj+hbiHGyN8YOpv9pbxzp0jjN18
B4T4HKh7jDmNJld8EMJwf8YdaduizUIY/uWevmKBaK8QjvBBiG+Chie6ekZo
+KObD4svIzT3oMQvkvth6eEGmn/R0w8AZXXxWw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAocUcYOKhYMCKIb56FQiw
YYhD+Bw4zOHEEAcbs4oLhzk8JItD7BHFEIe4VwSHOZjiEHOEcZgjhMMcwuKr
UfwrhCN80M3hwGEOG4Z4GEp8oZvDQrI4dv+y4AgfmDno4cmCI/xZcMQXIh0C
AD59zT8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoUUOwMRDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCz33VD
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQoscgImvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAOzvgpg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChxA6gi69eBQSvRDHEQ0Hg
KqY4hMQUB5uzCoc5U3GY00C8OC5zcNmLy524/IUrHHCFG0wcAFexeKU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAAmG4QOoIuvXgUEWZjioWCA
KQ4mHXCYo4XDHFEc5jAQL47LHFz24nInLn/hCgdc4QYTBwCmpXP1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0CIHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAFreRoI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHACTDaIHGi7wsRb5zUcVZxA9
wHDBPc7yax2aehGoPBxA+SI41AvjMF/4AHb3CB0wBoPLxIkDzcGuHoc40J3Y
1eMQB4YDdvWiONwvegAAzqJFDg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQoscgInrxCxqCjP5tf9m
bxnv3DnCcPEFhflfTpyFqndAiJ9SOeHz6ODv/UacRpMrPggdQDX/7/6MO9K2
RZsR4knmt0xLiv7t556+YoFoL7p6hgNgsgEh7v9E6OnRYwwHsKpvYDyAbv7s
t7Nv8skzHUB3j4H7iVbpmUwH0N3/6uK6fVeeMh24geZfiHOYD6CHD0y9elHn
p6RkEezmH0CIz4G65+y3sznt/KIY7p+h/ORQr48ohn+/ZoTHvyoSxRE+CPFk
aHiiq2eEhj+6+bD4OofmHpT4PYCZHjTQ/IuefgBdAw1y
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQgsdgImvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcQifhWTx1WDzMMUh9gvjMEcEhzmY4hBzRHGYI0ZQ
fDWKf8VwhA+6OQwY4mEo4Y9u/i8McdT4JV4cu39/7McePjBzMMWxhz/MHPT4
QqRDAJWk5yU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoQUOwMRDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCMB3UH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQgscgImvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAMUXglw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChhA6gi69eBQSvBDHEQ0Hg
KqY4hMQUB5uzCoc5U3GY00C8OC5zcNmLy524/IUrHHCFG0wcAC/ZeGk=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOACheA+gi4eCwFUeDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAH1edJ4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AIHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnADMGRkY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHACTDYIHGi7wsRb5zUcVZxA8
wHDBPc7yax2aegGoPBxA+QLY1TPw4zCf7wBW9zDwHjAGg8tEivPhEOfHIS6A
XbwBhzgwHLCrF8TufqA4ADXjQs4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQgscgInrxCxqCjP5tX+j
9FspK0t+uPiCwvwvJ85C1TfwwcVPqZzweXTw9/5UoRS1jw94D6Ca/3f/hR3m
VU/SEOJJ5rdMS4r+7RfTC3TUlkJXz3AAQiHE/Z8IPT16jOEAVvUNjAfQzZ/9
dvZNPnmmA+juMXA/0So9k+kAuvtfXVy378pTpgPo/oW4g/kAevjA1KsXdX5K
ShbAbv4BhPgcqHvOfjub084viOH+GcpPDvX6CGL492tGePyrIkHs4dOAEE+G
hie6ekZo+KObD4uvc2juQYnfA5jpQQPNv+jpBwAGWwrE
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQvMcgImvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcQifhWRxiD28GOKrwfbw4TBHAId6THGI+YI4zBEi
KL4axb9COMIH3RwGDPEwlPBHN/8Xhjhq/BIvjt2/P/ZjDx+YOZji2MP/x/4w
rPGFSIcA3+nmoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoTkOwMRDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwA8V3SP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQnMcgImvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAHVngeQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOACheA6gi4eCwFVuDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAHNodI8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChWA+gi4eCwFUWDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAC2udCY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0BwHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAONHRc4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQ3AcaLvCxFvnNRxPnOsBw
wT3O8msdmjgnlIYDKJ8Dh3p2HOazHcDuHtYDxmBwmUhxNhzi7DjEOXCIc+IQ
58Ihzo3D/dwHAHxJP+A=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQnMcgInrxCxqCjP5tX+j
9FspK0t2uPiCwvwvJ85C1TewwcVPqZzweXTw9/5UoRS1jw9YD6Ca/3f/hR3m
VU/SEOJJ5rdMS4r+7RfTC3TUlkJXz3AAQiHE/Z8IPT16jOEAVvUNjAfQzZ/9
dvZNPnmmA+juMXA/0So9k+kAuvtfXVy378pTpgPo/oW4g/kAevjA1PuB3cWB
w3xOuPgcqHsg7uLCcD9EHxeGfyH2cOEIH264eDI0PNHVM0LDH918WHyhuwc1
fjkx0oM/mn/R0w8A4wILRw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQrMcgImvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcRifVHGIPawY4qvB9rDhMIcDhzmcGOIQ93LhMIeH
oPhqFP/y4AgfdHMYMMTDUMIf3fxfGOKo8Uu8+Gqs/v2xH3v4wMxBD0+YOejh
/2N/GNb4QqRDANX25dU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoRkOwMRDQeAqM4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwDsmHQX
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQjMcgImvXgUCPzHEQ8EA
UxzCxRSHmPMDQzwMbA6mOIRLvHgoDnNw2YvLnbj8tQpHOOAKN3RxACW3gWw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChWA6gi4eCwFVmDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDACO4dBc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChfu1HF1+9CgR+YoiHggGm
OITCFIeY8wNDPAxsDqY4hCJePBSHObjsxeVOXP5ahSMccIUbTBwA8hGBbA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AwHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAJOXRVY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQzAcaLvCxFvnNRxNnOsBw
wT3O8msdmjgjlIaDA3Aaq/p/+7Gb/2c/dvf82m8MBpeJFP+DQ/wfDnGGA9jF
GXGIM+EQZz6AKzwBZA9FVg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQjMcgInrxCxqCjP5tT/J
/JZpSdG//TDxBYX5X06chan/Cxc/pXLC59HB3/thNKr5f/fD9MHEYebC7EFV
z3AA5i6YuP8ToadHjzEcwKq+gfEAuvmz386+ySfPdADdPQbuJ1qlZzIdQHf/
q4vr9l15ynQA3b8QdcwH0MMHpt4P6i6s5gPdBROfA3UPzF3o7ofpQ/cvzB7s
4cMMF0+GuhtdPSPUn+jmw8IF3T0o8Yvkfli4+6P5Fz39AAAQRxnV
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfRsPEV4HBLwzxUDD4iyEO
4TMcwK6eEUMcYj4ThjiEz0KyOMy96OIw92I3h+EAdvWMGOIw92I3h4Wg+GoU
/yLEUcMH3RwGDPEwlPBHN/8Xhjhq/BIvvhqrf3/sxx4+MHPQw/PH/jCs4Q8z
Hz2+EOkQAM5l8bs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoT/sh4mHgsBVZgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgA554IY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQn/YDxNfvQoEfmKIh4IB
pjiEjykOMecHhngY2BxMcQifePFQHObgsheXO3H5axWOcMAVbujiAHL3j20=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChfuxHF1+9CgS+Y4iHggGm
OITCFIeY8w1DPAxsDqY4hCJePBSHObjsxeVOXP5ahSMccIUbTBwA3iWBTg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChnuxHFw8LBYHHGOKrwOAR
hjiEwhSHmPMQQ3w12JwHOMwhXnwVDnNw2YvLnbj8FYojHHCFG0wcAAz5gBQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0B/2N1zgYy3ymw8VZ4KL
M1xwj7P8WgcVZ0SIowIc6v/tx27+H7g4qnt+wcWNweAyAfE/OMT/4RBHuBNV
nBGHOBMOcUS44QpPAODXU1c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQ3/Y3XOBjLfKbjyb+ZT/D
Bfc4y691aOKf9jOgAqj4Bxzq3+Aw/8V+7O55st8YDC4TKf4Ch/gbHOIfcIh/
wiH+BYf4Nxzu/7YfAGjPTVQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQn/YDxPXiVnUFGbya//R
vC3ZL568gYsvKMz/cuIsTP0ruPgplRM+jw7+3j/Fc8LMI83P96Oa/3e/w+N7
LybOfgoXTzK/ZVpS9G9/xA4X1rUZT9DUMxyAUAhx/ydCT48eYziAVX0D4wF0
82e/nX2TT57pwGQ09xi4n2iVnsl04D8YvISLv7q4bt+Vp0wHjqD5F+IO5gPo
4QNTP/eE6qnu3o8Y5kPUf4aLz4G6x+y2+WZZuy8Y7k/om8BtbvQVw79XFsfW
rjz9FUf4fIOLJ0PDE109IzT80c2HxRe6e2Dxy4jmflh6mI/mX/T0AwD2pCib

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQj/YDxNfBQa/MMRDweAv
hjiEz3AAu3pGDHGI+UwY4hA+C8niEHueYohD7HmFw5wPONR/wmH+Vxzm/CAo
vhrFvz9whA+6OQwY4mEo4Y9u/i8McdT4JV48DKt/f+xfjTV8YOaghydMPXr4
w8xHjy9EOgQAQcr+wQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDnAAAUw8VAQuMqMIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUBfu9o1w==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LWfAQpg4qtXgcBPDPFQMMAU
h/AwxSHm/MAQDwObgykO4REvHorDHFz24nInLn+twhEOuMINXRwAt/92LA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChHuxHF1+9CgTuYYiHgsFd
DHEIdQeHObcwxMPA5tzEYc4NosVDcZiDy15c7sTlr1U4wgFXuMHEAdEqf7w=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChbtiji4eCwU0M8dWrQOAW
hjiEuoPDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuMHEAdv/eDQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB9ggIKGC3ysRX7zoeJMcHGG
C+5xll/roOKMCHFUgEP9v/3Yzf8DF0d1zy+4uDEYXCYg/geH+D8c4gh3oooz
4hBnwiGOCDdc4QkAJe46Fg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQN/Y3XOBjLfKbjyZ+YT/D
Bfc4y691aOIH9jOgggNwFnb19jjMt8fhHntjMLhMpPgFHOIHcIgzMOBQvx+H
+TjEb+zHFZ4AzzNFUA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LWfAQpg4joxi5rCTH7tv9EZ
s2jPjR32MPEFhflfTpz9tf8/GByHi59SOeHz6ODv/Tdz7p8p+3HBHtX8v/sb
LJ307py4AhdPMr9lWlL0b79/f9nXpXrX0dQzHIBQN+Di/k+Enh49xnAgAJv6
BsYD6ObPfjv7Jp8804FbaO4xcD/RKj2T6QALWOMJuPiri+v2XXnKdOABmn8h
7mA+wNU1z8eysssGXf05iPr96Ob/gYQPXHwO1D3XIe7Zj+7+Ooj796P71w/i
3/04wgcungwNzwA09YzQ8G9CMx8WX7fQ3AOLXzZI+OxHTw/v0PwLSz+Q8Jm1
BwDwsi3q
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQj+wh4mvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcQifhWTxMLA9V3GIH8VhDno4sBwIgajfj138KoY4
1D0ExVej+nc/jvDZjyM84eJhqOGPZv4vDHG0+CVaPAyrf2Hi6OEDMwczXYVg
DX+YOHp8IdIhAPYY6ws=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoT/Yw8RDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBGHHqY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQn+wh4mvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAH8sh+0=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChHtiji68CA0zxsFAQeIgh
DqEe4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRtMHAAX1niQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChvtmji4eCAab46lUggCkO
ob7jMAdTHGzMKkxxCPWDaPHVOMzBZS8ud+LyVxiOcMAVbjBxAOkGecw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0B/sGy7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAO0MS9c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQT+wbLvCxFvnNRxN/Yc9w
wT3O8msdmvgbGJ8BVfwDDvWfcJj/xR67e77ZG4PBZSLFv+AQ/4RD/AMO8Tc4
xF/gEH+Cw/1P7AF04EXC
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQn+wh4nrxCxqCjP5tX/e
CdVT3b0f4eILCvO/nDgLU/8ZLn5K5YTPo4O/95vdNt8sa/fFHtX8v/sT+iZw
mxt9hYsnmd8yLSn6t//K4tjalae/oqlnOAChvsHF/Z8IPT16jOEAVvUNjAfQ
zZ/9dvZNPnmmA+juMXA/0So9k+kAuvtfXVy378pTpgPo/oWoYz6AHj4w9cfy
tmS/ePIGw3xGsPpXcPE5UPdM8Zww80jzcwz3Oz6+92Li7KcY/o3c4cK6NuMJ
jvBBiCdDwzMCTT0jNPzt0cyHxddkNPfA4vfffxB4iZEeDqH5F5Z+wMr/v7cH
AF1CIhM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfStvDxFeBwS8M8VAw+Ish
DuEzHMCunhFDHGI+E4Y4hM9CsngY2J6vGOKrwfZ8wmHOBxzqX+Ew/ykOcx4Q
FF+N4t8HOMIH3RwGDPEwlPBHN/8Xhjhq/BIvHorVvz/2r8IaPjBz0MMTph49
/GHmo8cXIh0CAFyL8ME=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoRkcYOKhIHCVGUN89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwD4zWyX
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQjM4wMRXrwKBnxjioWCA
KQ7hYopDzPmBIR4GNgdTHMIlXjwUhzm47MXlTlz+WoUjHHCFG7o4ADHseew=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChftiji4eCAab46lUggCkO
oX7iMAdTHGzMKkxxCPWLaPHVOMzBZS8ud+LyVxiOcMAVbjBxAPzyeeo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChmB3QxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYWAhWhyXObjsxeVOXP7CFQ64wg0mDgAv62yW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AwODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAJ/MPdY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQv+wbLvCxFvnNRxP/Y89w
wT3O8msdmvg/GJ8BVZzBAbt6Rgfs5jM5YHcPs4MxGFwmUpwJhzgjDnEGHOL/
7LGL/8Eh/sseV3gCAHIxPsw=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQjM4wMR1YhY1hZn82u//
ROjp0WMI8QWF+V9OnIWqb2CEi59SOeHz6ODv/bPfzr7JJ8/kgGr+3/0G7ida
pWcixJPMb5mWFP3b/+riun1XnqKrZzgAoZjh4lB3HMCqvoHxALr5UHccQHcP
VN0BdPdDzT2A7l+oOw6ghw9MfTLEH/ZYzWf4CxefA3UPNJzs0d0PDVd7dP9C
48Eee/ggxKHu2I+unhEa/ujmw+IL3T2w+P0PBn/s0dNDIpp/0dMPAEToE08=

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQrM4wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOJRPsvhqiHkY4lD7cZjDgCEeBvGfPXbzf2GIQ8OP
oPhqFP8ixFHDB90cBgzxMJTwRzf/F4Y4avwSL74Kq39/7A/FGj4wc9DDE6Ye
Pfxh5qPHFyIdAgBSP+O7
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoTkcYOKhIHCVGUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBIjG0P
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQnM4wMRXrwKBnxjioWCA
KQ7hY4pDzPmBIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4AIGcemQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChWBzQxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYWAlWhyXObjsxeVOXP7CFQ64wg0mDgA54Wyl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChuB3QxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYeAhWhyXObjsxeVOXP7CFQ64wg0mDgB/m20O
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0BwODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAO98Pk4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQrA4NF/hYi/zmo4mzOTBc
cI+z/FqHJs7uwIAKoOIcONRz4jCfywG7e7gdjMHgMpHiXDjEOXGIc+AQZ8ch
zoZDnBWH+1kdAIhyOFo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQnM4wMR1YhY1hZn82u//
ROjp0WMI8QWF+V9OnIWqb+CEi59SOeHz6ODv/bPfzr7JJ8/lgGr+3/0G7ida
pWcixJPMb5mWFP3b/+riun1XnqKrZzgAobjh4hB3MBzAqr6B8QC6+RB3MB1A
dw9EHdMBdPdDzGU6gO5fiDuYD6CHD0z9Jum3UlaW7DjMZ4OLz4G6J1UoRe3j
A1YM91/YYV71JI0Vw79ieoGO2lKsOMIHIZ4MDU909YzQ8Ec3HxZf6O5BjV82
jPSwEc2/6OkHABn1/ro=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQvM4wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOITPQrL4arB5XBjiEPs5cZjDgcMcNgzxMLA5rDjM
YSEovhrFvyw4wgfdHAYM8TCU8Ec3/xeGOGr8Ei8eitW/P/ZjDx+YOejhCTMH
Pfx/7F+FNb4Q6RAAWxfX1Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoQUcYOKhIHCVGUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCYPG2H
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQgs4wMRXrwKBnxjioWCA
KQ7hY4pDzPmBIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4ANFMetw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOACheBzQxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYeAlWhyXObjsxeVOXP7CFQ64wg0mDgCJkW0d
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAAmGwQd0MVDQWAqpvjqVSCA
KQ4hcZhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRtMHAA9jHFo
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AIODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAD87PsY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQvA4NF/hYi/zmo4nzOTBc
cI+z/FqHJs7vwIAKoOIC2NU3COAwX9ABq3saBB2MweAyceIMuNQL4FCPS5wf
hzgfDnFe7O4HigMAQJA6yg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQgs4wMR1YhY1hZn82q9e
1PkpKRkhvqAw/8uJs1D1BxDip1RO+Dw6+Hv/uW9nc9r5BR1Qzf+7f4byk0O9
PgjxJPNbpiVF//Z/zQiPf1WErp7hAJhsQIj7PxF6evQYwwGs6hsYD6CbP/vt
7Jt88kwH0N1j4H6iVXom0wF097+6uG7fladMBzTQ/AtxDvMB9PCBqd8k/VbK
ypIfu/kNfHDxOVD3pAqlqH18wIvh/gs7zKuepPFi+FdML9BRW4oXe/gwIMST
oeGJrp4RGv7o5sPiC909KPGL5H5YetiI5l/09AMAyJH+Nw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQgs5wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOITPQrI4xB5BDPHVYHsEcJiDKQ5Rz4chHgY2nxeH
OTwExVej+JcHR/igm8OAIR6GEv7o5v/CEEeNX+LFQ7H698d+7OEDMwc9PGHq
McWxxxciHQIAUVrYoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoUUcYOKhIHCVGUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwDAFG3D
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQos4wMRXrwKBnxjioWCA
KQ7hY4pDzPmBIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4APkkexg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChhBzQxUNBQBRTfPUqINDC
FAeTDjjMCcVhThYOcxqIF8dlDi57cbkTl79whQOucIOJAwCxWmv1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAAmG0Qd0MVDQWAqpvjqVSCA
KQ4hcZhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRtMHABlZHGk
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0CIODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAGcTPwI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHACTDUIODRf4WIv85qOKMwg7
MFxwj7P8WoemHiiOCqDqRXCoF8FhvqgDdveIOhiDwWXixBlwqRfBoR6HONBf
2NXjEAeGG67wBADa0T2L
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQos4wMR1YhY1hZn82q9e
1PkpKRkhvqAw/8uJs1D1BxDip1RO+Dw6+Hv/uW9nc9r5RR1Qzf+7f4byk0O9
PgjxJPNbpiVF//Z/zQiPf1WErp7hAJhsQIj7PxF6evQYwwGs6hsYD6CbP/vt
7Jt88kwH0N1j4H6iVXom0wF097+6uG7fladMBzTQ/AtxDvMB9PCBqb/ZW8Y7
d44wdvMdEOJzoO4x5jSaXPFBCMP9GXekbYs2C2H4l3v6igWivUI4wgchngwN
T3T1jNDwRzcfFl9GaO5BiV8k98PSww00/6KnHwCLqwD0
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQos5wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOITPQrI4xB5RDPHVYHtEcJiDKQ4xRxiHOUI4zCEs
vhrFv0I4wgfdHAYM8TCU8Ec3/xeGOGr8Ei+O3b8/9mMPH5g56OEJMwdTHHt8
IdIhAPNW2SU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQoscgImvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxANgTgno=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQoscgImHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OAD9CIFA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQosdQBdfvQoIXoliiIeC
wFVMcTB1AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVuMHEAFQiGpg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfTDUIHUAXX70KCLIwxUPB
AFMcTDngMEcLhzmiOMxhIF4clzm47MXlTlz+whUOuMINJg4AY/yB9g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoUUONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxAJ+OToA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPphpEDzRc4GMt8puPKs4g
eoDhgnuc5dc6NPUiBxhQAEy9CA71wjjMFz6A3T1CB4zB4DJx4kBzsKvHIQ50
J3b1OMSB4YBdvSgO94seAACL+VMP
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQoscgIlH7HBhXZvxZP/N
3jLeuXOE4eIOj++9mDj7KUS9A0J8sueEmUean+834jSaXPFB6ACq+a/2Z9yR
ti3ajBA/krcl+8WTN/u5p69YINqLrv4DxPwGhPjcE6qnuns/4lD/GcN8s9vm
m2XtvmC4J6FvAre50VcM919ZHFu78vTX/TfQ/Asx/xtG+MDUqxd1fkpKFsFu
/gGEuDnUPWe/nc1p5xeFizNC3T9D+cmhXh+E+Hyof79mhMe/KhLFET4I8WPQ
8ERXzwQNf3Tzp0Dj6xyaexyR4xfJ/ZHQ9KCB5l/09AMAY88VPA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQgsdgImHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksVXg+3BFIfYI4zDHBEc5mCKQ8wRxWGOGEHxMBT/
IsRXo4QPujkfcKh/hcP8pzjMeUCyOHb/PsARPg9whOcDHOH/AEd8IdIhALa/
9Cs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQgscgImvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxALA7gj4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQgscgImHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OADVMIEE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQgsdQBdfvQoIXgliiIeC
wFVMcTB1AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVuMHEA7SGGag==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQvMeQBcPBYGrPBjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwA6tYKf
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoQUONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxAHe2TkQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPphoEDzRc4GMt8puPKs4g
eIDhgnuc5dc6NPUCBxhQAEy9AHb1DPw4zOc7gNU9DLwHjMHgMpHifDjE+XGI
C2AXb8AhDgwH7OoFsbsfKA4A8ytQzw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQgscgIlH7HBhXZvxZP9G
6bdSVpb8cHGHx/deTJz9FKK+gQ8uPtlzwswjzc/3pwqlqH18wHsA1fxX+y/s
MK96koYQP5K3JfvFkzf7xfQCHbWl0NV/gLoHIT73hOqp7t6PONR/xjDf7Lb5
Zlm7LxjuSeibwG1u9BXD/VcWx9auPP0Vw78Q879hhA9MvXpR56ekZAHs5h9A
iJtD3XP229mcdn5BuDgj1P0zlJ8c6vVBiM+H+vdrRnj8qyJB7OHTgBA/Bg1P
dPVM0PBHN38KNL7OobnHETl+kdwfCU0PGmj+RU8/AA0nEo4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQvMcgImHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksUh5vFiiK8G28+HwxwBHOoxxSHmC+IwR4igeBiK
fxHiq1HCB92cDzjUv8Jh/lMc5jwgWRy7fx/gCJ8HOMLzAY7wf7A/DGt8IdIh
AAET86Y=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQnMcgImvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAGCLgcY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQnMcgImHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OACFgICM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQvMcQBcPBYGr3Bjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwAwv4KQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQrMeQBcPBYGrLBjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwDq9oIn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoTkONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxACgGTcw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPobkPNFzgYy3ym48mznWA
4YJ7nOXXOjRxzgMMKAAmzoFDPTsO89kOYHcP6wFjMLhMpDgbDnF2HOIcOMQ5
cYhz4RDnxuF+7gMAOaBN4Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQnMcgIlH7HBhXZvxZP9G
6bdSVpbscHGHx/deTJz9FKK+gQ0uPtlzwswjzc/3pwqlqH18wHoA1fxX+y/s
MK96koYQP5K3JfvFkzf7xfQCHbWl0NV/gLoHIT73hOqp7t6PONR/xjDf7Lb5
Zlm7LxjuSeibwG1u9BXD/VcWx9auPP0Vw78Q879hhA9Mvd8ToadHj3HgMJ8T
Lm4Odc/st7Nv8slzwcUZoe43cD/RKj0TIT4f6t9XF9ftu/KUC0f4cMPFj0HD
E109EzT80c2fAo0vdPc4osQvwv2R0PTgj+Zf9PQDAOnOExE=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQrMcgImHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksUh5rFiiK8G28+GwxwOHOZwYohD/MGFwxweguJh
KP5FiK9GCR90cz7gUP8Kh/lPcZjzgGTx1Vj9+wBH+DzAEZ4PcIT/g/1hWOML
kQ4B9xHy2w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQjMcgImvXgUC3zHEQ8EA
UxzCxRSHmPMNQzwMbA6mOIRLvHgoDnNw2YvLnbj8tQpHOOAKN3RxABDbgU4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQjMcgImHhYLAYwzxVWDw
CEMcwsUUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OAA10IAU

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQrMcQBcPBYGrzBjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwDhAIIY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQv/ajy6+ehUI/MQQDwUD
THEIjSkOMecHhngY2BxMcQhNvHgoDnNw2YvLnbj8tQpHOOAKN5g4AK9oj20=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoRkONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxANhHTVQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoZkPNFzgYy3ym48mznSA
4YJ7nOXXOjRxxgMMKAAmzoBD/b/92M3/sx+7e37tNwaDy0SK/8Eh/g+HOMMB
7OKMOMSZcIgzH8AVngAhZlNX
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQjMcgIlH7HBhXZvxZH+S
+S3TkqJ/+2HiDo/vvZg4+ylU/V+4+GTPCTOPND/ff0rlhM+jg7/3o5r/av+C
wvwvJ87+gosfyduS/eLJm/06MYuawkx+oan/ADUfIT73hOqp7t6PONR/xjDf
7Lb5Zlm7LxjuSeibwG1u9BXD/VcWx9auPP0Vw78Qdd8wwgem3u+J0NOjxxDi
KOY3MMLFzaHumf129k0+eSa4OCPU/QbuJ1qlZyLE50P9++riun1XniLEUcOH
GS5+DBqe6OqZoOGPbv4UaHyhu8cROX6R3B8JTQ/+aP5FTz8AFxMhnw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQv/YDxMPBYOnGOKrwOAV
hjiE/wGH+k84zP+Kw5wfJItD7PmFIQ6x5y8OcxgOYFfPiCEOMZ8JQxxCsxAU
D0PxL0J8NUr4oJvzAYf6VzjMf4rDnAcki6/G6t8HOMLnAY7wfLA/DGv4w8xH
jy9EOgQA74D+wQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQn/YDxNfvQoEvmOIh4IB
pjiEjykOMecbhngY2BxMcQifePFQHObgsheXO3H5axWOcMAVbujiAF4bj08=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQn/YDxMPCwWBxxjiq8Dg
EYY4hI8pDjHnIYb4arA5D3CYQ7z4Khzm4LIXlztx+SsURzjgCjd0cQCDEI4V

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQv/Yjy6+ehUIfMcQDwUD
THEIjSkOMecbhngY2BxMcQhNvHgoDnNw2YvLnbj8tQpHOOAKN5g4AJt8j08=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQj/Zjy4eFgoCjzHEV4HB
IwxxCI0pDjHnIYb4arA5D3CYQ7z4Khzm4LIXlztx+SsURzjgCjeYOADKQY4V

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoT/sb7jAx1rkNx8q/gUu
znDBPc7yax1U/BNCHAV8wKH+DQ7zX8DFUd3zBC5uDAaXCYi/wCH+Bof4Bxzi
n3CIf8Eh/g2H+xHiACWWW1U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPob/tb7jAx1rkNx9N/Mt+
hgvucZZf69DEP0FpGICJf8Ch/g0O81/sx+6eJ/uNweAykeIvcIi/wSH+AYf4
JxziX3CIf8Ph/m/7ASYmW1U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQn/YDxOP2OHCujbjyf6j
eVuyXzx5Axd3eHzvxcTZT6HqX8HFJ3tOmHmk+fn+KVAa1fxX+2H6YOJHoObC
7EFV/2E/zF0w8bknVE91937Eof4zhvlmt803y9p92T8ZzT0JfRO4zY2+7v8P
Bi/h4lcWx9auPP11/xE0/0LM/4YRPjD1MHehmw9zF0zcHOoemLtg4oxQdTB9
MPH5UHNh9mAPn29w8WNQd6OrZ4KGP7r5sHhCd48jNBwZ0dwfCQ33+Wj+RU8/
AP1wMGU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfRsPEQ8HgKYb4KjB4hSEO
4X/Aof4TDvO/4jDnB8niMPeii8Pci92cDzjUf8Jh/lcc5vwgKB6G4l+E+GqU
8EE35wMO9a9wmP8UhzkPSBYPw+rfB/tXYw2fBzjCE6YePfxh5qPHFyIdAgBi
5QvW
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LGfAQpg4qtXgcB3DPFQMMAU
h/AwxSHmfMMQDwObgykO4REvHorDHFz24nInLn+twhEOuMINXRwAoyN2Dg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLKfAQpg4mGhIPAYQ3wVGDzC
EIfwMMUh5jzEEF8NNucBDnOIF1+Fwxxc9uJyJy5/heIIB1zhhi4OAMgYdNQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQj/Yjy6+ehUI3MMQDwWD
uxjiEPoODnNuYYiHgc25icOcG0SLh+IwB5e9uNyJy1+rcIQDrnCDiQMAjoGN
vQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQt+wRxcPBYObGOKrV4HA
LQxxCH0Hhzl3McTBxqy6h8OcB0SLr8ZhDi57cbkTl7/CcIQDrnCDiQMAmVaG
NQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNvPAAUNF/hYi/zmQ8W/wMUZ
LrjHWX6tg4p/QoijgA841L/BYf4LuDiqe57AxY3B4DIB8Rc4xN/gEP+AQ/wT
DvEvOMS/4XA/QhwAap5CFA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoW/sb7jAx1rkNx9N/MJ+
hgvucZZf69DED0BpGPiA4GNXb4/DfHsc7rE3BoPLRIpfwCF+AIc4AwMO9ftx
mI9D/MZ+XOEJAIyKU1E=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLKfAQpg4hE7XFjXZjzZf6Mz
ZtGeGzvsYeIOj++9mDj76f7/YHAcLj7Zc8LMI83P99/MuX+m7McFe1TzX+1v
sHTSu3PiClz8SN6W7BdP3uz37y/7ulTvOpr6D1D33ICLzz2heqq79+P+AKzq
P2OYb3bbfLOs3Zf9t9Dck9A3gdvc6Ot+FrC+E3DxK4tja1ee/rr/AZp/IeZ/
28/VNc/HsrLLBl39OYj6/ejm/4GED1zcHOqe6xD3wMUZoe6vg7gfLj4f6l8/
iH/34wgfuPgxaHgGoKlngoZ/E5r5U6DxdQvNPY7Q+GWDhA9cPBKaHt6h+ReW
fiDhM2sPAPd+NbQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfStvDxEPB4CmG+CoweIUh
DuF/wKH+Ew7zv+Iw5wfJ4mFg867iED+Kwxz0cPixPwSifj928asY4rDwIyQe
hupfuPhq1PDZjyM80dS/wmH+UxzmPCBZPAyrf2Hi6OHzAEd4PoCFpz12cfT4
QqRDABdC+BE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQn+wh4mvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAGpQh88=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQn+wh4mHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OACPRYaV

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQj+wRxdfBQaY4mGhIPAQ
QxxCP8JhDqY42JjQxzjMeUK0eBgOc3DZi8uduPy1Gkc44Ao3mDgA1R6GkQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQn+zRxcPBQNM8dWrQABT
HEJ/x2EOpjjYmFWY4hD6B9Hiq3GYg8teXO7E5a8wHOGAK9xg4gCmXYfN
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoT/YN1zgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxADHLU9U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoZ/YN1zgYy3ym48m/sKe
4YJ7nOXXOjTxN1A+DMDEP+BQ/wmH+V/ssbvnm70xGFwmUvwLDvFPOMQ/4BB/
g0P8BQ7xJzjc/8QeADI3U8M=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQn+wh4lH7HBhXZvxZP+8
E6qnuns/wsUdHt97MXH2U6j6z3DxyZ4TZh5pfr7f7Lb5Zlm7L/ao5r/an9A3
gdvc6Ctc/EjeluwXT97sv7I4tnbl6a9o6j9Azf8GF58LcQcO9Z8xzIe6A8M9
UHUY7oeai+FfqDswwgem/hjEHxjmM0L8DRc3h7pnCiSc4OKMUPc7QsIVLj4f
6t9ISDzgCB+EONQd+yPQ1DNBw98ezXyoO/ZPRnMP1B37//0HgZdwcag79h9C
8y8s/YCV/39vDwBkDind
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQv+wh4mHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksXDIOZhiK+G2I/DnA841L/CYf5THOY8ICgehuJf
hPhqlPBBN+cDDvWvcJj/FIc5D0gWD8Xq3wf7V2ENnwc4whOmHj38Yeajxxci
HQIAfab9xw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQjM4wMRXrwKB7xjioWCA
KQ7hYopDzPmGIR4GNgdTHMIlXjwUhzm47MXlTlz+WoUjHHCFG7o4AB0Qec4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQjM4wMTDQkHgMYb4KjB4
hCEO4WKKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHABCBXiU

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQv+wRxcPBQNM8dWrQABT
HEL/xGEOpjjYmFWY4hD6F9Hiq3GYg8teXO7E5a8wHOGAK9xg4gC6SYfr
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQjM7oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPAQrQ4LnNw2YvLnbj8hSsccIUbTBwA7TN6lw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoRkcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4AOR8RdQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoX/ZN1zgYy3ym48m/see
4YJ7nOXXOjTxf1A+DMDEGRywq2d0wG4+kwN29zA7GIPBZSLFmXCIM+IQZ8Ah
/s8eu/gfHOK/7HGFJwAviEzN
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQjM4wMQjdriwrs14st//
idDTo8cQ4g6P772YOPspRH0DI1x8sueEmUean++f/Xb2TT55JgdU81/tN3A/
0So9EyF+JG9L9osnb/a/urhu35Wn6Oo/QN3DDBefe0L1VHfvRxzqP2OYb3bb
fLOs3RcM9yT0TeA2N/qK4f4ri2NrV57+iuFfiPnfMMIHpj7Z/JZpSdE/e6zm
M/yFi5tD3XNK5YTPo4O/4eKMUPcvKMz/cuLsL7j4fKh/dWIWNYWZIMRRwwch
fgwanujqmaDhj27+FGh8obvHERq//8HgD1w8EpoeEtH8i55+AEu0Gxk=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQrM4wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeKrwfYwYYhD7GHEYQ4DhngYWP1fe+zm/8IQh9IE
xcNQ/IsQX40SPujmfMCh/hUO85/iMOcByeKrsPr3ATQ80cPnAY7wfIAj/GHm
o8cXIh0CAHNa8ME=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQnM4wMRXrwKB7xjioWCA
KQ7hY4pDzPmGIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4AGzAekY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQnM4wMTDQkHgMYb4KjB4
hCEO4WOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHACRtXkM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQrM4oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPASrQ4LnNw2YvLnbj8hSsccIUbTBwA9yl6pg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQnM7oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPAQ7Q4LnNw2YvLnbj8hSsccIUbTBwAPPJ7Dw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoTkcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4ADQ7Rkw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoVkdGi7wsRb5zUcTZ3Ng
uOAeZ/m1Dk2c3YEBBcDEOXCo58RhPpcDdvdwOxiDwWUixblwiHPiEOfAIc6O
Q5wNhzgrDvezOgAARclGWw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQnM4wMQjdriwrs14st//
idDTo8cQ4g6P772YOPspRH0DJ1x8sueEmUean++f/Xb2TT55LgdU81/tN3A/
0So9EyF+JG9L9osnb/a/urhu35Wn6Oo/QN3DDRefe0L1VHfvRxzqP2OYb3bb
fLOs3RcM9yT0TeA2N/qK4f4ri2NrV57+iuFfiPnfMMIHpn6T9FspK0t2HOaz
wcXNoe5JFUpR+/iAFS7OCHX/hR3mVU/SEOLzof4V0wt01JZixRE+CPFj0PBE
V88EDX9086dA4wvdPY4o8YtwfyQ0PWxE8y96+gEAIMEGkw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQvM4wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeKrwfZwYYhD7OHEYQ4HDnPYMMTDwOaw4jCHhaB4
GIp/EeKrUcIH3ZwPONS/wmH+UxzmPCBZPBSrfx/gCJ8HOMLzAY7wf7B/Fdb4
QqRDAHwy5Ns=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQgs4wMRXrwKB7xjioWCA
KQ7hY4pDzPmGIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4ALxwer4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQgs4wMTDQkHgMYb4KjB4
hCEO4WOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHADhZXmE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQvM4oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPAS7Q4LnNw2YvLnbj8hSsccIUbTBwARuh7Hg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfTDUIOqCLh4LAVEzx1atA
AFMcTB3AYc5VHOa8wmEOgxDR4rjMwWUvLnfi8heucMAVbjBxAPrUf2k=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoQUcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4AIPrRsQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoXkdGi7wsRb5zUcT53Ng
uOAeZ/m1Dk2c34EBBcDEBbCrbxDAYb6gA1b3NAg6GIPBZeLEGXCpF8ChHpc4
Pw5xPhzivNjdDxQHAP3YSMs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQgs4wMQjdriwrs14sl+9
qPNTUjJC3OHxvRcTZz+FqD+AEJ/sOWHmkebn+899O5vTzi/ogGr+q/0zlJ8c
6vVBiB/J25L94smb/V8zwuNfFaGr/wAxvwEhPveE6qnu3o841H/GMN/stvlm
WbsvGO5J6JvAbW70FcP9VxbH1q48/XW/Bpp/IeZ/wwgfmPpN0m+lrCz5sZvf
wAcXN4e6J1UoRe3jA164OCPU/Rd2mFc9SUOIz4f6V0wv0FFbihd7+DAgxI9B
wxNdPRM0/NHNnwKNL3T3OCLHL5L7I6HpYSOaf9HTDwDPXQYQ
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQgs5wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeIQ8wQxxFeD7RfAYQ6mOEQ9H4Z4GNh8Xhzm8BAU
D0PxL0J8NUr4oJvzAYf6VzjMf4rDnAcki4di9e8DHOHzAEd4PsAR/g9wxBci
HQIAcnXlpg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQos4wMRXrwKB7xjioWCA
KQ7hY4pDzPmGIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4AORIevo=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQos4wMTDQkHgMYb4KjB4
hCEO4WOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHAAJTHnA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQgs5oIuHgoAopvjqVUCg
hSkOphxwmBOKw5wsHOY0EC+Oyxxc9uJyJy5/4QoHXOEGEwcAbrF59g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfTDWIOqCLh4LAVEzx1atA
AFMcTB3AYc5VHOa8wmEOgxjR4rjMwWUvLnfi8heucMAVbjBxACK7f6U=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoUUcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4AKvDRwA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPphqEHBou8LEW+c1HFWcQ
dmC44B5n+bUOTT1QHAXA1IvgUC+Cw3xRB+zuEXUwBoPLxIkz4FIvgkM9DnGg
v7CrxyEODDdc4QkAmChLjA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQos4wMQjdriwrs14sl+9
qPNTUjJC3OHxvRcTZz+FqD+AEJ/sOWHmkebn+899O5vTzi/qgGr+q/0zlJ8c
6vVBiB/J25L94smb/V8zwuNfFaGr/wAxvwEhPveE6qnu3o841H/GMN/stvlm
WbsvGO5J6JvAbW70FcP9VxbH1q48/XW/Bpp/IeZ/wwgfmPqbvWW8c+cIYzff
ASFuDnWPMafR5IoPQnBxRqj7M+5I2xZtRojPh/qXe/qKBaK9QjjCByF+DBqe
6OqZoOGPbv4UaHwZobnHETl+kdwfCU0PN9D8i55+AJJ3CL4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQos5wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeIQ80QxxFeD7RfBYQ6mOMQcYRzmCOEwh7B4GIp/
EeKrUcIH3ZwPONS/wmH+UxzmPCBZHLt/H+AInwc4wvMBjvB/gCO+EOkQABSA
5is=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQoscgImvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMAvoiA
6A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlRQ7AxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwCNHXlg

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUIHYAXXz1KiB4JYohHgoCVzHF
weAApjjYnFU4zJmKw5wG4sVxmYPLXlzuxOUvXOGAK9xg4gCP+W1l
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewZk0CB0AF189SogyMIUDwUDTHEw
cMBhjhYOc0RxmMNAvDguc3DZi8uduPyFKxxwhRtMHADe7Wi1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoUUONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAMXSRnw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMyaBA90HCBj7XIbz6qOIPoAYYL
7nGWX+vQ1IscYMAKRHCoF8ZhvvAB7O4ROmAMBpeJEweag109DnGgO7GrxyEO
DAfs6kVxuF/0AAAG+TnO
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlRQ7AxAP6y74u1btuf7O3
jHfuHGG4eIOlk96dE1cg6h0Q4rdy7p8p+3HB3ojTaHLFByG4OBNY4Qn7jDvS
tkWbEeL3OmMW7bmxw557+ooFor0Ica6ueT6WlVU2YG0NCPGrEPX70dX//Q8C
x/ejm38T4p796O6ph7h/P7r7/SH+3X8Dzb/Q8NmPI3z2qxd1fkpKRog3Ipt/
ACF+B+qes9/O5rTzi8LF2SDhs3+G8pNDvT4I8bdQ/37NCI9/VYQQ73he9vPV
rcl7IOGDED8DDU909d8h4WOPbv4NaHydQ3NPHXL8IrnfD5oeNND8i55+AOw5
I+w=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClhQ7AxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBZfvQoEMMXB1oQK4zBHBIc5mOIQc0RxmCNGUDwM
xb/o4kdxmAMDYujhaY9d/CqGOGr8Ei+Ow7/2OMLHHkd42uMIf3sc8QVPVwAN
wOB1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQgscgImvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMAlrCA
rA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlBQ7AxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwBlRXkk

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUIHQAXXz1KiB4JYghHgoCVzHF
weAApjjYnFU4zJmKw5wG4sVxmYPLXlzuxOUvXOGAK9xg4gBoIW0p
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHsAXTwUBK7yYIivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOALWmaV4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoQUONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAJ36RkA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMyaBA80HCBj7XIbz6qOIPgAYYL
7nGWX+vQ1AscYMAKBLCrZ+DHYT7fAazuYeA9YAwGl4kU58Mhzo9DXAC7eAMO
cWA4YFcviN39QHEAbis3jg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlBQ7AxAP6y74u1btuv1H6
rZSVJT9cvMHSSe/OiSsQ9Q18cPFbOffPlP24YJ8qlKL28QEvXJwJrPCE/YUd
5lVP0hDi9zpjFu25scNeTC/QUVsKIc7VNc/HsrLKBuIehPhViPr96Or//geB
4/vRzb8Jcc9+dPfUQ9y/H939/hD/7kf3LzR89uMIn/3qRZ2fkpIR4o3I5h9A
iN+Buufst7M57fyCcHE2SPjsn6H85FCvD0L8LdS/XzPC418VIcQ7npf9fHVr
8h6I+xHiZ6Dhia7+OyR87NHNvwGNr3No7qlDjl8k9/tB04MGmn/R0w8AlZEh
Pg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACleQ7AxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBYHGxfKiyG+ehUI8OEwRwCHekxxiPmCOMwRIige
huJfdPGjOMyBASH08LTHLn4VQxw1fokXx+FfexzhY48jPO1xhD/U3xjxBU9X
AFgF3/A=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQnMcgImvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMARwCA
NA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlOQ7AxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwAVlXis

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHMAXTwUBK5yY4ivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOAKuwaU8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHoAXTwUBK6yYIivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOAGX2aOY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoTkONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAE5KRcg=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK4D7QcIGPtchvPpo41wGGC+5x
ll/r0MQ5DzBgBRw41LPjMJ/tAHb3sB4wBoPLRIqz4RBnxyHOgUOcE4c4Fw5x
bhzu5z4AALSRNKA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlOQ7AxAP6y74u1btuv1H6
rZSVJTtcvMHSSe/OiSsQ9Q1scPFbOffPlP24YJ8qlKL28QErXJwJrPCE/YUd
5lVP0hDi9zpjFu25scNeTC/QUVsKIc7VNc/HsrLKBuIehPhViPr96Or//geB
4/vRzb8Jcc9+dPfUQ9y/H939/hD/7kf3LzR89uMIn/1+T4SeHj2GEG9EMZ8T
Ln4H6p7Zb2ff5JPngouzQcJnv4H7iVbpmQjxt1D/vrq4bt+VpwjxjudlP1/d
mrwH4h5uuPgZaHiiq/8OCR97dPNvQOML3T11KPGLcL8fND34o/kXPf0AAHJH
IcE=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClWQ7AxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBYHGxfKiiG+ehUIsOEwhwOHOZwY4mBjVnHhMIeH
oHgYin/RxY/iMAcGeNDD0x67+FUMcdT4JV58NXb/2uMIH3sc4WmPI/yh/saI
L3i6AgBOEt8l
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQjMcgImvXgUC9zDEQ8Hg
LoY4hHsHhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMA90F/
vA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlGQ7AxEPB4CaG+OpVIHAL
QxzCvYPDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwDF1ng0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHIAXTwUBK4yY4ivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOAFwAaNc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8Gs/uvjqVSDwE0M8FAwwxSEA
Uxxizg8M8TCwOZjiEEC8eCgOc3DZi8uduPy1Ckc44Ao3mDgAKmh2LA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoRkONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjh2gq7fHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAP6LRVA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKYD7QcIGPtchvPpo40wGGC+5x
ll/r0MQZDzBgBzjU/9uP3fw/+7G759d+YzC4TKT4Hxzi/3CIMxzALs6IQ5wJ
hzjzAVzhCQCcVzoW
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlGQ7AxAP6y74u1btun2R+
y7Sk6N9+mHiDpZPenRNXoOr/wsVv5dw/U/bjgv0plRM+jw7+hoszgdWdsF9Q
mP/lxNlfcPF7nTGL9tzYYa8Ts6gpzAQhztU1z8eyssoGYj5C/CpE/X509X//
g8Dx/ejm34S4Zz+6e+oh7t+P7n5/iH/3o/sXGj77cYTPfr8nQk+PHkOINyKb
38AIF78Ddc/st7Nv8skzwcXZIOGz38D9RKv0TIT4W6h/X11ct+/KU4R4x/Oy
n69uTd4DcQ4zXPwMNDzR1X+HhI89uvk3oPGF7p465PhFcr8fND34o/kXPf0A
AJ99ME8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClf+yHiYeFgsBVHOJHMcQZ
UABCPASifj928asY4lD3kCy+Cgx+YYiDrQn9i8MchgPY1TNiiEPMZ8IQh9As
BMXDUPyLLn4UhzkwgBAPQQl/dPGrGOKo8Uu8+Grs/rXHET4w92KIh2EPf6j5
GPEFT1cARoHrCw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQn/YDxNfvQoE7mGIh4LB
XQxxCP8ODnNuYYiHgc25icOcG0SLh+IwB5e9uNyJy1+rcIQDrnBDFwcARJCN
vQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlP+yHiYeCwU0M8dWrQOAW
hjiEfweHOXcxxMHGrLqHw5wHRIuvxmEOLntxuROXv8JwhAOucEMXBwATJYY1

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8GM/uvjqVSDwHUM8FAwwxSEA
UxxizjcM8TCwOZjiEEC8eCgOc3DZi8uduPy1Ckc44Ao3mDgAFnx2Dg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8GQ/unhYKAg8xhBfBQaPMMQh
AFMcYs5DDPHVYHMe4DCHePFVOMzBZS8ud+LyVyiOcMAVbjBxAEVBdNQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoT/sb7jAx1rkNx8qfgEu
znDBPc7yax1U/ABCHCvAUG+Pw3y4OJp74OLGYHCZgPgFHOIHcIgj3Immfj92
8Qs4xBHhhis8AUvaU1E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK+La/4QIfa5HffDTxL/sZLrjH
WX6tQxP/tJ8BK/iAQ/0bHOa/2I/dPU/2G4PBZSLFX+AQf4ND/AMO8U84xL/g
EP+Gw/3f9gMAoRdCFA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlP+yHiQf0l31dqnfd/mje
luwXT97AxRssnfTunLgCVf8KLn4r5/6Zsh8X7Kd4Tph5pPk5XJwJrO6EvcPj
ey8mzn4KF7/XGbNoz40d9hE7XFjXZjyBi3N1zfOxrKyygZiPEL8KUb8fXf3f
/yBwfD+6+Tch7tk/Gc099RD37wdr+/8SLu4P8e/+I2j+hYbPfhzhs3/uCdVT
3b0f4eKNUPMh6j/Dxe9A3WN223yzrN0XuDgbJHz2J/RN4DY3+goXfwv175XF
sbUrTyPEO56X/Xx1a/IeiPnf4OJnoOGJrv47JHzs0c2/AY0vdPfUQeOXEc39
ftD0MB/Nv+jpBwCF6T8V
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACj98PEw0JB4CoO8aMY4gwo
ACEeAlG/H7v4VQxxGJ9UcbBxoU8xxFeBwSsc5nzAof4TDvO/4jDnB0HxMBT/
oosfxWEODPxAD0977OJXMcRR45d48TDs/rVfjT187HGEJ1Q9RvhDzceIL3j4
AQC51/gR
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLCfAQpg4qtXgcA9DPFQMLiL
IQ7h3cFhzi0M8TCwOTdxmHODaPFQHObgsheXO3H5axWOcMAVbujiAImYdHw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlEeKhYHATQ3z1KhC4hSEO
4d3BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9zQxQFYLWz0
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8GA/uvjqVSBwD0M8FAzuYohD
wB0c5tzCEA8Dm3MThzk3iBYPxWEOLntxuROXv1bhCAdc4QYTBwAJgXR8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUcMMeXTwUDG5iiK9eBQK3MMQh
4A4Oc+5iiIONWXUPhzkPiBZfjcMcXPbicicuf4XhCAdc4QYTBwAUVmz0
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NjPAAUNF/hYi/zmQ8UvwMUZ
LrjHWX6tg4ofQIjjAqjq7XGYDxdHcw9c3BgMLhMQv4BD/AAOcQRAU78fu/gF
HOKIcMMVngCQ4joQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKuLG/4QIfa5HffDTxC/sZLrjH
WX6tQxM/sJ8BF8Cu3h6H+fY43GNvDAaXiRS/gEP8AA5xBgYc6vfjMB+H+I39
uMITAAeKOhA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlEeIB/WVfl+pdt7/RGbNo
z40d9jDxBksnvTsnrtj/B4PjcPFbOffPlP24YH8TSsPEmcCmnoDrg4nfg5rr
D7UHJs7VNc/HsrLKBuYumPhViPr9AWjq/0LcsR/dfKg79t9Cc089RN1+Fqi7
YOJQd+x/gOZfqDv2Q9zVZYMWPvvPQd0FE2+Emv8H6i6Y+B2oe65DaZg4G8Qd
++ug+mDib6Hm+kHtgYl3PC/7+erW5D0wd8HEz0DdHYCm/js0nprQzL8BDZdb
aO6BugPuLpg41B3279D8C4snSPjM2gMAf/dEZA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACnYeJhoSBwFYf4UQxxBhSA
EA+BqN+PXfwqhjiUT7I4zL3YxY/iMAcjHPbD3Itd/CqGOIwmJB6G6l808aM4
zIGH53608LTHLn4VQxwtfokWD8PuX7h7sZuDma5CsIc/3L240iEAbjTkWw==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQn+wh4mvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMAUMWG
PQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlP9jDxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwAfWn61

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8MAeXXwVGGCKh4WCwEMMcQh4
hMMcTHGwMaGPcZjzhGjxMBzm4LIXlztx+Ws1jnDAFW4wcQBQHm1Q
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8M0eXTwUDDDFV68CAUxxCPiO
wxxMcbAxqzDFIeAH0eKrcZiDy15c7sTlrzAc4YAr3GDiACFdbow=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoT/YN1zgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAFgPS9E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKeGLfcIGPtchvPpr4C3uGC+5x
ll/r0MTfoPFh4AMO9Z9wmP/FHrt7vtkbg8FlIsW/4BD/hEP8Aw7xNzjEX+AQ
f4LD/U/sAa0oOoI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlP9jDxAP6y74u1btuP++E
6qnu3o9w8QZLJ707J65A1X+Gi9/KuX+m7McFe7Pb5ptl7b7AxZnA6k7YJ/RN
4DY3+goXv9cZs2jPjR32VxbH1q48jRDn6prnY1lZZQMx/xtc/CpE/X509X//
g8Dx/ejm34S4Zz+6e+oh7t+P7n5/iH/3o/sXGj77cYTP/mN5W7JfPHkDF2+E
ms8IVv8KLn4H6p4pnhNmHml+Dhdng4TPfsfH915MnP0ULv4W6t/IHS6sazOe
wMU7npf9fHVr8h6IexDiZ6DhGYGm/jskfOzt0cy/AY2vyWjuqYPG7z+wvpdw
cT9oejiE5l9Y+gEr///eHgDseDiN
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClf9jDxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBaHuOsrhvjqVSDwCYc5H3Cof4XD/Kc4zHlAUDwM
xb/o4kdxmAMDD9DD0x67+FUMcdT4JV48FLt/7VdhDx97HOEJVY8R/lDzMeIL
nq4A1JjqEQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQjM4wMRXrwKBexjioWBw
F0Mcwr2Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQEDhXg8

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlGRxg4qFgcBNDfPUqELiF
IQ7h3sFhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFAdILcLQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8MMeXTwUDDDFV68CAUxxCPiJ
wxxMcbAxqzDFIeAX0eKrcZiDy15c7sTlrzAc4YAr3GDiADVJbqo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwOyALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GFaHFc5uCyF5c7cfkLVzjgCjeYOABoM2FW
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoRkcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxw7Q1dvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPAArPPdA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK+GXfcIGPtchvPpr4H3uGC+5x
ll/r0MT/ofHhwAG7ekYH7OYzOWB3D7ODMRhcJlKcCYc4Iw5xBhzi/+yxi//B
If7LHld4AgCqeTOM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlGRxg4gH9ZV+X6l23938i
9PToMYR4g6WT3p0TVyDqGxjh4rdy7p8p+3HBfvbb2Tf55Jng4kxghSfsDdxP
tErPRIjf64xZtOfGDvtXF9ftu/IUIc7VNc/HsrLKBuIcZrj4VYj6/ejq//4H
geP70c2/CXHPfnT31EPcvx/d/f4Q/+5H9y80fPbjCJ/9yea3TEuK/tnDxBuR
zWf4Cxe/A3XPKZUTPo8O/oaLs0HCZ/+CwvwvJ87+gou/hfpXJ2ZRU5gJQrzj
ednPV7cm74GYjxA/Aw1PdPXfIeFjj27+DWh8obunDhq/YG3//8DF/aDpIRHN
v+jpBwDUHinJ
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClWRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuvXgUCTBjiYGtCGXGYw4AhDvHfX3vs5v/CEIfQ
PwiKh6H4F138KA5zYAAhHoIS/ujiVzHEUeOXePFV2P1rH4o9fGDuRQ9Pexzh
DzUfI77g6QoAykzdCw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQnM4wMRXrwKBexjioWBw
F0Mcwr+Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQFTNXi0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlORxg4qFgcBNDfPUqELiF
IQ7h38Fhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFASHKcSw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwOKALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GVaHFc5uCyF5c7cfkLVzjgCjeYOAByKWFl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwO2ALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GHaHFc5uCyF5c7cfkLVzjgCjeYOAC342HO
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoTkcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxwow1NvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPAFp/Pkg=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKYHVouMDHWuQ3H02czYHhgnuc
5dc6NHF2BwasgAOHek4c5nM5YHcPt4MxGFwmUpwLhzgnDnEOHOLsOMTZcIiz
4nA/qwMAwLotGg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlORxg4gH9ZV+X6l23938i
9PToMYR4g6WT3p0TVyDqGzjh4rdy7p8p+3HBfvbb2Tf55Lng4kxghSfsDdxP
tErPRIjf64xZtOfGDvtXF9ftu/IUIc7VNc/HsrLKBuIebrj4VYj6/ejq//4H
geP70c2/CXHPfnT31EPcvx/d/f4Q/+5H9y80fPbjCJ/9m6TfSllZssPFG1HM
Z4OL34G6J1UoRe3jA1a4OBskfPZf2GFe9SQNIf4W6l8xvUBHbSmEeMfzsp+v
bk3eA3EPQvwMNDzR1X+HhI89uvk3oPGF7p46lPhFuN8Pmh42ovkXPf0AAKkr
FUM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACleRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuvXgUCXBjiYGtCOXGYw4HDHDYMcYi/WXGYw0JQ
PAzFv+jiR3GYAwMs6OFpj138KoY4avwSLx6K3b/2OMLHHkd42uMIf/tV2OML
nq4A0yTRJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQgs4wMRXrwKBexjioWBw
F0Mcwr+Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQGi5Xks

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlBRxg4qFgcBNDfPUqELiF
IQ7h38Fhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFAXF6caQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwOOALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GXaHFc5uCyF5c7cfkLVzjgCjeYOADB2WHd
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewZk0CDogC4eCgJTMcVXrwIBTHEw
OIDDnKs4zHmFwxwGIaLFcZmDy15c7sTlL1zhgCvcYOIAddRmKA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoQUcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxwow1NvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPAKovPsA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK4HVouMDHWuQ3H02cz4Hhgnuc
5dc6NHF+BwasQAC7+gYBHOYLOmB1T4OggzEYXCZOnAGXegEc6nGJ8+MQ58Mh
zovd/UBxAHjYL4o=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlBRxg4gH9ZV+X6l23Vy/q
/JSUjBBvsHTSu3PiCkT9AYT4rZz7Z8p+XLA/9+1sTju/IFycCazwhP0M5SeH
en0Q4vc6YxbtubHD/mtGePyrIoQ4V9c8H8vKKhuwtgaE+FWI+v3o6v/+B4Hj
+9HNvwlxz35099RD3L8f3f3+EP/u10DzLzR89uMIn/2bpN9KWVnyw8Ubkc1v
4IOL34G6J1UoRe3jA164OBskfPZf2GFe9SQNIf4W6l8xvUBHbSmEeMfzsp+v
bk3eA3EPQvwMNDzR1X+HhI89uvk3oPGF7p465PhFcr8fND1sRPMvevoBAFfW
FMA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClhRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuDjQsVxBBfvQoEBHCYgykOUc+HIQ7xNy8Oc3gI
ioeh+Bdd/CgOc2CABz087bGLX8UQR41f4sVDsfvXHkf42OMIT3sc4W+PI77g
6QoAyWfR8A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQos4wMRXrwKBexjioWBw
F0Mcwr+Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQHKvXlo

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlRRxg4qFgcBNDfPUqELiF
IQ7h38Fhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFAZlSceA=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUIOSALh4KAqKY4qtXAYEWpjgY
OOAwJxSHOVk4zGkgXhyXObjsxeVOXP7CFQ64wg0mDgDpomC1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewZk0CDqgC4eCgJTMcVXrwIBTHEw
OIDDnKs4zHmFwxwGMaLFcZmDy15c7sTlL1zhgCvcYOIAnaxmZA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoUUcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxwow1NvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPANIHPvw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMyaBByaLjAx1rkNx9VnEHYgeGC
e5zl1zo09UBxrEAEh3oRHOaLOmB3j6iDMRhcJk6cAZd6ERzqcYgD/YVdPQ5x
YLjhCk8AEygySw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlRRxg4gH9ZV+X6l23Vy/q
/JSUjBBvsHTSu3PiCkT9AYT4rZz7Z8p+XLA/9+1sTju/KFycCazwhP0M5SeH
en0Q4vc6YxbtubHD/mtGePyrIoQ4V9c8H8vKKhuwtgaE+FWI+v3o6v/+B4Hj
+9HNvwlxz35099RD3L8f3f3+EP/u10DzLzR89uMIn/03e8t4584Rhos3Ipvv
gBC/A3WPMafR5IoPQnBxNkj47M+4I21btBkh/hbqX+7pKxaI9iLEO56X/Xx1
a/IeSPggxM9AwxNd/XdI+Nijm38DGl9GaO6pQ45fJPf7QdPDDTT/oqcfABrw
F24=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClxRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuDjQsVxRBfvQoERHCYgykOMUcYhzlCOMwhLB6G
4l908aM4zIEBIfTwtMcufhVDHDV+iRfH4V97HOFjjyM87XGEvz2O+IKnKwBr
ctJ1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClRQ7AxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OADLxXm8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalRQ7AxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFAabkevg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClxQ6gi69eBQSvRDHEQ0Hg
KqY4mDqAKQ42ZxUOc6biMKeBeHFc5uCyF5c7cfkLVzjgCjeYOADlLn8m
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AChG4QOoIuvXgUEWZjioWCA
KQ6mHHCYo4XDHFEc5jAQL47LHFz24nInLn/hCgdc4QYTBwA0MXp2
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSIgcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4Abw9G7g==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDQDaIHGi7wsRb5zUcVZxA9
wHDBPc7yax2aepEDDCgApl4Eh3phHOYLH8DuHqEDxmBwmThxoDnY1eMQB7oT
u3oc4sBwwK5eFIf7RQ8AAFwuS48=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalRQ7AxK8sjq1defqr/c3e
Mt65c4Th4gl9E7jNjb5C1DsgxM1um2+Wtftib8RpNLnig9ABVPM/22fckbYt
2owQn3dC9VR370d77ukrFoj2oqv/AKEbEOJH87Zkv3jyBkM9I1jhKwzzp3hO
mHmk+TmGexwe33sxcfZTDPdH7HBhXZvxxP4Gmn8h7nmCET4w9epFnZ+SkkWw
m38AIT4J6p6z387mtPOLwsX//QeBl/YzlJ8c6vVBiB+C+vdrRnj8qyKEOFj5
//fQ8EGIz4WGJ3b1nzDMh8XXOTT3oMTvAcz0oIHmX/T0AwD7rhqu
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlhQ7AxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFIfZgioOtCRXGYY4IDnMwxSHmiOIwR4ygeCiK
fxHiq1DCB92cDzjUf8Jh/lcc5vwgWRy7f3/gCJ8fOMLzB47w/4EjvhDpEACo
YuYr
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClBQ7AxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OACj7XmA
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalBQ7AxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFAX8Merw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClhQ6gi69eBQSvBDHEQ0Hg
KqY4mDqAKQ42ZxUOc6biMKeBeHFc5uCyF5c7cfkLVzjgCjeYOAC9Vn7q
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACleQ+gi4eCwFUeDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAArqex8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSAgcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4ARzdGsg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDQDYIHGi7wsRb5zUcVZxA8
wHDBPc7yax2aeoEDDCgApl4Au3oGfhzm8x3A6h4G3gPGYHCZSHE+HOL8OMQF
sIs34BAHhgN29YLY3Q8UBwDDYElP
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalBQ7AxK8sjq1defqr/Ubp
t1JWlvxw8YS+CdzmRl8h6hv44OJmt803y9p9sU8VSlH7+ID3AKr5n+0v7DCv
epKGEJ93QvVUd+9HezG9QEdtKXT1H6A0Qvxo3pbsF0/eYKhnBKt7hWH+FM8J
M480P8dwj8Pjey8mzn6K4f6IHS6sazOeYPgX4o4nGOEDU69e1PkpKVkAu/kH
EOKToO45++1sTju/IFz8338QeGk/Q/nJoV4fhPghqH+/ZoTHvypCiIOV/38P
dT9CfC40PLGr/4RhPiy+zqG5ByV+D2CmBw00/6KnHwClBhgA
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGleQ7AxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFwcaF8mKIQ+znw2GOAA71mOIQ8wVxmCNEUDwU
xb8I8VUo4YNuzgcc6j/hMP8rDnN+kCyO3b8/cITPDxzh+QNH+P+Axj96fCHS
IQDyp+Wm
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClOQ7AxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OABUPXkI
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalOQ7AxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFAS9cekQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACleQ6gi4eCwFVuDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAAD0exA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClWQ+gi4eCwFUWDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDALsreqc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSHAcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4A93hGOg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDS3AcaLvCxFvnNRxPnOsBw
wT3O8msdmjjnAQYUABPnwKGeHYf5bAewu4f1gDEYXCZSnA2HODsOcQ4c4pw4
xLlwiHPjcD/3AQAJ1UZh
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalOQ7AxK8sjq1defqr/Ubp
t1JWluxw8YS+CdzmRl8h6hvY4OJmt803y9p9sU8VSlH7+ID1AKr5n+0v7DCv
epKGEJ93QvVUd+9HezG9QEdtKXT1H6A0Qvxo3pbsF0/eYKhnBKt7hWH+FM8J
M480P8dwj8Pjey8mzn6K4f6IHS6sazOeYPgX4o4nGOEDU+/3ROjp0WMcOMzn
hItPgrpn9tvZN/nkueDi//6DwEt7A/cTrdIzEeKHoP59dXHdvitPEeJg5f/f
Q93DDRefCw1P7Oo/YZgPiy9096DGLydGevBH8y96+gEAgbwYgw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlWQ7AxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFwcaFsmKIQ+xnw2EOBw5zODHEwcas4sJhDg9B
8VAU/yLEV6GED7o5H3Co/4TD/K84zPlBsvhqrP79gSN8fuAIzx84wv8HNP7R
4wuRDgHotOTb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClGQ7AxFeBAaZ4WCgIPMQQ
h3Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OAAEjXiQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalGQ7AxEPBAFN89SoQwBSH
cL/jMAdTHGzMKkxxCPcH0eKrcZiDy15c7sTlrzAc4YAr3NDFAd+decw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClWQ6gi4eCwFVmDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDALE1epg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClf+1HF1+9CgR+YoiHggGm
OITGFIeY8wNDPAxsDqY4hCZePBSHObjsxeVOXP5ahSMccIUbTBwAf52H7Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSDAcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4Ap8hFwg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSzAcaLvCxFvnNRxNnOsBw
wT3O8msdmjjjAQYUABNnwKH+337s5v/Zj909v/Ybg8FlIsX/4BD/h0Oc4QB2
cUYc4kw4xJkP4ApPAPGMS9c=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalGQ7AxK8sjq1defqrfZL5
LdOSon/7YeIJfRO4zY2+QtX/hYub3TbfLGv3xf6UygmfRwd/70c1/7P9gsL8
LyfO/oKLzzuheqq796O9TsyipjCTX2jqP0BphPjRvC3ZL568wVDPCFb3CsP8
KZ4TZh5pfo7hHofH915MnP0Uw/0RO1xY12Y8wfAvRN0TjPCBqfd7IvT06DGE
OIr5DYxw8UlQ98x+O/smnzwTXPzffxB4aW/gfqJVeiZC/BDUv68urtt35SlC
HKz8/3uoe5jh4nOh4Yld/ScM82Hxhe4elPhFcj8sPfij+Rc9/QAArvInEQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGj98PEw0JB4CuG+OpVIPAJ
QxzC/4BD/Ssc5j/FYc4DksXB1qz6hSEOtib0Lw5zGA5gV8+IIQ4xnwlDHEKz
EBQPRfEvQnwVSvigm/MBh/pPOMz/isOcHySLr8bq3x84wucHjvD8AY1n9PCH
mY8eX4h0CADhI/DB
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClP+yHia8CA0zxsFAQeIgh
DuE/wmEOpjjYmNDHOMx5QrR4GA5zcNmLy524/LUaRzjgCjd0cQBRzYaR
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalP+yHiYeCAab46lUggCkO
4X/HYQ6mONiYVZjiEP4PosVX4zAHl7243InLX2E4wgFXuKGLAwAs7IfN
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClf+xHF1+9CgS+Y4iHggGm
OITGFIeY8w1DPAxsDqY4hCZePBSHObjsxeVOXP5ahSMccIUbTBwAa7GHzw==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACln+xHFw8LBYHHGOKrwOAR
hjiExhSHmPMQQ3w12JwHOMwhXnwVDnNw2YvLnbj8FYojHHCFG0wcAJp2hpU=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSH/Y3XOBjLfKbD+W/gIsz
XHCPs/xaB+W/QYijgA841H/CYf4XuDiqe77BxY3B4DIB8S84xD/hEP+AQ/wN
DvEXOMSf4HA/QhwA9QhTww==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDS3/Y3XOBjLfKbjyb+ZT/D
Bfc4y691aOKf9jOgAJj4Bxzq3+Aw/8V+7O55st8YDC4TKf4Ch/gbHOIfcIh/
wiH+BYf4Nxzu/7YfAPZMU9U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalP+yHiV9ZHFu78vRX+6N5
W7JfPHkDF0/om8BtbvQVqv4VXNzstvlmWbsv9lM8J8w80vx8P6r5n+0dHt97
MXH2U7j4vBOqp7p7P9pH7HBhXZvxBE39ByiNEIe6A0M9I8QdGOZD3WE/Gc09
UHX2/8HgJVwcaq79ETT/Qt2BET4w9XMh/sAwH+pvuPgkqHug4QQX/wdxByxc
4eKHoP6FxgNcHOLu97B4g4tD3YFD/ScM82Hxhe4eWPwyorkflh7mo/kXPf0A
AJVeNdc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlH+yHiYeFgsBXDPHVq0Dg
E4Y4hP8Bh/pXOMx/isOcBySLh0LMwxBfBbEfhzkfcKj/hMP8rzjM+UFQPBTF
vwjxVSjhg27OBxzqP+Ew/ysOc36QLB6G1b8/YPGPwxz08ISpRw9/mPno8YVI
hwBUiP3H
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClEeKrwABTPCwUBB5iiEN4
j3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINXRwAltVtUA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalEeKhYIApvnoVCGCKQ3jf
cZiDKQ42ZhWmOIT3g2jx1TjMwWUvLnfi8lcYjnDAFW7o4gBx9G6M
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClH+xHF1+9CgTuYYiHgsFd
DHEIfQeHObcwxMPA5tzEYc4NosVDcZiDy15c7sTlr1U4wgFXuMHEAV62hj0=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClb9iji4eCwU0M8dWrQOAW
hjiEvoPDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuMHEAWmLfrU=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSDAwNF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAOh86gg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSN/Y3XOBjLfKbjyZ+YT/D
Bfc4y691aOIH9jOgAJg4SAtW9fY4zLfH4R57YzC4TKT4BRziB3CIMzDgUL8f
h/k4xG/sxxWeAFy/S9E=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalEeJXFsfWrjz91f5GZ8yi
PTd22MPEE/omcJsbfbX/DwbH4eJmt803y9p9sb+Zc/9M2Y8L9qjmf7ZvsHTS
u3PiClx83gnVU929H+39+8u+LtW7jqb+A5S+ARc/mrcl+8WTN/YBaOoZwepe
YZg/xXPCzCPNz+1vobnH4fG9FxNnP7VnAes7AReP2OHCujbjif0DNP9C3PHE
nqtrno9lZZcNuvpzEPX70c3/AwkfuPgkqHuuQ9wDF/8HVvfSvg7ifrj4Iah/
/SD+hYtDwv09LHzg4nOh4RmAVf0n+yY082HxdQvNPbD4ZYOEz3709PAOzb+w
9AMJn1l7AI9sOyY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlH9jDxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFIeZdxSF+FIc56OHwwD4Eon4/dvGrGOJQmqB4
KKp/4eKrUMNnP47wRFP/CYf5X3GY84Nk8TCs/oWJo4fPDxzh+QMWnvbYxdHj
C5EOAQjl6hE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClP9jDxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OABeAn8R
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalP9jDxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFATkhgE0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClH9iji68CA0zxsFAQeIgh
DqEf4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRtMHAClU38R
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClv9mji4eCAab46lUggCkO
ob/jMAdTHGzMKkxxCP2DaPHVOMzBZS8ud+LyVxiOcMAVbjBxAHaSgE0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSH+wbLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4AAUxMQw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDST+wbLvCxFvnNRxN/Yc9w
wT3O8msdmvgbKA0DHxDyWNV/wmH+F3vs7vlmbwwGl4kU/4JD/BMO8Q84xN/g
EH+BQ/wJDvc/sQcAAmxMQw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalP9jDxK8sjq1defqr/bwT
qqe6ez/CxRP6JnCbG32Fqv8MFze7bb5Z1u4LnEY1/zNcH0wcZi7MHlT1H+Du
gokfzduS/eLJGwz1jGB1rzDMn+I5YeaR5ucY7nF4fO/FxNlPMdwfscOFdW3G
Ewz/QtQ9wQgfmPpjUHehmw9zF0x8EtQ9MHfBxP/9B4GX9o5QfTDxQ1BzI6H2
wMTByv+/h7sLJj4X6u4IrOo/2dujmQ8Ll8lo7oGFI8xd6OnhEJp/YfEEcxcA
++0vTw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGnYeJhoSDwFUN89SoQ+IQh
DuF/wKH+FQ7zn+Iw5wHJ4jD3oovD3IvdnA841L/CYf5THOY8ICgeiuJfhPgq
lPBBN+cDDvWfcJj/FYc5P0gWD8Xq3x9w92I3Bz08f8Ddi9189PhCpEMAb0nv
xw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClGRxg4qvAAFM8LBQEHmKI
Q7iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHAAQwnEQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalGRxg4qFggCm+ehUIYIpD
uN9xmIMpDjZmFaY4hPuDaPHVOMzBZS8ud+LyVxiOcMAVbujiAOvSckw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClf9iji4eCAab46lUggCkO
oX/iMAdTHGzMKkxxCP2LaPHVOMzBZS8ud+LyVxiOcMAVbjBxAIp+gGs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClmR3QxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYWAhWhyXObjsxeVOXP7CFQ64wg0mDgC9aHMX
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSDA4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAs/0+Qg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSv+wbLvCxFvnNRxP/Y89w
wT3O8msdmvg/KA0DMHEGB+zqGR2wm8/kgN09zA7GYHCZSHEmHOKMOMQZcIj/
s8cu/geH+C97XOEJAP+uRU0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalGRxg4lcWx9auPP3V3v+J
0NOjxxDiCX0TuM2NvkLUNzDCxc1um2+WtftiP/vt7Jt88kwOqOZ/tjdwP9Eq
PRMhPu+E6qnu3o/2ry6u23flKbr6D1CaGS5+NG9L9osnbzDUM4LVvcIwf4rn
hJlHmp9juMfh8b0XE2c/xXB/xA4X1rUZTzD8C3HHE4zwgalPNr9lWlL0zx6r
+Qx/4eKToO45pXLC59HB33Dxf/9B4KX9gsL8LyfO/oKLH4L6VydmUVOYCUIc
rPz/e6j5CPG50PDErv4Thvmw+EJ3Dyx+Ifr+2KOnh0Q0/6KnHwDjkyCL
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlWRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniEHuYMMTB1oQy4jCHAUMc4q6/9tjN/4UhDgs/
QuKhKP5FiK9CCR90cz7gUP8Jh/lfcZjzg2TxVVj9+wNqD3r4/MARnj9whD/M
fPT4QqRDAGT94sE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClORxg4qvAAFM8LBQEHmKI
Q/iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHABgcnGI
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalORxg4qFggCm+ehUIYIpD
+N9xmIMpDjZmFaY4hP+DaPHVOMzBZS8ud+LyVxiOcMAVbujiADuRcsQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClWRzQxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYWAlWhyXObjsxeVOXP7CFQ64wg0mDgDHXnMm
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACluR3QxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYeAhWhyXObjsxeVOXP7CFQ64wg0mDgANJ3OP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSHA4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAA7w+ug==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSrA4NF/hYi/zmo4mzOTBc
cI+z/FqHJs7uwIACYOIcONRz4jCfywG7e7gdjMHgMpHiXDjEOXGIc+AQZ8ch
zoZDnBWH+1kdABX+Pts=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalORxg4lcWx9auPP3V3v+J
0NOjxxDiCX0TuM2NvkLUN3DCxc1um2+WtftiP/vt7Jt88lwOqOZ/tjdwP9Eq
PRMhPu+E6qnu3o/2ry6u23flKbr6D1CaGy5+NG9L9osnbzDUM4LVvcIwf4rn
hJlHmp9juMfh8b0XE2c/xXB/xA4X1rUZTzD8C3HHE4zwganfJP1WysqSHYf5
bHDxSVD3pAqlqH18wAoX//cfBF7aX9hhXvUkDSF+COpfMb1AR20phDhY+f/3
UPcgxOdCwxO7+k8Y5sPiC909qPHLhpEeNqL5Fz39AAC4oAwF
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGleRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniEHu4MMTB1oRy4jCHA4c5bBjiEPey4jCHhaB4
KIp/EeKrUMIH3ZwPONR/wmH+Vxzm/CBZPBSrf3/gCJ8fOMLzB47w/wH1B3p8
IdIhAG3V1ts=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClBRxg4qvAAFM8LBQEHmKI
Q/iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHACwInIA
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalBRxg4qFggCm+ehUIYIpD
+N9xmIMpDjZmFaY4hP+DaPHVOMzBZS8ud+LyVxiOcMAVbujiAItBczw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACleRzQxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYeAlWhyXObjsxeVOXP7CFQ64wg0mDgAXHXOe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AChGwQd0MVDQWAqpvjqVSCA
KQ6mDuAw5yoOc17hMIdBiGhxXObgsheXO3H5C1c44Ao3mDgAywl36Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSAg4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAU2w/Mg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSvA4NF/hYi/zmo4nzOTBc
cI+z/FqHJs7vwIACYOIC2NU3COAwX9ABq3saBB2MweAyceIMuNQL4FCPS5wf
hzgfDnFe7O4HigMAzg1BSw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalBRxg4lcWx9auPP3VXr2o
81NSMkI8oW8Ct7nRV4j6Awhxs9vmm2Xtvtif+3Y2p51f0AHV/M/2M5SfHOr1
QYjPO6F6qrv3o/3XjPD4V0Xo6j9A6AaE+NG8LdkvnrzBUM8IVvgKw/wpnhNm
Hml+juEeh8f3Xkyc/RTD/RE7XFjXZjyx10DzL8Q9TzDCB6Z+k/RbKStLfuzm
N/DBxSdB3ZMqlKL28QEvXPzffxB4aX9hh3nVkzSE+CGof8X0Ah21pRDiYOX/
30PdgxCfCw1P7Oo/YZgPiy9096DEL5L7YelhI5p/0dMPAGdLC4I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlhRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniYONCBTHEIfYL4DAHUxying9DHOJeXhzm8BAU
D0XxL0J8FUr4oJvzAYf6TzjM/4rDnB8ki4di9e8PHOHzA0d4/sAR/j9wxBci
HQIAZBjXpg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClRRxg4qvAAFM8LBQEHmKI
Q/iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHADX+nI8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalRRxg4qFggCm+ehUIYIpD
+N9xmIMpDjZmFaY4hP+DaPHVOMzBZS8ud+LyVxiOcMAVbujiALMZc3g=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClhRzQxUNBQBRTfPUqINDC
FAdTDjjMCcVhThYOcxqIF8dlDi57cbkTl79whQOucIOJAwA+5nJ2
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AChG0Qd0MVDQWAqpvjqVSCA
KQ6mDuAw5yoOc17hMIdBjGhxXObgsheXO3H5C1c44Ao3mDgA8uF4JQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSIg4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAe0Q/bg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDQDUIODRf4WIv85qOKMwg7
MFxwj7P8WoemHiiOAmDqRXCoF8FhvqgDdveIOhiDwWXixBlwqRfBoR6HONBf
2NXjEAeGG67wBABoXUQM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalRRxg4lcWx9auPP3VXr2o
81NSMkI8oW8Ct7nRV4j6Awhxs9vmm2Xtvtif+3Y2p51f1AHV/M/2M5SfHOr1
QYjPO6F6qrv3o/3XjPD4V0Xo6j9A6AaE+NG8LdkvnrzBUM8IVvgKw/wpnhNm
Hml+juEeh8f3Xkyc/RTD/RE7XFjXZjyx10DzL8Q9TzDCB6b+Zm8Z79w5wtjN
d0CIT4K6x5jTaHLFByG4+L//IPDSPuOOtG3RZoT4Iah/uaevWCDaixAHK///
Hho+CPG50PDErv4Thvmw+DJCcw9K/CK5H5YebqD5Fz39AAAqZQ4w
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlxRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniYONCRTHEIfaL4DAHUxxijjAOc4RwmENYPBTF
vwjxVSjhg27OBxzqP+Ew/ysOc36QLI7dvz9whM8PHOH5A0f4/8ARX4h0CAAG
I9gr
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlRQ7AxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAbvAexY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAhAptwg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQYgfQxVevAoJXohjioSBw
FVMcTB7AFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRtMHAAn5nEl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcACTDUIH0MVXrwKCLEzxUDDA
FIeQOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wg4kDAHbabHU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSIgcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPADSwP/g=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOIDJBtEDDRf4WIv85qOKM4ge
YLjgHmf5tQ5NvcgBBlQAVS+CQ70wDvOFD2B3j9ABYzC4TJw40Bzs6nGIA92J
XT0OcWA4YFcvisP9ogcAntc9jg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0CIHYOKvLq7bd+Upk8PN
3jLeuXOE4eIG7idapWcyQdQ7IMRnv519k0+eycGI02hyxQehAyjmNzA6ZNyR
ti3ajBD3fyL09OgxBgfu6SsWiPaiqQeaDNGHEE82v2VaUvTPHrv6v/bo5p9S
OeHz6OBve3T3LCjM/3Li7C97dPfrxCxqCjP5ZX8Dzb8Q86HqkcIHpl69qPNT
UrIIdvMPIMRPQt1z9tvZnHZ+Ubj4fzD4Yz9D+cmhXh+EeCLUv18zwuNfFYni
CB+EuB80PNHVg42vZ3RANx8WX+fQ3IMSvwcw04MGmn/R0w8AqhMK6g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0EIHYOKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0Mcwv9BsjjEPExxiHuFcZgjgsMcTHGIOaI4zBEj
KL4Kxb9iaOH5F4c5sPBEV8+IIb4KJb7QzWEhWRy7f1kcsIcPzBxMcezhDzMH
Pb4Q6RAAG53ZJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlBQ7AxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAZPoeto=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAXDJthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQQgfQxVevAoJXghjioSBw
FVMcTB7AFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRtMHAAADnDp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQvAfQxUNB4CoPhvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQBTZNtHg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSAgcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAAzYP7w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOIDJBsEDDRf4WIv85qOKMwge
YLjgHmf5tQ5NvcABBlQAVS+AXT0DPw7z+Q5gdQ8D7wFjMLhMpDgfDnF+HOIC
2MUbcIgDwwG7ekHs7geKAwAGGDtO
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AIHYOKvLq7bd+Upk8NG
6bdSVpb8cHED9xOt0jOZIOob+ODis9/Ovsknz+SQKpSi9vEB7wEU8xsYHS7s
MK96koYQ938i9PToMQYHMb1AR20pNPUMDFD3IMSTzW+ZlhT9s8eu/q89uvmn
VE74PDr42x7dPQsK87+cOPvLHt39OjGLmsJMftmj+xdiPlQ9UvjA1KsXdX5K
ShbAbv4BhPhJqHvOfjub084vCBf/DwZ/7GcoPznU64MQT4T692tGePyrIkHs
4dOAEPeDhie6erDx9YwO6ObD4uscmntQ4vcAZnrQQPMvevoBAFNrCDw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0DwHYOKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0Mcwv9BsjjEXbwY4hB7+HCYI4BDPaY4xHxBHOYI
ERRfheJfIbTw/IvDHFh4oqtnxBBfhRJf6OawkCyO3b8sDtjDB2YOpjj28Gdx
CMMaX4h0CABl4tig
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlOQ7AxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAUQ4emI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwADIJtDg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQPAfQxUNB4Co3hvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQBQ51tDw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQrAfQxUNB4CoLhvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQB/dRspg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSHAcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAL0ZP0Q=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAo7gMNF/hYi/zmo4lzHWC4
4B5n+bUOTZzzAAMqgIpz4FDPjsN8tgPY3cN6wBgMLhMpzoZDnB2HOAcOcU4c
4lw4xLlxuJ/7AABMfjhg
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0BwHYOKvLq7bd+Upk8NG
6bdSVpbscHED9xOt0jOZIOob2ODis9/Ovsknz+SQKpSi9vEB6wEU8xsYHS7s
MK96koYQ938i9PToMQYHMb1AR20pNPUMDFD3IMSTzW+ZlhT9s8eu/q89uvmn
VE74PDr42x7dPQsK87+cOPvLHt39OjGLmsJMftmj+xdiPlQ9UvjA1PuB/cGB
w3xOuPhJqHsg4cQFF/8PBn+g4YoQT4T6FxIPXDjChxsu7gcNT3T1YOPrGR3Q
zYfFF7p7UOOXEyM9+KP5Fz39AAAwIQi/
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0gdg4qtXgQAThngoGDBi
iEP4DBjiYWD1f+2xm/8LQxzC/0GyOMRdrBjiEHvYcJjDgcMcTgxxsDGruHCY
w0NQfBWKf3nQwvMvDnNg4YmunhFDfBVKfKGbw0Ky+Gqs/mVxwB4+MHPQwxNm
Dnr4sziEYY0vRDoEAFvv19U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlGQ7AxEPBAFN89SoQwBSH
cH/iMAdTHGzMKkxxCPcX0eKrcZiDy15c7sTlrzAc4YAr3NDFAfR5eeo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAvMNslg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQLAfQxUNB4CozhvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQB895slw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQv/aji69eBQI/McRDwQBT
HEJhikPM+YEhHgY2B1McQhEvHorDHFz24nInLn+twhEOuMINJg4AwkZ57A==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSDAcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAG1pPsw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAo5gMNF/hYi/zmo4kzHWC4
4B5n+bUOTZzxAAMqgIoz4FD/bz928//sx+6eX/uNweAykeJ/cIj/wyHOcAC7
OCMOcSYc4swHcIUnADREPdY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AwHYOKvLq7bd+Upk0OS
+S3TkqJ/+2HiBu4nWqVnMkHV/4WLz347+yafPJPDKZUTPo8O/t6PYn4Do8OC
wvwvJ87+gov7PxF6evQYg4NOzKKmMJNfqOoZGKDmI8STIe6wx67+rz26+VB3
2KO7B6rOHt39UHPt0f0LdQfMXQfQ1ftB/HEAq/kNjHDxk1D3QMMJLv4fDP7A
whUungj1LzQeDmAPH2a4ONQdDujqwcbXMzqgmw+LL3T3oMQvkvth6cEfzb/o
6QcAXVcXTQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0D/2w8RXrwIBJgzxUDBg
xBCH8BkwxMPA6v/aYzf/F4Y4lE+y+CqIeRjiEPf+xWEOwwHs6hkxxCHmM2GI
Q8OPoPgqFP8ixENRwgfdHFh4oqtnxBBfhRJf6OawkCy+Gqt/WRywhw/MHPTw
ZHEIwxr+MPPR4wuRDgFUXuO7
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlP+yHiYeCAab46lUggCkO
4f/EYQ6mONiYVZjiEP4vosVX4zAHl7243InLX2E4wgFXuKGLAwBByIfr
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPAQrQ4LnNw2YvLnbj8hSsccIUbujgAChJ6lw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQP/aji69eBQLfMcRDwQBT
HEJhikPM+YYhHgY2B1McQhEvHorDHFz24nInLn+twhEOuMINJg4Arlp5zg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQT/aji4eFgsBjDPFVYPAI
QxxCYYpDzHmIIb4abM4DHOYQL74Khzm47MXlTlz+CsURDrjCDSYOAN0feJQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSH/Y3XOBjLfKbD+X/gYsz
XHCPs/xaB+X/Q4ijAgfs6hnh4qjmM8HFUd3DDBc3BoPLBMSZcIgz4hBnwCGO
8Beq+B8c4ohwwxWeALqpTM0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECob/sbLvCxFvnNRxP/sp/h
gnuc5dc6NPFP+xlQAVT8Aw71b3CY/2I/dvc82W8MBpeJFH+BQ/wNDvEPOMQ/
4RD/gkP8Gw73f9sPADkERdQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0B/2w8RfXVy378pTJoej
eVuyXzx5Axc3cD/RKj2TCar+FVx89tvZN/nkmRymeE6YeaT5+X4U8xsYHRwe
33sxcfZTuLj/E6GnR48xOETscGFdm/EEVT0DA9R8hHiy+S3TkqJ/9tjV/7VH
N/+UygmfRwd/209Gc8+CwvwvJ87+sv8PBi/h4joxi5rCTH7ZH0HzL8T8X/bo
4QNTP/eE6qnu3o8Y5kPUf4aLn4S6x+y2+WZZuy9wcYg7/tgn9E3gNjf6ChdP
hPr3yuLY2pWnv+IIn29wcT9oeKKrBxtfz+iAbj4svtDdA4tfRjT3w9LDfDT/
oqcfAEPDJhM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0A/2w8RXrwIBJgzxUDBg
xBCH8BkwxMPA6v/aYzf/F4Y4hP+DZHGIu55iiIOtWfUKhzkfcKj/hMP8rzjM
+UFQfBWKf3+ghedfHObAwhNdPSOG+CqU+EI3h4Vk8TCs/mVxWI01fGDmoIcn
TD16+MPMR48vRDoEAMe08ME=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlEeKhYIApvnoVCGCKQ3g/
cZiDKQ42ZhWmOIT3i2jx1TjMwWUvLnfi8lcYjnDAFW7o4gCG0G6q
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHZggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGFiIFsdlDi57cbkTl79whQOucEMXBwBPGmFW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQD/aji69eBQL3MMRDweAu
hjiEuoPDnFsY4mFgc27iMOcG0eKhOMzBZS8ud+Ly1yoc4YAr3GDiAKFfeDw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQN+zRxUPB4CaG+OpVIHAL
QxxC3cFhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3GDiAKw0cLQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSDAwNF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAP+xM4w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECoG/sbLvCxFvnNRxO/sJ/h
gnuc5dc6NPED+xlQgQOchV29PQ7z7XG4x94YDC4TKX4Bh/gBHOIMDDjU78dh
Pg7xG/txhScAn2g90A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHZggAKY+KuL6/ZdecrkcKMz
ZtGeGzvsYeIG7idapWcyOfwHg+Nw8dlvZ9/kk2dyuJlz/0zZjwv2KOY3MDo0
WDrp3TlxBS7u/0To6dFjDA7+/WVfl+pdR1XPwAB1zw24eLL5LdOSon/2AVjV
/7VHN/+UygmfRwd/299Cc8+CwvwvJ87+smcB6zsBF9eJWdQUZvLL/gGafyHm
/7Ln6prnY1nZZYOu/hxE/X508/9AwgcufhLqnusQ98DFIeH4x74O4n64eCLU
v34Q/+7HET5wcT9oeAagqQcbX8/o0IRmPiy+bqG5Bxa/bJDw2Y+eHt6h+ReW
fiDhM2sPAD3RK2I=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0A/sYeKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0Mcwv9BsjjEnqs4xI/iMAc9HH7Yh0DU78cufhVD
HOoeguKrUP27HzU8/+IwBx6e+3GEP5r5TBjiaPFLtHgYVv/CxNHDB2YOZroK
wRr+MHH0+EKkQwB8Ed0L
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlP9jDxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAU39gGs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAFkdzFw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQD+zRxVeBAaZ4WCgIPMQQ
h1CPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg0mDgDn/HEQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQ3+zRxUPBAFN89SoQwBSH
UN9xmIMpDjZmFaY4hPpBtPhqHObgsheXO3H5KwxHOOAKN5g4ALk7ckw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSH+wbLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAMbeRU0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECoJ/YNF/hYi/zmo4m/sGe4
4B5n+bUOTfwNjM+AKv4Bh/pPOMz/Yo/dPd/sjcHgMpHiX3CIf8Ih/gGH+Bsc
4i9wiD/B4f4n9gBFFT5C
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0B/sYeKvLq7bd+Upk8O8
E6qnuns/wsUN3E+0Ss9kgqr/DBef/Xb2TT55Jgez2+abZe2+2KOY38DokNA3
gdvc6Ctc3P+J0NOjxxgcriyOrV15+iuqegYGqPnf4OLJ5rdMS4r+2WNX/9ce
3fxTKid8Hh38bY/ungWF+V9OnP1lj+5+nZhFTWEmv+zR/QtRB1P/AUP9sbwt
2S+evMEwnxGs/hVc/CTUPVM8J8w80vwcLv4fDP7YOz6+92Li7Kdw8USofyN3
uLCuzXiCI3wQ4n7Q8IxAUw82vp7RwR7NfFh8TUZzDyx+/4E1vsRID4fQ/AtL
PxB/vLcHAKpSH4s=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0D/sYeKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0McxidVHGLPVwxxiD2fcJjzAYf6VzjMf4rDnAcE
xVeh+PcBWnj+xWEOLDzR1TNiiK9CiS90c1hIFg/F6l8Wh1VYwwdmDnp4wtSj
hz/MfPT4QqRDAOJ14sE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlGRxg4qFggCm+ehUIYIpD
uD9xmIMpDjZmFaY4hPuLaPHVOMzBZS8ud+LyVxiOcMAVbujiAAC9cmo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AyPhlFg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQP+zRxUPBAFN89SoQwBSH
UD9xmIMpDjZmFaY4hPpFtPhqHObgsheXO3H5KwxHOOAKN5g4AM0ncmo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQzA7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMLAQLY7LHFz24nInLn/hCgdc4QYTBwAAIGUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSDA4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAHmeN0w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECoX/YNF/hYi/zmo4n/sWe4
4B5n+bUOTfwfjM+AKg6ksapndMBuPpMDdvcwOxiDwWUixZlwiDPiEGfAIf7P
Hrv4Hxziv+xxhScAQmY3TA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AwOMPFXF9ftu/KUycH/
idDTo8cQ4gbuJ1qlZzJB1DcwwsVnv519k0+eyQFGo5gPVAfTBxOHmQuzB9U9
DA4wd8HEk81vmZYU/bPHrv6vPbr5p1RO+Dw6+Nse3T0LCvO/nDj7yx7d/Tox
i5rCTH7Zo/sXYv4vuLvQ1cPchdV8oLtg4ieh7oG5Cyb+Hwz+wPXBxBOh5sLs
wR4+CHE/qLvR1YONr2d0QDcfFi7o7oGFI8xd6OkhEc2/6OkHAJH4EMc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0TDx1atAgAlDPBQMGDHE
IXwGDPEwsPq/9tjN/4UhDuH/IFkc5l50cZh7sZvDgCEOcy92839hiMNoQuKr
UPyLEA9FCR90c2Dhia6eEUN8FUp8oZvDQrL4Kqz+ZXEIxRo+MHPQwxOmHj38
YeajxxciHQIA2CnVuw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlORxg4qFggCm+ehUIYIpD
+D9xmIMpDjZmFaY4hP+LaPHVOMzBZS8ud+LyVxiOcMAVbujiAFBtcuI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AGLdljg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQLA7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMLASLY7LHFz24nInLn/hCgdc4QYTBwAKFmUl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQ3A7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMPAQLY7LHFz24nInLn/hCgdc4QYTBwBP0GWO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSHA4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAMlON8Q=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAoVoeGC3ysRX7z0cTZHBgu
uMdZfq1DE2eH0nAA5XPgUM+Jw3wuB+zu4XYwBoPLRIpz4RDnxCHOgUOcHYc4
Gw5xVhzuZ3UAAFinMNo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0BwOMPFXF9ftu/KUycH/
idDTo8cQ4gbuJ1qlZzJB1DdwwsVnv519k0+eyQFCczmgmN/A6ADRhxCHmMvg
ALEHTT0DA9Q93HDxZPNbpiVF/+yxq/9rj27+KZUTPo8O/rZHd8+CwvwvJ87+
skd3v07MoqYwk1/26P6FmA9VjxQ+MPWbpN9KWVmy4zCfDS5+EuqeVKEUtY8P
WOHi/8Hgj/2FHeZVT9IQ4olQ/4rpBTpqS7HiCB+EuB80PNHVg42vZ3RANx8W
X+juQY1fNoz0sBHNv+jpBwBnBfwy
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0DwOMPHVq0CACUM8FAwY
McQhfAYM8TCw+r/22M3/hSEO4f8gWRxiHheGOMS9nDjM4cBhDhuGOMQfrDjM
YSEovgrFvyxo4fkXhzmw8ERXz4ghvgolvtDNYSFZPBSrf1kcsIcPzBz08ISZ
gx7+LA6rsMYXIh0CAOEBydU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlBRxg4qFggCm+ehUIYIpD
+D9xmIMpDjZmFaY4hP+LaPHVOMzBZS8ud+LyVxiOcMAVbujiAKAdc1o=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AaGdmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQPA7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMPASLY7LHFz24nInLn/hCgdc4QYTBwBZxmWd
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcACTDYIO6OKhIDAVU3z1KhDA
FAeTB3CYcxWHOa9wmMMgRLQ4LnNw2YvLnbj8hSsccIUbTBwADcFp6A==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSAg4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnABkNODw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAoXoeGC3ysRX7z0cT5HBgu
uMdZfq1DE+eH0nAA5QtgV98ggMN8QQes7mkQdDAGg8vEiTPgUi+AQz0ucX4c
4nw4xHmxux8oDgAQxTNK
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AIOMPFXF9ftu/KUyUG9
qPNTUjJC3MD9RKv0TCaI+gMI8dlvZ9/kk2dyOPftbE47v6ADivkNjA4zlJ8c
6vVBiPs/EXp69BiDw9eM8PhXRWjqGRgg5jcgxJPNb5mWFP2zx67+rz26+adU
Tvg8OvjbHt09Cwrzv5w4+8se3f06MYuawkx+2Wug+RdiPlQ9A6b6TdJvpaws
+bGb38AHFz8JdU+qUIraxwe8cPH/YPDH/sIO86onaQjxRKh/xfQCHbWleLGH
DwNC3A8anujqwcbXMzqgmw+LL3T3oMQvkvth6WEjmn/R0w8AFbD7rw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0EIOMPHVq0CACUM8FAwY
McQhfAYM8TCw+r/22M3/hSEO4f8gWRziLkEMcYg9AjjMwRSHqOfDEIf4gxeH
OTwExVeh+JcHLTz/4jAHFp7o6hkxxFehxBe6OSwki4di9S+LA/bwgZmDHp4w
9Zji2OMLkQ4B10TKoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlRRxg4qFggCm+ehUIYIpD
+D9xmIMpDjZmFaY4hP+LaPHVOMzBZS8ud+LyVxiOcMAVbujiAMf1c5Y=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AkD9mQg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQQg7o4qEgIIopvnoVEGhh
ikNIHOaE4jAnC4c5DcSL4zIHl7243InLX7jCAVe4wcQBgY9kdQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcACTDaIO6OKhIDAVU3z1KhDA
FAeTB3CYcxWHOa9wmMMgRrQ4LnNw2YvLnbj8hSsccIUbTBwANZlqJA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSIg4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAEDlOHg=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOIDJBiGHhgt8rEV+81HFGYQd
GC64x1l+rUNTLwyVhwMoXwSHehEc5os6YHePqIMxGFwmTpwBl3oRHOpxiAP9
hV09DnFguOEKTwCrBjYL
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0CIOMPFXF9ftu/KUyUG9
qPNTUjJC3MD9RKv0TCaI+gMI8dlvZ9/kk2dyOPftbE47v6gDivkNjA4zlJ8c
6vVBiPs/EXp69BiDw9eM8PhXRWjqGRgg5jcgxJPNb5mWFP2zx67+rz26+adU
Tvg8OvjbHt09Cwrzv5w4+8se3f06MYuawkx+2Wug+RdiPlQ9A6b6m71lvHPn
CGM33wEhfhLqHmNOo8kVH4Tg4v/B4I99xh1p26LNCPFEqH+5p69YINorhCN8
EOJ+0PBEVw82vp7RAd18WHwZobkHJX6R3A9LDzfQ/IuefgDYu/5d
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0GIOMPHVq0CACUM8FAwY
McQhfAYM8TCw+r/22M3/hSEO4f8gWRziLlEMcYg9IjjMwRSHmCOMwxwhHOYQ
Fl+F4l8htPD8i8McWHiiq2fEEF+FEl/o5rCQLI7dvywO2MMHZg56eMLMwRTH
Hl+IdAgAeU/LJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAjnht0Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwA13puOg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0GIH0MVXrwKCV6IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwAe1ZxnQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HAAUw1CB9DFV68CgixM8VAw
wBQHUw44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnCDiQMAykps7Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaJEDDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwAXYTmG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDiAqQbRAw0X+FiL/OajijOI
HmC44B5n+bUOTb3IAQYUAFMvgkO9MA7zhQ9gd4/QAWMwuEycONAc7OpxiAPd
iV09DnFgOGBXL4rD/aIHAPJHPgY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0CIHYOKvLq7bd+Upl8PN
3jLeuXOE4eIG7idapWdyQdQ7IMRnv519k0+ey8GI02hyxQehAyjmN3A6ZNyR
ti3ajBD3fyL09OgxDgfu6SsWiPaiqWfggJjfgBDfKP1WysqSHbv6BjYM81OF
UtQ+PmDFcM+FHeZVT9JYMdwvphfoqC3F6nADzb8Q97BihA9MvXpR56ekZBHs
5h9AiKdA3XP229mcdn5RDPfPUH5yqNdHFMO/XzPC418VieIIH4S4HzQ80dX/
B4F6TgzzYfF1Ds09KPF7ADM9aKD5Fz39AADcpfZU
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0EIHYOKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh9mCKQ9wrjMMcERzmYIpDzBHFYY4YQfFQ
FP+K4QgfdHM4cJjDiSG+CiW+0M3hIVkcu395cIQPzBxMcezhz4MjvhDpEABi
zs0/
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAZqBtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAr6Jt/g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0EIH0MVXrwKCV4IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwAU35xYQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0LwH0MVDQeAqD4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAaEDbZY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaIEDDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwDvejlK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDiAqQbBAw0X+FiL/OajijMI
HmC44B5n+bUOTb3AAQYUAFMvgF09Az8O8/kOYHUPA+8BYzC4TKQ4Hw5xfhzi
AtjFG3CIA8MBu3pB7O4HigMAWYg7xg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AIHYOKvLq7bd+Upl8NG
6bdSVpb8cHED9xOt0jO5IOob+ODis9/Ovsknz+WQKpSi9vEB7wEU8xs4HS7s
MK96koYQ938i9PToMQ4HMb1AR20pNPUMHFD3IMQh7mDHrr6BDcN8iDtYMdwD
UceK4X6IuawY/oW4gxUjfGDq1Ys6PyUlC2A3/wBCPAXqnrPfzua08wtiuH+G
8pNDvT6CGP79mhEe/6pIEHv4NCDE/aDhia7+PwjUc2KYD4uvc2juQYnfA5jp
QQPNv+jpBwCF/fOm
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0gdg4qtXgQAXhngoGHBi
iEP4HDjMYcMQDwObw4rDHBaSxSHu4sUQh9jPh8McARzqMcUh5gviMEeIoHgo
in+FcIQPujkcOMzhxBBfhRJf6ObwkCyO3b88OMIHZg6mOPbw53EIwxpfiHQI
AK0TzLo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAFvBtHQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAX/Jthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0DwH0MVDQeAqN4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAZcNbYc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0KwH0MVDQeAqC4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAVFTbR4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaI4DDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwCfyjjS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaO4DDRf4WIv85qOJcx1g
uOAeZ/m1Dk2c8wADCoCJc+BQz47DfLYD2N3DesAYDC4TKc6GQ5wdhzgHDnFO
HOJcOMS5cbif+wAAn+442A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0BwHYOKvLq7bd+Upl8NG
6bdSVpbscHED9xOt0jO5IOob2ODis9/Ovsknz+WQKpSi9vEB6wEU8xs4HS7s
MK96koYQ938i9PToMQ4HMb1AR20pNPUMHFD3IMSh7sCuvoENw3yoOzDcA1WH
4X6ouRj+hboDI3xg6v0g/sBhPidcPAXqHmg4YbgfGq4Y/oXGA47w4YaLQ92B
of4/CNRzYpgPiy9096DGLydGevBH8y96+gEAYrP0KQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0CwHYOKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh7mLFEIfaj8McDhzmcGKIr4KEBw5zeAiK
h6L4lwdH+KCbw4HDHE4M8VUo8YVuDg/J4qux+pcHR/jAzEEPTx4c4c/jEIY1
vhDpEACjIMvv
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAxzFspQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAEEJtDg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0CwH0MVDQeAqM4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAUddbQ8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0L/2o4uvXgUCPzHEQ8EA
UxxCY4pDzPmBIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOABXFemQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaIYDDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwBQGjha
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaOYDDRf4WIv85qOJMx1g
uOAeZ/m1Dk2c8QADCoCJM+BQ/28/dvP/7Mfunl/7jcHgMpHif3CI/8MhznAA
uzgjDnEmHOLMB3CFJwCHtD5O
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AwHYOKvLq7bd+Upl0OS
+S3TkqJ/+2HiBu4nWqVnckHV/4WLz347+yafPJfDKZUTPo8O/t6PYn4Dp8OC
wvwvJ87+gov7PxF6evQYh4NOzKKmMJNfqOoZOKDmI8Q3Sr+VsrJkx66+gQ3D
/FShFLWPD1gx3HNhh3nVkzRWDPeL6QU6akuxYvgXog6mHhE+MPV+YH8gxFHM
b2CEi6dA3QMJJ6YD6O6HhCtCHOZfSDygqYeHDzNc3A8anujq/4NAPSeG+bD4
QncPSvwiuR+WHvzR/IuefgCP6QLG
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0D/2w8RXrwIBLgzxUDDg
xBCH8DlwmMOGIR4GNocVhzksJIuDrVn1C0Mc4t6/OMxhOIBdPSOGOMR8Jgxx
KE1QPBTFvwhx1PBBN4cDhzmcGOKrUOIL3RweksVXY/UvD47wgZmDHp48DmFY
wx9mPnp8IdIhAJuP19U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPASrQ4LnNw2YvLnbj8hSsccIUbujgAFIB6pg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPAQ7Q4LnNw2YvLnbj8hSsccIUbujgAXYJ7Dw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0D/2o4uvXgUC3zHEQ8EA
UxxCY4pDzPmGIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAAHZekY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0E/2o4uHhYLAYwzxVWDw
CEMcQmOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg0mDgAwnnkM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpA6A/7Gy7wsRb5zYeKs8HF
GS64x1l+rYOKsyPEUQAHDvWcOMzngoujuocbLm4MBpcJiHPhEOfEIc6BQ5wd
hzgbDnFEuOEKTwCdWkZb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6G/7Gy7wsRb5zUcT/7Kf
4YJ7nOXXOjTxT/sZUABM/AMO9W9wmP9iP3b3PNlvDAaXiRR/gUP8DQ7xDzjE
P+EQ/4JD/BsO93/bDwCMdEZM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0B/2w8RfXVy378pTLoej
eVuyXzx5Axc3cD/RKj2TC6r+FVx89tvZN/nkuRymeE6YeaT5+X4U8xs4HRwe
33sxcfZTuLj/E6GnR49xOETscGFdm/EEVT0DB9R8hPhG6bdSVpbs2NU3sGGY
nyqUovbxAavDZDT3XNhhXvUkjdXhPxi8hIuL6QU6akuxOhxB8y/EHawY4QNT
P/eE6qnu3o8Y5kPUf4aLp0DdY3bbfLOs3RcM9yf0TeA2N/qK4d8ri2NrV57+
iiN8vsHF/aDhia4e7M16TgzzYfGF7h5Y/DKiuR+WHuaj+Rc9/QAAdlURjA==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0A/2w8RXrwIBLgzxUDDg
xBCH8DlwmMOGIR4GNocVhzksJItD3PUUQxxs/apXOMz5gEP9Jxzmf8Vhzg+C
4qEo/v2BI3zQzeHAYQ4nhvgqlPhCN4eHZPEwrP7lcViNNXxg5qCHJ0w9evjD
zEePL0Q6BAAO9OTb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHFggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGFiJFsdlDi57cbkTl79whQOucEMXBwBZiGFl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HZggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGHiIFsdlDi57cbkTl79whQOucEMXBwCiimHO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0A/2o4uvXgUC9zDEQ8Hg
LoY4hL6Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9xg4gD0z3i0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0Dfs0cVDweAmhvjqVSBw
C0McQt/BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9xg4gD/pHEs

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDowQEHDBT7WIr/5UHE2uDjD
Bfc4y691UHF2hDgK4MChnhOH+VxwcVT3cMPFjcHgMgFxLhzinDjEOXCIs+MQ
Z8Mhjgg3XOEJAOJiLRo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6Bv7Gy7wsRb5zUcTv7Cf
4YJ7nOXXOjTxA/sZUABMHKQFq3p7HObb43CPvTEYXCZS/AIO8QM4xBkYcKjf
j8N8HOI39uMKTwDy2D5I
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HZggAKY+KuL6/ZdecrlcKMz
ZtGeGzvsYeIG7idapWdyOfwHg+Nw8dlvZ9/kk+dyuJlz/0zZjwv2KOY3cDo0
WDrp3TlxBS7u/0To6dFjHA7+/WVfl+pdR1XPwAF1zw24+Ebpt1JWluwOAdjU
N7BhmJ8qlKL28QGrwy0091zYYV71JI3VgQWs8QRcXEwv0FFbitXhAZp/Ie5g
deDqmudjWdllg67+HET9fnTz/0DCBy6eAnXPdYh79qO7vw7i/v3o/vWD+Hc/
jvCBi/tBwzMATT3YGfWcDk1o5sPi6xaae2DxywYJn/3o6eEdmn9h6QcSPrP2
AABwYxbb
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0A/sYeKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh5l3FIX4Uhzno4cDiEAJRvx+7+FUMcah7
CIqHovp3P47w2Y8jPPfjCH+4+CrU+NqPI36JFg/D6l+YOHr4wMzBTFchWMMf
Jo4eX4h0CADDQtEl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAILVzJg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAabdzjw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0A/s0cVXgQGmeFgoCDzE
EIfQj3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINJg4AO3txiA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0N/s0cVDwQBTfPUqEMAU
h9DfcZiDKQ42ZhWmOIT+QbT4ahzm4LIXlztx+SsMRzjgCjeYOAAMunLE
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpA6A/2DRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwCpjz7b
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6Cf2DRf4WIv85qOJv7Bn
uOAeZ/m1Dk38DZQPAzDxDzjUf8Jh/hd77O75Zm8MBpeJFP+CQ/wTDvEPOMTf
4BB/gUP8CQ73P7EHAJiFPro=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0B/sYeKvLq7bd+Upl8O8
E6qnuns/wsUN3E+0Ss/kgqr/DBef/Xb2TT55Lgez2+abZe2+2KOY38DpkNA3
gdvc6Ctc3P+J0NOjxzgcriyOrV15+iuqegYOqPnf4OIbpd9KWVmyY1ffwIZh
fqpQitrHB6wY7rmww7zqSRorhvvF9AIdtaVYMfwLUQdT/wFD/bG8LdkvnrzB
MJ8RrP4VXDwF6p4pnhNmHml+juF+x8f3Xkyc/RTDv5E7XFjXZjzBET4IcT9o
eEagqf8PAvWcDvZo5sPiazKae2Dx+w+s8SVGejiE5l9Y+gEr///eHgDc5AsE

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0D/sYeKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh5n3FEIfY/wmHOR9wqH+Fw/ynOMx5QFA8
FMW/D3CED7o5HDjM4cQQX4USX+jm8JAsHorVvzwOq7CGD8wc9PCEqUcPf5j5
6PGFSIcAKbXW2w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4A02ZlJQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AHHdljg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0D/s0cVDwQBTfPUqEMAU
h9A/cZiDKQ42ZhWmOIT+RbT4ahzm4LIXlztx+SsMRzjgCjeYOAAgpnLi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0MwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOEGEwcAU5Bljg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaAaHhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwBcTzDa
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6F/2DRf4WIv85qOJ/7Fn
uOAeZ/m1Dk38H5QPAzBxBgfs6hkdsJvP5IDdPcwOxmBwmUhxJhzijDjEGXCI
/7PHLv4Hh/gve1zhCQCV1jfE
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AwOMPFXF9ftu/KUy8H/
idDTo8cQ4gbuJ1qlZ3JB1DcwwsVnv519k0+eywFCMzmgmN/A6QDRhxCHmMvh
ALEHTT0DB9Q9zHDxjdJvpaws2bGrb2DDMD9VKEXt4wNWDPdc2GFe9SSNFcP9
YnqBjtpSrBj+hbiDFSN8YOqTzW+ZlhT9s8dqPsNfuHgK1D2nVE74PDr42x7d
/QsK87+cOPvLHt2/OjGLmsJMftljDx+EuB80PNHV/weBek4M82Hxhe4eWPyC
9f3/Y4+eHhLR/IuefgDEivwx
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0CwOMPHVq0CAC0M8FAw4
McQhfA4c5rBhiIeBzWHFYQ4LyeIQe5gwxCHuZcRhDgOGOMRdf+2xm/8LQxxC
/yAoHoriX4Q4avigm8OBwxxODPFVKPGFbg4PyeKrsPqXBxqe6OEDMwc9PHlw
hD/MfPT4QqRDAB9pydU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AIyVlnQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AbCdmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0CwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAXYZlnQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0NwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOEGEwcAo0BmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaA6Hhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwCr/zFS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaFaHhgt8rEV+89HE2RwY
LrjHWX6tQxNnh9IwABPnwKGeE4f5XA7Y3cPtYAwGl4kU58IhzolDnAOHODsO
cTYc4qw43M/qAACsFzFS
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0BwOMPFXF9ftu/KUy8H/
idDTo8cQ4gbuJ1qlZ3JB1DdwwsVnv519k0+eywFGo5gPVAfTBxOHmQuzB9U9
HA4wd8HEN0q/lbKyZMeuvoENw/xUoRS1jw9YMdxzYYd51ZM0Vgz3i+kFOmpL
sWL4F+IOVozwganfBHUXdvPZ4OIpUPfA3IXufpg+dP/C7MEePghxP6i70dX/
B4F6TgzzYeGC7h7U+GXDSA8b0fyLnn4AmZfnqw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0TDx1atAgAtDPBQMODHE
IXwOHOawYYiHgc1hxWEOC8niMPeii8Pci90cDhzmsGGIw9yL3RwWguKhKP5l
wRE+6OZw4DCHE0N8FUp8oZvDQ7J4KFb/8uAIH5g56OHJgyP8eRxWYY0vRDoE
AChBve8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4ActVmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4Au9dmfg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0DwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOEGEwcArTZmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HAAUw2CDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIES0OC5zcNmLy524/IUrHHCFG0wcAGExamA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaAGHhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwD7rzHK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaF6Hhgt8rEV+89HE+RwY
LrjHWX6tQxPnh9IwABMXwK6+QQCH+YIOWN3TIOhgDAaXiRNnwKVeAId6XOL8
OMT5cIjzYnc/UBwAZDUzwg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AIOMPFXF9ftu/KUy0G9
qPNTUjJC3MD9RKv0TC6I+gMI8dlvZ9/kk+dyOPftbE47v6ADivkNnA4zlJ8c
6vVBiPs/EXp69BiHw9eM8PhXRWjqGTgg5jcgxDdKv5WysmTHrr6BDcP8VKEU
tY8PWDHcc2GHedWTNFYM94vpBTpqS7E6aKD5F+IeVozwganfBHYXP3bzG/jg
4ilQ90DcxYvhfog+Xgz/QuzhxR4+DAhxP2h4oqv/DwL1nBjmw+IL3T0o8Yvk
flh62IjmX/T0AwBIQuco
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0EIOMPHVq0CAC0M8FAw4
McQhfA4c5rBhiIeBzWHFYQ4LyeIQdwliiEPsF8BhDqY4RD0fhjjEvbw4zOEh
KB6K4l8eHOGDbg4HDnM4McRXocQXujk8JIuHYvUvD47wgZmDHp48OMKfB0d8
IdIhAB6Evro=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4Amq1mUQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4A469mug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0EIO6OKhICCKKb56FRBo
YYqDKQcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7jBxAHU/2Tt
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HAAUw2iDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIEa0OC5zcNmLy524/IUrHHCFG0wcAIkJapw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaBGHhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwAjljIG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDiAqQYhh4YLfKxFfvNRxRmE
HRguuMdZfq1DUy8MlYcBmHoRHOpFcJgv6oDdPaIOxmBwmThxBlzqRXCoxyEO
9Bd29TjEgeGGKzwB/nY2gw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0CIOMPFXF9ftu/KUy0G9
qPNTUjJC3MD9RKv0TC6I+gMI8dlvZ9/kk+dyOPftbE47v6gDivkNnA4zlJ8c
6vVBiPs/EXp69BiHw9eM8PhXRWjqGTgg5jcgxDdKv5WysmTHrr6BDcP8VKEU
tY8PWDHcc2GHedWTNFYM94vpBTpqS7E6aKD5F+IeVozwgam/2VvGO3eOMHbz
HRDiKVD3GHMaTa74IITh/ow70rZFm4Uw/Ms9fcUC0V4hHOGDEPeDhie6+v8g
UM+JYT4svozQ3IMSv0juh6WHG2j+RU8/AAtc6dY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0GIOMPHVq0CAC0M8FAw4
McQhfA4c5rBhiIeBzWHFYQ4LyeIQd4liiEPsF8FhDqY4xBxhHOYI4TCHsHgo
in+FcIQPujkcOMzhxBBfhRJf6ObwkCyO3b88OMIHZg56ePLgCH8eHPGFSIcA
wIC/Pw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwA4ehuSQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMIgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQC4O3KU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0GIH0MVXrwKCV6IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwAzsZyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHAAUw1CB9DFV68CgixM8VAw
wBQHUw44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnCDiQMAHcltZQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaJEDDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScA4vA79g==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDiAqQbRAw0X+FiL/OajijOI
HmC44B5n+bUOTb3IAQYUAFMvgkO9MA7zhQ9gd4/QAWMwuEycONAc7OpxiAPd
iV09DnFgOGBXL4rD/aIHAEXGPn4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMIgdg4l8zwuNfFQk6
3Owt4507RxguPkP5yaFeH6h6B4T4uW9nc9r5BR2MOI0mV3wQOoBi/gEBh4w7
0rZFmxHi6kWdn5KSBRy4p69YINqLpp5BAGJ+A0J8o/RbKStLfuzqG/gwzE8V
SlH7+IAXwz0XdphXPUnjxXC/mF6go7YUr8MNNP9C3MOLET4w9RB/iGA3/wBC
PAXqnrPgcBLFcD8kXEUx/AuJB1Ec4SOKEZ5Y1QPDH918WHydQ3MPSvwewEwP
Gmj+RU8/ALDm8VU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0gdg4qFgIIghvnoVCAhg
iEP4mOIQ9XwY4mFg83lxmMNDsjjEHkxxiD+EcZgjgsMcTHGIOaI4zBEjKB6K
4l8xHOGDbo4ADvWY4qjxhW6OEMni2P0rhCN8YOZgimMPfyEc8YVIhwB2Yc4K

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAuhBuDQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMAgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQCQY3JY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0EIH0MVXrwKCV4IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwApu5x2Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0LwH0MVDQeAqD4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAfRzbg4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaIEDDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAuxg7ug==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDiAqQbBAw0X+FiL/OajijMI
HmC44B5n+bUOTb3AAQYUAFMvgF09Az8O8/kOYHUPA+8BYzC4TKQ4Hw5xfhzi
AtjFG3CIA8MBu3pB7O4HigMArPg8Pg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMAgdg4l8zwuNfFQk6
bJR+K2VlyQ8Xn6H85FCvD1R9Ax9c/Ny3sznt/IIOqUIpah8f8B5AMf+AgMOF
HeZVT9IQ4upFnZ+SkgUcxPQCHbWl0NQzCEDdgxCHugO7+gY+DPOh7sBwD1Qd
hvuh5mL4F+oOjPCBqYf6A7v5BxDiKVD3nIWEE4b7oeGK4V9oPGAPnwZBjPDE
qh4Y/ujmw+LrHJp7UOL3AGZ60EDzL3r6AQBaPu6n
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0DwHYOKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xL28GOJQ+3GYI4BDPaY4NDxwmCNEUDwU
xb9COMIH3RwBHOoxxVHjC90cIZLFsftXCEf4wMzBFMce/kIOYVjjC5EOAcCm
zYU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAamBtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMHAdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQBAs3Hg
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0DwH0MVDQeAqN4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAep9bf8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0KwH0MVDQeAqC4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAaTDbZY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaI4DDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAa2g7Qg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaO4DDRf4WIv85qOJcx1g
uOAeZ/m1Dk2c8wADCoCJc+BQz47DfLYD2N3DesAYDC4TKc6GQ5wdhzgHDnFO
HOJcOMS5cbif+wAA8145UA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMHAdg4l8zwuNfFQk6
bJR+K2VlyQ4Xn6H85FCvD1R9Axtc/Ny3sznt/IIOqUIpah8fsB5AMf+AgMOF
HeZVT9IQ4upFnZ+SkgUcxPQCHbWl0NQzCEDdgxCHuIMfu/oGPgzzIe7gxXAP
RB0vhvsh5vJi+BfiDl6M8IGp93si9PToMQ4c5nPCxVOg7pn9dvZNPnkuDPcb
uJ9olZ7JheHfVxfX7bvylAtH+HBjhCdW9cDwRzcfFl/o7kGNX06M9OCP5l/0
9AMANvTvKg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0CwHYOKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xL2sGOIQ+9lwmMOBwxxODHGwMau4cJjD
Q1A8FMW/PDjCB90cARzqMcVR4wvdHCGSxVdj9a8QjvCBmYMenkI4wl/IIQxr
fCHSIQC2s8y6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAGrBtHQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0YICAAzDxUBCYiim+ehUI
YIpDeDjMuYrDnFc4zGEQIloclzm47MXlTlz+whUOuMINXRwA8PRxaA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0CwH0MVDQeAqM4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAZrNbYc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0L/2o4uvXgUCPzHEQ8EA
UxxCY4pDzPmBIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAGk1etw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaIYDDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAG7g6yg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaOYDDRf4WIv85qOJMx1g
uOAeZ/m1Dk2c8QADCoCJM+BQ/28/dvP/7Mfunl/7jcHgMpHif3CI/8MhznAA
uzgjDnEmHOLMB3CFJwDbJD7G
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0YICAAzDxrxnh8a+KBB2S
zG+ZlhT92w8Tn6H85FCvD0z9X7j4uW9nc9r5BR1OqZzweXTw934U8w8IOCwo
zP9y4uwvuLh6UeenpGQBB52YRU1hJr9Q1TMIQM1HiG+UfitlZcmPXX0DH4b5
qUIpah8f8GK458IO86onabwY7hfTC3TUluLF8C9EHUw9Inxg6v2eCD09egwh
jmJ+AyNcPAXqntlvZ9/kk2c6gO5+A/cTrdIzEeIw/766uG7flado6uHhw3wA
PTyxqgeGP7r5sPhCdw9K/CK5H5Ye/NH8i55+AGQq/bg=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0D/2w8RDwUAQQ3z1KhAQ
wBCH8DHFIer5MMTDwObz4jCHh2RxsDWrfmGIQ/zxF4c5DAewq2fEEIeYz4Qh
DqFZCIqHovgXIY4aPujmCOBQjymOGl/o5giRLL4aq3+FcIQPzBz08BRyCMMa
/jDz0eMLkQ4BryLYoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPAS7Q4LnNw2YvLnbj8hSsccIUbujgAZ/B7Hg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMH/bDxENBYCqm+OpV
IIApDuYewGHOVRzmvMJhDoMQ0eK4zMFlLy534vIXrnDAFW7o4gA+Q39p
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0D/2o4uvXgUC3zHEQ8EA
UxxCY4pDzPmGIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAFVJer4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0E/2o4uHhYLAYwzxVWDw
CEMcQmOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg0mDgCEDnmE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpA6A/7Gy7wsRb5zYeK88HF
GS64x1l+rYOK8yPEUYAAdvUNCHFU8wXh4ijuaUCIG4PBZfziDLjUC+BQj0uc
H4c4Hw5xRLjhCk8AaPhIyw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6G/7Gy7wsRb5zUcT/7Kf
4YJ7nOXXOjTxT/sZUABM/AMO9W9wmP9iP3b3PNlvDAaXiRR/gUP8DQ7xDzjE
P+EQ/4JD/BsO93/bDwDf5EbE
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMH/bDxL9mhMe/KhJ0
OJq3JfvFkzdw8RnKTw71+sDUv4KLn/t2NqedX9BhiueEmUean+9HMf+AgIPD
43svJs5+ChdXL+r8lJQs4BCxw4V1bcYTVPUMAlDzEeIbpd9KWVnyY1ffwIdh
fqpQitrHB7wOk9Hcc2GHedWTNF6H/2DwEi4uphfoqC3F63AEzb8Qd/BihA9M
/dwTqqe6ez9imA9R/xkungJ1j9lt882ydl8w3J/QN4Hb3Ogrhn+vLI6tXXn6
K47w+YYRnljVA8Mf3XxYfKG7Bxa/jGjuh6WH+Wj+RU8/AEqWDI0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0A/2w8RDwUAQQ3z1KhAQ
wBCH8DHFIer5MMTDwObz4jCHh2RxiHufYoiDrV/1Coc5H3Co/4TD/K84zPlB
UDwUxb8/cIQPujkCONRjiqPGF7o5QiSLh2H1r5DDaqzhAzMHPTxh6tHDH2Y+
enwh0iEAIoflpg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HFggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGHiJFsdlDi57cbkTl79whQOucEMXBwCs+GHd
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0YIACmHgoCEzFFF+9CgQw
xcGcAzjMuYrDnFc4zGEQIloclzm47MXlTlz+whUOuMINXRwAg0tmKA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0A/2o4uvXgUC9zDEQ8Hg
LoY4hL6Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9xg4gBITnks

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0Dfs0cVDweAmhvjqVSBw
C0McQt/BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9xg4gBTI3Gk

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DowQEHDBT7WIr/5UHE+uDjD
Bfc4y691UHF+hDgKEMCuvgEhjmq+IFwcxT0NCHFjMLiMX5wBl3oBHOpxifPj
EOfDIY4IN1zhCQCuAC+K
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6Bv7Gy7wsRb5zUcTv7Cf
4YJ7nOXXOjTxA/sZUABMHKQFq3p7HObb43CPvTEYXCZS/AIO8QM4xBkYcKjf
j8N8HOI39uMKTwBGVz7A
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0YIACmPjXjPD4V0WCDjc6
YxbtubHDHiY+Q/nJoV4fQYf/YHAcLn7u29mcdn5Bh5s598+U/bhgj2L+AQGH
BksnvTsnrsDF1Ys6PyUlCzj495d9Xap3HVU9gwDUPTfg4hul30pZWfI7BGBT
38CHYX6qUIraxwe8DrfQ3HNhh3nVkzReBxawxhNwcTG9QEdtKV6HB2j+hbiD
14Gra56PZWWXDbr6cxD1+9HN/wMJH7h4CtQ91yHu2Y/u/jqI+/ej+9cP4t/9
OMJnP3p4BmBTDwz/JjTzYfF1C809sPhlg4TPfvT08A7Nv7D0AwmfWXsARKQR
3A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0A/sYeKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xLyrOMSP4jAHPRx4HEIg6vdjF7+KIQ51
D0HxUFT/7scRPvtxhOd+HOG/H0d87ccRv0SLh2H1L0wcPXxg5mCmqxCs4Q8T
R48vRDoEANbV0fA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAdCVzng==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMH+xh4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQBKeHfp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0A/s0cVXgQGmeFgoCDzE
EIfQj3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINJg4AjutyAA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0N/s0cVDwQBTfPUqEMAU
h9DfcZiDKQ42ZhWmOIT+QbT4ahzm4LIXlztx+SsMRzjgCjeYOABgKnM8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpA6A/2DRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAdS1BSw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6Cf2DRf4WIv85qOJv7Bn
uOAeZ/m1Dk38DZQPAzDxDzjUf8Jh/hd77O75Zm8MBpeJFP+CQ/wTDvEPOMTf
4BB/gUP8CQ73P7EHAOv1PzI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMH+xh4l8zwuNfFQk6
zDuheqq79yNcfIbyk0O9PjD1n+Hi576dzWnnF3Qwu22+Wdbuiz2K+QcEHBL6
JnCbG32Fi6sXdX5KShZwuLI4tnbl6a+o6hkEoOZ/g4tvlH4rZWXJj119Ax+G
+alCKWofH/BiuOfCDvOqJ2m8GO4X0wt01JbixfAvRB1M/QcM9cfytmS/ePIG
w3xGsPpXcPEUqHumeE6YeaT5OYb7HR/fezFx9lMM/0bucGFdm/EER/g8wQjP
CGzqgeFvj2Y+LL4mo7kHFr///oPAS4z0cAjNv7D0A1b+/709ALElBgU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0D/sYeKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xLyvGOIQ+z/hMOcDDvWvcJj/FIc5DwiK
h6L49wGO8EE3RwCHekxx1PhCN0eIZPFQrP4VcliFNXxg5qCHJ0w9evjDzEeP
L0Q6BAA9SNem
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AJuVlnQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0YIAAB5h4KAhMxRRfvQoE
MMXBvAM4zLmKw5xXOMxhECJaHJc5uOzF5U5c/sIVDrjCDV0cAP0paeg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0D/s0cVDwQBTfPUqEMAU
h9A/cZiDKQ42ZhWmOIT+RbT4ahzm4LIXlztx+SsMRzjgCjeYOAB0FnNa
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0MwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOEGEwcApwBmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaAaHhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMAJ+0zSg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6F/2DRf4WIv85qOJ/7Fn
uOAeZ/m1Dk38H5QPAzBxBgfs6hkdsJvP5IDdPcwOxmBwmUhxJhzijDjEGXCI
/7PHLv4Hh/gve1zhCQDpRjg8
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0YIAAB5j414zw+FdFgg7+
T4SeHj2GEJ+h/ORQrw9UfQMjXPzct7M57fyCDrPfzr7JJ8/kgGL+AQEHA/cT
rdIzEeLqRZ2fkpIFHF5dXLfvylM09QwCUPcww8U3Sr+VsrLkx66+gQ/D/FSh
FLWPD3gx3HNhh3nVkzReDPeL6QU6akvxYvgX4g5ejPCBqU82v2VaUvTPHqv5
DH/h4ilQ95xSOeHz6OBve3T3LyjM/3Li7C97dP/qxCxqCjP5ZY89fBDisPDE
qh4Y/ujmw+IL3T2w+P0PBn/s0dNDIpp/0dMPAJjL9zI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0CwOMPFQMBDEEF+9CgQE
MMQhfExxiHo+DPEwsPm8OMzhIVkcYg8ThjjEH4w4zGHAEIe46689dvN/YYhD
6B8ExUNR/IsQRw0fdHMEcKjHFEeNL3RzhEgWX4XVv0LQ8EQPH5g56OEphCP8
YeajxxciHQIAMvzKoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AdpVmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMHA4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRu6OABM6Gpg
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0CwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAsPZmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0NwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOEGEwcA9rBmfg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaA6Hhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMAd50zwg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaFaHhgt8rEV+89HE2RwY
LrjHWX6tQxNnh9IwABPnwKGeE4f5XA7Y3cPtYAwGl4kU58IhzolDnAOHODsO
cTYc4qw43M/qAAD/hzHK
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMHA4w8a8Z4fGvigQd
/J8IPT16DCE+Q/nJoV4fqPoGTrj4uW9nc9r5BR1mv519k0+eywHF/AMCDgbu
J1qlZyLE1Ys6PyUlCzi8urhu35WnaOoZBKDu4YaLb5R+K2VlyY9dfQMfhvmp
QilqHx/wYrjnwg7zqidpvBjuF9MLdNSW4sXwL8QdvBjhA1O/Cewudhzms8HF
U6DugbiLFcP9EH2sGP6F2MOKI3xYMcITq3pg+KObD4svdPegxi8bRnrYiOZf
9PQDAG3Y4qw=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0DwOMPFQMBDEEF+9CgQE
MMQhfExxiHo+DPEwsPm8OMzhIVkcYg8XhjjEH5w4zOHAYQ4bhjjEvaw4zGEh
KB6K4l8WHOGDbo4ADvWY4qjxhW6OEMnioVj9K4QjfGDmoIenEI7wF3JYhTW+
EOkQADvUvro=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AxkVmjQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMAg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRu6OACcmGrY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0DwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAALVmjQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHAAUw2CDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIES0OC5zcNmLy524/IUrHHCFG0wcALShatg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaAGHhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMAx000Og==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaF6Hhgt8rEV+89HE+RwY
LrjHWX6tQxPnh9IwABMXwK6+QQCH+YIOWN3TIOhgDAaXiRNnwKVeAId6XOL8
OMT5cIjzYnc/UBwAt6U0Og==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMAg4w8a8Z4fGvigQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5BBxiNYj5QHUwfTBxmLsweFPVA
d8DcBRPfKP1WysqSH7v6Bj4M81OFUtQ+PuDFcM+FHeZVT9J4MdwvphfoqC3F
66CB5l+Ie3gxwgemfhPUXVjNB7oLJp4CdQ/MXejuh+lD9y/MHqzhw8CLEZ5Y
1QP9iW4+LFzQ3YMSv0juh4X7RjT/oqcfAByD4ik=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0TDxUDAQxBBfvQoEBDDE
IXxMcYh6PgzxMLD5vDjM4SFZHOZedHGYe7GbgykOcy+6OMy92M3hISgeiuJf
Hhzhg26OAA71mOKo8YVujhDJ4qFY/SuEI3xg5qCHpxCO8BfCEV+IdAgAMhe/
hQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4A7h1myQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMIg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRu6OADEcGsU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0EIO6OKhICCKKb56FRBo
YYqDKQcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7jBxAEofmVl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHAAUw2iDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIEa0OC5zcNmLy524/IUrHHCFG0wcANx5axQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaBGHhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMA7yU0dg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDiAqQYhh4YLfKxFfvNRxRmE
HRguuMdZfq1DUy8MlYcBmHoRHOpFcJgv6oDdPaIOxmBwmThxBlzqRXCoxyEO
9Bd29TjEgeGGKzwBUfU2+w==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMIg4w8a8Z4fGvigQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5BBwgt6oBi/gEBB4g+hDjEXAEH
iD1o6hkEIOY3IMQ3Sr+VsrLkx66+gQ/D/FShFLWPD3gx3HNhh3nVkzReDPeL
6QU6akvxOmig+RfiHl6M8IGpv9lbxjt3jjB28x0Q4ilQ9xhzGk2u+CCE4f6M
O9K2RZuFMPzLPX3FAtFeIRzhI4QRnljVA8Mf3XxYfBmhuQclfpHcD0sPN9D8
i55+AN+O5Nc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0GIOMPFQMBDEEF+9CgQE
MMQhfExxiHo+DPEwsPm8OMzhIVkc4l5RDHGI/SI4zMEUh5gjjMMcIRzmEBYP
RfGvEI7wQTdHAId6THHU+EI3R4hkcez+FcIRPjBz0MNTCEf4C+GIL0Q6BADU
E8AK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0CIHYOKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAAIBtIQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMIgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQDh83LQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0GIH0MVXrwKCV6IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwA+H5yUQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHEAUw1CB9DFV68CgixM8VAw
wBQHUw44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnCDiQMAR4FtoQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGkQMNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJAJNIPrc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDiAqQbRAw0X+FiL/OajijOI
HmC44B5n+bUOTb3IAQYUAFMvgkO9MA7zhQ9gd4/QAWMwuEycONAc7OpxiAPd
iV09DnFgOGBXL4rD/aIHAG9+Pro=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMIgdg4l8zwuNfFYk6
3Owt4507RxguPkP5yaFeH6h6B4T4uW9nc9r5RR2MOI0mV3wQOoBi/gERh4w7
0rZFmxHi6kWdn5KSRRy4p69YINqLpp5BBGJ+A0Ic6g7s6h2EMcyHugPDPVB1
GO6HmutwA82/UHdghA9MPdQf2M0/IILhnrOQcMJwPzRc4eJQdzhA4wFH+Ihi
hCdW9cDwRzcfFl/n0NyDEr8HMNODBpp/0dMPANQ39AQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0EIHYOKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sWh5mGIQ+3HYY4IDnMwxaHhgcMcMYLiqP4VwxE+
6OaI4DAHUxw1vtDNESNZHLt/xXCED8wcTHHs4S+GI74Q6RAAKlzOjw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AIHYOKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcA2Jls5Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMAgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQC6G3KU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0EIH0MVXrwKCV4IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwA0KZyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0LwH0MVDQeAqD4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAR46bko=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGgQMNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJAGtwPns=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDiAqQbBAw0X+FiL/OajijMI
HmC44B5n+bUOTb3AAQYUAFMvgF09Az8O8/kOYHUPA+8BYzC4TKQ4Hw5xfhzi
AtjFG3CIA8MBu3pB7O4HigMA1rA8eg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMAgdg4l8zwuNfFYk6
bJR+K2VlyQ8Xn6H85FCvD1R9Ax9c/Ny3sznt/KIOqUIpah8f8B5AMf+AiMOF
HeZVT9IQ4upFnZ+SkkUcxPQCHbWl0NQziEDdgxC/2VvGO3eOMHb1DsIY5htx
Gk2u+CCE4Z6MO9K2RZuFMNzPPX3FAtFeIQz/QtQJYYQPTD3EHwLYzT8ggOGe
s+BwEsRwPyRcEeI3oP6FxIMg9vBpEMQIT6zqgeGPbj4svs6huQclfg9gpgcN
NP+ipx8AfY/xVg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0DwHYOKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sUh9vBiiEPs4cNhjgAO9ZjiEPMFcZgjRFAc1b9C
OMIH3RwRHOZgiqPGF7o5YiSLY/evGI7wgZmDKY49/MUcwrDGFyIdAgB0oc4K

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0BwHYOKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAiOlsbQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMHAdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQBqa3Ic
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0DwH0MVDQeAqN4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEARREbjs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0KwH0MVDQeAqC4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAc57bdI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGjgMNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJABvAPgM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaO4DDRf4WIv85qOJcx1g
uOAeZ/m1Dk2c8wADCoCJc+BQz47DfLYD2N3DesAYDC4TKc6GQ5wdhzgHDnFO
HOJcOMS5cbif+wAAHSU5jA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMHAdg4l8zwuNfFYk6
bJR+K2VlyQ4Xn6H85FCvD1R9Axtc/Ny3sznt/KIOqUIpah8fsB5AMf+AiMOF
HeZVT9IQ4upFnZ+SkkUcxPQCHbWl0NQziEDdgxC/2VvGO3eOMHb1DsIY5htx
Gk2u+CCE4Z6MO9K2RZuFMNzPPX3FAtFeIQz/QtQJYYQPTL3fE6GnR49x4DCf
E8M9s9/Ovsknz4XhfgP3E63SMxHiN6D+fXVx3b4rT7lwhA83RnhiVQ8Mf3Tz
YfGF7h7U+OXESA/+aP5FTz8AWkXx2Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0CwHYOKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sUh9rBiiEPsYcNhDgcOczgxxMHGrOLCYQ4PQXFU
//LgCB90c0RwmIMpjhpf6OaIkSy+Gqt/xXCED8wc9PAUwxH+Yg5hWOMLkQ4B
aq7NPw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AwHYOKhICCKKb56FRBo
YYqDeQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAOTlr9Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1YICAAzDxUBCYiim+ehUI
YIpDeDjMuYrDnFc4zGEQI1oclzm47MXlTlz+whUOuMINXRwAGrtxpA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0CwH0MVDQeAqM4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAcSFbcM=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0L/2o4uvXgUCPzHEQ8EA
UxxCY4pDzPmBIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAJLtexg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5MEDAgYYLfKxFfvMh4gzC
cHGGC+5xll/roOqRxFGACA71CHFU80Xh4qjuQYgbg8Fl/OIMuNSL4FCPQxzJ
X6jqcYgjhRuu8AQAzAE9iw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaOYDDRf4WIv85qOJMx1g
uOAeZ/m1Dk2c8QADCoCJM+BQ/28/dvP/7Mfunl/7jcHgMpHif3CI/8MhznAA
uzgjDnEmHOLMB3CFJwAE6z8C
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1YICAAzDxrxnh8a+KRB2S
zG+ZlhT92w8Tn6H85FCvD0z9X7j4uW9nc9r5RR1OqZzweXTw934U8w+IOCwo
zP9y4uwvuLh6UeenpGQRB52YRU1hJr9Q1TOIQM1HiN/sLeOdO0cYu3oHYQzz
jTiNJld8EMJwT8YdaduizUIY7ueevmKBaK8Qhn8h4QNTjwgfmHq/J0JPjx5D
iKOY38B4AN09s9/Ovsknz3QA3f0G7idapWcixG9A/fvq4rp9V56iqYeHD/MB
9PDEqh4Y/ujmw+IL3T0o8Yvkflh68EfzL3r6AQCHewB2
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0D/2w8RDwUAUQ3z1KhAQ
wRCH8DHFIeYI4zBHCIc5pIuDjVv1C0McYv9fHOYwHMCunhFDHGI+E4Y4hGYh
KI7qX4Q4avigmyOCwxxMcdT4QjdHjGTx1Vj9K4YjfGDmoIenmEMY1vCHmY8e
X4h0CABjHdkl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0B/2w8RDQUAUU3z1KiDQ
whQHcx1wmBOKw5wsHOY0EC+Oyxxc9uJyJy5/4QoHXOGGLg4Ahnl59g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMH/bDxENBYCqm+OpV
IIApDuYewGHOVRzmvMJhDoMY0eK4zMFlLy534vIXrnDAFW7o4gBn+3+l
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0D/2o4uvXgUC3zHEQ8EA
UxxCY4pDzPmGIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAH8Bevo=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0E/2o4uHhYLAYwzxVWDw
CEMcQmOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg0mDgCtxnnA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGmGD/sbLvCxFvnNh4gz
CMPFGS64x1l+rYOqRxJHASI41CPEUc0XhYujugchbgwGl/GLM+BSL4JDPQ5x
JH+hqschjhRuuMITABlQS4w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6G/7Gy7wsRb5zUcT/7Kf
4YJ7nOXXOjTxT/sZUABM/AMO9W9wmP9iP3b3PNlvDAaXiRR/gUP8DQ7xDzjE
P+EQ/4JD/BsO93/bDwAJq0cA
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMH/bDxL9mhMe/KhJ1
OJq3JfvFkzdw8RnKTw71+sDUv4KLn/t2NqedX9RhiueEmUean+9HMf+AiIPD
43svJs5+ChdXL+r8lJQs4hCxw4V1bcYTVPUMIlDzEeI3e8t4584Rxq7eQRjD
fCNOo8kVH4QcJqO5J+OOtG3RZiGH/2DwEi7OPX3FAtFeIYcjaP6FhI8QRvjA
1M89oXqqu/cjhvkQ9Z8x3GN223yzrN0XDPcn9E3gNjf6Che/AfXvlcWxtStP
f8URPt8wwhOremD4o5sPiy9098DilxHN/bD0MB/Nv+jpBwBt5w88
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0A/2w8RDwUAUQ3z1KhAQ
wRCH8DHFIeYI4zBHCIc5pItD7HmKIQ62ZtUrHOZ8wKH+Ew7zv+Iw5wdBcVT/
/sARPujmiOAwB1McNb7QzREjWTwMq3/FHFZjDR+YOejhCVOPHv4w89HjC5EO
AdZz5is=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHJggAKYeCgIiGKKr14FBFqY
4mCOAw5zQnGYk4XDnAbixXGZg8teXO7E5S9c4YAr3NDFAcuBYLU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1YIACmHgoCEzFFF+9CgQw
xcGcAzjMuYrDnFc4zGEQI1oclzm47MXlTlz+whUOuMINXRwArQNmZA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0A/2o4uvXgUC9zDEQ8Hg
LoY4hL6Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9xg4gByBnlo

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0Dfs0cVDweAmhvjqVSBw
C0McQt/BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9xg4gB823Hg

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5MEBBwwU+1iK/+RBxBmG4
OMMF9zjLr3VQ9UjiKEAEh3qEOKr5onBxVPcgxI3B4DJ+cQZc6kVwqMchjuQv
VPU4xJHCDVd4AgBeWDJL
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6Bv7Gy7wsRb5zUcTv7Cf
4YJ7nOXXOjTxA/sZUABMHKQFq3p7HObb43CPvTEYXCZS/AIO8QM4xBkYcKjf
j8N8HOI39uMKTwBwDz78
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1YIACmPjXjPD4V0WiDjc6
YxbtubHDHiY+Q/nJoV4fUYf/YHAcLn7u29mcdn5Rh5s598+U/bhgj2L+ARGH
BksnvTsnrsDF1Ys6PyUlizj495d9Xap3HVU9gwjUPTfg4jd7y3jnzhF2CMCm
3kEYw3wjTqPJFR+EHG6huSfjjrRt0WYhBxawxhNwce7pKxaI9go5PEDzLyR8
hBy4uub5WFZ22aCrPwdRvx/d/D+Q8NmP7p7rEPfsR3d/HcT9cPEbUP/6Qfy7
H0f47EcPzwBs6oHh34RmPiy+bqG5Bxa/bJDw2Y+eHt6h+ReWfiDhM2sPAGf1
FIs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0A/sYeKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sXDwPZcxSF+FIc56OEg5BACUb8fu/hVDHGoewiK
o/l3P47w2Y8jPPfjCP/9OOJrP474JVo8DKt/YeLo4QMzBzNdhWANf5g4enwh
0iEAitDSdQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0B/sYeKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAkq5ydg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMH+xh4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQB0MHgl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0A/s0cVXgQGmeFgoCDzE
EIfQj3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINJg4AuKNyPA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0N/s0cVDwQBTfPUqEMAU
h9DfcZiDKQ42ZhWmOIT+QbT4ahzm4LIXlztx+SsMRzjgCjeYOACJ4nN4
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGmGD/YNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJACWFRAw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6Cf2DRf4WIv85qOJv7Bn
uOAeZ/m1Dk38DZQPAzDxDzjUf8Jh/hd77O75Zm8MBpeJFP+CQ/wTDvEPOMTf
4BB/gUP8CQ73P7EHABW8P24=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMH+xh4l8zwuNfFYk6
zDuheqq79yNcfIbyk0O9PjD1n+Hi576dzWnnF3Uwu22+Wdbuiz2K+QdEHBL6
JnCbG32Fi6sXdX5KShZxuLI4tnbl6a+o6hlEoOZ/g4vf7C3jnTtHGLt6B2EM
8404jSZXfBDCcE/GHWnbos1CGO7nnr5igWivEIZ/IeEDU/8BQ/2xvC3ZL568
wTCfEaz+FYZ7pnhOmHmk+TmG+x0f33sxcfZTuPgNqH8jd7iwrs14giN8nmCE
ZwQ29cDwt0czHxZfk9HcA4vff/9B4CVGejiE5l9Y+gEr///eHgDUdgi0
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0D/sYeKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sXDwPZ8xRCH2PMJhzkfcKh/hcP8pzjMeUBQHNW/
D3CED7o5IjjMwRRHjS90c8RIFg/F6l8xh1VYwwdmDnp4wtSjhz/MfPT4QqRD
APE02Cs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AwOMPFQEBDFFF+9Cgi0
MMUhPBzmhOIwJwuHOQ3Ei+MyB5e9uNyJy1+4wgFXuKGLAwBFbmR1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1YIAAB5h4KAhMxRRfvQoE
MMXBvAM4zLmKw5xXOMxhECNaHJc5uOzF5U5c/sIVDrjCDV0cACbwaiQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0D/s0cVDwQBTfPUqEMAU
h9A/cZiDKQ42ZhWmOIT+RbT4ahzm4LIXlztx+SsMRzjgCjeYOACdznOW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0MwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOEGEwcA0LhmQg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5MECAQ8MFPtYiv/kQcQZh
uDjDBfc4y691UPVI4ihABId6hDiq+aJwcVT3IMSNweAyfnEGXOpFcKjHIY7k
L1T1OMSRwg1XeAIA2DY2Cw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6F/2DRf4WIv85qOJ/7Fn
uOAeZ/m1Dk38H5QPAzBxBgfs6hkdsJvP5IDdPcwOxmBwmUhxJhzijDjEGXCI
/7PHLv4Hh/gve1zhCQATDTh4
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1YIAAB5j414zw+FdFog7+
T4SeHj2GEJ+h/ORQrw9UfQMjXPzct7M57fyiDrPfzr7JJ8/kgGL+AREHA/cT
rdIzEeLqRZ2fkpJFHF5dXLfvylM09QwiUPcww8Vv9pbxzp0jjF29gzCG+Uac
RpMrPghhuCfjjrRt0WYhDPdzT1+xQLRXCMO/EHVCGOEDU59sfsu0pOifPVbz
Gf7ao7vnlMoJn0cHf9uju39BYf6XE2d/wcVvQP2rE7OoKczklz328EGIw8IT
q3pg+KObD4svdPfA4vc/GPyxR08PiWj+RU8/ALwc+eE=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0CwOMPFQMBDFEF+9CgRE
MMQhfExxiDnCOMwRwmEO6eIQ85gwxCH2M+IwhwFDPAys/q89dvN/YYhD6B8E
xVH9ixBHDR90c0RwmIMpjhpf6OaIkSy+Cqt/xaDhiR4+MHPQw1MMR/jDzEeP
L0Q6BADm6Msl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0BwOMPFQEBDFFF+9Cgi0
MMXBXAcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7ihiwMAlR5k7Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMHA4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRu6OAB2oGqc
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0CwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOEGEwcA2q5mUQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0NwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOEGEwcAIHdmug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGDoeGC3ysRX7zIeIM
wnBxhgvucZZf66DqkcRRgAgO9QhxVPNF4eKo7kGIG4PBZfziDLjUi+BQj0Mc
yV+o6nGII4UbrvAEACf1NoM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaFaHhgt8rEV+89HE2RwY
LrjHWX6tQxNnh9IwABPnwKGeE4f5XA7Y3cPtYAwGl4kU58IhzolDnAOHODsO
cTYc4qw43M/qAAApTjIG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMHA4w8a8Z4fGvikQd
/J8IPT16DCE+Q/nJoV4fqPoGTrj4uW9nc9r5RR1mv519k0+eywHF/AMiDgbu
J1qlZyLE1Ys6PyUlizi8urhu35WnaOoZRKDu4YaL3+wt4507Rxi7egdhDPON
OI0mV3wQwnBPxh1p26LNQhju556+YoForxCGfyHqhDDCB6Z+k/RbKStLdhzm
s2G4J1UoRe3jA1YM91/YYV71JA0hfgPqXzG9QEdtKVYc4cOKEZ5Y1QPDH918
WHyhuwc1ftkw0sNGNP+ipx8AkSnlWw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0DwOMPFQMBDFEF+9CgRE
MMQhfExxiDnCOMwRwmEO6eIQ87gwxCH2c+IwhwOHOWwY4mFgc1hxmMNCUBzV
vyw4wgfdHBEc5mCKo8YXujliJIuHYvWvGI7wgZmDHp5iOMJfzGEV1vhCpEMA
78C/Pw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AIOMPFQEBDFFF+9Cgi0
MMXBXAcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7ihiwMA5M5lZQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMAg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRu6OADGUGsU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0DwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAKm1myQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHEAUw2CDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIES0OC5zcNmLy524/IUrHHCFG0wcAN5ZaxQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGAYeGC3ysRX7zIeIM
wnBxhgvucZZf66DqkcRRgAgO9QhxVPNF4eKo7kGIG4PBZfziDLjUi+BQj0Mc
yV+o6nGII4UbrvAEAHelNvs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaF6Hhgt8rEV+89HE+RwY
LrjHWX6tQxPnh9IwABMXwK6+QQCH+YIOWN3TIOhgDAaXiRNnwKVeAId6XOL8
OMT5cIjzYnc/UBwA4V00dg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMAg4w8a8Z4fGvikQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5RBwgt6IBi/gERB4g+hDjEXBEH
iD1o6hlEIOY3IMRv9pbxzp0jjF29gzCG+UacRpMrPghhuCfjjrRt0WYhDPdz
T1+xQLRXyEEDzb8QdwhhhA9M/Sbpt1JWlvzYzW/gw3BPqlCK2scHvBjuv7DD
vOpJGkL8BtS/YnqBjtpSvNjDh4EXIzyxqgeGP7r5sPhCdw9K/CK5H5YeNqL5
Fz39AAA/1OTY
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0EIOMPFQMBDFEF+9CgRE
MMQhfExxiDnCOMwRwmEO6eIQewQxxCH2COAwB1Mcop4PQzwMbD4vDnN4CIqj
+pcHR/igmyOCwxxMcdT4QjdHjGTxUKz+FcMRPjBz0MNTDEf4i+GIL0Q6BADm
A8AK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0CIOMPFQEBDFFF+9Cgi0
MMXBXAcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7ihiwMADLVloQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMIg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRu6OADuKGtQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0EIO6OKhICCKKb56FRBo
YYqDKQcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7jBxAFSNmWh
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHEAUw2iDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIEa0OC5zcNmLy524/IUrHHCFG0wcAAZAa1A=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGEYeGC3ysRX7zIeIM
wnBxhgvucZZf66DqkcRRgAgO9QhxVPNF4eKo7kGIG4PBZfziDLjUi+BQj0Mc
yV+o6nGII4UbrvAEAJ99Nzc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDiAqQYhh4YLfKxFfvNRxRmE
HRguuMdZfq1DUy8MlYcBmHoRHOpFcJgv6oDdPaIOxmBwmThxBlzqRXCoxyEO
9Bd29TjEgeGGKzwBe603Nw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMIg4w8a8Z4fGvikQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5RBxiNYj5QHUwfTBxmLsweFPVA
d8DcBRO/2VvGO3eOMHb1DsIY5htxGk2u+CCE4Z6MO9K2RZuFMNzPPX3FAtFe
IQcNNP9C3CGEET4w9TB3YTXfQRjDPcZQGt39MH0w8RtQc2H2YA8fIYzwxKoe
6E9082HhYoTmHpT4RXI/LNxvoPkXPf0AAALu54Y=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0TDxUDAQxRBfvQoERDDE
IXxMcYg5wjjMEcJhDuniMPeii8Pci90cTHGYe7GbI4TDHMLiqP4VwhE+6OaI
4DAHUxw1vtDNESNZHLt/xXCED8wc9PAUwxH+YjjiC5EOAYgOwI8=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyUfXlATV33/73kuoXcBmSIqAhF5AlJ+5jHUhQZHkISryFTT4jS3COUSoMp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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxtXXlYTd/Xv5FUaI7MkSEyRMakfTKLUpRCEpL4GjIlRKmoKEpRMoVoMIUQ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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>{{-5, 3}, {-6.5, 6.5}, {-6.5, 6.5}}]], "Print",
 CellChangeTimes->{3.563404669997407*^9, 3.5661011624661083`*^9, 
  3.614727726310614*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->
  "During evaluation of \
In[257]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData["3.51729400000000014259171621233690530062`6.566808584480055"], \
"Output",
 CellChangeTimes->{3.5634046736643963`*^9, 3.566101168461384*^9, 
  3.614727726324181*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"Out[257]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[plot = TurboPlot[
\t{PointOfRays[{10,10}, NumberOfRays->33, BirthPoint->{-100,10,10}],
\tlenslet,
\tMove[Screen[{15,15}],2.3]}, CloneSortLength->3, CreateClones -> positions, \
RunningCommentary->TurboTrace]][[1]]\
\>", "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"In[258]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277265809803`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726583372*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726585175*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726586896*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "5.`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "5.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "4.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "3.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "2.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", 
            RowBox[{"-", "1.`"}], ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "0.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "1.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "2.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "3.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "4.`", ",", "5.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "5.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "4.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "3.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "2.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", 
            RowBox[{"-", "1.`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "1.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "2.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "3.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "4.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "5.`", ",", "5.`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`ReportedSurfaces -> All, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`CloneSortLength -> 3, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJx1lsFNQzEQRC24cMwhDVCJXQMlIHHmTHX8klJCOOysxJsdS9GXnxb/2ckQ
7/vn98fXy1rr5+/zurju1/8n+S3wt8BX4I/fUB/0PHaoP0FP4LfA7+Dqk7rE
6YP29KHrAqcPPNfq98zpQ+sJnD50v+Dqhz6IU684feh94PSBf2/1e+b0ofUE
Th+6X3DptpzqnMCtjwtPcPpgdazfM6cPrSdw+tD9gksffRCnD+L0ofsMnD6Y
L6zfM6cPrSdw+tD9gmul3630f5xynb7n1HdalgetM2PLQy3LQy3LQ73P8lDc
8lDc8iDdgVseQp9dzzxof4KewC0P6hdc51oeilseilsedG7glgfqYD19OnhS
T+CWh9rbfSF+zdzuC703cLsvitt9QX2s532h+jNzuy9qb/dF7W1+EL9mbvOD
3hu4zQ/FbX6ADqvn/KD6M3ObH878nu4XXHubJ3VO4DZP6tzAbZ6EDqvnPKn6
M3ObJ2tv8+TR8wlCC6DM
      "], Optica`Optica`RunningCommentary -> 
     Optica`Optica`TurboTrace, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`ReportedSurfaces -> 
     All, Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`CloneSortLength -> 3, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJx1lsFNQzEQRC24cMwhDVCJXQMlIHHmTHX8klJCOOysxJsdS9GXnxb/2ckQ
7/vn98fXy1rr5+/zurju1/8n+S3wt8BX4I/fUB/0PHaoP0FP4LfA7+Dqk7rE
6YP29KHrAqcPPNfq98zpQ+sJnD50v+Dqhz6IU684feh94PSBf2/1e+b0ofUE
Th+6X3DptpzqnMCtjwtPcPpgdazfM6cPrSdw+tD9gksffRCnD+L0ofsMnD6Y
L6zfM6cPrSdw+tD9gmul3630f5xynb7n1HdalgetM2PLQy3LQy3LQ73P8lDc
8lDc8iDdgVseQp9dzzxof4KewC0P6hdc51oeilseilsedG7glgfqYD19OnhS
T+CWh9rbfSF+zdzuC703cLsvitt9QX2s532h+jNzuy9qb/dF7W1+EL9mbvOD
3hu4zQ/FbX6ADqvn/KD6M3ObH878nu4XXHubJ3VO4DZP6tzAbZ6EDqvnPKn6
M3ObJ2tv8+TR8wlCC6DM
      "], Optica`Optica`RunningCommentary -> 
     Optica`Optica`TurboTrace, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726595442*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277266069403`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277266085377`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.10180100000000000259881005604256642982`5.028351957413457", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.10180100000000000259881005604256642982`5.028351957413457, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277266721687`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277266743517`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726676055*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726677731*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726727813*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726730698*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277267334747`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727726736459*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277267380257`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727044599*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727046411*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727048152*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277270496683`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"PointOfRays", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"10", ",", "10"}], "}"}], ",", 
             RowBox[{"NumberOfRays", "\[Rule]", "33"}], ",", 
             RowBox[{"BirthPoint", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "100"}], ",", "10", ",", "10"}], "}"}]}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "10", ",", "10"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.9901475429766743`", ",", 
              RowBox[{"-", "0.09901475429766744`"}], ",", 
              RowBox[{"-", "0.09901475429766744`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.09950371902099892`", ",", "0.9950371902099892`", ",", "0.`"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09852336290568345`", ",", 
              RowBox[{"-", "0.009852336290568343`"}], ",", 
              "0.9950859653474028`"}], "}"}]}], "}"}]}], "}"}]}], "}"}], 
      "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`PointOfRays[{
           Optica`Optica`Ray[]}, {10, 10}, Optica`Optica`NumberOfRays -> 33, 
          Optica`Optica`BirthPoint -> {-100, 10, 10}, 
          Optica`Optica`SourceTransformation -> {{0., 0., 0.}, {{1., 0., 
            0.}, {0., 1., 0.}, {0., 0., 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-100, 10, 10}, {{
         0.9901475429766743, -0.09901475429766744, -0.09901475429766744}, {
         0.09950371902099892, 0.9950371902099892, 0.}, {
         0.09852336290568345, -0.009852336290568343, 0.9950859653474028}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-100, 10, 
         10}, {{5 
           Rational[2, 51]^Rational[1, 2], -102^Rational[-1, 2], -102^
            Rational[-1, 2]}, {
          101^Rational[-1, 2], 10 101^Rational[-1, 2], 0}, {
          5 Rational[2, 5151]^Rational[1, 2], -10302^Rational[-1, 2], 
           Rational[101, 102]^Rational[1, 2]}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 33, 
       Optica`Optica`BirthPoint :> {-100, 10, 10}, 
       Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 68033, 
       Optica`Optica`SourceFraction :> {1, 1}, 
       Optica`Optica`SourceOffset :> {0, 0}, 
       Optica`Optica`GridSpacing :> {#& , #& }, Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues :> {}], False, False, False, 
      False, {{-100, 10, 10}, {{
       0.9901475429766743, -0.09901475429766744, -0.09901475429766744}, {
       0.09950371902099892, 0.9950371902099892, 0.}, {
       0.09852336290568345, -0.009852336290568343, 0.9950859653474028}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277270517797`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277273122387`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277273139677`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727315527*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727474382*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277275327787`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727534542*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727727536199*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277275390377`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "2"}],
  SequenceForm["maximum used clone sort position = ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277283075523`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1017", ",", "72", ",", "0"}], "}"}]}],
  SequenceForm["Histogram of used sort positions: ", {1017, 72, 0}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277283093557`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({1017, 72, 0}\\)\\), \
\\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] All\\)\\)\\)\\)]\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727728351962*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "0.90229400000000004045119794682250358164`5.975947982721367", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "2087",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   0.90229400000000004045119794682250358164`5.975947982721367, 
   " seconds with ", 2087, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277284021883`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277284464817`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277284481373`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728449636*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277284513187`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"DrawSurfaceWithHole:1 called for rectangle and circle \
boundaries.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277284528217`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"RectCirc called.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728454321*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"DrawSurfaceWithHole:1 called for rectangle and circle \
boundaries.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.6147277284561234`*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"RectCirc called.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728459405*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"getSurfaceNetRectCirc called.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728461669*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728463194*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728464705*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727728519144*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727729068371*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.61472772935077*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"During evaluation of In[258]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJy03X+UXmV19/9JMgTCjJAMyVhLXfWrYBAQbEQoViRtoRTll9KFgvBEASsW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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoUUOwMRXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEADFd50Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZRA7AxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OADXLdSE=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAocUOoIuvXgUEr0QxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAKFh50Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAphqEDqCLr14FBFmY4qFg
gCkOphxwmKOFwxxRHOYwEC+Oyxxc9uJyJy5/4QoHXOEGEwcAd0x1IQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMIgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwDDMUY6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiBwAUw2iBxou8LEW+c1HFWcQ
PcBwwT3O8msdmnqYPAzA+CI41AvjMF/4AHb3CB0wBoPLxIkDzcGuHoc4kMau
Hoc4MBywqxfF4X7RAwCfSUY6
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZRA7AxLmnr1gg2it0
4GZvGe/cOcJw8Yw70rZFm6HqHRDiRpxGkys+CB2A0SjmA9XB9MHEYebC7EFR
D3QHzF0wcfWizk9JySLY1R8QwTD/3LezOe38ohjumaH85FCvjyiG+79mhMe/
KhI9cAPNvxB3iGKED0w9zF1YzT8gguGes1Aa3f0wfTBxDai5MHuwh48oRnhi
VQ/0J7r5sHA5h+YelPg9gJkeNND8i55+AFOKAJI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAo2Hiq1eBAKZ4KBgIY4hD
+CI4zMEUh5gjisMcMZLFYe5FF4e5F7s5IjjMwRSHuRe7OWIExVH9K4YjfNDN
wRRHDX90c4RwmEO6OHb/CuEIH5g5mOLYw18IR3wh0hsAhircjw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoQUOwMRXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEA5HB5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZBA7AxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OAA3zdOU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoYUOoIuvXgUErwQxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAAIB5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoXkPoIuHgsBVHgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwBOBXXK
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMAgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwCbWUX+
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiBwAUw2CBxou8LEW+c1HFWcQ
PMBwwT3O8msdmnoBqDwMwNQLYFfPwI/DfL4DWN3DwHvAGAwuEynOh0OcH4e4
AHbxBhziwHDArl4Qu/uB4gAGikP6
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZBA7AxLmnr1gg2it0
YKP0WykrS364eMYdaduizVD1DXxwcSNOo8kVH4QOpAqlqH18wHsAxXwH4QMX
dphXPUlDiN/sLeOdO0f4gJheoKO2FJp6BhGoexDi6kWdn5KSRbCrPyCCYf65
b2dz2vlFMdwzQ/nJoV4fUQz3f80Ij39VJIrhX4g6UYzwgamHuEsAu/kHBDDc
cxZMC2K4H6IPIa4B9S/EHkHs4dMgiBGeWNUDwx/dfFh8nUNzD0r8HsBMDxpo
/kVPPwD80/3V
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoXkOwMRXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJItDzOPFEIfYz4fDHAEc6jHFIeYL4jBHiKA4qn+F
cIQPujmY4qjhj26OEA5zSBfH7l8hHOEDMwdTHHv4Cx0IwxpfiPQGANBv3Ao=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoTkOwMRXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAlMB5HQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZOA7AxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OAL40dG0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoXkOoIuHgsBVbgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwBED3W7
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoVkPoIuHgsBVFgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwD+RnVS
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMHAcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwBLqUWG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0NwHGi7wsRb5zUcT5zrA
cME9zvJrHZo4J5SGAZg4Bw717DjMZzuA3T2sB4zB4DKR4mw4xNlxiHPgEOfE
Ic6FQ5wbh/u5DwAATPBBDA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZOA7AxLmnr1gg2it0
YKP0WykrS3a4eMYdaduizVD1DWxwcSNOo8kVH4QOpAqlqH18wHoAxXwH4QMX
dphXPUlDiN/sLeOdO0f4gJheoKO2FJp6BhGoexDi6kWdn5KSRbCrPyCCYf65
b2dz2vlFMdwzQ/nJoV4fUQz3f80Ij39VJIrhX4g6UYzwgan3eyL09OgxDhzm
c2K4Z/bb2Tf55Lkw3G/gfqJVeiZCXAPq31cX1+278pQLR/hwY4QnVvXA8Ec3
HxZf6O5BjV9OjPTgj+Zf9PQDANmJ/lg=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoVkOwMRXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJItDzGPFEIfYz4bDHA4c5nBiiIONWcWFwxweguKo
/uXBET7o5mCKo4Y/ujlCOMwhXXw1Vv8K4QgfmDno4SmEI/yFDoRhjS9EegMA
xnzbPw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoRkOwMRXrwKCV6IY4qEg
cBVTHMLDFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRu6OABFEHil
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6wAABB2Diq1cBQRameCgY
YIqDeQ44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnBDFwcAboRz9Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoVkOoIuHgsBVZgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwD0UHVD
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoX/tRxdfvQoEfmKIh4IB
pjiExhSHmPMDQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAMK4gpg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeYICAAw0X+FiL/OZDxBkQ
4gwX3OMsv9ZB1YsgxFGACA71wjjMR4ijukcILm4MBpfxiyOZg6oehziSO1HV
4xBHCgdU9QhxXOEJAPvqRQ4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0MwHGi7wsRb5zUcTZzrA
cME9zvJrHZo4I5SGAZg4Aw71//ZjN//Pfuzu+bXfGAwuEyn+B4f4PxziDAew
izPiEGfCIc58AFd4AgA0tkaC
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6wAABB2Di3NNXLBDtFTqQ
ZH7LtKTo336YeMYdaduizTD1f+HiRpxGkys+CB04pXLC59HB3/tRzHcQPrCg
MP/LibO/4OI3e8t4584RPqATs6gpzOQXqnoGEaj5CHH1os5PScki2NUfEMEw
/9y3sznt/KIY7pmh/ORQr48ohvu/ZoTHvyoSxfAvJHxg6hHhA1Pv90To6dFj
CHEU8xsYD6C7Z/bb2Tf55JkOoLvfwP1Eq/RMhLgG1L+vLq7bd+Upmnp4+DAf
QA9PrOqB4Y9uPiy+0N2DEr9I7oelB380/6KnHwAGzgz1
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoX/sh4mvXgUCmOKhYCCM
IQ7hi+AwB1McYo4oDnPESBYHW7PqF4Y4xJ6/OMxhOIBdPSOGOMR8JgxxCM1C
UBzVvwhx1PBBNwdTHDX80c0RwmEO6eKrsfpXCEf4wMxBD0+hA2FYwx9mPnp8
IdIbAL7r5yU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoT/sh4mvXgUEr0QxxENB
4CqmOJh7AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVu6OIAklCGpg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZPuyHia9eBQRZmOKh
YIApDuY64DBHC4c5ojjMYSBeHJc5uOzF5U5c/sIVDrjCDV0cALvEgfY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoX/sRxdfvQoEvmOIh4IB
pjiExhSHmPMNQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAK7Mgno=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoZ/sRxcPCwWBxxjiq8Dg
EYY4hMYUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRtMHADdkYFA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMH/Y3XOBjLfKbDxFn
QIgzXHCPs/xaB1UvghBHASI41AvjMB8hjuoeIbi4MRhcxi+OZA6qehziSO5E
VY9DHCkcUNUjxHGFJwBJOVMP
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0N/2N1zgYy3ym48m/mU/
wwX3OMuvdWjin/YzoACY+Acc6t/gMP/FfuzuebLfGAwuEyn+Aof4GxziH3CI
f8Ih/gWH+Dcc7v+2HwA5dk6A
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZPuyHiXNPX7FAtFfo
wNG8LdkvnryBi2fckbYt2gxT/woubsRpNLnig9CBKZ4TZh5pfr4fxXwH4QMO
j++9mDj7KVz8Zm8Z79w5wgcidriwrs14gqqeQQRqPkJcvajzU1KyCHb1B0Qw
zD/37WxOO7/ogclo7pmh/ORQr4/ogf9g8BIu/jUjPP5VkeiBI2j+hYSPKEb4
wNTPPaF6qrv3I4b5EPWfMdxjdtt8s6zdFwz3J/RN4DY3+goX14D698ri2NqV
p7/iCJ9vGOGJVT0w/NHNh8UXuntg8cuI5n5YepiP5l/09AMA7Ssbuw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoR/sh4mvXgUCmOKhYCCM
IQ7hi+AwB1McYo4oDnPESBaHmPcUQxxs/apXOMz5gEP9Jxzmf8Vhzg+C4qj+
/YEjfNDNwRRHDX90c4RwmEO6eBhW/wodWI01fGDmoIcnTD16+MPMR48vRHoD
ADJQ9Cs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDvAAAUw8dWrgOCVKIZ4KAhc
xRQHcw5gioPNWYXDnKk4zGkgXhyXObjsxeVOXP7CFQ64wg1dHADXWG1l
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6wAAFMPHVq4AgC1M8FAww
xcEcBxzmaOEwRxSHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwAA22i1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoR/sRxdfvQoE7mGIh4LB
XQxxCH0Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7jBxAGh0YDo

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoW/Yo4uHgsFNDPHVq0Dg
FoY4hL6Dw5y7GOJgY1bdw2HOA6LFV+MwB5e9uNyJy19hOMIBV7jBxAGspnlg

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeYICChgt8rEV+8yHiDAhx
hgvucZZf66DqRRDiKEAEh3phHOYjxFHdIwQXNwaDy/jFkcxBVY9DHMmdqOpx
iCOFA6p6hDiu8AQAjkE5zg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0Df2N1zgYy3ym48mfmE/
wwX3OMuvdWjiB/YzoACYOEgLVvX2OMy3x+Eee2MwuEyk+AUc4gdwiDMw4FC/
H4f5OMRv7McVngCf2kZ8
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6wAAFMHHu6SsWiPYKHbjR
GbNoz40d9jDxjDvStkWbhQ78B4PjcHEjTqPJFR+EDtzMuX+m7McFexTzHYQP
NFg66d05cQUufrO3jHfuHOED/v1lX5fqXUdVzyACdc8NuLh6UeenpGSRAwHY
1B8QwTD/3LezOe38ogduoblnhvKTQ70+ogdYwBpPwMW/ZoTHvyoSPfAAzb+Q
8BE9wNU1z8eysssGXf05iPr96Ob/gYTPfnT3XIe4Zz+6++sg7oeLa0D96wfx
734c4bMfPTwDsKkHhn8Tmvmw+LqF5h5Y/LJBwmc/enp4h+ZfWPqBhM+sPQDn
OSEK
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoR/Yw8RXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJIuHgc27ikP8KA5z0MNB7EAIRP1+7OJXMcSh7iEo
jubf/TjCZz+O8NyPI/z344iv/Tjil2jxMKz+hYmjhw/MHMx0FYI1/GHi6PGF
SG8A5p7gdQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoT/Yw8RXrwKCV6IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAnoV/Jg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZPtjDxFevAoIsTPFQ
MMAUB3MdcJijhcMcURzmMBAvjsscXPbicicuf+EKB1zhhi4OAMf5enY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoR/Yo4uvAgNM8bBQEHiI
IQ6hH+EwB1McbEzoYxzmPCFaPAyHObjsxeVOXP5ajSMccIUbTBwA6G55vA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAob/Zo4uHggGm+OpVIIAp
DqG/4zAHUxxszCpMcQj9g2jx1TjMwWUvLnfi8lcYjnDAFW4wcQC5rXr4
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMH+wbLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQYijABEc6oVxmI8QR3WPEFzcGAwu4xdHMgdVPQ5xJHei
qschjhQOqOoR4rjCEwBVbkuP
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0E/sGy7wsRb5zUcTf2HP
cME9zvJrHZr4GygfBmDiH3Co/4TD/C/22N3zzd4YDC4TKf4Fh/gnHOIfcIi/
wSH+Aof4Exzuf2IPAEWHRu4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZPtjDxLmnr1gg2it0
YN4J1VPdvR/h4hl3pG2LNsPUf4aLG3EaTa74IHTA7Lb5Zlm7L/Yo5jsIH0jo
m8BtbvQVLn6zt4x37hzhA1cWx9auPP0VVT2DCNT8b3Bx9aLOT0nJItjVHxDB
MP/ct7M57fyiGO6ZofzkUK+PKIb7v2aEx78qEsXwLyR8YOo/YKg/lrcl+8WT
NxjmM4LVv8JwzxTPCTOPND/HcL/j43svJs5+ChfXgPo3cocL69qMJzjC5wlG
eEZgUw8Mf3s082HxNRnNPbD4/fcfBF5ipIdDaP6FpR+w8v/v7QFTyRUz
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoX/Yw8RXrwIBTPFQMBDG
EIfwRXCYgykOMUcUhzliJIuHgc37iiEOsf8TDnM+4FD/Cof5T3GY84CgOKp/
H+AIH3RzMMVRwx/dHCEc5pAuHorVv0IHVmENH5g56OEJU48e/jDz0eMLkd4A
TRHmKw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoRkcYOKrVwHBK1EM8VAQ
uIopDuYdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAUUVxJQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6wAABDjDx1auAIAtTPBQM
MMUhPBzmaOEwRxSHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwB6uWx1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoX/Yo4uHggGm+OpVIIAp
DqF/4jAHUxxszCpMcQj9i2jx1TjMwWUvLnfi8lcYjnDAFW4wcQDNmXsW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoZkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINJg4AAJJtwg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeYIAAh4YLfKxFfvMh4gwI
cYYL7nGWX+ug6kUQ4ihABId6YRzmI8RR3SMEFzcGg8v4xZHMQVWPQxzJnajq
cYgjhQOqeoQ4rvAEAAguPY4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0L/sGy7wsRb5zUcT/2PP
cME9zvJrHZr4PygfBmDiDA7Y1TM6YDefyQG7e5gdjMHgMpHiTDjEGXGIM+AQ
/2ePXfwPDvFf9rjCEwBC2D/4
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6wAABDjBx7ukrFoj2Ch3w
fyL09OgxhHjGHWnbos1Q9Q2McHEjTqPJFR+EDsx+O/smnzyTA4r5DsIHDNxP
tErPRIjf7C3jnTtH+MCri+v2XXmKpp5BBOoeZri4elHnp6RkEezqD4hgmH/u
29mcdn5RDPfMUH5yqNdHFMP9XzPC418ViWL4F6JOFCN8YOqTzW+ZlhT9s8dq
PsNfe3T3nFI54fPo4G97dPcvKMz/cuLsL7i4BtS/OjGLmsJMftljDx+EOCw8
saoHhj+6+bD4QncPLH7/g8Efe/T0kIjmX/T0AwA7bwZv
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoVkcYOKrV4EApngoGAhj
iEP4IjjMwRSHmCOKwxwxksUh9jBhiEPsYcRhDgOGeBhY/V977Ob/whCH0D8I
iqP6FyGOGj7o5mCKo4Y/ujlCOMwhXXwVVv8KQcMTPXxg5qCHpxCO8IeZjx5f
iPQGAELF2SU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoTkcYOKrVwHBK1EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAoPVxnQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZOBxg4qtXAUEWpngo
GGCKg7kOOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wQxcHAMppbO0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoVkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINJg4ACoht0Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAobkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINJg4AUEJuOg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMHA4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdWLIMRRgAgO9cI4zEeIo7pHCC5uDAaX8YsjmYOqHoc4kjtR
1eMQRwoHVPUIcVzhCQBX3j4G
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0KwODRf4WIv85qOJszkw
XHCPs/xahybO7sCAAmDiHDjUc+Iwn8sBu3u4HYzB4DKR4lw4xDlxiHPgEGfH
Ic6GQ5wVh/tZHQBZGTmG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZOBxg4tzTVywQ7RU6
4P9E6OnRYwjxjDvStkWboeobOOHiRpxGkys+CB2Y/Xb2TT55LgcU8x2EDxi4
n2iVnokQv9lbxjt3jvCBVxfX7bvyFE09gwjUPdxwcfWizk9JySLY1R8QwTD/
3LezOe38ohjumaH85FCvjyiG+79mhMe/KhLF8C9EnShG+MDUb5J+K2VlyY7D
fDYM96QKpah9fMCK4f4LO8yrnqQhxDWg/hXTC3TUlmLFET6sGOGJVT0w/NHN
h8UXuntQ45cNIz1sRPMvevoBABB88do=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAoXkcYOKrV4EApngoGAhj
iEP4IjjMwRSHmCOKwxwxksUh9nBhiEPs4cRhDgcOc9gwxMPA5rDiMIeFoDiq
f1lwhA+6OZjiqOGPbo4QDnNIFw/F6l8hHOEDMwc9PIVwhL/QgVVY4wuR3gBL
nc0/
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoQUcYOKrVwHBK1EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgA8KVyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZBBxg4qtXAUEWpngo
GGCKg7kOOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wQxcHABoobWU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoXkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINJg4AWjhuSQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAphoEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYhocVzm4LIXlztx+QtXOOAKN5g4AA4zcpQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMAg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdWLIMRRgAgO9cI4zEeIo7pHCC5uDAaX8YsjmYOqHoc4kjtR
1eMQRwoHVPUIcVzhCQCnjj5+
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiByA0LwODRf4WIv85qOJ8zkw
XHCPs/xahybO78CAAmDiAtjVNwjgMF/QAat7GgQdjMHgMnHiDLjUC+BQj0uc
H4c4Hw5xXuzuB4oDABE3O/Y=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZBBxg4tzTVywQ7RU6
oF7U+SkpGSGecUfatmgzVP0BhLgRp9Hkig9CB859O5vTzi/ogGK+g/CBGcpP
DvX6IMRv9pbxzp0jfOBrRnj8qyI09QwiEPMbEOIQd4hgV39ABMN8iDtEMdwD
USeK4X6IuaIHNND8C3GHKEb4wNRvkn4rZWXJj938Bj4M96QKpah9fMCL4f4L
O8yrnqQhxDWg/hXTC3TUluLFHj4MvBjhiVU9MPzRzYfFF7p7UOIXyf2w9LAR
zb/o6QcAvxjxVw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoApR1g4qtXgQCmeCgYCGOI
Q/giOMzBFIeYI4rDHDGSxSHmCWKIQ+wXwGEOpjhEPR+GeBjYfF4c5vAQFEf1
Lw+O8EE3B1McNfzRzRHCYQ7p4qFY/SuEI3xg5qCHpxCO8BfCEV+I9AYAQeDO
Cg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDsAoUUcYOKrVwHBK1EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAGIxyUQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBA6AKYZRBxg4qtXAUEWpngo
GGCKg7kOOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wQxcHAEIAbaE=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAoYUc0MVDQUAUU3z1KiDQ
whQHUw44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnCDiQMAggFtIQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDkAphpEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYxocVzm4LIXlztx+QtXOOAKN5g4ADYLctA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINIgeANMMIg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdWLIMRRgAgO9cI4zEeIo7pHCC5uDAaX8YsjmYOqHoc4kjtR
1eMQRwoHVPUIcVzhCQDPZj66
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiBwAUw1CDg0X+FiL/OajijMI
OzBccI+z/FqHph4ojgJg6kVwqBfBYb6oA3b3iDoYg8Fl4sQZcKkXwaEehzjQ
X9jV4xAHhhuu8AQAq3g+tw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBA6AKYZRBxg4tzTVywQ7RU6
oF7U+SkpGSGecUfatmgzVP0BhLgRp9Hkig9CB859O5vTzi/qgGK+g/CBGcpP
DvX6IMRv9pbxzp0jfOBrRnj8qyI09QwiEPMbEOJQd2BXf0AEw3yoOzDcA1WH
4X6ouQc00PwLdQdG+MDUQ/2B3XwHYQz3GEPCCcP90HCFi0PdcQAaDzjCRwgj
PLGqB4Y/uvmw+DJCcw9K/CK5H5YebqD5Fz39AACCMvQF
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEDoAocUcYOKrV4EApngoGAhj
iEP4IjjMwRSHmCOKwxwxksWh5mGIQ+3HYQ6mONR/OMwRwmEOYXFU/wrhCB90
czDFUcMf3RwhHOaQLo7dv0I4wgdmDnp4CuEIfyEc8YVIbwDj3M6P
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoUUOwMRXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEA4pB5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoUUOwMRDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwARzHXK
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAocUOoIuvXgUEr0QxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgA/pF5lQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAphqEDqCLr14FBFmY4qFg
gCkOphxwmKOFwxxRHOYwEC+Oyxxc9uJyJy5/4QoHXOEGEwcATZR05Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMIgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeABhyQ/o=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCBwAUw2iBxou8LEW+c1HFWcQ
PcBwwT3O8msdmnoRqDwMwNSL4FAvjMN84QPY3SN0wBgMLhMnDjQHu3oc4kB3
YlePQxwYDtjVi+Jwv+gBAHWRRf4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoUUOwMTF9AIdtaV4D9zs
LeOdO0cYLn5hh3nVkzSoegeEeKpQitrHB7wHjDiNJld8EDqAYn4D34GMO9K2
RZsR4hul30pZWfIf4J6+YoFoL5p6BgGI+Q0IcfWizk9JyQLY1R8QwDD/3Lez
Oe38ghjumaH85FCvjyCG+79mhMe/KhI8cAPNvxB3CGKED0w9xF0i2M0/IILh
nrNgWhTD/RB9CHENqH8h9ojiCB+E+CZoeKKrZ4SGP7r5sPg6h+YelPg9gJke
NND8i55+AJqo/VU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoYUOwMRDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFIfZgikPsEcZhjggOczDFIeaI4jBHjKA4qn/F
cIQPujmY4qjhjxAPQ4kvdHN4SBbH7l8eHOEDMwdTHHv48+CIL0Q6BADjP9wK

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoQUOwMRXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAurh5WQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoQUOwMRDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwDp5XWO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoYUOoIuvXgUErwQxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgA1rl5WQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoXkPoIuHgsBVHgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwAkTXWO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMAgcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeAPCLQ74=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCBwAUw2CBxou8LEW+c1HFWcQ
PMBwwT3O8msdmnqYPAzA+ALY1TPw4zCf7wBW9zDwHjAGg8tEivPhEOfHIS6A
XbwBhzgwHLCrF8TufqA4ANzDQ74=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoQUOwMTF9AIdtaV4D2yU
fitlZckPF7+ww7zqSRpUfQMfXDxVKEXt4wPeAzAaxXygOpg+mDjMXJg9qO4R
OABzF0xcvajzU1KyAHb1BwQwzD/37WxOO78ghntmKD851OsjiOH+rxnh8a+K
BDH8C1EniBE+MPUwd2E1/4AAhnvOQml098P0wcQ1oObC7MEaPg0I8U1Qd6Or
Z4T6E918WLicQ3MPSvwewEwPGmj+RU8/AEQA+qc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAo2HioWDAiyG+ehUI8GGI
Q/gCONRjikPMF8RhjhDJ4jD3oovD3IvdHAEc6jHFYe7Fbo4QQXFU/wrhCB90
czDFUcMfIR6GEl/o5vCQLI7dvzw4wgdmDqY49vDnORCGNb4Q6RAALZPbhQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoTkOwMRXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAawh44Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoTkOwMRDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCaNXUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoXkOoIuHgsBVbgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwAaV3V/
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoVkPoIuHgsBVFgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDUjnUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMHAcaLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeAKDbQ0Y=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0NwHGi7wsRb5zUcT5zrA
cME9zvJrHZo4J5SGAZg4Bw717DjMZzuA3T2sB4zB4DKR4mw4xNlxiHPgEOfE
Ic6FQ5wbh/u5DwAAIzhA0A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoTkOwMTF9AIdtaV4D2yU
fitlZckOF7+ww7zqSRpUfQMbXDxVKEXt4wPeAxCa9QCK+Q18ByD6EOIQc/kP
QOxBU88gAHUPQly9qPNTUrIAdvUHBDDMP/ftbE47vyCGe2YoPznU6yOI4f6v
GeHxr4oEMfwLUSeIET4w9X5PhJ4ePcaBw3xODPfMfjv7Jp88F4b7DdxPtErP
RIhrQP376uK6fVeecuEIH264+CZoeKKrZ4SGP7r5sPhCdw9q/HJipAd/NP+i
px8AILb7Kg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoVkOwMRDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFIeaxYohD7GfDYQ4HDnM4McTBxqziwmEOD0Fx
VP/y4AgfdHMwxVHDHyEehhJf6ObwkCy+Gqt/eXCED8wc9PDkwRH+PAfCsMYX
Ih0CACOg2ro=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoRkOwMRXrwKCV4IY4qEg
cBVTHMLDFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRu6OAAbWHhp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoRkOwMRDQeAqD4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBKhXSe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoVkOoIuHgsBVZgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDKmHUH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoX/tRxdfvQoEfmKIh4IB
pjiExhSHmPMDQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAJkAglw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeYICAAw0X+FiL/OZDxBkQ
4gwX3OMsv9ZB1QsgxFGAAHb1DPw4zOeDi6O4h4EXLm4MBpcJiPPhEOfHIS6A
XbwBhzhSOKCqR4jjCk8AUStCzg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0MwHGi7wsRb5zUcTZzrA
cME9zvJrHZo4I5SGAZg4Aw71//ZjN//Pfuzu+bXfGAwuEyn+B4f4PxziDAew
izPiEGfCIc58AFd4AgAK/kZG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoRkOwMTF9AIdtaV4DySZ
3zItKfq3HyZ+YYd51ZM0mPq/cPFUoRS1jw94D5xSOeHz6ODv/SjmN/AdWFCY
/+XE2V9w8Y3Sb6WsLPkP6MQsagoz+YWqnkEAaj5CXL2o81NSsgB29QcEMMw/
9+1sTju/IIZ7Zig/OdTrI4jh/q8Z4fGvigQx/AtxP0w9Inxg6v2eCD09egwh
jmJ+A+MBdPfMfjv7Jp880wF09xu4n2iVnokQ14D699XFdfuuPEVTDw8fZrj4
Jmh4oqtnhIY/uvmw+EJ3D0r8Irkflh780fyLnn4ATewJxw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoX/sh4mHggEvhvjqVSDA
hyEO4QvgUI8pDjFfEIc5QiSLg61Z9QtDHGLPXxzmMBzArp4RQxxiPhOGOIRm
ISiO6l+EOGr4oJuDKY4a/gjxMJT4QjeHh2Tx1Vj9y4MjfGDmoIcnz4EwrOEP
Mx89vhDpEAAcD+ag
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoT/sh4mvXgUErwQxxENB
4CqmOJh7AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVu6OIAaJiGag==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoT/sh4mHgsBVHgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgCXxYKf
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoX/sRxdfvQoEvmOIh4IB
pjiExhSHmPMNQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAIUUgj4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoZ/sRxcPCwWBxxjiq8Dg
EYY4hMYUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRtMHACz2YEE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMH/Y3XOBjLfKbDxFn
QIgzXHCPs/xaB1UvgBBHAQLY1TPw4zCfDy6O4h4GXri4MRhcJiDOh0OcH4e4
AHbxBhziSOGAqh4hjis8AZ5rUM8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0N/2N1zgYy3ym48m/mU/
wwX3OMuvdWjin/YzoACY+Acc6t/gMP/FfuzuebLfGAwuEyn+Aof4GxziH3CI
f8Ih/gWH+Dcc7v+2HwAPvk5E
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoT/sh4mL6QU6akvxHjia
tyX7xZM3cPELO8yrnqTB1L+Ci6cKpah9fMB7YIrnhJlHmp/vRzG/ge+Aw+N7
LybOfgoX3yj9VsrKkv9AxA4X1rUZT1DVMwhAzUeIqxd1fkpKFsCu/oAAhvnn
vp3NaecXPDAZzT0zlJ8c6vURPPAfDF7Cxb9mhMe/KhI8cATNvxD3C2KED0z9
3BOqp7p7P2KYD1H/GcM9ZrfNN8vafcFwf0LfBG5zo69wcQ2of68sjq1defor
jvD5BhffBA1PdPWM0PBHNx8WX+jugcUvI5r7YelhPpp/0dMPADRYGI0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoR/sh4mHggEvhvjqVSDA
hyEO4QvgUI8pDjFfEIc5QiSLQ8x7iiEOtn7VKxzmfMCh/hMO87/iMOcHQXFU
//7AET7o5mCKo4Y/QjwMJb7QzeEhWTwMq395DqzGGj4wc9DDE6YePfxh5qPH
FyIdAgCPZfOm
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDrAAAUw8dWrgOCVIIZ4KAhc
xRQHcw5gioPNWYXDnKk4zGkgXhyXObjsxeVOXP7CFQ64wg1dHACtoG0p
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D3AAAUw8VAQuMqDIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUB3M1pXg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoR/sRxdfvQoE7mGIh4LB
XQxxCH0Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7jBxAF4GYCs

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoW/Yo4uHgsFNDPHVq0Dg
FoY4hL6Dw5y7GOJgY1bdw2HOA6LFV+MwB5e9uNyJy19hOMIBV7jBxAGC7nkk

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeYICChgt8rEV+8yHiDAhx
hgvucZZf66DqBRDiKEAAu3oGfhzm88HFUdzDwAsXNwaDywTE+XCI8+MQF8Au
3oBDHCkcUNUjxHGFJwDjczeO
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0Df2N1zgYy3ym48mfmE/
wwX3OMuvdWjiB/YzoACYOEgLVvX2OMy3x+Eee2MwuEyk+AUc4gdwiDMw4FC/
H4f5OMRv7McVngB2IkZA
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D3AAAUwcTG9QEdtKd4DNzpj
Fu25scMeJn5hh3nVkzTeA//B4DhcPFUoRe3jA94DN3Punyn7ccEexfwGvgMN
lk56d05cgYtvlH4rZWXJf8C/v+zrUr3rqOoZBKDuuQEXVy/q/JSULHAgAJv6
AwIY5p/7djannV/wwC0098xQfnKo10fwAAtY4wm4+NeM8PhXRYIHHqD5F+J+
wQNcXfN8LCu7bNDVn4Oo349u/h9I+OxHd891iHv2o7u/DuJ+uLgG1L9+EP/u
xxE+cPFN0PAMQFPPCA3/JjTzYfF1C809sPhlg4TPfvT08A7Nv7D0AwmfWXsA
LmYd3A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoR/Yw8RDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFw8DmXcUhfhSHOejhIHQgBKJ+P3bxqxjiUPcQ
FEfz734c4bMfR3juxxH+cPEw1PjajyN+iRYPw+pfmDh6+MDMwUxXIVjDHyaO
Hl+IdAgAQ8Lf8A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoT/Yw8RXrwKCV4IY4qEg
cBVTHMw9gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3dHEAdM1+6g==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoT/Yw8RDQeAqD4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCj+nsf
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoR/Yo4uvAgNM8bBQEHiI
IQ6hH+EwB1McbEzoYxzmPCFaPAyHObjsxeVOXP5ajSMccIUbTBwAvrZ5gA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAob/Zo4uHggGm+OpVIIAp
DqG/4zAHUxxszCpMcQj9g2jx1TjMwWUvLnfi8lcYjnDAFW4wcQCP9Xq8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMH+wbLvCxFvnNh4gz
IMQZLrjHWX6tg6oXQIijAAHs6hn4cZjPBxdHcQ8DL1zcGAwuExDnwyHOj0Nc
ALt4Aw5xpHBAVY8QxxWeAKqgSU8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0E/sGy7wsRb5zUcTf2HP
cME9zvJrHZr4GygfBmDiH3Co/4TD/C/22N3zzd4YDC4TKf4Fh/gnHOIfcIi/
wSH+Aof4Exzuf2IPABvPRrI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoT/Yw8TF9AIdtaV4D8w7
oXqqu/cjXPzCDvOqJ2kw9Z/h4qlCKWofH/AeMLttvlnW7os9ivkNfAcS+iZw
mxt9hYtvlH4rZWXJf+DK4tjalae/oqpnEICa/w0url7U+SkpWQC7+gMCGOaf
+3Y2p51fEMM9M5SfHOr1EcRw/9eM8PhXRYIY/oW4H6b+A4b6Y3lbsl88eYNh
PiNY/SsM90zxnDDzSPNzDPc7Pr73YuLsp3BxDah/I3e4sK7NeIIjfBDim6Dh
GYGmnhEa/vZo5sPiazKae2Dx++8/CLzESA+H0PwLSz9g5f/f2wMAmucSBQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoX/Yw8RDwYAXQ3z1KhDg
wxCH8AVwqMcUh5gviMMcIZLFw8DmfcUQh9j/CYc5H3Cof4XD/Kc4zHlAUBzV
vw9whA+6OZjiqOGPEA9DiS90c3hIFg/F6l+eA6uwhg/MHPTwhKlHD3+Y+ejx
hUiHAKom5aY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoRkcYOKrVwHBK0EM8VAQ
uIopDuYdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAJ41w6Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoRkcYOKhIHCVB0N89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBWum0e
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoX/Yo4uHggGm+OpVIIAp
DqF/4jAHUxxszCpMcQj9i2jx1TjMwWUvLnfi8lcYjnDAFW4wcQCj4Xra
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoZkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINJg4A1stthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeYIAAh4YLfKxFfvMh4gwI
cYYL7nGWX+ug6gUQ4ihAALt6Bn4c5vPBxVHcw8ALFzcGg8sExPlwiPPjEBfA
Lt6AQxwpHFDVI8RxhScAXWA7Tg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0L/sGy7wsRb5zUcT/2PP
cME9zvJrHZr4PygfBmDiDA7Y1TM6YDefyQG7e5gdjMHgMpHiTDjEGXGIM+AQ
/2ePXfwPDvFf9rjCEwAZID+8
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoRkcYOJieoGO2lK8B/yf
CD09egwhfmGHedWTNKj6Bka4eKpQitrHB7wHZr+dfZNPnskBxfwGvgMG7ida
pWcixDdKv5WysuQ/8Oriun1XnqKpZxCAuocZLq5e1PkpKVkAu/oDAhjmn/t2
NqedXxDDPTOUnxzq9RHEcP/XjPD4V0WCGP6FqBPECB+Y+mTzW6YlRf/ssZrP
8Nce3T2nVE74PDr42x7d/QsK87+cOPsLLq4B9a9OzKKmMJNf9tjDByG+CRqe
6OoZoeGPbj4svtDdA4vf/2Dwxx49PSSi+Rc9/QAAgo0DQQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoVkcYOKhYMCLIb56FQjw
YYhD+AI41GOKQ8wXxGGOEMniEHuYMMQh9jDiMIcBQzwMrP6vPXbzf2GIQ+gf
BMVR/YsQRw0fdHMwxVHDHyEehhJf6ObwkCy+Cqt/eaDhiR4+MHPQw5MHR/jD
zEePL0Q6BACf2tig
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoTkcYOKrVwHBK0EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAdz1xYQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoTkcYOKhIHCVB0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCmam2W
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoVkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINJg4A4MFtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAobkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINJg4AJopt/g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMHA4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdULIMRRgAB29Qz8OMzng4ujuIeBFy5uDAaXCYjz4RDnxyEu
gF28AYc4UjigqkeI4wpPAK0QO8Y=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0KwODRf4WIv85qOJszkw
XHCPs/xahybO7sCAAmDiHDjUc+Iwn8sBu3u4HYzB4DKR4lw4xDlxiHPgEGfH
Ic6GQ5wVh/tZHQAvYTlK
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoTkcYOJieoGO2lK8B/yf
CD09egwhfmGHedWTNKj6Bk64eKpQitrHB7wHZr+dfZNPnssBxfwGvgMG7ida
pWcixDdKv5WysuQ/8Oriun1XnqKpZxCAuocbLq5e1PkpKVkAu/oDAhjmn/t2
NqedXxDDPTOUnxzq9RHEcP/XjPD4V0WCGP6FqBPECB+Y+k1gf7DjMJ8Nwz2Q
cGLFcD8kXBHiGlD/QuKBFUf4IMQ3QcMTXT0jNPzRzYfFF7p7UOOXDSM9bETz
L3r6AQBXmu6s
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkApR1g4qFgwIshvnoVCPBh
iEP4AjjUY4pDzBfEYY4QyeIQe7gwxCH2cOIwhwOHOWwY4mFgc1hxmMNCUBzV
vyw4wgfdHExx1PBHiIehxBe6OTwki4di9S8PjvCBmYMenjw4wp/nwCqs8YVI
hwCossy6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoQUcYOKrVwHBK0EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgAxu1x2Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoQUcYOKhIHCVB0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwD2Gm4O
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoXkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINJg4AMIBuDQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAphoEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYhocVzm4LIXlztx+QtXOOAKN5g4AORsclg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMAg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdULIMRRgAB29Qz8OMzng4ujuIeBFy5uDAaXCYjz4RDnxyEu
gF28AYc4UjigqkeI4wpPAPzAPD4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCByA0LwODRf4WIv85qOJ8zkw
XHCPs/xahybO78CAAmDiAtjVNwjgMF/QAat7GgQdjMHgMnHiDLjUC+BQj0uc
H4c4Hw5xXuzuB4oDAOdwO7o=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoQUcYOJieoGO2lK8B9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB74Fz387mtPMLOqCY38B3YIbyk0O9
PgjxjdJvpaws+Q98zQiPf1WEpp5BAGJ+A0Ic6g7s6g8IYJgPdQeGe6DqMNwP
NfeABpp/oe7ACB+Y+k0Qf2A3v4EPwz3QcMJwPzRc4eJQdxyAxgP28GFAiEPd
gaGeERr+6ObD4gvdPSjxi+R+WHrYiOZf9PQDAAZF7ik=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAoYUcYOKhYMCLIb56FQjw
YYhD+AI41GOKQ8wXxGGOEMniUPMwxKH24zAHUxzqPwzxMEh44DCHh6A4qn95
cIQPujmY4qjhjxAPQ4kvdHN4SBYPxepfHhzhAzMHPTx5cIQ/D474QqRDAJ71
zYU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDoAoUUcYOKrVwHBK0EM8VAQ
uIopDuYewBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbujgA7sVyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4D0AoUUcYOKhIHCVB0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwAeAW5K
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAoYUc0MVDQUAUU3z1KiDQ
whQHUw44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnCDiQMAWEls5Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEDgAphpEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYxocVzm4LIXlztx+QtXOOAKN5g4AAxTcpQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAgeANMMIg4NF/hYi/zmQ8QZ
EOIMF9zjLL/WQdULIMRRgAB29Qz8OMzng4ujuIeBFy5uDAaXCYjz4RDnxyEu
gF28AYc4UjigqkeI4wpPACSnPHo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCBwAUw1CDg0X+FiL/OajijMI
OzBccI+z/FqHph4ojgJg6kVwqBfBYb6oA3b3iDoYg8Fl4sQZcKkXwaEehzjQ
X9jV4xAHhhuu8AQAgcA+ew==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4D0AoUUcYOJieoGO2lK8B9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB74Fz387mtPOLOqCY38B3YIbyk0O9
PgjxjdJvpaws+Q98zQiPf1WEpp5BAGJ+A0Ic4g4B7OoPCGCYD3GHIIZ7IOoE
MdwPMVfwgAaafyHuEMQIH5j6m71lvHPnCGM330EYwz3GnEaTKz4IYbg/4460
bdFmhLgG1L/c01csEO0VwhE+CPFN0PBEV88IDX9082HxZYTmHpT4RXI/LD3c
QPMvevoBAMlQ8Nc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4DkAocUcYOKhYMCLIb56FQjw
YYhD+AI41GOKQ8wXxGGOEMniEPNEMcQh9ovgMAdTHGKOMA5zhHCYQ1gc1b9C
OMIH3RxMcdTwR4iHocQXujk8JItj9y8PjvCBmYMenjw4wp8HR3wh0iEAQQDO
Cg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoUUOwMRDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwAHXnW7
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoUUOwMRDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwC+TXVS
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAocUOoIuvXgUEr0QxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAqyF5HQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAphqEDqCLr14FBFmY4qFg
gCkOphxwmKOFwxxRHOYwEC+Oyxxc9uJyJy5/4QoHXOEGEwcA+hV0bQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0CIHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwBHaEEM
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcBwAUw2iBxou8LEW+c1HFWcQ
PcBwwT3O8msdmnoRqDwMwNSL4FAvjMN84QPY3SN0wBgMLhMnDjQHu3oc4kB3
YlePQxwYDtjVi+Jwv+gBACIhRYY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoUUOwMTF9AIdtaVYD9zs
LeOdO0cYLn5hh3nVkzSoegeEeKpQitrHB6wHjDiNJld8EDqAYn4D24GMO9K2
RZsR4hul30pZWbIf4J6+YoFoL5p6Bg6I+Q0Icf8nQk+PHuPArr6BE8P82W9n
3+ST58Jwj4H7iVbpmVwY7n91cd2+K0+5DtxA8y/EPdwY4QNTr17U+SkpWQS7
+QcQ4nOg7jn77WxOO78ohvtnKD851OsjiuHfrxnh8a+KRHGED0J8EzQ80dUz
QsMf3XxYfJ1Dcw9K/B7ATA8aaP5FTz8ANs392Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoYUOwMRDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBaHuAtTHGK/MA5zRHCYgykOMUcUhzliBMVX
o/hXDEf4oJvDgcMcNgzxMJT4QjeHhWRx7P5lwRE+MHMwxbGHPwuO+EKkQwDg
vNs/
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoQUOwMRDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwDfd3V/
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoQUOwMRDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCWdXUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoYUOoIuvXgUErwQxxENB
4CqmOJg6gCkONmcVDnOm4jCngXhxXObgsheXO3H5C1c44Ao3mDgAg0l44Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoXkPoIuHgsBVHgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDQznUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AIHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwAfkEDQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcBwAUw2CBxou8LEW+c1HFWcQ
PMBwwT3O8msdmnoBqDwMwNQLYFfPwI/DfL4DWN3DwHvAGAwuEynOh0OcH4e4
AHbxBhziwHDArl4Qu/uB4gCJU0NG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoQUOwMTF9AIdtaVYD2yU
fitlZckPF7+ww7zqSRpUfQMfXDxVKEXt4wPWAxCa9wCK+Q1sByD6EOIQc9kP
QOxBU8/AAXUPQtz/idDTo8c4sKtv4MQwf/bb2Tf55Lkw3GPgfqJVeiYXhvtf
XVy378pTLgz/QtzBjRE+MPXqRZ2fkpIFsJt/ACE+B+qes9/O5rTzC2K4f4by
k0O9PoIY/v2aER7/qkgQe/g0IMQ3QcMTXT0jNPzRzYfF1zk096DE7wHM9KCB
5l/09AMA4Bb7Kw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoXkOwMRDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBaH2MOLIQ5xLx8OcwRwqMcUh5gviMMcIYLi
q1H8K4QjfNDN4cBhDhuGeBhKfKGbw0KyOHb/suAIH5g5mOLYw5/lQBjW+EKk
QwArENq6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoTkOwMRDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCPx3UH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoTkOwMRDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBGxXSe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoXkOoIuHgsBVbgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwDG2HUH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoVkPoIuHgsBVFgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwCBHnSe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0BwHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwDP0UBY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0NwHGi7wsRb5zUcT5zrA
cME9zvJrHZo4J5SGAZg4Bw717DjMZzuA3T2sB4zB4DKR4mw4xNlxiHPgEOfE
Ic6FQ5wbh/u5DwAAz7lAWA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoTkOwMTF9AIdtaVYD2yU
fitlZckOF7+ww7zqSRpUfQMbXDxVKEXt4wPWAzAaxXygOpg+mDjMXJg9qO7h
OABzF0zc/4nQ06PHOLCrb+DEMH/229k3+eS5MNxj4H6iVXomF4b7X11ct+/K
Uy4M/0LcwY0RPjD1flB3YTefEy4+B+oemLvQ3Q/Th+5fmD3Yw4cbLr4J6m50
9YxQf6KbDwsXdPegxi8nRnrwR/MvevoBALzM+64=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAo2HioWDAiiG+ehUIsGGI
Q/gcOMzhxBAHG7OKC4c5PCSLw9yLLg5zL3ZzOHCYw4khDnMvdnN4CIqvRvEv
D47wQTeHA4c5bBjiYSjxhW4OC8niq7H6lwVH+MDMQQ9PFhzhz3IgDGt8IdIh
ACEd2e8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoRkOwMRDQeAqN4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBAF3SP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoRkOwMRDQeAqC4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwD3BnQm
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoVkOoIuHgsBVZgzx1atA
AFMcTDVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucIOJAwB3KHSP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoX/tRxdfvQoEfmKIh4IB
pjiExhSHmPMDQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcAEWQgeQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AwHGi7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwCAIT/g
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0MwHGi7wsRb5zUcTZzrA
cME9zvJrHZo4I5SGAZg4Aw71//ZjN//Pfuzu+bXfGAwuEyn+B4f4PxziDAew
izPiEGfCIc58AFd4AgC3f0XO
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoRkOwMTF9AIdtaVYDySZ
3zItKfq3HyZ+YYd51ZM0mPq/cPFUoRS1jw9YD5xSOeHz6ODv/SjmN7AdWFCY
/+XE2V9w8Y3Sb6WsLNkP6MQsagoz+YWqnoEDaj5C3P+J0NOjxziwq2/gxDB/
9tvZN/nkuTDcY+B+olV6JheG+19dXLfvylMuDP9C1HFjhA9MvR/YXQhxFPMb
GOHic6DugbiL6QC6+yH6EOIw/0LsQVMPDx9muPgmaHiiq2eEhj+6+bD4QncP
SvwiuR+WHvzR/IuefgDqAgpL
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoX/sh4mHggErhvjqVSDA
hiEO4XPgMIcTQxxszCouHObwkCwOMe8XhjjE/r84zGE4gF09I4Y4xHwmDHFY
+BESX43iX4Q4avigm8OBwxw2DPEwlPhCN4eFZPHVWP3LgiN8YOaghyfLgTCs
4Q8zHz2+EOkQABmM5dU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoT/sh4mHgsBVbgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgCNV4KQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoT/sh4mHgsBVFgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgBEVYIn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoX/sRxdfvQoEvmOIh4IB
pjiExhSHmPMNQzwMbA6mOIQmXjwUhzm47MXlTlz+WoUjHHCFG0wcADGkgcY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoZ/sRxcPCwWBxxjiq8Dg
EYY4hMYUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRtMHABgaYCM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0B/2N1zgYy3ymw8V54KL
M1xwj7P8WgcV50SIowAOHOrZcZjPBhdHdQ8rXNwYDC4TEGfDIc6OQ5wDhzgn
DnEuHOKIcMMVngDNYU3h
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0N/2N1zgYy3ym48m/mU/
wwX3OMuvdWjin/YzoACY+Acc6t/gMP/FfuzuebLfGAwuEyn+Aof4GxziH3CI
f8Ih/gWH+Dcc7v+2HwC8P03M
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoT/sh4mL6QU6akuxHjia
tyX7xZM3cPELO8yrnqTB1L+Ci6cKpah9fMB6YIrnhJlHmp/vRzG/ge2Aw+N7
LybOfgoX3yj9VsrKkv1AxA4X1rUZT1DVM3BAzUeI+z8Renr0GAd29Q2cGObP
fjv7Jp8814HJaO4xcD/RKj2T68B/MHgJF391cd2+K0+5DhxB8y/EHdwY4QNT
P/eE6qnu3o8Y5kPUf4aLz4G6x+y2+WZZuy8Y7k/om8BtbvQVw79XFsfWrjz9
FUf4fIOLb4KGJ7p6Rmj4o5sPiy9098DilxHN/bD0MB/Nv+jpBwDQbhkR
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoR/sh4mHggErhvjqVSDA
hiEO4XPgMIcTQxxszCouHObwkCwOsecphjjEnlc4zPmAQ/0nHOZ/xWHOD4Li
q1H8+wNH+KCbw4HDHDYM8TCU+EI3h4Vk8TCs/mU5sBpr+MDMQQ9PmHr08IeZ
jx5fiHQIAIzi8ts=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DnAAAUw8VAQuMqNIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUB0l9pTw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD3AAAUw8VAQuMqCIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUBiV1o5g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoR/sRxdfvQoE7mGIh4LB
XQxxCH0Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7jBxAEkqYA0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoW/Yo4uHgsFNDPHVq0Dg
FoY4hL6Dw5y7GOJgY1bdw2HOA6LFV+MwB5e9uNyJy19hOMIBV7jBxAEvfnis

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB9ggIKGC3ysRX7zoeJccHGG
C+5xll/roOKcCHEUwIFDPTsO89ng4qjuYYWLG4PBZQLibDjE2XGIc+AQ58Qh
zoVDHBFuuMITABJ4NKA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0Df2N1zgYy3ym48mfmE/
wwX3OMuvdWjiB/YzoACYOEgLVvX2OMy3x+Eee2MwuEyk+AUc4gdwiDMw4FC/
H4f5OMRv7McVngAiskXI
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD3AAAUwcTG9QEdtKdYDNzpj
Fu25scMeJn5hh3nVkzTWA//B4DhcPFUoRe3jA9YDN3Punyn7ccEexfwGtgMN
lk56d05cgYtvlH4rZWXJfsC/v+zrUr3rqOoZOKDuuQEX938i9PToMY4DAdjU
N3BimD/77eybfPJcB26hucfA/USr9EyuAyxgjSfg4q8urtt35SnXgQdo/oW4
g/sAV9c8H8vKLht09ecg6vejm/8HEj5w8TlQ91yHuGc/uvvrIO7fj+5fP4h/
9+MIH7j4Jmh4BqCpZ4SGfxOa+bD4uoXmHlj8skHCZz96eniH5l9Y+oGEz6w9
AMp8HmA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoR/Yw8RDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBYPA9tzFYf4URzmoIcDz4EQiPr92MWvYohD
3UNQfDWqf/fjCJ/9OMJzP47wh4uHocbXfhzxS7R4GFb/wsTRwwdmDma6CsEa
/jBx9PhCpEMAQT/fJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoT/Yw8RDQeAqN4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCZjHsQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoT/Yw8RDQeAqC4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBQinqn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoR/Yo4uvAgNM8bBQEHiI
IQ6hH+EwB1McbEzoYxzmPCFaPAyHObjsxeVOXP5ajSMccIUbTBwAa0Z5CA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAob/Zo4uHggGm+OpVIIAp
DqG/4zAHUxxszCpMcQj9g2jx1TjMwWUvLnfi8lcYjnDAFW4wcQA8hXpE
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0B/sGy7wsRb5zYeKc8HF
GS64x1l+rYOKcyLEUQAHDvXsOMxng4ujuocVLm4MBpcJiLPhEGfHIc6BQ5wT
hzgXDnFEuOEKTwDZlkZh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0E/sGy7wsRb5zUcTf2HP
cME9zvJrHZr4GygfBmDiH3Co/4TD/C/22N3zzd4YDC4TKf4Fh/gnHOIfcIi/
wSH+Aof4Exzuf2IPAMhQRjo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoT/Yw8TF9AIdtaVYD8w7
oXqqu/cjXPzCDvOqJ2kw9Z/h4qlCKWofH7AeMLttvlnW7os9ivkNbAcS+iZw
mxt9hYtvlH4rZWXJfuDK4tjalae/oqpn4ICa/w0u7v9E6OnRYxzY1TdwYpg/
++3sm3zyXBjuMXA/0So9kwvD/a8urtt35SkXhn8h6rgxwgem/ljeluwXT95g
mM8IVv8KLj4H6p4pnhNmHml+juF+x8f3Xkyc/RTDv5E7XFjXZjzBET4I8U3Q
8IxAU88IDX97NPNh8TUZzT2w+P33HwReYqSHQ2j+haUfsPL/7+0BNwwSiQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoX/Yw8RDwYAVQ3z1KhBg
wxCH8DlwmMOJIQ42ZhUXDnN4SBYPA9vzFUMc4t5POMz5gEP9KxzmP8VhzgOC
4qtR/PsAR/igm8OBwxw2DPEwlPhCN4eFZPFQrP5lObAKa/jAzEEPT5h69PCH
mY8eX4h0CACno+Tb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoRkcYOKhIHCVG0N89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBMTG0P
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoRkcYOKhIHCVBUN89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwADSmym
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoX/Yo4uHggGm+OpVIIAp
DqF/4jAHUxxszCpMcQj9i2jx1TjMwWUvLnfi8lcYjnDAFW4wcQBQcXpi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoZkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINJg4Ag1ttDg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AwODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwCMVjhg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0L/sGy7wsRb5zUcT/2PP
cME9zvJrHZr4PygfBmDiDA7Y1TM6YDefyQG7e5gdjMHgMpHiTDjEGXGIM+AQ
/2ePXfwPDvFf9rjCEwDFoT9E
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoRkcYOJieoGO2lKsB/yf
CD09egwhfmGHedWTNKj6Bka4eKpQitrHB6wHZr+dfZNPnskBxfwGtgMG7ida
pWcixDdKv5WysmQ/8Oriun1XnqKpZ+CAuocZLg5xBwd29Q2cGOZD3MGF4R6I
Oi4M90PM5cLwL8Qd3BjhA1OfbH7LtKTonz1W8xn+wsXnQN1zSuWEz6ODv+3R
3b+gMP/LibO/7NH9qxOzqCnM5Jc99vBBiG+Chie6ekZo+KObD4svdPfA4vc/
GPyxR08PiWj+RU8/AB6yA8U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkApR1g4qFgwIohvnoVCLBh
iEP4HDjM4cQQBxuziguHOTwki0PcxYQhDrGfEYc5DBjiYWD1f+2xm/8LQxxC
/yAovhrFvwhx1PBBN4cDhzlsGOJhKPGFbg4LyeKrsPqXBRqe6OEDMwc9PFlw
hD/MfPT4QqRDAJ1X19U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoTkcYOKhIHCVG0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCb/G2H
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoTkcYOKhIHCVBUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBS+m0e
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoVkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINJg4AjVFtHQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAobkd0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINJg4A0wtthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0BwODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwDcBjjY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0KwODRf4WIv85qOJszkw
XHCPs/xahybO7sCAAmDiHDjUc+Iwn8sBu3u4HYzB4DKR4lw4xDlxiHPgEGfH
Ic6GQ5wVh/tZHQDb4jjS
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoTkcYOJieoGO2lKsB/yf
CD09egwhfmGHedWTNKj6Bk64eKpQitrHB6wHZr+dfZNPnssBxfwGtgMG7ida
pWcixDdKv5WysmQ/8Oriun1XnqKpZ+CAuocbLg51B3b1DZwY5kPdgeEeqDoM
90PNxfAv1B0Y4QNTvwniDxzms8HF50DdAw0nDPdDwxXDv9B4wBE+CHGoOzDU
M0LDH918WHyhuwc1ftkw0sNGNP+ipx8A87DvMA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoXkcYOKhYMCKIb56FQiw
YYhD+Bw4zOHEEAcbs4oLhzk8JItD3MWFIQ61H4c5HDjMYcMQD4OEBw5zWAiK
r0bxLwuO8EE3hwOHOWwY4mEo8YVuDgvJ4qFY/cuCI3xg5qCHJwuO8Gc5sApr
fCHSIQCmL8vv
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoQUcYOKhIHCVG0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwDrrG3/
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoQUcYOKhIHCVBUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCiqm2W
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoXkc0MVXrwICLUzxUDDA
FAdTDTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINJg4A3QFtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAphoEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYhocVzm4LIXlztx+QtXOOAKN5g4AJD8ceA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0AIODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwArxTlQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcByA0LwODRf4WIv85qOJ8zkw
XHCPs/xahybO78CAAmDiAtjVNwjgMF/QAat7GgQdjMHgMnHiDLjUC+BQj0uc
H4c4Hw5xXuzuB4oDAJQAO0I=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoQUcYOJieoGO2lKsB9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB64Fz387mtPMLOqCY38B2YIbyk0O9
PgjxjdJvpaws2Q98zQiPf1WEpp6BA2J+A0Lc/4nQ06PHOLCrb+DEMH/229k3
+eS5MNxj4H6iVXomF4b7X11ct+/KU64DGmj+hbiHGyN8YOo3gf3Bj938Bj64
+ByoeyDhxIvhfki48mL4FxIPvNjDhwEhvgkanujqGaHhj24+LL7Q3YMSv0ju
h6WHjWj+RU8/AKJb7q0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAoYUcYOKhYMCKIb56FQiw
YYhD+Bw4zOHEEAcbs4oLhzk8JItD7BHEEIe4VwCHOZjiEPV8GOJhYPN5cZjD
Q1B8NYp/eXCED7o5HDjMYcMQD0OJL3RzWEgWD8XqXxYc4QMzBz08WXCEPwuO
+EKkQwCccsy6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DkAoUUcYOKhIHCVG0N89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwATk247
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYD0AoUUcYOKhIHCVBUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwDKgm3S
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAoYUc0MVDQUAUU3z1KiDQ
whQHUw44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnCDiQMABNlsbQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4DgAphpEHdDFQ0FgKqb46lUg
gCkOpg7gMOcqDnNe4TCHQYxocVzm4LIXlztx+QtXOOAKN5g4ALjUchw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcB+A0CIODRf4WIv85kPFueDi
DBfc4yy/1kHFORHiKIADh3p2HOazwcVR3cMKFzcGg8sExNlwiLPjEOfAIc6J
Q5wLhzgi3HCFJwBTnTmM
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcBwAUw1CDg0X+FiL/OajijMI
OzBccI+z/FqHph4ojgJg6kVwqBfBYb6oA3b3iDoYg8Fl4sQZcKkXwaEehzjQ
X9jV4xAHhhuu8AQALlA+Aw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYD0AoUUcYOJieoGO2lKsB9SL
Oj8lJSPEL+wwr3qSBlV/ACGeKpSi9vEB64Fz387mtPOLOqCY38B2YIbyk0O9
PgjxjdJvpaws2Q98zQiPf1WEpp6BA2J+A0Lc/4nQ06PHOLCrb+DEMH/229k3
+eS5MNxj4H6iVXomF4b7X11ct+/KU64DGmj+hbiHGyN8YOpv9pbxzp0jjN18
B4T4HKh7jDmNJld8EMJwf8YdaduizUIY/uWevmKBaK8QjvBBiG+Chie6ekZo
+KObD4svIzT3oMQvkvth6eEGmn/R0w8AZXXxWw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYDkAocUcYOKhYMCKIb56FQiw
YYhD+Bw4zOHEEAcbs4oLhzk8JItD7BHFEIe4VwSHOZjiEHOEcZgjhMMcwuKr
UfwrhCN80M3hwGEOG4Z4GEp8oZvDQrI4dv+y4AgfmDno4cmCI/xZcMQXIh0C
AD59zT8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoUUOwMRDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCz33VD
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQoscgImvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAOzvgpg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChxA6gi69eBQSvRDHEQ0Hg
KqY4hMQUB5uzCoc5U3GY00C8OC5zcNmLy524/IUrHHCFG0wcAFexeKU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAAmG4QOoIuvXgUEWZjioWCA
KQ4mHXCYo4XDHFEc5jAQL47LHFz24nInLn/hCgdc4QYTBwCmpXP1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0CIHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAFreRoI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHACTDaIHGi7wsRb5zUcVZxA9
wHDBPc7yax2aehGoPBxA+SI41AvjMF/4AHb3CB0wBoPLxIkDzcGuHoc40J3Y
1eMQB4YDdvWiONwvegAAzqJFDg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQoscgInrxCxqCjP5tf9m
bxnv3DnCcPEFhflfTpyFqndAiJ9SOeHz6ODv/UacRpMrPggdQDX/7/6MO9K2
RZsR4knmt0xLiv7t556+YoFoL7p6hgNgsgEh7v9E6OnRYwwHsKpvYDyAbv7s
t7Nv8skzHUB3j4H7iVbpmUwH0N3/6uK6fVeeMh24geZfiHOYD6CHD0y9elHn
p6RkEezmH0CIz4G65+y3sznt/KIY7p+h/ORQr48ohn+/ZoTHvyoSxRE+CPFk
aHiiq2eEhj+6+bD4OofmHpT4PYCZHjTQ/IuefgBdAw1y
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQgsdgImvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcQifhWTx1WDzMMUh9gvjMEcEhzmY4hBzRHGYI0ZQ
fDWKf8VwhA+6OQwY4mEo4Y9u/i8McdT4JV4cu39/7McePjBzMMWxhz/MHPT4
QqRDAJWk5yU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoQUOwMRDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwCMB3UH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQgscgImvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAMUXglw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChhA6gi69eBQSvBDHEQ0Hg
KqY4hMQUB5uzCoc5U3GY00C8OC5zcNmLy524/IUrHHCFG0wcAC/ZeGk=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOACheA+gi4eCwFUeDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAH1edJ4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AIHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnADMGRkY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHACTDYIHGi7wsRb5zUcVZxA8
wHDBPc7yax2aegGoPBxA+QLY1TPw4zCf7wBW9zDwHjAGg8tEivPhEOfHIS6A
XbwBhzgwHLCrF8TufqA4ADXjQs4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQgscgInrxCxqCjP5tX+j
9FspK0t+uPiCwvwvJ85C1TfwwcVPqZzweXTw9/5UoRS1jw94D6Ca/3f/hR3m
VU/SEOJJ5rdMS4r+7RfTC3TUlkJXz3AAQiHE/Z8IPT16jOEAVvUNjAfQzZ/9
dvZNPnmmA+juMXA/0So9k+kAuvtfXVy378pTpgPo/oW4g/kAevjA1KsXdX5K
ShbAbv4BhPgcqHvOfjub084viOH+GcpPDvX6CGL492tGePyrIkHs4dOAEE+G
hie6ekZo+KObD4uvc2juQYnfA5jpQQPNv+jpBwAGWwrE
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQvMcgImvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcQifhWRxiD28GOKrwfbw4TBHAId6THGI+YI4zBEi
KL4axb9COMIH3RwGDPEwlPBHN/8Xhjhq/BIvjt2/P/ZjDx+YOZji2MP/x/4w
rPGFSIcA3+nmoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoTkOwMRDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwA8V3SP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQnMcgImvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAHVngeQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOACheA6gi4eCwFVuDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAHNodI8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChWA+gi4eCwFUWDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAC2udCY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0BwHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAONHRc4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQ3AcaLvCxFvnNRxPnOsBw
wT3O8msdmjgnlIYDKJ8Dh3p2HOazHcDuHtYDxmBwmUhxNhzi7DjEOXCIc+IQ
58Ihzo3D/dwHAHxJP+A=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQnMcgInrxCxqCjP5tX+j
9FspK0t2uPiCwvwvJ85C1TewwcVPqZzweXTw9/5UoRS1jw9YD6Ca/3f/hR3m
VU/SEOJJ5rdMS4r+7RfTC3TUlkJXz3AAQiHE/Z8IPT16jOEAVvUNjAfQzZ/9
dvZNPnmmA+juMXA/0So9k+kAuvtfXVy378pTpgPo/oW4g/kAevjA1PuB3cWB
w3xOuPgcqHsg7uLCcD9EHxeGfyH2cOEIH264eDI0PNHVM0LDH918WHyhuwc1
fjkx0oM/mn/R0w8A4wILRw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQrMcgImvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcRifVHGIPawY4qvB9rDhMIcDhzmcGOIQ93LhMIeH
oPhqFP/y4AgfdHMYMMTDUMIf3fxfGOKo8Uu8+Gqs/v2xH3v4wMxBD0+YOejh
/2N/GNb4QqRDANX25dU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoRkOwMRDQeAqM4b46lUg
gCkO5jVgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwDsmHQX
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQjMcgImvXgUCPzHEQ8EA
UxzCxRSHmPMDQzwMbA6mOIRLvHgoDnNw2YvLnbj8tQpHOOAKN3RxACW3gWw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChWA6gi4eCwFVmDPHVq0AA
UxxMNmCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDACO4dBc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChfu1HF1+9CgR+YoiHggGm
OITCFIeY8wNDPAxsDqY4hCJePBSHObjsxeVOXP5ahSMccIUbTBwA8hGBbA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AwHGi7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAJOXRVY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQzAcaLvCxFvnNRxNnOsBw
wT3O8msdmjgjlIaDA3Aaq/p/+7Gb/2c/dvf82m8MBpeJFP+DQ/wfDnGGA9jF
GXGIM+EQZz6AKzwBZA9FVg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQjMcgInrxCxqCjP5tT/J
/JZpSdG//TDxBYX5X06chan/Cxc/pXLC59HB3/thNKr5f/fD9MHEYebC7EFV
z3AA5i6YuP8ToadHjzEcwKq+gfEAuvmz386+ySfPdADdPQbuJ1qlZzIdQHf/
q4vr9l15ynQA3b8QdcwH0MMHpt4P6i6s5gPdBROfA3UPzF3o7ofpQ/cvzB7s
4cMMF0+GuhtdPSPUn+jmw8IF3T0o8Yvkfli4+6P5Fz39AAAQRxnV
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfRsPEV4HBLwzxUDD4iyEO
4TMcwK6eEUMcYj4ThjiEz0KyOMy96OIw92I3h+EAdvWMGOIw92I3h4Wg+GoU
/yLEUcMH3RwGDPEwlPBHN/8Xhjhq/BIvvhqrf3/sxx4+MHPQw/PH/jCs4Q8z
Hz2+EOkQAM5l8bs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoT/sh4mHgsBVZgzx1atA
AFMczG3AFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4YYuDgA554IY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQn/YDxNfvQoEfmKIh4IB
pjiEjykOMecHhngY2BxMcQifePFQHObgsheXO3H5axWOcMAVbujiAHL3j20=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChfuxHF1+9CgS+Y4iHggGm
OITCFIeY8w1DPAxsDqY4hCJePBSHObjsxeVOXP5ahSMccIUbTBwA3iWBTg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChnuxHFw8LBYHHGOKrwOAR
hjiEwhSHmPMQQ3w12JwHOMwhXnwVDnNw2YvLnbj8FYojHHCFG0wcAAz5gBQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0B/2N1zgYy3ymw8VZ4KL
M1xwj7P8WgcVZ0SIowIc6v/tx27+H7g4qnt+wcWNweAyAfE/OMT/4RBHuBNV
nBGHOBMOcUS44QpPAODXU1c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQ3/Y3XOBjLfKbjyb+ZT/D
Bfc4y691aOKf9jOgAqj4Bxzq3+Aw/8V+7O55st8YDC4TKf4Ch/gbHOIfcIh/
wiH+BYf4Nxzu/7YfAGjPTVQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQn/YDxPXiVnUFGbya//R
vC3ZL568gYsvKMz/cuIsTP0ruPgplRM+jw7+3j/Fc8LMI83P96Oa/3e/w+N7
LybOfgoXTzK/ZVpS9G9/xA4X1rUZT9DUMxyAUAhx/ydCT48eYziAVX0D4wF0
82e/nX2TT57pwGQ09xi4n2iVnsl04D8YvISLv7q4bt+Vp0wHjqD5F+IO5gPo
4QNTP/eE6qnu3o8Y5kPUf4aLz4G6x+y2+WZZuy8Y7k/om8BtbvQVw79XFsfW
rjz9FUf4fIOLJ0PDE109IzT80c2HxRe6e2Dxy4jmflh6mI/mX/T0AwD2pCib

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQj/YDxNfBQa/MMRDweAv
hjiEz3AAu3pGDHGI+UwY4hA+C8niEHueYohD7HmFw5wPONR/wmH+Vxzm/CAo
vhrFvz9whA+6OQwY4mEo4Y9u/i8McdT4JV48DKt/f+xfjTV8YOaghydMPXr4
w8xHjy9EOgQAQcr+wQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDnAAAUw8VAQuMqMIb56FQhg
ioM5DZjiYHNCcZijhcMcBuLFcZmDy15c7sTlL1zhgCvc0MUBfu9o1w==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LWfAQpg4qtXgcBPDPFQMMAU
h/AwxSHm/MAQDwObgykO4REvHorDHFz24nInLn+twhEOuMINXRwAt/92LA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChHuxHF1+9CgTuYYiHgsFd
DHEIdQeHObcwxMPA5tzEYc4NosVDcZiDy15c7sTlr1U4wgFXuMHEAdEqf7w=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChbtiji4eCwU0M8dWrQOAW
hjiEuoPDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuMHEAdv/eDQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB9ggIKGC3ysRX7zoeJMcHGG
C+5xll/roOKMCHFUgEP9v/3Yzf8DF0d1zy+4uDEYXCYg/geH+D8c4gh3oooz
4hBnwiGOCDdc4QkAJe46Fg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQN/Y3XOBjLfKbjyZ+YT/D
Bfc4y691aOIH9jOgggNwFnb19jjMt8fhHntjMLhMpPgFHOIHcIgzMOBQvx+H
+TjEb+zHFZ4AzzNFUA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LWfAQpg4joxi5rCTH7tv9EZ
s2jPjR32MPEFhflfTpz9tf8/GByHi59SOeHz6ODv/Tdz7p8p+3HBHtX8v/sb
LJ307py4AhdPMr9lWlL0b79/f9nXpXrX0dQzHIBQN+Di/k+Enh49xnAgAJv6
BsYD6ObPfjv7Jp8804FbaO4xcD/RKj2T6QALWOMJuPiri+v2XXnKdOABmn8h
7mA+wNU1z8eysssGXf05iPr96Ob/gYQPXHwO1D3XIe7Zj+7+Ooj796P71w/i
3/04wgcungwNzwA09YzQ8G9CMx8WX7fQ3AOLXzZI+OxHTw/v0PwLSz+Q8Jm1
BwDwsi3q
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQj+wh4mvAoNfGOKhYPAX
QxzCZziAXT0jhjjEfCYMcQifhWTxMLA9V3GIH8VhDno4sBwIgajfj138KoY4
1D0ExVej+nc/jvDZjyM84eJhqOGPZv4vDHG0+CVaPAyrf2Hi6OEDMwczXYVg
DX+YOHp8IdIhAPYY6ws=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoT/Yw8RDQeAqM4b46lUg
gCkO5jZgioPNCcVhjhYOcxiIF8dlDi57cbkTl79whQOucEMXBwBGHHqY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQn+wh4mvXgUCPzHEQ8EA
UxzCxxSHmPMDQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAH8sh+0=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChHtiji68CA0zxsFAQeIgh
DqEe4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRtMHAAX1niQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChvtmji4eCAab46lUggCkO
ob7jMAdTHGzMKkxxCPWDaPHVOMzBZS8ud+LyVxiOcMAVbjBxAOkGecw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0B/sGy7wsRb5zYeKM8HF
GS64x1l+rYOKMyLEUQEO9f/2Yzf/D1wc1T2/4OLGYHCZgPgfHOL/cIgj3Ikq
zohDnAmHOCLccIUnAO0MS9c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQT+wbLvCxFvnNRxN/Yc9w
wT3O8msdmvgbGJ8BVfwDDvWfcJj/xR67e77ZG4PBZSLFv+AQ/4RD/AMO8Tc4
xF/gEH+Cw/1P7AF04EXC
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQn+wh4nrxCxqCjP5tX/e
CdVT3b0f4eILCvO/nDgLU/8ZLn5K5YTPo4O/95vdNt8sa/fFHtX8v/sT+iZw
mxt9hYsnmd8yLSn6t//K4tjalae/oqlnOAChvsHF/Z8IPT16jOEAVvUNjAfQ
zZ/9dvZNPnmmA+juMXA/0So9k+kAuvtfXVy378pTpgPo/oWoYz6AHj4w9cfy
tmS/ePIGw3xGsPpXcPE5UPdM8Zww80jzcwz3Oz6+92Li7KcY/o3c4cK6NuMJ
jvBBiCdDwzMCTT0jNPzt0cyHxddkNPfA4vfffxB4iZEeDqH5F5Z+wMr/v7cH
AF1CIhM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfStvDxFeBwS8M8VAw+Ish
DuEzHMCunhFDHGI+E4Y4hM9CsngY2J6vGOKrwfZ8wmHOBxzqX+Ew/ykOcx4Q
FF+N4t8HOMIH3RwGDPEwlPBHN/8Xhjhq/BIvHorVvz/2r8IaPjBz0MMTph49
/GHmo8cXIh0CAFyL8ME=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoRkcYOKhIHCVGUN89SoQ
wBQH8xowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwD4zWyX
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQjM4wMRXrwKBnxjioWCA
KQ7hYopDzPmBIR4GNgdTHMIlXjwUhzm47MXlTlz+WoUjHHCFG7o4ADHseew=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChftiji4eCAab46lUggCkO
oX7iMAdTHGzMKkxxCPWLaPHVOMzBZS8ud+LyVxiOcMAVbjBxAPzyeeo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChmB3QxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYWAhWhyXObjsxeVOXP7CFQ64wg0mDgAv62yW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AwODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAJ/MPdY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQv+wbLvCxFvnNRxP/Y89w
wT3O8msdmvg/GJ8BVZzBAbt6Rgfs5jM5YHcPs4MxGFwmUpwJhzgjDnEGHOL/
7LGL/8Eh/sseV3gCAHIxPsw=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQjM4wMR1YhY1hZn82u//
ROjp0WMI8QWF+V9OnIWqb2CEi59SOeHz6ODv/bPfzr7JJ8/kgGr+3/0G7ida
pWcixJPMb5mWFP3b/+riun1XnqKrZzgAoZjh4lB3HMCqvoHxALr5UHccQHcP
VN0BdPdDzT2A7l+oOw6ghw9MfTLEH/ZYzWf4CxefA3UPNJzs0d0PDVd7dP9C
48Eee/ggxKHu2I+unhEa/ujmw+IL3T2w+P0PBn/s0dNDIpp/0dMPAEToE08=

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQrM4wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOJRPsvhqiHkY4lD7cZjDgCEeBvGfPXbzf2GIQ8OP
oPhqFP8ixFHDB90cBgzxMJTwRzf/F4Y4avwSL74Kq39/7A/FGj4wc9DDE6Ye
Pfxh5qPHFyIdAgBSP+O7
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoTkcYOKhIHCVGUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwBIjG0P
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQnM4wMRXrwKBnxjioWCA
KQ7hY4pDzPmBIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4AIGcemQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChWBzQxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYWAlWhyXObjsxeVOXP7CFQ64wg0mDgA54Wyl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChuB3QxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYeAhWhyXObjsxeVOXP7CFQ64wg0mDgB/m20O
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0BwODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAO98Pk4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQrA4NF/hYi/zmo4mzOTBc
cI+z/FqHJs7uwIAKoOIcONRz4jCfywG7e7gdjMHgMpHiXDjEOXGIc+AQZ8ch
zoZDnBWH+1kdAIhyOFo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQnM4wMR1YhY1hZn82u//
ROjp0WMI8QWF+V9OnIWqb+CEi59SOeHz6ODv/bPfzr7JJ8/lgGr+3/0G7ida
pWcixJPMb5mWFP3b/+riun1XnqKrZzgAobjh4hB3MBzAqr6B8QC6+RB3MB1A
dw9EHdMBdPdDzGU6gO5fiDuYD6CHD0z9Jum3UlaW7DjMZ4OLz4G6J1UoRe3j
A1YM91/YYV71JI0Vw79ieoGO2lKsOMIHIZ4MDU909YzQ8Ec3HxZf6O5BjV82
jPSwEc2/6OkHABn1/ro=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQvM4wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOITPQrL4arB5XBjiEPs5cZjDgcMcNgzxMLA5rDjM
YSEovhrFvyw4wgfdHAYM8TCU8Ec3/xeGOGr8Ei8eitW/P/ZjDx+YOejhCTMH
Pfx/7F+FNb4Q6RAAWxfX1Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoQUcYOKhIHCVGUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwCYPG2H
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQgs4wMRXrwKBnxjioWCA
KQ7hY4pDzPmBIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4ANFMetw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOACheBzQxVevAgItTPFQMMAU
B5MNOMxZhcOcqzjMYeAlWhyXObjsxeVOXP7CFQ64wg0mDgCJkW0d
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAAmGwQd0MVDQWAqpvjqVSCA
KQ4hcZhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRtMHAA9jHFo
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0AIODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAD87PsY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHIBQvA4NF/hYi/zmo4nzOTBc
cI+z/FqHJs7vwIAKoOIC2NU3COAwX9ABq3saBB2MweAyceIMuNQL4FCPS5wf
hzgfDnFe7O4HigMAQJA6yg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQgs4wMR1YhY1hZn82q9e
1PkpKRkhvqAw/8uJs1D1BxDip1RO+Dw6+Hv/uW9nc9r5BR1Qzf+7f4byk0O9
PgjxJPNbpiVF//Z/zQiPf1WErp7hAJhsQIj7PxF6evQYwwGs6hsYD6CbP/vt
7Jt88kwH0N1j4H6iVXom0wF097+6uG7fladMBzTQ/AtxDvMB9PCBqd8k/VbK
ypIfu/kNfHDxOVD3pAqlqH18wIvh/gs7zKuepPFi+FdML9BRW4oXe/gwIMST
oeGJrp4RGv7o5sPiC909KPGL5H5YetiI5l/09AMAyJH+Nw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQgs5wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOITPQrI4xB5BDPHVYHsEcJiDKQ5Rz4chHgY2nxeH
OTwExVej+JcHR/igm8OAIR6GEv7o5v/CEEeNX+LFQ7H698d+7OEDMwc9PGHq
McWxxxciHQIAUVrYoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYDkAoUUcYOKhIHCVGUN89SoQ
wBQHcxswxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuKGLAwDAFG3D
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LUfQos4wMRXrwKBnxjioWCA
KQ7hY4pDzPmBIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4APkkexg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAChhBzQxUNBQBRTfPUqINDC
FAeTDjjMCcVhThYOcxqIF8dlDi57cbkTl79whQOucIOJAwCxWmv1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIOAAmG0Qd0MVDQWAqpvjqVSCA
KQ4hcZhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRtMHABlZHGk
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYMB+A0CIODRf4WIv85kPFmeDi
DBfc4yy/1kHFGRHiqACH+n/7sZv/By6O6p5fcHFjMLhMQPwPDvF/OMQR7kQV
Z8QhzoRDHBFuuMITAGcTPwI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEHACTDUIODRf4WIv85qOKMwg7
MFxwj7P8WoemHiiOCqDqRXCoF8FhvqgDdveIOhiDwWXixBlwqRfBoR6HONBf
2NXjEAeGG67wBADa0T2L
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+LUfQos4wMR1YhY1hZn82q9e
1PkpKRkhvqAw/8uJs1D1BxDip1RO+Dw6+Hv/uW9nc9r5RR1Qzf+7f4byk0O9
PgjxJPNbpiVF//Z/zQiPf1WErp7hAJhsQIj7PxF6evQYwwGs6hsYD6CbP/vt
7Jt88kwH0N1j4H6iVXom0wF097+6uG7fladMBzTQ/AtxDvMB9PCBqb/ZW8Y7
d44wdvMdEOJzoO4x5jSaXPFBCMP9GXekbYs2C2H4l3v6igWivUI4wgchngwN
T3T1jNDwRzcfFl9GaO5BiV8k98PSww00/6KnHwCLqwD0
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+LEfQos5wMRXgcEvDPFQMPiL
IQ7hMxzArp4RQxxiPhOGOITPQrI4xB5RDPHVYHtEcJiDKQ4xRxiHOUI4zCEs
vhrFv0I4wgfdHAYM8TCU8Ec3/xeGOGr8Ei+O3b8/9mMPH5g56OEJMwdTHHt8
IdIhAPNW2SU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQoscgImvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxANgTgno=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQoscgImHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OAD9CIFA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQosdQBdfvQoIXoliiIeC
wFVMcTB1AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVuMHEAFQiGpg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfTDUIHUAXX70KCLIwxUPB
AFMcTDngMEcLhzmiOMxhIF4clzm47MXlTlz+whUOuMINJg4AY/yB9g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoUUONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxAJ+OToA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPphpEDzRc4GMt8puPKs4g
eoDhgnuc5dc6NPUiBxhQAEy9CA71wjjMFz6A3T1CB4zB4DJx4kBzsKvHIQ50
J3b1OMSB4YBdvSgO94seAACL+VMP
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQoscgIlH7HBhXZvxZP/N
3jLeuXOE4eIOj++9mDj7KUS9A0J8sueEmUean+834jSaXPFB6ACq+a/2Z9yR
ti3ajBA/krcl+8WTN/u5p69YINqLrv4DxPwGhPjcE6qnuns/4lD/GcN8s9vm
m2XtvmC4J6FvAre50VcM919ZHFu78vTX/TfQ/Asx/xtG+MDUqxd1fkpKFsFu
/gGEuDnUPWe/nc1p5xeFizNC3T9D+cmhXh+E+Hyof79mhMe/KhLFET4I8WPQ
8ERXzwQNf3Tzp0Dj6xyaexyR4xfJ/ZHQ9KCB5l/09AMAY88VPA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQgsdgImHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksVXg+3BFIfYI4zDHBEc5mCKQ8wRxWGOGEHxMBT/
IsRXo4QPujkfcKh/hcP8pzjMeUCyOHb/PsARPg9whOcDHOH/AEd8IdIhALa/
9Cs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQgscgImvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxALA7gj4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQgscgImHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OADVMIEE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQgsdQBdfvQoIXgliiIeC
wFVMcTB1AFMcbM4qHOZMxWFOA/HiuMzBZS8ud+LyF65wwBVuMHEA7SGGag==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQvMeQBcPBYGrPBjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwA6tYKf
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoQUONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxAHe2TkQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPphoEDzRc4GMt8puPKs4g
eIDhgnuc5dc6NPUCBxhQAEy9AHb1DPw4zOc7gNU9DLwHjMHgMpHifDjE+XGI
C2AXb8AhDgwH7OoFsbsfKA4A8ytQzw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQgscgIlH7HBhXZvxZP9G
6bdSVpb8cHGHx/deTJz9FKK+gQ8uPtlzwswjzc/3pwqlqH18wHsA1fxX+y/s
MK96koYQP5K3JfvFkzf7xfQCHbWl0NV/gLoHIT73hOqp7t6PONR/xjDf7Lb5
Zlm7LxjuSeibwG1u9BXD/VcWx9auPP0Vw78Q879hhA9MvXpR56ekZAHs5h9A
iJtD3XP229mcdn5BuDgj1P0zlJ8c6vVBiM+H+vdrRnj8qyJB7OHTgBA/Bg1P
dPVM0PBHN38KNL7OobnHETl+kdwfCU0PGmj+RU8/AA0nEo4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQvMcgImHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksUh5vFiiK8G28+HwxwBHOoxxSHmC+IwR4igeBiK
fxHiq1HCB92cDzjUv8Jh/lMc5jwgWRy7fx/gCJ8HOMLzAY7wf7A/DGt8IdIh
AAET86Y=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQnMcgImvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAGCLgcY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQnMcgImHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OACFgICM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQvMcQBcPBYGr3Bjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwAwv4KQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQrMeQBcPBYGrLBjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwDq9oIn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoTkONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxACgGTcw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPobkPNFzgYy3ym48mznWA
4YJ7nOXXOjRxzgMMKAAmzoFDPTsO89kOYHcP6wFjMLhMpDgbDnF2HOIcOMQ5
cYhz4RDnxuF+7gMAOaBN4Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQnMcgIlH7HBhXZvxZP9G
6bdSVpbscHGHx/deTJz9FKK+gQ0uPtlzwswjzc/3pwqlqH18wHoA1fxX+y/s
MK96koYQP5K3JfvFkzf7xfQCHbWl0NV/gLoHIT73hOqp7t6PONR/xjDf7Lb5
Zlm7LxjuSeibwG1u9BXD/VcWx9auPP0Vw78Q879hhA9Mvd8ToadHj3HgMJ8T
Lm4Odc/st7Nv8slzwcUZoe43cD/RKj0TIT4f6t9XF9ftu/KUC0f4cMPFj0HD
E109EzT80c2fAo0vdPc4osQvwv2R0PTgj+Zf9PQDAOnOExE=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQrMcgImHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksUh5rFiiK8G28+GwxwOHOZwYohD/MGFwxweguJh
KP5FiK9GCR90cz7gUP8Kh/lPcZjzgGTx1Vj9+wBH+DzAEZ4PcIT/g/1hWOML
kQ4B9xHy2w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQjMcgImvXgUC3zHEQ8EA
UxzCxRSHmPMNQzwMbA6mOIRLvHgoDnNw2YvLnbj8tQpHOOAKN3RxABDbgU4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQjMcgImHhYLAYwzxVWDw
CEMcwsUUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OAA10IAU

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQrMcQBcPBYGrzBjiq1eB
AKY4mGrAFAebE4rDHC0c5jAQL47LHFz24nInLn/hCgdc4QYTBwDhAIIY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQv/ajy6+ehUI/MQQDwUD
THEIjSkOMecHhngY2BxMcQhNvHgoDnNw2YvLnbj8tQpHOOAKN5g4AK9oj20=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoRkONFzgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxANhHTVQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoZkPNFzgYy3ym48mznSA
4YJ7nOXXOjRxxgMMKAAmzoBD/b/92M3/sx+7e37tNwaDy0SK/8Eh/g+HOMMB
7OKMOMSZcIgzH8AVngAhZlNX
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQjMcgIlH7HBhXZvxZH+S
+S3TkqJ/+2HiDo/vvZg4+ylU/V+4+GTPCTOPND/ff0rlhM+jg7/3o5r/av+C
wvwvJ87+gosfyduS/eLJm/06MYuawkx+oan/ADUfIT73hOqp7t6PONR/xjDf
7Lb5Zlm7LxjuSeibwG1u9BXD/VcWx9auPP0Vw78Qdd8wwgem3u+J0NOjxxDi
KOY3MMLFzaHumf129k0+eSa4OCPU/QbuJ1qlZyLE50P9++riun1XniLEUcOH
GS5+DBqe6OqZoOGPbv4UaHyhu8cROX6R3B8JTQ/+aP5FTz8AFxMhnw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQv/YDxMPBYOnGOKrwOAV
hjiE/wGH+k84zP+Kw5wfJItD7PmFIQ6x5y8OcxgOYFfPiCEOMZ8JQxxCsxAU
D0PxL0J8NUr4oJvzAYf6VzjMf4rDnAcki6/G6t8HOMLnAY7wfLA/DGv4w8xH
jy9EOgQA74D+wQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQn/YDxNfvQoEvmOIh4IB
pjiEjykOMecbhngY2BxMcQifePFQHObgsheXO3H5axWOcMAVbujiAF4bj08=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQn/YDxMPCwWBxxjiq8Dg
EYY4hI8pDjHnIYb4arA5D3CYQ7z4Khzm4LIXlztx+SsURzjgCjd0cQCDEI4V

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQv/Yjy6+ehUIfMcQDwUD
THEIjSkOMecbhngY2BxMcQhNvHgoDnNw2YvLnbj8tQpHOOAKN5g4AJt8j08=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQj/Zjy4eFgoCjzHEV4HB
IwxxCI0pDjHnIYb4arA5D3CYQ7z4Khzm4LIXlztx+SsURzjgCjeYOADKQY4V

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoT/sb7jAx1rkNx8q/gUu
znDBPc7yax1U/BNCHAV8wKH+DQ7zX8DFUd3zBC5uDAaXCYi/wCH+Bof4Bxzi
n3CIf8Eh/g2H+xHiACWWW1U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPob/tb7jAx1rkNx9N/Mt+
hgvucZZf69DEP0FpGICJf8Ch/g0O81/sx+6eJ/uNweAykeIvcIi/wSH+AYf4
JxziX3CIf8Ph/m/7ASYmW1U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQn/YDxOP2OHCujbjyf6j
eVuyXzx5Axd3eHzvxcTZT6HqX8HFJ3tOmHmk+fn+KVAa1fxX+2H6YOJHoObC
7EFV/2E/zF0w8bknVE91937Eof4zhvlmt803y9p92T8ZzT0JfRO4zY2+7v8P
Bi/h4lcWx9auPP11/xE0/0LM/4YRPjD1MHehmw9zF0zcHOoemLtg4oxQdTB9
MPH5UHNh9mAPn29w8WNQd6OrZ4KGP7r5sHhCd48jNBwZ0dwfCQ33+Wj+RU8/
AP1wMGU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfRsPEQ8HgKYb4KjB4hSEO
4X/Aof4TDvO/4jDnB8niMPeii8Pci92cDzjUf8Jh/lcc5vwgKB6G4l+E+GqU
8EE35wMO9a9wmP8UhzkPSBYPw+rfB/tXYw2fBzjCE6YePfxh5qPHFyIdAgBi
5QvW
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LGfAQpg4qtXgcB3DPFQMMAU
h/AwxSHmfMMQDwObgykO4REvHorDHFz24nInLn+twhEOuMINXRwAoyN2Dg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLKfAQpg4mGhIPAYQ3wVGDzC
EIfwMMUh5jzEEF8NNucBDnOIF1+Fwxxc9uJyJy5/heIIB1zhhi4OAMgYdNQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQj/Yjy6+ehUI3MMQDwWD
uxjiEPoODnNuYYiHgc25icOcG0SLh+IwB5e9uNyJy1+rcIQDrnCDiQMAjoGN
vQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQt+wRxcPBYObGOKrV4HA
LQxxCH0Hhzl3McTBxqy6h8OcB0SLr8ZhDi57cbkTl7/CcIQDrnCDiQMAmVaG
NQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNvPAAUNF/hYi/zmQ8W/wMUZ
LrjHWX6tg4p/QoijgA841L/BYf4LuDiqe57AxY3B4DIB8Rc4xN/gEP+AQ/wT
DvEvOMS/4XA/QhwAap5CFA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoW/sb7jAx1rkNx9N/MJ+
hgvucZZf69DED0BpGPiA4GNXb4/DfHsc7rE3BoPLRIpfwCF+AIc4AwMO9ftx
mI9D/MZ+XOEJAIyKU1E=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLKfAQpg4hE7XFjXZjzZf6Mz
ZtGeGzvsYeIOj++9mDj76f7/YHAcLj7Zc8LMI83P99/MuX+m7McFe1TzX+1v
sHTSu3PiClz8SN6W7BdP3uz37y/7ulTvOpr6D1D33ICLzz2heqq79+P+AKzq
P2OYb3bbfLOs3Zf9t9Dck9A3gdvc6Ot+FrC+E3DxK4tja1ee/rr/AZp/IeZ/
28/VNc/HsrLLBl39OYj6/ejm/4GED1zcHOqe6xD3wMUZoe6vg7gfLj4f6l8/
iH/34wgfuPgxaHgGoKlngoZ/E5r5U6DxdQvNPY7Q+GWDhA9cPBKaHt6h+ReW
fiDhM2sPAPd+NbQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfStvDxEPB4CmG+CoweIUh
DuF/wKH+Ew7zv+Iw5wfJ4mFg867iED+Kwxz0cPixPwSifj928asY4rDwIyQe
hupfuPhq1PDZjyM80dS/wmH+UxzmPCBZPAyrf2Hi6OHzAEd4PoCFpz12cfT4
QqRDABdC+BE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQn+wh4mvXgUC3zHEQ8EA
UxzCxxSHmPMNQzwMbA6mOIRPvHgoDnNw2YvLnbj8tQpHOOAKN3RxAGpQh88=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQn+wh4mHhYLAYwzxVWDw
CEMcwscUh5jzEEN8NdicBzjMIV58FQ5zcNmLy524/BWKIxxwhRu6OACPRYaV

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQj+wRxdfBQaY4mGhIPAQ
QxxCP8JhDqY42JjQxzjMeUK0eBgOc3DZi8uduPy1Gkc44Ao3mDgA1R6GkQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQn+zRxcPBQNM8dWrQABT
HEJ/x2EOpjjYmFWY4hD6B9Hiq3GYg8teXO7E5a8wHOGAK9xg4gCmXYfN
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoT/YN1zgYy3ymw8V/wIX
Z7jgHmf5tQ4q/gkhjgI+4FD/Bof5L+DiqO55Ahc3BoPLBMRf4BB/g0P8Aw7x
TzjEv+AQ/4bD/QhxADHLU9U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoZ/YN1zgYy3ym48m/sKe
4YJ7nOXXOjTxN1A+DMDEP+BQ/wmH+V/ssbvnm70xGFwmUvwLDvFPOMQ/4BB/
g0P8BQ7xJzjc/8QeADI3U8M=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQn+wh4lH7HBhXZvxZP+8
E6qnuns/wsUdHt97MXH2U6j6z3DxyZ4TZh5pfr7f7Lb5Zlm7L/ao5r/an9A3
gdvc6Ctc/EjeluwXT97sv7I4tnbl6a9o6j9Azf8GF58LcQcO9Z8xzIe6A8M9
UHUY7oeai+FfqDswwgem/hjEHxjmM0L8DRc3h7pnCiSc4OKMUPc7QsIVLj4f
6t9ISDzgCB+EONQd+yPQ1DNBw98ezXyoO/ZPRnMP1B37//0HgZdwcag79h9C
8y8s/YCV/39vDwBkDind
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQv+wh4mHgsFTDPFVYPAK
QxzC/4BD/Scc5n/FYc4PksXDIOZhiK+G2I/DnA841L/CYf5THOY8ICgehuJf
hPhqlPBBN+cDDvWvcJj/FIc5D0gWD8Xq3wf7V2ENnwc4whOmHj38Yeajxxci
HQIAfab9xw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQjM4wMRXrwKB7xjioWCA
KQ7hYopDzPmGIR4GNgdTHMIlXjwUhzm47MXlTlz+WoUjHHCFG7o4AB0Qec4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQjM4wMTDQkHgMYb4KjB4
hCEO4WKKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHABCBXiU

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQv+wRxcPBQNM8dWrQABT
HEL/xGEOpjjYmFWY4hD6F9Hiq3GYg8teXO7E5a8wHOGAK9xg4gC6SYfr
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQjM7oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPAQrQ4LnNw2YvLnbj8hSsccIUbTBwA7TN6lw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoRkcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4AOR8RdQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoX/ZN1zgYy3ym48m/see
4YJ7nOXXOjTxf1A+DMDEGRywq2d0wG4+kwN29zA7GIPBZSLFmXCIM+IQZ8Ah
/s8eu/gfHOK/7HGFJwAviEzN
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQjM4wMQjdriwrs14st//
idDTo8cQ4g6P772YOPspRH0DI1x8sueEmUean++f/Xb2TT55JgdU81/tN3A/
0So9EyF+JG9L9osnb/a/urhu35Wn6Oo/QN3DDBefe0L1VHfvRxzqP2OYb3bb
fLOs3RcM9yT0TeA2N/qK4f4ri2NrV57+iuFfiPnfMMIHpj7Z/JZpSdE/e6zm
M/yFi5tD3XNK5YTPo4O/4eKMUPcvKMz/cuLsL7j4fKh/dWIWNYWZIMRRwwch
fgwanujqmaDhj27+FGh8obvHERq//8HgD1w8EpoeEtH8i55+AEu0Gxk=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQrM4wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeKrwfYwYYhD7GHEYQ4DhngYWP1fe+zm/8IQh9IE
xcNQ/IsQX40SPujmfMCh/hUO85/iMOcByeKrsPr3ATQ80cPnAY7wfIAj/GHm
o8cXIh0CAHNa8ME=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQnM4wMRXrwKB7xjioWCA
KQ7hY4pDzPmGIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4AGzAekY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQnM4wMTDQkHgMYb4KjB4
hCEO4WOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHACRtXkM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQrM4oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPASrQ4LnNw2YvLnbj8hSsccIUbTBwA9yl6pg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQnM7oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPAQ7Q4LnNw2YvLnbj8hSsccIUbTBwAPPJ7Dw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoTkcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4ADQ7Rkw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoVkdGi7wsRb5zUcTZ3Ng
uOAeZ/m1Dk2c3YEBBcDEOXCo58RhPpcDdvdwOxiDwWUixblwiHPiEOfAIc6O
Q5wNhzgrDvezOgAARclGWw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQnM4wMQjdriwrs14st//
idDTo8cQ4g6P772YOPspRH0DJ1x8sueEmUean++f/Xb2TT55LgdU81/tN3A/
0So9EyF+JG9L9osnb/a/urhu35Wn6Oo/QN3DDRefe0L1VHfvRxzqP2OYb3bb
fLOs3RcM9yT0TeA2N/qK4f4ri2NrV57+iuFfiPnfMMIHpn6T9FspK0t2HOaz
wcXNoe5JFUpR+/iAFS7OCHX/hR3mVU/SEOLzof4V0wt01JZixRE+CPFj0PBE
V88EDX9086dA4wvdPY4o8YtwfyQ0PWxE8y96+gEAIMEGkw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQvM4wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeKrwfZwYYhD7OHEYQ4HDnPYMMTDwOaw4jCHhaB4
GIp/EeKrUcIH3ZwPONS/wmH+UxzmPCBZPBSrfx/gCJ8HOMLzAY7wf7B/Fdb4
QqRDAHwy5Ns=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQgs4wMRXrwKB7xjioWCA
KQ7hY4pDzPmGIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4ALxwer4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQgs4wMTDQkHgMYb4KjB4
hCEO4WOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHADhZXmE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQvM4oIuvXgUEWpjioWCA
KQ6mGnCYswqHOVdxmMPAS7Q4LnNw2YvLnbj8hSsccIUbTBwARuh7Hg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfTDUIOqCLh4LAVEzx1atA
AFMcTB3AYc5VHOa8wmEOgxDR4rjMwWUvLnfi8heucMAVbjBxAPrUf2k=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoQUcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4AIPrRsQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPoXkdGi7wsRb5zUcT53Ng
uOAeZ/m1Dk2c34EBBcDEBbCrbxDAYb6gA1b3NAg6GIPBZeLEGXCpF8ChHpc4
Pw5xPhzivNjdDxQHAP3YSMs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQgs4wMQjdriwrs14sl+9
qPNTUjJC3OHxvRcTZz+FqD+AEJ/sOWHmkebn+899O5vTzi/ogGr+q/0zlJ8c
6vVBiB/J25L94smb/V8zwuNfFaGr/wAxvwEhPveE6qnu3o841H/GMN/stvlm
WbsvGO5J6JvAbW70FcP9VxbH1q48/XW/Bpp/IeZ/wwgfmPpN0m+lrCz5sZvf
wAcXN4e6J1UoRe3jA164OCPU/Rd2mFc9SUOIz4f6V0wv0FFbihd7+DAgxI9B
wxNdPRM0/NHNnwKNL3T3OCLHL5L7I6HpYSOaf9HTDwDPXQYQ
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQgs5wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeIQ8wQxxFeD7RfAYQ6mOEQ9H4Z4GNh8Xhzm8BAU
D0PxL0J8NUr4oJvzAYf6VzjMf4rDnAcki4di9e8DHOHzAEd4PsAR/g9wxBci
HQIAcnXlpg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LEfQos4wMRXrwKB7xjioWCA
KQ7hY4pDzPmGIR4GNgdTHMInXjwUhzm47MXlTlz+WoUjHHCFG7o4AORIevo=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLIfQos4wMTDQkHgMYb4KjB4
hCEO4WOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg1dHAAJTHnA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfQgs5oIuHgoAopvjqVUCg
hSkOphxwmBOKw5wsHOY0EC+Oyxxc9uJyJy5/4QoHXOEGEwcAbrF59g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+LAfTDWIOqCLh4LAVEzx1atA
AFMcTB3AYc5VHOa8wmEOgxjR4rjMwWUvLnfi8heucMAVbjBxACK7f6U=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNsPoUUcGi7wsRb5zYeKf4GL
M1xwj7P8WgcV/4QQRwEfcKh/g8P8F3BxVPc8gYsbg8FlAuIvcIi/wSH+AYf4
JxziX3CIf8PhfoQ4AKvDRwA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfNgPphqEHBou8LEW+c1HFWcQ
dmC44B5n+bUOTT1QHAXA1IvgUC+Cw3xRB+zuEXUwBoPLxIkz4FIvgkM9DnGg
v7CrxyEODDdc4QkAmChLjA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYweLIfQos4wMQjdriwrs14sl+9
qPNTUjJC3OHxvRcTZz+FqD+AEJ/sOWHmkebn+899O5vTzi/qgGr+q/0zlJ8c
6vVBiB/J25L94smb/V8zwuNfFaGr/wAxvwEhPveE6qnu3o841H/GMN/stvlm
WbsvGO5J6JvAbW70FcP9VxbH1q48/XW/Bpp/IeZ/wwgfmPqbvWW8c+cIYzff
ASFuDnWPMafR5IoPQnBxRqj7M+5I2xZtRojPh/qXe/qKBaK9QjjCByF+DBqe
6OqZoOGPbv4UaHwZobnHETl+kdwfCU0PN9D8i55+AJJ3CL4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweLAfQos5wMRDweAphvgqMHiF
IQ7hf8Ch/hMO87/iMOcHyeIQ80QxxFeD7RfBYQ6mOMQcYRzmCOEwh7B4GIp/
EeKrUcIH3ZwPONS/wmH+UxzmPCBZHLt/H+AInwc4wvMBjvB/gCO+EOkQABSA
5is=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQoscgImvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMAvoiA
6A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlRQ7AxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwCNHXlg

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUIHYAXXz1KiB4JYohHgoCVzHF
weAApjjYnFU4zJmKw5wG4sVxmYPLXlzuxOUvXOGAK9xg4gCP+W1l
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewZk0CB0AF189SogyMIUDwUDTHEw
cMBhjhYOc0RxmMNAvDguc3DZi8uduPyFKxxwhRtMHADe7Wi1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoUUONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAMXSRnw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMyaBA90HCBj7XIbz6qOIPoAYYL
7nGWX+vQ1IscYMAKRHCoF8ZhvvAB7O4ROmAMBpeJEweag109DnGgO7GrxyEO
DAfs6kVxuF/0AAAG+TnO
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlRQ7AxAP6y74u1btuf7O3
jHfuHGG4eIOlk96dE1cg6h0Q4rdy7p8p+3HB3ojTaHLFByG4OBNY4Qn7jDvS
tkWbEeL3OmMW7bmxw557+ooFor0Ica6ueT6WlVU2YG0NCPGrEPX70dX//Q8C
x/ejm38T4p796O6ph7h/P7r7/SH+3X8Dzb/Q8NmPI3z2qxd1fkpKRog3Ipt/
ACF+B+qes9/O5rTzi8LF2SDhs3+G8pNDvT4I8bdQ/37NCI9/VYQQ73he9vPV
rcl7IOGDED8DDU909d8h4WOPbv4NaHydQ3NPHXL8IrnfD5oeNND8i55+AOw5
I+w=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClhQ7AxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBZfvQoEMMXB1oQK4zBHBIc5mOIQc0RxmCNGUDwM
xb/o4kdxmAMDYujhaY9d/CqGOGr8Ei+Ow7/2OMLHHkd42uMIf3sc8QVPVwAN
wOB1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQgscgImvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMAlrCA
rA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlBQ7AxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwBlRXkk

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUIHQAXXz1KiB4JYghHgoCVzHF
weAApjjYnFU4zJmKw5wG4sVxmYPLXlzuxOUvXOGAK9xg4gBoIW0p
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHsAXTwUBK7yYIivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOALWmaV4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoQUONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAJ36RkA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMyaBA80HCBj7XIbz6qOIPgAYYL
7nGWX+vQ1AscYMAKBLCrZ+DHYT7fAazuYeA9YAwGl4kU58Mhzo9DXAC7eAMO
cWA4YFcviN39QHEAbis3jg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlBQ7AxAP6y74u1btuv1H6
rZSVJT9cvMHSSe/OiSsQ9Q18cPFbOffPlP24YJ8qlKL28QEvXJwJrPCE/YUd
5lVP0hDi9zpjFu25scNeTC/QUVsKIc7VNc/HsrLKBuIehPhViPr96Or//geB
4/vRzb8Jcc9+dPfUQ9y/H939/hD/7kf3LzR89uMIn/3qRZ2fkpIR4o3I5h9A
iN+Buufst7M57fyCcHE2SPjsn6H85FCvD0L8LdS/XzPC418VIcQ7npf9fHVr
8h6I+xHiZ6Dhia7+OyR87NHNvwGNr3No7qlDjl8k9/tB04MGmn/R0w8AlZEh
Pg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACleQ7AxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBYHGxfKiyG+ehUI8OEwRwCHekxxiPmCOMwRIige
huJfdPGjOMyBASH08LTHLn4VQxw1fokXx+FfexzhY48jPO1xhD/U3xjxBU9X
AFgF3/A=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQnMcgImvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMARwCA
NA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlOQ7AxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwAVlXis

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHMAXTwUBK5yY4ivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOAKuwaU8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHoAXTwUBK6yYIivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOAGX2aOY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoTkONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAE5KRcg=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK4D7QcIGPtchvPpo41wGGC+5x
ll/r0MQ5DzBgBRw41LPjMJ/tAHb3sB4wBoPLRIqz4RBnxyHOgUOcE4c4Fw5x
bhzu5z4AALSRNKA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlOQ7AxAP6y74u1btuv1H6
rZSVJTtcvMHSSe/OiSsQ9Q1scPFbOffPlP24YJ8qlKL28QErXJwJrPCE/YUd
5lVP0hDi9zpjFu25scNeTC/QUVsKIc7VNc/HsrLKBuIehPhViPr96Or//geB
4/vRzb8Jcc9+dPfUQ9y/H939/hD/7kf3LzR89uMIn/1+T4SeHj2GEG9EMZ8T
Ln4H6p7Zb2ff5JPngouzQcJnv4H7iVbpmQjxt1D/vrq4bt+VpwjxjudlP1/d
mrwH4h5uuPgZaHiiq/8OCR97dPNvQOML3T11KPGLcL8fND34o/kXPf0AAHJH
IcE=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClWQ7AxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBYHGxfKiiG+ehUIsOEwhwOHOZwY4mBjVnHhMIeH
oHgYin/RxY/iMAcGeNDD0x67+FUMcdT4JV58NXb/2uMIH3sc4WmPI/yh/saI
L3i6AgBOEt8l
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQjMcgImvXgUC9zDEQ8Hg
LoY4hHsHhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMA90F/
vA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlGQ7AxEPB4CaG+OpVIHAL
QxzCvYPDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwDF1ng0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwHIAXTwUBK4yY4ivXgUCmOJg
0IApDjYnFIc5WjjMYSBeHJc5uOzF5U5c/sIVDrjCDSYOAFwAaNc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8Gs/uvjqVSDwE0M8FAwwxSEA
Uxxizg8M8TCwOZjiEEC8eCgOc3DZi8uduPy1Ckc44Ao3mDgAKmh2LA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoRkONFzgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjh2gq7fHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAP6LRVA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKYD7QcIGPtchvPpo40wGGC+5x
ll/r0MQZDzBgBzjU/9uP3fw/+7G759d+YzC4TKT4Hxzi/3CIMxzALs6IQ5wJ
hzjzAVzhCQCcVzoW
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlGQ7AxAP6y74u1btun2R+
y7Sk6N9+mHiDpZPenRNXoOr/wsVv5dw/U/bjgv0plRM+jw7+hoszgdWdsF9Q
mP/lxNlfcPF7nTGL9tzYYa8Ts6gpzAQhztU1z8eyssoGYj5C/CpE/X509X//
g8Dx/ejm34S4Zz+6e+oh7t+P7n5/iH/3o/sXGj77cYTPfr8nQk+PHkOINyKb
38AIF78Ddc/st7Nv8skzwcXZIOGz38D9RKv0TIT4W6h/X11ct+/KU4R4x/Oy
n69uTd4DcQ4zXPwMNDzR1X+HhI89uvk3oPGF7p465PhFcr8fND34o/kXPf0A
AJ99ME8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClf+yHiYeFgsBVHOJHMcQZ
UABCPASifj928asY4lD3kCy+Cgx+YYiDrQn9i8MchgPY1TNiiEPMZ8IQh9As
BMXDUPyLLn4UhzkwgBAPQQl/dPGrGOKo8Uu8+Grs/rXHET4w92KIh2EPf6j5
GPEFT1cARoHrCw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQn/YDxNfvQoE7mGIh4LB
XQxxCP8ODnNuYYiHgc25icOcG0SLh+IwB5e9uNyJy1+rcIQDrnBDFwcARJCN
vQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlP+yHiYeCwU0M8dWrQOAW
hjiEfweHOXcxxMHGrLqHw5wHRIuvxmEOLntxuROXv8JwhAOucEMXBwATJYY1

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8GM/uvjqVSDwHUM8FAwwxSEA
UxxizjcM8TCwOZjiEEC8eCgOc3DZi8uduPy1Ckc44Ao3mDgAFnx2Dg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8GQ/unhYKAg8xhBfBQaPMMQh
AFMcYs5DDPHVYHMe4DCHePFVOMzBZS8ud+LyVyiOcMAVbjBxAEVBdNQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoT/sb7jAx1rkNx8qfgEu
znDBPc7yax1U/ABCHCvAUG+Pw3y4OJp74OLGYHCZgPgFHOIHcIgj3Immfj92
8Qs4xBHhhis8AUvaU1E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK+La/4QIfa5HffDTxL/sZLrjH
WX6tQxP/tJ8BK/iAQ/0bHOa/2I/dPU/2G4PBZSLFX+AQf4ND/AMO8U84xL/g
EP+Gw/3f9gMAoRdCFA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlP+yHiQf0l31dqnfd/mje
luwXT97AxRssnfTunLgCVf8KLn4r5/6Zsh8X7Kd4Tph5pPk5XJwJrO6EvcPj
ey8mzn4KF7/XGbNoz40d9hE7XFjXZjyBi3N1zfOxrKyygZiPEL8KUb8fXf3f
/yBwfD+6+Tch7tk/Gc099RD37wdr+/8SLu4P8e/+I2j+hYbPfhzhs3/uCdVT
3b0f4eKNUPMh6j/Dxe9A3WN223yzrN0XuDgbJHz2J/RN4DY3+goXfwv175XF
sbUrTyPEO56X/Xx1a/IeiPnf4OJnoOGJrv47JHzs0c2/AY0vdPfUQeOXEc39
ftD0MB/Nv+jpBwCF6T8V
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACj98PEw0JB4CoO8aMY4gwo
ACEeAlG/H7v4VQxxGJ9UcbBxoU8xxFeBwSsc5nzAof4TDvO/4jDnB0HxMBT/
oosfxWEODPxAD0977OJXMcRR45d48TDs/rVfjT187HGEJ1Q9RvhDzceIL3j4
AQC51/gR
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLCfAQpg4qtXgcA9DPFQMLiL
IQ7h3cFhzi0M8TCwOTdxmHODaPFQHObgsheXO3H5axWOcMAVbujiAImYdHw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlEeKhYHATQ3z1KhC4hSEO
4d3BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9zQxQFYLWz0
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8GA/uvjqVSBwD0M8FAzuYohD
wB0c5tzCEA8Dm3MThzk3iBYPxWEOLntxuROXv1bhCAdc4QYTBwAJgXR8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUcMMeXTwUDG5iiK9eBQK3MMQh
4A4Oc+5iiIONWXUPhzkPiBZfjcMcXPbicicuf4XhCAdc4QYTBwAUVmz0
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NjPAAUNF/hYi/zmQ8UvwMUZ
LrjHWX6tg4ofQIjjAqjq7XGYDxdHcw9c3BgMLhMQv4BD/AAOcQRAU78fu/gF
HOKIcMMVngCQ4joQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKuLG/4QIfa5HffDTxC/sZLrjH
WX6tQxM/sJ8BF8Cu3h6H+fY43GNvDAaXiRS/gEP8AA5xBgYc6vfjMB+H+I39
uMITAAeKOhA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlEeIB/WVfl+pdt7/RGbNo
z40d9jDxBksnvTsnrtj/B4PjcPFbOffPlP24YH8TSsPEmcCmnoDrg4nfg5rr
D7UHJs7VNc/HsrLKBuYumPhViPr9AWjq/0LcsR/dfKg79t9Cc089RN1+Fqi7
YOJQd+x/gOZfqDv2Q9zVZYMWPvvPQd0FE2+Emv8H6i6Y+B2oe65DaZg4G8Qd
++ug+mDib6Hm+kHtgYl3PC/7+erW5D0wd8HEz0DdHYCm/js0nprQzL8BDZdb
aO6BugPuLpg41B3279D8C4snSPjM2gMAf/dEZA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACnYeJhoSBwFYf4UQxxBhSA
EA+BqN+PXfwqhjiUT7I4zL3YxY/iMAcjHPbD3Itd/CqGOIwmJB6G6l808aM4
zIGH53608LTHLn4VQxwtfokWD8PuX7h7sZuDma5CsIc/3L240iEAbjTkWw==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQn+wh4mvXgUC9zDEQ8Hg
LoY4hH8Hhzm3MMTDwObcxGHODaLFQ3GYg8teXO7E5a9VOMIBV7ihiwMAUMWG
PQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlP9jDxEPB4CaG+OpVIHAL
QxzCv4PDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuKGLAwAfWn61

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8MAeXXwVGGCKh4WCwEMMcQh4
hMMcTHGwMaGPcZjzhGjxMBzm4LIXlztx+Ws1jnDAFW4wcQBQHm1Q
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8M0eXTwUDDDFV68CAUxxCPiO
wxxMcbAxqzDFIeAH0eKrcZiDy15c7sTlrzAc4YAr3GDiACFdbow=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoT/YN1zgYy3ymw8VvwAX
Z7jgHmf5tQ4qfgAhjhVgqLfHYT5cHM09cHFjMLhMQPwCDvEDOMQR7kRTvx+7
+AUc4ohwwxWeAFgPS9E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKeGLfcIGPtchvPpr4C3uGC+5x
ll/r0MTfoPFh4AMO9Z9wmP/FHrt7vtkbg8FlIsW/4BD/hEP8Aw7xNzjEX+AQ
f4LD/U/sAa0oOoI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlP9jDxAP6y74u1btuP++E
6qnu3o9w8QZLJ707J65A1X+Gi9/KuX+m7McFe7Pb5ptl7b7AxZnA6k7YJ/RN
4DY3+goXv9cZs2jPjR32VxbH1q48jRDn6prnY1lZZQMx/xtc/CpE/X509X//
g8Dx/ejm34S4Zz+6e+oh7t+P7n5/iH/3o/sXGj77cYTP/mN5W7JfPHkDF2+E
ms8IVv8KLn4H6p4pnhNmHml+Dhdng4TPfsfH915MnP0ULv4W6t/IHS6sazOe
wMU7npf9fHVr8h6IexDiZ6DhGYGm/jskfOzt0cy/AY2vyWjuqYPG7z+wvpdw
cT9oejiE5l9Y+gEr///eHgDseDiN
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClf9jDxMNCQeAqDvGjGOIM
KAAhHgJRvx+7+FUMcah7SBaHuOsrhvjqVSDwCYc5H3Cof4XD/Kc4zHlAUDwM
xb/o4kdxmAMDD9DD0x67+FUMcdT4JV48FLt/7VdhDx97HOEJVY8R/lDzMeIL
nq4A1JjqEQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQjM4wMRXrwKBexjioWBw
F0Mcwr2Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQEDhXg8

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlGRxg4qFgcBNDfPUqELiF
IQ7h3sFhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFAdILcLQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYU8MMeXTwUDDDFV68CAUxxCPiJ
wxxMcbAxqzDFIeAX0eKrcZiDy15c7sTlrzAc4YAr3GDiADVJbqo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwOyALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GFaHFc5uCyF5c7cfkLVzjgCjeYOABoM2FW
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoRkcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxw7Q1dvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPAArPPdA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK+GXfcIGPtchvPpr4H3uGC+5x
ll/r0MT/ofHhwAG7ekYH7OYzOWB3D7ODMRhcJlKcCYc4Iw5xBhzi/+yxi//B
If7LHld4AgCqeTOM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlGRxg4gH9ZV+X6l23938i
9PToMYR4g6WT3p0TVyDqGxjh4rdy7p8p+3HBfvbb2Tf55Jng4kxghSfsDdxP
tErPRIjf64xZtOfGDvtXF9ftu/IUIc7VNc/HsrLKBuIcZrj4VYj6/ejq//4H
geP70c2/CXHPfnT31EPcvx/d/f4Q/+5H9y80fPbjCJ/9yea3TEuK/tnDxBuR
zWf4Cxe/A3XPKZUTPo8O/oaLs0HCZ/+CwvwvJ87+gou/hfpXJ2ZRU5gJQrzj
ednPV7cm74GYjxA/Aw1PdPXfIeFjj27+DWh8obunDhq/YG3//8DF/aDpIRHN
v+jpBwDUHinJ
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClWRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuvXgUCTBjiYGtCGXGYw4AhDvHfX3vs5v/CEIfQ
PwiKh6H4F138KA5zYAAhHoIS/ujiVzHEUeOXePFV2P1rH4o9fGDuRQ9Pexzh
DzUfI77g6QoAykzdCw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQnM4wMRXrwKBexjioWBw
F0Mcwr+Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQFTNXi0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlORxg4qFgcBNDfPUqELiF
IQ7h38Fhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFASHKcSw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwOKALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GVaHFc5uCyF5c7cfkLVzjgCjeYOAByKWFl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwO2ALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GHaHFc5uCyF5c7cfkLVzjgCjeYOAC342HO
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoTkcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxwow1NvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPAFp/Pkg=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMKYHVouMDHWuQ3H02czYHhgnuc
5dc6NHF2BwasgAOHek4c5nM5YHcPt4MxGFwmUpwLhzgnDnEOHOLsOMTZcIiz
4nA/qwMAwLotGg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlORxg4gH9ZV+X6l23938i
9PToMYR4g6WT3p0TVyDqGzjh4rdy7p8p+3HBfvbb2Tf55Lng4kxghSfsDdxP
tErPRIjf64xZtOfGDvtXF9ftu/IUIc7VNc/HsrLKBuIebrj4VYj6/ejq//4H
geP70c2/CXHPfnT31EPcvx/d/f4Q/+5H9y80fPbjCJ/9m6TfSllZssPFG1HM
Z4OL34G6J1UoRe3jA1a4OBskfPZf2GFe9SQNIf4W6l8xvUBHbSmEeMfzsp+v
bk3eA3EPQvwMNDzR1X+HhI89uvk3oPGF7p46lPhFuN8Pmh42ovkXPf0AAKkr
FUM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweACleRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuvXgUCXBjiYGtCOXGYw4HDHDYMcYi/WXGYw0JQ
PAzFv+jiR3GYAwMs6OFpj138KoY4avwSLx6K3b/2OMLHHkd42uMIf/tV2OML
nq4A0yTRJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQgs4wMRXrwKBexjioWBw
F0Mcwr+Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQGi5Xks

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlBRxg4qFgcBNDfPUqELiF
IQ7h38Fhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFAXF6caQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUwOOALr56FRBoYYqHggGmOBg0
4DBnFQ5zruIwh4GXaHFc5uCyF5c7cfkLVzjgCjeYOADB2WHd
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewZk0CDogC4eCgJTMcVXrwIBTHEw
OIDDnKs4zHmFwxwGIaLFcZmDy15c7sTlL1zhgCvcYOIAddRmKA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoQUcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxwow1NvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPAKovPsA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMK4HVouMDHWuQ3H02cz4Hhgnuc
5dc6NHF+BwasQAC7+gYBHOYLOmB1T4OggzEYXCZOnAGXegEc6nGJ8+MQ58Mh
zovd/UBxAHjYL4o=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlBRxg4gH9ZV+X6l23Vy/q
/JSUjBBvsHTSu3PiCkT9AYT4rZz7Z8p+XLA/9+1sTju/IFycCazwhP0M5SeH
en0Q4vc6YxbtubHD/mtGePyrIoQ4V9c8H8vKKhuwtgaE+FWI+v3o6v/+B4Hj
+9HNvwlxz35099RD3L8f3f3+EP/u10DzLzR89uMIn/2bpN9KWVnyw8Ubkc1v
4IOL34G6J1UoRe3jA164OBskfPZf2GFe9SQNIf4W6l8xvUBHbSmEeMfzsp+v
bk3eA3EPQvwMNDzR1X+HhI89uvk3oPGF7p465PhFcr8fND1sRPMvevoBAFfW
FMA=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClhRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuDjQsVxBBfvQoEBHCYgykOUc+HIQ7xNy8Oc3gI
ioeh+Bdd/CgOc2CABz087bGLX8UQR41f4sVDsfvXHkf42OMIT3sc4W+PI77g
6QoAyWfR8A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweLAfQos4wMRXrwKBexjioWBw
F0Mcwr+Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9zQxQHKvXlo

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwuAGlRRxg4qFgcBNDfPUqELiF
IQ7h38Fhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3NDFAZlSceA=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYUIOSALh4KAqKY4qtXAYEWpjgY
OOAwJxSHOVk4zGkgXhyXObjsxeVOXP7CFQ64wg0mDgDpomC1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewZk0CDqgC4eCgJTMcVXrwIBTHEw
OIDDnKs4zHmFwxwGMaLFcZmDy15c7sTlL1zhgCvcYOIAnaxmZA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY3NgPoUUcGi7wsRb5zYeKX4CL
M1xwj7P8WgcVP4AQxwow1NvjMB8ujuYeuLgxGFwmIH4Bh/gBHOIId6Kp349d
/AIOcUS44QpPANIHPvw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMyaBByaLjAx1rkNx9VnEHYgeGC
e5zl1zo09UBxrEAEh3oRHOaLOmB3j6iDMRhcJk6cAZd6ERzqcYgD/YVdPQ5x
YLjhCk8AEygySw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwuAGlRRxg4gH9ZV+X6l23Vy/q
/JSUjBBvsHTSu3PiCkT9AYT4rZz7Z8p+XLA/9+1sTju/KFycCazwhP0M5SeH
en0Q4vc6YxbtubHD/mtGePyrIoQ4V9c8H8vKKhuwtgaE+FWI+v3o6v/+B4Hj
+9HNvwlxz35099RD3L8f3f3+EP/u10DzLzR89uMIn/03e8t4584Rhos3Ipvv
gBC/A3WPMafR5IoPQnBxNkj47M+4I21btBkh/hbqX+7pKxaI9iLEO56X/Xx1
a/IeSPggxM9AwxNd/XdI+Nijm38DGl9GaO6pQ45fJPf7QdPDDTT/oqcfABrw
F24=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYweAClxRxg4mGhIHAVh/hRDHEG
FIAQD4Go349d/CqGONQ9JIuDjQsVxRBfvQoERHCYgykOMUcYhzlCOMwhLB6G
4l908aM4zIEBIfTwtMcufhVDHDV+iRfH4V97HOFjjyM87XGEvz2O+IKnKwBr
ctJ1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClRQ7AxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OADLxXm8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalRQ7AxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFAabkevg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClxQ6gi69eBQSvRDHEQ0Hg
KqY4mDqAKQ42ZxUOc6biMKeBeHFc5uCyF5c7cfkLVzjgCjeYOADlLn8m
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AChG4QOoIuvXgUEWZjioWCA
KQ6mHHCYo4XDHFEc5jAQL47LHFz24nInLn/hCgdc4QYTBwA0MXp2
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSIgcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4Abw9G7g==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDQDaIHGi7wsRb5zUcVZxA9
wHDBPc7yax2aepEDDCgApl4Eh3phHOYLH8DuHqEDxmBwmThxoDnY1eMQB7oT
u3oc4sBwwK5eFIf7RQ8AAFwuS48=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalRQ7AxK8sjq1defqr/c3e
Mt65c4Th4gl9E7jNjb5C1DsgxM1um2+Wtftib8RpNLnig9ABVPM/22fckbYt
2owQn3dC9VR370d77ukrFoj2oqv/AKEbEOJH87Zkv3jyBkM9I1jhKwzzp3hO
mHmk+TmGexwe33sxcfZTDPdH7HBhXZvxxP4Gmn8h7nmCET4w9epFnZ+SkkWw
m38AIT4J6p6z387mtPOLwsX//QeBl/YzlJ8c6vVBiB+C+vdrRnj8qyKEOFj5
//fQ8EGIz4WGJ3b1nzDMh8XXOTT3oMTvAcz0oIHmX/T0AwD7rhqu
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlhQ7AxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFIfZgioOtCRXGYY4IDnMwxSHmiOIwR4ygeCiK
fxHiq1DCB92cDzjUf8Jh/lcc5vwgWRy7f3/gCJ8fOMLzB47w/4EjvhDpEACo
YuYr
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClBQ7AxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OACj7XmA
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalBQ7AxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFAX8Merw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClhQ6gi69eBQSvBDHEQ0Hg
KqY4mDqAKQ42ZxUOc6biMKeBeHFc5uCyF5c7cfkLVzjgCjeYOAC9Vn7q
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACleQ+gi4eCwFUeDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAArqex8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSAgcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4ARzdGsg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDQDYIHGi7wsRb5zUcVZxA8
wHDBPc7yax2aeoEDDCgApl4Au3oGfhzm8x3A6h4G3gPGYHCZSHE+HOL8OMQF
sIs34BAHhgN29YLY3Q8UBwDDYElP
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalBQ7AxK8sjq1defqr/Ubp
t1JWlvxw8YS+CdzmRl8h6hv44OJmt803y9p9sU8VSlH7+ID3AKr5n+0v7DCv
epKGEJ93QvVUd+9HezG9QEdtKXT1H6A0Qvxo3pbsF0/eYKhnBKt7hWH+FM8J
M480P8dwj8Pjey8mzn6K4f6IHS6sazOeYPgX4o4nGOEDU69e1PkpKVkAu/kH
EOKToO45++1sTju/IFz8338QeGk/Q/nJoV4fhPghqH+/ZoTHvypCiIOV/38P
dT9CfC40PLGr/4RhPiy+zqG5ByV+D2CmBw00/6KnHwClBhgA
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGleQ7AxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFwcaF8mKIQ+znw2GOAA71mOIQ8wVxmCNEUDwU
xb8I8VUo4YNuzgcc6j/hMP8rDnN+kCyO3b8/cITPDxzh+QNH+P+Axj96fCHS
IQDyp+Wm
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClOQ7AxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OABUPXkI
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalOQ7AxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFAS9cekQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACleQ6gi4eCwFVuDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDAAD0exA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClWQ+gi4eCwFUWDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDALsreqc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSHAcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4A93hGOg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDS3AcaLvCxFvnNRxPnOsBw
wT3O8msdmjjnAQYUABPnwKGeHYf5bAewu4f1gDEYXCZSnA2HODsOcQ4c4pw4
xLlwiHPjcD/3AQAJ1UZh
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalOQ7AxK8sjq1defqr/Ubp
t1JWluxw8YS+CdzmRl8h6hvY4OJmt803y9p9sU8VSlH7+ID1AKr5n+0v7DCv
epKGEJ93QvVUd+9HezG9QEdtKXT1H6A0Qvxo3pbsF0/eYKhnBKt7hWH+FM8J
M480P8dwj8Pjey8mzn6K4f6IHS6sazOeYPgX4o4nGOEDU+/3ROjp0WMcOMzn
hItPgrpn9tvZN/nkueDi//6DwEt7A/cTrdIzEeKHoP59dXHdvitPEeJg5f/f
Q93DDRefCw1P7Oo/YZgPiy9096DGLydGevBH8y96+gEAgbwYgw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlWQ7AxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFwcaFsmKIQ+xnw2EOBw5zODHEwcas4sJhDg9B
8VAU/yLEV6GED7o5H3Co/4TD/K84zPlBsvhqrP79gSN8fuAIzx84wv8HNP7R
4wuRDgHotOTb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClGQ7AxFeBAaZ4WCgIPMQQ
h3Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OAAEjXiQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalGQ7AxEPBAFN89SoQwBSH
cL/jMAdTHGzMKkxxCPcH0eKrcZiDy15c7sTlrzAc4YAr3NDFAd+decw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClWQ6gi4eCwFVmDPHVq0AA
UxxMNWCKg80JxWGOFg5zGIgXx2UOLntxuROXv3CFA65wg4kDALE1epg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClf+1HF1+9CgR+YoiHggGm
OITGFIeY8wNDPAxsDqY4hCZePBSHObjsxeVOXP5ahSMccIUbTBwAf52H7Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSDAcaLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4Ap8hFwg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSzAcaLvCxFvnNRxNnOsBw
wT3O8msdmjjjAQYUABNnwKH+337s5v/Zj909v/Ybg8FlIsX/4BD/h0Oc4QB2
cUYc4kw4xJkP4ApPAPGMS9c=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalGQ7AxK8sjq1defqrfZL5
LdOSon/7YeIJfRO4zY2+QtX/hYub3TbfLGv3xf6UygmfRwd/70c1/7P9gsL8
LyfO/oKLzzuheqq796O9TsyipjCTX2jqP0BphPjRvC3ZL568wVDPCFb3CsP8
KZ4TZh5pfo7hHofH915MnP0Uw/0RO1xY12Y8wfAvRN0TjPCBqfd7IvT06DGE
OIr5DYxw8UlQ98x+O/smnzwTXPzffxB4aW/gfqJVeiZC/BDUv68urtt35SlC
HKz8/3uoe5jh4nOh4Yld/ScM82Hxhe4elPhFcj8sPfij+Rc9/QAArvInEQ==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGj98PEw0JB4CuG+OpVIPAJ
QxzC/4BD/Ssc5j/FYc4DksXB1qz6hSEOtib0Lw5zGA5gV8+IIQ4xnwlDHEKz
EBQPRfEvQnwVSvigm/MBh/pPOMz/isOcHySLr8bq3x84wucHjvD8AY1n9PCH
mY8eX4h0CADhI/DB
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClP+yHia8CA0zxsFAQeIgh
DuE/wmEOpjjYmNDHOMx5QrR4GA5zcNmLy524/LUaRzjgCjd0cQBRzYaR
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalP+yHiYeCAab46lUggCkO
4X/HYQ6mONiYVZjiEP4PosVX4zAHl7243InLX2E4wgFXuKGLAwAs7IfN
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClf+xHF1+9CgS+Y4iHggGm
OITGFIeY8w1DPAxsDqY4hCZePBSHObjsxeVOXP5ahSMccIUbTBwAa7GHzw==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACln+xHFw8LBYHHGOKrwOAR
hjiExhSHmPMQQ3w12JwHOMwhXnwVDnNw2YvLnbj8FYojHHCFG0wcAJp2hpU=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSH/Y3XOBjLfKbD+W/gIsz
XHCPs/xaB+W/QYijgA841H/CYf4XuDiqe77BxY3B4DIB8S84xD/hEP+AQ/wN
DvEXOMSf4HA/QhwA9QhTww==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDS3/Y3XOBjLfKbjyb+ZT/D
Bfc4y691aOKf9jOgAJj4Bxzq3+Aw/8V+7O55st8YDC4TKf4Ch/gbHOIfcIh/
wiH+BYf4Nxzu/7YfAPZMU9U=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalP+yHiV9ZHFu78vRX+6N5
W7JfPHkDF0/om8BtbvQVqv4VXNzstvlmWbsv9lM8J8w80vx8P6r5n+0dHt97
MXH2U7j4vBOqp7p7P9pH7HBhXZvxBE39ByiNEIe6A0M9I8QdGOZD3WE/Gc09
UHX2/8HgJVwcaq79ETT/Qt2BET4w9XMh/sAwH+pvuPgkqHug4QQX/wdxByxc
4eKHoP6FxgNcHOLu97B4g4tD3YFD/ScM82Hxhe4eWPwyorkflh7mo/kXPf0A
AJVeNdc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlH+yHiYeFgsBXDPHVq0Dg
E4Y4hP8Bh/pXOMx/isOcBySLh0LMwxBfBbEfhzkfcKj/hMP8rzjM+UFQPBTF
vwjxVSjhg27OBxzqP+Ew/ysOc36QLB6G1b8/YPGPwxz08ISpRw9/mPno8YVI
hwBUiP3H
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClEeKrwABTPCwUBB5iiEN4
j3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINXRwAltVtUA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalEeKhYIApvnoVCGCKQ3jf
cZiDKQ42ZhWmOIT3g2jx1TjMwWUvLnfi8lcYjnDAFW7o4gBx9G6M
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClH+xHF1+9CgTuYYiHgsFd
DHEIfQeHObcwxMPA5tzEYc4NosVDcZiDy15c7sTlr1U4wgFXuMHEAV62hj0=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClb9iji4eCwU0M8dWrQOAW
hjiEvoPDnLsY4mBjVt3DYc4DosVX4zAHl7243InLX2E4wgFXuMHEAWmLfrU=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSDAwNF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAOh86gg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSN/Y3XOBjLfKbjyZ+YT/D
Bfc4y691aOIH9jOgAJg4SAtW9fY4zLfH4R57YzC4TKT4BRziB3CIMzDgUL8f
h/k4xG/sxxWeAFy/S9E=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalEeJXFsfWrjz91f5GZ8yi
PTd22MPEE/omcJsbfbX/DwbH4eJmt803y9p9sb+Zc/9M2Y8L9qjmf7ZvsHTS
u3PiClx83gnVU929H+39+8u+LtW7jqb+A5S+ARc/mrcl+8WTN/YBaOoZwepe
YZg/xXPCzCPNz+1vobnH4fG9FxNnP7VnAes7AReP2OHCujbjif0DNP9C3PHE
nqtrno9lZZcNuvpzEPX70c3/AwkfuPgkqHuuQ9wDF/8HVvfSvg7ifrj4Iah/
/SD+hYtDwv09LHzg4nOh4RmAVf0n+yY082HxdQvNPbD4ZYOEz3709PAOzb+w
9AMJn1l7AI9sOyY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlH9jDxMNCQeArhvjqVSDw
CUMcwv+AQ/0rHOY/xWHOA5LFIeZdxSF+FIc56OHwwD4Eon4/dvGrGOJQmqB4
KKp/4eKrUMNnP47wRFP/CYf5X3GY84Nk8TCs/oWJo4fPDxzh+QMWnvbYxdHj
C5EOAQjl6hE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClP9jDxFeBAaZ4WCgIPMQQ
h/Af4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRu6OABeAn8R
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalP9jDxEPBAFN89SoQwBSH
8L/jMAdTHGzMKkxxCP8H0eKrcZiDy15c7sTlrzAc4YAr3NDFATkhgE0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClH9iji68CA0zxsFAQeIgh
DqEf4TAHUxxsTOhjHOY8IVo8DIc5uOzF5U5c/lqNIxxwhRtMHAClU38R
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClv9mji4eCAab46lUggCkO
ob/jMAdTHGzMKkxxCP2DaPHVOMzBZS8ud+LyVxiOcMAVbjBxAHaSgE0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSH+wbLvCxFvnNh/JfwMUZ
LrjHWX6tg/LfIMRRwAcc6j/hMP8LXBzVPd/g4sZgcJmA+Bcc4p9wiH/AIf4G
h/gLHOJPcLgfIQ4AAUxMQw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDST+wbLvCxFvnNRxN/Yc9w
wT3O8msdmvgbKA0DHxDyWNV/wmH+F3vs7vlmbwwGl4kU/4JD/BMO8Q84xN/g
EH+BQ/wJDvc/sQcAAmxMQw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalP9jDxK8sjq1defqr/bwT
qqe6ez/CxRP6JnCbG32Fqv8MFze7bb5Z1u4LnEY1/zNcH0wcZi7MHlT1H+Du
gokfzduS/eLJGwz1jGB1rzDMn+I5YeaR5ucY7nF4fO/FxNlPMdwfscOFdW3G
Ewz/QtQ9wQgfmPpjUHehmw9zF0x8EtQ9MHfBxP/9B4GX9o5QfTDxQ1BzI6H2
wMTByv+/h7sLJj4X6u4IrOo/2dujmQ8Ll8lo7oGFI8xd6OnhEJp/YfEEcxcA
++0vTw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGnYeJhoSDwFUN89SoQ+IQh
DuF/wKH+FQ7zn+Iw5wHJ4jD3oovD3IvdnA841L/CYf5THOY8ICgeiuJfhPgq
lPBBN+cDDvWfcJj/FYc5P0gWD8Xq3x9w92I3Bz08f8Ddi9189PhCpEMAb0nv
xw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClGRxg4qvAAFM8LBQEHmKI
Q7iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHAAQwnEQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalGRxg4qFggCm+ehUIYIpD
uN9xmIMpDjZmFaY4hPuDaPHVOMzBZS8ud+LyVxiOcMAVbujiAOvSckw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClf9iji4eCAab46lUggCkO
oX/iMAdTHGzMKkxxCP2LaPHVOMzBZS8ud+LyVxiOcMAVbjBxAIp+gGs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClmR3QxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYWAhWhyXObjsxeVOXP7CFQ64wg0mDgC9aHMX
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSDA4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAs/0+Qg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSv+wbLvCxFvnNRxP/Y89w
wT3O8msdmvg/KA0DMHEGB+zqGR2wm8/kgN09zA7GYHCZSHEmHOKMOMQZcIj/
s8cu/geH+C97XOEJAP+uRU0=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalGRxg4lcWx9auPP3V3v+J
0NOjxxDiCX0TuM2NvkLUNzDCxc1um2+WtftiP/vt7Jt88kwOqOZ/tjdwP9Eq
PRMhPu+E6qnu3o/2ry6u23flKbr6D1CaGS5+NG9L9osnbzDUM4LVvcIwf4rn
hJlHmp9juMfh8b0XE2c/xXB/xA4X1rUZTzD8C3HHE4zwgalPNr9lWlL0zx6r
+Qx/4eKToO45pXLC59HB33Dxf/9B4KX9gsL8LyfO/oKLH4L6VydmUVOYCUIc
rPz/e6j5CPG50PDErv4Thvmw+EJ3Dyx+Ifr+2KOnh0Q0/6KnHwDjkyCL
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlWRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniEHuYMMTB1oQy4jCHAUMc4q6/9tjN/4UhDgs/
QuKhKP5FiK9CCR90cz7gUP8Jh/lfcZjzg2TxVVj9+wNqD3r4/MARnj9whD/M
fPT4QqRDAGT94sE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClORxg4qvAAFM8LBQEHmKI
Q/iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHABgcnGI
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalORxg4qFggCm+ehUIYIpD
+N9xmIMpDjZmFaY4hP+DaPHVOMzBZS8ud+LyVxiOcMAVbujiADuRcsQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClWRzQxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYWAlWhyXObjsxeVOXP7CFQ64wg0mDgDHXnMm
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACluR3QxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYeAhWhyXObjsxeVOXP7CFQ64wg0mDgANJ3OP
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSHA4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAA7w+ug==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSrA4NF/hYi/zmo4mzOTBc
cI+z/FqHJs7uwIACYOIcONRz4jCfywG7e7gdjMHgMpHiXDjEOXGIc+AQZ8ch
zoZDnBWH+1kdABX+Pts=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalORxg4lcWx9auPP3V3v+J
0NOjxxDiCX0TuM2NvkLUN3DCxc1um2+WtftiP/vt7Jt88lwOqOZ/tjdwP9Eq
PRMhPu+E6qnu3o/2ry6u23flKbr6D1CaGy5+NG9L9osnbzDUM4LVvcIwf4rn
hJlHmp9juMfh8b0XE2c/xXB/xA4X1rUZTzD8C3HHE4zwganfJP1WysqSHYf5
bHDxSVD3pAqlqH18wAoX//cfBF7aX9hhXvUkDSF+COpfMb1AR20phDhY+f/3
UPcgxOdCwxO7+k8Y5sPiC909qPHLhpEeNqL5Fz39AAC4oAwF
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGleRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniEHu4MMTB1oRy4jCHA4c5bBjiEPey4jCHhaB4
KIp/EeKrUMIH3ZwPONR/wmH+Vxzm/CBZPBSrf3/gCJ8fOMLzB47w/wH1B3p8
IdIhAG3V1ts=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClBRxg4qvAAFM8LBQEHmKI
Q/iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHACwInIA
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalBRxg4qFggCm+ehUIYIpD
+N9xmIMpDjZmFaY4hP+DaPHVOMzBZS8ud+LyVxiOcMAVbujiAItBczw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+ACleRzQxVevAgItTPFQMMAU
B1MNOMxZhcOcqzjMYeAlWhyXObjsxeVOXP7CFQ64wg0mDgAXHXOe
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AChGwQd0MVDQWAqpvjqVSCA
KQ6mDuAw5yoOc17hMIdBiGhxXObgsheXO3H5C1c44Ao3mDgAywl36Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSAg4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAU2w/Mg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDSvA4NF/hYi/zmo4nzOTBc
cI+z/FqHJs7vwIACYOIC2NU3COAwX9ABq3saBB2MweAyceIMuNQL4FCPS5wf
hzgfDnFe7O4HigMAzg1BSw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalBRxg4lcWx9auPP3VXr2o
81NSMkI8oW8Ct7nRV4j6Awhxs9vmm2Xtvtif+3Y2p51f0AHV/M/2M5SfHOr1
QYjPO6F6qrv3o/3XjPD4V0Xo6j9A6AaE+NG8LdkvnrzBUM8IVvgKw/wpnhNm
Hml+juEeh8f3Xkyc/RTD/RE7XFjXZjyx10DzL8Q9TzDCB6Z+k/RbKStLfuzm
N/DBxSdB3ZMqlKL28QEvXPzffxB4aX9hh3nVkzSE+CGof8X0Ah21pRDiYOX/
30PdgxCfCw1P7Oo/YZgPiy9096DEL5L7YelhI5p/0dMPAGdLC4I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlhRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniYONCBTHEIfYL4DAHUxying9DHOJeXhzm8BAU
D0XxL0J8FUr4oJvzAYf6TzjM/4rDnB8ki4di9e8PHOHzA0d4/sAR/j9wxBci
HQIAZBjXpg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYweAClRRxg4qvAAFM8LBQEHmKI
Q/iPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg1dHADX+nI8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AalRRxg4qFggCm+ehUIYIpD
+N9xmIMpDjZmFaY4hP+DaPHVOMzBZS8ud+LyVxiOcMAVbujiALMZc3g=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AClhRzQxUNBQBRTfPUqINDC
FAdTDjjMCcVhThYOcxqIF8dlDi57cbkTl79whQOucIOJAwA+5nJ2
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AChG0Qd0MVDQWAqpvjqVSCA
KQ6mDuAw5yoOc17hMIdBjGhxXObgsheXO3H5C1c44Ao3mDgA8uF4JQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYPIHSIg4NF/hYi/zmQ/kv4OIM
F9zjLL/WQflvEOIo4AMO9Z9wmP8FLo7qnm9wcWMwuExA/AsO8U84xD/gEH+D
Q/wFDvEnONyPEAcAe0Q/bg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYfIDQDUIODRf4WIv85qOKMwg7
MFxwj7P8WoemHiiOAmDqRXCoF8FhvqgDdveIOhiDwWXixBlwqRfBoR6HONBf
2NXjEAeGG67wBABoXUQM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw+AalRRxg4lcWx9auPP3VXr2o
81NSMkI8oW8Ct7nRV4j6Awhxs9vmm2Xtvtif+3Y2p51f1AHV/M/2M5SfHOr1
QYjPO6F6qrv3o/3XjPD4V0Xo6j9A6AaE+NG8LdkvnrzBUM8IVvgKw/wpnhNm
Hml+juEeh8f3Xkyc/RTD/RE7XFjXZjyx10DzL8Q9TzDCB6b+Zm8Z79w5wtjN
d0CIT4K6x5jTaHLFByG4+L//IPDSPuOOtG3RZoT4Iah/uaevWCDaixAHK///
Hho+CPG50PDErv4Thvmw+DJCcw9K/CK5H5YebqD5Fz39AAAqZQ4w
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw+AGlxRxg4mGhIPAVQ3z1KhD4
hCEO4X/Aof4VDvOf4jDnAcniYONCRTHEIfaL4DAHUxxijjAOc4RwmENYPBTF
vwjxVSjhg27OBxzqP+Ew/ysOc36QLI7dvz9whM8PHOH5A0f4/8ARX4h0CAAG
I9gr
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlRQ7AxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAbvAexY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAhAptwg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQYgfQxVevAoJXohjioSBw
FVMcTB7AFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRtMHAAn5nEl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcACTDUIH0MVXrwKCLEzxUDDA
FIeQOMzRwmGOKA5zGIgXx2UOLntxuROXv3CFA65wg4kDAHbabHU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSIgcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPADSwP/g=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOIDJBtEDDRf4WIv85qOKM4ge
YLjgHmf5tQ5NvcgBBlQAVS+CQ70wDvOFD2B3j9ABYzC4TJw40Bzs6nGIA92J
XT0OcWA4YFcvisP9ogcAntc9jg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0CIHYOKvLq7bd+Upk8PN
3jLeuXOE4eIG7idapWcyQdQ7IMRnv519k0+eycGI02hyxQehAyjmNzA6ZNyR
ti3ajBD3fyL09OgxBgfu6SsWiPaiqQeaDNGHEE82v2VaUvTPHrv6v/bo5p9S
OeHz6OBve3T3LCjM/3Li7C97dPfrxCxqCjP5ZX8Dzb8Q86HqkcIHpl69qPNT
UrIIdvMPIMRPQt1z9tvZnHZ+Ubj4fzD4Yz9D+cmhXh+EeCLUv18zwuNfFYni
CB+EuB80PNHVg42vZ3RANx8WX+fQ3IMSvwcw04MGmn/R0w8AqhMK6g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0EIHYOKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0Mcwv9BsjjEPExxiHuFcZgjgsMcTHGIOaI4zBEj
KL4Kxb9iaOH5F4c5sPBEV8+IIb4KJb7QzWEhWRy7f1kcsIcPzBxMcezhDzMH
Pb4Q6RAAG53ZJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlBQ7AxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAZPoeto=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAXDJthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQQgfQxVevAoJXghjioSBw
FVMcTB7AFAebswqHOVNxmNNAvDguc3DZi8uduPyFKxxwhRtMHAAADnDp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQvAfQxUNB4CoPhvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQBTZNtHg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSAgcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAAzYP7w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOIDJBsEDDRf4WIv85qOKMwge
YLjgHmf5tQ5NvcABBlQAVS+AXT0DPw7z+Q5gdQ8D7wFjMLhMpDgfDnF+HOIC
2MUbcIgDwwG7ekHs7geKAwAGGDtO
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AIHYOKvLq7bd+Upk8NG
6bdSVpb8cHED9xOt0jOZIOob+ODis9/Ovsknz+SQKpSi9vEB7wEU8xsYHS7s
MK96koYQ938i9PToMQYHMb1AR20pNPUMDFD3IMSTzW+ZlhT9s8eu/q89uvmn
VE74PDr42x7dPQsK87+cOPvLHt39OjGLmsJMftmj+xdiPlQ9UvjA1KsXdX5K
ShbAbv4BhPhJqHvOfjub084vCBf/DwZ/7GcoPznU64MQT4T692tGePyrIkHs
4dOAEPeDhie6erDx9YwO6ObD4uscmntQ4vcAZnrQQPMvevoBAFNrCDw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0DwHYOKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0Mcwv9BsjjEXbwY4hB7+HCYI4BDPaY4xHxBHOYI
ERRfheJfIbTw/IvDHFh4oqtnxBBfhRJf6OawkCyO3b8sDtjDB2YOpjj28Gdx
CMMaX4h0CABl4tig
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlOQ7AxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAUQ4emI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwADIJtDg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQPAfQxUNB4Co3hvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQBQ51tDw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQrAfQxUNB4CoLhvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQB/dRspg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSHAcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAL0ZP0Q=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAo7gMNF/hYi/zmo4lzHWC4
4B5n+bUOTZzzAAMqgIpz4FDPjsN8tgPY3cN6wBgMLhMpzoZDnB2HOAcOcU4c
4lw4xLlxuJ/7AABMfjhg
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0BwHYOKvLq7bd+Upk8NG
6bdSVpbscHED9xOt0jOZIOob2ODis9/Ovsknz+SQKpSi9vEB6wEU8xsYHS7s
MK96koYQ938i9PToMQYHMb1AR20pNPUMDFD3IMSTzW+ZlhT9s8eu/q89uvmn
VE74PDr42x7dPQsK87+cOPvLHt39OjGLmsJMftmj+xdiPlQ9UvjA1PuB/cGB
w3xOuPhJqHsg4cQFF/8PBn+g4YoQT4T6FxIPXDjChxsu7gcNT3T1YOPrGR3Q
zYfFF7p7UOOXEyM9+KP5Fz39AAAwIQi/
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0gdg4qtXgQAThngoGDBi
iEP4DBjiYWD1f+2xm/8LQxzC/0GyOMRdrBjiEHvYcJjDgcMcTgxxsDGruHCY
w0NQfBWKf3nQwvMvDnNg4YmunhFDfBVKfKGbw0Ky+Gqs/mVxwB4+MHPQwxNm
Dnr4sziEYY0vRDoEAFvv19U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlGQ7AxEPBAFN89SoQwBSH
cH/iMAdTHGzMKkxxCPcX0eKrcZiDy15c7sTlrzAc4YAr3NDFAfR5eeo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAvMNslg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQLAfQxUNB4CozhvjqVSCA
KQ4mGzDFweaE4jBHC4c5DMSL4zIHl7243InLX7jCAVe4wcQB895slw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQv/aji69eBQI/McRDwQBT
HEJhikPM+YEhHgY2B1McQhEvHorDHFz24nInLn+twhEOuMINJg4AwkZ57A==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSDAcaLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAG1pPsw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAo5gMNF/hYi/zmo4kzHWC4
4B5n+bUOTZzxAAMqgIoz4FD/bz928//sx+6eX/uNweAykeJ/cIj/wyHOcAC7
OCMOcSYc4swHcIUnADREPdY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AwHYOKvLq7bd+Upk0OS
+S3TkqJ/+2HiBu4nWqVnMkHV/4WLz347+yafPJPDKZUTPo8O/t6PYn4Do8OC
wvwvJ87+gov7PxF6evQYg4NOzKKmMJNfqOoZGKDmI8STIe6wx67+rz26+VB3
2KO7B6rOHt39UHPt0f0LdQfMXQfQ1ftB/HEAq/kNjHDxk1D3QMMJLv4fDP7A
whUungj1LzQeDmAPH2a4ONQdDujqwcbXMzqgmw+LL3T3oMQvkvth6cEfzb/o
6QcAXVcXTQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0D/2w8RXrwIBJgzxUDBg
xBCH8BkwxMPA6v/aYzf/F4Y4lE+y+CqIeRjiEPf+xWEOwwHs6hkxxCHmM2GI
Q8OPoPgqFP8ixENRwgfdHFh4oqtnxBBfhRJf6OawkCy+Gqt/WRywhw/MHPTw
ZHEIwxr+MPPR4wuRDgFUXuO7
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlP+yHiYeCAab46lUggCkO
4f/EYQ6mONiYVZjiEP4vosVX4zAHl7243InLX2E4wgFXuKGLAwBByIfr
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPAQrQ4LnNw2YvLnbj8hSsccIUbujgAChJ6lw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQP/aji69eBQLfMcRDwQBT
HEJhikPM+YYhHgY2B1McQhEvHorDHFz24nInLn+twhEOuMINJg4Arlp5zg==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQT/aji4eFgsBjDPFVYPAI
QxxCYYpDzHmIIb4abM4DHOYQL74Khzm47MXlTlz+CsURDrjCDSYOAN0feJQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSH/Y3XOBjLfKbD+X/gYsz
XHCPs/xaB+X/Q4ijAgfs6hnh4qjmM8HFUd3DDBc3BoPLBMSZcIgz4hBnwCGO
8Beq+B8c4ohwwxWeALqpTM0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECob/sbLvCxFvnNRxP/sp/h
gnuc5dc6NPFP+xlQAVT8Aw71b3CY/2I/dvc82W8MBpeJFH+BQ/wNDvEPOMQ/
4RD/gkP8Gw73f9sPADkERdQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0B/2w8RfXVy378pTJoej
eVuyXzx5Axc3cD/RKj2TCar+FVx89tvZN/nkmRymeE6YeaT5+X4U8xsYHRwe
33sxcfZTuLj/E6GnR48xOETscGFdm/EEVT0DA9R8hHiy+S3TkqJ/9tjV/7VH
N/+UygmfRwd/209Gc8+CwvwvJ87+sv8PBi/h4joxi5rCTH7ZH0HzL8T8X/bo
4QNTP/eE6qnu3o8Y5kPUf4aLn4S6x+y2+WZZuy9wcYg7/tgn9E3gNjf6ChdP
hPr3yuLY2pWnv+IIn29wcT9oeKKrBxtfz+iAbj4svtDdA4tfRjT3w9LDfDT/
oqcfAEPDJhM=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0A/2w8RXrwIBJgzxUDBg
xBCH8BkwxMPA6v/aYzf/F4Y4hP+DZHGIu55iiIOtWfUKhzkfcKj/hMP8rzjM
+UFQfBWKf3+ghedfHObAwhNdPSOG+CqU+EI3h4Vk8TCs/mVxWI01fGDmoIcn
TD16+MPMR48vRDoEAMe08ME=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlEeKhYIApvnoVCGCKQ3g/
cZiDKQ42ZhWmOIT3i2jx1TjMwWUvLnfi8lcYjnDAFW7o4gCG0G6q
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHZggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGFiIFsdlDi57cbkTl79whQOucEMXBwBPGmFW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQD/aji69eBQL3MMRDweAu
hjiEuoPDnFsY4mFgc27iMOcG0eKhOMzBZS8ud+Ly1yoc4YAr3GDiAKFfeDw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQN+zRxUPB4CaG+OpVIHAL
QxxC3cFhzl0McbAxq+7hMOcB0eKrcZiDy15c7sTlrzAc4YAr3GDiAKw0cLQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSDAwNF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAP+xM4w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECoG/sbLvCxFvnNRxO/sJ/h
gnuc5dc6NPED+xlQgQOchV29PQ7z7XG4x94YDC4TKX4Bh/gBHOIMDDjU78dh
Pg7xG/txhScAn2g90A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHZggAKY+KuL6/ZdecrkcKMz
ZtGeGzvsYeIG7idapWcyOfwHg+Nw8dlvZ9/kk2dyuJlz/0zZjwv2KOY3MDo0
WDrp3TlxBS7u/0To6dFjDA7+/WVfl+pdR1XPwAB1zw24eLL5LdOSon/2AVjV
/7VHN/+UygmfRwd/299Cc8+CwvwvJ87+smcB6zsBF9eJWdQUZvLL/gGafyHm
/7Ln6prnY1nZZYOu/hxE/X508/9AwgcufhLqnusQ98DFIeH4x74O4n64eCLU
v34Q/+7HET5wcT9oeAagqQcbX8/o0IRmPiy+bqG5Bxa/bJDw2Y+eHt6h+ReW
fiDhM2sPAD3RK2I=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0A/sYeKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0Mcwv9BsjjEnqs4xI/iMAc9HH7Yh0DU78cufhVD
HOoeguKrUP27HzU8/+IwBx6e+3GEP5r5TBjiaPFLtHgYVv/CxNHDB2YOZroK
wRr+MHH0+EKkQwB8Ed0L
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlP9jDxEPBAFN89SoQwBSH
8H/iMAdTHGzMKkxxCP8X0eKrcZiDy15c7sTlrzAc4YAr3NDFAU39gGs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgIVoclzm47MXlTlz+whUOuMINXRwAFkdzFw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQD+zRxVeBAaZ4WCgIPMQQ
h1CPcJiDKQ42JvQxDnOeEC0ehsMcXPbicicuf63GEQ64wg0mDgDn/HEQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQ3+zRxUPBAFN89SoQwBSH
UN9xmIMpDjZmFaY4hPpBtPhqHObgsheXO3H5KwxHOOAKN5g4ALk7ckw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSH+wbLvCxFvnNh/L/wMUZ
LrjHWX6tg/L/IcRRgQN29YxwcVTzmeDiqO5hhosbg8FlAuJMOMQZcYgz4BBH
+AtV/A8OcUS44QpPAMbeRU0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECoJ/YNF/hYi/zmo4m/sGe4
4B5n+bUOTfwNjM+AKv4Bh/pPOMz/Yo/dPd/sjcHgMpHiX3CIf8Ih/gGH+Bsc
4i9wiD/B4f4n9gBFFT5C
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0B/sYeKvLq7bd+Upk8O8
E6qnuns/wsUN3E+0Ss9kgqr/DBef/Xb2TT55Jgez2+abZe2+2KOY38DokNA3
gdvc6Ctc3P+J0NOjxxgcriyOrV15+iuqegYGqPnf4OLJ5rdMS4r+2WNX/9ce
3fxTKid8Hh38bY/ungWF+V9OnP1lj+5+nZhFTWEmv+zR/QtRB1P/AUP9sbwt
2S+evMEwnxGs/hVc/CTUPVM8J8w80vwcLv4fDP7YOz6+92Li7Kdw8USofyN3
uLCuzXiCI3wQ4n7Q8IxAUw82vp7RwR7NfFh8TUZzDyx+/4E1vsRID4fQ/AtL
PxB/vLcHAKpSH4s=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0D/sYeKrV4EAE4Z4KBgw
YohD+AwY4mFg9X/tsZv/C0McxidVHGLPVwxxiD2fcJjzAYf6VzjMf4rDnAcE
xVeh+PcBWnj+xWEOLDzR1TNiiK9CiS90c1hIFg/F6l8Wh1VYwwdmDnp4wtSj
hz/MfPT4QqRDAOJ14sE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlGRxg4qFggCm+ehUIYIpD
uD9xmIMpDjZmFaY4hPuLaPHVOMzBZS8ud+LyVxiOcMAVbujiAAC9cmo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AyPhlFg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQP+zRxUPBAFN89SoQwBSH
UD9xmIMpDjZmFaY4hPpFtPhqHObgsheXO3H5KwxHOOAKN5g4AM0ncmo=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQzA7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMLAQLY7LHFz24nInLn/hCgdc4QYTBwAAIGUW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSDA4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAHmeN0w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOECoX/YNF/hYi/zmo4n/sWe4
4B5n+bUOTfwfjM+AKg6ksapndMBuPpMDdvcwOxiDwWUixZlwiDPiEGfAIf7P
Hrv4Hxziv+xxhScAQmY3TA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AwOMPFXF9ftu/KUycH/
idDTo8cQ4gbuJ1qlZzJB1DcwwsVnv519k0+eyQFGo5gPVAfTBxOHmQuzB9U9
DA4wd8HEk81vmZYU/bPHrv6vPbr5p1RO+Dw6+Nse3T0LCvO/nDj7yx7d/Tox
i5rCTH7Zo/sXYv4vuLvQ1cPchdV8oLtg4ieh7oG5Cyb+Hwz+wPXBxBOh5sLs
wR4+CHE/qLvR1YONr2d0QDcfFi7o7oGFI8xd6OkhEc2/6OkHAJH4EMc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0TDx1atAgAlDPBQMGDHE
IXwGDPEwsPq/9tjN/4UhDuH/IFkc5l50cZh7sZvDgCEOcy92839hiMNoQuKr
UPyLEA9FCR90c2Dhia6eEUN8FUp8oZvDQrL4Kqz+ZXEIxRo+MHPQwxOmHj38
YeajxxciHQIA2CnVuw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlORxg4qFggCm+ehUIYIpD
+D9xmIMpDjZmFaY4hP+LaPHVOMzBZS8ud+LyVxiOcMAVbujiAFBtcuI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AGLdljg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQLA7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMLASLY7LHFz24nInLn/hCgdc4QYTBwAKFmUl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQ3A7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMPAQLY7LHFz24nInLn/hCgdc4QYTBwBP0GWO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSHA4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAMlON8Q=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAoVoeGC3ysRX7z0cTZHBgu
uMdZfq1DE2eH0nAA5XPgUM+Jw3wuB+zu4XYwBoPLRIpz4RDnxCHOgUOcHYc4
Gw5xVhzuZ3UAAFinMNo=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0BwOMPFXF9ftu/KUycH/
idDTo8cQ4gbuJ1qlZzJB1DdwwsVnv519k0+eyQFCczmgmN/A6ADRhxCHmMvg
ALEHTT0DA9Q93HDxZPNbpiVF/+yxq/9rj27+KZUTPo8O/rZHd8+CwvwvJ87+
skd3v07MoqYwk1/26P6FmA9VjxQ+MPWbpN9KWVmy4zCfDS5+EuqeVKEUtY8P
WOHi/8Hgj/2FHeZVT9IQ4olQ/4rpBTpqS7HiCB+EuB80PNHVg42vZ3RANx8W
X+juQY1fNoz0sBHNv+jpBwBnBfwy
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0DwOMPHVq0CACUM8FAwY
McQhfAYM8TCw+r/22M3/hSEO4f8gWRxiHheGOMS9nDjM4cBhDhuGOMQfrDjM
YSEovgrFvyxo4fkXhzmw8ERXz4ghvgolvtDNYSFZPBSrf1kcsIcPzBz08ISZ
gx7+LA6rsMYXIh0CAOEBydU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlBRxg4qFggCm+ehUIYIpD
+D9xmIMpDjZmFaY4hP+LaPHVOMzBZS8ud+LyVxiOcMAVbujiAKAdc1o=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AaGdmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQPA7o4qtXAYEWpngoGGCK
g8kGHOaswmHOVRzmMPASLY7LHFz24nInLn/hCgdc4QYTBwBZxmWd
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcACTDYIO6OKhIDAVU3z1KhDA
FAeTB3CYcxWHOa9wmMMgRLQ4LnNw2YvLnbj8hSsccIUbTBwADcFp6A==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSAg4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnABkNODw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOEAoXoeGC3ysRX7z0cT5HBgu
uMdZfq1DE+eH0nAA5QtgV98ggMN8QQes7mkQdDAGg8vEiTPgUi+AQz0ucX4c
4nw4xHmxux8oDgAQxTNK
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0AIOMPFXF9ftu/KUyUG9
qPNTUjJC3MD9RKv0TCaI+gMI8dlvZ9/kk2dyOPftbE47v6ADivkNjA4zlJ8c
6vVBiPs/EXp69BiDw9eM8PhXRWjqGRgg5jcgxJPNb5mWFP2zx67+rz26+adU
Tvg8OvjbHt09Cwrzv5w4+8se3f06MYuawkx+2Wug+RdiPlQ9A6b6TdJvpaws
+bGb38AHFz8JdU+qUIraxwe8cPH/YPDH/sIO86onaQjxRKh/xfQCHbWleLGH
DwNC3A8anujqwcbXMzqgmw+LL3T3oMQvkvth6WEjmn/R0w8AFbD7rw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0EIOMPHVq0CACUM8FAwY
McQhfAYM8TCw+r/22M3/hSEO4f8gWRziLkEMcYg9AjjMwRSHqOfDEIf4gxeH
OTwExVeh+JcHLTz/4jAHFp7o6hkxxFehxBe6OSwki4di9S+LA/bwgZmDHp4w
9Zji2OMLkQ4B10TKoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw+AGlRRxg4qFggCm+ehUIYIpD
+D9xmIMpDjZmFaY4hP+LaPHVOMzBZS8ud+LyVxiOcMAVbujiAMf1c5Y=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHaA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AkD9mQg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcIBQQg7o4qEgIIopvnoVEGhh
ikNIHOaE4jAnC4c5DcSL4zIHl7243InLX7jCAVe4wcQBgY9kdQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYIcACTDaIO6OKhIDAVU3z1KhDA
FAeTB3CYcxWHOa9wmMMgRrQ4LnNw2YvLnbj8hSsccIUbTBwANZlqJA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY/ILSIg4NF/hYi/zmQ/l/4OIM
F9zjLL/WQfn/EOKowAG7eka4OKr5THBxVPcww8WNweAyAXEmHOKMOMQZcIgj
/IUq/geHOCLccIUnAEDlOHg=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMEOIDJBiGHhgt8rEV+81HFGYQd
GC64x1l+rUNTLwyVhwMoXwSHehEc5os6YHePqIMxGFwmTpwBl3oRHOpxiAP9
hV09DnFguOEKTwCrBjYL
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYwYHaA0CIOMPFXF9ftu/KUyUG9
qPNTUjJC3MD9RKv0TCaI+gMI8dlvZ9/kk2dyOPftbE47v6gDivkNjA4zlJ8c
6vVBiPs/EXp69BiDw9eM8PhXRWjqGRgg5jcgxJPNb5mWFP2zx67+rz26+adU
Tvg8OvjbHt09Cwrzv5w4+8se3f06MYuawkx+2Wug+RdiPlQ9A6b6m71lvHPn
CGM33wEhfhLqHmNOo8kVH4Tg4v/B4I99xh1p26LNCPFEqH+5p69YINorhCN8
EOJ+0PBEVw82vp7RAd18WHwZobkHJX6R3A9LDzfQ/IuefgDYu/5d
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwYHGA0GIOMPHVq0CACUM8FAwY
McQhfAYM8TCw+r/22M3/hSEO4f8gWRziLlEMcYg9IjjMwRSHmCOMwxwhHOYQ
Fl+F4l8htPD8i8McWHiiq2fEEF+FEl/o5rCQLI7dvywO2MMHZg56eMLMwRTH
Hl+IdAgAeU/LJQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAjnht0Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwA13puOg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0GIH0MVXrwKCV6IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwAe1ZxnQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HAAUw1CB9DFV68CgixM8VAw
wBQHUw44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnCDiQMAykps7Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaJEDDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwAXYTmG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDiAqQbRAw0X+FiL/OajijOI
HmC44B5n+bUOTb3IAQYUAFMvgkO9MA7zhQ9gd4/QAWMwuEycONAc7OpxiAPd
iV09DnFgOGBXL4rD/aIHAPJHPgY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0CIHYOKvLq7bd+Upl8PN
3jLeuXOE4eIG7idapWdyQdQ7IMRnv519k0+ey8GI02hyxQehAyjmN3A6ZNyR
ti3ajBD3fyL09OgxDgfu6SsWiPaiqWfggJjfgBDfKP1WysqSHbv6BjYM81OF
UtQ+PmDFcM+FHeZVT9JYMdwvphfoqC3F6nADzb8Q97BihA9MvXpR56ekZBHs
5h9AiKdA3XP229mcdn5RDPfPUH5yqNdHFMO/XzPC418VieIIH4S4HzQ80dX/
B4F6TgzzYfF1Ds09KPF7ADM9aKD5Fz39AADcpfZU
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0EIHYOKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh9mCKQ9wrjMMcERzmYIpDzBHFYY4YQfFQ
FP+K4QgfdHM4cJjDiSG+CiW+0M3hIVkcu395cIQPzBxMcezhz4MjvhDpEABi
zs0/
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAZqBtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAr6Jt/g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0EIH0MVXrwKCV4IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwAU35xYQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0LwH0MVDQeAqD4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAaEDbZY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaIEDDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwDvejlK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDiAqQbBAw0X+FiL/OajijMI
HmC44B5n+bUOTb3AAQYUAFMvgF09Az8O8/kOYHUPA+8BYzC4TKQ4Hw5xfhzi
AtjFG3CIA8MBu3pB7O4HigMAWYg7xg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AIHYOKvLq7bd+Upl8NG
6bdSVpb8cHED9xOt0jO5IOob+ODis9/Ovsknz+WQKpSi9vEB7wEU8xs4HS7s
MK96koYQ938i9PToMQ4HMb1AR20pNPUMHFD3IMQh7mDHrr6BDcN8iDtYMdwD
UceK4X6IuawY/oW4gxUjfGDq1Ys6PyUlC2A3/wBCPAXqnrPfzua08wtiuH+G
8pNDvT6CGP79mhEe/6pIEHv4NCDE/aDhia7+PwjUc2KYD4uvc2juQYnfA5jp
QQPNv+jpBwCF/fOm
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0gdg4qtXgQAXhngoGHBi
iEP4HDjMYcMQDwObw4rDHBaSxSHu4sUQh9jPh8McARzqMcUh5gviMEeIoHgo
in+FcIQPujkcOMzhxBBfhRJf6ObwkCyO3b88OMIHZg6mOPbw53EIwxpfiHQI
AK0TzLo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAFvBtHQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAX/Jthg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0DwH0MVDQeAqN4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAZcNbYc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0KwH0MVDQeAqC4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAVFTbR4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaI4DDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwCfyjjS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaO4DDRf4WIv85qOJcx1g
uOAeZ/m1Dk2c8wADCoCJc+BQz47DfLYD2N3DesAYDC4TKc6GQ5wdhzgHDnFO
HOJcOMS5cbif+wAAn+442A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0BwHYOKvLq7bd+Upl8NG
6bdSVpbscHED9xOt0jO5IOob2ODis9/Ovsknz+WQKpSi9vEB6wEU8xs4HS7s
MK96koYQ938i9PToMQ4HMb1AR20pNPUMHFD3IMSh7sCuvoENw3yoOzDcA1WH
4X6ouRj+hboDI3xg6v0g/sBhPidcPAXqHmg4YbgfGq4Y/oXGA47w4YaLQ92B
of4/CNRzYpgPiy9096DGLydGevBH8y96+gEAYrP0KQ==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0CwHYOKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh7mLFEIfaj8McDhzmcGKIr4KEBw5zeAiK
h6L4lwdH+KCbw4HDHE4M8VUo8YVuDg/J4qux+pcHR/jAzEEPTx4c4c/jEIY1
vhDpEACjIMvv
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAxzFspQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAEEJtDg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0CwH0MVDQeAqM4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAUddbQ8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0L/2o4uvXgUCPzHEQ8EA
UxxCY4pDzPmBIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOABXFemQ=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaIYDDRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwBQGjha
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaOYDDRf4WIv85qOJMx1g
uOAeZ/m1Dk2c8QADCoCJM+BQ/28/dvP/7Mfunl/7jcHgMpHif3CI/8MhznAA
uzgjDnEmHOLMB3CFJwCHtD5O
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AwHYOKvLq7bd+Upl0OS
+S3TkqJ/+2HiBu4nWqVnckHV/4WLz347+yafPJfDKZUTPo8O/t6PYn4Dp8OC
wvwvJ87+gov7PxF6evQYh4NOzKKmMJNfqOoZOKDmI8Q3Sr+VsrJkx66+gQ3D
/FShFLWPD1gx3HNhh3nVkzRWDPeL6QU6akuxYvgXog6mHhE+MPV+YH8gxFHM
b2CEi6dA3QMJJ6YD6O6HhCtCHOZfSDygqYeHDzNc3A8anujq/4NAPSeG+bD4
QncPSvwiuR+WHvzR/IuefgCP6QLG
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0D/2w8RXrwIBLgzxUDDg
xBCH8DlwmMOGIR4GNocVhzksJIuDrVn1C0Mc4t6/OMxhOIBdPSOGOMR8Jgxx
KE1QPBTFvwhx1PBBN4cDhzmcGOKrUOIL3RweksVXY/UvD47wgZmDHp48DmFY
wx9mPnp8IdIhAJuP19U=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPASrQ4LnNw2YvLnbj8hSsccIUbujgAFIB6pg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPAQ7Q4LnNw2YvLnbj8hSsccIUbujgAXYJ7Dw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0D/2o4uvXgUC3zHEQ8EA
UxxCY4pDzPmGIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAAHZekY=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0E/2o4uHhYLAYwzxVWDw
CEMcQmOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg0mDgAwnnkM

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpA6A/7Gy7wsRb5zYeKs8HF
GS64x1l+rYOKsyPEUQAHDvWcOMzngoujuocbLm4MBpcJiHPhEOfEIc6BQ5wd
hzgbDnFEuOEKTwCdWkZb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6G/7Gy7wsRb5zUcT/7Kf
4YJ7nOXXOjTxT/sZUABM/AMO9W9wmP9iP3b3PNlvDAaXiRR/gUP8DQ7xDzjE
P+EQ/4JD/BsO93/bDwCMdEZM
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0B/2w8RfXVy378pTLoej
eVuyXzx5Axc3cD/RKj2TC6r+FVx89tvZN/nkuRymeE6YeaT5+X4U8xs4HRwe
33sxcfZTuLj/E6GnR49xOETscGFdm/EEVT0DB9R8hPhG6bdSVpbs2NU3sGGY
nyqUovbxAavDZDT3XNhhXvUkjdXhPxi8hIuL6QU6akuxOhxB8y/EHawY4QNT
P/eE6qnu3o8Y5kPUf4aLp0DdY3bbfLOs3RcM9yf0TeA2N/qK4d8ri2NrV57+
iiN8vsHF/aDhia4e7M16TgzzYfGF7h5Y/DKiuR+WHuaj+Rc9/QAAdlURjA==

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0A/2w8RXrwIBLgzxUDDg
xBCH8DlwmMOGIR4GNocVhzksJItD3PUUQxxs/apXOMz5gEP9Jxzmf8Vhzg+C
4qEo/v2BI3zQzeHAYQ4nhvgqlPhCN4eHZPEwrP7lcViNNXxg5qCHJ0w9evjD
zEePL0Q6BAAO9OTb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHFggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGFiJFsdlDi57cbkTl79whQOucEMXBwBZiGFl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HZggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGHiIFsdlDi57cbkTl79whQOucEMXBwCiimHO
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0A/2o4uvXgUC9zDEQ8Hg
LoY4hL6Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9xg4gD0z3i0

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0Dfs0cVDweAmhvjqVSBw
C0McQt/BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9xg4gD/pHEs

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDowQEHDBT7WIr/5UHE2uDjD
Bfc4y691UHF2hDgK4MChnhOH+VxwcVT3cMPFjcHgMgFxLhzinDjEOXCIs+MQ
Z8Mhjgg3XOEJAOJiLRo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6Bv7Gy7wsRb5zUcTv7Cf
4YJ7nOXXOjTxA/sZUABMHKQFq3p7HObb43CPvTEYXCZS/AIO8QM4xBkYcKjf
j8N8HOI39uMKTwDy2D5I
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HZggAKY+KuL6/ZdecrlcKMz
ZtGeGzvsYeIG7idapWdyOfwHg+Nw8dlvZ9/kk+dyuJlz/0zZjwv2KOY3cDo0
WDrp3TlxBS7u/0To6dFjHA7+/WVfl+pdR1XPwAF1zw24+Ebpt1JWluwOAdjU
N7BhmJ8qlKL28QGrwy0091zYYV71JI3VgQWs8QRcXEwv0FFbitXhAZp/Ie5g
deDqmudjWdllg67+HET9fnTz/0DCBy6eAnXPdYh79qO7vw7i/v3o/vWD+Hc/
jvCBi/tBwzMATT3YGfWcDk1o5sPi6xaae2DxywYJn/3o6eEdmn9h6QcSPrP2
AABwYxbb
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0A/sYeKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh5l3FIX4Uhzno4cDiEAJRvx+7+FUMcah7
CIqHovp3P47w2Y8jPPfjCH+4+CrU+NqPI36JFg/D6l+YOHr4wMzBTFchWMMf
Jo4eX4h0CADDQtEl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGFgJVoclzm47MXlTlz+whUOuMINXRwAILVzJg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgIVoclzm47MXlTlz+whUOuMINXRwAabdzjw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0A/s0cVXgQGmeFgoCDzE
EIfQj3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINJg4AO3txiA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0N/s0cVDwQBTfPUqEMAU
h9DfcZiDKQ42ZhWmOIT+QbT4ahzm4LIXlztx+SsMRzjgCjeYOAAMunLE
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpA6A/2DRf4WIv85kPF2eDi
DBfc4yy/1kHF2RHiKIADh3pOHOZzwcVR3cMNFzcGg8sExLlwiHPiEOfAIc6O
Q5wNhzgi3HCFJwCpjz7b
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6Cf2DRf4WIv85qOJv7Bn
uOAeZ/m1Dk38DZQPAzDxDzjUf8Jh/hd77O75Zm8MBpeJFP+CQ/wTDvEPOMTf
4BB/gUP8CQ73P7EHAJiFPro=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0B/sYeKvLq7bd+Upl8O8
E6qnuns/wsUN3E+0Ss/kgqr/DBef/Xb2TT55Lgez2+abZe2+2KOY38DpkNA3
gdvc6Ctc3P+J0NOjxzgcriyOrV15+iuqegYOqPnf4OIbpd9KWVmyY1ffwIZh
fqpQitrHB6wY7rmww7zqSRorhvvF9AIdtaVYMfwLUQdT/wFD/bG8LdkvnrzB
MJ8RrP4VXDwF6p4pnhNmHml+juF+x8f3Xkyc/RTDv5E7XFjXZjzBET4IcT9o
eEagqf8PAvWcDvZo5sPiazKae2Dx+w+s8SVGejiE5l9Y+gEr///eHgDc5AsE

       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0D/sYeKrV4EAF4Z4KBhw
YohD+Bw4zGHDEA8Dm8OKwxwWksUh5n3FEIfY/wmHOR9wqH+Fw/ynOMx5QFA8
FMW/D3CED7o5HDjM4cQQX4USX+jm8JAsHorVvzwOq7CGD8wc9PCEqUcPf5j5
6PGFSIcAKbXW2w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4A02ZlJQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AHHdljg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0D/s0cVDwQBTfPUqEMAU
h9A/cZiDKQ42ZhWmOIT+RbT4ahzm4LIXlztx+SsMRzjgCjeYOAAgpnLi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0MwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOEGEwcAU5Bljg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaAaHhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwBcTzDa
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhA6F/2DRf4WIv85qOJ/7Fn
uOAeZ/m1Dk38H5QPAzBxBgfs6hkdsJvP5IDdPcwOxmBwmUhxJhzijDjEGXCI
/7PHLv4Hh/gve1zhCQCV1jfE
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AwOMPFXF9ftu/KUy8H/
idDTo8cQ4gbuJ1qlZ3JB1DcwwsVnv519k0+eywFCMzmgmN/A6QDRhxCHmMvh
ALEHTT0DB9Q9zHDxjdJvpaws2bGrb2DDMD9VKEXt4wNWDPdc2GFe9SSNFcP9
YnqBjtpSrBj+hbiDFSN8YOqTzW+ZlhT9s8dqPsNfuHgK1D2nVE74PDr42x7d
/QsK87+cOPvLHt2/OjGLmsJMftljDx+EuB80PNHV/weBek4M82Hxhe4eWPyC
9f3/Y4+eHhLR/IuefgDEivwx
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0CwOMPHVq0CAC0M8FAw4
McQhfA4c5rBhiIeBzWHFYQ4LyeIQe5gwxCHuZcRhDgOGOMRdf+2xm/8LQxxC
/yAoHoriX4Q4avigm8OBwxxODPFVKPGFbg4PyeKrsPqXBxqe6OEDMwc9PHlw
hD/MfPT4QqRDAB9pydU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AIyVlnQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4AbCdmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0CwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAXYZlnQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0NwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOEGEwcAo0BmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaA6Hhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwCr/zFS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaFaHhgt8rEV+89HE2RwY
LrjHWX6tQxNnh9IwABPnwKGeE4f5XA7Y3cPtYAwGl4kU58IhzolDnAOHODsO
cTYc4qw43M/qAACsFzFS
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0BwOMPFXF9ftu/KUy8H/
idDTo8cQ4gbuJ1qlZ3JB1DdwwsVnv519k0+eywFGo5gPVAfTBxOHmQuzB9U9
HA4wd8HEN0q/lbKyZMeuvoENw/xUoRS1jw9YMdxzYYd51ZM0Vgz3i+kFOmpL
sWL4F+IOVozwganfBHUXdvPZ4OIpUPfA3IXufpg+dP/C7MEePghxP6i70dX/
B4F6TgzzYeGC7h7U+GXDSA8b0fyLnn4AmZfnqw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0TDx1atAgAtDPBQMODHE
IXwOHOawYYiHgc1hxWEOC8niMPeii8Pci90cDhzmsGGIw9yL3RwWguKhKP5l
wRE+6OZw4DCHE0N8FUp8oZvDQ7J4KFb/8uAIH5g56OHJgyP8eRxWYY0vRDoE
AChBve8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4ActVmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4Au9dmfg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0DwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOEGEwcArTZmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HAAUw2CDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIES0OC5zcNmLy524/IUrHHCFG0wcAGExamA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaAGHhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwD7rzHK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDhAaF6Hhgt8rEV+89HE+RwY
LrjHWX6tQxPnh9IwABMXwK6+QQCH+YIOWN3TIOhgDAaXiRNnwKVeAId6XOL8
OMT5cIjzYnc/UBwAZDUzwg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0AIOMPFXF9ftu/KUy0G9
qPNTUjJC3MD9RKv0TC6I+gMI8dlvZ9/kk+dyOPftbE47v6ADivkNnA4zlJ8c
6vVBiPs/EXp69BiHw9eM8PhXRWjqGTgg5jcgxDdKv5WysmTHrr6BDcP8VKEU
tY8PWDHcc2GHedWTNFYM94vpBTpqS7E6aKD5F+IeVozwganfBHYXP3bzG/jg
4ilQ90DcxYvhfog+Xgz/QuzhxR4+DAhxP2h4oqv/DwL1nBjmw+IL3T0o8Yvk
flh62IjmX/T0AwBIQuco
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0EIOMPHVq0CAC0M8FAw4
McQhfA4c5rBhiIeBzWHFYQ4LyeIQdwliiEPsF8BhDqY4RD0fhjjEvbw4zOEh
KB6K4l8eHOGDbg4HDnM4McRXocQXujk8JIuHYvUvD47wgZmDHp48OMKfB0d8
IdIhAB6Evro=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwYHGA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOGGLg4Amq1mUQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HaA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOGGLg4A469mug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HCA0EIO6OKhICCKKb56FRBo
YYqDKQcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7jBxAHU/2Tt
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HAAUw2iDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIEa0OC5zcNmLy524/IUrHHCFG0wcAIkJapw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYsDpAaBGHhgt8rEV+86HibHBx
hgvucZZf66Di7AhxFMCBQz0nDvO54OKo7uGGixuDwWUC4lw4xDlxiHPgEGfH
Ic6GQxwRbrjCEwAjljIG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYcDiAqQYhh4YLfKxFfvNRxRmE
HRguuMdZfq1DUy8MlYcBmHoRHOpFcJgv6oDdPaIOxmBwmThxBlzqRXCoxyEO
9Bd29TjEgeGGKzwB/nY2gw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYw4HaA0CIOMPFXF9ftu/KUy0G9
qPNTUjJC3MD9RKv0TC6I+gMI8dlvZ9/kk+dyOPftbE47v6gDivkNnA4zlJ8c
6vVBiPs/EXp69BiHw9eM8PhXRWjqGTgg5jcgxDdKv5WysmTHrr6BDcP8VKEU
tY8PWDHcc2GHedWTNFYM94vpBTpqS7E6aKD5F+IeVozwgam/2VvGO3eOMHbz
HRDiKVD3GHMaTa74IITh/ow70rZFm4Uw/Ms9fcUC0V4hHOGDEPeDhie6+v8g
UM+JYT4svozQ3IMSv0juh6WHG2j+RU8/AAtc6dY=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYw4HGA0GIOMPHVq0CAC0M8FAw4
McQhfA4c5rBhiIeBzWHFYQ4LyeIQd4liiEPsF8FhDqY4xBxhHOYI4TCHsHgo
in+FcIQPujkcOMzhxBBfhRJf6ObwkCyO3b88OMIHZg56ePLgCH8eHPGFSIcA
wIC/Pw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0CIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwA4ehuSQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMIgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQC4O3KU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0GIH0MVXrwKCV6IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwAzsZyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHAAUw1CB9DFV68CgixM8VAw
wBQHUw44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnCDiQMAHcltZQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaJEDDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScA4vA79g==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDiAqQbRAw0X+FiL/OajijOI
HmC44B5n+bUOTb3IAQYUAFMvgkO9MA7zhQ9gd4/QAWMwuEycONAc7OpxiAPd
iV09DnFgOGBXL4rD/aIHAEXGPn4=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMIgdg4l8zwuNfFQk6
3Owt4507RxguPkP5yaFeH6h6B4T4uW9nc9r5BR2MOI0mV3wQOoBi/gEBh4w7
0rZFmxHi6kWdn5KSBRy4p69YINqLpp5BAGJ+A0J8o/RbKStLfuzqG/gwzE8V
SlH7+IAXwz0XdphXPUnjxXC/mF6go7YUr8MNNP9C3MOLET4w9RB/iGA3/wBC
PAXqnrPgcBLFcD8kXEUx/AuJB1Ec4SOKEZ5Y1QPDH918WHydQ3MPSvwewEwP
Gmj+RU8/ALDm8VU=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0gdg4qFgIIghvnoVCAhg
iEP4mOIQ9XwY4mFg83lxmMNDsjjEHkxxiD+EcZgjgsMcTHGIOaI4zBEjKB6K
4l8xHOGDbo4ADvWY4qjxhW6OEMni2P0rhCN8YOZgimMPfyEc8YVIhwB2Yc4K

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AIHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAuhBuDQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMAgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQCQY3JY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0EIH0MVXrwKCV4IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwApu5x2Q==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0LwH0MVDQeAqD4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAfRzbg4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaIEDDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAuxg7ug==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDiAqQbBAw0X+FiL/OajijMI
HmC44B5n+bUOTb3AAQYUAFMvgF09Az8O8/kOYHUPA+8BYzC4TKQ4Hw5xfhzi
AtjFG3CIA8MBu3pB7O4HigMArPg8Pg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMAgdg4l8zwuNfFQk6
bJR+K2VlyQ8Xn6H85FCvD1R9Ax9c/Ny3sznt/IIOqUIpah8f8B5AMf+AgMOF
HeZVT9IQ4upFnZ+SkgUcxPQCHbWl0NQzCEDdgxCHugO7+gY+DPOh7sBwD1Qd
hvuh5mL4F+oOjPCBqYf6A7v5BxDiKVD3nIWEE4b7oeGK4V9oPGAPnwZBjPDE
qh4Y/ujmw+LrHJp7UOL3AGZ60EDzL3r6AQBaPu6n
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0DwHYOKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xL28GOJQ+3GYI4BDPaY4NDxwmCNEUDwU
xb9COMIH3RwBHOoxxVHjC90cIZLFsftXCEf4wMzBFMce/kIOYVjjC5EOAcCm
zYU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0BwHYOKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAamBtlQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMHAdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQBAs3Hg
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0DwH0MVDQeAqN4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAep9bf8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0KwH0MVDQeAqC4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAaTDbZY=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaI4DDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAa2g7Qg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaO4DDRf4WIv85qOJcx1g
uOAeZ/m1Dk2c8wADCoCJc+BQz47DfLYD2N3DesAYDC4TKc6GQ5wdhzgHDnFO
HOJcOMS5cbif+wAA8145UA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMHAdg4l8zwuNfFQk6
bJR+K2VlyQ4Xn6H85FCvD1R9Axtc/Ny3sznt/IIOqUIpah8fsB5AMf+AgMOF
HeZVT9IQ4upFnZ+SkgUcxPQCHbWl0NQzCEDdgxCHuIMfu/oGPgzzIe7gxXAP
RB0vhvsh5vJi+BfiDl6M8IGp93si9PToMQ4c5nPCxVOg7pn9dvZNPnkuDPcb
uJ9olZ7JheHfVxfX7bvylAtH+HBjhCdW9cDwRzcfFl/o7kGNX06M9OCP5l/0
9AMANvTvKg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0CwHYOKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xL2sGOIQ+9lwmMOBwxxODHGwMau4cJjD
Q1A8FMW/PDjCB90cARzqMcVR4wvdHCGSxVdj9a8QjvCBmYMenkI4wl/IIQxr
fCHSIQC2s8y6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AwHYOKrVwGBFqZ4KBhg
ioN5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAGrBtHQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0YICAAzDxUBCYiim+ehUI
YIpDeDjMuYrDnFc4zGEQIloclzm47MXlTlz+whUOuMINXRwA8PRxaA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0CwH0MVDQeAqM4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAZrNbYc=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0L/2o4uvXgUCPzHEQ8EA
UxxCY4pDzPmBIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAGk1etw=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaIYDDRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAG7g6yg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaOYDDRf4WIv85qOJMx1g
uOAeZ/m1Dk2c8QADCoCJM+BQ/28/dvP/7Mfunl/7jcHgMpHif3CI/8MhznAA
uzgjDnEmHOLMB3CFJwDbJD7G
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0YICAAzDxrxnh8a+KBB2S
zG+ZlhT92w8Tn6H85FCvD0z9X7j4uW9nc9r5BR1OqZzweXTw934U8w8IOCwo
zP9y4uwvuLh6UeenpGQBB52YRU1hJr9Q1TMIQM1HiG+UfitlZcmPXX0DH4b5
qUIpah8f8GK458IO86onabwY7hfTC3TUluLF8C9EHUw9Inxg6v2eCD09egwh
jmJ+AyNcPAXqntlvZ9/kk2c6gO5+A/cTrdIzEeIw/766uG7flado6uHhw3wA
PTyxqgeGP7r5sPhCdw9K/CK5H5Ye/NH8i55+AGQq/bg=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0D/2w8RDwUAQQ3z1KhAQ
wBCH8DHFIer5MMTDwObz4jCHh2RxsDWrfmGIQ/zxF4c5DAewq2fEEIeYz4Qh
DqFZCIqHovgXIY4aPujmCOBQjymOGl/o5giRLL4aq3+FcIQPzBz08BRyCMMa
/jDz0eMLkQ4BryLYoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0B/2w8RXrwICLUzxUDDA
FAdzG3CYswqHOVdxmMPAS7Q4LnNw2YvLnbj8hSsccIUbujgAZ/B7Hg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMH/bDxENBYCqm+OpV
IIApDuYewGHOVRzmvMJhDoMQ0eK4zMFlLy534vIXrnDAFW7o4gA+Q39p
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0D/2o4uvXgUC3zHEQ8EA
UxxCY4pDzPmGIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAFVJer4=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0E/2o4uHhYLAYwzxVWDw
CEMcQmOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg0mDgCEDnmE

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpA6A/7Gy7wsRb5zYeK88HF
GS64x1l+rYOK8yPEUYAAdvUNCHFU8wXh4ijuaUCIG4PBZfziDLjUC+BQj0uc
H4c4Hw5xRLjhCk8AaPhIyw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6G/7Gy7wsRb5zUcT/7Kf
4YJ7nOXXOjTxT/sZUABM/AMO9W9wmP9iP3b3PNlvDAaXiRR/gUP8DQ7xDzjE
P+EQ/4JD/BsO93/bDwDf5EbE
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMH/bDxL9mhMe/KhJ0
OJq3JfvFkzdw8RnKTw71+sDUv4KLn/t2NqedX9BhiueEmUean+9HMf+AgIPD
43svJs5+ChdXL+r8lJQs4BCxw4V1bcYTVPUMAlDzEeIbpd9KWVnyY1ffwIdh
fqpQitrHB7wOk9Hcc2GHedWTNF6H/2DwEi4uphfoqC3F63AEzb8Qd/BihA9M
/dwTqqe6ez9imA9R/xkungJ1j9lt882ydl8w3J/QN4Hb3Ogrhn+vLI6tXXn6
K47w+YYRnljVA8Mf3XxYfKG7Bxa/jGjuh6WH+Wj+RU8/AEqWDI0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0A/2w8RDwUAQQ3z1KhAQ
wBCH8DHFIer5MMTDwObz4jCHh2RxiHufYoiDrV/1Coc5H3Co/4TD/K84zPlB
UDwUxb8/cIQPujkCONRjiqPGF7o5QiSLh2H1r5DDaqzhAzMHPTxh6tHDH2Y+
enwh0iEAIoflpg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HFggAKY+OpVQKCFKR4KBpji
YE4DDnNW4TDnKg5zGHiJFsdlDi57cbkTl79whQOucEMXBwCs+GHd
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0YIACmHgoCEzFFF+9CgQw
xcGcAzjMuYrDnFc4zGEQIloclzm47MXlTlz+whUOuMINXRwAg0tmKA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0A/2o4uvXgUC9zDEQ8Hg
LoY4hL6Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9xg4gBITnks

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0Dfs0cVDweAmhvjqVSBw
C0McQt/BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9xg4gBTI3Gk

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DowQEHDBT7WIr/5UHE+uDjD
Bfc4y691UHF+hDgKEMCuvgEhjmq+IFwcxT0NCHFjMLiMX5wBl3oBHOpxifPj
EOfDIY4IN1zhCQCuAC+K
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6Bv7Gy7wsRb5zUcTv7Cf
4YJ7nOXXOjTxA/sZUABMHKQFq3p7HObb43CPvTEYXCZS/AIO8QM4xBkYcKjf
j8N8HOI39uMKTwBGVz7A
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0YIACmPjXjPD4V0WCDjc6
YxbtubHDHiY+Q/nJoV4fQYf/YHAcLn7u29mcdn5Bh5s598+U/bhgj2L+AQGH
BksnvTsnrsDF1Ys6PyUlCzj495d9Xap3HVU9gwDUPTfg4hul30pZWfI7BGBT
38CHYX6qUIraxwe8DrfQ3HNhh3nVkzReBxawxhNwcTG9QEdtKV6HB2j+hbiD
14Gra56PZWWXDbr6cxD1+9HN/wMJH7h4CtQ91yHu2Y/u/jqI+/ej+9cP4t/9
OMJnP3p4BmBTDwz/JjTzYfF1C809sPhlg4TPfvT08A7Nv7D0AwmfWXsARKQR
3A==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0A/sYeKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xLyrOMSP4jAHPRx4HEIg6vdjF7+KIQ51
D0HxUFT/7scRPvtxhOd+HOG/H0d87ccRv0SLh2H1L0wcPXxg5mCmqxCs4Q8T
R48vRDoEANbV0fA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0B/sYeKrVwGBFqZ4KBhg
ioO5DTjMWYXDnKs4zGHgJVoclzm47MXlTlz+whUOuMINXRwAdCVzng==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMH+xh4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GIaHFc5uCyF5c7cfkLVzjgCjd0cQBKeHfp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0A/s0cVXgQGmeFgoCDzE
EIfQj3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINJg4AjutyAA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0N/s0cVDwQBTfPUqEMAU
h9DfcZiDKQ42ZhWmOIT+QbT4ahzm4LIXlztx+SsMRzjgCjeYOABgKnM8
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpA6A/2DRf4WIv85kPF+eDi
DBfc4yy/1kHF+RHiKEAAu/oGhDiq+YJwcRT3NCDEjcHgMn5xBlzqBXCoxyXO
j0OcD4c4ItxwhScAdS1BSw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6Cf2DRf4WIv85qOJv7Bn
uOAeZ/m1Dk38DZQPAzDxDzjUf8Jh/hd77O75Zm8MBpeJFP+CQ/wTDvEPOMTf
4BB/gUP8CQ73P7EHAOv1PzI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMH+xh4l8zwuNfFQk6
zDuheqq79yNcfIbyk0O9PjD1n+Hi576dzWnnF3Qwu22+Wdbuiz2K+QcEHBL6
JnCbG32Fi6sXdX5KShZwuLI4tnbl6a+o6hkEoOZ/g4tvlH4rZWXJj119Ax+G
+alCKWofH/BiuOfCDvOqJ2m8GO4X0wt01JbixfAvRB1M/QcM9cfytmS/ePIG
w3xGsPpXcPEUqHumeE6YeaT5OYb7HR/fezFx9lMM/0bucGFdm/EER/g8wQjP
CGzqgeFvj2Y+LL4mo7kHFr///oPAS4z0cAjNv7D0A1b+/709ALElBgU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0D/sYeKhYCCIIb56FQgI
YIhD+JjiEPV8GOJhYPN5cZjDQ7I4xLyvGOIQ+z/hMOcDDvWvcJj/FIc5DwiK
h6L49wGO8EE3RwCHekxx1PhCN0eIZPFQrP4VcliFNXxg5qCHJ0w9evjDzEeP
L0Q6BAA9SNem
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AwOMPHVq4BAC1M8FAww
xcG8BhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AJuVlnQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0YIAAB5h4KAhMxRRfvQoE
MMXBvAM4zLmKw5xXOMxhECJaHJc5uOzF5U5c/sIVDrjCDV0cAP0paeg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0D/s0cVDwQBTfPUqEMAU
h9A/cZiDKQ42ZhWmOIT+RbT4ahzm4LIXlztx+SsMRzjgCjeYOAB0FnNa
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0MwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOEGEwcApwBmBg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaAaHhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMAJ+0zSg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhA6F/2DRf4WIv85qOJ/7Fn
uOAeZ/m1Dk38H5QPAzBxBgfs6hkdsJvP5IDdPcwOxmBwmUhxJhzijDjEGXCI
/7PHLv4Hh/gve1zhCQDpRjg8
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0YIAAB5j414zw+FdFgg7+
T4SeHj2GEJ+h/ORQrw9UfQMjXPzct7M57fyCDrPfzr7JJ8/kgGL+AQEHA/cT
rdIzEeLqRZ2fkpIFHF5dXLfvylM09QwCUPcww8U3Sr+VsrLkx66+gQ/D/FSh
FLWPD3gx3HNhh3nVkzReDPeL6QU6akvxYvgX4g5ejPCBqU82v2VaUvTPHqv5
DH/h4ilQ95xSOeHz6OBve3T3LyjM/3Li7C97dP/qxCxqCjP5ZY89fBDisPDE
qh4Y/ujmw+IL3T2w+P0PBn/s0dNDIpp/0dMPAJjL9zI=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0CwOMPFQMBDEEF+9CgQE
MMQhfExxiHo+DPEwsPm8OMzhIVkcYg8ThjjEH4w4zGHAEIe46689dvN/YYhD
6B8ExUNR/IsQRw0fdHMEcKjHFEeNL3RzhEgWX4XVv0LQ8EQPH5g56OEphCP8
YeajxxciHQIAMvzKoA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0BwOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AdpVmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMHA4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRu6OABM6Gpg
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0CwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAsPZmFQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0NwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOEGEwcA9rBmfg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaA6Hhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMAd50zwg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaFaHhgt8rEV+89HE2RwY
LrjHWX6tQxNnh9IwABPnwKGeE4f5XA7Y3cPtYAwGl4kU58IhzolDnAOHODsO
cTYc4qw43M/qAAD/hzHK
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMHA4w8a8Z4fGvigQd
/J8IPT16DCE+Q/nJoV4fqPoGTrj4uW9nc9r5BR1mv519k0+eywHF/AMCDgbu
J1qlZyLE1Ys6PyUlCzi8urhu35WnaOoZBKDu4YaLb5R+K2VlyY9dfQMfhvmp
QilqHx/wYrjnwg7zqidpvBjuF9MLdNSW4sXwL8QdvBjhA1O/Cewudhzms8HF
U6DugbiLFcP9EH2sGP6F2MOKI3xYMcITq3pg+KObD4svdPegxi8bRnrYiOZf
9PQDAG3Y4qw=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0DwOMPFQMBDEEF+9CgQE
MMQhfExxiHo+DPEwsPm8OMzhIVkcYg8XhjjEH5w4zOHAYQ4bhjjEvaw4zGEh
KB6K4l8WHOGDbo4ADvWY4qjxhW6OEMnioVj9K4QjfGDmoIenEI7wF3JYhTW+
EOkQADvUvro=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0AIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4AxkVmjQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMAg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRu6OACcmGrY
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0DwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAALVmjQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHAAUw2CDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIES0OC5zcNmLy524/IUrHHCFG0wcALShatg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaAGHhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMAx000Og==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDhAaF6Hhgt8rEV+89HE+RwY
LrjHWX6tQxPnh9IwABMXwK6+QQCH+YIOWN3TIOhgDAaXiRNnwKVeAId6XOL8
OMT5cIjzYnc/UBwAt6U0Og==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMAg4w8a8Z4fGvigQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5BBxiNYj5QHUwfTBxmLsweFPVA
d8DcBRPfKP1WysqSH7v6Bj4M81OFUtQ+PuDFcM+FHeZVT9J4MdwvphfoqC3F
66CB5l+Ie3gxwgemfhPUXVjNB7oLJp4CdQ/MXejuh+lD9y/MHqzhw8CLEZ5Y
1QP9iW4+LFzQ3YMSv0juh4X7RjT/oqcfAByD4ik=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0TDxUDAQxBBfvQoEBDDE
IXxMcYh6PgzxMLD5vDjM4SFZHOZedHGYe7GbgykOcy+6OMy92M3hISgeiuJf
Hhzhg26OAA71mOKo8YVujhDJ4qFY/SuEI3xg5qCHpxCO8BfCEV+IdAgAMhe/
hQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYw4HGA0CIOMPHVq4BAC1M8FAww
xcHcBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOGGLg4A7h1myQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB0ANMMIg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBEtDguc3DZi8uduPyFKxxwhRu6OADEcGsU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHCA0EIO6OKhICCKKb56FRBo
YYqDKQcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7jBxAEofmVl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHAAUw2iDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIEa0OC5zcNmLy524/IUrHHCFG0wcANx5axQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMY8DpAaBGHhgt8rEV+86HifHBx
hgvucZZf66Di/AhxFCCAXX0DQhzVfEG4OIp7GhDixmBwGb84Ay71AjjU4xLn
xyHOh0McEW64whMA7yU0dg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYCDiAqQYhh4YLfKxFfvNRxRmE
HRguuMdZfq1DUy8MlYcBmHoRHOpFcJgv6oDdPaIOxmBwmThxBlzqRXCoxyEO
9Bd29TjEgeGGKzwBUfU2+w==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB0ANMMIg4w8a8Z4fGvigQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5BBwgt6oBi/gEBB4g+hDjEXAEH
iD1o6hkEIOY3IMQ3Sr+VsrLkx66+gQ/D/FShFLWPD3gx3HNhh3nVkzReDPeL
6QU6akvxOmig+RfiHl6M8IGpv9lbxjt3jjB28x0Q4ilQ9xhzGk2u+CCE4f6M
O9K2RZuFMPzLPX3FAtFeIRzhI4QRnljVA8Mf3XxYfBmhuQclfpHcD0sPN9D8
i55+AN+O5Nc=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHKA0GIOMPFQMBDEEF+9CgQE
MMQhfExxiHo+DPEwsPm8OMzhIVkc4l5RDHGI/SI4zMEUh5gjjMMcIRzmEBYP
RfGvEI7wQTdHAId6THHU+EI3R4hkcez+FcIRPjBz0MNTCEf4C+GIL0Q6BADU
E8AK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0CIHYOKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAAIBtIQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMIgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQDh83LQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0GIH0MVXrwKCV6IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwA+H5yUQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHEAUw1CB9DFV68CgixM8VAw
wBQHUw44zNHCYY4oDnMYiBfHZQ4ue3G5E5e/cIUDrnCDiQMAR4FtoQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGkQMNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJAJNIPrc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDiAqQbRAw0X+FiL/OajijOI
HmC44B5n+bUOTb3IAQYUAFMvgkO9MA7zhQ9gd4/QAWMwuEycONAc7OpxiAPd
iV09DnFgOGBXL4rD/aIHAG9+Pro=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMIgdg4l8zwuNfFYk6
3Owt4507RxguPkP5yaFeH6h6B4T4uW9nc9r5RR2MOI0mV3wQOoBi/gERh4w7
0rZFmxHi6kWdn5KSRRy4p69YINqLpp5BBGJ+A0Ic6g7s6h2EMcyHugPDPVB1
GO6HmutwA82/UHdghA9MPdQf2M0/IILhnrOQcMJwPzRc4eJQdzhA4wFH+Ihi
hCdW9cDwRzcfFl/n0NyDEr8HMNODBpp/0dMPANQ39AQ=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0EIHYOKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sWh5mGIQ+3HYY4IDnMwxaHhgcMcMYLiqP4VwxE+
6OaI4DAHUxw1vtDNESNZHLt/xXCED8wcTHHs4S+GI74Q6RAAKlzOjw==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AIHYOKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcA2Jls5Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMAgdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQC6G3KU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0EIH0MVXrwKCV4IY4qEg
cBVTHEwdwBQHm7MKhzlTcZjTQLw4LnNw2YvLnbj8hSsccIUbTBwA0KZyFQ==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0LwH0MVDQeAqD4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAR46bko=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGgQMNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJAGtwPns=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDiAqQbBAw0X+FiL/OajijMI
HmC44B5n+bUOTb3AAQYUAFMvgF09Az8O8/kOYHUPA+8BYzC4TKQ4Hw5xfhzi
AtjFG3CIA8MBu3pB7O4HigMA1rA8eg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMAgdg4l8zwuNfFYk6
bJR+K2VlyQ8Xn6H85FCvD1R9Ax9c/Ny3sznt/KIOqUIpah8f8B5AMf+AiMOF
HeZVT9IQ4upFnZ+SkkUcxPQCHbWl0NQziEDdgxC/2VvGO3eOMHb1DsIY5htx
Gk2u+CCE4Z6MO9K2RZuFMNzPPX3FAtFeIQz/QtQJYYQPTD3EHwLYzT8ggOGe
s+BwEsRwPyRcEeI3oP6FxIMg9vBpEMQIT6zqgeGPbj4svs6huQclfg9gpgcN
NP+ipx8AfY/xVg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0DwHYOKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sUh9vBiiEPs4cNhjgAO9ZjiEPMFcZgjRFAc1b9C
OMIH3RwRHOZgiqPGF7o5YiSLY/evGI7wgZmDKY49/MUcwrDGFyIdAgB0oc4K

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0BwHYOKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAiOlsbQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMHAdg4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQBqa3Ic
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0DwH0MVDQeAqN4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEARREbjs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0KwH0MVDQeAqC4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAc57bdI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGjgMNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJABvAPgM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaO4DDRf4WIv85qOJcx1g
uOAeZ/m1Dk2c8wADCoCJc+BQz47DfLYD2N3DesAYDC4TKc6GQ5wdhzgHDnFO
HOJcOMS5cbif+wAAHSU5jA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMHAdg4l8zwuNfFYk6
bJR+K2VlyQ4Xn6H85FCvD1R9Axtc/Ny3sznt/KIOqUIpah8fsB5AMf+AiMOF
HeZVT9IQ4upFnZ+SkkUcxPQCHbWl0NQziEDdgxC/2VvGO3eOMHb1DsIY5htx
Gk2u+CCE4Z6MO9K2RZuFMNzPPX3FAtFeIQz/QtQJYYQPTL3fE6GnR49x4DCf
E8M9s9/Ovsknz4XhfgP3E63SMxHiN6D+fXVx3b4rT7lwhA83RnhiVQ8Mf3Tz
YfGF7h7U+OXESA/+aP5FTz8AWkXx2Q==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0CwHYOKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sUh9rBiiEPsYcNhDgcOczgxxMHGrOLCYQ4PQXFU
//LgCB90c0RwmIMpjhpf6OaIkSy+Gqt/xXCED8wc9PAUwxH+Yg5hWOMLkQ4B
aq7NPw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AwHYOKhICCKKb56FRBo
YYqDeQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAOTlr9Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1YICAAzDxUBCYiim+ehUI
YIpDeDjMuYrDnFc4zGEQI1oclzm47MXlTlz+whUOuMINXRwAGrtxpA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0CwH0MVDQeAqM4b46lUg
gCkOphowxcHmhOIwRwuHOQzEi+MyB5e9uNyJy1+4wgFXuMHEAcSFbcM=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0L/2o4uvXgUCPzHEQ8EA
UxxCY4pDzPmBIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAJLtexg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5MEDAgYYLfKxFfvMh4gzC
cHGGC+5xll/roOqRxFGACA71CHFU80Xh4qjuQYgbg8Fl/OIMuNSL4FCPQxzJ
X6jqcYgjhRuu8AQAzAE9iw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaOYDDRf4WIv85qOJMx1g
uOAeZ/m1Dk2c8QADCoCJM+BQ/28/dvP/7Mfunl/7jcHgMpHif3CI/8MhznAA
uzgjDnEmHOLMB3CFJwAE6z8C
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1YICAAzDxrxnh8a+KRB2S
zG+ZlhT92w8Tn6H85FCvD0z9X7j4uW9nc9r5RR1OqZzweXTw934U8w+IOCwo
zP9y4uwvuLh6UeenpGQRB52YRU1hJr9Q1TOIQM1HiN/sLeOdO0cYu3oHYQzz
jTiNJld8EMJwT8YdaduizUIY7ueevmKBaK8Qhn8h4QNTjwgfmHq/J0JPjx5D
iKOY38B4AN09s9/Ovsknz3QA3f0G7idapWcixG9A/fvq4rp9V56iqYeHD/MB
9PDEqh4Y/ujmw+IL3T0o8Yvkflh68EfzL3r6AQCHewB2
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0D/2w8RDwUAUQ3z1KhAQ
wRCH8DHFIeYI4zBHCIc5pIuDjVv1C0McYv9fHOYwHMCunhFDHGI+E4Y4hGYh
KI7qX4Q4avigmyOCwxxMcdT4QjdHjGTx1Vj9K4YjfGDmoIenmEMY1vCHmY8e
X4h0CABjHdkl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0B/2w8RDQUAUU3z1KiDQ
whQHcx1wmBOKw5wsHOY0EC+Oyxxc9uJyJy5/4QoHXOGGLg4Ahnl59g==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMH/bDxENBYCqm+OpV
IIApDuYewGHOVRzmvMJhDoMY0eK4zMFlLy534vIXrnDAFW7o4gBn+3+l
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0D/2o4uvXgUC3zHEQ8EA
UxxCY4pDzPmGIR4GNgdTHEITLx6Kwxxc9uJyJy5/rcIRDrjCDSYOAH8Bevo=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0E/2o4uHhYLAYwzxVWDw
CEMcQmOKQ8x5iCG+GmzOAxzmEC++Coc5uOzF5U5c/grFEQ64wg0mDgCtxnnA

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGmGD/sbLvCxFvnNh4gz
CMPFGS64x1l+rYOqRxJHASI41CPEUc0XhYujugchbgwGl/GLM+BSL4JDPQ5x
JH+hqschjhRuuMITABlQS4w=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6G/7Gy7wsRb5zUcT/7Kf
4YJ7nOXXOjTxT/sZUABM/AMO9W9wmP9iP3b3PNlvDAaXiRR/gUP8DQ7xDzjE
P+EQ/4JD/BsO93/bDwAJq0cA
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMH/bDxL9mhMe/KhJ1
OJq3JfvFkzdw8RnKTw71+sDUv4KLn/t2NqedX9RhiueEmUean+9HMf+AiIPD
43svJs5+ChdXL+r8lJQs4hCxw4V1bcYTVPUMIlDzEeI3e8t4584Rxq7eQRjD
fCNOo8kVH4QcJqO5J+OOtG3RZiGH/2DwEi7OPX3FAtFeIYcjaP6FhI8QRvjA
1M89oXqqu/cjhvkQ9Z8x3GN223yzrN0XDPcn9E3gNjf6Che/AfXvlcWxtStP
f8URPt8wwhOremD4o5sPiy9098DilxHN/bD0MB/Nv+jpBwBt5w88
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0A/2w8RDwUAUQ3z1KhAQ
wRCH8DHFIeYI4zBHCIc5pItD7HmKIQ62ZtUrHOZ8wKH+Ew7zv+Iw5wdBcVT/
/sARPujmiOAwB1McNb7QzREjWTwMq3/FHFZjDR+YOejhCVOPHv4w89HjC5EO
AdZz5is=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHJggAKYeCgIiGKKr14FBFqY
4mCOAw5zQnGYk4XDnAbixXGZg8teXO7E5S9c4YAr3NDFAcuBYLU=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1YIACmHgoCEzFFF+9CgQw
xcGcAzjMuYrDnFc4zGEQI1oclzm47MXlTlz+whUOuMINXRwArQNmZA==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0A/2o4uvXgUC9zDEQ8Hg
LoY4hL6Dw5xbGOJhYHNu4jDnBtHioTjMwWUvLnfi8tcqHOGAK9xg4gByBnlo

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0Dfs0cVDweAmhvjqVSBw
C0McQt/BYc5dDHGwMavu4TDnAdHiq3GYg8teXO7E5a8wHOGAK9xg4gB823Hg

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5MEBBwwU+1iK/+RBxBmG4
OMMF9zjLr3VQ9UjiKEAEh3qEOKr5onBxVPcgxI3B4DJ+cQZc6kVwqMchjuQv
VPU4xJHCDVd4AgBeWDJL
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6Bv7Gy7wsRb5zUcTv7Cf
4YJ7nOXXOjTxA/sZUABMHKQFq3p7HObb43CPvTEYXCZS/AIO8QM4xBkYcKjf
j8N8HOI39uMKTwBwDz78
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1YIACmPjXjPD4V0WiDjc6
YxbtubHDHiY+Q/nJoV4fUYf/YHAcLn7u29mcdn5Rh5s598+U/bhgj2L+ARGH
BksnvTsnrsDF1Ys6PyUlizj495d9Xap3HVU9gwjUPTfg4jd7y3jnzhF2CMCm
3kEYw3wjTqPJFR+EHG6huSfjjrRt0WYhBxawxhNwce7pKxaI9go5PEDzLyR8
hBy4uub5WFZ22aCrPwdRvx/d/D+Q8NmP7p7rEPfsR3d/HcT9cPEbUP/6Qfy7
H0f47EcPzwBs6oHh34RmPiy+bqG5Bxa/bJDw2Y+eHt6h+ReWfiDhM2sPAGf1
FIs=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0A/sYeKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sXDwPZcxSF+FIc56OEg5BACUb8fu/hVDHGoewiK
o/l3P47w2Y8jPPfjCP/9OOJrP474JVo8DKt/YeLo4QMzBzNdhWANf5g4enwh
0iEAitDSdQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0B/sYeKhICCKKb56FRBo
YYqDuQ44zAnFYU4WDnMaiBfHZQ4ue3G5E5e/cIUDrnBDFwcAkq5ydg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMH+xh4qEgMBVTfPUq
EMAUB3MP4DDnKg5zXuEwh0GMaHFc5uCyF5c7cfkLVzjgCjd0cQB0MHgl
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0A/s0cVXgQGmeFgoCDzE
EIfQj3CYgykONib0MQ5znhAtHobDHFz24nInLn+txhEOuMINJg4AuKNyPA==

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0N/s0cVDwQBTfPUqEMAU
h9DfcZiDKQ42ZhWmOIT+QbT4ahzm4LIXlztx+SsMRzjgCjeYOACJ4nN4
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGmGD/YNF/hYi/zmQ8QZ
hOHiDBfc4yy/1kHVI4mjABEc6hHiqOaLwsVR3YMQNwaDy/jFGXCpF8GhHoc4
kr9Q1eMQRwo3XOEJACWFRAw=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6Cf2DRf4WIv85qOJv7Bn
uOAeZ/m1Dk38DZQPAzDxDzjUf8Jh/hd77O75Zm8MBpeJFP+CQ/wTDvEPOMTf
4BB/gUP8CQ73P7EHABW8P24=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMH+xh4l8zwuNfFYk6
zDuheqq79yNcfIbyk0O9PjD1n+Hi576dzWnnF3Uwu22+Wdbuiz2K+QdEHBL6
JnCbG32Fi6sXdX5KShZxuLI4tnbl6a+o6hlEoOZ/g4vf7C3jnTtHGLt6B2EM
8404jSZXfBDCcE/GHWnbos1CGO7nnr5igWivEIZ/IeEDU/8BQ/2xvC3ZL568
wTCfEaz+FYZ7pnhOmHmk+TmG+x0f33sxcfZTuPgNqH8jd7iwrs14giN8nmCE
ZwQ29cDwt0czHxZfk9HcA4vff/9B4CVGejiE5l9Y+gEr///eHgDUdgi0
       
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0D/sYeKhYCCKIb56FQiI
YIhD+JjiEHOEcZgjhMMc0sXDwPZ8xRCH2PMJhzkfcKh/hcP8pzjMeUBQHNW/
D3CED7o5IjjMwRRHjS90c8RIFg/F6l8xh1VYwwdmDnp4wtSjhz/MfPT4QqRD
APE02Cs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AwOMPFQEBDFFF+9Cgi0
MMUhPBzmhOIwJwuHOQ3Ei+MyB5e9uNyJy1+4wgFXuKGLAwBFbmR1
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1YIAAB5h4KAhMxRRfvQoE
MMXBvAM4zLmKw5xXOMxhECNaHJc5uOzF5U5c/sIVDrjCDV0cACbwaiQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0D/s0cVDwQBTfPUqEMAU
h9A/cZiDKQ42ZhWmOIT+RbT4ahzm4LIXlztx+SsMRzjgCjeYOACdznOW
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0MwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEC2Oyxxc9uJyJy5/4QoHXOEGEwcA0LhmQg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5MECAQ8MFPtYiv/kQcQZh
uDjDBfc4y691UPVI4ihABId6hDiq+aJwcVT3IMSNweAyfnEGXOpFcKjHIY7k
L1T1OMSRwg1XeAIA2DY2Cw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhA6F/2DRf4WIv85qOJ/7Fn
uOAeZ/m1Dk38H5QPAzBxBgfs6hkdsJvP5IDdPcwOxmBwmUhxJhzijDjEGXCI
/7PHLv4Hh/gve1zhCQATDTh4
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1YIAAB5j414zw+FdFog7+
T4SeHj2GEJ+h/ORQrw9UfQMjXPzct7M57fyiDrPfzr7JJ8/kgGL+AREHA/cT
rdIzEeLqRZ2fkpJFHF5dXLfvylM09QwiUPcww8Vv9pbxzp0jjF29gzCG+Uac
RpMrPghhuCfjjrRt0WYhDPdzT1+xQLRXCMO/EHVCGOEDU59sfsu0pOifPVbz
Gf7ao7vnlMoJn0cHf9uju39BYf6XE2d/wcVvQP2rE7OoKczklz328EGIw8IT
q3pg+KObD4svdPfA4vc/GPyxR08PiWj+RU8/ALwc+eE=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0CwOMPFQMBDFEF+9CgRE
MMQhfExxiDnCOMwRwmEO6eIQ85gwxCH2M+IwhwFDPAys/q89dvN/YYhD6B8E
xVH9ixBHDR90c0RwmIMpjhpf6OaIkSy+Cqt/xaDhiR4+MHPQw1MMR/jDzEeP
L0Q6BADm6Msl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0BwOMPFQEBDFFF+9Cgi0
MMXBXAcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7ihiwMAlR5k7Q==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMHA4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRu6OAB2oGqc
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0CwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jCwEi2Oyxxc9uJyJy5/4QoHXOEGEwcA2q5mUQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0NwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEC2Oyxxc9uJyJy5/4QoHXOEGEwcAIHdmug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGDoeGC3ysRX7zIeIM
wnBxhgvucZZf66DqkcRRgAgO9QhxVPNF4eKo7kGIG4PBZfziDLjUi+BQj0Mc
yV+o6nGII4UbrvAEACf1NoM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaFaHhgt8rEV+89HE2RwY
LrjHWX6tQxNnh9IwABPnwKGeE4f5XA7Y3cPtYAwGl4kU58IhzolDnAOHODsO
cTYc4qw43M/qAAApTjIG
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMHA4w8a8Z4fGvikQd
/J8IPT16DCE+Q/nJoV4fqPoGTrj4uW9nc9r5RR1mv519k0+eywHF/AMiDgbu
J1qlZyLE1Ys6PyUlizi8urhu35WnaOoZRKDu4YaL3+wt4507Rxi7egdhDPON
OI0mV3wQwnBPxh1p26LNQhju556+YoForxCGfyHqhDDCB6Z+k/RbKStLdhzm
s2G4J1UoRe3jA1YM91/YYV71JA0hfgPqXzG9QEdtKVYc4cOKEZ5Y1QPDH918
WHyhuwc1ftkw0sNGNP+ipx8AkSnlWw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0DwOMPFQMBDFEF+9CgRE
MMQhfExxiDnCOMwRwmEO6eIQ87gwxCH2c+IwhwOHOWwY4mFgc1hxmMNCUBzV
vyw4wgfdHBEc5mCKo8YXujliJIuHYvWvGI7wgZmDHp5iOMJfzGEV1vhCpEMA
78C/Pw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0AIOMPFQEBDFFF+9Cgi0
MMXBXAcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7ihiwMA5M5lZQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMAg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRu6OADGUGsU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0DwO6OKrVwGBFqZ4KBhg
ioOpBhzmrMJhzlUc5jDwEi2Oyxxc9uJyJy5/4QoHXOEGEwcAKm1myQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHEAUw2CDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIES0OC5zcNmLy524/IUrHHCFG0wcAN5ZaxQ=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGAYeGC3ysRX7zIeIM
wnBxhgvucZZf66DqkcRRgAgO9QhxVPNF4eKo7kGIG4PBZfziDLjUi+BQj0Mc
yV+o6nGII4UbrvAEAHelNvs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDhAaF6Hhgt8rEV+89HE+RwY
LrjHWX6tQxPnh9IwABMXwK6+QQCH+YIOWN3TIOhgDAaXiRNnwKVeAId6XOL8
OMT5cIjzYnc/UBwA4V00dg==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMAg4w8a8Z4fGvikQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5RBwgt6IBi/gERB4g+hDjEXBEH
iD1o6hlEIOY3IMRv9pbxzp0jjF29gzCG+UacRpMrPghhuCfjjrRt0WYhDPdz
T1+xQLRXyEEDzb8QdwhhhA9M/Sbpt1JWlvzYzW/gw3BPqlCK2scHvBjuv7DD
vOpJGkL8BtS/YnqBjtpSvNjDh4EXIzyxqgeGP7r5sPhCdw9K/CK5H5YeNqL5
Fz39AAA/1OTY
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0EIOMPFQMBDFEF+9CgRE
MMQhfExxiDnCOMwRwmEO6eIQewQxxCH2COAwB1Mcop4PQzwMbD4vDnN4CIqj
+pcHR/igmyOCwxxMcdT4QjdHjGTxUKz+FcMRPjBz0MNTDEf4i+GIL0Q6BADm
A8AK
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHKA0CIOMPFQEBDFFF+9Cgi0
MMXBXAcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7ihiwMADLVloQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYQaBB1ANMMIg4w8VAQmIopvnoV
CGCKg7kHcJhzFYc5r3CYwyBGtDguc3DZi8uduPyFKxxwhRu6OADuKGtQ
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHGA0EIO6OKhICCKKb56FRBo
YYqDKQcc5oTiMCcLhzkNxIvjMgeXvbjcictfuMIBV7jBxAFSNmWh
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4TuEOu9fVGewYwEHEAUw2iDujioSAwFVN89SoQ
wBQHUwdwmHMVhzmvcJjDIEa0OC5zcNmLy524/IUrHHCFG0wcAAZAa1A=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMINAg5gGkGEYeGC3ysRX7zIeIM
wnBxhgvucZZf66DqkcRRgAgO9QhxVPNF4eKo7kGIG4PBZfziDLjUi+BQj0Mc
yV+o6nGII4UbrvAEAJ99Nzc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILbwVr8u+3WjPQMYiDiAqQYhh4YLfKxFfvNRxRmE
HRguuMdZfq1DUy8MlYcBmHoRHOpFcJgv6oDdPaIOxmBwmThxBlzqRXCoxyEO
9Bd29TjEgeGGKzwBe603Nw==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIH4TuEOu9fVGewYQaBB1ANMMIg4w8a8Z4fGvikQd
1Is6PyUlI8RnKD851OsDVX8AIX7u29mcdn5RBxiNYj5QHUwfTBxmLsweFPVA
d8DcBRO/2VvGO3eOMHb1DsIY5htxGk2u+CCE4Z6MO9K2RZuFMNzPPX3FAtFe
IQcNNP9C3CGEET4w9TB3YTXfQRjDPcZQGt39MH0w8RtQc2H2YA8fIYzwxKoe
6E9082HhYoTmHpT4RXI/LNxvoPkXPf0AAALu54Y=
       "], CompressedData["
1:eJxTTMoPSmViYGCQAWJmIH4TuEOu9fVGewYwEHOA0TDxUDAQxRBfvQoERDDE
IXxMcYg5wjjMEcJhDuniMPeii8Pci90cTHGYe7GbI4TDHMLiqP4VwhE+6OaI
4DAHUxw1vtDNESNZHLt/xXCED8wc9PAUwxH+YjjiC5EOAYgOwI8=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4DAyYHBjCQO8AABajiIjjEWXCIIwCaegfs4iI4
xOVIFMdlDi57cboTh79whQOucEOIAwD7ijEu
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4DAyYHBhQgdwC7uAgOcRYc4rjMZ3HAYT4OcTkS
xXGZg8tenO4kMRxwhZvcAQC92jEu
       "], {{2.3, -7.5, -7.5}, {2.3, 
       7.5, -7.5}, {2.3, 7.5, 7.5}, {2.3, -7.5, 7.5}, {2.3, -7.5, -7.5}}}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyUfXlATV33/73kuoXcBmSIqAhF5AlJ+5jHUhQZHkISryFTT4jS3COUSoMp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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxtXXlYTd/Xv5FUaI7MkSEyRMakfTKLUpRCEpL4GjIlRKmoKEpRMoVoMIUQ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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634046738753443`*^9, 3.566101168811161*^9, 
  3.614727730540771*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->
  "During evaluation of \
In[258]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData["3.57337699999999980349230099818669259548`6.573678751027676"], \
"Output",
 CellChangeTimes->{3.563404677487103*^9, 3.566101175522912*^9, 
  3.614727730566307*^9},
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."},
 CellLabel->"Out[258]="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 7 topics"]], "Text",
 CellTags->"PR7."]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.3 Solar Array Example", "Section",
 CellTags->{"7.3", "Solar Array Example", "PR7.3", "PR7."}],

Cell["\<\
positions = Flatten[Table[{x,y,0},{x,-5,5,1},{y,-5,5,1}],1]//N;\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[259]:="],

Cell["\<\
ListPlot[Map[Drop[#,-1]&,positions],PlotRange->All, AspectRatio->1];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[260]:="],

Cell["\<\
clonedplaces = Map[{#,(#/Sqrt[#.#])&[incomingVector = \
(#/Sqrt[#.#])&[{-50,0,50}-#];
\t\toutgoingVector = (#/Sqrt[#.#])&[{10,0,10}-#];
\t\tbisectingVector = incomingVector-outgoingVector;
\t\t-(incomingVector-
\t\t\tDot[incomingVector,bisectingVector]/Dot[bisectingVector,bisectingVector]*
\t\t\tbisectingVector)]}&,positions];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[261]:="],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[Mirror[{.9,.9}],CreateClones->clonedplaces, PlotType->TopView, \
ShowLabels->False];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[262]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.115723631026773, -5.416880522567345}, \
{-5.115723631026773, -5.416880522567345}, {-5.077149087351182, \
-5.277920348378229}, {-5.077149087351183, -5.277920348378229}, \
{-5.115723631026773, -5.416880522567345}}], 
     PolygonBox[{{-5.077149087351183, -5.277920348378229}, \
{-5.077149087351182, -5.277920348378229}, {-5.038574543675591, \
-5.138960174189115}, {-5.038574543675591, -5.138960174189115}, \
{-5.077149087351183, -5.277920348378229}}], 
     PolygonBox[{{-5.038574543675591, -5.138960174189115}, \
{-5.038574543675591, -5.138960174189115}, {-5., -5.}, {-5., -5.}, \
{-5.038574543675591, -5.138960174189115}}], 
     PolygonBox[{{-5., -5.}, {-5., -5.}, {-4.961425456324409, \
-4.861039825810885}, {-4.961425456324409, -4.861039825810885}, {-5., -5.}}], 
     PolygonBox[{{-4.961425456324409, -4.861039825810885}, \
{-4.961425456324409, -4.861039825810885}, {-4.922850912648817, \
-4.722079651621771}, {-4.922850912648817, -4.722079651621771}, \
{-4.961425456324409, -4.861039825810885}}], 
     PolygonBox[{{-4.922850912648817, -4.722079651621771}, \
{-4.922850912648817, -4.722079651621771}, {-4.884276368973227, \
-4.583119477432656}, {-4.884276368973227, -4.583119477432656}, \
{-4.922850912648817, -4.722079651621771}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.115723631026773, -5.416880522567345}, {-5.077149087351183, \
-5.277920348378229}, {-5.038574543675591, -5.138960174189115}, {-5., -5.}, \
{-4.961425456324409, -4.861039825810885}, {-4.922850912648817, \
-4.722079651621771}, {-4.884276368973227, -4.583119477432656}, \
{-4.884276368973227, -4.583119477432655}, {-4.922850912648817, \
-4.722079651621771}, {-4.961425456324409, -4.861039825810885}, {-5., -5.}, \
{-5.038574543675591, -5.138960174189115}, {-5.077149087351183, \
-5.277920348378229}, {-5.115723631026773, -5.416880522567344}, \
{-5.115723631026773, -5.416880522567345}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.432463165002302, -4.876231380689784}, \
{-5.432463165002302, -4.876231380689784}, {-5.2883087766682015`, \
-4.917487587126523}, {-5.2883087766682015`, -4.917487587126523}, \
{-5.432463165002302, -4.876231380689784}}], 
       PolygonBox[{{-5.2883087766682015`, -4.917487587126523}, \
{-5.2883087766682015`, -4.917487587126523}, {-5.144154388334101, \
-4.9587437935632614`}, {-5.144154388334101, -4.9587437935632614`}, \
{-5.2883087766682015`, -4.917487587126523}}], 
       PolygonBox[{{-5.144154388334101, -4.9587437935632614`}, \
{-5.144154388334101, -4.9587437935632614`}, {-5., -5.}, {-5., -5.}, \
{-5.144154388334101, -4.9587437935632614`}}], 
       PolygonBox[{{-5., -5.}, {-5., -5.}, {-4.8558456116659, \
-5.0412562064367386`}, {-4.8558456116659, -5.0412562064367386`}, {-5., -5.}}],
        PolygonBox[{{-4.8558456116659, -5.0412562064367386`}, \
{-4.8558456116659, -5.0412562064367386`}, {-4.7116912233317985`, \
-5.082512412873477}, {-4.7116912233317985`, -5.082512412873477}, \
{-4.8558456116659, -5.0412562064367386`}}], 
       PolygonBox[{{-4.7116912233317985`, -5.082512412873477}, \
{-4.7116912233317985`, -5.082512412873477}, {-4.567536834997698, \
-5.123768619310216}, {-4.567536834997698, -5.123768619310216}, \
{-4.7116912233317985`, -5.082512412873477}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.432463165002302, -4.876231380689784}, \
{-5.2883087766682015`, -4.917487587126523}, {-5.144154388334101, \
-4.9587437935632614`}, {-5., -5.}, {-4.8558456116659, -5.0412562064367386`}, \
{-4.7116912233317985`, -5.082512412873477}, {-4.567536834997698, \
-5.123768619310216}, {-4.567536834997698, -5.123768619310216}, \
{-4.7116912233317985`, -5.082512412873477}, {-4.855845611665899, \
-5.0412562064367386`}, {-5., -5.}, {-5.1441543883341, -4.9587437935632614`}, \
{-5.2883087766682015`, -4.917487587126523}, {-5.432463165002302, \
-4.876231380689784}, {-5.432463165002302, -4.876231380689784}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.548186796029076, -5.293111903257128}, \
{-5.316739533975529, -4.4593508581224395`}, {-4.451813203970924, \
-4.706888096742872}, {-4.683260466024471, -5.5406491418775605`}, \
{-5.548186796029076, -5.293111903257128}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.548186796029076, -5.293111903257128}, {-5.316739533975529, \
-4.4593508581224395`}, {-4.451813203970924, -4.706888096742872}, \
{-4.683260466024471, -5.5406491418775605`}, {-5.548186796029076, \
-5.293111903257128}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.0940256399592485`, -4.427940085673643}, \
{-5.0940256399592485`, -4.427940085673643}, {-5.062683759972832, \
-4.2852933904490955`}, {-5.062683759972832, -4.2852933904490955`}, \
{-5.0940256399592485`, -4.427940085673643}}], 
     PolygonBox[{{-5.062683759972832, -4.2852933904490955`}, \
{-5.062683759972832, -4.2852933904490955`}, {-5.0313418799864165`, \
-4.142646695224547}, {-5.0313418799864165`, -4.142646695224547}, \
{-5.062683759972832, -4.2852933904490955`}}], 
     PolygonBox[{{-5.0313418799864165`, -4.142646695224547}, \
{-5.0313418799864165`, -4.142646695224547}, {-5., -4.}, {-5., -4.}, \
{-5.0313418799864165`, -4.142646695224547}}], 
     PolygonBox[{{-5., -4.}, {-5., -4.}, {-4.9686581200135835`, \
-3.8573533047754522`}, {-4.9686581200135835`, -3.8573533047754522`}, {-5., \
-4.}}], PolygonBox[{{-4.9686581200135835`, -3.8573533047754522`}, \
{-4.9686581200135835`, -3.8573533047754522`}, {-4.937316240027168, \
-3.714706609550905}, {-4.937316240027168, -3.7147066095509045`}, \
{-4.9686581200135835`, -3.8573533047754522`}}], 
     PolygonBox[{{-4.937316240027168, -3.7147066095509045`}, \
{-4.937316240027168, -3.714706609550905}, {-4.9059743600407515`, \
-3.572059914326357}, {-4.9059743600407515`, -3.572059914326357}, \
{-4.937316240027168, -3.7147066095509045`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.0940256399592485`, -4.427940085673643}, \
{-5.062683759972832, -4.2852933904490955`}, {-5.0313418799864165`, \
-4.142646695224547}, {-5., -4.}, {-4.9686581200135835`, \
-3.8573533047754522`}, {-4.937316240027168, -3.7147066095509045`}, \
{-4.9059743600407515`, -3.572059914326357}, {-4.9059743600407515`, \
-3.572059914326357}, {-4.937316240027168, -3.7147066095509045`}, \
{-4.9686581200135835`, -3.8573533047754522`}, {-5., -4.}, \
{-5.0313418799864165`, -4.142646695224547}, {-5.062683759972832, \
-4.2852933904490955`}, {-5.0940256399592485`, -4.427940085673643}, \
{-5.0940256399592485`, -4.427940085673643}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.437304244059274, -3.8974014517457047`}, \
{-5.437304244059274, -3.8974014517457047`}, {-5.2915361627061825`, \
-3.93160096783047}, {-5.2915361627061825`, -3.93160096783047}, \
{-5.437304244059274, -3.8974014517457047`}}], 
       PolygonBox[{{-5.2915361627061825`, -3.93160096783047}, \
{-5.2915361627061825`, -3.93160096783047}, {-5.145768081353092, \
-3.9658004839152348`}, {-5.145768081353092, -3.9658004839152348`}, \
{-5.2915361627061825`, -3.93160096783047}}], 
       PolygonBox[{{-5.145768081353092, -3.9658004839152348`}, \
{-5.145768081353092, -3.9658004839152348`}, {-5., -4.}, {-5., -4.}, \
{-5.145768081353092, -3.9658004839152348`}}], 
       PolygonBox[{{-5., -4.}, {-5., -4.}, {-4.854231918646908, \
-4.034199516084765}, {-4.854231918646908, -4.034199516084765}, {-5., -4.}}], 
       PolygonBox[{{-4.854231918646908, -4.034199516084765}, \
{-4.854231918646908, -4.034199516084765}, {-4.7084638372938175`, \
-4.0683990321695305`}, {-4.7084638372938175`, -4.0683990321695305`}, \
{-4.854231918646908, -4.034199516084765}}], 
       PolygonBox[{{-4.7084638372938175`, -4.0683990321695305`}, \
{-4.7084638372938175`, -4.0683990321695305`}, {-4.562695755940726, \
-4.102598548254295}, {-4.562695755940726, -4.102598548254295}, \
{-4.7084638372938175`, -4.0683990321695305`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.437304244059274, -3.8974014517457047`}, \
{-5.2915361627061825`, -3.93160096783047}, {-5.145768081353092, \
-3.9658004839152348`}, {-5., -4.}, {-4.854231918646908, -4.034199516084765}, \
{-4.7084638372938175`, -4.0683990321695305`}, {-4.562695755940726, \
-4.102598548254295}, {-4.562695755940726, -4.102598548254295}, \
{-4.7084638372938175`, -4.0683990321695305`}, {-4.854231918646908, \
-4.034199516084765}, {-5., -4.}, {-5.145768081353092, -3.9658004839152348`}, \
{-5.2915361627061825`, -3.93160096783047}, {-5.437304244059274, \
-3.8974014517457047`}, {-5.437304244059274, -3.8974014517457047`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.531329884018523, -4.325341537419348}, \
{-5.343278604100026, -3.469461366072062}, {-4.468670115981477, \
-3.6746584625806524`}, {-4.656721395899974, -4.5305386339279385`}, \
{-5.531329884018523, -4.325341537419348}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.531329884018523, -4.325341537419348}, {-5.343278604100026, \
-3.469461366072062}, {-4.468670115981477, -3.6746584625806524`}, \
{-4.656721395899974, -4.5305386339279385`}, {-5.531329884018523, \
-4.325341537419348}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.071399969738751, -3.4371859536992355`}, \
{-5.071399969738751, -3.4371859536992355`}, {-5.047599979825834, \
-3.291457302466157}, {-5.047599979825834, -3.291457302466157}, \
{-5.071399969738751, -3.4371859536992355`}}], 
     PolygonBox[{{-5.047599979825834, -3.291457302466157}, \
{-5.047599979825834, -3.291457302466157}, {-5.023799989912917, \
-3.1457286512330787`}, {-5.023799989912917, -3.1457286512330787`}, \
{-5.047599979825834, -3.291457302466157}}], 
     PolygonBox[{{-5.023799989912917, -3.1457286512330787`}, \
{-5.023799989912917, -3.1457286512330787`}, {-5., -3.}, {-5., -3.}, \
{-5.023799989912917, -3.1457286512330787`}}], 
     PolygonBox[{{-5., -3.}, {-5., -3.}, {-4.976200010087083, \
-2.8542713487669213`}, {-4.976200010087083, -2.8542713487669213`}, {-5., \
-3.}}], PolygonBox[{{-4.976200010087083, -2.8542713487669213`}, \
{-4.976200010087083, -2.8542713487669213`}, {-4.952400020174166, \
-2.708542697533843}, {-4.952400020174166, -2.708542697533843}, \
{-4.976200010087083, -2.8542713487669213`}}], 
     PolygonBox[{{-4.952400020174166, -2.708542697533843}, \
{-4.952400020174166, -2.708542697533843}, {-4.928600030261249, \
-2.5628140463007645`}, {-4.928600030261249, -2.5628140463007645`}, \
{-4.952400020174166, -2.708542697533843}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.071399969738751, -3.4371859536992355`}, \
{-5.047599979825834, -3.291457302466157}, {-5.023799989912917, \
-3.1457286512330787`}, {-5., -3.}, {-4.976200010087083, \
-2.8542713487669213`}, {-4.952400020174166, -2.708542697533843}, \
{-4.928600030261249, -2.5628140463007645`}, {-4.928600030261249, \
-2.5628140463007645`}, {-4.952400020174166, -2.708542697533843}, \
{-4.976200010087083, -2.8542713487669213`}, {-5., -3.}, {-5.023799989912917, \
-3.1457286512330787`}, {-5.047599979825834, -3.291457302466157}, \
{-5.071399969738751, -3.4371859536992355`}, {-5.071399969738751, \
-3.4371859536992355`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.441227271248425, -2.920813598330298}, \
{-5.441227271248425, -2.920813598330298}, {-5.294151514165616, \
-2.947209065553532}, {-5.294151514165616, -2.947209065553532}, \
{-5.441227271248425, -2.920813598330298}}], 
       PolygonBox[{{-5.294151514165616, -2.947209065553532}, \
{-5.294151514165616, -2.947209065553532}, {-5.147075757082808, \
-2.973604532776766}, {-5.147075757082808, -2.973604532776766}, \
{-5.294151514165616, -2.947209065553532}}], 
       PolygonBox[{{-5.147075757082808, -2.973604532776766}, \
{-5.147075757082808, -2.973604532776766}, {-5., -3.}, {-5., -3.}, \
{-5.147075757082808, -2.973604532776766}}], 
       PolygonBox[{{-5., -3.}, {-5., -3.}, {-4.852924242917192, \
-3.026395467223234}, {-4.852924242917192, -3.026395467223234}, {-5., -3.}}], 
       PolygonBox[{{-4.852924242917192, -3.026395467223234}, \
{-4.852924242917192, -3.026395467223234}, {-4.705848485834384, \
-3.052790934446468}, {-4.705848485834384, -3.052790934446468}, \
{-4.852924242917192, -3.026395467223234}}], 
       PolygonBox[{{-4.705848485834384, -3.052790934446468}, \
{-4.705848485834384, -3.052790934446468}, {-4.558772728751576, \
-3.079186401669702}, {-4.558772728751576, -3.079186401669702}, \
{-4.705848485834384, -3.052790934446468}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.441227271248425, -2.920813598330298}, \
{-5.294151514165616, -2.947209065553532}, {-5.147075757082808, \
-2.973604532776766}, {-5., -3.}, {-4.852924242917192, -3.026395467223234}, \
{-4.705848485834384, -3.052790934446468}, {-4.558772728751576, \
-3.079186401669702}, {-4.558772728751575, -3.079186401669702}, \
{-4.705848485834384, -3.052790934446468}, {-4.852924242917192, \
-3.026395467223234}, {-5., -3.}, {-5.147075757082808, -2.973604532776766}, \
{-5.294151514165616, -2.947209065553532}, {-5.441227271248424, \
-2.920813598330298}, {-5.441227271248425, -2.920813598330298}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.512627240987176, -3.3579995520295336`}, \
{-5.369827301509674, -2.4836276446310626`}, {-4.487372759012824, \
-2.6420004479704664`}, {-4.630172698490326, -3.5163723553689374`}, \
{-5.512627240987176, -3.3579995520295336`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.512627240987176, -3.3579995520295336`}, \
{-5.369827301509674, -2.4836276446310626`}, {-4.487372759012824, \
-2.6420004479704664`}, {-4.630172698490326, -3.5163723553689374`}, \
{-5.512627240987176, -3.3579995520295336`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.048033365168029, -2.444168992879824}, \
{-5.048033365168029, -2.444168992879824}, {-5.032022243445353, \
-2.296112661919883}, {-5.032022243445353, -2.296112661919883}, \
{-5.048033365168029, -2.444168992879824}}], 
     PolygonBox[{{-5.032022243445353, -2.296112661919883}, \
{-5.032022243445353, -2.296112661919883}, {-5.016011121722676, \
-2.1480563309599416`}, {-5.016011121722676, -2.148056330959941}, \
{-5.032022243445353, -2.296112661919883}}], 
     PolygonBox[{{-5.016011121722676, -2.148056330959941}, \
{-5.016011121722676, -2.1480563309599416`}, {-5., -2.}, {-5., -2.}, \
{-5.016011121722676, -2.148056330959941}}], 
     PolygonBox[{{-5., -2.}, {-5., -2.}, {-4.983988878277324, \
-1.8519436690400588`}, {-4.983988878277324, -1.8519436690400588`}, {-5., \
-2.}}], PolygonBox[{{-4.983988878277324, -1.8519436690400588`}, \
{-4.983988878277324, -1.8519436690400588`}, {-4.967977756554647, \
-1.7038873380801174`}, {-4.967977756554647, -1.7038873380801174`}, \
{-4.983988878277324, -1.8519436690400588`}}], 
     PolygonBox[{{-4.967977756554647, -1.7038873380801174`}, \
{-4.967977756554647, -1.7038873380801174`}, {-4.951966634831971, \
-1.555831007120176}, {-4.951966634831971, -1.555831007120176}, \
{-4.967977756554647, -1.7038873380801174`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.048033365168029, -2.444168992879824}, {-5.032022243445353, \
-2.296112661919883}, {-5.016011121722676, -2.148056330959941}, {-5., -2.}, \
{-4.983988878277324, -1.8519436690400588`}, {-4.967977756554647, \
-1.7038873380801174`}, {-4.951966634831971, -1.555831007120176}, \
{-4.951966634831971, -1.555831007120176}, {-4.967977756554647, \
-1.7038873380801172`}, {-4.983988878277324, -1.8519436690400586`}, {-5., \
-2.}, {-5.016011121722676, -2.148056330959941}, {-5.032022243445353, \
-2.296112661919883}, {-5.048033365168029, -2.444168992879824}, \
{-5.048033365168029, -2.444168992879824}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.44411932046949, -1.9460861650894912`}, \
{-5.44411932046949, -1.9460861650894912`}, {-5.2960795469796595`, \
-1.964057443392994}, {-5.2960795469796595`, -1.964057443392994}, \
{-5.44411932046949, -1.9460861650894912`}}], 
       PolygonBox[{{-5.2960795469796595`, -1.964057443392994}, \
{-5.2960795469796595`, -1.964057443392994}, {-5.14803977348983, \
-1.9820287216964971`}, {-5.14803977348983, -1.9820287216964971`}, \
{-5.2960795469796595`, -1.964057443392994}}], 
       PolygonBox[{{-5.14803977348983, -1.9820287216964971`}, \
{-5.14803977348983, -1.9820287216964971`}, {-5., -2.}, {-5., -2.}, \
{-5.14803977348983, -1.9820287216964971`}}], 
       PolygonBox[{{-5., -2.}, {-5., -2.}, {-4.85196022651017, \
-2.017971278303503}, {-4.85196022651017, -2.017971278303503}, {-5., -2.}}], 
       PolygonBox[{{-4.85196022651017, -2.017971278303503}, \
{-4.85196022651017, -2.017971278303503}, {-4.7039204530203405`, \
-2.0359425566070057`}, {-4.7039204530203405`, -2.0359425566070057`}, \
{-4.85196022651017, -2.017971278303503}}], 
       PolygonBox[{{-4.7039204530203405`, -2.0359425566070057`}, \
{-4.7039204530203405`, -2.0359425566070057`}, {-4.55588067953051, \
-2.053913834910509}, {-4.55588067953051, -2.053913834910509}, \
{-4.7039204530203405`, -2.0359425566070057`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.44411932046949, -1.9460861650894912`}, \
{-5.2960795469796595`, -1.964057443392994}, {-5.14803977348983, \
-1.9820287216964971`}, {-5., -2.}, {-4.85196022651017, -2.017971278303503}, \
{-4.7039204530203405`, -2.0359425566070057`}, {-4.55588067953051, \
-2.053913834910509}, {-4.55588067953051, -2.053913834910509}, \
{-4.7039204530203405`, -2.0359425566070057`}, {-4.85196022651017, \
-2.017971278303503}, {-5., -2.}, {-5.14803977348983, -1.9820287216964971`}, \
{-5.2960795469796595`, -1.964057443392994}, {-5.44411932046949, \
-1.9460861650894912`}, {-5.44411932046949, -1.9460861650894912`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.492152685637519, -2.390255157969315}, \
{-5.39608595530146, -1.5019171722096671`}, {-4.507847314362481, \
-1.6097448420306848`}, {-4.60391404469854, -2.498082827790333}, \
{-5.492152685637519, -2.390255157969315}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.492152685637519, -2.390255157969315}, {-5.39608595530146, \
-1.5019171722096671`}, {-4.507847314362481, -1.6097448420306848`}, \
{-4.60391404469854, -2.498082827790333}, {-5.492152685637519, \
-2.390255157969315}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.02414962427121, -1.4485210978244876`}, \
{-5.02414962427121, -1.4485210978244876`}, {-5.01609974951414, \
-1.299014065216325}, {-5.01609974951414, -1.299014065216325}, \
{-5.02414962427121, -1.4485210978244876`}}], 
     PolygonBox[{{-5.01609974951414, -1.299014065216325}, {-5.01609974951414, \
-1.299014065216325}, {-5.00804987475707, -1.1495070326081627`}, \
{-5.00804987475707, -1.1495070326081624`}, {-5.01609974951414, \
-1.299014065216325}}], 
     PolygonBox[{{-5.00804987475707, -1.1495070326081624`}, \
{-5.00804987475707, -1.1495070326081627`}, {-5., -1.0000000000000002`}, {-5., \
-1.}, {-5.00804987475707, -1.1495070326081624`}}], 
     PolygonBox[{{-5., -1.}, {-5., -1.}, {-4.99195012524293, \
-0.8504929673918376}, {-4.99195012524293, -0.8504929673918376}, {-5., -1.}}], 
     PolygonBox[{{-4.99195012524293, -0.8504929673918376}, \
{-4.99195012524293, -0.8504929673918376}, {-4.98390025048586, \
-0.7009859347836751}, {-4.98390025048586, -0.7009859347836751}, \
{-4.99195012524293, -0.8504929673918376}}], 
     PolygonBox[{{-4.98390025048586, -0.7009859347836751}, \
{-4.98390025048586, -0.7009859347836751}, {-4.97585037572879, \
-0.5514789021755127}, {-4.97585037572879, -0.5514789021755127}, \
{-4.98390025048586, -0.7009859347836751}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.02414962427121, -1.4485210978244876`}, {-5.01609974951414, \
-1.299014065216325}, {-5.00804987475707, -1.1495070326081624`}, {-5., -1.}, \
{-4.99195012524293, -0.8504929673918376}, {-4.98390025048586, \
-0.7009859347836751}, {-4.97585037572879, -0.5514789021755127}, \
{-4.97585037572879, -0.5514789021755125}, {-4.98390025048586, \
-0.700985934783675}, {-4.99195012524293, -0.8504929673918376}, {-5., -1.}, \
{-5.00804987475707, -1.1495070326081624`}, {-5.01609974951414, \
-1.299014065216325}, {-5.02414962427121, -1.4485210978244873`}, \
{-5.02414962427121, -1.4485210978244876`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.445892160646057, -0.9726939484019419}, \
{-5.445892160646057, -0.9726939484019418}, {-5.297261440430704, \
-0.9817959656012946}, {-5.297261440430704, -0.9817959656012946}, \
{-5.445892160646057, -0.9726939484019419}}], 
       PolygonBox[{{-5.297261440430704, -0.9817959656012946}, \
{-5.297261440430704, -0.9817959656012946}, {-5.148630720215352, \
-0.9908979828006472}, {-5.148630720215352, -0.9908979828006472}, \
{-5.297261440430704, -0.9817959656012946}}], 
       PolygonBox[{{-5.148630720215352, -0.9908979828006472}, \
{-5.148630720215352, -0.9908979828006472}, {-5., -1.}, {-5., -1.}, \
{-5.148630720215352, -0.9908979828006472}}], 
       PolygonBox[{{-5., -1.}, {-5., -1.}, {-4.851369279784648, \
-1.0091020171993528`}, {-4.851369279784648, -1.0091020171993528`}, {-5., \
-1.}}], PolygonBox[{{-4.851369279784648, -1.0091020171993528`}, \
{-4.851369279784648, -1.0091020171993528`}, {-4.702738559569296, \
-1.0182040343987053`}, {-4.702738559569296, -1.0182040343987053`}, \
{-4.851369279784648, -1.0091020171993528`}}], 
       PolygonBox[{{-4.702738559569296, -1.0182040343987053`}, \
{-4.702738559569296, -1.0182040343987053`}, {-4.554107839353944, \
-1.027306051598058}, {-4.554107839353944, -1.027306051598058}, \
{-4.702738559569296, -1.0182040343987053`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.445892160646057, -0.9726939484019419}, \
{-5.297261440430704, -0.9817959656012946}, {-5.148630720215352, \
-0.9908979828006473}, {-5., -1.}, {-4.851369279784648, -1.0091020171993528`}, \
{-4.702738559569296, -1.0182040343987053`}, {-4.554107839353944, \
-1.027306051598058}, {-4.554107839353943, -1.027306051598058}, \
{-4.702738559569296, -1.0182040343987053`}, {-4.851369279784648, \
-1.0091020171993528`}, {-5., -1.}, {-5.148630720215352, -0.9908979828006473}, \
{-5.297261440430704, -0.9817959656012946}, {-5.445892160646056, \
-0.9726939484019419}, {-5.445892160646057, -0.9726939484019419}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.470041784917267, -1.4212150462264295`}, \
{-5.421742536374846, -0.5241728505774544}, {-4.529958215082733, \
-0.5787849537735706}, {-4.578257463625154, -1.4758271494225457`}, \
{-5.470041784917267, -1.4212150462264295`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.470041784917267, -1.4212150462264295`}, \
{-5.421742536374846, -0.5241728505774544}, {-4.529958215082733, \
-0.5787849537735706}, {-4.578257463625154, -1.4758271494225457`}, \
{-5.470041784917267, -1.4212150462264295`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5., -0.45}, {-5., -0.45}, {-5., -0.3}, {-5., \
-0.30000000000000004`}, {-5., -0.45}}], 
     PolygonBox[{{-5., -0.30000000000000004`}, {-5., -0.3}, {-5., \
-0.15000000000000008`}, {-5., -0.15000000000000002`}, {-5., \
-0.30000000000000004`}}], 
     PolygonBox[{{-5., -0.15000000000000002`}, {-5., -0.15000000000000008`}, \
{-5., -1.1102230246251565`*^-16}, {-5., 0.}, {-5., -0.15000000000000002`}}], 
     PolygonBox[{{-5., 0.}, {-5., 0.}, {-5., 0.14999999999999997`}, {-5., 
      0.14999999999999997`}, {-5., 0.}}], 
     PolygonBox[{{-5., 0.14999999999999997`}, {-5., 
      0.14999999999999997`}, {-5., 0.29999999999999993`}, {-5., 0.3}, {-5., 
      0.14999999999999997`}}], 
     PolygonBox[{{-5., 0.3}, {-5., 0.29999999999999993`}, {-5., 
      0.44999999999999996`}, {-5., 0.4499999999999999}, {-5., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5., -0.45}, {-5., -0.30000000000000004`}, {-5., \
-0.15000000000000002`}, {-5., -5.551115123125783*^-17}, {-5., 
       0.14999999999999997`}, {-5., 0.3}, {-5., 0.4499999999999999}, {-5., 
       0.45}, {-5., 0.30000000000000004`}, {-5., 0.15000000000000002`}, {-5., 
       5.551115123125783*^-17}, {-5., -0.14999999999999997`}, {-5., -0.3}, \
{-5., -0.4499999999999999}, {-5., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.446489549934516, 0.}, {-5.446489549934516, 
        5.5109105961630896`*^-17}, {-5.297659699956344, 
        4.592425496802574*^-17}, {-5.297659699956344, 
        9.184850993605149*^-18}, {-5.446489549934516, 0.}}], 
       PolygonBox[{{-5.297659699956344, 
        9.184850993605149*^-18}, {-5.297659699956344, 
        4.592425496802574*^-17}, {-5.148829849978172, 
        3.67394039744206*^-17}, {-5.148829849978172, 
        1.8369701987210297`*^-17}, {-5.297659699956344, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{-5.148829849978172, 
        1.8369701987210297`*^-17}, {-5.148829849978172, 
        3.67394039744206*^-17}, {-5., 2.7554552980815454`*^-17}, {-5., 
        2.7554552980815448`*^-17}, {-5.148829849978172, 
        1.8369701987210297`*^-17}}], 
       PolygonBox[{{-5., 2.7554552980815448`*^-17}, {-5., 
        2.7554552980815448`*^-17}, {-4.851170150021828, 
        1.83697019872103*^-17}, {-4.851170150021828, 
        3.6739403974420595`*^-17}, {-5., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{-4.851170150021828, 
        3.6739403974420595`*^-17}, {-4.851170150021828, 
        1.83697019872103*^-17}, {-4.702340300043656, 
        9.184850993605152*^-18}, {-4.702340300043656, 
        4.592425496802574*^-17}, {-4.851170150021828, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{-4.702340300043656, 
        4.592425496802574*^-17}, {-4.702340300043656, 
        9.184850993605153*^-18}, {-4.553510450065484, 
        4.5887548728832574`*^-33}, {-4.553510450065484, 
        5.510910596163089*^-17}, {-4.702340300043656, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.446489549934516, 0.}, {-5.297659699956344, 
         0.}, {-5.148829849978172, 0.}, {-5., 0.}, {-4.851170150021828, 
         0.}, {-4.702340300043656, 0.}, {-4.553510450065484, 
         0.}, {-4.553510450065484, 0.}, {-4.702340300043656, 
         0.}, {-4.851170150021828, 0.}, {-5., 0.}, {-5.148829849978172, 
         0.}, {-5.297659699956344, 0.}, {-5.446489549934516, 
         0.}, {-5.446489549934516, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.446489549934516, -0.45}, {-5.446489549934516, 
      0.45}, {-4.553510450065484, 
      0.45}, {-4.553510450065484, -0.45}, {-5.446489549934516, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.446489549934516, -0.45}, {-5.446489549934516, 
       0.45}, {-4.553510450065484, 
       0.45}, {-4.553510450065484, -0.45}, {-5.446489549934516, -0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.97585037572879, 0.5514789021755125}, {-4.975850375728789,
       0.5514789021755125}, {-4.98390025048586, 
      0.7009859347836751}, {-4.98390025048586, 
      0.700985934783675}, {-4.97585037572879, 0.5514789021755125}}], 
     PolygonBox[{{-4.98390025048586, 0.700985934783675}, {-4.98390025048586, 
      0.7009859347836751}, {-4.99195012524293, 
      0.8504929673918374}, {-4.99195012524293, 
      0.8504929673918376}, {-4.98390025048586, 0.700985934783675}}], 
     PolygonBox[{{-4.99195012524293, 0.8504929673918376}, {-4.99195012524293, 
      0.8504929673918374}, {-5., 0.9999999999999999}, {-5., 
      1.}, {-4.99195012524293, 0.8504929673918376}}], 
     PolygonBox[{{-5., 1.}, {-5., 1.}, {-5.00804987475707, 
      1.1495070326081624`}, {-5.00804987475707, 1.1495070326081624`}, {-5., 
      1.}}], PolygonBox[{{-5.00804987475707, 
      1.1495070326081624`}, {-5.00804987475707, 
      1.1495070326081624`}, {-5.01609974951414, 
      1.299014065216325}, {-5.01609974951414, 
      1.299014065216325}, {-5.00804987475707, 1.1495070326081624`}}], 
     PolygonBox[{{-5.01609974951414, 1.299014065216325}, {-5.01609974951414, 
      1.299014065216325}, {-5.02414962427121, 
      1.4485210978244873`}, {-5.02414962427121, 
      1.4485210978244873`}, {-5.01609974951414, 1.299014065216325}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.97585037572879, 0.5514789021755125}, {-4.98390025048586, 
       0.700985934783675}, {-4.99195012524293, 0.8504929673918376}, {-5., 
       1.}, {-5.00804987475707, 1.1495070326081624`}, {-5.01609974951414, 
       1.299014065216325}, {-5.02414962427121, 
       1.4485210978244873`}, {-5.02414962427121, 
       1.4485210978244876`}, {-5.01609974951414, 
       1.299014065216325}, {-5.00804987475707, 1.1495070326081624`}, {-5., 
       1.}, {-4.99195012524293, 0.8504929673918376}, {-4.98390025048586, 
       0.7009859347836751}, {-4.97585037572879, 
       0.5514789021755127}, {-4.97585037572879, 0.5514789021755125}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.445892160646057, 
        0.9726939484019419}, {-5.445892160646057, 
        0.9726939484019419}, {-5.297261440430704, 
        0.9817959656012947}, {-5.297261440430704, 
        0.9817959656012946}, {-5.445892160646057, 0.9726939484019419}}], 
       PolygonBox[{{-5.297261440430704, 
        0.9817959656012946}, {-5.297261440430704, 
        0.9817959656012947}, {-5.148630720215352, 
        0.9908979828006473}, {-5.148630720215352, 
        0.9908979828006473}, {-5.297261440430704, 0.9817959656012946}}], 
       PolygonBox[{{-5.148630720215352, 
        0.9908979828006473}, {-5.148630720215352, 0.9908979828006473}, {-5., 
        1.}, {-5., 1.}, {-5.148630720215352, 0.9908979828006473}}], 
       PolygonBox[{{-5., 1.}, {-5., 1.}, {-4.851369279784648, 
        1.0091020171993528`}, {-4.851369279784648, 1.0091020171993528`}, {-5.,
         1.}}], PolygonBox[{{-4.851369279784648, 
        1.0091020171993528`}, {-4.851369279784648, 
        1.0091020171993528`}, {-4.702738559569296, 
        1.0182040343987053`}, {-4.702738559569296, 
        1.0182040343987055`}, {-4.851369279784648, 1.0091020171993528`}}], 
       PolygonBox[{{-4.702738559569296, 
        1.0182040343987055`}, {-4.702738559569296, 
        1.0182040343987053`}, {-4.554107839353944, 
        1.027306051598058}, {-4.554107839353944, 
        1.027306051598058}, {-4.702738559569296, 1.0182040343987055`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.445892160646057, 
         0.9726939484019419}, {-5.297261440430704, 
         0.9817959656012946}, {-5.148630720215352, 0.9908979828006473}, {-5., 
         1.}, {-4.851369279784648, 1.0091020171993528`}, {-4.702738559569296, 
         1.0182040343987053`}, {-4.554107839353944, 
         1.027306051598058}, {-4.554107839353943, 
         1.027306051598058}, {-4.702738559569296, 
         1.0182040343987053`}, {-4.851369279784648, 
         1.0091020171993528`}, {-5., 1.}, {-5.148630720215352, 
         0.9908979828006473}, {-5.297261440430704, 
         0.9817959656012946}, {-5.445892160646056, 
         0.9726939484019419}, {-5.445892160646057, 
         0.9726939484019419}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.421742536374846, 
      0.5241728505774544}, {-5.470041784917267, 
      1.4212150462264295`}, {-4.578257463625154, 
      1.4758271494225457`}, {-4.529958215082733, 
      0.5787849537735706}, {-5.421742536374846, 0.5241728505774544}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.421742536374846, 0.5241728505774544}, {-5.470041784917267, 
       1.4212150462264295`}, {-4.578257463625154, 
       1.4758271494225457`}, {-4.529958215082733, 
       0.5787849537735706}, {-5.421742536374846, 0.5241728505774544}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.951966634831971, 1.555831007120176}, {-4.951966634831971,
       1.555831007120176}, {-4.967977756554647, 
      1.7038873380801174`}, {-4.967977756554647, 
      1.7038873380801172`}, {-4.951966634831971, 1.555831007120176}}], 
     PolygonBox[{{-4.967977756554647, 
      1.7038873380801172`}, {-4.967977756554647, 
      1.7038873380801174`}, {-4.983988878277324, 
      1.8519436690400586`}, {-4.983988878277324, 
      1.8519436690400586`}, {-4.967977756554647, 1.7038873380801172`}}], 
     PolygonBox[{{-4.983988878277324, 
      1.8519436690400586`}, {-4.983988878277324, 1.8519436690400586`}, {-5., 
      2.}, {-5., 2.}, {-4.983988878277324, 1.8519436690400586`}}], 
     PolygonBox[{{-5., 2.}, {-5., 2.}, {-5.016011121722676, 
      2.148056330959941}, {-5.016011121722676, 2.148056330959941}, {-5., 
      2.}}], PolygonBox[{{-5.016011121722676, 
      2.148056330959941}, {-5.016011121722676, 
      2.148056330959941}, {-5.032022243445353, 
      2.2961126619198824`}, {-5.032022243445353, 
      2.296112661919883}, {-5.016011121722676, 2.148056330959941}}], 
     PolygonBox[{{-5.032022243445353, 2.296112661919883}, {-5.032022243445353,
       2.2961126619198824`}, {-5.048033365168029, 
      2.444168992879824}, {-5.048033365168029, 
      2.444168992879824}, {-5.032022243445353, 2.296112661919883}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.951966634831971, 1.555831007120176}, {-4.967977756554647, 
       1.7038873380801172`}, {-4.983988878277324, 1.8519436690400586`}, {-5., 
       2.}, {-5.016011121722676, 2.148056330959941}, {-5.032022243445353, 
       2.296112661919883}, {-5.048033365168029, 
       2.444168992879824}, {-5.048033365168029, 
       2.444168992879824}, {-5.032022243445353, 
       2.296112661919883}, {-5.016011121722676, 2.148056330959941}, {-5., 
       2.}, {-4.983988878277324, 1.8519436690400588`}, {-4.967977756554647, 
       1.7038873380801174`}, {-4.951966634831971, 
       1.555831007120176}, {-4.951966634831971, 1.555831007120176}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.44411932046949, 
        1.9460861650894912`}, {-5.44411932046949, 
        1.9460861650894912`}, {-5.2960795469796595`, 
        1.9640574433929943`}, {-5.2960795469796595`, 
        1.964057443392994}, {-5.44411932046949, 1.9460861650894912`}}], 
       PolygonBox[{{-5.2960795469796595`, 
        1.964057443392994}, {-5.2960795469796595`, 
        1.9640574433929943`}, {-5.14803977348983, 
        1.9820287216964971`}, {-5.14803977348983, 
        1.9820287216964971`}, {-5.2960795469796595`, 1.964057443392994}}], 
       PolygonBox[{{-5.14803977348983, 
        1.9820287216964971`}, {-5.14803977348983, 1.9820287216964971`}, {-5., 
        2.}, {-5., 2.}, {-5.14803977348983, 1.9820287216964971`}}], 
       PolygonBox[{{-5., 2.}, {-5., 2.}, {-4.85196022651017, 
        2.017971278303503}, {-4.85196022651017, 2.017971278303503}, {-5., 
        2.}}], PolygonBox[{{-4.85196022651017, 
        2.017971278303503}, {-4.85196022651017, 
        2.017971278303503}, {-4.7039204530203405`, 
        2.0359425566070057`}, {-4.7039204530203405`, 
        2.0359425566070057`}, {-4.85196022651017, 2.017971278303503}}], 
       PolygonBox[{{-4.7039204530203405`, 
        2.0359425566070057`}, {-4.7039204530203405`, 
        2.0359425566070057`}, {-4.55588067953051, 
        2.053913834910509}, {-4.55588067953051, 
        2.053913834910509}, {-4.7039204530203405`, 2.0359425566070057`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.44411932046949, 
         1.9460861650894912`}, {-5.2960795469796595`, 
         1.964057443392994}, {-5.14803977348983, 1.9820287216964971`}, {-5., 
         2.}, {-4.85196022651017, 2.017971278303503}, {-4.7039204530203405`, 
         2.0359425566070057`}, {-4.55588067953051, 
         2.053913834910509}, {-4.55588067953051, 
         2.053913834910509}, {-4.7039204530203405`, 
         2.0359425566070057`}, {-4.85196022651017, 2.017971278303503}, {-5., 
         2.}, {-5.14803977348983, 1.9820287216964971`}, {-5.2960795469796595`,
          1.964057443392994}, {-5.44411932046949, 
         1.9460861650894912`}, {-5.44411932046949, 1.9460861650894912`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.39608595530146, 
      1.5019171722096671`}, {-5.492152685637519, 
      2.390255157969315}, {-4.60391404469854, 
      2.498082827790333}, {-4.507847314362481, 
      1.6097448420306848`}, {-5.39608595530146, 1.5019171722096671`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.39608595530146, 1.5019171722096671`}, {-5.492152685637519, 
       2.390255157969315}, {-4.60391404469854, 
       2.498082827790333}, {-4.507847314362481, 
       1.6097448420306848`}, {-5.39608595530146, 1.5019171722096671`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.928600030261249, 
      2.5628140463007645`}, {-4.928600030261249, 
      2.5628140463007645`}, {-4.952400020174166, 
      2.708542697533843}, {-4.952400020174166, 
      2.708542697533843}, {-4.928600030261249, 2.5628140463007645`}}], 
     PolygonBox[{{-4.952400020174166, 2.708542697533843}, {-4.952400020174166,
       2.708542697533843}, {-4.976200010087083, 
      2.8542713487669213`}, {-4.976200010087083, 
      2.8542713487669213`}, {-4.952400020174166, 2.708542697533843}}], 
     PolygonBox[{{-4.976200010087083, 
      2.8542713487669213`}, {-4.976200010087083, 2.8542713487669213`}, {-5., 
      3.}, {-5., 3.}, {-4.976200010087083, 2.8542713487669213`}}], 
     PolygonBox[{{-5., 3.}, {-5., 3.}, {-5.023799989912917, 
      3.1457286512330787`}, {-5.023799989912917, 3.1457286512330787`}, {-5., 
      3.}}], PolygonBox[{{-5.023799989912917, 
      3.1457286512330787`}, {-5.023799989912917, 
      3.1457286512330787`}, {-5.047599979825834, 
      3.291457302466157}, {-5.047599979825834, 
      3.291457302466157}, {-5.023799989912917, 3.1457286512330787`}}], 
     PolygonBox[{{-5.047599979825834, 3.291457302466157}, {-5.047599979825834,
       3.291457302466157}, {-5.071399969738751, 
      3.4371859536992355`}, {-5.071399969738751, 
      3.4371859536992355`}, {-5.047599979825834, 3.291457302466157}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.928600030261249, 2.5628140463007645`}, {-4.952400020174166,
        2.708542697533843}, {-4.976200010087083, 2.8542713487669213`}, {-5., 
       3.}, {-5.023799989912917, 3.1457286512330787`}, {-5.047599979825834, 
       3.291457302466157}, {-5.071399969738751, 
       3.4371859536992355`}, {-5.071399969738751, 
       3.4371859536992355`}, {-5.047599979825834, 
       3.291457302466157}, {-5.023799989912917, 3.1457286512330787`}, {-5., 
       3.}, {-4.976200010087083, 2.8542713487669213`}, {-4.952400020174166, 
       2.708542697533843}, {-4.928600030261249, 
       2.5628140463007645`}, {-4.928600030261249, 2.5628140463007645`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.441227271248425, 
        2.920813598330298}, {-5.441227271248425, 
        2.920813598330298}, {-5.294151514165616, 
        2.947209065553532}, {-5.294151514165616, 
        2.947209065553532}, {-5.441227271248425, 2.920813598330298}}], 
       PolygonBox[{{-5.294151514165616, 
        2.947209065553532}, {-5.294151514165616, 
        2.947209065553532}, {-5.147075757082808, 
        2.973604532776766}, {-5.147075757082808, 
        2.973604532776766}, {-5.294151514165616, 2.947209065553532}}], 
       PolygonBox[{{-5.147075757082808, 
        2.973604532776766}, {-5.147075757082808, 2.973604532776766}, {-5., 
        3.}, {-5., 3.}, {-5.147075757082808, 2.973604532776766}}], 
       PolygonBox[{{-5., 3.}, {-5., 3.}, {-4.852924242917192, 
        3.026395467223234}, {-4.852924242917192, 3.026395467223234}, {-5., 
        3.}}], PolygonBox[{{-4.852924242917192, 
        3.026395467223234}, {-4.852924242917192, 
        3.026395467223234}, {-4.705848485834384, 
        3.052790934446468}, {-4.705848485834384, 
        3.052790934446468}, {-4.852924242917192, 3.026395467223234}}], 
       PolygonBox[{{-4.705848485834384, 
        3.052790934446468}, {-4.705848485834384, 
        3.052790934446468}, {-4.558772728751576, 
        3.079186401669702}, {-4.558772728751576, 
        3.079186401669702}, {-4.705848485834384, 3.052790934446468}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.441227271248425, 2.920813598330298}, {-5.294151514165616,
          2.947209065553532}, {-5.147075757082808, 2.973604532776766}, {-5., 
         3.}, {-4.852924242917192, 3.026395467223234}, {-4.705848485834384, 
         3.052790934446468}, {-4.558772728751576, 
         3.079186401669702}, {-4.558772728751575, 
         3.079186401669702}, {-4.705848485834384, 
         3.052790934446468}, {-4.852924242917192, 3.026395467223234}, {-5., 
         3.}, {-5.147075757082808, 2.973604532776766}, {-5.294151514165616, 
         2.947209065553532}, {-5.441227271248424, 
         2.920813598330298}, {-5.441227271248425, 2.920813598330298}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.369827301509674, 
      2.4836276446310626`}, {-5.512627240987176, 
      3.3579995520295336`}, {-4.630172698490326, 
      3.5163723553689374`}, {-4.487372759012824, 
      2.6420004479704664`}, {-5.369827301509674, 2.4836276446310626`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.369827301509674, 2.4836276446310626`}, {-5.512627240987176,
        3.3579995520295336`}, {-4.630172698490326, 
       3.5163723553689374`}, {-4.487372759012824, 
       2.6420004479704664`}, {-5.369827301509674, 2.4836276446310626`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.9059743600407515`, 
      3.572059914326357}, {-4.9059743600407515`, 
      3.572059914326357}, {-4.937316240027168, 
      3.7147066095509045`}, {-4.937316240027168, 
      3.7147066095509045`}, {-4.9059743600407515`, 3.572059914326357}}], 
     PolygonBox[{{-4.937316240027168, 
      3.7147066095509045`}, {-4.937316240027168, 
      3.7147066095509045`}, {-4.9686581200135835`, 
      3.8573533047754522`}, {-4.9686581200135835`, 
      3.8573533047754522`}, {-4.937316240027168, 3.7147066095509045`}}], 
     PolygonBox[{{-4.9686581200135835`, 
      3.8573533047754522`}, {-4.9686581200135835`, 3.8573533047754522`}, {-5.,
       4.}, {-5., 4.}, {-4.9686581200135835`, 3.8573533047754522`}}], 
     PolygonBox[{{-5., 4.}, {-5., 4.}, {-5.0313418799864165`, 
      4.142646695224547}, {-5.0313418799864165`, 4.142646695224547}, {-5., 
      4.}}], PolygonBox[{{-5.0313418799864165`, 
      4.142646695224547}, {-5.0313418799864165`, 
      4.142646695224547}, {-5.062683759972832, 
      4.2852933904490955`}, {-5.062683759972832, 
      4.2852933904490955`}, {-5.0313418799864165`, 4.142646695224547}}], 
     PolygonBox[{{-5.062683759972832, 
      4.2852933904490955`}, {-5.062683759972832, 
      4.2852933904490955`}, {-5.0940256399592485`, 
      4.427940085673643}, {-5.0940256399592485`, 
      4.427940085673643}, {-5.062683759972832, 4.2852933904490955`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.9059743600407515`, 3.572059914326357}, {-4.937316240027168,
        3.7147066095509045`}, {-4.9686581200135835`, 
       3.8573533047754522`}, {-5., 4.}, {-5.0313418799864165`, 
       4.142646695224547}, {-5.062683759972832, 
       4.2852933904490955`}, {-5.0940256399592485`, 
       4.427940085673643}, {-5.0940256399592485`, 
       4.427940085673643}, {-5.062683759972832, 
       4.2852933904490955`}, {-5.0313418799864165`, 4.142646695224547}, {-5., 
       4.}, {-4.9686581200135835`, 3.8573533047754522`}, {-4.937316240027168, 
       3.7147066095509045`}, {-4.9059743600407515`, 
       3.572059914326357}, {-4.9059743600407515`, 3.572059914326357}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.437304244059274, 
        3.8974014517457047`}, {-5.437304244059274, 
        3.8974014517457047`}, {-5.2915361627061825`, 
        3.93160096783047}, {-5.2915361627061825`, 
        3.93160096783047}, {-5.437304244059274, 3.8974014517457047`}}], 
       PolygonBox[{{-5.2915361627061825`, 
        3.93160096783047}, {-5.2915361627061825`, 
        3.93160096783047}, {-5.145768081353092, 
        3.9658004839152348`}, {-5.145768081353092, 
        3.9658004839152348`}, {-5.2915361627061825`, 3.93160096783047}}], 
       PolygonBox[{{-5.145768081353092, 
        3.9658004839152348`}, {-5.145768081353092, 3.9658004839152348`}, {-5.,
         4.}, {-5., 4.}, {-5.145768081353092, 3.9658004839152348`}}], 
       PolygonBox[{{-5., 4.}, {-5., 4.}, {-4.854231918646908, 
        4.034199516084765}, {-4.854231918646908, 4.034199516084765}, {-5., 
        4.}}], PolygonBox[{{-4.854231918646908, 
        4.034199516084765}, {-4.854231918646908, 
        4.034199516084765}, {-4.7084638372938175`, 
        4.0683990321695305`}, {-4.7084638372938175`, 
        4.0683990321695305`}, {-4.854231918646908, 4.034199516084765}}], 
       PolygonBox[{{-4.7084638372938175`, 
        4.0683990321695305`}, {-4.7084638372938175`, 
        4.0683990321695305`}, {-4.562695755940726, 
        4.102598548254295}, {-4.562695755940726, 
        4.102598548254296}, {-4.7084638372938175`, 4.0683990321695305`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.437304244059274, 
         3.8974014517457047`}, {-5.2915361627061825`, 
         3.93160096783047}, {-5.145768081353092, 3.9658004839152348`}, {-5., 
         4.}, {-4.854231918646908, 4.034199516084765}, {-4.7084638372938175`, 
         4.0683990321695305`}, {-4.562695755940726, 
         4.102598548254295}, {-4.562695755940726, 
         4.102598548254295}, {-4.7084638372938175`, 
         4.0683990321695305`}, {-4.854231918646908, 4.034199516084765}, {-5., 
         4.}, {-5.145768081353092, 
         3.9658004839152348`}, {-5.2915361627061825`, 
         3.93160096783047}, {-5.437304244059274, 
         3.8974014517457047`}, {-5.437304244059274, 
         3.8974014517457047`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.343278604100026, 3.469461366072062}, {-5.531329884018523,
       4.325341537419348}, {-4.656721395899974, 
      4.5305386339279385`}, {-4.468670115981477, 
      3.6746584625806524`}, {-5.343278604100026, 3.469461366072062}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.343278604100026, 3.469461366072062}, {-5.531329884018523, 
       4.325341537419348}, {-4.656721395899974, 
       4.5305386339279385`}, {-4.468670115981477, 
       3.6746584625806524`}, {-5.343278604100026, 3.469461366072062}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.884276368973227, 4.583119477432655}, {-4.884276368973227,
       4.583119477432656}, {-4.922850912648817, 
      4.722079651621771}, {-4.922850912648817, 
      4.722079651621771}, {-4.884276368973227, 4.583119477432655}}], 
     PolygonBox[{{-4.922850912648817, 4.722079651621771}, {-4.922850912648817,
       4.722079651621771}, {-4.961425456324409, 
      4.861039825810885}, {-4.961425456324409, 
      4.861039825810885}, {-4.922850912648817, 4.722079651621771}}], 
     PolygonBox[{{-4.961425456324409, 4.861039825810885}, {-4.961425456324409,
       4.861039825810885}, {-5., 5.}, {-5., 5.}, {-4.961425456324409, 
      4.861039825810885}}], 
     PolygonBox[{{-5., 5.}, {-5., 5.}, {-5.038574543675591, 
      5.138960174189115}, {-5.038574543675591, 5.138960174189115}, {-5., 
      5.}}], PolygonBox[{{-5.038574543675591, 
      5.138960174189115}, {-5.038574543675591, 
      5.138960174189115}, {-5.077149087351183, 
      5.277920348378229}, {-5.077149087351183, 
      5.277920348378229}, {-5.038574543675591, 5.138960174189115}}], 
     PolygonBox[{{-5.077149087351183, 5.277920348378229}, {-5.077149087351183,
       5.277920348378229}, {-5.115723631026773, 
      5.416880522567344}, {-5.115723631026773, 
      5.416880522567344}, {-5.077149087351183, 5.277920348378229}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.884276368973227, 4.583119477432655}, {-4.922850912648817, 
       4.722079651621771}, {-4.961425456324409, 4.861039825810885}, {-5., 
       5.}, {-5.038574543675591, 5.138960174189115}, {-5.077149087351183, 
       5.277920348378229}, {-5.115723631026773, 
       5.416880522567344}, {-5.115723631026773, 
       5.416880522567345}, {-5.077149087351183, 
       5.277920348378229}, {-5.038574543675591, 5.138960174189115}, {-5., 
       5.}, {-4.961425456324409, 4.861039825810885}, {-4.922850912648817, 
       4.722079651621771}, {-4.884276368973227, 
       4.583119477432656}, {-4.884276368973227, 4.583119477432655}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-5.432463165002302, 
        4.876231380689784}, {-5.432463165002302, 
        4.876231380689784}, {-5.2883087766682015`, 
        4.917487587126523}, {-5.2883087766682015`, 
        4.917487587126523}, {-5.432463165002302, 4.876231380689784}}], 
       PolygonBox[{{-5.2883087766682015`, 
        4.917487587126523}, {-5.2883087766682015`, 
        4.917487587126523}, {-5.144154388334101, 
        4.9587437935632614`}, {-5.144154388334101, 
        4.9587437935632614`}, {-5.2883087766682015`, 4.917487587126523}}], 
       PolygonBox[{{-5.144154388334101, 
        4.9587437935632614`}, {-5.144154388334101, 4.9587437935632614`}, {-5.,
         5.}, {-5., 5.}, {-5.144154388334101, 4.9587437935632614`}}], 
       PolygonBox[{{-5., 5.}, {-5., 5.}, {-4.8558456116659, 
        5.0412562064367386`}, {-4.8558456116659, 5.0412562064367386`}, {-5., 
        5.}}], PolygonBox[{{-4.8558456116659, 
        5.0412562064367386`}, {-4.8558456116659, 
        5.0412562064367386`}, {-4.7116912233317985`, 
        5.082512412873477}, {-4.7116912233317985`, 
        5.082512412873477}, {-4.8558456116659, 5.0412562064367386`}}], 
       PolygonBox[{{-4.7116912233317985`, 
        5.082512412873477}, {-4.7116912233317985`, 
        5.082512412873477}, {-4.567536834997698, 
        5.123768619310216}, {-4.567536834997698, 
        5.123768619310216}, {-4.7116912233317985`, 5.082512412873477}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-5.432463165002302, 
         4.876231380689784}, {-5.2883087766682015`, 
         4.917487587126523}, {-5.144154388334101, 4.9587437935632614`}, {-5., 
         5.}, {-4.8558456116659, 5.0412562064367386`}, {-4.7116912233317985`, 
         5.082512412873477}, {-4.567536834997698, 
         5.123768619310216}, {-4.567536834997698, 
         5.123768619310216}, {-4.7116912233317985`, 
         5.082512412873477}, {-4.855845611665899, 5.0412562064367386`}, {-5., 
         5.}, {-5.1441543883341, 4.9587437935632614`}, {-5.2883087766682015`, 
         4.917487587126523}, {-5.432463165002302, 
         4.876231380689784}, {-5.432463165002302, 4.876231380689784}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-5.316739533975529, 
      4.4593508581224395`}, {-5.548186796029076, 
      5.293111903257128}, {-4.683260466024471, 
      5.5406491418775605`}, {-4.451813203970924, 
      4.706888096742872}, {-5.316739533975529, 4.4593508581224395`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-5.316739533975529, 4.4593508581224395`}, {-5.548186796029076,
        5.293111903257128}, {-4.683260466024471, 
       5.5406491418775605`}, {-4.451813203970924, 
       4.706888096742872}, {-5.316739533975529, 4.4593508581224395`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.118057072591385, -5.416370172410978}, \
{-4.118057072591385, -5.416370172410978}, {-4.0787047150609235`, \
-5.277580114940652}, {-4.0787047150609235`, -5.277580114940652}, \
{-4.118057072591385, -5.416370172410978}}], 
     PolygonBox[{{-4.0787047150609235`, -5.277580114940652}, \
{-4.0787047150609235`, -5.277580114940652}, {-4.039352357530461, \
-5.138790057470326}, {-4.039352357530461, -5.138790057470326}, \
{-4.0787047150609235`, -5.277580114940652}}], 
     PolygonBox[{{-4.039352357530461, -5.138790057470326}, \
{-4.039352357530461, -5.138790057470326}, {-4., -5.}, {-4., -5.}, \
{-4.039352357530461, -5.138790057470326}}], 
     PolygonBox[{{-4., -5.}, {-4., -5.}, {-3.9606476424695383`, \
-4.861209942529674}, {-3.9606476424695383`, -4.861209942529674}, {-4., -5.}}],
      PolygonBox[{{-3.9606476424695383`, -4.861209942529674}, \
{-3.9606476424695383`, -4.861209942529674}, {-3.9212952849390765`, \
-4.722419885059348}, {-3.9212952849390765`, -4.722419885059348}, \
{-3.9606476424695383`, -4.861209942529674}}], 
     PolygonBox[{{-3.9212952849390765`, -4.722419885059348}, \
{-3.9212952849390765`, -4.722419885059348}, {-3.881942927408615, \
-4.583629827589022}, {-3.881942927408615, -4.583629827589022}, \
{-3.9212952849390765`, -4.722419885059348}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.118057072591385, -5.416370172410978}, \
{-4.0787047150609235`, -5.277580114940652}, {-4.039352357530461, \
-5.138790057470326}, {-4., -5.}, {-3.9606476424695383`, -4.861209942529674}, \
{-3.9212952849390765`, -4.722419885059348}, {-3.881942927408615, \
-4.583629827589022}, {-3.881942927408615, -4.583629827589022}, \
{-3.9212952849390765`, -4.722419885059348}, {-3.9606476424695383`, \
-4.861209942529674}, {-4., -5.}, {-4.039352357530461, -5.138790057470326}, \
{-4.0787047150609235`, -5.277580114940652}, {-4.118057072591385, \
-5.416370172410978}, {-4.118057072591385, -5.416370172410978}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.432779226478679, -4.8767181800199015`}, \
{-4.432779226478679, -4.8767181800199015`}, {-4.288519484319119, \
-4.917812120013267}, {-4.28851948431912, -4.917812120013267}, \
{-4.432779226478679, -4.8767181800199015`}}], 
       PolygonBox[{{-4.28851948431912, -4.917812120013267}, \
{-4.288519484319119, -4.917812120013267}, {-4.1442597421595595`, \
-4.958906060006634}, {-4.1442597421595595`, -4.958906060006634}, \
{-4.28851948431912, -4.917812120013267}}], 
       PolygonBox[{{-4.1442597421595595`, -4.958906060006634}, \
{-4.1442597421595595`, -4.958906060006634}, {-4., -5.}, {-4., -5.}, \
{-4.1442597421595595`, -4.958906060006634}}], 
       PolygonBox[{{-4., -5.}, {-4., -5.}, {-3.8557402578404405`, \
-5.041093939993366}, {-3.8557402578404405`, -5.041093939993366}, {-4., -5.}}],
        PolygonBox[{{-3.8557402578404405`, -5.041093939993366}, \
{-3.8557402578404405`, -5.041093939993366}, {-3.7114805156808806`, \
-5.082187879986733}, {-3.7114805156808806`, -5.082187879986733}, \
{-3.8557402578404405`, -5.041093939993366}}], 
       PolygonBox[{{-3.7114805156808806`, -5.082187879986733}, \
{-3.7114805156808806`, -5.082187879986733}, {-3.5672207735213206`, \
-5.1232818199800985`}, {-3.567220773521321, -5.1232818199800985`}, \
{-3.7114805156808806`, -5.082187879986733}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.432779226478679, -4.8767181800199015`}, \
{-4.28851948431912, -4.917812120013267}, {-4.1442597421595595`, \
-4.958906060006634}, {-4., -5.}, {-3.8557402578404405`, -5.041093939993366}, \
{-3.7114805156808806`, -5.082187879986733}, {-3.567220773521321, \
-5.1232818199800985`}, {-3.5672207735213206`, -5.1232818199800985`}, \
{-3.7114805156808806`, -5.082187879986733}, {-3.85574025784044, \
-5.041093939993366}, {-4., -5.}, {-4.1442597421595595`, -4.958906060006634}, \
{-4.288519484319119, -4.917812120013267}, {-4.432779226478679, \
-4.8767181800199015`}, {-4.432779226478679, -4.8767181800199015`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.550836299070064, -5.293088352430879}, \
{-4.314722153887294, -4.460348007608924}, {-3.449163700929936, \
-4.706911647569121}, {-3.685277846112706, -5.539651992391076}, \
{-4.550836299070064, -5.293088352430879}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.550836299070064, -5.293088352430879}, {-4.314722153887294, \
-4.460348007608924}, {-3.449163700929936, -4.706911647569121}, \
{-3.685277846112706, -5.539651992391076}, {-4.550836299070064, \
-5.293088352430879}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.096014437278273, -4.427554247956007}, \
{-4.096014437278273, -4.427554247956007}, {-4.064009624852182, \
-4.285036165304004}, {-4.064009624852182, -4.285036165304004}, \
{-4.096014437278273, -4.427554247956007}}], 
     PolygonBox[{{-4.064009624852182, -4.285036165304004}, \
{-4.064009624852182, -4.285036165304004}, {-4.032004812426091, \
-4.1425180826520025`}, {-4.032004812426091, -4.1425180826520025`}, \
{-4.064009624852182, -4.285036165304004}}], 
     PolygonBox[{{-4.032004812426091, -4.1425180826520025`}, \
{-4.032004812426091, -4.1425180826520025`}, {-4., -4.}, {-4., -4.}, \
{-4.032004812426091, -4.1425180826520025`}}], 
     PolygonBox[{{-4., -4.}, {-4., -4.}, {-3.967995187573909, \
-3.857481917347998}, {-3.967995187573909, -3.857481917347998}, {-4., -4.}}], 
     PolygonBox[{{-3.967995187573909, -3.857481917347998}, \
{-3.967995187573909, -3.857481917347998}, {-3.9359903751478176`, \
-3.714963834695996}, {-3.9359903751478176`, -3.714963834695996}, \
{-3.967995187573909, -3.857481917347998}}], 
     PolygonBox[{{-3.9359903751478176`, -3.714963834695996}, \
{-3.9359903751478176`, -3.714963834695996}, {-3.9039855627217266`, \
-3.5724457520439934`}, {-3.9039855627217266`, -3.572445752043994}, \
{-3.9359903751478176`, -3.714963834695996}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.096014437278273, -4.427554247956007}, {-4.064009624852182, \
-4.285036165304004}, {-4.032004812426091, -4.1425180826520025`}, {-4., -4.}, \
{-3.967995187573909, -3.857481917347998}, {-3.9359903751478176`, \
-3.714963834695996}, {-3.9039855627217266`, -3.572445752043994}, \
{-3.9039855627217266`, -3.5724457520439934`}, {-3.9359903751478176`, \
-3.714963834695996}, {-3.967995187573909, -3.857481917347998}, {-4., -4.}, \
{-4.032004812426091, -4.1425180826520025`}, {-4.064009624852182, \
-4.285036165304004}, {-4.096014437278273, -4.427554247956007}, \
{-4.096014437278273, -4.427554247956007}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.437878744053974, -3.8976350016416244`}, \
{-4.437878744053974, -3.8976350016416244`}, {-4.29191916270265, \
-3.931756667761083}, {-4.29191916270265, -3.931756667761083}, \
{-4.437878744053974, -3.8976350016416244`}}], 
       PolygonBox[{{-4.29191916270265, -3.931756667761083}, \
{-4.29191916270265, -3.931756667761083}, {-4.145959581351325, \
-3.9658783338805415`}, {-4.145959581351325, -3.9658783338805415`}, \
{-4.29191916270265, -3.931756667761083}}], 
       PolygonBox[{{-4.145959581351325, -3.9658783338805415`}, \
{-4.145959581351325, -3.9658783338805415`}, {-4., -4.}, {-4., -4.}, \
{-4.145959581351325, -3.9658783338805415`}}], 
       PolygonBox[{{-4., -4.}, {-4., -4.}, {-3.854040418648675, \
-4.034121666119458}, {-3.854040418648675, -4.034121666119458}, {-4., -4.}}], 
       PolygonBox[{{-3.854040418648675, -4.034121666119458}, \
{-3.854040418648675, -4.034121666119458}, {-3.7080808372973504`, \
-4.068243332238917}, {-3.7080808372973504`, -4.068243332238917}, \
{-3.854040418648675, -4.034121666119458}}], 
       PolygonBox[{{-3.7080808372973504`, -4.068243332238917}, \
{-3.7080808372973504`, -4.068243332238917}, {-3.5621212559460256`, \
-4.102364998358375}, {-3.5621212559460256`, -4.102364998358375}, \
{-3.7080808372973504`, -4.068243332238917}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.437878744053974, -3.8976350016416244`}, \
{-4.29191916270265, -3.931756667761083}, {-4.145959581351325, \
-3.9658783338805415`}, {-4., -4.}, {-3.854040418648675, -4.034121666119458}, \
{-3.7080808372973504`, -4.068243332238917}, {-3.5621212559460256`, \
-4.102364998358375}, {-3.5621212559460256`, -4.102364998358375}, \
{-3.7080808372973504`, -4.068243332238917}, {-3.854040418648675, \
-4.034121666119458}, {-4., -4.}, {-4.145959581351325, -3.9658783338805415`}, \
{-4.29191916270265, -3.931756667761083}, {-4.437878744053974, \
-3.8976350016416244`}, {-4.437878744053974, -3.8976350016416244`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.533893181332248, -4.3251892495976305`}, \
{-4.341864306775701, -3.470080753685618}, {-3.466106818667752, \
-3.674810750402369}, {-3.658135693224299, -4.529919246314382}, \
{-4.533893181332248, -4.3251892495976305`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.533893181332248, -4.3251892495976305`}, \
{-4.341864306775701, -3.470080753685618}, {-3.466106818667752, \
-3.674810750402369}, {-3.658135693224299, -4.529919246314382}, \
{-4.533893181332248, -4.3251892495976305`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.072968589955883, -3.436939417382768}, \
{-4.072968589955882, -3.436939417382768}, {-4.048645726637255, \
-3.291292944921845}, {-4.048645726637255, -3.2912929449218455`}, \
{-4.072968589955883, -3.436939417382768}}], 
     PolygonBox[{{-4.048645726637255, -3.2912929449218455`}, \
{-4.048645726637255, -3.291292944921845}, {-4.024322863318627, \
-3.1456464724609225`}, {-4.024322863318628, -3.1456464724609225`}, \
{-4.048645726637255, -3.2912929449218455`}}], 
     PolygonBox[{{-4.024322863318628, -3.1456464724609225`}, \
{-4.024322863318627, -3.1456464724609225`}, {-4., -3.}, {-4., -3.}, \
{-4.024322863318628, -3.1456464724609225`}}], 
     PolygonBox[{{-4., -3.}, {-4., -3.}, {-3.9756771366813726`, \
-2.8543535275390775`}, {-3.9756771366813726`, -2.8543535275390775`}, {-4., \
-3.}}], PolygonBox[{{-3.9756771366813726`, -2.8543535275390775`}, \
{-3.9756771366813726`, -2.8543535275390775`}, {-3.951354273362745, \
-2.708707055078155}, {-3.951354273362745, -2.708707055078155}, \
{-3.9756771366813726`, -2.8543535275390775`}}], 
     PolygonBox[{{-3.951354273362745, -2.708707055078155}, \
{-3.951354273362745, -2.708707055078155}, {-3.9270314100441177`, \
-2.563060582617232}, {-3.9270314100441177`, -2.563060582617232}, \
{-3.951354273362745, -2.708707055078155}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.072968589955883, -3.436939417382768}, {-4.048645726637255, \
-3.2912929449218455`}, {-4.024322863318628, -3.1456464724609225`}, {-4., \
-3.}, {-3.9756771366813726`, -2.8543535275390775`}, {-3.951354273362745, \
-2.708707055078155}, {-3.9270314100441177`, -2.563060582617232}, \
{-3.9270314100441177`, -2.563060582617232}, {-3.951354273362745, \
-2.7087070550781545`}, {-3.9756771366813726`, -2.8543535275390775`}, {-4., \
-3.}, {-4.024322863318628, -3.1456464724609225`}, {-4.048645726637255, \
-3.291292944921845}, {-4.072968589955883, -3.436939417382768}, \
{-4.072968589955883, -3.436939417382768}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.442022402120948, -2.920882805806465}, \
{-4.442022402120948, -2.920882805806465}, {-4.2946816014139655`, \
-2.9472552038709767`}, {-4.2946816014139655`, -2.9472552038709767`}, \
{-4.442022402120948, -2.920882805806465}}], 
       PolygonBox[{{-4.2946816014139655`, -2.9472552038709767`}, \
{-4.2946816014139655`, -2.9472552038709767`}, {-4.147340800706983, \
-2.973627601935488}, {-4.147340800706982, -2.973627601935488}, \
{-4.2946816014139655`, -2.9472552038709767`}}], 
       PolygonBox[{{-4.147340800706982, -2.973627601935488}, \
{-4.147340800706983, -2.973627601935488}, {-4., -3.}, {-4., -3.}, \
{-4.147340800706982, -2.973627601935488}}], 
       PolygonBox[{{-4., -3.}, {-4., -3.}, {-3.8526591992930173`, \
-3.026372398064512}, {-3.8526591992930173`, -3.026372398064512}, {-4., -3.}}],
        PolygonBox[{{-3.8526591992930173`, -3.026372398064512}, \
{-3.8526591992930173`, -3.026372398064512}, {-3.7053183985860345`, \
-3.0527447961290233`}, {-3.7053183985860345`, -3.0527447961290233`}, \
{-3.8526591992930173`, -3.026372398064512}}], 
       PolygonBox[{{-3.7053183985860345`, -3.0527447961290233`}, \
{-3.7053183985860345`, -3.0527447961290233`}, {-3.557977597879052, \
-3.079117194193535}, {-3.557977597879052, -3.079117194193535}, \
{-3.7053183985860345`, -3.0527447961290233`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.442022402120948, -2.920882805806465}, \
{-4.2946816014139655`, -2.9472552038709767`}, {-4.147340800706982, \
-2.973627601935488}, {-4., -3.}, {-3.8526591992930173`, -3.026372398064512}, \
{-3.7053183985860345`, -3.0527447961290233`}, {-3.557977597879052, \
-3.079117194193535}, {-3.5579775978790518`, -3.079117194193535}, \
{-3.7053183985860345`, -3.0527447961290233`}, {-3.8526591992930173`, \
-3.026372398064512}, {-4., -3.}, {-4.147340800706982, -2.973627601935488}, \
{-4.2946816014139655`, -2.9472552038709767`}, {-4.442022402120948, \
-2.920882805806465}, {-4.442022402120948, -2.920882805806465}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.5149909920768305`, -3.357822223189233}, \
{-4.369053812165066, -2.4839433884236968`}, {-3.4850090079231695`, \
-2.642177776810767}, {-3.630946187834934, -3.5160566115763032`}, \
{-4.5149909920768305`, -3.357822223189233}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.5149909920768305`, -3.357822223189233}, \
{-4.369053812165066, -2.4839433884236968`}, {-3.4850090079231695`, \
-2.642177776810767}, {-3.630946187834934, -3.5160566115763032`}, \
{-4.5149909920768305`, -3.357822223189233}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.04911807263465, -2.444049074423594}, {-4.04911807263465, \
-2.444049074423594}, {-4.032745381756433, -2.296032716282396}, \
{-4.032745381756434, -2.296032716282396}, {-4.04911807263465, \
-2.444049074423594}}], 
     PolygonBox[{{-4.032745381756434, -2.296032716282396}, \
{-4.032745381756433, -2.296032716282396}, {-4.0163726908782165`, \
-2.148016358141198}, {-4.0163726908782165`, -2.148016358141198}, \
{-4.032745381756434, -2.296032716282396}}], 
     PolygonBox[{{-4.0163726908782165`, -2.148016358141198}, \
{-4.0163726908782165`, -2.148016358141198}, {-4., -2.}, {-4., -2.}, \
{-4.0163726908782165`, -2.148016358141198}}], 
     PolygonBox[{{-4., -2.}, {-4., -2.}, {-3.983627309121783, \
-1.851983641858802}, {-3.983627309121783, -1.851983641858802}, {-4., -2.}}], 
     PolygonBox[{{-3.983627309121783, -1.851983641858802}, \
{-3.983627309121783, -1.851983641858802}, {-3.9672546182435666`, \
-1.703967283717604}, {-3.9672546182435666`, -1.703967283717604}, \
{-3.983627309121783, -1.851983641858802}}], 
     PolygonBox[{{-3.9672546182435666`, -1.703967283717604}, \
{-3.9672546182435666`, -1.703967283717604}, {-3.9508819273653497`, \
-1.5559509255764061`}, {-3.9508819273653497`, -1.5559509255764061`}, \
{-3.9672546182435666`, -1.703967283717604}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.04911807263465, -2.444049074423594}, {-4.032745381756434, \
-2.296032716282396}, {-4.0163726908782165`, -2.148016358141198}, {-4., -2.}, \
{-3.983627309121783, -1.851983641858802}, {-3.9672546182435666`, \
-1.703967283717604}, {-3.9508819273653497`, -1.5559509255764061`}, \
{-3.9508819273653497`, -1.5559509255764061`}, {-3.9672546182435666`, \
-1.703967283717604}, {-3.983627309121783, -1.851983641858802}, {-4., -2.}, \
{-4.0163726908782165`, -2.1480163581411977`}, {-4.032745381756434, \
-2.296032716282396}, {-4.04911807263465, -2.4440490744235936`}, \
{-4.04911807263465, -2.444049074423594}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.445083645356384, -1.9460756600021216`}, \
{-4.445083645356384, -1.9460756600021216`}, {-4.2967224302375895`, \
-1.9640504400014145`}, {-4.2967224302375895`, -1.9640504400014145`}, \
{-4.445083645356384, -1.9460756600021216`}}], 
       PolygonBox[{{-4.2967224302375895`, -1.9640504400014145`}, \
{-4.2967224302375895`, -1.9640504400014145`}, {-4.148361215118794, \
-1.9820252200007071`}, {-4.148361215118794, -1.9820252200007071`}, \
{-4.2967224302375895`, -1.9640504400014145`}}], 
       PolygonBox[{{-4.148361215118794, -1.9820252200007071`}, \
{-4.148361215118794, -1.9820252200007071`}, {-4., -2.}, {-4., -2.}, \
{-4.148361215118794, -1.9820252200007071`}}], 
       PolygonBox[{{-4., -2.}, {-4., -2.}, {-3.8516387848812053`, \
-2.017974779999293}, {-3.8516387848812053`, -2.017974779999293}, {-4., -2.}}],
        PolygonBox[{{-3.8516387848812053`, -2.017974779999293}, \
{-3.8516387848812053`, -2.017974779999293}, {-3.703277569762411, \
-2.0359495599985857`}, {-3.703277569762411, -2.0359495599985853`}, \
{-3.8516387848812053`, -2.017974779999293}}], 
       PolygonBox[{{-3.703277569762411, -2.0359495599985853`}, \
{-3.703277569762411, -2.0359495599985857`}, {-3.554916354643616, \
-2.053924339997878}, {-3.554916354643616, -2.053924339997878}, \
{-3.703277569762411, -2.0359495599985853`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.445083645356384, -1.9460756600021216`}, \
{-4.2967224302375895`, -1.9640504400014145`}, {-4.148361215118794, \
-1.9820252200007071`}, {-4., -2.}, {-3.8516387848812053`, \
-2.017974779999293}, {-3.703277569762411, -2.0359495599985857`}, \
{-3.554916354643616, -2.053924339997878}, {-3.554916354643616, \
-2.053924339997878}, {-3.7032775697624105`, -2.0359495599985857`}, \
{-3.8516387848812053`, -2.017974779999293}, {-4., -2.}, {-4.148361215118794, \
-1.9820252200007071`}, {-4.2967224302375895`, -1.9640504400014145`}, \
{-4.445083645356384, -1.9460756600021216`}, {-4.445083645356384, \
-1.9460756600021216`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.494201717991034, -2.3901247344257155`}, \
{-4.3959655727217335`, -1.5020265855785278`}, {-3.505798282008966, \
-1.6098752655742845`}, {-3.6040344272782665`, -2.4979734144214722`}, \
{-4.494201717991034, -2.3901247344257155`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.494201717991034, -2.3901247344257155`}, \
{-4.3959655727217335`, -1.5020265855785278`}, {-3.505798282008966, \
-1.6098752655742845`}, {-3.6040344272782665`, -2.4979734144214722`}, \
{-4.494201717991034, -2.3901247344257155`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.0247041546611975`, -1.4484894578920566`}, \
{-4.0247041546611975`, -1.4484894578920566`}, {-4.016469436440798, \
-1.2989929719280378`}, {-4.016469436440798, -1.2989929719280378`}, \
{-4.0247041546611975`, -1.4484894578920566`}}], 
     PolygonBox[{{-4.016469436440798, -1.2989929719280378`}, \
{-4.016469436440798, -1.2989929719280378`}, {-4.0082347182203995`, \
-1.1494964859640189`}, {-4.0082347182203995`, -1.1494964859640189`}, \
{-4.016469436440798, -1.2989929719280378`}}], 
     PolygonBox[{{-4.0082347182203995`, -1.1494964859640189`}, \
{-4.0082347182203995`, -1.1494964859640189`}, {-4., -1.0000000000000002`}, \
{-4., -1.}, {-4.0082347182203995`, -1.1494964859640189`}}], 
     PolygonBox[{{-4., -1.}, {-4., -1.}, {-3.9917652817796005`, \
-0.8505035140359812}, {-3.991765281779601, -0.8505035140359812}, {-4., -1.}}],
      PolygonBox[{{-3.991765281779601, -0.8505035140359812}, \
{-3.9917652817796005`, -0.8505035140359812}, {-3.9835305635592015`, \
-0.7010070280719625}, {-3.9835305635592015`, -0.7010070280719624}, \
{-3.991765281779601, -0.8505035140359812}}], 
     PolygonBox[{{-3.9835305635592015`, -0.7010070280719624}, \
{-3.9835305635592015`, -0.7010070280719625}, {-3.9752958453388025`, \
-0.5515105421079436}, {-3.9752958453388025`, -0.5515105421079436}, \
{-3.9835305635592015`, -0.7010070280719624}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.0247041546611975`, -1.4484894578920566`}, \
{-4.016469436440798, -1.2989929719280378`}, {-4.0082347182203995`, \
-1.1494964859640189`}, {-4., -1.}, {-3.991765281779601, -0.8505035140359812}, \
{-3.9835305635592015`, -0.7010070280719624}, {-3.9752958453388025`, \
-0.5515105421079436}, {-3.9752958453388025`, -0.5515105421079435}, \
{-3.9835305635592015`, -0.7010070280719622}, {-3.991765281779601, \
-0.8505035140359811}, {-4., -1.}, {-4.0082347182203995`, \
-1.1494964859640189`}, {-4.016469436440798, -1.2989929719280378`}, \
{-4.0247041546611975`, -1.4484894578920564`}, {-4.0247041546611975`, \
-1.4484894578920566`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.446962986985003, -0.9726703292708302}, \
{-4.446962986985003, -0.9726703292708302}, {-4.297975324656669, \
-0.9817802195138868}, {-4.297975324656669, -0.9817802195138868}, \
{-4.446962986985003, -0.9726703292708302}}], 
       PolygonBox[{{-4.297975324656669, -0.9817802195138868}, \
{-4.297975324656669, -0.9817802195138868}, {-4.148987662328334, \
-0.9908901097569434}, {-4.148987662328334, -0.9908901097569434}, \
{-4.297975324656669, -0.9817802195138868}}], 
       PolygonBox[{{-4.148987662328334, -0.9908901097569434}, \
{-4.148987662328334, -0.9908901097569434}, {-4., -1.}, {-4., -1.}, \
{-4.148987662328334, -0.9908901097569434}}], 
       PolygonBox[{{-4., -1.}, {-4., -1.}, {-3.8510123376716656`, \
-1.0091098902430566`}, {-3.8510123376716656`, -1.0091098902430566`}, {-4., \
-1.}}], PolygonBox[{{-3.8510123376716656`, -1.0091098902430566`}, \
{-3.8510123376716656`, -1.0091098902430566`}, {-3.7020246753433312`, \
-1.018219780486113}, {-3.7020246753433312`, -1.018219780486113}, \
{-3.8510123376716656`, -1.0091098902430566`}}], 
       PolygonBox[{{-3.7020246753433312`, -1.018219780486113}, \
{-3.7020246753433312`, -1.018219780486113}, {-3.553037013014997, \
-1.0273296707291697`}, {-3.553037013014997, -1.0273296707291697`}, \
{-3.7020246753433312`, -1.018219780486113}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.446962986985003, -0.9726703292708302}, \
{-4.297975324656669, -0.9817802195138868}, {-4.148987662328334, \
-0.9908901097569434}, {-4., -1.}, {-3.8510123376716656`, \
-1.0091098902430566`}, {-3.7020246753433312`, -1.0182197804861133`}, \
{-3.553037013014997, -1.0273296707291697`}, {-3.553037013014997, \
-1.0273296707291697`}, {-3.7020246753433312`, -1.0182197804861133`}, \
{-3.8510123376716656`, -1.0091098902430566`}, {-4., -1.}, \
{-4.148987662328334, -0.9908901097569435}, {-4.297975324656669, \
-0.9817802195138868}, {-4.446962986985003, -0.9726703292708303}, \
{-4.446962986985003, -0.9726703292708302}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.471667141646201, -1.4211597871628867`}, \
{-4.422258832323806, -0.5241808713787737}, {-3.5283328583537994`, \
-0.5788402128371133}, {-3.5777411676761943`, -1.4758191286212263`}, \
{-4.471667141646201, -1.4211597871628867`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.471667141646201, -1.4211597871628867`}, \
{-4.422258832323806, -0.5241808713787737}, {-3.5283328583537994`, \
-0.5788402128371133}, {-3.5777411676761943`, -1.4758191286212263`}, \
{-4.471667141646201, -1.4211597871628867`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4., -0.45}, {-4., -0.45}, {-4., -0.3}, {-4., \
-0.30000000000000004`}, {-4., -0.45}}], 
     PolygonBox[{{-4., -0.30000000000000004`}, {-4., -0.3}, {-4., \
-0.15000000000000008`}, {-4., -0.15000000000000002`}, {-4., \
-0.30000000000000004`}}], 
     PolygonBox[{{-4., -0.15000000000000002`}, {-4., -0.15000000000000008`}, \
{-4., -1.1102230246251565`*^-16}, {-4., 0.}, {-4., -0.15000000000000002`}}], 
     PolygonBox[{{-4., 0.}, {-4., 0.}, {-4., 0.14999999999999997`}, {-4., 
      0.14999999999999997`}, {-4., 0.}}], 
     PolygonBox[{{-4., 0.14999999999999997`}, {-4., 
      0.14999999999999997`}, {-4., 0.29999999999999993`}, {-4., 0.3}, {-4., 
      0.14999999999999997`}}], 
     PolygonBox[{{-4., 0.3}, {-4., 0.29999999999999993`}, {-4., 
      0.44999999999999996`}, {-4., 0.4499999999999999}, {-4., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4., -0.45}, {-4., -0.30000000000000004`}, {-4., \
-0.15000000000000002`}, {-4., -5.551115123125783*^-17}, {-4., 
       0.14999999999999997`}, {-4., 0.3}, {-4., 0.4499999999999999}, {-4., 
       0.45}, {-4., 0.30000000000000004`}, {-4., 0.15000000000000002`}, {-4., 
       5.551115123125783*^-17}, {-4., -0.14999999999999997`}, {-4., -0.3}, \
{-4., -0.4499999999999999}, {-4., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.4475967445892515`, 0.}, {-4.4475967445892515`, 
        5.5109105961630896`*^-17}, {-4.298397829726168, 
        4.592425496802574*^-17}, {-4.298397829726168, 
        9.184850993605149*^-18}, {-4.4475967445892515`, 0.}}], 
       PolygonBox[{{-4.298397829726168, 
        9.184850993605149*^-18}, {-4.298397829726168, 
        4.592425496802574*^-17}, {-4.149198914863084, 
        3.67394039744206*^-17}, {-4.149198914863084, 
        1.8369701987210297`*^-17}, {-4.298397829726168, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{-4.149198914863084, 
        1.8369701987210297`*^-17}, {-4.149198914863084, 
        3.67394039744206*^-17}, {-4., 2.7554552980815454`*^-17}, {-4., 
        2.7554552980815448`*^-17}, {-4.149198914863084, 
        1.8369701987210297`*^-17}}], 
       PolygonBox[{{-4., 2.7554552980815448`*^-17}, {-4., 
        2.7554552980815448`*^-17}, {-3.850801085136916, 
        1.83697019872103*^-17}, {-3.850801085136916, 
        3.6739403974420595`*^-17}, {-4., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{-3.850801085136916, 
        3.6739403974420595`*^-17}, {-3.850801085136916, 
        1.83697019872103*^-17}, {-3.701602170273832, 
        9.184850993605152*^-18}, {-3.701602170273832, 
        4.592425496802574*^-17}, {-3.850801085136916, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{-3.701602170273832, 
        4.592425496802574*^-17}, {-3.701602170273832, 
        9.184850993605153*^-18}, {-3.552403255410748, 
        4.5887548728832574`*^-33}, {-3.552403255410748, 
        5.510910596163089*^-17}, {-3.701602170273832, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.4475967445892515`, 0.}, {-4.298397829726168, 
         0.}, {-4.149198914863084, 0.}, {-4., 0.}, {-3.850801085136916, 
         0.}, {-3.701602170273832, 0.}, {-3.552403255410748, 
         0.}, {-3.552403255410748, 0.}, {-3.701602170273832, 
         0.}, {-3.850801085136916, 0.}, {-4., 0.}, {-4.149198914863084, 
         0.}, {-4.298397829726168, 0.}, {-4.4475967445892515`, 
         0.}, {-4.4475967445892515`, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.4475967445892515`, -0.45}, {-4.4475967445892515`, 
      0.45}, {-3.552403255410748, 
      0.45}, {-3.552403255410748, -0.45}, {-4.4475967445892515`, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.4475967445892515`, -0.45}, {-4.4475967445892515`, 
       0.45}, {-3.552403255410748, 
       0.45}, {-3.552403255410748, -0.45}, {-4.4475967445892515`, -0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.9752958453388025`, 
      0.5515105421079435}, {-3.975295845338802, 
      0.5515105421079435}, {-3.9835305635592015`, 
      0.7010070280719624}, {-3.9835305635592015`, 
      0.7010070280719622}, {-3.9752958453388025`, 0.5515105421079435}}], 
     PolygonBox[{{-3.9835305635592015`, 
      0.7010070280719622}, {-3.9835305635592015`, 
      0.7010070280719624}, {-3.9917652817796005`, 
      0.8505035140359811}, {-3.991765281779601, 
      0.8505035140359811}, {-3.9835305635592015`, 0.7010070280719622}}], 
     PolygonBox[{{-3.991765281779601, 
      0.8505035140359811}, {-3.9917652817796005`, 0.8505035140359811}, {-4., 
      0.9999999999999999}, {-4., 1.}, {-3.991765281779601, 
      0.8505035140359811}}], 
     PolygonBox[{{-4., 1.}, {-4., 1.}, {-4.0082347182203995`, 
      1.1494964859640189`}, {-4.0082347182203995`, 1.1494964859640189`}, {-4.,
       1.}}], PolygonBox[{{-4.0082347182203995`, 
      1.1494964859640189`}, {-4.0082347182203995`, 
      1.1494964859640189`}, {-4.016469436440798, 
      1.2989929719280375`}, {-4.016469436440798, 
      1.2989929719280378`}, {-4.0082347182203995`, 1.1494964859640189`}}], 
     PolygonBox[{{-4.016469436440798, 
      1.2989929719280378`}, {-4.016469436440798, 
      1.2989929719280375`}, {-4.0247041546611975`, 
      1.4484894578920564`}, {-4.0247041546611975`, 
      1.4484894578920564`}, {-4.016469436440798, 1.2989929719280378`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.9752958453388025`, 
       0.5515105421079435}, {-3.9835305635592015`, 
       0.7010070280719622}, {-3.991765281779601, 0.8505035140359811}, {-4., 
       1.}, {-4.0082347182203995`, 1.1494964859640189`}, {-4.016469436440798, 
       1.2989929719280378`}, {-4.0247041546611975`, 
       1.4484894578920564`}, {-4.0247041546611975`, 
       1.4484894578920566`}, {-4.016469436440798, 
       1.2989929719280378`}, {-4.0082347182203995`, 
       1.1494964859640189`}, {-4., 1.}, {-3.991765281779601, 
       0.8505035140359812}, {-3.9835305635592015`, 
       0.7010070280719624}, {-3.9752958453388025`, 
       0.5515105421079436}, {-3.9752958453388025`, 0.5515105421079435}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.446962986985003, 
        0.9726703292708302}, {-4.446962986985003, 
        0.9726703292708303}, {-4.297975324656669, 
        0.9817802195138868}, {-4.297975324656669, 
        0.9817802195138868}, {-4.446962986985003, 0.9726703292708302}}], 
       PolygonBox[{{-4.297975324656669, 
        0.9817802195138868}, {-4.297975324656669, 
        0.9817802195138868}, {-4.148987662328334, 
        0.9908901097569435}, {-4.148987662328334, 
        0.9908901097569435}, {-4.297975324656669, 0.9817802195138868}}], 
       PolygonBox[{{-4.148987662328334, 
        0.9908901097569435}, {-4.148987662328334, 0.9908901097569435}, {-4., 
        1.}, {-4., 1.}, {-4.148987662328334, 0.9908901097569435}}], 
       PolygonBox[{{-4., 1.}, {-4., 1.}, {-3.8510123376716656`, 
        1.0091098902430566`}, {-3.8510123376716656`, 
        1.0091098902430566`}, {-4., 1.}}], 
       PolygonBox[{{-3.8510123376716656`, 
        1.0091098902430566`}, {-3.8510123376716656`, 
        1.0091098902430566`}, {-3.7020246753433312`, 
        1.0182197804861133`}, {-3.7020246753433312`, 
        1.0182197804861133`}, {-3.8510123376716656`, 1.0091098902430566`}}], 
       PolygonBox[{{-3.7020246753433312`, 
        1.0182197804861133`}, {-3.7020246753433312`, 
        1.0182197804861133`}, {-3.553037013014997, 
        1.0273296707291697`}, {-3.553037013014997, 
        1.0273296707291697`}, {-3.7020246753433312`, 1.0182197804861133`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.446962986985003, 
         0.9726703292708302}, {-4.297975324656669, 
         0.9817802195138868}, {-4.148987662328334, 0.9908901097569434}, {-4., 
         1.}, {-3.8510123376716656`, 
         1.0091098902430566`}, {-3.7020246753433312`, 
         1.0182197804861133`}, {-3.553037013014997, 
         1.0273296707291697`}, {-3.553037013014997, 
         1.0273296707291697`}, {-3.7020246753433312`, 
         1.0182197804861133`}, {-3.8510123376716656`, 
         1.0091098902430566`}, {-4., 1.}, {-4.148987662328334, 
         0.9908901097569435}, {-4.297975324656669, 
         0.9817802195138868}, {-4.446962986985003, 
         0.9726703292708303}, {-4.446962986985003, 
         0.9726703292708302}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.422258832323806, 
      0.5241808713787737}, {-4.471667141646201, 
      1.4211597871628867`}, {-3.5777411676761943`, 
      1.4758191286212263`}, {-3.5283328583537994`, 
      0.5788402128371133}, {-4.422258832323806, 0.5241808713787737}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.422258832323806, 0.5241808713787737}, {-4.471667141646201, 
       1.4211597871628867`}, {-3.5777411676761943`, 
       1.4758191286212263`}, {-3.5283328583537994`, 
       0.5788402128371133}, {-4.422258832323806, 0.5241808713787737}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.9508819273653497`, 
      1.5559509255764061`}, {-3.9508819273653497`, 
      1.5559509255764061`}, {-3.9672546182435666`, 
      1.703967283717604}, {-3.9672546182435666`, 
      1.703967283717604}, {-3.9508819273653497`, 1.5559509255764061`}}], 
     PolygonBox[{{-3.9672546182435666`, 
      1.703967283717604}, {-3.9672546182435666`, 
      1.703967283717604}, {-3.983627309121783, 
      1.851983641858802}, {-3.983627309121783, 
      1.851983641858802}, {-3.9672546182435666`, 1.703967283717604}}], 
     PolygonBox[{{-3.983627309121783, 1.851983641858802}, {-3.983627309121783,
       1.851983641858802}, {-4., 2.}, {-4., 2.}, {-3.983627309121783, 
      1.851983641858802}}], 
     PolygonBox[{{-4., 2.}, {-4., 2.}, {-4.0163726908782165`, 
      2.1480163581411977`}, {-4.0163726908782165`, 2.1480163581411977`}, {-4.,
       2.}}], PolygonBox[{{-4.0163726908782165`, 
      2.1480163581411977`}, {-4.0163726908782165`, 
      2.1480163581411977`}, {-4.032745381756433, 
      2.296032716282396}, {-4.032745381756434, 
      2.296032716282396}, {-4.0163726908782165`, 2.1480163581411977`}}], 
     PolygonBox[{{-4.032745381756434, 2.296032716282396}, {-4.032745381756433,
       2.296032716282396}, {-4.04911807263465, 
      2.444049074423594}, {-4.04911807263465, 
      2.4440490744235936`}, {-4.032745381756434, 2.296032716282396}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.9508819273653497`, 
       1.5559509255764061`}, {-3.9672546182435666`, 
       1.703967283717604}, {-3.983627309121783, 1.851983641858802}, {-4., 
       2.}, {-4.0163726908782165`, 2.1480163581411977`}, {-4.032745381756434, 
       2.296032716282396}, {-4.04911807263465, 
       2.4440490744235936`}, {-4.04911807263465, 
       2.444049074423594}, {-4.032745381756434, 
       2.296032716282396}, {-4.0163726908782165`, 2.148016358141198}, {-4., 
       2.}, {-3.983627309121783, 1.851983641858802}, {-3.9672546182435666`, 
       1.703967283717604}, {-3.9508819273653497`, 
       1.5559509255764061`}, {-3.9508819273653497`, 1.5559509255764061`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.445083645356384, 
        1.9460756600021216`}, {-4.445083645356384, 
        1.9460756600021218`}, {-4.2967224302375895`, 
        1.9640504400014145`}, {-4.2967224302375895`, 
        1.9640504400014145`}, {-4.445083645356384, 1.9460756600021216`}}], 
       PolygonBox[{{-4.2967224302375895`, 
        1.9640504400014145`}, {-4.2967224302375895`, 
        1.9640504400014145`}, {-4.148361215118794, 
        1.9820252200007074`}, {-4.148361215118794, 
        1.9820252200007074`}, {-4.2967224302375895`, 1.9640504400014145`}}], 
       PolygonBox[{{-4.148361215118794, 
        1.9820252200007074`}, {-4.148361215118794, 1.9820252200007074`}, {-4.,
         2.}, {-4., 2.}, {-4.148361215118794, 1.9820252200007074`}}], 
       PolygonBox[{{-4., 2.}, {-4., 2.}, {-3.8516387848812053`, 
        2.017974779999293}, {-3.8516387848812053`, 2.017974779999293}, {-4., 
        2.}}], PolygonBox[{{-3.8516387848812053`, 
        2.017974779999293}, {-3.8516387848812053`, 
        2.017974779999293}, {-3.703277569762411, 
        2.0359495599985857`}, {-3.703277569762411, 
        2.0359495599985857`}, {-3.8516387848812053`, 2.017974779999293}}], 
       PolygonBox[{{-3.703277569762411, 
        2.0359495599985857`}, {-3.703277569762411, 
        2.0359495599985857`}, {-3.554916354643616, 
        2.053924339997878}, {-3.554916354643616, 
        2.053924339997878}, {-3.703277569762411, 2.0359495599985857`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.445083645356384, 
         1.9460756600021216`}, {-4.2967224302375895`, 
         1.9640504400014145`}, {-4.148361215118794, 
         1.9820252200007071`}, {-4., 2.}, {-3.8516387848812053`, 
         2.017974779999293}, {-3.703277569762411, 
         2.0359495599985857`}, {-3.554916354643616, 
         2.053924339997878}, {-3.554916354643616, 
         2.053924339997878}, {-3.7032775697624105`, 
         2.0359495599985857`}, {-3.8516387848812053`, 
         2.017974779999293}, {-4., 2.}, {-4.148361215118794, 
         1.9820252200007071`}, {-4.2967224302375895`, 
         1.9640504400014145`}, {-4.445083645356384, 
         1.9460756600021216`}, {-4.445083645356384, 
         1.9460756600021216`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.3959655727217335`, 
      1.5020265855785278`}, {-4.494201717991034, 
      2.3901247344257155`}, {-3.6040344272782665`, 
      2.4979734144214722`}, {-3.505798282008966, 
      1.6098752655742845`}, {-4.3959655727217335`, 1.5020265855785278`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.3959655727217335`, 
       1.5020265855785278`}, {-4.494201717991034, 
       2.3901247344257155`}, {-3.6040344272782665`, 
       2.4979734144214722`}, {-3.505798282008966, 
       1.6098752655742845`}, {-4.3959655727217335`, 1.5020265855785278`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.9270314100441177`, 
      2.563060582617232}, {-3.9270314100441177`, 
      2.563060582617232}, {-3.951354273362745, 
      2.708707055078155}, {-3.951354273362745, 
      2.7087070550781545`}, {-3.9270314100441177`, 2.563060582617232}}], 
     PolygonBox[{{-3.951354273362745, 
      2.7087070550781545`}, {-3.951354273362745, 
      2.708707055078155}, {-3.9756771366813726`, 
      2.8543535275390775`}, {-3.9756771366813726`, 
      2.8543535275390775`}, {-3.951354273362745, 2.7087070550781545`}}], 
     PolygonBox[{{-3.9756771366813726`, 
      2.8543535275390775`}, {-3.9756771366813726`, 2.8543535275390775`}, {-4.,
       3.}, {-4., 3.}, {-3.9756771366813726`, 2.8543535275390775`}}], 
     PolygonBox[{{-4., 3.}, {-4., 3.}, {-4.024322863318627, 
      3.1456464724609225`}, {-4.024322863318628, 3.1456464724609225`}, {-4., 
      3.}}], PolygonBox[{{-4.024322863318628, 
      3.1456464724609225`}, {-4.024322863318627, 
      3.1456464724609225`}, {-4.048645726637255, 
      3.291292944921845}, {-4.048645726637255, 
      3.291292944921845}, {-4.024322863318628, 3.1456464724609225`}}], 
     PolygonBox[{{-4.048645726637255, 3.291292944921845}, {-4.048645726637255,
       3.291292944921845}, {-4.072968589955883, 
      3.436939417382768}, {-4.072968589955883, 
      3.436939417382768}, {-4.048645726637255, 3.291292944921845}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.9270314100441177`, 2.563060582617232}, {-3.951354273362745,
        2.7087070550781545`}, {-3.9756771366813726`, 
       2.8543535275390775`}, {-4., 3.}, {-4.024322863318628, 
       3.1456464724609225`}, {-4.048645726637255, 
       3.291292944921845}, {-4.072968589955883, 
       3.436939417382768}, {-4.072968589955883, 
       3.436939417382768}, {-4.048645726637255, 
       3.2912929449218455`}, {-4.024322863318628, 3.1456464724609225`}, {-4., 
       3.}, {-3.9756771366813726`, 2.8543535275390775`}, {-3.951354273362745, 
       2.708707055078155}, {-3.9270314100441177`, 
       2.563060582617232}, {-3.9270314100441177`, 2.563060582617232}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.442022402120948, 
        2.920882805806465}, {-4.442022402120948, 
        2.920882805806465}, {-4.2946816014139655`, 
        2.9472552038709767`}, {-4.2946816014139655`, 
        2.9472552038709767`}, {-4.442022402120948, 2.920882805806465}}], 
       PolygonBox[{{-4.2946816014139655`, 
        2.9472552038709767`}, {-4.2946816014139655`, 
        2.9472552038709767`}, {-4.147340800706983, 
        2.973627601935488}, {-4.147340800706982, 
        2.973627601935488}, {-4.2946816014139655`, 2.9472552038709767`}}], 
       PolygonBox[{{-4.147340800706982, 
        2.973627601935488}, {-4.147340800706983, 2.973627601935488}, {-4., 
        3.}, {-4., 3.}, {-4.147340800706982, 2.973627601935488}}], 
       PolygonBox[{{-4., 3.}, {-4., 3.}, {-3.8526591992930173`, 
        3.026372398064512}, {-3.8526591992930173`, 3.026372398064512}, {-4., 
        3.}}], PolygonBox[{{-3.8526591992930173`, 
        3.026372398064512}, {-3.8526591992930173`, 
        3.026372398064512}, {-3.7053183985860345`, 
        3.0527447961290233`}, {-3.7053183985860345`, 
        3.0527447961290233`}, {-3.8526591992930173`, 3.026372398064512}}], 
       PolygonBox[{{-3.7053183985860345`, 
        3.0527447961290233`}, {-3.7053183985860345`, 
        3.0527447961290233`}, {-3.557977597879052, 
        3.079117194193535}, {-3.557977597879052, 
        3.079117194193535}, {-3.7053183985860345`, 3.0527447961290233`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.442022402120948, 
         2.920882805806465}, {-4.2946816014139655`, 
         2.9472552038709767`}, {-4.147340800706982, 2.973627601935488}, {-4., 
         3.}, {-3.8526591992930173`, 
         3.026372398064512}, {-3.7053183985860345`, 
         3.0527447961290233`}, {-3.557977597879052, 
         3.079117194193535}, {-3.5579775978790518`, 
         3.079117194193535}, {-3.7053183985860345`, 
         3.0527447961290233`}, {-3.8526591992930173`, 
         3.026372398064512}, {-4., 3.}, {-4.147340800706982, 
         2.973627601935488}, {-4.2946816014139655`, 
         2.9472552038709767`}, {-4.442022402120948, 
         2.920882805806465}, {-4.442022402120948, 2.920882805806465}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.369053812165066, 
      2.4839433884236968`}, {-4.5149909920768305`, 
      3.357822223189233}, {-3.630946187834934, 
      3.5160566115763032`}, {-3.4850090079231695`, 
      2.642177776810767}, {-4.369053812165066, 2.4839433884236968`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.369053812165066, 
       2.4839433884236968`}, {-4.5149909920768305`, 
       3.357822223189233}, {-3.630946187834934, 
       3.5160566115763032`}, {-3.4850090079231695`, 
       2.642177776810767}, {-4.369053812165066, 2.4839433884236968`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.9039855627217266`, 
      3.5724457520439934`}, {-3.9039855627217266`, 
      3.5724457520439934`}, {-3.9359903751478176`, 
      3.714963834695996}, {-3.9359903751478176`, 
      3.714963834695996}, {-3.9039855627217266`, 3.5724457520439934`}}], 
     PolygonBox[{{-3.9359903751478176`, 
      3.714963834695996}, {-3.9359903751478176`, 
      3.714963834695996}, {-3.9679951875739086`, 
      3.857481917347998}, {-3.967995187573909, 
      3.857481917347998}, {-3.9359903751478176`, 3.714963834695996}}], 
     PolygonBox[{{-3.967995187573909, 
      3.857481917347998}, {-3.9679951875739086`, 3.857481917347998}, {-4., 
      4.}, {-4., 4.}, {-3.967995187573909, 3.857481917347998}}], 
     PolygonBox[{{-4., 4.}, {-4., 4.}, {-4.032004812426091, 
      4.1425180826520025`}, {-4.032004812426091, 4.1425180826520025`}, {-4., 
      4.}}], PolygonBox[{{-4.032004812426091, 
      4.1425180826520025`}, {-4.032004812426091, 
      4.1425180826520025`}, {-4.064009624852182, 
      4.285036165304004}, {-4.064009624852182, 
      4.285036165304004}, {-4.032004812426091, 4.1425180826520025`}}], 
     PolygonBox[{{-4.064009624852182, 4.285036165304004}, {-4.064009624852182,
       4.285036165304004}, {-4.096014437278273, 
      4.427554247956007}, {-4.096014437278273, 
      4.427554247956007}, {-4.064009624852182, 4.285036165304004}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.9039855627217266`, 
       3.5724457520439934`}, {-3.9359903751478176`, 
       3.714963834695996}, {-3.967995187573909, 3.857481917347998}, {-4., 
       4.}, {-4.032004812426091, 4.1425180826520025`}, {-4.064009624852182, 
       4.285036165304004}, {-4.096014437278273, 
       4.427554247956007}, {-4.096014437278273, 
       4.427554247956007}, {-4.064009624852182, 
       4.285036165304004}, {-4.032004812426091, 4.1425180826520025`}, {-4., 
       4.}, {-3.967995187573909, 3.857481917347998}, {-3.9359903751478176`, 
       3.714963834695996}, {-3.9039855627217266`, 
       3.572445752043994}, {-3.9039855627217266`, 3.5724457520439934`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.437878744053974, 
        3.8976350016416244`}, {-4.437878744053974, 
        3.8976350016416244`}, {-4.29191916270265, 
        3.931756667761083}, {-4.29191916270265, 
        3.931756667761083}, {-4.437878744053974, 3.8976350016416244`}}], 
       PolygonBox[{{-4.29191916270265, 3.931756667761083}, {-4.29191916270265,
         3.931756667761083}, {-4.145959581351325, 
        3.9658783338805415`}, {-4.145959581351325, 
        3.9658783338805415`}, {-4.29191916270265, 3.931756667761083}}], 
       PolygonBox[{{-4.145959581351325, 
        3.9658783338805415`}, {-4.145959581351325, 3.9658783338805415`}, {-4.,
         4.}, {-4., 4.}, {-4.145959581351325, 3.9658783338805415`}}], 
       PolygonBox[{{-4., 4.}, {-4., 4.}, {-3.854040418648675, 
        4.034121666119458}, {-3.854040418648675, 4.034121666119458}, {-4., 
        4.}}], PolygonBox[{{-3.854040418648675, 
        4.034121666119458}, {-3.854040418648675, 
        4.034121666119458}, {-3.7080808372973504`, 
        4.068243332238917}, {-3.7080808372973504`, 
        4.068243332238917}, {-3.854040418648675, 4.034121666119458}}], 
       PolygonBox[{{-3.7080808372973504`, 
        4.068243332238917}, {-3.7080808372973504`, 
        4.068243332238917}, {-3.5621212559460256`, 
        4.102364998358375}, {-3.5621212559460256`, 
        4.102364998358375}, {-3.7080808372973504`, 4.068243332238917}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.437878744053974, 
         3.8976350016416244`}, {-4.29191916270265, 
         3.931756667761083}, {-4.145959581351325, 3.9658783338805415`}, {-4., 
         4.}, {-3.854040418648675, 4.034121666119458}, {-3.7080808372973504`, 
         4.068243332238917}, {-3.5621212559460256`, 
         4.102364998358375}, {-3.5621212559460256`, 
         4.102364998358375}, {-3.7080808372973504`, 
         4.068243332238917}, {-3.854040418648675, 4.034121666119458}, {-4., 
         4.}, {-4.145959581351325, 3.9658783338805415`}, {-4.29191916270265, 
         3.931756667761083}, {-4.437878744053974, 
         3.8976350016416244`}, {-4.437878744053974, 
         3.8976350016416244`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.341864306775701, 3.470080753685618}, {-4.533893181332248,
       4.3251892495976305`}, {-3.658135693224299, 
      4.529919246314382}, {-3.466106818667752, 
      3.674810750402369}, {-4.341864306775701, 3.470080753685618}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.341864306775701, 3.470080753685618}, {-4.533893181332248, 
       4.3251892495976305`}, {-3.658135693224299, 
       4.529919246314382}, {-3.466106818667752, 
       3.674810750402369}, {-4.341864306775701, 3.470080753685618}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.881942927408615, 4.583629827589022}, {-3.881942927408615,
       4.583629827589022}, {-3.9212952849390765`, 
      4.722419885059348}, {-3.9212952849390765`, 
      4.722419885059348}, {-3.881942927408615, 4.583629827589022}}], 
     PolygonBox[{{-3.9212952849390765`, 
      4.722419885059348}, {-3.9212952849390765`, 
      4.722419885059348}, {-3.9606476424695383`, 
      4.861209942529674}, {-3.9606476424695383`, 
      4.861209942529674}, {-3.9212952849390765`, 4.722419885059348}}], 
     PolygonBox[{{-3.9606476424695383`, 
      4.861209942529674}, {-3.9606476424695383`, 4.861209942529674}, {-4., 
      5.}, {-4., 5.}, {-3.9606476424695383`, 4.861209942529674}}], 
     PolygonBox[{{-4., 5.}, {-4., 5.}, {-4.039352357530461, 
      5.138790057470326}, {-4.039352357530461, 5.138790057470326}, {-4., 
      5.}}], PolygonBox[{{-4.039352357530461, 
      5.138790057470326}, {-4.039352357530461, 
      5.138790057470326}, {-4.0787047150609235`, 
      5.277580114940652}, {-4.0787047150609235`, 
      5.277580114940652}, {-4.039352357530461, 5.138790057470326}}], 
     PolygonBox[{{-4.0787047150609235`, 
      5.277580114940652}, {-4.0787047150609235`, 
      5.277580114940652}, {-4.118057072591385, 
      5.416370172410978}, {-4.118057072591385, 
      5.416370172410978}, {-4.0787047150609235`, 5.277580114940652}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.881942927408615, 4.583629827589022}, {-3.9212952849390765`,
        4.722419885059348}, {-3.9606476424695383`, 4.861209942529674}, {-4., 
       5.}, {-4.039352357530461, 5.138790057470326}, {-4.0787047150609235`, 
       5.277580114940652}, {-4.118057072591385, 
       5.416370172410978}, {-4.118057072591385, 
       5.416370172410978}, {-4.0787047150609235`, 
       5.277580114940652}, {-4.039352357530461, 5.138790057470326}, {-4., 
       5.}, {-3.9606476424695383`, 4.861209942529674}, {-3.9212952849390765`, 
       4.722419885059348}, {-3.881942927408615, 
       4.583629827589022}, {-3.881942927408615, 4.583629827589022}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-4.432779226478679, 
        4.8767181800199015`}, {-4.432779226478679, 
        4.8767181800199015`}, {-4.288519484319119, 
        4.917812120013267}, {-4.28851948431912, 
        4.917812120013267}, {-4.432779226478679, 4.8767181800199015`}}], 
       PolygonBox[{{-4.28851948431912, 
        4.917812120013267}, {-4.288519484319119, 
        4.917812120013267}, {-4.1442597421595595`, 
        4.958906060006634}, {-4.1442597421595595`, 
        4.958906060006634}, {-4.28851948431912, 4.917812120013267}}], 
       PolygonBox[{{-4.1442597421595595`, 
        4.958906060006634}, {-4.1442597421595595`, 4.958906060006634}, {-4., 
        5.}, {-4., 5.}, {-4.1442597421595595`, 4.958906060006634}}], 
       PolygonBox[{{-4., 5.}, {-4., 5.}, {-3.8557402578404405`, 
        5.041093939993366}, {-3.8557402578404405`, 5.041093939993366}, {-4., 
        5.}}], PolygonBox[{{-3.8557402578404405`, 
        5.041093939993366}, {-3.8557402578404405`, 
        5.041093939993366}, {-3.7114805156808806`, 
        5.082187879986733}, {-3.7114805156808806`, 
        5.082187879986733}, {-3.8557402578404405`, 5.041093939993366}}], 
       PolygonBox[{{-3.7114805156808806`, 
        5.082187879986733}, {-3.7114805156808806`, 
        5.082187879986733}, {-3.5672207735213206`, 
        5.1232818199800985`}, {-3.567220773521321, 
        5.1232818199800985`}, {-3.7114805156808806`, 5.082187879986733}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-4.432779226478679, 
         4.8767181800199015`}, {-4.28851948431912, 
         4.917812120013267}, {-4.1442597421595595`, 4.958906060006634}, {-4., 
         5.}, {-3.8557402578404405`, 
         5.041093939993366}, {-3.7114805156808806`, 
         5.082187879986733}, {-3.567220773521321, 
         5.1232818199800985`}, {-3.5672207735213206`, 
         5.1232818199800985`}, {-3.7114805156808806`, 
         5.082187879986733}, {-3.85574025784044, 5.041093939993366}, {-4., 
         5.}, {-4.1442597421595595`, 4.958906060006634}, {-4.288519484319119, 
         4.917812120013267}, {-4.432779226478679, 
         4.8767181800199015`}, {-4.432779226478679, 
         4.8767181800199015`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-4.314722153887294, 4.460348007608924}, {-4.550836299070064,
       5.293088352430879}, {-3.685277846112706, 
      5.539651992391076}, {-3.449163700929936, 
      4.706911647569121}, {-4.314722153887294, 4.460348007608924}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-4.314722153887294, 4.460348007608924}, {-4.550836299070064, 
       5.293088352430879}, {-3.685277846112706, 
       5.539651992391076}, {-3.449163700929936, 
       4.706911647569121}, {-4.314722153887294, 4.460348007608924}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.1203827253456273`, -5.415916369125761}, \
{-3.120382725345627, -5.415916369125761}, {-3.080255150230418, \
-5.2772775794171745`}, {-3.080255150230418, -5.2772775794171745`}, \
{-3.1203827253456273`, -5.415916369125761}}], 
     PolygonBox[{{-3.080255150230418, -5.2772775794171745`}, \
{-3.080255150230418, -5.2772775794171745`}, {-3.040127575115209, \
-5.138638789708588}, {-3.0401275751152093`, -5.138638789708587}, \
{-3.080255150230418, -5.2772775794171745`}}], 
     PolygonBox[{{-3.0401275751152093`, -5.138638789708587}, \
{-3.040127575115209, -5.138638789708588}, {-3., -5.}, {-3., -5.}, \
{-3.0401275751152093`, -5.138638789708587}}], 
     PolygonBox[{{-3., -5.}, {-3., -5.}, {-2.9598724248847907`, \
-4.861361210291413}, {-2.9598724248847907`, -4.861361210291413}, {-3., -5.}}],
      PolygonBox[{{-2.9598724248847907`, -4.861361210291413}, \
{-2.9598724248847907`, -4.861361210291413}, {-2.919744849769582, \
-4.7227224205828255`}, {-2.919744849769582, -4.7227224205828255`}, \
{-2.9598724248847907`, -4.861361210291413}}], 
     PolygonBox[{{-2.919744849769582, -4.7227224205828255`}, \
{-2.919744849769582, -4.7227224205828255`}, {-2.8796172746543727`, \
-4.584083630874239}, {-2.8796172746543727`, -4.584083630874239}, \
{-2.919744849769582, -4.7227224205828255`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.1203827253456273`, -5.415916369125761}, \
{-3.080255150230418, -5.2772775794171745`}, {-3.0401275751152093`, \
-5.138638789708587}, {-3., -5.}, {-2.9598724248847907`, -4.861361210291413}, \
{-2.919744849769582, -4.7227224205828255`}, {-2.8796172746543727`, \
-4.584083630874239}, {-2.8796172746543727`, -4.584083630874239}, \
{-2.919744849769582, -4.7227224205828255`}, {-2.9598724248847907`, \
-4.861361210291413}, {-3., -5.}, {-3.0401275751152093`, -5.138638789708587}, \
{-3.080255150230418, -5.2772775794171745`}, {-3.1203827253456273`, \
-5.415916369125761}, {-3.1203827253456273`, -5.415916369125761}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4328884804176623`, -4.8774374717476725`}, \
{-3.4328884804176623`, -4.8774374717476725`}, {-3.2885923202784415`, \
-4.918291647831781}, {-3.2885923202784415`, -4.918291647831781}, \
{-3.4328884804176623`, -4.8774374717476725`}}], 
       PolygonBox[{{-3.2885923202784415`, -4.918291647831781}, \
{-3.2885923202784415`, -4.918291647831781}, {-3.1442961601392208`, \
-4.9591458239158905`}, {-3.1442961601392208`, -4.9591458239158905`}, \
{-3.2885923202784415`, -4.918291647831781}}], 
       PolygonBox[{{-3.1442961601392208`, -4.9591458239158905`}, \
{-3.1442961601392208`, -4.9591458239158905`}, {-3., -5.}, {-3., -5.}, \
{-3.1442961601392208`, -4.9591458239158905`}}], 
       PolygonBox[{{-3., -5.}, {-3., -5.}, {-2.8557038398607792`, \
-5.0408541760841095`}, {-2.8557038398607792`, -5.0408541760841095`}, {-3., \
-5.}}], PolygonBox[{{-2.8557038398607792`, -5.0408541760841095`}, \
{-2.8557038398607792`, -5.0408541760841095`}, {-2.7114076797215585`, \
-5.081708352168219}, {-2.7114076797215585`, -5.081708352168219}, \
{-2.8557038398607792`, -5.0408541760841095`}}], 
       PolygonBox[{{-2.7114076797215585`, -5.081708352168219}, \
{-2.7114076797215585`, -5.081708352168219}, {-2.5671115195823377`, \
-5.1225625282523275`}, {-2.5671115195823377`, -5.1225625282523275`}, \
{-2.7114076797215585`, -5.081708352168219}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4328884804176623`, -4.8774374717476725`}, \
{-3.2885923202784415`, -4.918291647831781}, {-3.1442961601392208`, \
-4.9591458239158905`}, {-3., -5.}, {-2.8557038398607792`, \
-5.0408541760841095`}, {-2.7114076797215585`, -5.081708352168219}, \
{-2.5671115195823377`, -5.1225625282523275`}, {-2.5671115195823377`, \
-5.1225625282523275`}, {-2.7114076797215585`, -5.081708352168219}, \
{-2.8557038398607792`, -5.0408541760841095`}, {-3., -5.}, \
{-3.1442961601392208`, -4.9591458239158905`}, {-3.2885923202784415`, \
-4.918291647831781}, {-3.4328884804176623`, -4.8774374717476725`}, \
{-3.4328884804176623`, -4.8774374717476725`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.5532712057632896`, -5.293353840873434}, \
{-3.312505755072035, -4.46152110262191}, {-2.4467287942367104`, \
-4.706646159126566}, {-2.687494244927965, -5.53847889737809}, \
{-3.5532712057632896`, -5.293353840873434}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5532712057632896`, -5.293353840873434}, \
{-3.312505755072035, -4.46152110262191}, {-2.4467287942367104`, \
-4.706646159126566}, {-2.687494244927965, -5.53847889737809}, \
{-3.5532712057632896`, -5.293353840873434}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.098007462709227, -4.427202585799375}, \
{-3.098007462709227, -4.427202585799375}, {-3.0653383084728176`, \
-4.2848017238662495`}, {-3.065338308472818, -4.2848017238662495`}, \
{-3.098007462709227, -4.427202585799375}}], 
     PolygonBox[{{-3.065338308472818, -4.2848017238662495`}, \
{-3.0653383084728176`, -4.2848017238662495`}, {-3.032669154236409, \
-4.142400861933125}, {-3.032669154236409, -4.142400861933125}, \
{-3.065338308472818, -4.2848017238662495`}}], 
     PolygonBox[{{-3.032669154236409, -4.142400861933125}, \
{-3.032669154236409, -4.142400861933125}, {-3., -4.}, {-3., -4.}, \
{-3.032669154236409, -4.142400861933125}}], 
     PolygonBox[{{-3., -4.}, {-3., -4.}, {-2.967330845763591, \
-3.8575991380668753`}, {-2.967330845763591, -3.8575991380668753`}, {-3., \
-4.}}], PolygonBox[{{-2.967330845763591, -3.8575991380668753`}, \
{-2.967330845763591, -3.8575991380668753`}, {-2.934661691527182, \
-3.7151982761337505`}, {-2.934661691527182, -3.7151982761337505`}, \
{-2.967330845763591, -3.8575991380668753`}}], 
     PolygonBox[{{-2.934661691527182, -3.7151982761337505`}, \
{-2.934661691527182, -3.7151982761337505`}, {-2.901992537290773, \
-3.5727974142006254`}, {-2.901992537290773, -3.572797414200626}, \
{-2.934661691527182, -3.7151982761337505`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.098007462709227, -4.427202585799375}, {-3.065338308472818, \
-4.2848017238662495`}, {-3.032669154236409, -4.142400861933125}, {-3., -4.}, \
{-2.967330845763591, -3.8575991380668753`}, {-2.934661691527182, \
-3.7151982761337505`}, {-2.901992537290773, -3.572797414200626}, \
{-2.901992537290773, -3.5727974142006254`}, {-2.934661691527182, \
-3.7151982761337505`}, {-2.967330845763591, -3.8575991380668753`}, {-3., \
-4.}, {-3.032669154236409, -4.142400861933125}, {-3.065338308472818, \
-4.2848017238662495`}, {-3.098007462709227, -4.427202585799375}, \
{-3.098007462709227, -4.427202585799375}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4382614998780574`, -3.898056447287591}, \
{-3.4382614998780574`, -3.898056447287591}, {-3.2921743332520386`, \
-3.9320376315250605`}, {-3.2921743332520386`, -3.932037631525061}, \
{-3.4382614998780574`, -3.898056447287591}}], 
       PolygonBox[{{-3.2921743332520386`, -3.932037631525061}, \
{-3.2921743332520386`, -3.9320376315250605`}, {-3.1460871666260193`, \
-3.9660188157625305`}, {-3.1460871666260193`, -3.9660188157625305`}, \
{-3.2921743332520386`, -3.932037631525061}}], 
       PolygonBox[{{-3.1460871666260193`, -3.9660188157625305`}, \
{-3.1460871666260193`, -3.9660188157625305`}, {-3., -4.}, {-3., -4.}, \
{-3.1460871666260193`, -3.9660188157625305`}}], 
       PolygonBox[{{-3., -4.}, {-3., -4.}, {-2.8539128333739807`, \
-4.0339811842374695`}, {-2.8539128333739807`, -4.0339811842374695`}, {-3., \
-4.}}], PolygonBox[{{-2.8539128333739807`, -4.0339811842374695`}, \
{-2.8539128333739807`, -4.0339811842374695`}, {-2.707825666747962, \
-4.067962368474939}, {-2.7078256667479614`, -4.067962368474939}, \
{-2.8539128333739807`, -4.0339811842374695`}}], 
       PolygonBox[{{-2.7078256667479614`, -4.067962368474939}, \
{-2.707825666747962, -4.067962368474939}, {-2.5617385001219426`, \
-4.101943552712409}, {-2.5617385001219426`, -4.101943552712409}, \
{-2.7078256667479614`, -4.067962368474939}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4382614998780574`, -3.898056447287591}, \
{-3.2921743332520386`, -3.932037631525061}, {-3.1460871666260193`, \
-3.9660188157625305`}, {-3., -4.}, {-2.8539128333739807`, \
-4.0339811842374695`}, {-2.7078256667479614`, -4.067962368474939}, \
{-2.5617385001219426`, -4.101943552712409}, {-2.5617385001219426`, \
-4.101943552712409}, {-2.7078256667479614`, -4.067962368474939}, \
{-2.8539128333739807`, -4.0339811842374695`}, {-3., -4.}, \
{-3.1460871666260193`, -3.9660188157625305`}, {-3.2921743332520386`, \
-3.932037631525061}, {-3.4382614998780574`, -3.898056447287591}, \
{-3.4382614998780574`, -3.898056447287591}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.5362689625872843`, -4.325259033086965}, \
{-3.3402540371688305`, -3.4708538614882167`}, {-2.4637310374127157`, \
-3.6747409669130344`}, {-2.6597459628311695`, -4.529146138511783}, \
{-3.5362689625872843`, -4.325259033086965}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.5362689625872843`, -4.325259033086965}, \
{-3.3402540371688305`, -3.4708538614882167`}, {-2.4637310374127157`, \
-3.6747409669130344`}, {-2.6597459628311695`, -4.529146138511783}, \
{-3.5362689625872843`, -4.325259033086965}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.0745474784257523`, -3.4367108084914983`}, \
{-3.0745474784257523`, -3.4367108084914983`}, {-3.0496983189505014`, \
-3.2911405389943322`}, {-3.0496983189505014`, -3.2911405389943322`}, \
{-3.0745474784257523`, -3.4367108084914983`}}], 
     PolygonBox[{{-3.0496983189505014`, -3.2911405389943322`}, \
{-3.0496983189505014`, -3.2911405389943322`}, {-3.0248491594752505`, \
-3.145570269497166}, {-3.024849159475251, -3.145570269497166}, \
{-3.0496983189505014`, -3.2911405389943322`}}], 
     PolygonBox[{{-3.024849159475251, -3.145570269497166}, \
{-3.0248491594752505`, -3.145570269497166}, {-3., -3.}, {-3., -3.}, \
{-3.024849159475251, -3.145570269497166}}], 
     PolygonBox[{{-3., -3.}, {-3., -3.}, {-2.975150840524749, \
-2.854429730502834}, {-2.975150840524749, -2.854429730502834}, {-3., -3.}}], 
     PolygonBox[{{-2.975150840524749, -2.854429730502834}, \
{-2.975150840524749, -2.854429730502834}, {-2.9503016810494986`, \
-2.7088594610056678`}, {-2.9503016810494986`, -2.7088594610056678`}, \
{-2.975150840524749, -2.854429730502834}}], 
     PolygonBox[{{-2.9503016810494986`, -2.7088594610056678`}, \
{-2.9503016810494986`, -2.7088594610056678`}, {-2.9254525215742477`, \
-2.5632891915085017`}, {-2.9254525215742477`, -2.5632891915085017`}, \
{-2.9503016810494986`, -2.7088594610056678`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.0745474784257523`, -3.4367108084914983`}, \
{-3.0496983189505014`, -3.2911405389943322`}, {-3.024849159475251, \
-3.145570269497166}, {-3., -3.}, {-2.975150840524749, -2.854429730502834}, \
{-2.9503016810494986`, -2.7088594610056678`}, {-2.9254525215742477`, \
-2.5632891915085017`}, {-2.9254525215742477`, -2.5632891915085017`}, \
{-2.9503016810494986`, -2.7088594610056678`}, {-2.975150840524749, \
-2.854429730502834}, {-3., -3.}, {-3.024849159475251, -3.145570269497166}, \
{-3.0496983189505014`, -3.2911405389943322`}, {-3.0745474784257523`, \
-3.4367108084914983`}, {-3.0745474784257523`, -3.4367108084914983`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4426402739770836`, -2.9210928190399392`}, \
{-3.4426402739770836`, -2.9210928190399392`}, {-3.295093515984722, \
-2.947395212693293}, {-3.295093515984722, -2.947395212693293}, \
{-3.4426402739770836`, -2.9210928190399392`}}], 
       PolygonBox[{{-3.295093515984722, -2.947395212693293}, \
{-3.295093515984722, -2.947395212693293}, {-3.147546757992361, \
-2.9736976063466463`}, {-3.147546757992361, -2.9736976063466463`}, \
{-3.295093515984722, -2.947395212693293}}], 
       PolygonBox[{{-3.147546757992361, -2.9736976063466463`}, \
{-3.147546757992361, -2.9736976063466463`}, {-3., -3.}, {-3., -3.}, \
{-3.147546757992361, -2.9736976063466463`}}], 
       PolygonBox[{{-3., -3.}, {-3., -3.}, {-2.852453242007639, \
-3.0263023936533537`}, {-2.852453242007639, -3.0263023936533533`}, {-3., \
-3.}}], PolygonBox[{{-2.852453242007639, -3.0263023936533533`}, \
{-2.852453242007639, -3.0263023936533537`}, {-2.704906484015278, \
-3.052604787306707}, {-2.704906484015278, -3.052604787306707}, \
{-2.852453242007639, -3.0263023936533533`}}], 
       PolygonBox[{{-2.704906484015278, -3.052604787306707}, \
{-2.704906484015278, -3.052604787306707}, {-2.557359726022917, \
-3.0789071809600608`}, {-2.557359726022917, -3.0789071809600608`}, \
{-2.704906484015278, -3.052604787306707}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4426402739770836`, -2.9210928190399392`}, \
{-3.295093515984722, -2.947395212693293}, {-3.147546757992361, \
-2.9736976063466463`}, {-3., -3.}, {-2.852453242007639, \
-3.0263023936533537`}, {-2.704906484015278, -3.052604787306707}, \
{-2.557359726022917, -3.0789071809600608`}, {-2.5573597260229164`, \
-3.0789071809600608`}, {-2.704906484015278, -3.052604787306707}, \
{-2.852453242007639, -3.0263023936533537`}, {-3., -3.}, {-3.147546757992361, \
-2.9736976063466463`}, {-3.295093515984722, -2.947395212693293}, \
{-3.442640273977083, -2.9210928190399392`}, {-3.4426402739770836`, \
-2.9210928190399392`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.517187752402836, -3.357803627531438}, \
{-3.3680927955513313`, -2.484382010548441}, {-2.482812247597164, \
-2.642196372468562}, {-2.6319072044486687`, -3.515617989451559}, \
{-3.517187752402836, -3.357803627531438}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.517187752402836, -3.357803627531438}, \
{-3.3680927955513313`, -2.484382010548441}, {-2.482812247597164, \
-2.642196372468562}, {-2.6319072044486687`, -3.515617989451559}, \
{-3.517187752402836, -3.357803627531438}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.0502134135558063`, -2.4439365891396965`}, \
{-3.0502134135558063`, -2.4439365891396965`}, {-3.0334756090372044`, \
-2.295957726093131}, {-3.0334756090372044`, -2.295957726093131}, \
{-3.0502134135558063`, -2.4439365891396965`}}], 
     PolygonBox[{{-3.0334756090372044`, -2.295957726093131}, \
{-3.0334756090372044`, -2.295957726093131}, {-3.016737804518602, \
-2.1479788630465655`}, {-3.016737804518602, -2.1479788630465655`}, \
{-3.0334756090372044`, -2.295957726093131}}], 
     PolygonBox[{{-3.016737804518602, -2.1479788630465655`}, \
{-3.016737804518602, -2.1479788630465655`}, {-3., -2.}, {-3., -2.}, \
{-3.016737804518602, -2.1479788630465655`}}], 
     PolygonBox[{{-3., -2.}, {-3., -2.}, {-2.983262195481398, \
-1.8520211369534345`}, {-2.983262195481398, -1.8520211369534345`}, {-3., \
-2.}}], PolygonBox[{{-2.983262195481398, -1.8520211369534345`}, \
{-2.983262195481398, -1.8520211369534345`}, {-2.9665243909627956`, \
-1.704042273906869}, {-2.9665243909627956`, -1.704042273906869}, \
{-2.983262195481398, -1.8520211369534345`}}], 
     PolygonBox[{{-2.9665243909627956`, -1.704042273906869}, \
{-2.9665243909627956`, -1.704042273906869}, {-2.9497865864441937`, \
-1.5560634108603035`}, {-2.9497865864441937`, -1.5560634108603035`}, \
{-2.9665243909627956`, -1.704042273906869}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.0502134135558063`, -2.4439365891396965`}, \
{-3.0334756090372044`, -2.295957726093131}, {-3.016737804518602, \
-2.1479788630465655`}, {-3., -2.}, {-2.983262195481398, \
-1.8520211369534345`}, {-2.9665243909627956`, -1.704042273906869}, \
{-2.9497865864441937`, -1.5560634108603035`}, {-2.9497865864441937`, \
-1.5560634108603033`}, {-2.9665243909627956`, -1.7040422739068688`}, \
{-2.983262195481398, -1.8520211369534345`}, {-3., -2.}, {-3.016737804518602, \
-2.1479788630465655`}, {-3.0334756090372044`, -2.295957726093131}, \
{-3.0502134135558063`, -2.4439365891396965`}, {-3.0502134135558063`, \
-2.4439365891396965`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4458827884659806`, -1.9461583997072363`}, \
{-3.4458827884659806`, -1.9461583997072363`}, {-3.297255192310654, \
-1.964105599804824}, {-3.297255192310654, -1.964105599804824}, \
{-3.4458827884659806`, -1.9461583997072363`}}], 
       PolygonBox[{{-3.297255192310654, -1.964105599804824}, \
{-3.297255192310654, -1.964105599804824}, {-3.148627596155327, \
-1.982052799902412}, {-3.1486275961553267`, -1.982052799902412}, \
{-3.297255192310654, -1.964105599804824}}], 
       PolygonBox[{{-3.1486275961553267`, -1.982052799902412}, \
{-3.148627596155327, -1.982052799902412}, {-3., -2.}, {-3., -2.}, \
{-3.1486275961553267`, -1.982052799902412}}], 
       PolygonBox[{{-3., -2.}, {-3., -2.}, {-2.8513724038446733`, \
-2.0179472000975878`}, {-2.8513724038446733`, -2.0179472000975878`}, {-3., \
-2.}}], PolygonBox[{{-2.8513724038446733`, -2.0179472000975878`}, \
{-2.8513724038446733`, -2.0179472000975878`}, {-2.702744807689346, \
-2.035894400195176}, {-2.702744807689346, -2.035894400195176}, \
{-2.8513724038446733`, -2.0179472000975878`}}], 
       PolygonBox[{{-2.702744807689346, -2.035894400195176}, \
{-2.702744807689346, -2.035894400195176}, {-2.5541172115340194`, \
-2.0538416002927637`}, {-2.5541172115340194`, -2.0538416002927637`}, \
{-2.702744807689346, -2.035894400195176}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4458827884659806`, -1.9461583997072363`}, \
{-3.297255192310654, -1.964105599804824}, {-3.1486275961553267`, \
-1.982052799902412}, {-3., -2.}, {-2.8513724038446733`, \
-2.0179472000975878`}, {-2.702744807689346, -2.035894400195176}, \
{-2.5541172115340194`, -2.0538416002927637`}, {-2.5541172115340194`, \
-2.0538416002927637`}, {-2.702744807689346, -2.035894400195176}, \
{-2.8513724038446733`, -2.0179472000975878`}, {-3., -2.}, \
{-3.1486275961553267`, -1.982052799902412}, {-3.297255192310654, \
-1.9641055998048242`}, {-3.4458827884659806`, -1.9461583997072363`}, \
{-3.4458827884659806`, -1.9461583997072363`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.496096202021787, -2.3900949888469327`}, \
{-3.3956693749101743`, -1.5022218105675396`}, {-2.503903797978213, \
-1.6099050111530673`}, {-2.6043306250898257`, -2.49777818943246}, \
{-3.496096202021787, -2.3900949888469327`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.496096202021787, -2.3900949888469327`}, \
{-3.3956693749101743`, -1.5022218105675396`}, {-2.503903797978213, \
-1.6099050111530673`}, {-2.6043306250898257`, -2.49777818943246}, \
{-3.496096202021787, -2.3900949888469327`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.025265228437042, -1.4484595816658583`}, \
{-3.025265228437042, -1.4484595816658583`}, {-3.0168434856246944`, \
-1.2989730544439055`}, {-3.016843485624695, -1.2989730544439055`}, \
{-3.025265228437042, -1.4484595816658583`}}], 
     PolygonBox[{{-3.016843485624695, -1.2989730544439055`}, \
{-3.0168434856246944`, -1.2989730544439055`}, {-3.0084217428123474`, \
-1.1494865272219528`}, {-3.0084217428123474`, -1.1494865272219528`}, \
{-3.016843485624695, -1.2989730544439055`}}], 
     PolygonBox[{{-3.0084217428123474`, -1.1494865272219528`}, \
{-3.0084217428123474`, -1.1494865272219528`}, {-3., -1.0000000000000002`}, \
{-3., -1.}, {-3.0084217428123474`, -1.1494865272219528`}}], 
     PolygonBox[{{-3., -1.}, {-3., -1.}, {-2.9915782571876526`, \
-0.8505134727780472}, {-2.9915782571876526`, -0.8505134727780472}, {-3., \
-1.}}], PolygonBox[{{-2.9915782571876526`, -0.8505134727780472}, \
{-2.9915782571876526`, -0.8505134727780472}, {-2.983156514375305, \
-0.7010269455560945}, {-2.983156514375305, -0.7010269455560945}, \
{-2.9915782571876526`, -0.8505134727780472}}], 
     PolygonBox[{{-2.983156514375305, -0.7010269455560945}, \
{-2.983156514375305, -0.7010269455560945}, {-2.974734771562958, \
-0.5515404183341417}, {-2.974734771562958, -0.5515404183341417}, \
{-2.983156514375305, -0.7010269455560945}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.025265228437042, -1.4484595816658583`}, \
{-3.016843485624695, -1.2989730544439055`}, {-3.0084217428123474`, \
-1.1494865272219528`}, {-3., -1.}, {-2.9915782571876526`, \
-0.8505134727780472}, {-2.983156514375305, -0.7010269455560945}, \
{-2.974734771562958, -0.5515404183341417}, {-2.974734771562958, \
-0.5515404183341417}, {-2.983156514375305, -0.7010269455560945}, \
{-2.9915782571876526`, -0.8505134727780472}, {-3., -1.}, \
{-3.0084217428123474`, -1.1494865272219528`}, {-3.016843485624695, \
-1.2989730544439055`}, {-3.025265228437042, -1.4484595816658583`}, \
{-3.025265228437042, -1.4484595816658583`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4478766516405615`, -0.972693007413714}, \
{-3.4478766516405615`, -0.972693007413714}, {-3.298584434427041, \
-0.9817953382758093}, {-3.298584434427041, -0.9817953382758093}, \
{-3.4478766516405615`, -0.972693007413714}}], 
       PolygonBox[{{-3.298584434427041, -0.9817953382758093}, \
{-3.298584434427041, -0.9817953382758093}, {-3.1492922172135205`, \
-0.9908976691379047}, {-3.1492922172135205`, -0.9908976691379047}, \
{-3.298584434427041, -0.9817953382758093}}], 
       PolygonBox[{{-3.1492922172135205`, -0.9908976691379047}, \
{-3.1492922172135205`, -0.9908976691379047}, {-3., -1.}, {-3., -1.}, \
{-3.1492922172135205`, -0.9908976691379047}}], 
       PolygonBox[{{-3., -1.}, {-3., -1.}, {-2.8507077827864795`, \
-1.0091023308620952`}, {-2.8507077827864795`, -1.0091023308620952`}, {-3., \
-1.}}], PolygonBox[{{-2.8507077827864795`, -1.0091023308620952`}, \
{-2.8507077827864795`, -1.0091023308620952`}, {-2.701415565572959, \
-1.0182046617241907`}, {-2.701415565572959, -1.0182046617241907`}, \
{-2.8507077827864795`, -1.0091023308620952`}}], 
       PolygonBox[{{-2.701415565572959, -1.0182046617241907`}, \
{-2.701415565572959, -1.0182046617241907`}, {-2.5521233483594385`, \
-1.0273069925862859`}, {-2.5521233483594385`, -1.0273069925862859`}, \
{-2.701415565572959, -1.0182046617241907`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4478766516405615`, -0.972693007413714}, \
{-3.298584434427041, -0.9817953382758093}, {-3.1492922172135205`, \
-0.9908976691379047}, {-3., -1.}, {-2.8507077827864795`, \
-1.0091023308620952`}, {-2.701415565572959, -1.0182046617241907`}, \
{-2.5521233483594385`, -1.0273069925862859`}, {-2.5521233483594385`, \
-1.0273069925862859`}, {-2.701415565572959, -1.0182046617241907`}, \
{-2.8507077827864795`, -1.0091023308620952`}, {-3., -1.}, \
{-3.1492922172135205`, -0.9908976691379047}, {-3.298584434427041, \
-0.9817953382758093}, {-3.4478766516405615`, -0.972693007413714}, \
{-3.4478766516405615`, -0.972693007413714}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.4731418800776033`, -1.4211525890795724`}, \
{-3.4226114232035196`, -0.5242334257478558}, {-2.5268581199223967`, \
-0.5788474109204276}, {-2.5773885767964804`, -1.4757665742521442`}, \
{-3.4731418800776033`, -1.4211525890795724`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.4731418800776033`, -1.4211525890795724`}, \
{-3.4226114232035196`, -0.5242334257478558}, {-2.5268581199223967`, \
-0.5788474109204276}, {-2.5773885767964804`, -1.4757665742521442`}, \
{-3.4731418800776033`, -1.4211525890795724`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3., -0.45}, {-3., -0.45}, {-3., -0.3}, {-3., \
-0.30000000000000004`}, {-3., -0.45}}], 
     PolygonBox[{{-3., -0.30000000000000004`}, {-3., -0.3}, {-3., \
-0.15000000000000008`}, {-3., -0.15000000000000002`}, {-3., \
-0.30000000000000004`}}], 
     PolygonBox[{{-3., -0.15000000000000002`}, {-3., -0.15000000000000008`}, \
{-3., -1.1102230246251565`*^-16}, {-3., 0.}, {-3., -0.15000000000000002`}}], 
     PolygonBox[{{-3., 0.}, {-3., 0.}, {-3., 0.14999999999999997`}, {-3., 
      0.14999999999999997`}, {-3., 0.}}], 
     PolygonBox[{{-3., 0.14999999999999997`}, {-3., 
      0.14999999999999997`}, {-3., 0.29999999999999993`}, {-3., 0.3}, {-3., 
      0.14999999999999997`}}], 
     PolygonBox[{{-3., 0.3}, {-3., 0.29999999999999993`}, {-3., 
      0.44999999999999996`}, {-3., 0.4499999999999999}, {-3., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3., -0.45}, {-3., -0.30000000000000004`}, {-3., \
-0.15000000000000002`}, {-3., -5.551115123125783*^-17}, {-3., 
       0.14999999999999997`}, {-3., 0.3}, {-3., 0.4499999999999999}, {-3., 
       0.45}, {-3., 0.30000000000000004`}, {-3., 0.15000000000000002`}, {-3., 
       5.551115123125783*^-17}, {-3., -0.14999999999999997`}, {-3., -0.3}, \
{-3., -0.4499999999999999}, {-3., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.44854958885624, 0.}, {-3.44854958885624, 
        5.5109105961630896`*^-17}, {-3.2990330592374932`, 
        4.592425496802574*^-17}, {-3.2990330592374937`, 
        9.184850993605149*^-18}, {-3.44854958885624, 0.}}], 
       PolygonBox[{{-3.2990330592374937`, 
        9.184850993605149*^-18}, {-3.2990330592374932`, 
        4.592425496802574*^-17}, {-3.149516529618747, 
        3.67394039744206*^-17}, {-3.149516529618747, 
        1.8369701987210297`*^-17}, {-3.2990330592374937`, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{-3.149516529618747, 
        1.8369701987210297`*^-17}, {-3.149516529618747, 
        3.67394039744206*^-17}, {-3., 2.7554552980815454`*^-17}, {-3., 
        2.7554552980815448`*^-17}, {-3.149516529618747, 
        1.8369701987210297`*^-17}}], 
       PolygonBox[{{-3., 2.7554552980815448`*^-17}, {-3., 
        2.7554552980815448`*^-17}, {-2.850483470381253, 
        1.83697019872103*^-17}, {-2.850483470381253, 
        3.6739403974420595`*^-17}, {-3., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{-2.850483470381253, 
        3.6739403974420595`*^-17}, {-2.850483470381253, 
        1.83697019872103*^-17}, {-2.7009669407625068`, 
        9.184850993605152*^-18}, {-2.7009669407625068`, 
        4.592425496802574*^-17}, {-2.850483470381253, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{-2.7009669407625068`, 
        4.592425496802574*^-17}, {-2.7009669407625068`, 
        9.184850993605153*^-18}, {-2.55145041114376, 
        4.5887548728832574`*^-33}, {-2.55145041114376, 
        5.510910596163089*^-17}, {-2.7009669407625068`, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.44854958885624, 0.}, {-3.2990330592374937`, 
         0.}, {-3.149516529618747, 0.}, {-3., 0.}, {-2.850483470381253, 
         0.}, {-2.7009669407625068`, 0.}, {-2.55145041114376, 
         0.}, {-2.55145041114376, 0.}, {-2.7009669407625063`, 
         0.}, {-2.850483470381253, 0.}, {-3., 0.}, {-3.149516529618747, 
         0.}, {-3.2990330592374932`, 0.}, {-3.44854958885624, 
         0.}, {-3.44854958885624, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.44854958885624, -0.45}, {-3.44854958885624, 
      0.45}, {-2.55145041114376, 
      0.45}, {-2.55145041114376, -0.45}, {-3.44854958885624, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.44854958885624, -0.45}, {-3.44854958885624, 
       0.45}, {-2.55145041114376, 
       0.45}, {-2.55145041114376, -0.45}, {-3.44854958885624, -0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.974734771562958, 
      0.5515404183341417}, {-2.9747347715629577`, 
      0.5515404183341417}, {-2.983156514375305, 
      0.7010269455560945}, {-2.983156514375305, 
      0.7010269455560945}, {-2.974734771562958, 0.5515404183341417}}], 
     PolygonBox[{{-2.983156514375305, 
      0.7010269455560945}, {-2.983156514375305, 
      0.7010269455560945}, {-2.9915782571876526`, 
      0.8505134727780471}, {-2.9915782571876526`, 
      0.8505134727780472}, {-2.983156514375305, 0.7010269455560945}}], 
     PolygonBox[{{-2.9915782571876526`, 
      0.8505134727780472}, {-2.9915782571876526`, 0.8505134727780471}, {-3., 
      0.9999999999999999}, {-3., 1.}, {-2.9915782571876526`, 
      0.8505134727780472}}], 
     PolygonBox[{{-3., 1.}, {-3., 1.}, {-3.0084217428123474`, 
      1.1494865272219528`}, {-3.0084217428123474`, 1.1494865272219528`}, {-3.,
       1.}}], 
     PolygonBox[{{-3.0084217428123474`, 
      1.1494865272219528`}, {-3.0084217428123474`, 
      1.1494865272219528`}, {-3.0168434856246944`, 
      1.2989730544439055`}, {-3.016843485624695, 
      1.2989730544439055`}, {-3.0084217428123474`, 1.1494865272219528`}}], 
     PolygonBox[{{-3.016843485624695, 
      1.2989730544439055`}, {-3.0168434856246944`, 
      1.2989730544439055`}, {-3.025265228437042, 
      1.4484595816658583`}, {-3.025265228437042, 
      1.4484595816658583`}, {-3.016843485624695, 1.2989730544439055`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.974734771562958, 0.5515404183341417}, {-2.983156514375305, 
       0.7010269455560945}, {-2.9915782571876526`, 0.8505134727780472}, {-3., 
       1.}, {-3.0084217428123474`, 1.1494865272219528`}, {-3.016843485624695, 
       1.2989730544439055`}, {-3.025265228437042, 
       1.4484595816658583`}, {-3.025265228437042, 
       1.4484595816658583`}, {-3.016843485624695, 
       1.2989730544439055`}, {-3.0084217428123474`, 
       1.1494865272219528`}, {-3., 1.}, {-2.9915782571876526`, 
       0.8505134727780472}, {-2.983156514375305, 
       0.7010269455560945}, {-2.974734771562958, 
       0.5515404183341417}, {-2.974734771562958, 0.5515404183341417}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4478766516405615`, 
        0.972693007413714}, {-3.4478766516405615`, 
        0.9726930074137141}, {-3.298584434427041, 
        0.9817953382758094}, {-3.298584434427041, 
        0.9817953382758093}, {-3.4478766516405615`, 0.972693007413714}}], 
       PolygonBox[{{-3.298584434427041, 
        0.9817953382758093}, {-3.298584434427041, 
        0.9817953382758094}, {-3.1492922172135205`, 
        0.9908976691379047}, {-3.1492922172135205`, 
        0.9908976691379047}, {-3.298584434427041, 0.9817953382758093}}], 
       PolygonBox[{{-3.1492922172135205`, 
        0.9908976691379047}, {-3.1492922172135205`, 0.9908976691379047}, {-3.,
         1.}, {-3., 1.}, {-3.1492922172135205`, 0.9908976691379047}}], 
       PolygonBox[{{-3., 1.}, {-3., 1.}, {-2.8507077827864795`, 
        1.0091023308620954`}, {-2.8507077827864795`, 
        1.0091023308620954`}, {-3., 1.}}], 
       PolygonBox[{{-2.8507077827864795`, 
        1.0091023308620954`}, {-2.8507077827864795`, 
        1.0091023308620954`}, {-2.701415565572959, 
        1.0182046617241907`}, {-2.701415565572959, 
        1.0182046617241907`}, {-2.8507077827864795`, 1.0091023308620954`}}], 
       PolygonBox[{{-2.701415565572959, 
        1.0182046617241907`}, {-2.701415565572959, 
        1.0182046617241907`}, {-2.5521233483594385`, 
        1.0273069925862859`}, {-2.5521233483594385`, 
        1.027306992586286}, {-2.701415565572959, 1.0182046617241907`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4478766516405615`, 
         0.972693007413714}, {-3.298584434427041, 
         0.9817953382758093}, {-3.1492922172135205`, 
         0.9908976691379047}, {-3., 1.}, {-2.8507077827864795`, 
         1.0091023308620952`}, {-2.701415565572959, 
         1.0182046617241907`}, {-2.5521233483594385`, 
         1.0273069925862859`}, {-2.5521233483594385`, 
         1.0273069925862859`}, {-2.701415565572959, 
         1.0182046617241907`}, {-2.8507077827864795`, 
         1.0091023308620952`}, {-3., 1.}, {-3.1492922172135205`, 
         0.9908976691379047}, {-3.298584434427041, 
         0.9817953382758093}, {-3.4478766516405615`, 
         0.972693007413714}, {-3.4478766516405615`, 
         0.972693007413714}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.4226114232035196`, 
      0.5242334257478558}, {-3.4731418800776033`, 
      1.4211525890795724`}, {-2.5773885767964804`, 
      1.4757665742521442`}, {-2.5268581199223967`, 
      0.5788474109204276}, {-3.4226114232035196`, 0.5242334257478558}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.4226114232035196`, 
       0.5242334257478558}, {-3.4731418800776033`, 
       1.4211525890795724`}, {-2.5773885767964804`, 
       1.4757665742521442`}, {-2.5268581199223967`, 
       0.5788474109204276}, {-3.4226114232035196`, 0.5242334257478558}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.9497865864441937`, 
      1.5560634108603033`}, {-2.9497865864441932`, 
      1.5560634108603033`}, {-2.9665243909627956`, 
      1.704042273906869}, {-2.9665243909627956`, 
      1.7040422739068688`}, {-2.9497865864441937`, 1.5560634108603033`}}], 
     PolygonBox[{{-2.9665243909627956`, 
      1.7040422739068688`}, {-2.9665243909627956`, 
      1.704042273906869}, {-2.9832621954813976`, 
      1.8520211369534343`}, {-2.983262195481398, 
      1.8520211369534345`}, {-2.9665243909627956`, 1.7040422739068688`}}], 
     PolygonBox[{{-2.983262195481398, 
      1.8520211369534345`}, {-2.9832621954813976`, 1.8520211369534343`}, {-3.,
       2.}, {-3., 2.}, {-2.983262195481398, 1.8520211369534345`}}], 
     PolygonBox[{{-3., 2.}, {-3., 2.}, {-3.016737804518602, 
      2.1479788630465655`}, {-3.016737804518602, 2.1479788630465655`}, {-3., 
      2.}}], PolygonBox[{{-3.016737804518602, 
      2.1479788630465655`}, {-3.016737804518602, 
      2.1479788630465655`}, {-3.0334756090372044`, 
      2.295957726093131}, {-3.0334756090372044`, 
      2.295957726093131}, {-3.016737804518602, 2.1479788630465655`}}], 
     PolygonBox[{{-3.0334756090372044`, 
      2.295957726093131}, {-3.0334756090372044`, 
      2.295957726093131}, {-3.0502134135558063`, 
      2.4439365891396965`}, {-3.0502134135558063`, 
      2.4439365891396965`}, {-3.0334756090372044`, 2.295957726093131}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.9497865864441937`, 
       1.5560634108603033`}, {-2.9665243909627956`, 
       1.7040422739068688`}, {-2.983262195481398, 1.8520211369534345`}, {-3., 
       2.}, {-3.016737804518602, 2.1479788630465655`}, {-3.0334756090372044`, 
       2.295957726093131}, {-3.0502134135558063`, 
       2.4439365891396965`}, {-3.0502134135558063`, 
       2.4439365891396965`}, {-3.0334756090372044`, 
       2.295957726093131}, {-3.016737804518602, 2.1479788630465655`}, {-3., 
       2.}, {-2.983262195481398, 1.8520211369534345`}, {-2.9665243909627956`, 
       1.704042273906869}, {-2.9497865864441937`, 
       1.5560634108603035`}, {-2.9497865864441937`, 1.5560634108603033`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4458827884659806`, 
        1.9461583997072363`}, {-3.4458827884659806`, 
        1.9461583997072363`}, {-3.297255192310654, 
        1.9641055998048242`}, {-3.297255192310654, 
        1.9641055998048242`}, {-3.4458827884659806`, 1.9461583997072363`}}], 
       PolygonBox[{{-3.297255192310654, 
        1.9641055998048242`}, {-3.297255192310654, 
        1.9641055998048242`}, {-3.148627596155327, 
        1.982052799902412}, {-3.1486275961553267`, 
        1.982052799902412}, {-3.297255192310654, 1.9641055998048242`}}], 
       PolygonBox[{{-3.1486275961553267`, 
        1.982052799902412}, {-3.148627596155327, 1.982052799902412}, {-3., 
        2.}, {-3., 2.}, {-3.1486275961553267`, 1.982052799902412}}], 
       PolygonBox[{{-3., 2.}, {-3., 2.}, {-2.8513724038446733`, 
        2.0179472000975878`}, {-2.8513724038446733`, 
        2.0179472000975878`}, {-3., 2.}}], 
       PolygonBox[{{-2.8513724038446733`, 
        2.0179472000975878`}, {-2.8513724038446733`, 
        2.0179472000975878`}, {-2.702744807689346, 
        2.035894400195176}, {-2.702744807689346, 
        2.035894400195176}, {-2.8513724038446733`, 2.0179472000975878`}}], 
       PolygonBox[{{-2.702744807689346, 
        2.035894400195176}, {-2.702744807689346, 
        2.035894400195176}, {-2.5541172115340194`, 
        2.0538416002927637`}, {-2.5541172115340194`, 
        2.0538416002927637`}, {-2.702744807689346, 2.035894400195176}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4458827884659806`, 
         1.9461583997072363`}, {-3.297255192310654, 
         1.964105599804824}, {-3.1486275961553267`, 1.982052799902412}, {-3., 
         2.}, {-2.8513724038446733`, 
         2.0179472000975878`}, {-2.702744807689346, 
         2.035894400195176}, {-2.5541172115340194`, 
         2.0538416002927637`}, {-2.5541172115340194`, 
         2.0538416002927637`}, {-2.702744807689346, 
         2.035894400195176}, {-2.8513724038446733`, 
         2.0179472000975878`}, {-3., 2.}, {-3.1486275961553267`, 
         1.982052799902412}, {-3.297255192310654, 
         1.9641055998048242`}, {-3.4458827884659806`, 
         1.9461583997072363`}, {-3.4458827884659806`, 
         1.9461583997072363`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.3956693749101743`, 
      1.5022218105675396`}, {-3.496096202021787, 
      2.3900949888469327`}, {-2.6043306250898257`, 
      2.49777818943246}, {-2.503903797978213, 
      1.6099050111530673`}, {-3.3956693749101743`, 1.5022218105675396`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.3956693749101743`, 
       1.5022218105675396`}, {-3.496096202021787, 
       2.3900949888469327`}, {-2.6043306250898257`, 
       2.49777818943246}, {-2.503903797978213, 
       1.6099050111530673`}, {-3.3956693749101743`, 1.5022218105675396`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.9254525215742477`, 
      2.5632891915085017`}, {-2.9254525215742477`, 
      2.5632891915085017`}, {-2.9503016810494986`, 
      2.7088594610056678`}, {-2.9503016810494986`, 
      2.7088594610056678`}, {-2.9254525215742477`, 2.5632891915085017`}}], 
     PolygonBox[{{-2.9503016810494986`, 
      2.7088594610056678`}, {-2.9503016810494986`, 
      2.7088594610056678`}, {-2.975150840524749, 
      2.854429730502834}, {-2.975150840524749, 
      2.854429730502834}, {-2.9503016810494986`, 2.7088594610056678`}}], 
     PolygonBox[{{-2.975150840524749, 2.854429730502834}, {-2.975150840524749,
       2.854429730502834}, {-3., 3.}, {-3., 3.}, {-2.975150840524749, 
      2.854429730502834}}], 
     PolygonBox[{{-3., 3.}, {-3., 3.}, {-3.024849159475251, 
      3.145570269497166}, {-3.024849159475251, 3.145570269497166}, {-3., 
      3.}}], PolygonBox[{{-3.024849159475251, 
      3.145570269497166}, {-3.024849159475251, 
      3.145570269497166}, {-3.0496983189505014`, 
      3.2911405389943322`}, {-3.0496983189505014`, 
      3.2911405389943322`}, {-3.024849159475251, 3.145570269497166}}], 
     PolygonBox[{{-3.0496983189505014`, 
      3.2911405389943322`}, {-3.0496983189505014`, 
      3.2911405389943322`}, {-3.0745474784257523`, 
      3.4367108084914983`}, {-3.0745474784257523`, 
      3.4367108084914983`}, {-3.0496983189505014`, 3.2911405389943322`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.9254525215742477`, 
       2.5632891915085017`}, {-2.9503016810494986`, 
       2.7088594610056678`}, {-2.975150840524749, 2.854429730502834}, {-3., 
       3.}, {-3.024849159475251, 3.145570269497166}, {-3.0496983189505014`, 
       3.2911405389943322`}, {-3.0745474784257523`, 
       3.4367108084914983`}, {-3.0745474784257523`, 
       3.4367108084914983`}, {-3.0496983189505014`, 
       3.2911405389943322`}, {-3.024849159475251, 3.145570269497166}, {-3., 
       3.}, {-2.975150840524749, 2.854429730502834}, {-2.9503016810494986`, 
       2.7088594610056678`}, {-2.9254525215742477`, 
       2.5632891915085017`}, {-2.9254525215742477`, 2.5632891915085017`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4426402739770836`, 
        2.9210928190399392`}, {-3.4426402739770836`, 
        2.9210928190399392`}, {-3.295093515984722, 
        2.947395212693293}, {-3.295093515984722, 
        2.947395212693293}, {-3.4426402739770836`, 2.9210928190399392`}}], 
       PolygonBox[{{-3.295093515984722, 
        2.947395212693293}, {-3.295093515984722, 
        2.947395212693293}, {-3.147546757992361, 
        2.9736976063466463`}, {-3.147546757992361, 
        2.9736976063466463`}, {-3.295093515984722, 2.947395212693293}}], 
       PolygonBox[{{-3.147546757992361, 
        2.9736976063466463`}, {-3.147546757992361, 2.9736976063466463`}, {-3.,
         3.}, {-3., 3.}, {-3.147546757992361, 2.9736976063466463`}}], 
       PolygonBox[{{-3., 3.}, {-3., 3.}, {-2.852453242007639, 
        3.0263023936533537`}, {-2.852453242007639, 3.0263023936533537`}, {-3.,
         3.}}], PolygonBox[{{-2.852453242007639, 
        3.0263023936533537`}, {-2.852453242007639, 
        3.0263023936533537`}, {-2.704906484015278, 
        3.052604787306707}, {-2.704906484015278, 
        3.052604787306707}, {-2.852453242007639, 3.0263023936533537`}}], 
       PolygonBox[{{-2.704906484015278, 
        3.052604787306707}, {-2.704906484015278, 
        3.052604787306707}, {-2.557359726022917, 
        3.0789071809600608`}, {-2.557359726022917, 
        3.0789071809600608`}, {-2.704906484015278, 3.052604787306707}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4426402739770836`, 
         2.9210928190399392`}, {-3.295093515984722, 
         2.947395212693293}, {-3.147546757992361, 2.9736976063466463`}, {-3., 
         3.}, {-2.852453242007639, 3.0263023936533537`}, {-2.704906484015278, 
         3.052604787306707}, {-2.557359726022917, 
         3.0789071809600608`}, {-2.5573597260229164`, 
         3.0789071809600608`}, {-2.704906484015278, 
         3.052604787306707}, {-2.852453242007639, 3.0263023936533537`}, {-3., 
         3.}, {-3.147546757992361, 2.9736976063466463`}, {-3.295093515984722, 
         2.947395212693293}, {-3.442640273977083, 
         2.9210928190399392`}, {-3.4426402739770836`, 
         2.9210928190399392`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.3680927955513313`, 
      2.484382010548441}, {-3.517187752402836, 
      3.357803627531438}, {-2.6319072044486687`, 
      3.515617989451559}, {-2.482812247597164, 
      2.642196372468562}, {-3.3680927955513313`, 2.484382010548441}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.3680927955513313`, 2.484382010548441}, {-3.517187752402836,
        3.357803627531438}, {-2.6319072044486687`, 
       3.515617989451559}, {-2.482812247597164, 
       2.642196372468562}, {-3.3680927955513313`, 2.484382010548441}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.901992537290773, 
      3.5727974142006254`}, {-2.901992537290773, 
      3.5727974142006254`}, {-2.934661691527182, 
      3.7151982761337505`}, {-2.934661691527182, 
      3.7151982761337505`}, {-2.901992537290773, 3.5727974142006254`}}], 
     PolygonBox[{{-2.934661691527182, 
      3.7151982761337505`}, {-2.934661691527182, 
      3.7151982761337505`}, {-2.9673308457635907`, 
      3.8575991380668753`}, {-2.967330845763591, 
      3.8575991380668753`}, {-2.934661691527182, 3.7151982761337505`}}], 
     PolygonBox[{{-2.967330845763591, 
      3.8575991380668753`}, {-2.9673308457635907`, 3.8575991380668753`}, {-3.,
       4.}, {-3., 4.}, {-2.967330845763591, 3.8575991380668753`}}], 
     PolygonBox[{{-3., 4.}, {-3., 4.}, {-3.032669154236409, 
      4.142400861933125}, {-3.032669154236409, 4.142400861933125}, {-3., 
      4.}}], PolygonBox[{{-3.032669154236409, 
      4.142400861933125}, {-3.032669154236409, 
      4.142400861933125}, {-3.065338308472818, 
      4.2848017238662495`}, {-3.065338308472818, 
      4.2848017238662495`}, {-3.032669154236409, 4.142400861933125}}], 
     PolygonBox[{{-3.065338308472818, 
      4.2848017238662495`}, {-3.065338308472818, 
      4.2848017238662495`}, {-3.098007462709227, 
      4.427202585799375}, {-3.098007462709227, 
      4.427202585799375}, {-3.065338308472818, 4.2848017238662495`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.901992537290773, 3.5727974142006254`}, {-2.934661691527182,
        3.7151982761337505`}, {-2.967330845763591, 3.8575991380668753`}, {-3.,
        4.}, {-3.032669154236409, 4.142400861933125}, {-3.065338308472818, 
       4.2848017238662495`}, {-3.098007462709227, 
       4.427202585799375}, {-3.098007462709227, 
       4.427202585799375}, {-3.065338308472818, 
       4.2848017238662495`}, {-3.032669154236409, 4.142400861933125}, {-3., 
       4.}, {-2.967330845763591, 3.8575991380668753`}, {-2.934661691527182, 
       3.7151982761337505`}, {-2.901992537290773, 
       3.572797414200626}, {-2.901992537290773, 3.5727974142006254`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4382614998780574`, 
        3.898056447287591}, {-3.4382614998780574`, 
        3.898056447287591}, {-3.2921743332520386`, 
        3.932037631525061}, {-3.2921743332520386`, 
        3.932037631525061}, {-3.4382614998780574`, 3.898056447287591}}], 
       PolygonBox[{{-3.2921743332520386`, 
        3.932037631525061}, {-3.2921743332520386`, 
        3.932037631525061}, {-3.1460871666260193`, 
        3.9660188157625305`}, {-3.1460871666260193`, 
        3.9660188157625305`}, {-3.2921743332520386`, 3.932037631525061}}], 
       PolygonBox[{{-3.1460871666260193`, 
        3.9660188157625305`}, {-3.1460871666260193`, 
        3.9660188157625305`}, {-3., 4.}, {-3., 4.}, {-3.1460871666260193`, 
        3.9660188157625305`}}], 
       PolygonBox[{{-3., 4.}, {-3., 4.}, {-2.8539128333739807`, 
        4.0339811842374695`}, {-2.8539128333739807`, 
        4.0339811842374695`}, {-3., 4.}}], 
       PolygonBox[{{-2.8539128333739807`, 
        4.0339811842374695`}, {-2.8539128333739807`, 
        4.0339811842374695`}, {-2.707825666747962, 
        4.067962368474939}, {-2.7078256667479614`, 
        4.067962368474939}, {-2.8539128333739807`, 4.0339811842374695`}}], 
       PolygonBox[{{-2.7078256667479614`, 
        4.067962368474939}, {-2.707825666747962, 
        4.067962368474939}, {-2.5617385001219426`, 
        4.101943552712409}, {-2.5617385001219426`, 
        4.101943552712409}, {-2.7078256667479614`, 4.067962368474939}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4382614998780574`, 
         3.898056447287591}, {-3.2921743332520386`, 
         3.932037631525061}, {-3.1460871666260193`, 
         3.9660188157625305`}, {-3., 4.}, {-2.8539128333739807`, 
         4.0339811842374695`}, {-2.7078256667479614`, 
         4.067962368474939}, {-2.5617385001219426`, 
         4.101943552712409}, {-2.5617385001219426`, 
         4.101943552712409}, {-2.7078256667479614`, 
         4.067962368474939}, {-2.8539128333739807`, 
         4.0339811842374695`}, {-3., 4.}, {-3.1460871666260193`, 
         3.9660188157625305`}, {-3.2921743332520386`, 
         3.932037631525061}, {-3.4382614998780574`, 
         3.898056447287591}, {-3.4382614998780574`, 
         3.898056447287591}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.3402540371688305`, 
      3.4708538614882167`}, {-3.5362689625872843`, 
      4.325259033086965}, {-2.6597459628311695`, 
      4.529146138511783}, {-2.4637310374127157`, 
      3.6747409669130344`}, {-3.3402540371688305`, 3.4708538614882167`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.3402540371688305`, 
       3.4708538614882167`}, {-3.5362689625872843`, 
       4.325259033086965}, {-2.6597459628311695`, 
       4.529146138511783}, {-2.4637310374127157`, 
       3.6747409669130344`}, {-3.3402540371688305`, 3.4708538614882167`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.8796172746543727`, 
      4.584083630874239}, {-2.8796172746543727`, 
      4.584083630874239}, {-2.919744849769582, 
      4.7227224205828255`}, {-2.919744849769582, 
      4.7227224205828255`}, {-2.8796172746543727`, 4.584083630874239}}], 
     PolygonBox[{{-2.919744849769582, 
      4.7227224205828255`}, {-2.919744849769582, 
      4.7227224205828255`}, {-2.9598724248847907`, 
      4.861361210291413}, {-2.9598724248847907`, 
      4.861361210291413}, {-2.919744849769582, 4.7227224205828255`}}], 
     PolygonBox[{{-2.9598724248847907`, 
      4.861361210291413}, {-2.9598724248847907`, 4.861361210291413}, {-3., 
      5.}, {-3., 5.}, {-2.9598724248847907`, 4.861361210291413}}], 
     PolygonBox[{{-3., 5.}, {-3., 5.}, {-3.040127575115209, 
      5.138638789708587}, {-3.0401275751152093`, 5.138638789708587}, {-3., 
      5.}}], PolygonBox[{{-3.0401275751152093`, 
      5.138638789708587}, {-3.040127575115209, 
      5.138638789708587}, {-3.080255150230418, 
      5.2772775794171745`}, {-3.080255150230418, 
      5.2772775794171745`}, {-3.0401275751152093`, 5.138638789708587}}], 
     PolygonBox[{{-3.080255150230418, 
      5.2772775794171745`}, {-3.080255150230418, 
      5.2772775794171745`}, {-3.1203827253456273`, 
      5.415916369125761}, {-3.1203827253456273`, 
      5.415916369125761}, {-3.080255150230418, 5.2772775794171745`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.8796172746543727`, 4.584083630874239}, {-2.919744849769582,
        4.7227224205828255`}, {-2.9598724248847907`, 4.861361210291413}, {-3.,
        5.}, {-3.0401275751152093`, 5.138638789708587}, {-3.080255150230418, 
       5.2772775794171745`}, {-3.1203827253456273`, 
       5.415916369125761}, {-3.1203827253456273`, 
       5.415916369125761}, {-3.080255150230418, 
       5.2772775794171745`}, {-3.0401275751152093`, 5.138638789708587}, {-3., 
       5.}, {-2.9598724248847907`, 4.861361210291413}, {-2.919744849769582, 
       4.7227224205828255`}, {-2.8796172746543727`, 
       4.584083630874239}, {-2.8796172746543727`, 4.584083630874239}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-3.4328884804176623`, 
        4.8774374717476725`}, {-3.4328884804176623`, 
        4.8774374717476725`}, {-3.2885923202784415`, 
        4.918291647831781}, {-3.2885923202784415`, 
        4.918291647831781}, {-3.4328884804176623`, 4.8774374717476725`}}], 
       PolygonBox[{{-3.2885923202784415`, 
        4.918291647831781}, {-3.2885923202784415`, 
        4.918291647831781}, {-3.1442961601392208`, 
        4.9591458239158905`}, {-3.1442961601392208`, 
        4.9591458239158905`}, {-3.2885923202784415`, 4.918291647831781}}], 
       PolygonBox[{{-3.1442961601392208`, 
        4.9591458239158905`}, {-3.1442961601392208`, 
        4.9591458239158905`}, {-3., 5.}, {-3., 5.}, {-3.1442961601392208`, 
        4.9591458239158905`}}], 
       PolygonBox[{{-3., 5.}, {-3., 5.}, {-2.8557038398607792`, 
        5.0408541760841095`}, {-2.8557038398607792`, 
        5.0408541760841095`}, {-3., 5.}}], 
       PolygonBox[{{-2.8557038398607792`, 
        5.0408541760841095`}, {-2.8557038398607792`, 
        5.0408541760841095`}, {-2.7114076797215585`, 
        5.081708352168219}, {-2.7114076797215585`, 
        5.081708352168219}, {-2.8557038398607792`, 5.0408541760841095`}}], 
       PolygonBox[{{-2.7114076797215585`, 
        5.081708352168219}, {-2.7114076797215585`, 
        5.081708352168219}, {-2.5671115195823377`, 
        5.1225625282523275`}, {-2.5671115195823377`, 
        5.1225625282523275`}, {-2.7114076797215585`, 5.081708352168219}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-3.4328884804176623`, 
         4.8774374717476725`}, {-3.2885923202784415`, 
         4.918291647831781}, {-3.1442961601392208`, 
         4.9591458239158905`}, {-3., 5.}, {-2.8557038398607792`, 
         5.0408541760841095`}, {-2.7114076797215585`, 
         5.081708352168219}, {-2.5671115195823377`, 
         5.1225625282523275`}, {-2.5671115195823377`, 
         5.1225625282523275`}, {-2.7114076797215585`, 
         5.081708352168219}, {-2.8557038398607792`, 
         5.0408541760841095`}, {-3., 5.}, {-3.1442961601392208`, 
         4.9591458239158905`}, {-3.2885923202784415`, 
         4.918291647831781}, {-3.4328884804176623`, 
         4.8774374717476725`}, {-3.4328884804176623`, 
         4.8774374717476725`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-3.312505755072035, 
      4.46152110262191}, {-3.5532712057632896`, 
      5.293353840873434}, {-2.687494244927965, 
      5.53847889737809}, {-2.4467287942367104`, 
      4.706646159126566}, {-3.312505755072035, 4.46152110262191}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-3.312505755072035, 4.46152110262191}, {-3.5532712057632896`, 
       5.293353840873434}, {-2.687494244927965, 
       5.53847889737809}, {-2.4467287942367104`, 
       4.706646159126566}, {-3.312505755072035, 4.46152110262191}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.122675395370443, -5.415537047668212}, \
{-2.1226753953704427`, -5.415537047668212}, {-2.0817835969136285`, \
-5.277024698445475}, {-2.0817835969136285`, -5.277024698445475}, \
{-2.122675395370443, -5.415537047668212}}], 
     PolygonBox[{{-2.0817835969136285`, -5.277024698445475}, \
{-2.0817835969136285`, -5.277024698445475}, {-2.0408917984568142`, \
-5.138512349222737}, {-2.0408917984568142`, -5.138512349222737}, \
{-2.0817835969136285`, -5.277024698445475}}], 
     PolygonBox[{{-2.0408917984568142`, -5.138512349222737}, \
{-2.0408917984568142`, -5.138512349222737}, {-2., -5.}, {-2., -5.}, \
{-2.0408917984568142`, -5.138512349222737}}], 
     PolygonBox[{{-2., -5.}, {-2., -5.}, {-1.9591082015431858`, \
-4.861487650777263}, {-1.9591082015431858`, -4.861487650777263}, {-2., -5.}}],
      PolygonBox[{{-1.9591082015431858`, -4.861487650777263}, \
{-1.9591082015431858`, -4.861487650777263}, {-1.9182164030863713`, \
-4.722975301554525}, {-1.9182164030863713`, -4.722975301554525}, \
{-1.9591082015431858`, -4.861487650777263}}], 
     PolygonBox[{{-1.9182164030863713`, -4.722975301554525}, \
{-1.9182164030863713`, -4.722975301554525}, {-1.877324604629557, \
-4.584462952331788}, {-1.877324604629557, -4.584462952331788}, \
{-1.9182164030863713`, -4.722975301554525}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.122675395370443, -5.415537047668212}, \
{-2.0817835969136285`, -5.277024698445475}, {-2.0408917984568142`, \
-5.138512349222737}, {-2., -5.}, {-1.9591082015431858`, -4.861487650777263}, \
{-1.9182164030863713`, -4.722975301554525}, {-1.877324604629557, \
-4.584462952331788}, {-1.877324604629557, -4.584462952331788}, \
{-1.9182164030863713`, -4.722975301554525}, {-1.9591082015431858`, \
-4.861487650777263}, {-2., -5.}, {-2.0408917984568142`, -5.138512349222737}, \
{-2.0817835969136285`, -5.277024698445475}, {-2.1226753953704427`, \
-5.415537047668212}, {-2.122675395370443, -5.415537047668212}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.4327508547046017`, -4.8784281719069265`}, \
{-2.4327508547046017`, -4.8784281719069265`}, {-2.288500569803068, \
-4.918952114604617}, {-2.288500569803068, -4.918952114604617}, \
{-2.4327508547046017`, -4.8784281719069265`}}], 
       PolygonBox[{{-2.288500569803068, -4.918952114604617}, \
{-2.288500569803068, -4.918952114604617}, {-2.144250284901534, \
-4.959476057302309}, {-2.144250284901534, -4.959476057302309}, \
{-2.288500569803068, -4.918952114604617}}], 
       PolygonBox[{{-2.144250284901534, -4.959476057302309}, \
{-2.144250284901534, -4.959476057302309}, {-2., -5.}, {-2., -5.}, \
{-2.144250284901534, -4.959476057302309}}], 
       PolygonBox[{{-2., -5.}, {-2., -5.}, {-1.855749715098466, \
-5.040523942697691}, {-1.855749715098466, -5.040523942697691}, {-2., -5.}}], 
       PolygonBox[{{-1.855749715098466, -5.040523942697691}, \
{-1.855749715098466, -5.040523942697691}, {-1.7114994301969322`, \
-5.081047885395383}, {-1.7114994301969322`, -5.081047885395383}, \
{-1.855749715098466, -5.040523942697691}}], 
       PolygonBox[{{-1.7114994301969322`, -5.081047885395383}, \
{-1.7114994301969322`, -5.081047885395383}, {-1.567249145295398, \
-5.1215718280930735`}, {-1.5672491452953983`, -5.1215718280930735`}, \
{-1.7114994301969322`, -5.081047885395383}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.4327508547046017`, -4.8784281719069265`}, \
{-2.288500569803068, -4.918952114604617}, {-2.144250284901534, \
-4.959476057302309}, {-2., -5.}, {-1.855749715098466, -5.040523942697691}, \
{-1.7114994301969322`, -5.081047885395383}, {-1.5672491452953983`, \
-5.1215718280930735`}, {-1.567249145295398, -5.1215718280930735`}, \
{-1.711499430196932, -5.081047885395383}, {-1.855749715098466, \
-5.040523942697691}, {-2., -5.}, {-2.144250284901534, -4.959476057302309}, \
{-2.288500569803068, -4.918952114604617}, {-2.4327508547046017`, \
-4.8784281719069265`}, {-2.4327508547046017`, -4.8784281719069265`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.555426250075045, -5.2939652195751385`}, \
{-2.310075459334159, -4.462891124238714}, {-1.4445737499249551`, \
-4.7060347804248615`}, {-1.689924540665841, -5.537108875761286}, \
{-2.555426250075045, -5.2939652195751385`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.555426250075045, -5.2939652195751385`}, \
{-2.310075459334159, -4.462891124238714}, {-1.4445737499249551`, \
-4.7060347804248615`}, {-1.689924540665841, -5.537108875761286}, \
{-2.555426250075045, -5.2939652195751385`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.099984579182302, -4.426897555491506}, \
{-2.099984579182302, -4.426897555491506}, {-2.066656386121535, \
-4.284598370327671}, {-2.066656386121535, -4.284598370327671}, \
{-2.099984579182302, -4.426897555491506}}], 
     PolygonBox[{{-2.066656386121535, -4.284598370327671}, \
{-2.066656386121535, -4.284598370327671}, {-2.0333281930607674`, \
-4.142299185163836}, {-2.0333281930607674`, -4.142299185163836}, \
{-2.066656386121535, -4.284598370327671}}], 
     PolygonBox[{{-2.0333281930607674`, -4.142299185163836}, \
{-2.0333281930607674`, -4.142299185163836}, {-2., -4.}, {-2., -4.}, \
{-2.0333281930607674`, -4.142299185163836}}], 
     PolygonBox[{{-2., -4.}, {-2., -4.}, {-1.9666718069392326`, \
-3.8577008148361647`}, {-1.9666718069392326`, -3.8577008148361647`}, {-2., \
-4.}}], PolygonBox[{{-1.9666718069392326`, -3.8577008148361647`}, \
{-1.9666718069392326`, -3.8577008148361647`}, {-1.9333436138784652`, \
-3.7154016296723293`}, {-1.9333436138784652`, -3.7154016296723293`}, \
{-1.9666718069392326`, -3.8577008148361647`}}], 
     PolygonBox[{{-1.9333436138784652`, -3.7154016296723293`}, \
{-1.9333436138784652`, -3.7154016296723293`}, {-1.9000154208176978`, \
-3.573102444508494}, {-1.9000154208176978`, -3.573102444508494}, \
{-1.9333436138784652`, -3.7154016296723293`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.099984579182302, -4.426897555491506}, {-2.066656386121535, \
-4.284598370327671}, {-2.0333281930607674`, -4.142299185163836}, {-2., -4.}, \
{-1.9666718069392326`, -3.8577008148361647`}, {-1.9333436138784652`, \
-3.7154016296723293`}, {-1.9000154208176978`, -3.573102444508494}, \
{-1.9000154208176978`, -3.5731024445084936`}, {-1.9333436138784652`, \
-3.7154016296723293`}, {-1.9666718069392326`, -3.8577008148361647`}, {-2., \
-4.}, {-2.0333281930607674`, -4.142299185163836}, {-2.066656386121535, \
-4.284598370327671}, {-2.099984579182302, -4.426897555491506}, \
{-2.099984579182302, -4.426897555491506}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.438411364870582, -3.8987006365216725`}, \
{-2.438411364870582, -3.8987006365216725`}, {-2.292274243247055, \
-3.9324670910144484`}, {-2.292274243247055, -3.9324670910144484`}, \
{-2.438411364870582, -3.8987006365216725`}}], 
       PolygonBox[{{-2.292274243247055, -3.9324670910144484`}, \
{-2.292274243247055, -3.9324670910144484`}, {-2.1461371216235277`, \
-3.966233545507224}, {-2.1461371216235277`, -3.966233545507224}, \
{-2.292274243247055, -3.9324670910144484`}}], 
       PolygonBox[{{-2.1461371216235277`, -3.966233545507224}, \
{-2.1461371216235277`, -3.966233545507224}, {-2., -4.}, {-2., -4.}, \
{-2.1461371216235277`, -3.966233545507224}}], 
       PolygonBox[{{-2., -4.}, {-2., -4.}, {-1.8538628783764726`, \
-4.033766454492776}, {-1.8538628783764726`, -4.033766454492776}, {-2., -4.}}],
        PolygonBox[{{-1.8538628783764726`, -4.033766454492776}, \
{-1.8538628783764726`, -4.033766454492776}, {-1.7077257567529451`, \
-4.067532908985552}, {-1.7077257567529451`, -4.067532908985552}, \
{-1.8538628783764726`, -4.033766454492776}}], 
       PolygonBox[{{-1.7077257567529451`, -4.067532908985552}, \
{-1.7077257567529451`, -4.067532908985552}, {-1.5615886351294177`, \
-4.1012993634783275`}, {-1.5615886351294177`, -4.1012993634783275`}, \
{-1.7077257567529451`, -4.067532908985552}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.438411364870582, -3.8987006365216725`}, \
{-2.292274243247055, -3.9324670910144484`}, {-2.1461371216235277`, \
-3.966233545507224}, {-2., -4.}, {-1.8538628783764726`, -4.033766454492776}, \
{-1.7077257567529451`, -4.067532908985552}, {-1.5615886351294177`, \
-4.1012993634783275`}, {-1.5615886351294177`, -4.1012993634783275`}, \
{-1.7077257567529451`, -4.067532908985552}, {-1.8538628783764726`, \
-4.033766454492776}, {-2., -4.}, {-2.146137121623527, -3.966233545507224}, \
{-2.292274243247055, -3.9324670910144484`}, {-2.438411364870582, \
-3.8987006365216725`}, {-2.438411364870582, -3.8987006365216725`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.5383959440528843`, -4.325598192013179}, \
{-2.3384267856882803`, -3.4718030810301665`}, {-1.4616040559471155`, \
-3.674401807986821}, {-1.66157321431172, -4.528196918969834}, \
{-2.5383959440528843`, -4.325598192013179}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5383959440528843`, -4.325598192013179}, \
{-2.3384267856882803`, -3.4718030810301665`}, {-1.4616040559471155`, \
-3.674401807986821}, {-1.66157321431172, -4.528196918969834}, \
{-2.5383959440528843`, -4.325598192013179}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.076121685070304, -3.436507564016404}, \
{-2.076121685070304, -3.436507564016404}, {-2.050747790046869, \
-3.291005042677603}, {-2.0507477900468696`, -3.291005042677603}, \
{-2.076121685070304, -3.436507564016404}}], 
     PolygonBox[{{-2.0507477900468696`, -3.291005042677603}, \
{-2.050747790046869, -3.291005042677603}, {-2.0253738950234346`, \
-3.1455025213388015`}, {-2.0253738950234346`, -3.1455025213388015`}, \
{-2.0507477900468696`, -3.291005042677603}}], 
     PolygonBox[{{-2.0253738950234346`, -3.1455025213388015`}, \
{-2.0253738950234346`, -3.1455025213388015`}, {-2., -3.}, {-2., -3.}, \
{-2.0253738950234346`, -3.1455025213388015`}}], 
     PolygonBox[{{-2., -3.}, {-2., -3.}, {-1.9746261049765652`, \
-2.8544974786611985`}, {-1.9746261049765652`, -2.8544974786611985`}, {-2., \
-3.}}], PolygonBox[{{-1.9746261049765652`, -2.8544974786611985`}, \
{-1.9746261049765652`, -2.8544974786611985`}, {-1.9492522099531306`, \
-2.708994957322397}, {-1.9492522099531306`, -2.708994957322397}, \
{-1.9746261049765652`, -2.8544974786611985`}}], 
     PolygonBox[{{-1.9492522099531306`, -2.708994957322397}, \
{-1.9492522099531306`, -2.708994957322397}, {-1.9238783149296959`, \
-2.563492435983596}, {-1.9238783149296959`, -2.563492435983596}, \
{-1.9492522099531306`, -2.708994957322397}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.076121685070304, -3.436507564016404}, \
{-2.0507477900468696`, -3.291005042677603}, {-2.0253738950234346`, \
-3.1455025213388015`}, {-2., -3.}, {-1.9746261049765652`, \
-2.8544974786611985`}, {-1.9492522099531306`, -2.708994957322397}, \
{-1.9238783149296959`, -2.563492435983596}, {-1.9238783149296959`, \
-2.563492435983596}, {-1.9492522099531306`, -2.708994957322397}, \
{-1.9746261049765652`, -2.8544974786611985`}, {-2., -3.}, \
{-2.0253738950234346`, -3.1455025213388015`}, {-2.0507477900468696`, \
-3.291005042677603}, {-2.076121685070304, -3.436507564016404}, \
{-2.076121685070304, -3.436507564016404}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.443039216995193, -2.9214720710923667`}, \
{-2.443039216995193, -2.9214720710923667`}, {-2.2953594779967954`, \
-2.947648047394911}, {-2.2953594779967954`, -2.947648047394911}, \
{-2.443039216995193, -2.9214720710923667`}}], 
       PolygonBox[{{-2.2953594779967954`, -2.947648047394911}, \
{-2.2953594779967954`, -2.947648047394911}, {-2.1476797389983977`, \
-2.9738240236974556`}, {-2.1476797389983977`, -2.9738240236974556`}, \
{-2.2953594779967954`, -2.947648047394911}}], 
       PolygonBox[{{-2.1476797389983977`, -2.9738240236974556`}, \
{-2.1476797389983977`, -2.9738240236974556`}, {-2., -3.}, {-2., -3.}, \
{-2.1476797389983977`, -2.9738240236974556`}}], 
       PolygonBox[{{-2., -3.}, {-2., -3.}, {-1.8523202610016023`, \
-3.0261759763025444`}, {-1.8523202610016023`, -3.0261759763025444`}, {-2., \
-3.}}], PolygonBox[{{-1.8523202610016023`, -3.0261759763025444`}, \
{-1.8523202610016023`, -3.0261759763025444`}, {-1.7046405220032046`, \
-3.052351952605089}, {-1.7046405220032046`, -3.052351952605089}, \
{-1.8523202610016023`, -3.0261759763025444`}}], 
       PolygonBox[{{-1.7046405220032046`, -3.052351952605089}, \
{-1.7046405220032046`, -3.052351952605089}, {-1.556960783004807, \
-3.0785279289076333`}, {-1.556960783004807, -3.0785279289076333`}, \
{-1.7046405220032046`, -3.052351952605089}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.443039216995193, -2.9214720710923667`}, \
{-2.2953594779967954`, -2.947648047394911}, {-2.1476797389983977`, \
-2.9738240236974556`}, {-2., -3.}, {-1.8523202610016023`, \
-3.0261759763025444`}, {-1.7046405220032046`, -3.052351952605089}, \
{-1.556960783004807, -3.0785279289076333`}, {-1.556960783004807, \
-3.0785279289076333`}, {-1.7046405220032046`, -3.052351952605089}, \
{-1.8523202610016023`, -3.0261759763025444`}, {-2., -3.}, \
{-2.1476797389983977`, -2.9738240236974556`}, {-2.2953594779967954`, \
-2.947648047394911}, {-2.443039216995193, -2.9214720710923667`}, \
{-2.443039216995193, -2.9214720710923667`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.5191609020654973`, -3.357979635108771}, \
{-2.366917531924889, -2.4849645070759623`}, {-1.4808390979345027`, \
-2.642020364891229}, {-1.633082468075111, -3.5150354929240377`}, \
{-2.5191609020654973`, -3.357979635108771}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.5191609020654973`, -3.357979635108771}, \
{-2.366917531924889, -2.4849645070759623`}, {-1.4808390979345027`, \
-2.642020364891229}, {-1.633082468075111, -3.5150354929240377`}, \
{-2.5191609020654973`, -3.357979635108771}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.0513095581746894`, -2.44383497634162}, \
{-2.051309558174689, -2.44383497634162}, {-2.0342063721164596`, \
-2.2958899842277467`}, {-2.0342063721164596`, -2.2958899842277467`}, \
{-2.0513095581746894`, -2.44383497634162}}], 
     PolygonBox[{{-2.0342063721164596`, -2.2958899842277467`}, \
{-2.0342063721164596`, -2.2958899842277467`}, {-2.01710318605823, \
-2.1479449921138736`}, {-2.01710318605823, -2.147944992113873}, \
{-2.0342063721164596`, -2.2958899842277467`}}], 
     PolygonBox[{{-2.01710318605823, -2.147944992113873}, {-2.01710318605823, \
-2.1479449921138736`}, {-2., -2.}, {-2., -2.}, {-2.01710318605823, \
-2.147944992113873}}], 
     PolygonBox[{{-2., -2.}, {-2., -2.}, {-1.9828968139417702`, \
-1.8520550078861266`}, {-1.9828968139417702`, -1.8520550078861266`}, {-2., \
-2.}}], PolygonBox[{{-1.9828968139417702`, -1.8520550078861266`}, \
{-1.9828968139417702`, -1.8520550078861266`}, {-1.9657936278835404`, \
-1.7041100157722535`}, {-1.9657936278835404`, -1.7041100157722533`}, \
{-1.9828968139417702`, -1.8520550078861266`}}], 
     PolygonBox[{{-1.9657936278835404`, -1.7041100157722533`}, \
{-1.9657936278835404`, -1.7041100157722535`}, {-1.9486904418253108`, \
-1.5561650236583802`}, {-1.9486904418253108`, -1.5561650236583802`}, \
{-1.9657936278835404`, -1.7041100157722533`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.0513095581746894`, -2.44383497634162}, \
{-2.0342063721164596`, -2.2958899842277467`}, {-2.01710318605823, \
-2.147944992113873}, {-2., -2.}, {-1.9828968139417702`, \
-1.8520550078861266`}, {-1.9657936278835404`, -1.7041100157722533`}, \
{-1.9486904418253108`, -1.5561650236583802`}, {-1.9486904418253108`, \
-1.5561650236583802`}, {-1.9657936278835404`, -1.7041100157722533`}, \
{-1.9828968139417702`, -1.8520550078861266`}, {-2., -2.}, {-2.01710318605823, \
-2.147944992113873}, {-2.0342063721164596`, -2.2958899842277467`}, \
{-2.0513095581746894`, -2.44383497634162}, {-2.0513095581746894`, \
-2.44383497634162}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.446474929456423, -1.946354468818439}, \
{-2.446474929456423, -1.9463544688184389`}, {-2.2976499529709487`, \
-1.964236312545626}, {-2.297649952970949, -1.964236312545626}, \
{-2.446474929456423, -1.946354468818439}}], 
       PolygonBox[{{-2.297649952970949, -1.964236312545626}, \
{-2.2976499529709487`, -1.964236312545626}, {-2.1488249764854745`, \
-1.982118156272813}, {-2.1488249764854745`, -1.982118156272813}, \
{-2.297649952970949, -1.964236312545626}}], 
       PolygonBox[{{-2.1488249764854745`, -1.982118156272813}, \
{-2.1488249764854745`, -1.982118156272813}, {-2., -2.}, {-2., -2.}, \
{-2.1488249764854745`, -1.982118156272813}}], 
       PolygonBox[{{-2., -2.}, {-2., -2.}, {-1.8511750235145257`, \
-2.017881843727187}, {-1.8511750235145257`, -2.017881843727187}, {-2., -2.}}],
        PolygonBox[{{-1.8511750235145257`, -2.017881843727187}, \
{-1.8511750235145257`, -2.017881843727187}, {-1.7023500470290513`, \
-2.035763687454374}, {-1.7023500470290511`, -2.035763687454374}, \
{-1.8511750235145257`, -2.017881843727187}}], 
       PolygonBox[{{-1.7023500470290511`, -2.035763687454374}, \
{-1.7023500470290513`, -2.035763687454374}, {-1.5535250705435768`, \
-2.053645531181561}, {-1.5535250705435768`, -2.053645531181561}, \
{-1.7023500470290511`, -2.035763687454374}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.446474929456423, -1.946354468818439}, \
{-2.297649952970949, -1.964236312545626}, {-2.1488249764854745`, \
-1.982118156272813}, {-2., -2.}, {-1.8511750235145257`, -2.017881843727187}, \
{-1.7023500470290511`, -2.035763687454374}, {-1.5535250705435768`, \
-2.053645531181561}, {-1.5535250705435768`, -2.053645531181561}, \
{-1.7023500470290511`, -2.035763687454374}, {-1.8511750235145255`, \
-2.017881843727187}, {-2., -2.}, {-2.1488249764854745`, -1.982118156272813}, \
{-2.2976499529709487`, -1.964236312545626}, {-2.446474929456423, \
-1.946354468818439}, {-2.446474929456423, -1.946354468818439}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.4977844876311126`, -2.390189445160059}, \
{-2.395165371281734, -1.502519492476819}, {-1.5022155123688876`, \
-1.609810554839941}, {-1.604834628718266, -2.497480507523181}, \
{-2.4977844876311126`, -2.390189445160059}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.4977844876311126`, -2.390189445160059}, \
{-2.395165371281734, -1.502519492476819}, {-1.5022155123688876`, \
-1.609810554839941}, {-1.604834628718266, -2.497480507523181}, \
{-2.4977844876311126`, -2.390189445160059}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.0258279869764584`, -1.4484323484908068`}, \
{-2.0258279869764584`, -1.4484323484908068`}, {-2.0172186579843054`, \
-1.298954898993871}, {-2.0172186579843054`, -1.298954898993871}, \
{-2.0258279869764584`, -1.4484323484908068`}}], 
     PolygonBox[{{-2.0172186579843054`, -1.298954898993871}, \
{-2.0172186579843054`, -1.298954898993871}, {-2.0086093289921525`, \
-1.1494774494969358`}, {-2.008609328992153, -1.1494774494969355`}, \
{-2.0172186579843054`, -1.298954898993871}}], 
     PolygonBox[{{-2.008609328992153, -1.1494774494969355`}, \
{-2.0086093289921525`, -1.1494774494969358`}, {-2., -1.0000000000000002`}, \
{-2., -1.}, {-2.008609328992153, -1.1494774494969355`}}], 
     PolygonBox[{{-2., -1.}, {-2., -1.}, {-1.9913906710078473`, \
-0.8505225505030645}, {-1.9913906710078473`, -0.8505225505030645}, {-2., \
-1.}}], PolygonBox[{{-1.9913906710078473`, -0.8505225505030645}, \
{-1.9913906710078473`, -0.8505225505030645}, {-1.9827813420156943`, \
-0.7010451010061289}, {-1.9827813420156943`, -0.7010451010061289}, \
{-1.9913906710078473`, -0.8505225505030645}}], 
     PolygonBox[{{-1.9827813420156943`, -0.7010451010061289}, \
{-1.9827813420156943`, -0.7010451010061289}, {-1.9741720130235416`, \
-0.5515676515091933}, {-1.9741720130235416`, -0.5515676515091934}, \
{-1.9827813420156943`, -0.7010451010061289}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.0258279869764584`, -1.4484323484908068`}, \
{-2.0172186579843054`, -1.298954898993871}, {-2.008609328992153, \
-1.1494774494969355`}, {-2., -1.}, {-1.9913906710078473`, \
-0.8505225505030645}, {-1.9827813420156943`, -0.7010451010061289}, \
{-1.9741720130235416`, -0.5515676515091934}, {-1.9741720130235416`, \
-0.5515676515091932}, {-1.9827813420156943`, -0.7010451010061288}, \
{-1.9913906710078473`, -0.8505225505030645}, {-2., -1.}, {-2.008609328992153, \
-1.1494774494969355`}, {-2.0172186579843054`, -1.298954898993871}, \
{-2.0258279869764584`, -1.4484323484908066`}, {-2.0258279869764584`, \
-1.4484323484908068`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.4485913527490135`, -0.9727723685245406}, \
{-2.4485913527490135`, -0.9727723685245406}, {-2.2990609018326755`, \
-0.9818482456830271}, {-2.299060901832676, -0.9818482456830271}, \
{-2.4485913527490135`, -0.9727723685245406}}], 
       PolygonBox[{{-2.299060901832676, -0.9818482456830271}, \
{-2.2990609018326755`, -0.9818482456830271}, {-2.149530450916338, \
-0.9909241228415135}, {-2.149530450916338, -0.9909241228415135}, \
{-2.299060901832676, -0.9818482456830271}}], 
       PolygonBox[{{-2.149530450916338, -0.9909241228415135}, \
{-2.149530450916338, -0.9909241228415135}, {-2., -1.}, {-2., -1.}, \
{-2.149530450916338, -0.9909241228415135}}], 
       PolygonBox[{{-2., -1.}, {-2., -1.}, {-1.8504695490836622`, \
-1.0090758771584865`}, {-1.8504695490836622`, -1.0090758771584865`}, {-2., \
-1.}}], PolygonBox[{{-1.8504695490836622`, -1.0090758771584865`}, \
{-1.8504695490836622`, -1.0090758771584865`}, {-1.7009390981673245`, \
-1.018151754316973}, {-1.7009390981673242`, -1.018151754316973}, \
{-1.8504695490836622`, -1.0090758771584865`}}], 
       PolygonBox[{{-1.7009390981673242`, -1.018151754316973}, \
{-1.7009390981673245`, -1.018151754316973}, {-1.5514086472509865`, \
-1.0272276314754594`}, {-1.5514086472509865`, -1.0272276314754594`}, \
{-1.7009390981673242`, -1.018151754316973}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.4485913527490135`, -0.9727723685245406}, \
{-2.299060901832676, -0.9818482456830271}, {-2.149530450916338, \
-0.9909241228415135}, {-2., -1.}, {-1.8504695490836622`, \
-1.0090758771584865`}, {-1.7009390981673242`, -1.018151754316973}, \
{-1.5514086472509865`, -1.0272276314754594`}, {-1.5514086472509865`, \
-1.0272276314754594`}, {-1.7009390981673242`, -1.018151754316973}, \
{-1.850469549083662, -1.0090758771584865`}, {-2., -1.}, {-2.149530450916338, \
-0.9909241228415135}, {-2.2990609018326755`, -0.9818482456830271}, \
{-2.4485913527490135`, -0.9727723685245406}, {-2.4485913527490135`, \
-0.9727723685245406}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.474419339725472, -1.4212047170153475`}, \
{-2.422763365772555, -0.5243400200337339}, {-1.525580660274528, \
-0.5787952829846525}, {-1.5772366342274449`, -1.4756599799662662`}, \
{-2.474419339725472, -1.4212047170153475`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.474419339725472, -1.4212047170153475`}, \
{-2.422763365772555, -0.5243400200337339}, {-1.525580660274528, \
-0.5787952829846525}, {-1.5772366342274449`, -1.4756599799662662`}, \
{-2.474419339725472, -1.4212047170153475`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2., -0.45}, {-2., -0.45}, {-2., -0.3}, {-2., \
-0.30000000000000004`}, {-2., -0.45}}], 
     PolygonBox[{{-2., -0.30000000000000004`}, {-2., -0.3}, {-2., \
-0.15000000000000008`}, {-2., -0.15000000000000002`}, {-2., \
-0.30000000000000004`}}], 
     PolygonBox[{{-2., -0.15000000000000002`}, {-2., -0.15000000000000008`}, \
{-2., -1.1102230246251565`*^-16}, {-2., 0.}, {-2., -0.15000000000000002`}}], 
     PolygonBox[{{-2., 0.}, {-2., 0.}, {-2., 0.14999999999999997`}, {-2., 
      0.14999999999999997`}, {-2., 0.}}], 
     PolygonBox[{{-2., 0.14999999999999997`}, {-2., 
      0.14999999999999997`}, {-2., 0.29999999999999993`}, {-2., 0.3}, {-2., 
      0.14999999999999997`}}], 
     PolygonBox[{{-2., 0.3}, {-2., 0.29999999999999993`}, {-2., 
      0.44999999999999996`}, {-2., 0.4499999999999999}, {-2., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2., -0.45}, {-2., -0.30000000000000004`}, {-2., \
-0.15000000000000002`}, {-2., -5.551115123125783*^-17}, {-2., 
       0.14999999999999997`}, {-2., 0.3}, {-2., 0.4499999999999999}, {-2., 
       0.45}, {-2., 0.30000000000000004`}, {-2., 0.15000000000000002`}, {-2., 
       5.551115123125783*^-17}, {-2., -0.14999999999999997`}, {-2., -0.3}, \
{-2., -0.4499999999999999}, {-2., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.4493063074013928`, 0.}, {-2.4493063074013928`, 
        5.5109105961630896`*^-17}, {-2.2995375382675953`, 
        4.592425496802574*^-17}, {-2.2995375382675953`, 
        9.184850993605149*^-18}, {-2.4493063074013928`, 0.}}], 
       PolygonBox[{{-2.2995375382675953`, 
        9.184850993605149*^-18}, {-2.2995375382675953`, 
        4.592425496802574*^-17}, {-2.1497687691337974`, 
        3.67394039744206*^-17}, {-2.1497687691337974`, 
        1.8369701987210297`*^-17}, {-2.2995375382675953`, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{-2.1497687691337974`, 
        1.8369701987210297`*^-17}, {-2.1497687691337974`, 
        3.67394039744206*^-17}, {-2., 2.7554552980815454`*^-17}, {-2., 
        2.7554552980815448`*^-17}, {-2.1497687691337974`, 
        1.8369701987210297`*^-17}}], 
       PolygonBox[{{-2., 2.7554552980815448`*^-17}, {-2., 
        2.7554552980815448`*^-17}, {-1.8502312308662026`, 
        1.83697019872103*^-17}, {-1.8502312308662026`, 
        3.6739403974420595`*^-17}, {-2., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{-1.8502312308662026`, 
        3.6739403974420595`*^-17}, {-1.8502312308662026`, 
        1.83697019872103*^-17}, {-1.700462461732405, 
        9.184850993605152*^-18}, {-1.700462461732405, 
        4.592425496802574*^-17}, {-1.8502312308662026`, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{-1.700462461732405, 
        4.592425496802574*^-17}, {-1.700462461732405, 
        9.184850993605153*^-18}, {-1.5506936925986072`, 
        4.5887548728832574`*^-33}, {-1.5506936925986072`, 
        5.510910596163089*^-17}, {-1.700462461732405, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.4493063074013928`, 0.}, {-2.2995375382675953`, 
         0.}, {-2.1497687691337974`, 0.}, {-2., 0.}, {-1.8502312308662026`, 
         0.}, {-1.700462461732405, 0.}, {-1.5506936925986072`, 
         0.}, {-1.5506936925986072`, 0.}, {-1.7004624617324047`, 
         0.}, {-1.8502312308662023`, 0.}, {-2., 0.}, {-2.1497687691337974`, 
         0.}, {-2.2995375382675953`, 0.}, {-2.4493063074013928`, 
         0.}, {-2.4493063074013928`, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.4493063074013928`, -0.45}, {-2.4493063074013928`, 
      0.45}, {-1.5506936925986072`, 
      0.45}, {-1.5506936925986072`, -0.45}, {-2.4493063074013928`, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.4493063074013928`, -0.45}, {-2.4493063074013928`, 
       0.45}, {-1.5506936925986072`, 
       0.45}, {-1.5506936925986072`, -0.45}, {-2.4493063074013928`, \
-0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.9741720130235416`, 
      0.5515676515091932}, {-1.9741720130235416`, 
      0.5515676515091932}, {-1.9827813420156943`, 
      0.7010451010061289}, {-1.9827813420156943`, 
      0.7010451010061288}, {-1.9741720130235416`, 0.5515676515091932}}], 
     PolygonBox[{{-1.9827813420156943`, 
      0.7010451010061288}, {-1.9827813420156943`, 
      0.7010451010061289}, {-1.991390671007847, 
      0.8505225505030644}, {-1.9913906710078473`, 
      0.8505225505030645}, {-1.9827813420156943`, 0.7010451010061288}}], 
     PolygonBox[{{-1.9913906710078473`, 
      0.8505225505030645}, {-1.991390671007847, 0.8505225505030644}, {-2., 
      0.9999999999999999}, {-2., 1.}, {-1.9913906710078473`, 
      0.8505225505030645}}], 
     PolygonBox[{{-2., 1.}, {-2., 1.}, {-2.008609328992153, 
      1.1494774494969355`}, {-2.008609328992153, 1.1494774494969355`}, {-2., 
      1.}}], PolygonBox[{{-2.008609328992153, 
      1.1494774494969355`}, {-2.008609328992153, 
      1.1494774494969355`}, {-2.0172186579843054`, 
      1.298954898993871}, {-2.0172186579843054`, 
      1.298954898993871}, {-2.008609328992153, 1.1494774494969355`}}], 
     PolygonBox[{{-2.0172186579843054`, 
      1.298954898993871}, {-2.0172186579843054`, 
      1.298954898993871}, {-2.0258279869764584`, 
      1.4484323484908068`}, {-2.0258279869764584`, 
      1.4484323484908066`}, {-2.0172186579843054`, 1.298954898993871}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.9741720130235416`, 
       0.5515676515091932}, {-1.9827813420156943`, 
       0.7010451010061288}, {-1.9913906710078473`, 0.8505225505030645}, {-2., 
       1.}, {-2.008609328992153, 1.1494774494969355`}, {-2.0172186579843054`, 
       1.298954898993871}, {-2.0258279869764584`, 
       1.4484323484908066`}, {-2.0258279869764584`, 
       1.4484323484908068`}, {-2.0172186579843054`, 
       1.298954898993871}, {-2.008609328992153, 1.1494774494969355`}, {-2., 
       1.}, {-1.9913906710078473`, 0.8505225505030645}, {-1.9827813420156943`,
        0.7010451010061289}, {-1.9741720130235416`, 
       0.5515676515091934}, {-1.9741720130235416`, 0.5515676515091932}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.4485913527490135`, 
        0.9727723685245406}, {-2.4485913527490135`, 
        0.9727723685245407}, {-2.2990609018326755`, 
        0.9818482456830272}, {-2.299060901832676, 
        0.9818482456830271}, {-2.4485913527490135`, 0.9727723685245406}}], 
       PolygonBox[{{-2.299060901832676, 
        0.9818482456830271}, {-2.2990609018326755`, 
        0.9818482456830272}, {-2.149530450916338, 
        0.9909241228415135}, {-2.149530450916338, 
        0.9909241228415135}, {-2.299060901832676, 0.9818482456830271}}], 
       PolygonBox[{{-2.149530450916338, 
        0.9909241228415135}, {-2.149530450916338, 0.9909241228415135}, {-2., 
        1.}, {-2., 1.}, {-2.149530450916338, 0.9909241228415135}}], 
       PolygonBox[{{-2., 1.}, {-2., 1.}, {-1.8504695490836622`, 
        1.0090758771584865`}, {-1.8504695490836622`, 
        1.0090758771584865`}, {-2., 1.}}], 
       PolygonBox[{{-1.8504695490836622`, 
        1.0090758771584865`}, {-1.8504695490836622`, 
        1.0090758771584865`}, {-1.7009390981673245`, 
        1.018151754316973}, {-1.7009390981673242`, 
        1.018151754316973}, {-1.8504695490836622`, 1.0090758771584865`}}], 
       PolygonBox[{{-1.7009390981673242`, 
        1.018151754316973}, {-1.7009390981673245`, 
        1.018151754316973}, {-1.5514086472509865`, 
        1.0272276314754594`}, {-1.5514086472509865`, 
        1.0272276314754594`}, {-1.7009390981673242`, 1.018151754316973}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.4485913527490135`, 
         0.9727723685245406}, {-2.299060901832676, 
         0.9818482456830271}, {-2.149530450916338, 0.9909241228415135}, {-2., 
         1.}, {-1.8504695490836622`, 
         1.0090758771584865`}, {-1.7009390981673242`, 
         1.018151754316973}, {-1.5514086472509865`, 
         1.0272276314754594`}, {-1.5514086472509865`, 
         1.0272276314754594`}, {-1.7009390981673242`, 
         1.018151754316973}, {-1.850469549083662, 1.0090758771584865`}, {-2., 
         1.}, {-2.149530450916338, 0.9909241228415135}, {-2.2990609018326755`,
          0.9818482456830271}, {-2.4485913527490135`, 
         0.9727723685245406}, {-2.4485913527490135`, 
         0.9727723685245406}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.422763365772555, 
      0.5243400200337339}, {-2.474419339725472, 
      1.4212047170153475`}, {-1.5772366342274449`, 
      1.4756599799662662`}, {-1.525580660274528, 
      0.5787952829846525}, {-2.422763365772555, 0.5243400200337339}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.422763365772555, 0.5243400200337339}, {-2.474419339725472, 
       1.4212047170153475`}, {-1.5772366342274449`, 
       1.4756599799662662`}, {-1.525580660274528, 
       0.5787952829846525}, {-2.422763365772555, 0.5243400200337339}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.9486904418253108`, 
      1.5561650236583802`}, {-1.9486904418253106`, 
      1.5561650236583802`}, {-1.9657936278835404`, 
      1.7041100157722533`}, {-1.9657936278835404`, 
      1.7041100157722533`}, {-1.9486904418253108`, 1.5561650236583802`}}], 
     PolygonBox[{{-1.9657936278835404`, 
      1.7041100157722533`}, {-1.9657936278835404`, 
      1.7041100157722533`}, {-1.9828968139417702`, 
      1.8520550078861266`}, {-1.9828968139417702`, 
      1.8520550078861266`}, {-1.9657936278835404`, 1.7041100157722533`}}], 
     PolygonBox[{{-1.9828968139417702`, 
      1.8520550078861266`}, {-1.9828968139417702`, 1.8520550078861266`}, {-2.,
       2.}, {-2., 2.}, {-1.9828968139417702`, 1.8520550078861266`}}], 
     PolygonBox[{{-2., 2.}, {-2., 2.}, {-2.01710318605823, 
      2.147944992113873}, {-2.01710318605823, 2.147944992113873}, {-2., 2.}}],
      PolygonBox[{{-2.01710318605823, 2.147944992113873}, {-2.01710318605823, 
      2.147944992113873}, {-2.0342063721164596`, 
      2.2958899842277467`}, {-2.0342063721164596`, 
      2.2958899842277467`}, {-2.01710318605823, 2.147944992113873}}], 
     PolygonBox[{{-2.0342063721164596`, 
      2.2958899842277467`}, {-2.0342063721164596`, 
      2.2958899842277467`}, {-2.0513095581746894`, 
      2.44383497634162}, {-2.0513095581746894`, 
      2.44383497634162}, {-2.0342063721164596`, 2.2958899842277467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.9486904418253108`, 
       1.5561650236583802`}, {-1.9657936278835404`, 
       1.7041100157722533`}, {-1.9828968139417702`, 
       1.8520550078861266`}, {-2., 2.}, {-2.01710318605823, 
       2.147944992113873}, {-2.0342063721164596`, 
       2.2958899842277467`}, {-2.0513095581746894`, 
       2.44383497634162}, {-2.0513095581746894`, 
       2.44383497634162}, {-2.0342063721164596`, 
       2.2958899842277467`}, {-2.01710318605823, 2.147944992113873}, {-2., 
       2.}, {-1.9828968139417702`, 
       1.8520550078861266`}, {-1.9657936278835404`, 
       1.7041100157722533`}, {-1.9486904418253108`, 
       1.5561650236583802`}, {-1.9486904418253108`, 1.5561650236583802`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.446474929456423, 
        1.946354468818439}, {-2.446474929456423, 
        1.946354468818439}, {-2.2976499529709487`, 
        1.9642363125456261`}, {-2.297649952970949, 
        1.964236312545626}, {-2.446474929456423, 1.946354468818439}}], 
       PolygonBox[{{-2.297649952970949, 
        1.964236312545626}, {-2.2976499529709487`, 
        1.9642363125456261`}, {-2.1488249764854745`, 
        1.982118156272813}, {-2.1488249764854745`, 
        1.982118156272813}, {-2.297649952970949, 1.964236312545626}}], 
       PolygonBox[{{-2.1488249764854745`, 
        1.982118156272813}, {-2.1488249764854745`, 1.982118156272813}, {-2., 
        2.}, {-2., 2.}, {-2.1488249764854745`, 1.982118156272813}}], 
       PolygonBox[{{-2., 2.}, {-2., 2.}, {-1.8511750235145257`, 
        2.017881843727187}, {-1.8511750235145257`, 2.017881843727187}, {-2., 
        2.}}], PolygonBox[{{-1.8511750235145257`, 
        2.017881843727187}, {-1.8511750235145257`, 
        2.017881843727187}, {-1.7023500470290513`, 
        2.035763687454374}, {-1.7023500470290511`, 
        2.035763687454374}, {-1.8511750235145257`, 2.017881843727187}}], 
       PolygonBox[{{-1.7023500470290511`, 
        2.035763687454374}, {-1.7023500470290513`, 
        2.035763687454374}, {-1.5535250705435768`, 
        2.053645531181561}, {-1.5535250705435768`, 
        2.053645531181561}, {-1.7023500470290511`, 2.035763687454374}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.446474929456423, 1.946354468818439}, {-2.297649952970949,
          1.964236312545626}, {-2.1488249764854745`, 1.982118156272813}, {-2.,
          2.}, {-1.8511750235145257`, 
         2.017881843727187}, {-1.7023500470290511`, 
         2.035763687454374}, {-1.5535250705435768`, 
         2.053645531181561}, {-1.5535250705435768`, 
         2.053645531181561}, {-1.7023500470290511`, 
         2.035763687454374}, {-1.8511750235145255`, 2.017881843727187}, {-2., 
         2.}, {-2.1488249764854745`, 
         1.982118156272813}, {-2.2976499529709487`, 
         1.964236312545626}, {-2.446474929456423, 
         1.946354468818439}, {-2.446474929456423, 1.946354468818439}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.395165371281734, 
      1.502519492476819}, {-2.4977844876311126`, 
      2.390189445160059}, {-1.604834628718266, 
      2.497480507523181}, {-1.5022155123688876`, 
      1.609810554839941}, {-2.395165371281734, 1.502519492476819}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.395165371281734, 1.502519492476819}, {-2.4977844876311126`,
        2.390189445160059}, {-1.604834628718266, 
       2.497480507523181}, {-1.5022155123688876`, 
       1.609810554839941}, {-2.395165371281734, 1.502519492476819}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.9238783149296959`, 
      2.563492435983596}, {-1.9238783149296959`, 
      2.563492435983596}, {-1.9492522099531304`, 
      2.708994957322397}, {-1.9492522099531306`, 
      2.708994957322397}, {-1.9238783149296959`, 2.563492435983596}}], 
     PolygonBox[{{-1.9492522099531306`, 
      2.708994957322397}, {-1.9492522099531304`, 
      2.708994957322397}, {-1.9746261049765652`, 
      2.8544974786611985`}, {-1.9746261049765652`, 
      2.8544974786611985`}, {-1.9492522099531306`, 2.708994957322397}}], 
     PolygonBox[{{-1.9746261049765652`, 
      2.8544974786611985`}, {-1.9746261049765652`, 2.8544974786611985`}, {-2.,
       3.}, {-2., 3.}, {-1.9746261049765652`, 2.8544974786611985`}}], 
     PolygonBox[{{-2., 3.}, {-2., 3.}, {-2.0253738950234346`, 
      3.1455025213388015`}, {-2.0253738950234346`, 3.1455025213388015`}, {-2.,
       3.}}], PolygonBox[{{-2.0253738950234346`, 
      3.1455025213388015`}, {-2.0253738950234346`, 
      3.1455025213388015`}, {-2.0507477900468696`, 
      3.291005042677603}, {-2.0507477900468696`, 
      3.291005042677603}, {-2.0253738950234346`, 3.1455025213388015`}}], 
     PolygonBox[{{-2.0507477900468696`, 
      3.291005042677603}, {-2.0507477900468696`, 
      3.291005042677603}, {-2.076121685070304, 
      3.436507564016404}, {-2.076121685070304, 
      3.436507564016404}, {-2.0507477900468696`, 3.291005042677603}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.9238783149296959`, 
       2.563492435983596}, {-1.9492522099531306`, 
       2.708994957322397}, {-1.9746261049765652`, 2.8544974786611985`}, {-2., 
       3.}, {-2.0253738950234346`, 
       3.1455025213388015`}, {-2.0507477900468696`, 
       3.291005042677603}, {-2.076121685070304, 
       3.436507564016404}, {-2.076121685070304, 
       3.436507564016404}, {-2.0507477900468696`, 
       3.291005042677603}, {-2.0253738950234346`, 3.1455025213388015`}, {-2., 
       3.}, {-1.9746261049765652`, 
       2.8544974786611985`}, {-1.9492522099531306`, 
       2.708994957322397}, {-1.9238783149296959`, 
       2.563492435983596}, {-1.9238783149296959`, 2.563492435983596}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.443039216995193, 
        2.9214720710923667`}, {-2.443039216995193, 
        2.9214720710923667`}, {-2.2953594779967954`, 
        2.947648047394911}, {-2.2953594779967954`, 
        2.947648047394911}, {-2.443039216995193, 2.9214720710923667`}}], 
       PolygonBox[{{-2.2953594779967954`, 
        2.947648047394911}, {-2.2953594779967954`, 
        2.947648047394911}, {-2.1476797389983977`, 
        2.9738240236974556`}, {-2.1476797389983977`, 
        2.9738240236974556`}, {-2.2953594779967954`, 2.947648047394911}}], 
       PolygonBox[{{-2.1476797389983977`, 
        2.9738240236974556`}, {-2.1476797389983977`, 
        2.9738240236974556`}, {-2., 3.}, {-2., 3.}, {-2.1476797389983977`, 
        2.9738240236974556`}}], 
       PolygonBox[{{-2., 3.}, {-2., 3.}, {-1.8523202610016023`, 
        3.0261759763025444`}, {-1.8523202610016023`, 
        3.0261759763025444`}, {-2., 3.}}], 
       PolygonBox[{{-1.8523202610016023`, 
        3.0261759763025444`}, {-1.8523202610016023`, 
        3.0261759763025444`}, {-1.7046405220032046`, 
        3.052351952605089}, {-1.7046405220032046`, 
        3.052351952605089}, {-1.8523202610016023`, 3.0261759763025444`}}], 
       PolygonBox[{{-1.7046405220032046`, 
        3.052351952605089}, {-1.7046405220032046`, 
        3.052351952605089}, {-1.556960783004807, 
        3.0785279289076333`}, {-1.556960783004807, 
        3.0785279289076333`}, {-1.7046405220032046`, 3.052351952605089}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.443039216995193, 
         2.9214720710923667`}, {-2.2953594779967954`, 
         2.947648047394911}, {-2.1476797389983977`, 
         2.9738240236974556`}, {-2., 3.}, {-1.8523202610016023`, 
         3.0261759763025444`}, {-1.7046405220032046`, 
         3.052351952605089}, {-1.556960783004807, 
         3.0785279289076333`}, {-1.556960783004807, 
         3.0785279289076333`}, {-1.7046405220032046`, 
         3.052351952605089}, {-1.8523202610016023`, 
         3.0261759763025444`}, {-2., 3.}, {-2.1476797389983977`, 
         2.9738240236974556`}, {-2.2953594779967954`, 
         2.947648047394911}, {-2.443039216995193, 
         2.9214720710923667`}, {-2.443039216995193, 
         2.9214720710923667`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.366917531924889, 
      2.4849645070759623`}, {-2.5191609020654973`, 
      3.357979635108771}, {-1.633082468075111, 
      3.5150354929240377`}, {-1.4808390979345027`, 
      2.642020364891229}, {-2.366917531924889, 2.4849645070759623`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.366917531924889, 
       2.4849645070759623`}, {-2.5191609020654973`, 
       3.357979635108771}, {-1.633082468075111, 
       3.5150354929240377`}, {-1.4808390979345027`, 
       2.642020364891229}, {-2.366917531924889, 2.4849645070759623`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.9000154208176978`, 
      3.5731024445084936`}, {-1.9000154208176978`, 
      3.5731024445084936`}, {-1.9333436138784652`, 
      3.7154016296723293`}, {-1.9333436138784652`, 
      3.7154016296723293`}, {-1.9000154208176978`, 3.5731024445084936`}}], 
     PolygonBox[{{-1.9333436138784652`, 
      3.7154016296723293`}, {-1.9333436138784652`, 
      3.7154016296723293`}, {-1.9666718069392326`, 
      3.8577008148361647`}, {-1.9666718069392326`, 
      3.8577008148361647`}, {-1.9333436138784652`, 3.7154016296723293`}}], 
     PolygonBox[{{-1.9666718069392326`, 
      3.8577008148361647`}, {-1.9666718069392326`, 3.8577008148361647`}, {-2.,
       4.}, {-2., 4.}, {-1.9666718069392326`, 3.8577008148361647`}}], 
     PolygonBox[{{-2., 4.}, {-2., 4.}, {-2.0333281930607674`, 
      4.142299185163836}, {-2.0333281930607674`, 4.142299185163836}, {-2., 
      4.}}], PolygonBox[{{-2.0333281930607674`, 
      4.142299185163836}, {-2.0333281930607674`, 
      4.142299185163836}, {-2.066656386121535, 
      4.284598370327671}, {-2.066656386121535, 
      4.284598370327671}, {-2.0333281930607674`, 4.142299185163836}}], 
     PolygonBox[{{-2.066656386121535, 4.284598370327671}, {-2.066656386121535,
       4.284598370327671}, {-2.099984579182302, 
      4.426897555491506}, {-2.099984579182302, 
      4.426897555491506}, {-2.066656386121535, 4.284598370327671}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.9000154208176978`, 
       3.5731024445084936`}, {-1.9333436138784652`, 
       3.7154016296723293`}, {-1.9666718069392326`, 
       3.8577008148361647`}, {-2., 4.}, {-2.0333281930607674`, 
       4.142299185163836}, {-2.066656386121535, 
       4.284598370327671}, {-2.099984579182302, 
       4.426897555491506}, {-2.099984579182302, 
       4.426897555491506}, {-2.066656386121535, 
       4.284598370327671}, {-2.0333281930607674`, 4.142299185163836}, {-2., 
       4.}, {-1.9666718069392326`, 
       3.8577008148361647`}, {-1.9333436138784652`, 
       3.7154016296723293`}, {-1.9000154208176978`, 
       3.573102444508494}, {-1.9000154208176978`, 3.5731024445084936`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.438411364870582, 
        3.8987006365216725`}, {-2.438411364870582, 
        3.8987006365216725`}, {-2.292274243247055, 
        3.9324670910144484`}, {-2.292274243247055, 
        3.9324670910144484`}, {-2.438411364870582, 3.8987006365216725`}}], 
       PolygonBox[{{-2.292274243247055, 
        3.9324670910144484`}, {-2.292274243247055, 
        3.9324670910144484`}, {-2.1461371216235277`, 
        3.966233545507224}, {-2.1461371216235277`, 
        3.966233545507224}, {-2.292274243247055, 3.9324670910144484`}}], 
       PolygonBox[{{-2.1461371216235277`, 
        3.966233545507224}, {-2.1461371216235277`, 3.966233545507224}, {-2., 
        4.}, {-2., 4.}, {-2.1461371216235277`, 3.966233545507224}}], 
       PolygonBox[{{-2., 4.}, {-2., 4.}, {-1.8538628783764726`, 
        4.033766454492776}, {-1.8538628783764726`, 4.033766454492776}, {-2., 
        4.}}], PolygonBox[{{-1.8538628783764726`, 
        4.033766454492776}, {-1.8538628783764726`, 
        4.033766454492776}, {-1.7077257567529451`, 
        4.067532908985552}, {-1.7077257567529451`, 
        4.067532908985552}, {-1.8538628783764726`, 4.033766454492776}}], 
       PolygonBox[{{-1.7077257567529451`, 
        4.067532908985552}, {-1.7077257567529451`, 
        4.067532908985552}, {-1.5615886351294177`, 
        4.1012993634783275`}, {-1.5615886351294177`, 
        4.1012993634783275`}, {-1.7077257567529451`, 4.067532908985552}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.438411364870582, 
         3.8987006365216725`}, {-2.292274243247055, 
         3.9324670910144484`}, {-2.1461371216235277`, 
         3.966233545507224}, {-2., 4.}, {-1.8538628783764726`, 
         4.033766454492776}, {-1.7077257567529451`, 
         4.067532908985552}, {-1.5615886351294177`, 
         4.1012993634783275`}, {-1.5615886351294177`, 
         4.1012993634783275`}, {-1.7077257567529451`, 
         4.067532908985552}, {-1.8538628783764726`, 4.033766454492776}, {-2., 
         4.}, {-2.146137121623527, 3.966233545507224}, {-2.292274243247055, 
         3.9324670910144484`}, {-2.438411364870582, 
         3.8987006365216725`}, {-2.438411364870582, 
         3.8987006365216725`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.3384267856882803`, 
      3.4718030810301665`}, {-2.5383959440528843`, 
      4.325598192013179}, {-1.66157321431172, 
      4.528196918969834}, {-1.4616040559471155`, 
      3.674401807986821}, {-2.3384267856882803`, 3.4718030810301665`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.3384267856882803`, 
       3.4718030810301665`}, {-2.5383959440528843`, 
       4.325598192013179}, {-1.66157321431172, 
       4.528196918969834}, {-1.4616040559471155`, 
       3.674401807986821}, {-2.3384267856882803`, 3.4718030810301665`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.877324604629557, 
      4.584462952331788}, {-1.8773246046295569`, 
      4.584462952331788}, {-1.9182164030863713`, 
      4.722975301554525}, {-1.9182164030863713`, 
      4.722975301554525}, {-1.877324604629557, 4.584462952331788}}], 
     PolygonBox[{{-1.9182164030863713`, 
      4.722975301554525}, {-1.9182164030863713`, 
      4.722975301554525}, {-1.9591082015431855`, 
      4.861487650777263}, {-1.9591082015431858`, 
      4.861487650777263}, {-1.9182164030863713`, 4.722975301554525}}], 
     PolygonBox[{{-1.9591082015431858`, 
      4.861487650777263}, {-1.9591082015431855`, 4.861487650777263}, {-2., 
      5.}, {-2., 5.}, {-1.9591082015431858`, 4.861487650777263}}], 
     PolygonBox[{{-2., 5.}, {-2., 5.}, {-2.0408917984568142`, 
      5.138512349222737}, {-2.0408917984568142`, 5.138512349222737}, {-2., 
      5.}}], PolygonBox[{{-2.0408917984568142`, 
      5.138512349222737}, {-2.0408917984568142`, 
      5.138512349222737}, {-2.0817835969136285`, 
      5.277024698445475}, {-2.0817835969136285`, 
      5.277024698445475}, {-2.0408917984568142`, 5.138512349222737}}], 
     PolygonBox[{{-2.0817835969136285`, 
      5.277024698445475}, {-2.0817835969136285`, 
      5.277024698445475}, {-2.1226753953704427`, 
      5.415537047668212}, {-2.1226753953704427`, 
      5.415537047668212}, {-2.0817835969136285`, 5.277024698445475}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.877324604629557, 4.584462952331788}, {-1.9182164030863713`,
        4.722975301554525}, {-1.9591082015431858`, 4.861487650777263}, {-2., 
       5.}, {-2.0408917984568142`, 5.138512349222737}, {-2.0817835969136285`, 
       5.277024698445475}, {-2.1226753953704427`, 
       5.415537047668212}, {-2.122675395370443, 
       5.415537047668212}, {-2.0817835969136285`, 
       5.277024698445475}, {-2.0408917984568142`, 5.138512349222737}, {-2., 
       5.}, {-1.9591082015431858`, 4.861487650777263}, {-1.9182164030863713`, 
       4.722975301554525}, {-1.877324604629557, 
       4.584462952331788}, {-1.877324604629557, 4.584462952331788}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-2.4327508547046017`, 
        4.8784281719069265`}, {-2.4327508547046017`, 
        4.8784281719069265`}, {-2.288500569803068, 
        4.918952114604617}, {-2.288500569803068, 
        4.918952114604617}, {-2.4327508547046017`, 4.8784281719069265`}}], 
       PolygonBox[{{-2.288500569803068, 
        4.918952114604617}, {-2.288500569803068, 
        4.918952114604617}, {-2.144250284901534, 
        4.959476057302309}, {-2.144250284901534, 
        4.959476057302309}, {-2.288500569803068, 4.918952114604617}}], 
       PolygonBox[{{-2.144250284901534, 
        4.959476057302309}, {-2.144250284901534, 4.959476057302309}, {-2., 
        5.}, {-2., 5.}, {-2.144250284901534, 4.959476057302309}}], 
       PolygonBox[{{-2., 5.}, {-2., 5.}, {-1.855749715098466, 
        5.040523942697691}, {-1.855749715098466, 5.040523942697691}, {-2., 
        5.}}], PolygonBox[{{-1.855749715098466, 
        5.040523942697691}, {-1.855749715098466, 
        5.040523942697691}, {-1.7114994301969322`, 
        5.081047885395383}, {-1.7114994301969322`, 
        5.081047885395383}, {-1.855749715098466, 5.040523942697691}}], 
       PolygonBox[{{-1.7114994301969322`, 
        5.081047885395383}, {-1.7114994301969322`, 
        5.081047885395383}, {-1.567249145295398, 
        5.1215718280930735`}, {-1.5672491452953983`, 
        5.1215718280930735`}, {-1.7114994301969322`, 5.081047885395383}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-2.4327508547046017`, 
         4.8784281719069265`}, {-2.288500569803068, 
         4.918952114604617}, {-2.144250284901534, 4.959476057302309}, {-2., 
         5.}, {-1.855749715098466, 5.040523942697691}, {-1.7114994301969322`, 
         5.081047885395383}, {-1.5672491452953983`, 
         5.1215718280930735`}, {-1.567249145295398, 
         5.1215718280930735`}, {-1.711499430196932, 
         5.081047885395383}, {-1.855749715098466, 5.040523942697691}, {-2., 
         5.}, {-2.144250284901534, 4.959476057302309}, {-2.288500569803068, 
         4.918952114604617}, {-2.4327508547046017`, 
         4.8784281719069265`}, {-2.4327508547046017`, 
         4.8784281719069265`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-2.310075459334159, 4.462891124238714}, {-2.555426250075045,
       5.2939652195751385`}, {-1.689924540665841, 
      5.537108875761286}, {-1.4445737499249551`, 
      4.7060347804248615`}, {-2.310075459334159, 4.462891124238714}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-2.310075459334159, 4.462891124238714}, {-2.555426250075045, 
       5.2939652195751385`}, {-1.689924540665841, 
       5.537108875761286}, {-1.4445737499249551`, 
       4.7060347804248615`}, {-2.310075459334159, 4.462891124238714}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.1249029946161069`, -5.415252911740647}, \
{-1.1249029946161067`, -5.415252911740648}, {-1.0832686630774044`, \
-5.276835274493765}, {-1.0832686630774047`, -5.276835274493765}, \
{-1.1249029946161069`, -5.415252911740647}}], 
     PolygonBox[{{-1.0832686630774047`, -5.276835274493765}, \
{-1.0832686630774044`, -5.276835274493765}, {-1.0416343315387022`, \
-5.138417637246882}, {-1.0416343315387022`, -5.138417637246882}, \
{-1.0832686630774047`, -5.276835274493765}}], 
     PolygonBox[{{-1.0416343315387022`, -5.138417637246882}, \
{-1.0416343315387022`, -5.138417637246882}, {-1., -5.}, {-1., -5.}, \
{-1.0416343315387022`, -5.138417637246882}}], 
     PolygonBox[{{-1., -5.}, {-1., -5.}, {-0.9583656684612977, \
-4.861582362753118}, {-0.9583656684612977, -4.861582362753118}, {-1., -5.}}], 
     PolygonBox[{{-0.9583656684612977, -4.861582362753118}, \
{-0.9583656684612977, -4.861582362753118}, {-0.9167313369225955, \
-4.723164725506235}, {-0.9167313369225955, -4.723164725506235}, \
{-0.9583656684612977, -4.861582362753118}}], 
     PolygonBox[{{-0.9167313369225955, -4.723164725506235}, \
{-0.9167313369225955, -4.723164725506235}, {-0.8750970053838931, \
-4.584747088259353}, {-0.8750970053838931, -4.584747088259353}, \
{-0.9167313369225955, -4.723164725506235}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.1249029946161069`, -5.415252911740647}, \
{-1.0832686630774047`, -5.276835274493765}, {-1.0416343315387022`, \
-5.138417637246882}, {-1., -5.}, {-0.9583656684612977, -4.861582362753118}, \
{-0.9167313369225955, -4.723164725506235}, {-0.8750970053838931, \
-4.584747088259353}, {-0.8750970053838931, -4.584747088259353}, \
{-0.9167313369225955, -4.723164725506235}, {-0.9583656684612977, \
-4.861582362753118}, {-1., -5.}, {-1.0416343315387022`, -5.138417637246882}, \
{-1.0832686630774047`, -5.276835274493765}, {-1.1249029946161069`, \
-5.415252911740647}, {-1.1249029946161069`, -5.415252911740647}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4323172471057517`, -4.879732542943477}, \
{-1.4323172471057517`, -4.879732542943477}, {-1.288211498070501, \
-4.919821695295651}, {-1.288211498070501, -4.919821695295651}, \
{-1.4323172471057517`, -4.879732542943477}}], 
       PolygonBox[{{-1.288211498070501, -4.919821695295651}, \
{-1.288211498070501, -4.919821695295651}, {-1.1441057490352506`, \
-4.9599108476478255`}, {-1.1441057490352506`, -4.9599108476478255`}, \
{-1.288211498070501, -4.919821695295651}}], 
       PolygonBox[{{-1.1441057490352506`, -4.9599108476478255`}, \
{-1.1441057490352506`, -4.9599108476478255`}, {-1., -5.}, {-1., -5.}, \
{-1.1441057490352506`, -4.9599108476478255`}}], 
       PolygonBox[{{-1., -5.}, {-1., -5.}, {-0.8558942509647495, \
-5.0400891523521745`}, {-0.8558942509647495, -5.0400891523521745`}, {-1., \
-5.}}], PolygonBox[{{-0.8558942509647495, -5.0400891523521745`}, \
{-0.8558942509647495, -5.0400891523521745`}, {-0.7117885019294989, \
-5.080178304704349}, {-0.7117885019294989, -5.080178304704349}, \
{-0.8558942509647495, -5.0400891523521745`}}], 
       PolygonBox[{{-0.7117885019294989, -5.080178304704349}, \
{-0.7117885019294989, -5.080178304704349}, {-0.5676827528942485, \
-5.120267457056523}, {-0.5676827528942485, -5.120267457056523}, \
{-0.7117885019294989, -5.080178304704349}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4323172471057517`, -4.879732542943477}, \
{-1.288211498070501, -4.919821695295651}, {-1.1441057490352506`, \
-4.9599108476478255`}, {-1., -5.}, {-0.8558942509647495, \
-5.0400891523521745`}, {-0.7117885019294989, -5.080178304704349}, \
{-0.5676827528942485, -5.120267457056523}, {-0.5676827528942484, \
-5.120267457056523}, {-0.7117885019294989, -5.080178304704349}, \
{-0.8558942509647495, -5.0400891523521745`}, {-1., -5.}, \
{-1.1441057490352504`, -4.9599108476478255`}, {-1.288211498070501, \
-4.919821695295651}, {-1.4323172471057515`, -4.879732542943477}, \
{-1.4323172471057517`, -4.879732542943477}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.5572202417218586`, -5.294985454684124}, \
{-1.3074142524896448`, -4.464479631202829}, {-0.44277975827814153`, \
-4.705014545315876}, {-0.6925857475103553, -5.535520368797171}, \
{-1.5572202417218586`, -5.294985454684124}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5572202417218586`, -5.294985454684124}, \
{-1.3074142524896448`, -4.464479631202829}, {-0.44277975827814153`, \
-4.705014545315876}, {-0.6925857475103553, -5.535520368797171}, \
{-1.5572202417218586`, -5.294985454684124}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.1019196239073528`, -4.4266538045272394`}, \
{-1.1019196239073528`, -4.4266538045272394`}, {-1.067946415938235, \
-4.284435869684827}, {-1.0679464159382352`, -4.284435869684827}, \
{-1.1019196239073528`, -4.4266538045272394`}}], 
     PolygonBox[{{-1.0679464159382352`, -4.284435869684827}, \
{-1.067946415938235, -4.284435869684827}, {-1.0339732079691175`, \
-4.142217934842414}, {-1.0339732079691175`, -4.142217934842413}, \
{-1.0679464159382352`, -4.284435869684827}}], 
     PolygonBox[{{-1.0339732079691175`, -4.142217934842413}, \
{-1.0339732079691175`, -4.142217934842414}, {-1., -4.}, {-1., -4.}, \
{-1.0339732079691175`, -4.142217934842413}}], 
     PolygonBox[{{-1., -4.}, {-1., -4.}, {-0.9660267920308824, \
-3.8577820651575867`}, {-0.9660267920308824, -3.8577820651575867`}, {-1., \
-4.}}], PolygonBox[{{-0.9660267920308824, -3.8577820651575867`}, \
{-0.9660267920308824, -3.8577820651575867`}, {-0.9320535840617648, \
-3.7155641303151734`}, {-0.9320535840617649, -3.7155641303151734`}, \
{-0.9660267920308824, -3.8577820651575867`}}], 
     PolygonBox[{{-0.9320535840617649, -3.7155641303151734`}, \
{-0.9320535840617648, -3.7155641303151734`}, {-0.8980803760926472, \
-3.57334619547276}, {-0.8980803760926472, -3.5733461954727606`}, \
{-0.9320535840617649, -3.7155641303151734`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.1019196239073528`, -4.4266538045272394`}, \
{-1.0679464159382352`, -4.284435869684827}, {-1.0339732079691175`, \
-4.142217934842413}, {-1., -4.}, {-0.9660267920308824, -3.8577820651575867`}, \
{-0.9320535840617649, -3.7155641303151734`}, {-0.8980803760926472, \
-3.5733461954727606`}, {-0.8980803760926472, -3.57334619547276}, \
{-0.9320535840617648, -3.7155641303151734`}, {-0.9660267920308824, \
-3.8577820651575867`}, {-1., -4.}, {-1.0339732079691175`, \
-4.142217934842413}, {-1.0679464159382352`, -4.284435869684827}, \
{-1.1019196239073528`, -4.4266538045272394`}, {-1.1019196239073528`, \
-4.4266538045272394`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4382770431043812`, -3.8996061687900316`}, \
{-1.4382770431043812`, -3.8996061687900316`}, {-1.2921846954029208`, \
-3.9330707791933546`}, {-1.2921846954029208`, -3.9330707791933546`}, \
{-1.4382770431043812`, -3.8996061687900316`}}], 
       PolygonBox[{{-1.2921846954029208`, -3.9330707791933546`}, \
{-1.2921846954029208`, -3.9330707791933546`}, {-1.1460923477014604`, \
-3.966535389596677}, {-1.1460923477014604`, -3.966535389596677}, \
{-1.2921846954029208`, -3.9330707791933546`}}], 
       PolygonBox[{{-1.1460923477014604`, -3.966535389596677}, \
{-1.1460923477014604`, -3.966535389596677}, {-1., -4.}, {-1., -4.}, \
{-1.1460923477014604`, -3.966535389596677}}], 
       PolygonBox[{{-1., -4.}, {-1., -4.}, {-0.8539076522985396, \
-4.033464610403323}, {-0.8539076522985396, -4.033464610403323}, {-1., -4.}}], 
       PolygonBox[{{-0.8539076522985396, -4.033464610403323}, \
{-0.8539076522985396, -4.033464610403323}, {-0.7078153045970793, \
-4.066929220806646}, {-0.7078153045970792, -4.066929220806646}, \
{-0.8539076522985396, -4.033464610403323}}], 
       PolygonBox[{{-0.7078153045970792, -4.066929220806646}, \
{-0.7078153045970793, -4.066929220806646}, {-0.561722956895619, \
-4.100393831209968}, {-0.561722956895619, -4.100393831209968}, \
{-0.7078153045970792, -4.066929220806646}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4382770431043812`, -3.8996061687900316`}, \
{-1.2921846954029208`, -3.9330707791933546`}, {-1.1460923477014604`, \
-3.966535389596677}, {-1., -4.}, {-0.8539076522985396, -4.033464610403323}, \
{-0.7078153045970792, -4.066929220806646}, {-0.561722956895619, \
-4.100393831209968}, {-0.5617229568956189, -4.100393831209968}, \
{-0.7078153045970792, -4.066929220806646}, {-0.8539076522985396, \
-4.033464610403323}, {-1., -4.}, {-1.1460923477014604`, -3.966535389596677}, \
{-1.2921846954029208`, -3.9330707791933546`}, {-1.438277043104381, \
-3.8996061687900316`}, {-1.4382770431043812`, -3.8996061687900316`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.5401966670117337`, -4.3262599733172715`}, \
{-1.3363574191970282`, -3.4729523642627917`}, {-0.45980333298826614`, \
-3.6737400266827285`}, {-0.6636425808029717, -4.527047635737208}, \
{-1.5401966670117337`, -4.3262599733172715`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.5401966670117337`, -4.3262599733172715`}, \
{-1.3363574191970282`, -3.4729523642627917`}, {-0.45980333298826614`, \
-3.6737400266827285`}, {-0.6636425808029717, -4.527047635737208}, \
{-1.5401966670117337`, -4.3262599733172715`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.0776714352856203`, -3.436338567286028}, \
{-1.07767143528562, -3.436338567286028}, {-1.05178095685708, \
-3.2908923781906854`}, {-1.0517809568570802`, -3.2908923781906854`}, \
{-1.0776714352856203`, -3.436338567286028}}], 
     PolygonBox[{{-1.0517809568570802`, -3.2908923781906854`}, \
{-1.05178095685708, -3.2908923781906854`}, {-1.02589047842854, \
-3.1454461890953427`}, {-1.02589047842854, -3.1454461890953427`}, \
{-1.0517809568570802`, -3.2908923781906854`}}], 
     PolygonBox[{{-1.02589047842854, -3.1454461890953427`}, \
{-1.02589047842854, -3.1454461890953427`}, {-1., -3.}, {-1., -3.}, \
{-1.02589047842854, -3.1454461890953427`}}], 
     PolygonBox[{{-1., -3.}, {-1., -3.}, {-0.9741095215714599, \
-2.8545538109046573`}, {-0.9741095215714599, -2.8545538109046573`}, {-1., \
-3.}}], PolygonBox[{{-0.9741095215714599, -2.8545538109046573`}, \
{-0.9741095215714599, -2.8545538109046573`}, {-0.9482190431429198, \
-2.7091076218093146`}, {-0.9482190431429199, -2.7091076218093146`}, \
{-0.9741095215714599, -2.8545538109046573`}}], 
     PolygonBox[{{-0.9482190431429199, -2.7091076218093146`}, \
{-0.9482190431429198, -2.7091076218093146`}, {-0.9223285647143799, \
-2.563661432713972}, {-0.9223285647143799, -2.563661432713972}, \
{-0.9482190431429199, -2.7091076218093146`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.0776714352856203`, -3.436338567286028}, \
{-1.0517809568570802`, -3.2908923781906854`}, {-1.02589047842854, \
-3.1454461890953427`}, {-1., -3.}, {-0.9741095215714599, \
-2.8545538109046573`}, {-0.9482190431429199, -2.7091076218093146`}, \
{-0.9223285647143799, -2.563661432713972}, {-0.9223285647143799, \
-2.563661432713972}, {-0.9482190431429198, -2.7091076218093146`}, \
{-0.9741095215714599, -2.8545538109046573`}, {-1., -3.}, {-1.02589047842854, \
-3.1454461890953427`}, {-1.0517809568570802`, -3.2908923781906854`}, \
{-1.07767143528562, -3.436338567286028}, {-1.0776714352856203`, \
-3.436338567286028}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.443166495626191, -2.922052563612084}, \
{-1.443166495626191, -2.922052563612084}, {-1.2954443304174605`, \
-2.9480350424080557`}, {-1.2954443304174608`, -2.9480350424080557`}, \
{-1.443166495626191, -2.922052563612084}}], 
       PolygonBox[{{-1.2954443304174608`, -2.9480350424080557`}, \
{-1.2954443304174605`, -2.9480350424080557`}, {-1.1477221652087304`, \
-2.974017521204028}, {-1.1477221652087304`, -2.974017521204028}, \
{-1.2954443304174608`, -2.9480350424080557`}}], 
       PolygonBox[{{-1.1477221652087304`, -2.974017521204028}, \
{-1.1477221652087304`, -2.974017521204028}, {-1., -3.}, {-1., -3.}, \
{-1.1477221652087304`, -2.974017521204028}}], 
       PolygonBox[{{-1., -3.}, {-1., -3.}, {-0.8522778347912697, \
-3.025982478795972}, {-0.8522778347912697, -3.025982478795972}, {-1., -3.}}], 
       PolygonBox[{{-0.8522778347912697, -3.025982478795972}, \
{-0.8522778347912697, -3.025982478795972}, {-0.7045556695825395, \
-3.051964957591944}, {-0.7045556695825395, -3.051964957591944}, \
{-0.8522778347912697, -3.025982478795972}}], 
       PolygonBox[{{-0.7045556695825395, -3.051964957591944}, \
{-0.7045556695825395, -3.051964957591944}, {-0.5568335043738092, \
-3.077947436387916}, {-0.5568335043738093, -3.077947436387916}, \
{-0.7045556695825395, -3.051964957591944}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.443166495626191, -2.922052563612084}, \
{-1.2954443304174608`, -2.9480350424080557`}, {-1.1477221652087304`, \
-2.974017521204028}, {-1., -3.}, {-0.8522778347912697, -3.025982478795972}, \
{-0.7045556695825395, -3.0519649575919443`}, {-0.5568335043738093, \
-3.077947436387916}, {-0.5568335043738091, -3.077947436387916}, \
{-0.7045556695825393, -3.0519649575919443`}, {-0.8522778347912696, \
-3.025982478795972}, {-1., -3.}, {-1.1477221652087302`, -2.974017521204028}, \
{-1.2954443304174605`, -2.9480350424080557`}, {-1.4431664956261907`, \
-2.922052563612084}, {-1.443166495626191, -2.922052563612084}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.520837930911811, -3.358391130898112}, \
{-1.3654950603405707`, -2.485713996326056}, {-0.4791620690881889, \
-2.641608869101888}, {-0.6345049396594293, -3.514286003673944}, \
{-1.520837930911811, -3.358391130898112}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.520837930911811, -3.358391130898112}, \
{-1.3654950603405707`, -2.485713996326056}, {-0.4791620690881889, \
-2.641608869101888}, {-0.6345049396594293, -3.514286003673944}, \
{-1.520837930911811, -3.358391130898112}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.052393314703181, -2.443748393960468}, \
{-1.052393314703181, -2.443748393960468}, {-1.0349288764687872`, \
-2.295832262640312}, {-1.0349288764687874`, -2.295832262640312}, \
{-1.052393314703181, -2.443748393960468}}], 
     PolygonBox[{{-1.0349288764687874`, -2.295832262640312}, \
{-1.0349288764687872`, -2.295832262640312}, {-1.0174644382343936`, \
-2.147916131320156}, {-1.0174644382343936`, -2.147916131320156}, \
{-1.0349288764687874`, -2.295832262640312}}], 
     PolygonBox[{{-1.0174644382343936`, -2.147916131320156}, \
{-1.0174644382343936`, -2.147916131320156}, {-1., -2.}, {-1., -2.}, \
{-1.0174644382343936`, -2.147916131320156}}], 
     PolygonBox[{{-1., -2.}, {-1., -2.}, {-0.9825355617656063, \
-1.852083868679844}, {-0.9825355617656063, -1.852083868679844}, {-1., -2.}}], 
     PolygonBox[{{-0.9825355617656063, -1.852083868679844}, \
{-0.9825355617656063, -1.852083868679844}, {-0.9650711235312126, \
-1.7041677373596882`}, {-0.9650711235312127, -1.7041677373596882`}, \
{-0.9825355617656063, -1.852083868679844}}], 
     PolygonBox[{{-0.9650711235312127, -1.7041677373596882`}, \
{-0.9650711235312126, -1.7041677373596882`}, {-0.947606685296819, \
-1.5562516060395322`}, {-0.947606685296819, -1.5562516060395322`}, \
{-0.9650711235312127, -1.7041677373596882`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.052393314703181, -2.443748393960468}, \
{-1.0349288764687874`, -2.295832262640312}, {-1.0174644382343936`, \
-2.147916131320156}, {-1., -2.}, {-0.9825355617656063, -1.852083868679844}, \
{-0.9650711235312127, -1.7041677373596882`}, {-0.947606685296819, \
-1.5562516060395322`}, {-0.947606685296819, -1.5562516060395322`}, \
{-0.9650711235312127, -1.704167737359688}, {-0.9825355617656063, \
-1.852083868679844}, {-1., -2.}, {-1.0174644382343936`, -2.147916131320156}, \
{-1.0349288764687874`, -2.295832262640312}, {-1.052393314703181, \
-2.4437483939604676`}, {-1.052393314703181, -2.443748393960468}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4468065107841634`, -1.9466867424375631`}, \
{-1.4468065107841634`, -1.946686742437563}, {-1.2978710071894421`, \
-1.9644578282917087`}, {-1.2978710071894421`, -1.9644578282917087`}, \
{-1.4468065107841634`, -1.9466867424375631`}}], 
       PolygonBox[{{-1.2978710071894421`, -1.9644578282917087`}, \
{-1.2978710071894421`, -1.9644578282917087`}, {-1.1489355035947213`, \
-1.9822289141458542`}, {-1.148935503594721, -1.9822289141458542`}, \
{-1.2978710071894421`, -1.9644578282917087`}}], 
       PolygonBox[{{-1.148935503594721, -1.9822289141458542`}, \
{-1.1489355035947213`, -1.9822289141458542`}, {-1., -2.}, {-1., -2.}, \
{-1.148935503594721, -1.9822289141458542`}}], 
       PolygonBox[{{-1., -2.}, {-1., -2.}, {-0.8510644964052789, \
-2.0177710858541458`}, {-0.8510644964052789, -2.0177710858541458`}, {-1., \
-2.}}], PolygonBox[{{-0.8510644964052789, -2.0177710858541458`}, \
{-0.8510644964052789, -2.0177710858541458`}, {-0.7021289928105579, \
-2.035542171708291}, {-0.7021289928105579, -2.035542171708291}, \
{-0.8510644964052789, -2.0177710858541458`}}], 
       PolygonBox[{{-0.7021289928105579, -2.035542171708291}, \
{-0.7021289928105579, -2.035542171708291}, {-0.5531934892158368, \
-2.053313257562437}, {-0.5531934892158368, -2.053313257562437}, \
{-0.7021289928105579, -2.035542171708291}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4468065107841634`, -1.9466867424375631`}, \
{-1.2978710071894421`, -1.9644578282917087`}, {-1.148935503594721, \
-1.9822289141458542`}, {-1., -2.}, {-0.8510644964052789, \
-2.0177710858541458`}, {-0.7021289928105579, -2.0355421717082915`}, \
{-0.5531934892158368, -2.053313257562437}, {-0.5531934892158367, \
-2.053313257562437}, {-0.7021289928105577, -2.0355421717082915`}, \
{-0.8510644964052789, -2.0177710858541458`}, {-1., -2.}, {-1.148935503594721, \
-1.9822289141458544`}, {-1.2978710071894421`, -1.9644578282917087`}, \
{-1.4468065107841632`, -1.9466867424375631`}, {-1.4468065107841634`, \
-1.9466867424375631`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.4991998254873442`, -2.3904351363980307`}, \
{-1.3944131960809822`, -1.502938348477095}, {-0.5008001745126557, \
-1.609564863601969}, {-0.6055868039190176, -2.497061651522905}, \
{-1.4991998254873442`, -2.3904351363980307`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.4991998254873442`, -2.3904351363980307`}, \
{-1.3944131960809822`, -1.502938348477095}, {-0.5008001745126557, \
-1.609564863601969}, {-0.6055868039190176, -2.497061651522905}, \
{-1.4991998254873442`, -2.3904351363980307`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.0263858473362126`, -1.4484088295723214`}, \
{-1.0263858473362126`, -1.4484088295723214`}, {-1.0175905648908083`, \
-1.2989392197148808`}, {-1.0175905648908086`, -1.298939219714881}, \
{-1.0263858473362126`, -1.4484088295723214`}}], 
     PolygonBox[{{-1.0175905648908086`, -1.298939219714881}, \
{-1.0175905648908083`, -1.2989392197148808`}, {-1.008795282445404, \
-1.1494696098574406`}, {-1.0087952824454043`, -1.1494696098574404`}, \
{-1.0175905648908086`, -1.298939219714881}}], 
     PolygonBox[{{-1.0087952824454043`, -1.1494696098574404`}, \
{-1.008795282445404, -1.1494696098574406`}, {-1., -1.0000000000000002`}, \
{-1., -1.}, {-1.0087952824454043`, -1.1494696098574404`}}], 
     PolygonBox[{{-1., -1.}, {-1., -1.}, {-0.9912047175545957, \
-0.8505303901425596}, {-0.9912047175545957, -0.8505303901425596}, {-1., \
-1.}}], PolygonBox[{{-0.9912047175545957, -0.8505303901425596}, \
{-0.9912047175545957, -0.8505303901425596}, {-0.9824094351091915, \
-0.7010607802851192}, {-0.9824094351091915, -0.7010607802851191}, \
{-0.9912047175545957, -0.8505303901425596}}], 
     PolygonBox[{{-0.9824094351091915, -0.7010607802851191}, \
{-0.9824094351091915, -0.7010607802851192}, {-0.9736141526637873, \
-0.5515911704276787}, {-0.9736141526637873, -0.5515911704276788}, \
{-0.9824094351091915, -0.7010607802851191}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.0263858473362126`, -1.4484088295723214`}, \
{-1.0175905648908086`, -1.298939219714881}, {-1.0087952824454043`, \
-1.1494696098574404`}, {-1., -1.}, {-0.9912047175545957, \
-0.8505303901425596}, {-0.9824094351091915, -0.7010607802851191}, \
{-0.9736141526637873, -0.5515911704276788}, {-0.9736141526637873, \
-0.5515911704276786}, {-0.9824094351091915, -0.701060780285119}, \
{-0.9912047175545957, -0.8505303901425595}, {-1., -1.}, \
{-1.0087952824454043`, -1.1494696098574404`}, {-1.0175905648908086`, \
-1.2989392197148808`}, {-1.0263858473362126`, -1.4484088295723212`}, \
{-1.0263858473362126`, -1.4484088295723214`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4490531449080963`, -0.9729203282528953}, \
{-1.4490531449080963`, -0.9729203282528953}, {-1.299368763272064, \
-0.9819468855019302}, {-1.299368763272064, -0.9819468855019302}, \
{-1.4490531449080963`, -0.9729203282528953}}], 
       PolygonBox[{{-1.299368763272064, -0.9819468855019302}, \
{-1.299368763272064, -0.9819468855019302}, {-1.1496843816360323`, \
-0.9909734427509651}, {-1.149684381636032, -0.9909734427509651}, \
{-1.299368763272064, -0.9819468855019302}}], 
       PolygonBox[{{-1.149684381636032, -0.9909734427509651}, \
{-1.1496843816360323`, -0.9909734427509651}, {-1., -1.}, {-1., -1.}, \
{-1.149684381636032, -0.9909734427509651}}], 
       PolygonBox[{{-1., -1.}, {-1., -1.}, {-0.850315618363968, \
-1.009026557249035}, {-0.850315618363968, -1.009026557249035}, {-1., -1.}}], 
       PolygonBox[{{-0.850315618363968, -1.009026557249035}, \
{-0.850315618363968, -1.009026557249035}, {-0.7006312367279359, \
-1.0180531144980698`}, {-0.7006312367279359, -1.0180531144980698`}, \
{-0.850315618363968, -1.009026557249035}}], 
       PolygonBox[{{-0.7006312367279359, -1.0180531144980698`}, \
{-0.7006312367279359, -1.0180531144980698`}, {-0.5509468550919039, \
-1.0270796717471047`}, {-0.5509468550919039, -1.0270796717471047`}, \
{-0.7006312367279359, -1.0180531144980698`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4490531449080963`, -0.9729203282528953}, \
{-1.299368763272064, -0.9819468855019302}, {-1.149684381636032, \
-0.9909734427509651}, {-1., -1.}, {-0.850315618363968, -1.009026557249035}, \
{-0.7006312367279359, -1.0180531144980698`}, {-0.5509468550919039, \
-1.0270796717471047`}, {-0.5509468550919038, -1.0270796717471047`}, \
{-0.7006312367279358, -1.0180531144980698`}, {-0.850315618363968, \
-1.009026557249035}, {-1., -1.}, {-1.149684381636032, -0.9909734427509651}, \
{-1.299368763272064, -0.9819468855019302}, {-1.4490531449080961`, \
-0.9729203282528953}, {-1.4490531449080963`, -0.9729203282528953}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.475438992244309, -1.4213291578252167`}, \
{-1.4226672975718835`, -0.524511498680574}, {-0.524561007755691, \
-0.5786708421747833}, {-0.5773327024281165, -1.4754885013194259`}, \
{-1.475438992244309, -1.4213291578252167`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.475438992244309, -1.4213291578252167`}, \
{-1.4226672975718835`, -0.524511498680574}, {-0.524561007755691, \
-0.5786708421747833}, {-0.5773327024281165, -1.4754885013194259`}, \
{-1.475438992244309, -1.4213291578252167`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1., -0.45}, {-0.9999999999999999, -0.45}, \
{-0.9999999999999999, -0.3}, {-1., -0.30000000000000004`}, {-1., -0.45}}], 
     PolygonBox[{{-1., -0.30000000000000004`}, {-0.9999999999999999, -0.3}, \
{-0.9999999999999999, -0.15000000000000008`}, {-1., -0.15000000000000002`}, \
{-1., -0.30000000000000004`}}], 
     PolygonBox[{{-1., -0.15000000000000002`}, {-0.9999999999999999, \
-0.15000000000000008`}, {-1., -1.1102230246251565`*^-16}, {-1., 
      0.}, {-1., -0.15000000000000002`}}], 
     PolygonBox[{{-1., 0.}, {-1., 0.}, {-1., 0.14999999999999997`}, {-1., 
      0.14999999999999997`}, {-1., 0.}}], 
     PolygonBox[{{-1., 0.14999999999999997`}, {-1., 
      0.14999999999999997`}, {-1., 0.29999999999999993`}, {-1., 0.3}, {-1., 
      0.14999999999999997`}}], 
     PolygonBox[{{-1., 0.3}, {-1., 0.29999999999999993`}, {-1., 
      0.44999999999999996`}, {-1., 0.4499999999999999}, {-1., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1., -0.45}, {-1., -0.30000000000000004`}, {-1., \
-0.15000000000000002`}, {-1., -5.551115123125783*^-17}, {-1., 
       0.14999999999999997`}, {-1., 0.3}, {-1., 0.4499999999999999}, {-1., 
       0.45}, {-1., 0.30000000000000004`}, {-1., 0.15000000000000002`}, {-1., 
       5.551115123125783*^-17}, {-1., -0.14999999999999997`}, {-1., -0.3}, \
{-1., -0.4499999999999999}, {-1., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4498128457508597`, 0.}, {-1.4498128457508597`, 
        5.5109105961630896`*^-17}, {-1.2998752305005732`, 
        4.592425496802574*^-17}, {-1.2998752305005732`, 
        9.184850993605149*^-18}, {-1.4498128457508597`, 0.}}], 
       PolygonBox[{{-1.2998752305005732`, 
        9.184850993605149*^-18}, {-1.2998752305005732`, 
        4.592425496802574*^-17}, {-1.1499376152502867`, 
        3.67394039744206*^-17}, {-1.1499376152502867`, 
        1.8369701987210297`*^-17}, {-1.2998752305005732`, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{-1.1499376152502867`, 
        1.8369701987210297`*^-17}, {-1.1499376152502867`, 
        3.67394039744206*^-17}, {-1., 2.7554552980815454`*^-17}, {-1., 
        2.7554552980815448`*^-17}, {-1.1499376152502867`, 
        1.8369701987210297`*^-17}}], 
       PolygonBox[{{-1., 2.7554552980815448`*^-17}, {-1., 
        2.7554552980815448`*^-17}, {-0.8500623847497135, 
        1.83697019872103*^-17}, {-0.8500623847497135, 
        3.6739403974420595`*^-17}, {-1., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{-0.8500623847497135, 
        3.6739403974420595`*^-17}, {-0.8500623847497135, 
        1.83697019872103*^-17}, {-0.7001247694994269, 
        9.184850993605152*^-18}, {-0.7001247694994268, 
        4.592425496802574*^-17}, {-0.8500623847497135, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{-0.7001247694994268, 
        4.592425496802574*^-17}, {-0.7001247694994269, 
        9.184850993605153*^-18}, {-0.5501871542491403, 
        4.5887548728832574`*^-33}, {-0.5501871542491403, 
        5.510910596163089*^-17}, {-0.7001247694994268, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4498128457508597`, 0.}, {-1.2998752305005732`, 
         0.}, {-1.1499376152502867`, 0.}, {-1., 0.}, {-0.8500623847497135, 
         0.}, {-0.7001247694994268, 0.}, {-0.5501871542491403, 
         0.}, {-0.5501871542491403, 0.}, {-0.7001247694994268, 
         0.}, {-0.8500623847497134, 0.}, {-1., 0.}, {-1.1499376152502865`, 
         0.}, {-1.2998752305005732`, 0.}, {-1.4498128457508597`, 
         0.}, {-1.4498128457508597`, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.4498128457508597`, -0.45}, {-1.4498128457508597`, 
      0.45}, {-0.5501871542491403, 
      0.45}, {-0.5501871542491403, -0.45}, {-1.4498128457508597`, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.4498128457508597`, -0.45}, {-1.4498128457508597`, 
       0.45}, {-0.5501871542491403, 
       0.45}, {-0.5501871542491403, -0.45}, {-1.4498128457508597`, \
-0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.9736141526637873, 
      0.5515911704276786}, {-0.9736141526637871, 
      0.5515911704276786}, {-0.9824094351091914, 
      0.7010607802851191}, {-0.9824094351091915, 
      0.701060780285119}, {-0.9736141526637873, 0.5515911704276786}}], 
     PolygonBox[{{-0.9824094351091915, 
      0.701060780285119}, {-0.9824094351091914, 
      0.7010607802851191}, {-0.9912047175545957, 
      0.8505303901425595}, {-0.9912047175545957, 
      0.8505303901425595}, {-0.9824094351091915, 0.701060780285119}}], 
     PolygonBox[{{-0.9912047175545957, 
      0.8505303901425595}, {-0.9912047175545957, 
      0.8505303901425595}, {-0.9999999999999999, 0.9999999999999999}, {-1., 
      1.}, {-0.9912047175545957, 0.8505303901425595}}], 
     PolygonBox[{{-1., 1.}, {-1., 1.}, {-1.0087952824454043`, 
      1.1494696098574404`}, {-1.0087952824454043`, 1.1494696098574404`}, {-1.,
       1.}}], PolygonBox[{{-1.0087952824454043`, 
      1.1494696098574404`}, {-1.0087952824454043`, 
      1.1494696098574404`}, {-1.0175905648908083`, 
      1.2989392197148808`}, {-1.0175905648908086`, 
      1.2989392197148808`}, {-1.0087952824454043`, 1.1494696098574404`}}], 
     PolygonBox[{{-1.0175905648908086`, 
      1.2989392197148808`}, {-1.0175905648908083`, 
      1.2989392197148808`}, {-1.0263858473362126`, 
      1.4484088295723212`}, {-1.0263858473362126`, 
      1.4484088295723212`}, {-1.0175905648908086`, 1.2989392197148808`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.9736141526637873, 
       0.5515911704276786}, {-0.9824094351091915, 
       0.701060780285119}, {-0.9912047175545957, 0.8505303901425595}, {-1., 
       1.}, {-1.0087952824454043`, 
       1.1494696098574404`}, {-1.0175905648908086`, 
       1.2989392197148808`}, {-1.0263858473362126`, 
       1.4484088295723212`}, {-1.0263858473362126`, 
       1.4484088295723214`}, {-1.0175905648908086`, 
       1.298939219714881}, {-1.0087952824454043`, 1.1494696098574404`}, {-1., 
       1.}, {-0.9912047175545957, 0.8505303901425596}, {-0.9824094351091915, 
       0.7010607802851191}, {-0.9736141526637873, 
       0.5515911704276788}, {-0.9736141526637873, 0.5515911704276786}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4490531449080963`, 
        0.9729203282528953}, {-1.4490531449080963`, 
        0.9729203282528954}, {-1.299368763272064, 
        0.9819468855019303}, {-1.299368763272064, 
        0.9819468855019302}, {-1.4490531449080963`, 0.9729203282528953}}], 
       PolygonBox[{{-1.299368763272064, 
        0.9819468855019302}, {-1.299368763272064, 
        0.9819468855019303}, {-1.1496843816360323`, 
        0.9909734427509651}, {-1.149684381636032, 
        0.9909734427509651}, {-1.299368763272064, 0.9819468855019302}}], 
       PolygonBox[{{-1.149684381636032, 
        0.9909734427509651}, {-1.1496843816360323`, 
        0.9909734427509651}, {-1.0000000000000002`, 1.}, {-1., 
        1.}, {-1.149684381636032, 0.9909734427509651}}], 
       PolygonBox[{{-1., 1.}, {-1., 1.}, {-0.850315618363968, 
        1.009026557249035}, {-0.850315618363968, 1.009026557249035}, {-1., 
        1.}}], PolygonBox[{{-0.850315618363968, 
        1.009026557249035}, {-0.850315618363968, 
        1.009026557249035}, {-0.7006312367279359, 
        1.0180531144980698`}, {-0.7006312367279359, 
        1.0180531144980698`}, {-0.850315618363968, 1.009026557249035}}], 
       PolygonBox[{{-0.7006312367279359, 
        1.0180531144980698`}, {-0.7006312367279359, 
        1.0180531144980698`}, {-0.5509468550919039, 
        1.0270796717471047`}, {-0.5509468550919039, 
        1.0270796717471047`}, {-0.7006312367279359, 1.0180531144980698`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4490531449080963`, 
         0.9729203282528953}, {-1.299368763272064, 
         0.9819468855019302}, {-1.149684381636032, 0.9909734427509651}, {-1., 
         1.}, {-0.850315618363968, 1.009026557249035}, {-0.7006312367279359, 
         1.0180531144980698`}, {-0.5509468550919039, 
         1.0270796717471047`}, {-0.5509468550919038, 
         1.0270796717471047`}, {-0.7006312367279358, 
         1.0180531144980698`}, {-0.850315618363968, 1.009026557249035}, {-1., 
         1.}, {-1.149684381636032, 0.9909734427509651}, {-1.299368763272064, 
         0.9819468855019302}, {-1.4490531449080961`, 
         0.9729203282528953}, {-1.4490531449080963`, 
         0.9729203282528953}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.4226672975718835`, 
      0.524511498680574}, {-1.475438992244309, 
      1.4213291578252167`}, {-0.5773327024281165, 
      1.4754885013194259`}, {-0.524561007755691, 
      0.5786708421747833}, {-1.4226672975718835`, 0.524511498680574}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.4226672975718835`, 0.524511498680574}, {-1.475438992244309,
        1.4213291578252167`}, {-0.5773327024281165, 
       1.4754885013194259`}, {-0.524561007755691, 
       0.5786708421747833}, {-1.4226672975718835`, 0.524511498680574}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.947606685296819, 
      1.5562516060395322`}, {-0.9476066852968189, 
      1.5562516060395322`}, {-0.9650711235312126, 
      1.7041677373596882`}, {-0.9650711235312127, 
      1.704167737359688}, {-0.947606685296819, 1.5562516060395322`}}], 
     PolygonBox[{{-0.9650711235312127, 
      1.704167737359688}, {-0.9650711235312126, 
      1.7041677373596882`}, {-0.9825355617656063, 
      1.852083868679844}, {-0.9825355617656063, 
      1.852083868679844}, {-0.9650711235312127, 1.704167737359688}}], 
     PolygonBox[{{-0.9825355617656063, 
      1.852083868679844}, {-0.9825355617656063, 
      1.852083868679844}, {-0.9999999999999999, 2.}, {-1., 
      2.}, {-0.9825355617656063, 1.852083868679844}}], 
     PolygonBox[{{-1., 2.}, {-1., 2.}, {-1.0174644382343936`, 
      2.147916131320156}, {-1.0174644382343936`, 2.147916131320156}, {-1., 
      2.}}], PolygonBox[{{-1.0174644382343936`, 
      2.147916131320156}, {-1.0174644382343936`, 
      2.147916131320156}, {-1.0349288764687874`, 
      2.295832262640312}, {-1.0349288764687874`, 
      2.295832262640312}, {-1.0174644382343936`, 2.147916131320156}}], 
     PolygonBox[{{-1.0349288764687874`, 
      2.295832262640312}, {-1.0349288764687874`, 
      2.295832262640312}, {-1.052393314703181, 
      2.443748393960468}, {-1.052393314703181, 
      2.4437483939604676`}, {-1.0349288764687874`, 2.295832262640312}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.947606685296819, 
       1.5562516060395322`}, {-0.9650711235312127, 
       1.704167737359688}, {-0.9825355617656063, 1.852083868679844}, {-1., 
       2.}, {-1.0174644382343936`, 2.147916131320156}, {-1.0349288764687874`, 
       2.295832262640312}, {-1.052393314703181, 
       2.4437483939604676`}, {-1.052393314703181, 
       2.443748393960468}, {-1.0349288764687874`, 
       2.295832262640312}, {-1.0174644382343936`, 2.147916131320156}, {-1., 
       2.}, {-0.9825355617656063, 1.852083868679844}, {-0.9650711235312127, 
       1.7041677373596882`}, {-0.947606685296819, 
       1.5562516060395322`}, {-0.947606685296819, 1.5562516060395322`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4468065107841634`, 
        1.9466867424375631`}, {-1.4468065107841634`, 
        1.9466867424375631`}, {-1.2978710071894421`, 
        1.9644578282917087`}, {-1.2978710071894421`, 
        1.9644578282917087`}, {-1.4468065107841634`, 1.9466867424375631`}}], 
       PolygonBox[{{-1.2978710071894421`, 
        1.9644578282917087`}, {-1.2978710071894421`, 
        1.9644578282917087`}, {-1.1489355035947213`, 
        1.9822289141458544`}, {-1.148935503594721, 
        1.9822289141458544`}, {-1.2978710071894421`, 1.9644578282917087`}}], 
       PolygonBox[{{-1.148935503594721, 
        1.9822289141458544`}, {-1.1489355035947213`, 
        1.9822289141458544`}, {-1.0000000000000002`, 2.}, {-1., 
        2.}, {-1.148935503594721, 1.9822289141458544`}}], 
       PolygonBox[{{-1., 2.}, {-1., 2.}, {-0.8510644964052789, 
        2.0177710858541458`}, {-0.8510644964052789, 
        2.0177710858541458`}, {-1., 2.}}], 
       PolygonBox[{{-0.8510644964052789, 
        2.0177710858541458`}, {-0.8510644964052789, 
        2.0177710858541458`}, {-0.7021289928105579, 
        2.0355421717082915`}, {-0.7021289928105579, 
        2.0355421717082915`}, {-0.8510644964052789, 2.0177710858541458`}}], 
       PolygonBox[{{-0.7021289928105579, 
        2.0355421717082915`}, {-0.7021289928105579, 
        2.0355421717082915`}, {-0.5531934892158368, 
        2.053313257562437}, {-0.5531934892158368, 
        2.053313257562437}, {-0.7021289928105579, 2.0355421717082915`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4468065107841634`, 
         1.9466867424375631`}, {-1.2978710071894421`, 
         1.9644578282917087`}, {-1.148935503594721, 
         1.9822289141458542`}, {-1., 2.}, {-0.8510644964052789, 
         2.0177710858541458`}, {-0.7021289928105579, 
         2.0355421717082915`}, {-0.5531934892158368, 
         2.053313257562437}, {-0.5531934892158367, 
         2.053313257562437}, {-0.7021289928105577, 
         2.0355421717082915`}, {-0.8510644964052789, 
         2.0177710858541458`}, {-1., 2.}, {-1.148935503594721, 
         1.9822289141458544`}, {-1.2978710071894421`, 
         1.9644578282917087`}, {-1.4468065107841632`, 
         1.9466867424375631`}, {-1.4468065107841634`, 
         1.9466867424375631`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.3944131960809822`, 
      1.502938348477095}, {-1.4991998254873442`, 
      2.3904351363980307`}, {-0.6055868039190176, 
      2.497061651522905}, {-0.5008001745126557, 
      1.609564863601969}, {-1.3944131960809822`, 1.502938348477095}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.3944131960809822`, 
       1.502938348477095}, {-1.4991998254873442`, 
       2.3904351363980307`}, {-0.6055868039190176, 
       2.497061651522905}, {-0.5008001745126557, 
       1.609564863601969}, {-1.3944131960809822`, 1.502938348477095}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.9223285647143799, 
      2.563661432713972}, {-0.9223285647143797, 
      2.563661432713972}, {-0.9482190431429198, 
      2.7091076218093146`}, {-0.9482190431429198, 
      2.7091076218093146`}, {-0.9223285647143799, 2.563661432713972}}], 
     PolygonBox[{{-0.9482190431429198, 
      2.7091076218093146`}, {-0.9482190431429198, 
      2.7091076218093146`}, {-0.9741095215714599, 
      2.8545538109046573`}, {-0.9741095215714599, 
      2.8545538109046573`}, {-0.9482190431429198, 2.7091076218093146`}}], 
     PolygonBox[{{-0.9741095215714599, 
      2.8545538109046573`}, {-0.9741095215714599, 
      2.8545538109046573`}, {-0.9999999999999999, 3.}, {-1., 
      3.}, {-0.9741095215714599, 2.8545538109046573`}}], 
     PolygonBox[{{-1., 3.}, {-1., 3.}, {-1.02589047842854, 
      3.1454461890953427`}, {-1.02589047842854, 3.1454461890953427`}, {-1., 
      3.}}], PolygonBox[{{-1.02589047842854, 
      3.1454461890953427`}, {-1.02589047842854, 
      3.1454461890953427`}, {-1.0517809568570802`, 
      3.2908923781906854`}, {-1.0517809568570802`, 
      3.2908923781906854`}, {-1.02589047842854, 3.1454461890953427`}}], 
     PolygonBox[{{-1.0517809568570802`, 
      3.2908923781906854`}, {-1.0517809568570802`, 
      3.2908923781906854`}, {-1.0776714352856203`, 
      3.436338567286028}, {-1.07767143528562, 
      3.436338567286028}, {-1.0517809568570802`, 3.2908923781906854`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.9223285647143799, 2.563661432713972}, {-0.9482190431429198,
        2.7091076218093146`}, {-0.9741095215714599, 
       2.8545538109046573`}, {-1., 3.}, {-1.02589047842854, 
       3.1454461890953427`}, {-1.0517809568570802`, 
       3.2908923781906854`}, {-1.07767143528562, 
       3.436338567286028}, {-1.0776714352856203`, 
       3.436338567286028}, {-1.0517809568570802`, 
       3.2908923781906854`}, {-1.02589047842854, 3.1454461890953427`}, {-1., 
       3.}, {-0.9741095215714599, 2.8545538109046573`}, {-0.9482190431429199, 
       2.7091076218093146`}, {-0.9223285647143799, 
       2.563661432713972}, {-0.9223285647143799, 2.563661432713972}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.443166495626191, 
        2.922052563612084}, {-1.443166495626191, 
        2.922052563612084}, {-1.2954443304174605`, 
        2.948035042408056}, {-1.2954443304174608`, 
        2.9480350424080557`}, {-1.443166495626191, 2.922052563612084}}], 
       PolygonBox[{{-1.2954443304174608`, 
        2.9480350424080557`}, {-1.2954443304174605`, 
        2.948035042408056}, {-1.1477221652087304`, 
        2.974017521204028}, {-1.1477221652087304`, 
        2.974017521204028}, {-1.2954443304174608`, 2.9480350424080557`}}], 
       PolygonBox[{{-1.1477221652087304`, 
        2.974017521204028}, {-1.1477221652087304`, 
        2.974017521204028}, {-1.0000000000000002`, 3.}, {-1., 
        3.}, {-1.1477221652087304`, 2.974017521204028}}], 
       PolygonBox[{{-1., 3.}, {-1., 3.}, {-0.8522778347912697, 
        3.025982478795972}, {-0.8522778347912697, 3.025982478795972}, {-1., 
        3.}}], PolygonBox[{{-0.8522778347912697, 
        3.025982478795972}, {-0.8522778347912697, 
        3.025982478795972}, {-0.7045556695825395, 
        3.0519649575919443`}, {-0.7045556695825395, 
        3.0519649575919443`}, {-0.8522778347912697, 3.025982478795972}}], 
       PolygonBox[{{-0.7045556695825395, 
        3.0519649575919443`}, {-0.7045556695825395, 
        3.0519649575919443`}, {-0.5568335043738092, 
        3.077947436387916}, {-0.5568335043738093, 
        3.077947436387916}, {-0.7045556695825395, 3.0519649575919443`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.443166495626191, 
         2.922052563612084}, {-1.2954443304174608`, 
         2.9480350424080557`}, {-1.1477221652087304`, 
         2.974017521204028}, {-1., 3.}, {-0.8522778347912697, 
         3.025982478795972}, {-0.7045556695825395, 
         3.0519649575919443`}, {-0.5568335043738093, 
         3.077947436387916}, {-0.5568335043738091, 
         3.077947436387916}, {-0.7045556695825393, 
         3.0519649575919443`}, {-0.8522778347912696, 3.025982478795972}, {-1.,
          3.}, {-1.1477221652087302`, 
         2.974017521204028}, {-1.2954443304174605`, 
         2.9480350424080557`}, {-1.4431664956261907`, 
         2.922052563612084}, {-1.443166495626191, 2.922052563612084}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.3654950603405707`, 
      2.485713996326056}, {-1.520837930911811, 
      3.358391130898112}, {-0.6345049396594293, 
      3.514286003673944}, {-0.4791620690881889, 
      2.641608869101888}, {-1.3654950603405707`, 2.485713996326056}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.3654950603405707`, 2.485713996326056}, {-1.520837930911811,
        3.358391130898112}, {-0.6345049396594293, 
       3.514286003673944}, {-0.4791620690881889, 
       2.641608869101888}, {-1.3654950603405707`, 2.485713996326056}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.8980803760926472, 
      3.57334619547276}, {-0.8980803760926471, 
      3.57334619547276}, {-0.9320535840617648, 
      3.7155641303151734`}, {-0.9320535840617648, 
      3.7155641303151734`}, {-0.8980803760926472, 3.57334619547276}}], 
     PolygonBox[{{-0.9320535840617648, 
      3.7155641303151734`}, {-0.9320535840617648, 
      3.7155641303151734`}, {-0.9660267920308823, 
      3.8577820651575867`}, {-0.9660267920308824, 
      3.8577820651575867`}, {-0.9320535840617648, 3.7155641303151734`}}], 
     PolygonBox[{{-0.9660267920308824, 
      3.8577820651575867`}, {-0.9660267920308823, 
      3.8577820651575867`}, {-0.9999999999999999, 4.}, {-1., 
      4.}, {-0.9660267920308824, 3.8577820651575867`}}], 
     PolygonBox[{{-1., 4.}, {-1., 4.}, {-1.0339732079691175`, 
      4.142217934842413}, {-1.0339732079691175`, 4.142217934842413}, {-1., 
      4.}}], PolygonBox[{{-1.0339732079691175`, 
      4.142217934842413}, {-1.0339732079691175`, 
      4.142217934842413}, {-1.0679464159382352`, 
      4.284435869684827}, {-1.0679464159382352`, 
      4.284435869684827}, {-1.0339732079691175`, 4.142217934842413}}], 
     PolygonBox[{{-1.0679464159382352`, 
      4.284435869684827}, {-1.0679464159382352`, 
      4.284435869684827}, {-1.1019196239073528`, 
      4.4266538045272394`}, {-1.1019196239073528`, 
      4.4266538045272394`}, {-1.0679464159382352`, 4.284435869684827}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.8980803760926472, 3.57334619547276}, {-0.9320535840617648, 
       3.7155641303151734`}, {-0.9660267920308824, 3.8577820651575867`}, {-1.,
        4.}, {-1.0339732079691175`, 4.142217934842413}, {-1.0679464159382352`,
        4.284435869684827}, {-1.1019196239073528`, 
       4.4266538045272394`}, {-1.1019196239073528`, 
       4.4266538045272394`}, {-1.0679464159382352`, 
       4.284435869684827}, {-1.0339732079691175`, 4.142217934842413}, {-1., 
       4.}, {-0.9660267920308824, 3.8577820651575867`}, {-0.9320535840617649, 
       3.7155641303151734`}, {-0.8980803760926472, 
       3.5733461954727606`}, {-0.8980803760926472, 3.57334619547276}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4382770431043812`, 
        3.8996061687900316`}, {-1.4382770431043812`, 
        3.8996061687900316`}, {-1.2921846954029208`, 
        3.9330707791933546`}, {-1.2921846954029208`, 
        3.9330707791933546`}, {-1.4382770431043812`, 3.8996061687900316`}}], 
       PolygonBox[{{-1.2921846954029208`, 
        3.9330707791933546`}, {-1.2921846954029208`, 
        3.9330707791933546`}, {-1.1460923477014604`, 
        3.966535389596677}, {-1.1460923477014604`, 
        3.966535389596677}, {-1.2921846954029208`, 3.9330707791933546`}}], 
       PolygonBox[{{-1.1460923477014604`, 
        3.966535389596677}, {-1.1460923477014604`, 
        3.966535389596677}, {-1.0000000000000002`, 4.}, {-1., 
        4.}, {-1.1460923477014604`, 3.966535389596677}}], 
       PolygonBox[{{-1., 4.}, {-1., 4.}, {-0.8539076522985396, 
        4.033464610403323}, {-0.8539076522985396, 4.033464610403323}, {-1., 
        4.}}], PolygonBox[{{-0.8539076522985396, 
        4.033464610403323}, {-0.8539076522985396, 
        4.033464610403323}, {-0.7078153045970793, 
        4.066929220806646}, {-0.7078153045970792, 
        4.066929220806646}, {-0.8539076522985396, 4.033464610403323}}], 
       PolygonBox[{{-0.7078153045970792, 
        4.066929220806646}, {-0.7078153045970793, 
        4.066929220806646}, {-0.561722956895619, 
        4.100393831209968}, {-0.561722956895619, 
        4.100393831209969}, {-0.7078153045970792, 4.066929220806646}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4382770431043812`, 
         3.8996061687900316`}, {-1.2921846954029208`, 
         3.9330707791933546`}, {-1.1460923477014604`, 
         3.966535389596677}, {-1., 4.}, {-0.8539076522985396, 
         4.033464610403323}, {-0.7078153045970792, 
         4.066929220806646}, {-0.561722956895619, 
         4.100393831209968}, {-0.5617229568956189, 
         4.100393831209968}, {-0.7078153045970792, 
         4.066929220806646}, {-0.8539076522985396, 4.033464610403323}, {-1., 
         4.}, {-1.1460923477014604`, 
         3.966535389596677}, {-1.2921846954029208`, 
         3.9330707791933546`}, {-1.438277043104381, 
         3.8996061687900316`}, {-1.4382770431043812`, 
         3.8996061687900316`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.3363574191970282`, 
      3.4729523642627917`}, {-1.5401966670117337`, 
      4.3262599733172715`}, {-0.6636425808029717, 
      4.527047635737208}, {-0.45980333298826614`, 
      3.6737400266827285`}, {-1.3363574191970282`, 3.4729523642627917`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.3363574191970282`, 
       3.4729523642627917`}, {-1.5401966670117337`, 
       4.3262599733172715`}, {-0.6636425808029717, 
       4.527047635737208}, {-0.45980333298826614`, 
       3.6737400266827285`}, {-1.3363574191970282`, 3.4729523642627917`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.8750970053838931, 
      4.584747088259353}, {-0.875097005383893, 
      4.584747088259353}, {-0.9167313369225953, 
      4.723164725506235}, {-0.9167313369225955, 
      4.723164725506235}, {-0.8750970053838931, 4.584747088259353}}], 
     PolygonBox[{{-0.9167313369225955, 
      4.723164725506235}, {-0.9167313369225953, 
      4.723164725506235}, {-0.9583656684612977, 
      4.861582362753118}, {-0.9583656684612977, 
      4.861582362753118}, {-0.9167313369225955, 4.723164725506235}}], 
     PolygonBox[{{-0.9583656684612977, 
      4.861582362753118}, {-0.9583656684612977, 
      4.861582362753118}, {-0.9999999999999999, 5.}, {-1., 
      5.}, {-0.9583656684612977, 4.861582362753118}}], 
     PolygonBox[{{-1., 5.}, {-1., 5.}, {-1.0416343315387022`, 
      5.138417637246882}, {-1.0416343315387022`, 5.138417637246882}, {-1., 
      5.}}], PolygonBox[{{-1.0416343315387022`, 
      5.138417637246882}, {-1.0416343315387022`, 
      5.138417637246882}, {-1.0832686630774044`, 
      5.276835274493765}, {-1.0832686630774047`, 
      5.276835274493765}, {-1.0416343315387022`, 5.138417637246882}}], 
     PolygonBox[{{-1.0832686630774047`, 
      5.276835274493765}, {-1.0832686630774044`, 
      5.276835274493765}, {-1.1249029946161069`, 
      5.415252911740647}, {-1.1249029946161069`, 
      5.415252911740647}, {-1.0832686630774047`, 5.276835274493765}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.8750970053838931, 4.584747088259353}, {-0.9167313369225955,
        4.723164725506235}, {-0.9583656684612977, 4.861582362753118}, {-1., 
       5.}, {-1.0416343315387022`, 5.138417637246882}, {-1.0832686630774047`, 
       5.276835274493765}, {-1.1249029946161069`, 
       5.415252911740647}, {-1.1249029946161069`, 
       5.415252911740647}, {-1.0832686630774047`, 
       5.276835274493765}, {-1.0416343315387022`, 5.138417637246882}, {-1., 
       5.}, {-0.9583656684612977, 4.861582362753118}, {-0.9167313369225955, 
       4.723164725506235}, {-0.8750970053838931, 
       4.584747088259353}, {-0.8750970053838931, 4.584747088259353}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-1.4323172471057517`, 
        4.879732542943477}, {-1.4323172471057517`, 
        4.879732542943477}, {-1.288211498070501, 
        4.919821695295651}, {-1.288211498070501, 
        4.919821695295651}, {-1.4323172471057517`, 4.879732542943477}}], 
       PolygonBox[{{-1.288211498070501, 
        4.919821695295651}, {-1.288211498070501, 
        4.919821695295651}, {-1.1441057490352506`, 
        4.9599108476478255`}, {-1.1441057490352506`, 
        4.9599108476478255`}, {-1.288211498070501, 4.919821695295651}}], 
       PolygonBox[{{-1.1441057490352506`, 
        4.9599108476478255`}, {-1.1441057490352506`, 
        4.9599108476478255`}, {-1.0000000000000002`, 5.}, {-1., 
        5.}, {-1.1441057490352506`, 4.9599108476478255`}}], 
       PolygonBox[{{-1., 5.}, {-1., 5.}, {-0.8558942509647495, 
        5.0400891523521745`}, {-0.8558942509647495, 
        5.0400891523521745`}, {-1., 5.}}], 
       PolygonBox[{{-0.8558942509647495, 
        5.0400891523521745`}, {-0.8558942509647495, 
        5.0400891523521745`}, {-0.7117885019294989, 
        5.080178304704349}, {-0.7117885019294989, 
        5.080178304704349}, {-0.8558942509647495, 5.0400891523521745`}}], 
       PolygonBox[{{-0.7117885019294989, 
        5.080178304704349}, {-0.7117885019294989, 
        5.080178304704349}, {-0.5676827528942485, 
        5.120267457056523}, {-0.5676827528942485, 
        5.120267457056523}, {-0.7117885019294989, 5.080178304704349}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-1.4323172471057517`, 
         4.879732542943477}, {-1.288211498070501, 
         4.919821695295651}, {-1.1441057490352506`, 
         4.9599108476478255`}, {-1., 5.}, {-0.8558942509647495, 
         5.0400891523521745`}, {-0.7117885019294989, 
         5.080178304704349}, {-0.5676827528942485, 
         5.120267457056523}, {-0.5676827528942484, 
         5.120267457056523}, {-0.7117885019294989, 
         5.080178304704349}, {-0.8558942509647495, 5.0400891523521745`}, {-1.,
          5.}, {-1.1441057490352504`, 
         4.9599108476478255`}, {-1.288211498070501, 
         4.919821695295651}, {-1.4323172471057515`, 
         4.879732542943477}, {-1.4323172471057517`, 
         4.879732542943477}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-1.3074142524896448`, 
      4.464479631202829}, {-1.5572202417218586`, 
      5.294985454684124}, {-0.6925857475103553, 
      5.535520368797171}, {-0.44277975827814153`, 
      4.705014545315876}, {-1.3074142524896448`, 4.464479631202829}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-1.3074142524896448`, 
       4.464479631202829}, {-1.5572202417218586`, 
       5.294985454684124}, {-0.6925857475103553, 
       5.535520368797171}, {-0.44277975827814153`, 
       4.705014545315876}, {-1.3074142524896448`, 4.464479631202829}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.12702537303504904`, -5.415087291346398}, \
{-0.12702537303504893`, -5.415087291346399}, {-0.08468358202336594, \
-5.276724860897599}, {-0.08468358202336604, -5.276724860897599}, \
{-0.12702537303504904`, -5.415087291346398}}], 
     PolygonBox[{{-0.08468358202336604, -5.276724860897599}, \
{-0.08468358202336594, -5.276724860897599}, {-0.042341791011682964`, \
-5.1383624304488}, {-0.04234179101168302, -5.138362430448799}, \
{-0.08468358202336604, -5.276724860897599}}], 
     PolygonBox[{{-0.04234179101168302, -5.138362430448799}, \
{-0.042341791011682964`, -5.1383624304488}, {2.150773786538172*^-17, -5.}, {
      0., -5.}, {-0.04234179101168302, -5.138362430448799}}], 
     PolygonBox[{{0., -5.}, {5.284695872207303*^-17, -5.}, {
      0.04234179101168303, -4.861637569551201}, {
      0.042341791011683, -4.861637569551201}, {0., -5.}}], 
     PolygonBox[{{0.042341791011683, -4.861637569551201}, {
      0.04234179101168303, -4.861637569551201}, {
      0.08468358202336601, -4.723275139102401}, {
      0.08468358202336602, -4.723275139102401}, {
      0.042341791011683, -4.861637569551201}}], 
     PolygonBox[{{0.08468358202336602, -4.723275139102401}, {
      0.08468358202336601, -4.723275139102401}, {
      0.12702537303504902`, -4.584912708653602}, {
      0.12702537303504902`, -4.584912708653602}, {
      0.08468358202336602, -4.723275139102401}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.12702537303504904`, -5.415087291346398}, \
{-0.08468358202336604, -5.276724860897599}, {-0.04234179101168302, \
-5.138362430448799}, {-1.566961042834566*^-17, -5.}, {
       0.042341791011683, -4.861637569551201}, {
       0.08468358202336602, -4.723275139102401}, {
       0.12702537303504902`, -4.584912708653602}, {
       0.12702537303504904`, -4.584912708653602}, {
       0.08468358202336604, -4.723275139102401}, {
       0.04234179101168302, -4.861637569551201}, {
       1.566961042834566*^-17, -5.}, {-0.042341791011683, \
-5.138362430448799}, {-0.08468358202336602, -5.276724860897599}, \
{-0.12702537303504902`, -5.415087291346398}, {-0.12702537303504904`, \
-5.415087291346398}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.43152816598930516`, -4.881395214396651}, \
{-0.43152816598930516`, -4.881395214396651}, {-0.2876854439928701, \
-4.9209301429311}, {-0.28768544399287016`, -4.9209301429311}, \
{-0.43152816598930516`, -4.881395214396651}}], 
       PolygonBox[{{-0.28768544399287016`, -4.9209301429311}, \
{-0.2876854439928701, -4.9209301429311}, {-0.1438427219964351, \
-4.96046507146555}, {-0.14384272199643508`, -4.96046507146555}, \
{-0.28768544399287016`, -4.9209301429311}}], 
       PolygonBox[{{-0.14384272199643508`, -4.96046507146555}, \
{-0.1438427219964351, -4.96046507146555}, {-9.868694043190486*^-17, -5.}, {
        7.778060824893566*^-18, -5.}, {-0.14384272199643508`, \
-4.96046507146555}}], 
       PolygonBox[{{7.778060824893566*^-18, -5.}, {
        7.778060824893566*^-18, -5.}, {
        0.14384272199643502`, -5.03953492853445}, {
        0.14384272199643502`, -5.03953492853445}, {
        7.778060824893566*^-18, -5.}}], 
       PolygonBox[{{0.14384272199643502`, -5.03953492853445}, {
        0.14384272199643502`, -5.03953492853445}, {
        0.28768544399287005`, -5.0790698570689}, {
        0.2876854439928701, -5.0790698570689}, {
        0.14384272199643502`, -5.03953492853445}}], 
       PolygonBox[{{0.2876854439928701, -5.0790698570689}, {
        0.28768544399287005`, -5.0790698570689}, {
        0.4315281659893051, -5.118604785603349}, {
        0.43152816598930505`, -5.118604785603349}, {
        0.2876854439928701, -5.0790698570689}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.43152816598930516`, -4.881395214396651}, \
{-0.28768544399287016`, -4.9209301429311}, {-0.14384272199643508`, \
-4.96046507146555}, {-5.323250062839922*^-17, -5.}, {
         0.14384272199643502`, -5.03953492853445}, {
         0.2876854439928701, -5.0790698570689}, {
         0.43152816598930505`, -5.118604785603349}, {
         0.43152816598930516`, -5.118604785603349}, {
         0.28768544399287016`, -5.0790698570689}, {
         0.14384272199643508`, -5.03953492853445}, {
         5.323250062839922*^-17, -5.}, {-0.14384272199643502`, \
-4.96046507146555}, {-0.2876854439928701, -4.9209301429311}, \
{-0.43152816598930505`, -4.881395214396651}, {-0.43152816598930516`, \
-4.881395214396651}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.5585535390243542, -5.296482505743049}, \
{-0.3045027929542561, -4.466307923050252}, {
      0.5585535390243542, -4.703517494256951}, {
      0.3045027929542561, -5.533692076949748}, {-0.5585535390243542, \
-5.296482505743049}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5585535390243542, -5.296482505743049}, \
{-0.3045027929542561, -4.466307923050252}, {
       0.5585535390243542, -4.703517494256951}, {
       0.3045027929542561, -5.533692076949748}, {-0.5585535390243542, \
-5.296482505743049}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.10377923337074094`, -4.426488166154326}, \
{-0.10377923337074083`, -4.426488166154326}, {-0.06918615558049386, \
-4.284325444102883}, {-0.06918615558049396, -4.284325444102883}, \
{-0.10377923337074094`, -4.426488166154326}}], 
     PolygonBox[{{-0.06918615558049396, -4.284325444102883}, \
{-0.06918615558049386, -4.284325444102883}, {-0.03459307779024692, \
-4.142162722051442}, {-0.03459307779024698, -4.142162722051442}, \
{-0.06918615558049396, -4.284325444102883}}], 
     PolygonBox[{{-0.03459307779024698, -4.142162722051442}, \
{-0.03459307779024692, -4.142162722051442}, {2.801043716368183*^-17, -4.}, {
      0., -4.}, {-0.03459307779024698, -4.142162722051442}}], 
     PolygonBox[{{0., -4.}, {5.3614458133936034`*^-17, -4.}, {
      0.034593077790247, -3.8578372779485584`}, {
      0.034593077790246965`, -3.8578372779485584`}, {0., -4.}}], 
     PolygonBox[{{0.034593077790246965`, -3.8578372779485584`}, {
      0.034593077790247, -3.8578372779485584`}, {
      0.06918615558049394, -3.7156745558971163`}, {
      0.06918615558049394, -3.7156745558971163`}, {
      0.034593077790246965`, -3.8578372779485584`}}], 
     PolygonBox[{{0.06918615558049394, -3.7156745558971163`}, {
      0.06918615558049394, -3.7156745558971163`}, {
      0.10377923337074092`, -3.5735118338456746`}, {
      0.10377923337074091`, -3.5735118338456746`}, {
      0.06918615558049394, -3.7156745558971163`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.10377923337074094`, -4.426488166154326}, \
{-0.06918615558049396, -4.284325444102883}, {-0.03459307779024698, \
-4.142162722051442}, {-1.2802010485127108`*^-17, -4.}, {
       0.034593077790246965`, -3.8578372779485584`}, {
       0.06918615558049394, -3.7156745558971163`}, {
       0.10377923337074091`, -3.5735118338456746`}, {
       0.10377923337074094`, -3.5735118338456746`}, {
       0.06918615558049396, -3.7156745558971163`}, {
       0.03459307779024698, -3.8578372779485584`}, {
       1.2802010485127108`*^-17, -4.}, {-0.034593077790246965`, \
-4.142162722051442}, {-0.06918615558049394, -4.284325444102883}, \
{-0.10377923337074091`, -4.426488166154325}, {-0.10377923337074094`, \
-4.426488166154326}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4377952742885909, -3.9008147447888457`}, \
{-0.4377952742885909, -3.9008147447888457`}, {-0.2918635161923939, \
-3.933876496525897}, {-0.291863516192394, -3.933876496525897}, \
{-0.4377952742885909, -3.9008147447888457`}}], 
       PolygonBox[{{-0.291863516192394, -3.933876496525897}, \
{-0.2918635161923939, -3.933876496525897}, {-0.14593175809619705`, \
-3.9669382482629487`}, {-0.145931758096197, -3.9669382482629487`}, \
{-0.291863516192394, -3.933876496525897}}], 
       PolygonBox[{{-0.145931758096197, -3.9669382482629487`}, \
{-0.14593175809619705`, -3.9669382482629487`}, {-1.0165655327667877`*^-16, \
-4.}, {6.354645298272203*^-18, -4.}, {-0.145931758096197, \
-3.9669382482629487`}}], 
       PolygonBox[{{6.354645298272203*^-18, -4.}, {
        6.354645298272203*^-18, -4.}, {
        0.14593175809619693`, -4.033061751737051}, {
        0.14593175809619693`, -4.033061751737051}, {
        6.354645298272203*^-18, -4.}}], 
       PolygonBox[{{0.14593175809619693`, -4.033061751737051}, {
        0.14593175809619693`, -4.033061751737051}, {
        0.29186351619239387`, -4.066123503474103}, {
        0.2918635161923939, -4.066123503474103}, {
        0.14593175809619693`, -4.033061751737051}}], 
       PolygonBox[{{0.2918635161923939, -4.066123503474103}, {
        0.29186351619239387`, -4.066123503474103}, {
        0.43779527428859083`, -4.099185255211154}, {
        0.4377952742885908, -4.099185255211154}, {
        0.2918635161923939, -4.066123503474103}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4377952742885909, -3.9008147447888457`}, \
{-0.291863516192394, -3.933876496525897}, {-0.145931758096197, \
-3.9669382482629487`}, {-5.4005599287475487`*^-17, -4.}, {
         0.14593175809619693`, -4.033061751737051}, {
         0.2918635161923939, -4.066123503474103}, {
         0.4377952742885908, -4.099185255211154}, {
         0.4377952742885909, -4.099185255211155}, {
         0.291863516192394, -4.066123503474103}, {
         0.145931758096197, -4.033061751737051}, {
         5.4005599287475487`*^-17, -4.}, {-0.14593175809619693`, \
-3.9669382482629487`}, {-0.2918635161923939, -3.933876496525897}, \
{-0.4377952742885908, -3.9008147447888457`}, {-0.4377952742885909, \
-3.9008147447888457`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.5415745076593318, -4.327302910943171}, \
{-0.33401604091785, -3.4743265786345203`}, {
      0.5415745076593318, -3.672697089056829}, {
      0.33401604091785, -4.52567342136548}, {-0.5415745076593318, \
-4.327302910943171}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5415745076593318, -4.327302910943171}, {-0.33401604091785, \
-3.4743265786345203`}, {0.5415745076593318, -3.672697089056829}, {
       0.33401604091785, -4.52567342136548}, {-0.5415745076593318, \
-4.327302910943171}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.07917108577043312, -3.4362141970266387`}, \
{-0.07917108577043301, -3.4362141970266387`}, {-0.05278072384695533, \
-3.2908094646844255`}, {-0.052780723846955424`, -3.290809464684426}, \
{-0.07917108577043312, -3.4362141970266387`}}], 
     PolygonBox[{{-0.052780723846955424`, -3.290809464684426}, \
{-0.05278072384695533, -3.2908094646844255`}, {-0.02639036192347765, \
-3.1454047323422127`}, {-0.026390361923477712`, -3.1454047323422127`}, \
{-0.052780723846955424`, -3.290809464684426}}], 
     PolygonBox[{{-0.026390361923477712`, -3.1454047323422127`}, \
{-0.02639036192347765, -3.1454047323422127`}, {3.471368212298017*^-17, -3.}, {
      0., -3.}, {-0.026390361923477712`, -3.1454047323422127`}}], 
     PolygonBox[{{0., -3.}, {5.424647374673748*^-17, -3.}, {
      0.026390361923477736`, -2.8545952676577873`}, {
      0.0263903619234777, -2.8545952676577873`}, {0., -3.}}], 
     PolygonBox[{{0.0263903619234777, -2.8545952676577873`}, {
      0.026390361923477736`, -2.8545952676577873`}, {
      0.052780723846955424`, -2.7091905353155745`}, {
      0.05278072384695542, -2.7091905353155745`}, {
      0.0263903619234777, -2.8545952676577873`}}], 
     PolygonBox[{{0.05278072384695542, -2.7091905353155745`}, {
      0.052780723846955424`, -2.7091905353155745`}, {
      0.07917108577043312, -2.5637858029733613`}, {
      0.07917108577043311, -2.5637858029733613`}, {
      0.05278072384695542, -2.7091905353155745`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.07917108577043312, -3.4362141970266387`}, \
{-0.052780723846955424`, -3.290809464684426}, {-0.026390361923477712`, \
-3.1454047323422127`}, {-9.766395811878662*^-18, -3.}, {
       0.0263903619234777, -2.8545952676577873`}, {
       0.05278072384695542, -2.7091905353155745`}, {
       0.07917108577043311, -2.5637858029733613`}, {
       0.07917108577043312, -2.5637858029733613`}, {
       0.052780723846955424`, -2.709190535315574}, {
       0.026390361923477712`, -2.8545952676577873`}, {
       9.766395811878662*^-18, -3.}, {-0.0263903619234777, \
-3.1454047323422127`}, {-0.05278072384695542, -3.2908094646844255`}, \
{-0.07917108577043311, -3.4362141970266387`}, {-0.07917108577043312, \
-3.4362141970266387`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4429560734123993, -2.9228695035000056`}, \
{-0.4429560734123993, -2.9228695035000056`}, {-0.2953040489415995, \
-2.948579669000004}, {-0.29530404894159956`, -2.948579669000004}, \
{-0.4429560734123993, -2.9228695035000056`}}], 
       PolygonBox[{{-0.29530404894159956`, -2.948579669000004}, \
{-0.2953040489415995, -2.948579669000004}, {-0.14765202447079984`, \
-2.9742898345000017`}, {-0.14765202447079978`, -2.9742898345000017`}, \
{-0.29530404894159956`, -2.948579669000004}}], 
       PolygonBox[{{-0.14765202447079978`, -2.9742898345000017`}, \
{-0.14765202447079984`, -2.9742898345000017`}, {-1.0443662062797688`*^-16, \
-3.}, {4.8478308386890745`*^-18, -3.}, {-0.14765202447079978`, \
-2.9742898345000017`}}], 
       PolygonBox[{{4.8478308386890745`*^-18, -3.}, {
        4.8478308386890745`*^-18, -3.}, {
        0.14765202447079973`, -3.0257101654999983`}, {
        0.14765202447079973`, -3.025710165499998}, {
        4.8478308386890745`*^-18, -3.}}], 
       PolygonBox[{{0.14765202447079973`, -3.025710165499998}, {
        0.14765202447079973`, -3.0257101654999983`}, {
        0.29530404894159945`, -3.051420330999996}, {
        0.2953040489415995, -3.051420330999996}, {
        0.14765202447079973`, -3.025710165499998}}], 
       PolygonBox[{{0.2953040489415995, -3.051420330999996}, {
        0.29530404894159945`, -3.051420330999996}, {
        0.44295607341239923`, -3.0771304964999944`}, {
        0.4429560734123992, -3.0771304964999944`}, {
        0.2953040489415995, -3.051420330999996}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4429560734123993, -2.9228695035000056`}, \
{-0.29530404894159956`, -2.948579669000004}, {-0.14765202447079978`, \
-2.9742898345000017`}, {-5.464222573333298*^-17, -3.}, {
         0.14765202447079973`, -3.0257101654999983`}, {
         0.2953040489415995, -3.051420330999996}, {
         0.4429560734123992, -3.0771304964999944`}, {
         0.4429560734123993, -3.0771304964999944`}, {
         0.29530404894159956`, -3.051420330999996}, {
         0.14765202447079978`, -3.0257101654999983`}, {
         5.464222573333298*^-17, -3.}, {-0.14765202447079973`, \
-2.9742898345000017`}, {-0.2953040489415995, -2.948579669000004}, \
{-0.4429560734123992, -2.9228695035000056`}, {-0.4429560734123993, \
-2.9228695035000056`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.5221271591828324, -3.3590837005266443`}, \
{-0.36378498764196615`, -2.4866553064733674`}, {
      0.5221271591828324, -2.6409162994733557`}, {
      0.36378498764196615`, -3.5133446935266326`}, {-0.5221271591828324, \
-3.3590837005266443`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5221271591828324, -3.3590837005266443`}, \
{-0.36378498764196615`, -2.4866553064733674`}, {
       0.5221271591828324, -2.6409162994733557`}, {
       0.36378498764196615`, -3.5133446935266326`}, {-0.5221271591828324, \
-3.3590837005266443`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.053447346893498573`, -2.443681761282597}, \
{-0.05344734689349846, -2.443681761282597}, {-0.035631564595665625`, \
-2.295787840855065}, {-0.03563156459566572, -2.295787840855065}, \
{-0.053447346893498573`, -2.443681761282597}}], 
     PolygonBox[{{-0.03563156459566572, -2.295787840855065}, \
{-0.035631564595665625`, -2.295787840855065}, {-0.017815782297832795`, \
-2.1478939204275322`}, {-0.01781578229783286, -2.1478939204275322`}, \
{-0.03563156459566572, -2.295787840855065}}], 
     PolygonBox[{{-0.01781578229783286, -2.1478939204275322`}, \
{-0.017815782297832795`, -2.1478939204275322`}, {
      4.153207462178052*^-17, -2.}, {
      0., -2.}, {-0.01781578229783286, -2.1478939204275322`}}], 
     PolygonBox[{{0., -2.}, {5.471840242762272*^-17, -2.}, {
      0.017815782297832893`, -1.8521060795724678`}, {
      0.017815782297832854`, -1.8521060795724678`}, {0., -2.}}], 
     PolygonBox[{{0.017815782297832854`, -1.8521060795724678`}, {
      0.017815782297832893`, -1.8521060795724678`}, {
      0.03563156459566573, -1.7042121591449353`}, {
      0.035631564595665716`, -1.7042121591449353`}, {
      0.017815782297832854`, -1.8521060795724678`}}], 
     PolygonBox[{{0.035631564595665716`, -1.7042121591449353`}, {
      0.03563156459566573, -1.7042121591449353`}, {
      0.05344734689349857, -1.5563182387174028`}, {
      0.05344734689349856, -1.5563182387174028`}, {
      0.035631564595665716`, -1.7042121591449353`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.053447346893498573`, -2.443681761282597}, \
{-0.03563156459566572, -2.295787840855065}, {-0.01781578229783286, \
-2.1478939204275322`}, {-6.593163902921106*^-18, -2.}, {
       0.017815782297832854`, -1.8521060795724678`}, {
       0.035631564595665716`, -1.7042121591449353`}, {
       0.05344734689349856, -1.5563182387174028`}, {
       0.053447346893498573`, -1.5563182387174028`}, {
       0.03563156459566572, -1.704212159144935}, {
       0.01781578229783286, -1.8521060795724675`}, {
       6.593163902921106*^-18, -2.}, {-0.017815782297832854`, \
-2.1478939204275322`}, {-0.035631564595665716`, -2.295787840855065}, \
{-0.05344734689349856, -2.443681761282597}, {-0.053447346893498573`, \
-2.443681761282597}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4468096635349866, -1.9471807249650424`}, \
{-0.4468096635349866, -1.9471807249650424`}, {-0.29787310902332437`, \
-1.964787149976695}, {-0.2978731090233244, -1.964787149976695}, \
{-0.4468096635349866, -1.9471807249650424`}}], 
       PolygonBox[{{-0.2978731090233244, -1.964787149976695}, \
{-0.29787310902332437`, -1.964787149976695}, {-0.14893655451166227`, \
-1.9823935749883475`}, {-0.1489365545116622, -1.9823935749883475`}, \
{-0.2978731090233244, -1.964787149976695}}], 
       PolygonBox[{{-0.1489365545116622, -1.9823935749883475`}, \
{-0.14893655451166227`, -1.9823935749883475`}, {-1.0696248856998934`*^-16, \
-2.}, {3.2727061148020633`*^-18, -2.}, {-0.1489365545116622, \
-1.9823935749883475`}}], 
       PolygonBox[{{3.2727061148020633`*^-18, -2.}, {
        3.2727061148020633`*^-18, -2.}, {
        0.14893655451166216`, -2.0176064250116523`}, {
        0.14893655451166216`, -2.0176064250116523`}, {
        3.2727061148020633`*^-18, -2.}}], 
       PolygonBox[{{0.14893655451166216`, -2.0176064250116523`}, {
        0.14893655451166216`, -2.0176064250116523`}, {
        0.2978731090233243, -2.035212850023305}, {
        0.29787310902332437`, -2.035212850023305}, {
        0.14893655451166216`, -2.0176064250116523`}}], 
       PolygonBox[{{0.29787310902332437`, -2.035212850023305}, {
        0.2978731090233243, -2.035212850023305}, {
        0.4468096635349865, -2.0528192750349574`}, {
        0.44680966353498647`, -2.0528192750349574`}, {
        0.29787310902332437`, -2.035212850023305}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4468096635349866, -1.9471807249650424`}, \
{-0.2978731090233244, -1.964787149976695}, {-0.1489365545116622, \
-1.9823935749883475`}, {-5.51175973423957*^-17, -2.}, {
         0.14893655451166216`, -2.0176064250116523`}, {
         0.29787310902332437`, -2.035212850023305}, {
         0.44680966353498647`, -2.0528192750349574`}, {
         0.4468096635349866, -2.0528192750349574`}, {
         0.2978731090233244, -2.035212850023305}, {
         0.1489365545116622, -2.0176064250116523`}, {
         5.51175973423957*^-17, -2.}, {-0.14893655451166216`, \
-1.9823935749883475`}, {-0.29787310902332437`, -1.964787149976695}, \
{-0.44680966353498647`, -1.9471807249650424`}, {-0.4468096635349866, \
-1.9471807249650424`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.5002570104284851, -2.3908624862476398`}, \
{-0.393362316641488, -1.5034989636824452`}, {
      0.5002570104284851, -1.6091375137523605`}, {
      0.393362316641488, -2.4965010363175546`}, {-0.5002570104284851, \
-2.3908624862476398`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5002570104284851, -2.3908624862476398`}, \
{-0.393362316641488, -1.5034989636824452`}, {
       0.5002570104284851, -1.6091375137523605`}, {
       0.393362316641488, -2.4965010363175546`}, {-0.5002570104284851, \
-2.3908624862476398`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.026930083315269002`, -1.4483903023154623`}, \
{-0.02693008331526889, -1.4483903023154623`}, {-0.01795338887684591, \
-1.2989268682103083`}, {-0.017953388876846003`, -1.2989268682103083`}, \
{-0.026930083315269002`, -1.4483903023154623`}}], 
     PolygonBox[{{-0.017953388876846003`, -1.2989268682103083`}, \
{-0.01795338887684591, -1.2989268682103083`}, {-0.008976694438422932, \
-1.1494634341051542`}, {-0.008976694438423001, -1.1494634341051542`}, \
{-0.017953388876846003`, -1.2989268682103083`}}], 
     PolygonBox[{{-0.008976694438423001, -1.1494634341051542`}, \
{-0.008976694438422932, -1.1494634341051542`}, {
      4.836620616162607*^-17, -1.0000000000000002`}, {
      0., -1.}, {-0.008976694438423001, -1.1494634341051542`}}], 
     PolygonBox[{{0., -1.}, {5.501029472866726*^-17, -1.}, {
      0.008976694438423034, -0.8505365658948459}, {
      0.008976694438422998, -0.8505365658948459}, {0., -1.}}], 
     PolygonBox[{{0.008976694438422998, -0.8505365658948459}, {
      0.008976694438423034, -0.8505365658948459}, {
      0.017953388876846013`, -0.7010731317896919}, {
      0.017953388876846, -0.7010731317896918}, {
      0.008976694438422998, -0.8505365658948459}}], 
     PolygonBox[{{0.017953388876846, -0.7010731317896918}, {
      0.017953388876846013`, -0.7010731317896919}, {
      0.026930083315269, -0.5516096976845377}, {
      0.026930083315268995`, -0.5516096976845377}, {
      0.017953388876846, -0.7010731317896918}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.026930083315269002`, -1.4483903023154623`}, \
{-0.017953388876846003`, -1.2989268682103083`}, {-0.008976694438423001, \
-1.1494634341051542`}, {-3.3220442835206016`*^-18, -1.}, {
       0.008976694438422998, -0.8505365658948459}, {
       0.017953388876846, -0.7010731317896918}, {
       0.026930083315268995`, -0.5516096976845377}, {
       0.026930083315269002`, -0.5516096976845377}, {
       0.017953388876846003`, -0.7010731317896917}, {
       0.008976694438423001, -0.8505365658948458}, {
       3.3220442835206016`*^-18, -1.}, {-0.008976694438422998, \
-1.1494634341051542`}, {-0.017953388876846, -1.2989268682103083`}, \
{-0.026930083315268995`, -1.4483903023154623`}, {-0.026930083315269002`, \
-1.4483903023154623`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4491931450518433, -0.9731502811545253}, \
{-0.4491931450518433, -0.9731502811545253}, {-0.29946209670122886`, \
-0.9821001874363502}, {-0.2994620967012289, -0.9821001874363502}, \
{-0.4491931450518433, -0.9731502811545253}}], 
       PolygonBox[{{-0.2994620967012289, -0.9821001874363502}, \
{-0.29946209670122886`, -0.9821001874363502}, {-0.14973104835061452`, \
-0.9910500937181751}, {-0.14973104835061446`, -0.9910500937181751}, \
{-0.2994620967012289, -0.9821001874363502}}], 
       PolygonBox[{{-0.14973104835061446`, -0.9910500937181751}, \
{-0.14973104835061452`, -0.9910500937181751}, {-1.0917424623676902`*^-16, \
-1.}, {1.6489920166407863`*^-18, -1.}, {-0.14973104835061446`, \
-0.9910500937181751}}], 
       PolygonBox[{{1.6489920166407863`*^-18, -1.}, {
        1.6489920166407863`*^-18, -1.}, {
        0.1497310483506144, -1.0089499062818248`}, {
        0.1497310483506144, -1.0089499062818248`}, {
        1.6489920166407863`*^-18, -1.}}], 
       PolygonBox[{{0.1497310483506144, -1.0089499062818248`}, {
        0.1497310483506144, -1.0089499062818248`}, {
        0.2994620967012288, -1.0178998125636498`}, {
        0.29946209670122886`, -1.0178998125636498`}, {
        0.1497310483506144, -1.0089499062818248`}}], 
       PolygonBox[{{0.29946209670122886`, -1.0178998125636498`}, {
        0.2994620967012288, -1.0178998125636498`}, {
        0.44919314505184327`, -1.0268497188454746`}, {
        0.4491931450518432, -1.0268497188454746`}, {
        0.29946209670122886`, -1.0178998125636498`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4491931450518433, -0.9731502811545253}, \
{-0.2994620967012289, -0.9821001874363502}, {-0.14973104835061446`, \
-0.9910500937181751}, {-5.5411619126704904`*^-17, -1.}, {
         0.1497310483506144, -1.0089499062818248`}, {
         0.29946209670122886`, -1.0178998125636498`}, {
         0.4491931450518432, -1.0268497188454746`}, {
         0.4491931450518433, -1.0268497188454746`}, {
         0.2994620967012289, -1.0178998125636498`}, {
         0.14973104835061446`, -1.0089499062818248`}, {
         5.5411619126704904`*^-17, -1.}, {-0.1497310483506144, \
-0.9910500937181751}, {-0.29946209670122886`, -0.9821001874363502}, \
{-0.4491931450518432, -0.9731502811545253}, {-0.4491931450518433, \
-0.9731502811545253}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.47612322836711235`, -1.4215405834699877`}, \
{-0.4222630617365743, -0.5247599788390629}, {
      0.47612322836711235`, -0.5784594165300123}, {
      0.4222630617365743, -1.475240021160937}, {-0.47612322836711235`, \
-1.4215405834699877`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.47612322836711235`, -1.4215405834699877`}, \
{-0.4222630617365743, -0.5247599788390629}, {
       0.47612322836711235`, -0.5784594165300123}, {
       0.4222630617365743, -1.475240021160937}, {-0.47612322836711235`, \
-1.4215405834699877`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0., -0.45}, {1.1021821192326179`*^-16, -0.45}, {
      9.184850993605148*^-17, -0.3}, {0., -0.30000000000000004`}, {
      0., -0.45}}], 
     PolygonBox[{{0., -0.30000000000000004`}, {
      9.184850993605148*^-17, -0.3}, {
      7.34788079488412*^-17, -0.15000000000000008`}, {
      0., -0.15000000000000002`}, {0., -0.30000000000000004`}}], 
     PolygonBox[{{0., -0.15000000000000002`}, {
      7.34788079488412*^-17, -0.15000000000000008`}, {
      5.510910596163091*^-17, -1.1102230246251565`*^-16}, {0., 0.}, {
      0., -0.15000000000000002`}}], 
     PolygonBox[{{0., 0.}, {5.5109105961630896`*^-17, 0.}, {
      3.67394039744206*^-17, 0.14999999999999997`}, {0., 
      0.14999999999999997`}, {0., 0.}}], 
     PolygonBox[{{0., 0.14999999999999997`}, {3.67394039744206*^-17, 
      0.14999999999999997`}, {1.8369701987210304`*^-17, 
      0.29999999999999993`}, {0., 0.3}, {0., 0.14999999999999997`}}], 
     PolygonBox[{{0., 0.3}, {1.8369701987210307`*^-17, 
      0.29999999999999993`}, {9.177509745766515*^-33, 0.44999999999999996`}, {
      0., 0.4499999999999999}, {0., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -0.45}, {0., -0.30000000000000004`}, {
       0., -0.15000000000000002`}, {0., -5.551115123125783*^-17}, {0., 
       0.14999999999999997`}, {0., 0.3}, {0., 0.4499999999999999}, {0., 
       0.45}, {0., 0.30000000000000004`}, {0., 0.15000000000000002`}, {0., 
       5.551115123125783*^-17}, {0., -0.14999999999999997`}, {0., -0.3}, {
       0., -0.4499999999999999}, {0., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.45, 0.}, {-0.45, 5.5109105961630896`*^-17}, {-0.3, 
        4.592425496802574*^-17}, {-0.30000000000000004`, 
        9.184850993605149*^-18}, {-0.45, 0.}}], 
       PolygonBox[{{-0.30000000000000004`, 9.184850993605149*^-18}, {-0.3, 
        4.592425496802574*^-17}, {-0.15000000000000008`, 
        3.67394039744206*^-17}, {-0.15000000000000002`, 
        1.8369701987210297`*^-17}, {-0.30000000000000004`, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{-0.15000000000000002`, 
        1.8369701987210297`*^-17}, {-0.15000000000000008`, 
        3.67394039744206*^-17}, {-1.1102230246251565`*^-16, 
        2.7554552980815454`*^-17}, {0., 
        2.7554552980815448`*^-17}, {-0.15000000000000002`, 
        1.8369701987210297`*^-17}}], 
       PolygonBox[{{0., 2.7554552980815448`*^-17}, {0., 
        2.7554552980815448`*^-17}, {0.14999999999999997`, 
        1.83697019872103*^-17}, {0.14999999999999997`, 
        3.6739403974420595`*^-17}, {0., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{0.14999999999999997`, 3.6739403974420595`*^-17}, {
        0.14999999999999997`, 1.83697019872103*^-17}, {0.29999999999999993`, 
        9.184850993605152*^-18}, {0.3, 4.592425496802574*^-17}, {
        0.14999999999999997`, 3.6739403974420595`*^-17}}], 
       PolygonBox[{{0.3, 4.592425496802574*^-17}, {0.29999999999999993`, 
        9.184850993605153*^-18}, {0.44999999999999996`, 
        4.5887548728832574`*^-33}, {0.4499999999999999, 
        5.510910596163089*^-17}, {0.3, 4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.45, 0.}, {-0.30000000000000004`, 
         0.}, {-0.15000000000000002`, 0.}, {-5.551115123125783*^-17, 0.}, {
         0.14999999999999997`, 0.}, {0.3, 0.}, {0.4499999999999999, 0.}, {
         0.45, 0.}, {0.30000000000000004`, 0.}, {0.15000000000000002`, 0.}, {
         5.551115123125783*^-17, 0.}, {-0.14999999999999997`, 0.}, {-0.3, 
         0.}, {-0.4499999999999999, 0.}, {-0.45, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.45, -0.45}, {-0.45, 0.45}, {0.45, 0.45}, {
      0.45, -0.45}, {-0.45, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.45, -0.45}, {-0.45, 0.45}, {0.45, 0.45}, {
       0.45, -0.45}, {-0.45, -0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.026930083315269002`, 0.5516096976845377}, {
      0.026930083315269113`, 0.5516096976845377}, {0.01795338887684609, 
      0.7010731317896918}, {0.017953388876846003`, 0.7010731317896917}, {
      0.026930083315269002`, 0.5516096976845377}}], 
     PolygonBox[{{0.017953388876846003`, 0.7010731317896917}, {
      0.01795338887684609, 0.7010731317896918}, {0.008976694438423078, 
      0.8505365658948458}, {0.008976694438423001, 0.8505365658948458}, {
      0.017953388876846003`, 0.7010731317896917}}], 
     PolygonBox[{{0.008976694438423001, 0.8505365658948458}, {
      0.008976694438423078, 0.8505365658948458}, {6.165438329570848*^-17, 
      0.9999999999999999}, {0., 1.}, {0.008976694438423001, 
      0.8505365658948458}}], 
     PolygonBox[{{0., 1.}, {5.501029472866726*^-17, 
      1.}, {-0.008976694438422961, 
      1.1494634341051542`}, {-0.008976694438422998, 1.1494634341051542`}, {0.,
       1.}}], PolygonBox[{{-0.008976694438422998, 
      1.1494634341051542`}, {-0.008976694438422961, 
      1.1494634341051542`}, {-0.01795338887684598, 
      1.2989268682103081`}, {-0.017953388876846, 
      1.2989268682103083`}, {-0.008976694438422998, 1.1494634341051542`}}], 
     PolygonBox[{{-0.017953388876846, 
      1.2989268682103083`}, {-0.01795338887684598, 
      1.2989268682103081`}, {-0.026930083315269, 
      1.4483903023154623`}, {-0.026930083315268995`, 
      1.4483903023154623`}, {-0.017953388876846, 1.2989268682103083`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.026930083315269002`, 0.5516096976845377}, {
       0.017953388876846003`, 0.7010731317896917}, {0.008976694438423001, 
       0.8505365658948458}, {3.3220442835206016`*^-18, 
       1.}, {-0.008976694438422998, 1.1494634341051542`}, {-0.017953388876846,
        1.2989268682103083`}, {-0.026930083315268995`, 
       1.4483903023154623`}, {-0.026930083315269002`, 
       1.4483903023154623`}, {-0.017953388876846003`, 
       1.2989268682103083`}, {-0.008976694438423001, 
       1.1494634341051542`}, {-3.3220442835206016`*^-18, 1.}, {
       0.008976694438422998, 0.8505365658948459}, {0.017953388876846, 
       0.7010731317896918}, {0.026930083315268995`, 0.5516096976845377}, {
       0.026930083315269002`, 0.5516096976845377}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4491931450518433, 
        0.9731502811545253}, {-0.4491931450518433, 
        0.9731502811545254}, {-0.29946209670122886`, 
        0.9821001874363503}, {-0.2994620967012289, 
        0.9821001874363502}, {-0.4491931450518433, 0.9731502811545253}}], 
       PolygonBox[{{-0.2994620967012289, 
        0.9821001874363502}, {-0.29946209670122886`, 
        0.9821001874363503}, {-0.14973104835061452`, 
        0.9910500937181751}, {-0.14973104835061446`, 
        0.9910500937181751}, {-0.2994620967012289, 0.9821001874363502}}], 
       PolygonBox[{{-0.14973104835061446`, 
        0.9910500937181751}, {-0.14973104835061452`, 
        0.9910500937181751}, {-1.124722302700506*^-16, 
        1.}, {-1.6489920166407863`*^-18, 1.}, {-0.14973104835061446`, 
        0.9910500937181751}}], 
       PolygonBox[{{-1.6489920166407863`*^-18, 
        1.}, {-1.6489920166407863`*^-18, 1.}, {0.1497310483506144, 
        1.008949906281825}, {0.1497310483506144, 
        1.008949906281825}, {-1.6489920166407863`*^-18, 1.}}], 
       PolygonBox[{{0.1497310483506144, 1.008949906281825}, {
        0.1497310483506144, 1.008949906281825}, {0.2994620967012288, 
        1.0178998125636498`}, {0.29946209670122886`, 1.0178998125636498`}, {
        0.1497310483506144, 1.008949906281825}}], 
       PolygonBox[{{0.29946209670122886`, 1.0178998125636498`}, {
        0.2994620967012288, 1.0178998125636498`}, {0.44919314505184327`, 
        1.0268497188454746`}, {0.4491931450518432, 1.0268497188454748`}, {
        0.29946209670122886`, 1.0178998125636498`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4491931450518433, 
         0.9731502811545253}, {-0.2994620967012289, 
         0.9821001874363502}, {-0.14973104835061446`, 
         0.9910500937181751}, {-5.5411619126704904`*^-17, 1.}, {
         0.1497310483506144, 1.0089499062818248`}, {0.29946209670122886`, 
         1.0178998125636498`}, {0.4491931450518432, 1.0268497188454746`}, {
         0.4491931450518433, 1.0268497188454746`}, {0.2994620967012289, 
         1.0178998125636498`}, {0.14973104835061446`, 1.0089499062818248`}, {
         5.5411619126704904`*^-17, 1.}, {-0.1497310483506144, 
         0.9910500937181751}, {-0.29946209670122886`, 
         0.9821001874363502}, {-0.4491931450518432, 
         0.9731502811545253}, {-0.4491931450518433, 0.9731502811545253}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.4222630617365743, 
      0.5247599788390629}, {-0.47612322836711235`, 1.4215405834699877`}, {
      0.4222630617365743, 1.475240021160937}, {0.47612322836711235`, 
      0.5784594165300123}, {-0.4222630617365743, 0.5247599788390629}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.4222630617365743, 
       0.5247599788390629}, {-0.47612322836711235`, 1.4215405834699877`}, {
       0.4222630617365743, 1.475240021160937}, {0.47612322836711235`, 
       0.5784594165300123}, {-0.4222630617365743, 0.5247599788390629}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.053447346893498573`, 1.5563182387174028`}, {
      0.053447346893498685`, 1.5563182387174028`}, {0.035631564595665806`, 
      1.7042121591449353`}, {0.03563156459566572, 1.704212159144935}, {
      0.053447346893498573`, 1.5563182387174028`}}], 
     PolygonBox[{{0.03563156459566572, 1.704212159144935}, {
      0.035631564595665806`, 1.7042121591449353`}, {0.01781578229783294, 
      1.8521060795724675`}, {0.01781578229783286, 1.8521060795724675`}, {
      0.03563156459566572, 1.704212159144935}}], 
     PolygonBox[{{0.01781578229783286, 1.8521060795724675`}, {
      0.01781578229783294, 1.8521060795724675`}, {6.790473023346494*^-17, 
      2.}, {0., 2.}, {0.01781578229783286, 1.8521060795724675`}}], 
     PolygonBox[{{0., 2.}, {5.471840242762272*^-17, 
      2.}, {-0.017815782297832816`, 
      2.1478939204275322`}, {-0.017815782297832854`, 2.1478939204275322`}, {
      0., 2.}}], 
     PolygonBox[{{-0.017815782297832854`, 
      2.1478939204275322`}, {-0.017815782297832816`, 
      2.1478939204275322`}, {-0.03563156459566569, 
      2.2957878408550645`}, {-0.035631564595665716`, 
      2.295787840855065}, {-0.017815782297832854`, 2.1478939204275322`}}], 
     PolygonBox[{{-0.035631564595665716`, 
      2.295787840855065}, {-0.03563156459566569, 
      2.2957878408550645`}, {-0.05344734689349857, 
      2.443681761282597}, {-0.05344734689349856, 
      2.443681761282597}, {-0.035631564595665716`, 2.295787840855065}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.053447346893498573`, 1.5563182387174028`}, {
       0.03563156459566572, 1.704212159144935}, {0.01781578229783286, 
       1.8521060795724675`}, {6.593163902921106*^-18, 
       2.}, {-0.017815782297832854`, 
       2.1478939204275322`}, {-0.035631564595665716`, 
       2.295787840855065}, {-0.05344734689349856, 
       2.443681761282597}, {-0.053447346893498573`, 
       2.443681761282597}, {-0.03563156459566572, 
       2.295787840855065}, {-0.01781578229783286, 
       2.1478939204275322`}, {-6.593163902921106*^-18, 2.}, {
       0.017815782297832854`, 1.8521060795724678`}, {0.035631564595665716`, 
       1.7042121591449353`}, {0.05344734689349856, 1.5563182387174028`}, {
       0.053447346893498573`, 1.5563182387174028`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4468096635349866, 
        1.9471807249650424`}, {-0.4468096635349866, 
        1.9471807249650426`}, {-0.29787310902332437`, 
        1.964787149976695}, {-0.2978731090233244, 
        1.964787149976695}, {-0.4468096635349866, 1.9471807249650424`}}], 
       PolygonBox[{{-0.2978731090233244, 
        1.964787149976695}, {-0.29787310902332437`, 
        1.964787149976695}, {-0.14893655451166227`, 
        1.9823935749883475`}, {-0.1489365545116622, 
        1.9823935749883475`}, {-0.2978731090233244, 1.964787149976695}}], 
       PolygonBox[{{-0.1489365545116622, 
        1.9823935749883475`}, {-0.14893655451166227`, 
        1.9823935749883475`}, {-1.1350790079959346`*^-16, 
        2.}, {-3.2727061148020633`*^-18, 2.}, {-0.1489365545116622, 
        1.9823935749883475`}}], 
       PolygonBox[{{-3.2727061148020633`*^-18, 
        2.}, {-3.2727061148020633`*^-18, 2.}, {0.14893655451166216`, 
        2.0176064250116523`}, {0.14893655451166216`, 
        2.0176064250116528`}, {-3.2727061148020633`*^-18, 2.}}], 
       PolygonBox[{{0.14893655451166216`, 2.0176064250116528`}, {
        0.14893655451166216`, 2.0176064250116523`}, {0.2978731090233243, 
        2.035212850023305}, {0.29787310902332437`, 2.035212850023305}, {
        0.14893655451166216`, 2.0176064250116528`}}], 
       PolygonBox[{{0.29787310902332437`, 2.035212850023305}, {
        0.2978731090233243, 2.035212850023305}, {0.4468096635349865, 
        2.0528192750349574`}, {0.44680966353498647`, 2.0528192750349574`}, {
        0.29787310902332437`, 2.035212850023305}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4468096635349866, 
         1.9471807249650424`}, {-0.2978731090233244, 
         1.964787149976695}, {-0.1489365545116622, 
         1.9823935749883475`}, {-5.51175973423957*^-17, 2.}, {
         0.14893655451166216`, 2.0176064250116523`}, {0.29787310902332437`, 
         2.035212850023305}, {0.44680966353498647`, 2.0528192750349574`}, {
         0.4468096635349866, 2.0528192750349574`}, {0.2978731090233244, 
         2.035212850023305}, {0.1489365545116622, 2.0176064250116523`}, {
         5.51175973423957*^-17, 2.}, {-0.14893655451166216`, 
         1.9823935749883475`}, {-0.29787310902332437`, 
         1.964787149976695}, {-0.44680966353498647`, 
         1.9471807249650424`}, {-0.4468096635349866, 
         1.9471807249650424`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.393362316641488, 
      1.5034989636824452`}, {-0.5002570104284851, 2.3908624862476398`}, {
      0.393362316641488, 2.4965010363175546`}, {0.5002570104284851, 
      1.6091375137523605`}, {-0.393362316641488, 1.5034989636824452`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.393362316641488, 
       1.5034989636824452`}, {-0.5002570104284851, 2.3908624862476398`}, {
       0.393362316641488, 2.4965010363175546`}, {0.5002570104284851, 
       1.6091375137523605`}, {-0.393362316641488, 1.5034989636824452`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.07917108577043312, 2.5637858029733613`}, {
      0.07917108577043323, 2.5637858029733613`}, {0.05278072384695551, 
      2.7091905353155745`}, {0.052780723846955424`, 2.709190535315574}, {
      0.07917108577043312, 2.5637858029733613`}}], 
     PolygonBox[{{0.052780723846955424`, 2.709190535315574}, {
      0.05278072384695551, 2.7091905353155745`}, {0.026390361923477795`, 
      2.8545952676577873`}, {0.026390361923477712`, 2.8545952676577873`}, {
      0.052780723846955424`, 2.709190535315574}}], 
     PolygonBox[{{0.026390361923477712`, 2.8545952676577873`}, {
      0.026390361923477795`, 2.8545952676577873`}, {7.377926537049482*^-17, 
      3.}, {0., 3.}, {0.026390361923477712`, 2.8545952676577873`}}], 
     PolygonBox[{{0., 3.}, {5.424647374673748*^-17, 
      3.}, {-0.026390361923477667`, 
      3.1454047323422127`}, {-0.0263903619234777, 3.1454047323422127`}, {0., 
      3.}}], PolygonBox[{{-0.0263903619234777, 
      3.1454047323422127`}, {-0.026390361923477667`, 
      3.1454047323422127`}, {-0.05278072384695538, 
      3.2908094646844255`}, {-0.05278072384695542, 
      3.2908094646844255`}, {-0.0263903619234777, 3.1454047323422127`}}], 
     PolygonBox[{{-0.05278072384695542, 
      3.2908094646844255`}, {-0.05278072384695538, 
      3.2908094646844255`}, {-0.07917108577043312, 
      3.4362141970266387`}, {-0.07917108577043311, 
      3.4362141970266387`}, {-0.05278072384695542, 3.2908094646844255`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.07917108577043312, 2.5637858029733613`}, {
       0.052780723846955424`, 2.709190535315574}, {0.026390361923477712`, 
       2.8545952676577873`}, {9.766395811878662*^-18, 
       3.}, {-0.0263903619234777, 3.1454047323422127`}, {-0.05278072384695542,
        3.2908094646844255`}, {-0.07917108577043311, 
       3.4362141970266387`}, {-0.07917108577043312, 
       3.4362141970266387`}, {-0.052780723846955424`, 
       3.290809464684426}, {-0.026390361923477712`, 
       3.1454047323422127`}, {-9.766395811878662*^-18, 3.}, {
       0.0263903619234777, 2.8545952676577873`}, {0.05278072384695542, 
       2.7091905353155745`}, {0.07917108577043311, 2.5637858029733613`}, {
       0.07917108577043312, 2.5637858029733613`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4429560734123993, 
        2.9228695035000056`}, {-0.4429560734123993, 
        2.9228695035000056`}, {-0.2953040489415995, 
        2.948579669000004}, {-0.29530404894159956`, 
        2.948579669000004}, {-0.4429560734123993, 2.9228695035000056`}}], 
       PolygonBox[{{-0.29530404894159956`, 
        2.948579669000004}, {-0.2953040489415995, 
        2.948579669000004}, {-0.14765202447079984`, 
        2.9742898345000017`}, {-0.14765202447079978`, 
        2.9742898345000017`}, {-0.29530404894159956`, 2.948579669000004}}], 
       PolygonBox[{{-0.14765202447079978`, 
        2.9742898345000017`}, {-0.14765202447079984`, 
        2.9742898345000017`}, {-1.1413228230535503`*^-16, 
        3.}, {-4.8478308386890745`*^-18, 3.}, {-0.14765202447079978`, 
        2.9742898345000017`}}], 
       PolygonBox[{{-4.8478308386890745`*^-18, 
        3.}, {-4.8478308386890745`*^-18, 3.}, {0.14765202447079973`, 
        3.0257101654999983`}, {0.14765202447079973`, 
        3.0257101654999983`}, {-4.8478308386890745`*^-18, 3.}}], 
       PolygonBox[{{0.14765202447079973`, 3.0257101654999983`}, {
        0.14765202447079973`, 3.0257101654999983`}, {0.29530404894159945`, 
        3.051420330999996}, {0.2953040489415995, 3.051420330999996}, {
        0.14765202447079973`, 3.0257101654999983`}}], 
       PolygonBox[{{0.2953040489415995, 3.051420330999996}, {
        0.29530404894159945`, 3.051420330999996}, {0.44295607341239923`, 
        3.0771304964999944`}, {0.4429560734123992, 3.0771304964999944`}, {
        0.2953040489415995, 3.051420330999996}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4429560734123993, 
         2.9228695035000056`}, {-0.29530404894159956`, 
         2.948579669000004}, {-0.14765202447079978`, 
         2.9742898345000017`}, {-5.464222573333298*^-17, 3.}, {
         0.14765202447079973`, 3.0257101654999983`}, {0.2953040489415995, 
         3.051420330999996}, {0.4429560734123992, 3.0771304964999944`}, {
         0.4429560734123993, 3.0771304964999944`}, {0.29530404894159956`, 
         3.051420330999996}, {0.14765202447079978`, 3.0257101654999983`}, {
         5.464222573333298*^-17, 3.}, {-0.14765202447079973`, 
         2.9742898345000017`}, {-0.2953040489415995, 
         2.948579669000004}, {-0.4429560734123992, 
         2.9228695035000056`}, {-0.4429560734123993, 
         2.9228695035000056`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.36378498764196615`, 
      2.4866553064733674`}, {-0.5221271591828324, 3.3590837005266443`}, {
      0.36378498764196615`, 3.5133446935266326`}, {0.5221271591828324, 
      2.6409162994733557`}, {-0.36378498764196615`, 2.4866553064733674`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.36378498764196615`, 
       2.4866553064733674`}, {-0.5221271591828324, 3.3590837005266443`}, {
       0.36378498764196615`, 3.5133446935266326`}, {0.5221271591828324, 
       2.6409162994733557`}, {-0.36378498764196615`, 
       2.4866553064733674`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.10377923337074094`, 3.5735118338456746`}, {
      0.10377923337074105`, 3.5735118338456746`}, {0.06918615558049403, 
      3.7156745558971163`}, {0.06918615558049396, 3.7156745558971163`}, {
      0.10377923337074094`, 3.5735118338456746`}}], 
     PolygonBox[{{0.06918615558049396, 3.7156745558971163`}, {
      0.06918615558049403, 3.7156745558971163`}, {0.03459307779024706, 
      3.8578372779485584`}, {0.03459307779024698, 3.8578372779485584`}, {
      0.06918615558049396, 3.7156745558971163`}}], 
     PolygonBox[{{0.03459307779024698, 3.8578372779485584`}, {
      0.03459307779024706, 3.8578372779485584`}, {7.921847910419026*^-17, 
      4.}, {0., 4.}, {0.03459307779024698, 3.8578372779485584`}}], 
     PolygonBox[{{0., 4.}, {5.3614458133936034`*^-17, 
      4.}, {-0.03459307779024693, 4.142162722051442}, {-0.034593077790246965`,
       4.142162722051442}, {0., 4.}}], 
     PolygonBox[{{-0.034593077790246965`, 
      4.142162722051442}, {-0.03459307779024693, 
      4.142162722051442}, {-0.06918615558049392, 
      4.284325444102883}, {-0.06918615558049394, 
      4.284325444102883}, {-0.034593077790246965`, 4.142162722051442}}], 
     PolygonBox[{{-0.06918615558049394, 
      4.284325444102883}, {-0.06918615558049392, 
      4.284325444102883}, {-0.10377923337074092`, 
      4.426488166154326}, {-0.10377923337074091`, 
      4.426488166154325}, {-0.06918615558049394, 4.284325444102883}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.10377923337074094`, 3.5735118338456746`}, {
       0.06918615558049396, 3.7156745558971163`}, {0.03459307779024698, 
       3.8578372779485584`}, {1.2802010485127108`*^-17, 
       4.}, {-0.034593077790246965`, 
       4.142162722051442}, {-0.06918615558049394, 
       4.284325444102883}, {-0.10377923337074091`, 
       4.426488166154325}, {-0.10377923337074094`, 
       4.426488166154326}, {-0.06918615558049396, 
       4.284325444102883}, {-0.03459307779024698, 
       4.142162722051442}, {-1.2802010485127108`*^-17, 4.}, {
       0.034593077790246965`, 3.8578372779485584`}, {0.06918615558049394, 
       3.7156745558971163`}, {0.10377923337074091`, 3.5735118338456746`}, {
       0.10377923337074094`, 3.5735118338456746`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.4377952742885909, 
        3.9008147447888457`}, {-0.4377952742885909, 
        3.9008147447888457`}, {-0.2918635161923939, 
        3.933876496525897}, {-0.291863516192394, 
        3.933876496525897}, {-0.4377952742885909, 3.9008147447888457`}}], 
       PolygonBox[{{-0.291863516192394, 
        3.933876496525897}, {-0.2918635161923939, 
        3.933876496525897}, {-0.14593175809619705`, 
        3.9669382482629487`}, {-0.145931758096197, 
        3.9669382482629487`}, {-0.291863516192394, 3.933876496525897}}], 
       PolygonBox[{{-0.145931758096197, 
        3.9669382482629487`}, {-0.14593175809619705`, 
        3.9669382482629487`}, {-1.1436584387322319`*^-16, 
        4.}, {-6.354645298272203*^-18, 4.}, {-0.145931758096197, 
        3.9669382482629487`}}], 
       PolygonBox[{{-6.354645298272203*^-18, 4.}, {-6.354645298272203*^-18, 
        4.}, {0.14593175809619693`, 4.033061751737051}, {0.14593175809619693`,
         4.033061751737051}, {-6.354645298272203*^-18, 4.}}], 
       PolygonBox[{{0.14593175809619693`, 4.033061751737051}, {
        0.14593175809619693`, 4.033061751737051}, {0.29186351619239387`, 
        4.066123503474103}, {0.2918635161923939, 4.066123503474103}, {
        0.14593175809619693`, 4.033061751737051}}], 
       PolygonBox[{{0.2918635161923939, 4.066123503474103}, {
        0.29186351619239387`, 4.066123503474103}, {0.43779527428859083`, 
        4.099185255211154}, {0.4377952742885908, 4.099185255211155}, {
        0.2918635161923939, 4.066123503474103}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.4377952742885909, 
         3.9008147447888457`}, {-0.291863516192394, 
         3.933876496525897}, {-0.145931758096197, 
         3.9669382482629487`}, {-5.4005599287475487`*^-17, 4.}, {
         0.14593175809619693`, 4.033061751737051}, {0.2918635161923939, 
         4.066123503474103}, {0.4377952742885908, 4.099185255211154}, {
         0.4377952742885909, 4.099185255211155}, {0.291863516192394, 
         4.066123503474103}, {0.145931758096197, 4.033061751737051}, {
         5.4005599287475487`*^-17, 4.}, {-0.14593175809619693`, 
         3.9669382482629487`}, {-0.2918635161923939, 
         3.933876496525897}, {-0.4377952742885908, 
         3.9008147447888457`}, {-0.4377952742885909, 
         3.9008147447888457`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.33401604091785, 
      3.4743265786345203`}, {-0.5415745076593318, 4.327302910943171}, {
      0.33401604091785, 4.52567342136548}, {0.5415745076593318, 
      3.672697089056829}, {-0.33401604091785, 3.4743265786345203`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.33401604091785, 3.4743265786345203`}, {-0.5415745076593318,
        4.327302910943171}, {0.33401604091785, 4.52567342136548}, {
       0.5415745076593318, 3.672697089056829}, {-0.33401604091785, 
       3.4743265786345203`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.12702537303504904`, 4.584912708653602}, {
      0.12702537303504916`, 4.584912708653602}, {0.08468358202336611, 
      4.723275139102401}, {0.08468358202336604, 4.723275139102401}, {
      0.12702537303504904`, 4.584912708653602}}], 
     PolygonBox[{{0.08468358202336604, 4.723275139102401}, {
      0.08468358202336611, 4.723275139102401}, {0.0423417910116831, 
      4.8616375695512}, {0.04234179101168302, 4.861637569551201}, {
      0.08468358202336604, 4.723275139102401}}], 
     PolygonBox[{{0.04234179101168302, 4.861637569551201}, {
      0.0423417910116831, 4.8616375695512}, {8.418617957876437*^-17, 5.}, {0.,
       5.}, {0.04234179101168302, 4.861637569551201}}], 
     PolygonBox[{{0., 5.}, {5.284695872207303*^-17, 
      5.}, {-0.042341791011682964`, 5.138362430448799}, {-0.042341791011683, 
      5.138362430448799}, {0., 5.}}], 
     PolygonBox[{{-0.042341791011683, 
      5.138362430448799}, {-0.042341791011682964`, 
      5.138362430448799}, {-0.08468358202336598, 
      5.276724860897599}, {-0.08468358202336602, 
      5.276724860897599}, {-0.042341791011683, 5.138362430448799}}], 
     PolygonBox[{{-0.08468358202336602, 
      5.276724860897599}, {-0.08468358202336598, 
      5.276724860897599}, {-0.12702537303504902`, 
      5.415087291346398}, {-0.12702537303504902`, 
      5.415087291346398}, {-0.08468358202336602, 5.276724860897599}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.12702537303504904`, 4.584912708653602}, {
       0.08468358202336604, 4.723275139102401}, {0.04234179101168302, 
       4.861637569551201}, {1.566961042834566*^-17, 5.}, {-0.042341791011683, 
       5.138362430448799}, {-0.08468358202336602, 
       5.276724860897599}, {-0.12702537303504902`, 
       5.415087291346398}, {-0.12702537303504904`, 
       5.415087291346398}, {-0.08468358202336604, 
       5.276724860897599}, {-0.04234179101168302, 
       5.138362430448799}, {-1.566961042834566*^-17, 5.}, {0.042341791011683, 
       4.861637569551201}, {0.08468358202336602, 4.723275139102401}, {
       0.12702537303504902`, 4.584912708653602}, {0.12702537303504904`, 
       4.584912708653602}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{-0.43152816598930516`, 
        4.881395214396651}, {-0.43152816598930516`, 
        4.881395214396651}, {-0.2876854439928701, 
        4.9209301429311}, {-0.28768544399287016`, 
        4.9209301429311}, {-0.43152816598930516`, 4.881395214396651}}], 
       PolygonBox[{{-0.28768544399287016`, 
        4.9209301429311}, {-0.2876854439928701, 
        4.9209301429311}, {-0.1438427219964351, 
        4.96046507146555}, {-0.14384272199643508`, 
        4.96046507146555}, {-0.28768544399287016`, 4.9209301429311}}], 
       PolygonBox[{{-0.14384272199643508`, 
        4.96046507146555}, {-0.1438427219964351, 
        4.96046507146555}, {-1.14243062081692*^-16, 
        5.}, {-7.778060824893566*^-18, 5.}, {-0.14384272199643508`, 
        4.96046507146555}}], 
       PolygonBox[{{-7.778060824893566*^-18, 5.}, {-7.778060824893566*^-18, 
        5.}, {0.14384272199643502`, 5.03953492853445}, {0.14384272199643502`, 
        5.03953492853445}, {-7.778060824893566*^-18, 5.}}], 
       PolygonBox[{{0.14384272199643502`, 5.03953492853445}, {
        0.14384272199643502`, 5.03953492853445}, {0.28768544399287005`, 
        5.0790698570689}, {0.2876854439928701, 5.0790698570689}, {
        0.14384272199643502`, 5.03953492853445}}], 
       PolygonBox[{{0.2876854439928701, 5.0790698570689}, {
        0.28768544399287005`, 5.0790698570689}, {0.4315281659893051, 
        5.118604785603349}, {0.43152816598930505`, 5.118604785603349}, {
        0.2876854439928701, 5.0790698570689}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{-0.43152816598930516`, 
         4.881395214396651}, {-0.28768544399287016`, 
         4.9209301429311}, {-0.14384272199643508`, 
         4.96046507146555}, {-5.323250062839922*^-17, 5.}, {
         0.14384272199643502`, 5.03953492853445}, {0.2876854439928701, 
         5.0790698570689}, {0.43152816598930505`, 5.118604785603349}, {
         0.43152816598930516`, 5.118604785603349}, {0.28768544399287016`, 
         5.0790698570689}, {0.14384272199643508`, 5.03953492853445}, {
         5.323250062839922*^-17, 5.}, {-0.14384272199643502`, 
         4.96046507146555}, {-0.2876854439928701, 
         4.9209301429311}, {-0.43152816598930505`, 
         4.881395214396651}, {-0.43152816598930516`, 4.881395214396651}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-0.3045027929542561, 
      4.466307923050252}, {-0.5585535390243542, 5.296482505743049}, {
      0.3045027929542561, 5.533692076949748}, {0.5585535390243542, 
      4.703517494256951}, {-0.3045027929542561, 4.466307923050252}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.3045027929542561, 4.466307923050252}, {-0.5585535390243542,
        5.296482505743049}, {0.3045027929542561, 5.533692076949748}, {
       0.5585535390243542, 4.703517494256951}, {-0.3045027929542561, 
       4.466307923050252}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.8710067056590125, -5.415065653440038}, {
      0.8710067056590125, -5.415065653440038}, {
      0.9140044704393417, -5.276710435626692}, {
      0.9140044704393416, -5.276710435626692}, {
      0.8710067056590125, -5.415065653440038}}], 
     PolygonBox[{{0.9140044704393416, -5.276710435626692}, {
      0.9140044704393417, -5.276710435626692}, {
      0.9570022352196709, -5.138355217813346}, {
      0.9570022352196708, -5.138355217813346}, {
      0.9140044704393416, -5.276710435626692}}], 
     PolygonBox[{{0.9570022352196708, -5.138355217813346}, {
      0.9570022352196709, -5.138355217813346}, {1., -5.}, {1., -5.}, {
      0.9570022352196708, -5.138355217813346}}], 
     PolygonBox[{{1., -5.}, {1., -5.}, {
      1.0429977647803292`, -4.861644782186654}, {
      1.0429977647803292`, -4.861644782186654}, {1., -5.}}], 
     PolygonBox[{{1.0429977647803292`, -4.861644782186654}, {
      1.0429977647803292`, -4.861644782186654}, {
      1.0859955295606583`, -4.723289564373308}, {
      1.0859955295606583`, -4.723289564373308}, {
      1.0429977647803292`, -4.861644782186654}}], 
     PolygonBox[{{1.0859955295606583`, -4.723289564373308}, {
      1.0859955295606583`, -4.723289564373308}, {
      1.1289932943409875`, -4.584934346559963}, {
      1.1289932943409875`, -4.584934346559963}, {
      1.0859955295606583`, -4.723289564373308}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.8710067056590125, -5.415065653440038}, {
       0.9140044704393416, -5.276710435626692}, {
       0.9570022352196708, -5.138355217813346}, {1., -5.}, {
       1.0429977647803292`, -4.861644782186654}, {
       1.0859955295606583`, -4.723289564373308}, {
       1.1289932943409875`, -4.584934346559963}, {
       1.1289932943409875`, -4.584934346559962}, {
       1.0859955295606585`, -4.723289564373308}, {
       1.0429977647803292`, -4.861644782186654}, {1., -5.}, {
       0.9570022352196709, -5.138355217813346}, {
       0.9140044704393416, -5.276710435626692}, {
       0.8710067056590125, -5.415065653440037}, {
       0.8710067056590125, -5.415065653440038}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5696873477287563, -4.883461451229845}, {
        0.5696873477287563, -4.883461451229845}, {
        0.7131248984858376, -4.92230763415323}, {
        0.7131248984858376, -4.92230763415323}, {
        0.5696873477287563, -4.883461451229845}}], 
       PolygonBox[{{0.7131248984858376, -4.92230763415323}, {
        0.7131248984858376, -4.92230763415323}, {
        0.8565624492429187, -4.961153817076615}, {
        0.8565624492429188, -4.961153817076615}, {
        0.7131248984858376, -4.92230763415323}}], 
       PolygonBox[{{0.8565624492429188, -4.961153817076615}, {
        0.8565624492429187, -4.961153817076615}, {0.9999999999999999, -5.}, {
        1., -5.}, {0.8565624492429188, -4.961153817076615}}], 
       PolygonBox[{{1., -5.}, {1., -5.}, {
        1.143437550757081, -5.038846182923385}, {
        1.143437550757081, -5.038846182923385}, {1., -5.}}], 
       PolygonBox[{{1.143437550757081, -5.038846182923385}, {
        1.143437550757081, -5.038846182923385}, {
        1.2868751015141624`, -5.07769236584677}, {
        1.2868751015141624`, -5.07769236584677}, {
        1.143437550757081, -5.038846182923385}}], 
       PolygonBox[{{1.2868751015141624`, -5.07769236584677}, {
        1.2868751015141624`, -5.07769236584677}, {
        1.4303126522712435`, -5.116538548770155}, {
        1.4303126522712435`, -5.116538548770155}, {
        1.2868751015141624`, -5.07769236584677}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5696873477287563, -4.883461451229845}, {
         0.7131248984858376, -4.92230763415323}, {
         0.8565624492429188, -4.961153817076615}, {1., -5.}, {
         1.143437550757081, -5.038846182923385}, {
         1.2868751015141624`, -5.07769236584677}, {
         1.4303126522712435`, -5.116538548770155}, {
         1.4303126522712437`, -5.116538548770155}, {
         1.2868751015141624`, -5.07769236584677}, {
         1.1434375507570813`, -5.038846182923385}, {1., -5.}, {
         0.8565624492429188, -4.961153817076615}, {
         0.7131248984858376, -4.92230763415323}, {
         0.5696873477287565, -4.883461451229845}, {
         0.5696873477287563, -4.883461451229845}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.4406940533877688, -5.298527104669883}, {
      0.6986806420697439, -4.468395797789808}, {
      1.5593059466122312`, -4.701472895330117}, {
      1.301319357930256, -5.531604202210192}, {
      0.4406940533877688, -5.298527104669883}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.4406940533877688, -5.298527104669883}, {
       0.6986806420697439, -4.468395797789808}, {
       1.5593059466122312`, -4.701472895330117}, {
       1.301319357930256, -5.531604202210192}, {
       0.4406940533877688, -5.298527104669883}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.8944782759745522, -4.426419413851459}, {
      0.8944782759745523, -4.426419413851459}, {
      0.9296521839830348, -4.284279609234306}, {
      0.9296521839830347, -4.284279609234306}, {
      0.8944782759745522, -4.426419413851459}}], 
     PolygonBox[{{0.9296521839830347, -4.284279609234306}, {
      0.9296521839830348, -4.284279609234306}, {
      0.9648260919915175, -4.142139804617154}, {
      0.9648260919915174, -4.142139804617153}, {
      0.9296521839830347, -4.284279609234306}}], 
     PolygonBox[{{0.9648260919915174, -4.142139804617153}, {
      0.9648260919915175, -4.142139804617154}, {1., -4.}, {1., -4.}, {
      0.9648260919915174, -4.142139804617153}}], 
     PolygonBox[{{1., -4.}, {1., -4.}, {
      1.0351739080084825`, -3.857860195382847}, {
      1.0351739080084825`, -3.857860195382847}, {1., -4.}}], 
     PolygonBox[{{1.0351739080084825`, -3.857860195382847}, {
      1.0351739080084825`, -3.857860195382847}, {
      1.0703478160169653`, -3.7157203907656937`}, {
      1.0703478160169653`, -3.7157203907656937`}, {
      1.0351739080084825`, -3.857860195382847}}], 
     PolygonBox[{{1.0703478160169653`, -3.7157203907656937`}, {
      1.0703478160169653`, -3.7157203907656937`}, {
      1.1055217240254478`, -3.573580586148541}, {
      1.1055217240254478`, -3.573580586148541}, {
      1.0703478160169653`, -3.7157203907656937`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.8944782759745522, -4.426419413851459}, {
       0.9296521839830347, -4.284279609234306}, {
       0.9648260919915174, -4.142139804617153}, {1., -4.}, {
       1.0351739080084825`, -3.857860195382847}, {
       1.0703478160169653`, -3.7157203907656937`}, {
       1.1055217240254478`, -3.573580586148541}, {
       1.1055217240254478`, -3.573580586148541}, {
       1.0703478160169653`, -3.7157203907656937`}, {
       1.0351739080084825`, -3.857860195382847}, {1., -4.}, {
       0.9648260919915174, -4.142139804617153}, {
       0.9296521839830348, -4.284279609234306}, {
       0.8944782759745522, -4.426419413851459}, {
       0.8944782759745522, -4.426419413851459}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5631108008182854, -3.902369834327319}, {
        0.5631108008182854, -3.9023698343273185`}, {
        0.7087405338788568, -3.9349132228848793`}, {
        0.7087405338788568, -3.9349132228848793`}, {
        0.5631108008182854, -3.902369834327319}}], 
       PolygonBox[{{0.7087405338788568, -3.9349132228848793`}, {
        0.7087405338788568, -3.9349132228848793`}, {
        0.8543702669394284, -3.9674566114424397`}, {
        0.8543702669394284, -3.9674566114424397`}, {
        0.7087405338788568, -3.9349132228848793`}}], 
       PolygonBox[{{0.8543702669394284, -3.9674566114424397`}, {
        0.8543702669394284, -3.9674566114424397`}, {
        0.9999999999999999, -4.}, {1., -4.}, {
        0.8543702669394284, -3.9674566114424397`}}], 
       PolygonBox[{{1., -4.}, {1., -4.}, {
        1.1456297330605716`, -4.032543388557561}, {
        1.1456297330605716`, -4.032543388557561}, {1., -4.}}], 
       PolygonBox[{{1.1456297330605716`, -4.032543388557561}, {
        1.1456297330605716`, -4.032543388557561}, {
        1.2912594661211432`, -4.065086777115121}, {
        1.2912594661211432`, -4.065086777115121}, {
        1.1456297330605716`, -4.032543388557561}}], 
       PolygonBox[{{1.2912594661211432`, -4.065086777115121}, {
        1.2912594661211432`, -4.065086777115121}, {
        1.4368891991817145`, -4.0976301656726815`}, {
        1.4368891991817145`, -4.0976301656726815`}, {
        1.2912594661211432`, -4.065086777115121}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5631108008182854, -3.902369834327319}, {
         0.7087405338788568, -3.9349132228848793`}, {
         0.8543702669394284, -3.9674566114424397`}, {1., -4.}, {
         1.1456297330605716`, -4.032543388557561}, {
         1.2912594661211432`, -4.065086777115121}, {
         1.4368891991817145`, -4.0976301656726815`}, {
         1.4368891991817145`, -4.0976301656726815`}, {
         1.2912594661211432`, -4.065086777115121}, {
         1.1456297330605716`, -4.032543388557561}, {1., -4.}, {
         0.8543702669394284, -3.9674566114424397`}, {
         0.7087405338788568, -3.9349132228848793`}, {
         0.5631108008182855, -3.902369834327319}, {
         0.5631108008182854, -3.902369834327319}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.45758907679283756`, -4.328789248178778}, {
      0.6686325248437331, -3.4759504204758596`}, {
      1.5424109232071626`, -3.671210751821222}, {
      1.331367475156267, -4.52404957952414}, {
      0.45758907679283756`, -4.328789248178778}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.45758907679283756`, -4.328789248178778}, {
       0.6686325248437331, -3.4759504204758596`}, {
       1.5424109232071626`, -3.671210751821222}, {
       1.331367475156267, -4.52404957952414}, {
       0.45758907679283756`, -4.328789248178778}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.9194119258859308, -3.4361462361834545`}, {
      0.9194119258859309, -3.4361462361834545`}, {
      0.9462746172572873, -3.2907641574556363`}, {
      0.9462746172572872, -3.2907641574556363`}, {
      0.9194119258859308, -3.4361462361834545`}}], 
     PolygonBox[{{0.9462746172572872, -3.2907641574556363`}, {
      0.9462746172572873, -3.2907641574556363`}, {
      0.9731373086286437, -3.145382078727818}, {
      0.9731373086286436, -3.145382078727818}, {
      0.9462746172572872, -3.2907641574556363`}}], 
     PolygonBox[{{0.9731373086286436, -3.145382078727818}, {
      0.9731373086286437, -3.145382078727818}, {1., -3.}, {1., -3.}, {
      0.9731373086286436, -3.145382078727818}}], 
     PolygonBox[{{1., -3.}, {1., -3.}, {
      1.0268626913713563`, -2.854617921272182}, {
      1.0268626913713563`, -2.854617921272182}, {1., -3.}}], 
     PolygonBox[{{1.0268626913713563`, -2.854617921272182}, {
      1.0268626913713563`, -2.854617921272182}, {
      1.0537253827427129`, -2.7092358425443637`}, {
      1.0537253827427129`, -2.7092358425443637`}, {
      1.0268626913713563`, -2.854617921272182}}], 
     PolygonBox[{{1.0537253827427129`, -2.7092358425443637`}, {
      1.0537253827427129`, -2.7092358425443637`}, {
      1.0805880741140692`, -2.5638537638165455`}, {
      1.0805880741140692`, -2.563853763816546}, {
      1.0537253827427129`, -2.7092358425443637`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.9194119258859308, -3.4361462361834545`}, {
       0.9462746172572872, -3.2907641574556363`}, {
       0.9731373086286436, -3.145382078727818}, {1., -3.}, {
       1.0268626913713563`, -2.854617921272182}, {
       1.0537253827427129`, -2.7092358425443637`}, {
       1.0805880741140692`, -2.563853763816546}, {
       1.0805880741140692`, -2.5638537638165455`}, {
       1.0537253827427129`, -2.7092358425443637`}, {
       1.0268626913713563`, -2.854617921272182}, {1., -3.}, {
       0.9731373086286436, -3.145382078727818}, {
       0.9462746172572872, -3.2907641574556363`}, {
       0.9194119258859308, -3.436146236183454}, {
       0.9194119258859308, -3.4361462361834545`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5576735557045728, -2.923960385498139}, {
        0.5576735557045728, -2.9239603854981384`}, {
        0.7051157038030484, -2.949306923665426}, {
        0.7051157038030484, -2.949306923665426}, {
        0.5576735557045728, -2.923960385498139}}], 
       PolygonBox[{{0.7051157038030484, -2.949306923665426}, {
        0.7051157038030484, -2.949306923665426}, {
        0.8525578519015242, -2.974653461832713}, {
        0.8525578519015242, -2.974653461832713}, {
        0.7051157038030484, -2.949306923665426}}], 
       PolygonBox[{{0.8525578519015242, -2.974653461832713}, {
        0.8525578519015242, -2.974653461832713}, {0.9999999999999999, -3.}, {
        1., -3.}, {0.8525578519015242, -2.974653461832713}}], 
       PolygonBox[{{1., -3.}, {1., -3.}, {
        1.1474421480984758`, -3.025346538167287}, {
        1.1474421480984758`, -3.025346538167287}, {1., -3.}}], 
       PolygonBox[{{1.1474421480984758`, -3.025346538167287}, {
        1.1474421480984758`, -3.025346538167287}, {
        1.2948842961969516`, -3.050693076334574}, {
        1.2948842961969516`, -3.050693076334574}, {
        1.1474421480984758`, -3.025346538167287}}], 
       PolygonBox[{{1.2948842961969516`, -3.050693076334574}, {
        1.2948842961969516`, -3.050693076334574}, {
        1.4423264442954271`, -3.076039614501861}, {
        1.4423264442954271`, -3.076039614501861}, {
        1.2948842961969516`, -3.050693076334574}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5576735557045728, -2.923960385498139}, {
         0.7051157038030484, -2.949306923665426}, {
         0.8525578519015242, -2.974653461832713}, {1., -3.}, {
         1.1474421480984758`, -3.025346538167287}, {
         1.2948842961969516`, -3.050693076334574}, {
         1.4423264442954271`, -3.076039614501861}, {
         1.4423264442954271`, -3.076039614501861}, {
         1.2948842961969516`, -3.050693076334574}, {
         1.1474421480984758`, -3.025346538167287}, {1., -3.}, {
         0.8525578519015242, -2.974653461832713}, {
         0.7051157038030484, -2.949306923665426}, {
         0.5576735557045729, -2.923960385498139}, {
         0.5576735557045728, -2.923960385498139}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.47708548159050357`, -3.360106621681593}, {
      0.638261629818642, -2.4878141493146844`}, {
      1.5229145184094963`, -2.639893378318407}, {
      1.361738370181358, -3.5121858506853156`}, {
      0.47708548159050357`, -3.360106621681593}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.47708548159050357`, -3.360106621681593}, {
       0.638261629818642, -2.4878141493146844`}, {
       1.5229145184094963`, -2.639893378318407}, {
       1.361738370181358, -3.5121858506853156`}, {
       0.47708548159050357`, -3.360106621681593}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.9455506413883192, -2.4436407387825065`}, {
      0.9455506413883193, -2.4436407387825065`}, {
      0.9637004275922129, -2.295760492521671}, {
      0.9637004275922127, -2.295760492521671}, {
      0.9455506413883192, -2.4436407387825065`}}], 
     PolygonBox[{{0.9637004275922127, -2.295760492521671}, {
      0.9637004275922129, -2.295760492521671}, {
      0.9818502137961065, -2.1478802462608355`}, {
      0.9818502137961064, -2.1478802462608355`}, {
      0.9637004275922127, -2.295760492521671}}], 
     PolygonBox[{{0.9818502137961064, -2.1478802462608355`}, {
      0.9818502137961065, -2.1478802462608355`}, {1., -2.}, {1., -2.}, {
      0.9818502137961064, -2.1478802462608355`}}], 
     PolygonBox[{{1., -2.}, {1., -2.}, {
      1.0181497862038937`, -1.8521197537391645`}, {
      1.0181497862038935`, -1.8521197537391645`}, {1., -2.}}], 
     PolygonBox[{{1.0181497862038935`, -1.8521197537391645`}, {
      1.0181497862038937`, -1.8521197537391645`}, {
      1.0362995724077873`, -1.7042395074783292`}, {
      1.0362995724077873`, -1.7042395074783292`}, {
      1.0181497862038935`, -1.8521197537391645`}}], 
     PolygonBox[{{1.0362995724077873`, -1.7042395074783292`}, {
      1.0362995724077873`, -1.7042395074783292`}, {
      1.0544493586116808`, -1.5563592612174937`}, {
      1.0544493586116808`, -1.556359261217494}, {
      1.0362995724077873`, -1.7042395074783292`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.9455506413883192, -2.4436407387825065`}, {
       0.9637004275922127, -2.295760492521671}, {
       0.9818502137961064, -2.1478802462608355`}, {1., -2.}, {
       1.0181497862038935`, -1.8521197537391645`}, {
       1.0362995724077873`, -1.7042395074783292`}, {
       1.0544493586116808`, -1.556359261217494}, {
       1.0544493586116808`, -1.5563592612174937`}, {
       1.0362995724077873`, -1.704239507478329}, {
       1.0181497862038935`, -1.8521197537391645`}, {1., -2.}, {
       0.9818502137961064, -2.1478802462608355`}, {
       0.9637004275922127, -2.295760492521671}, {
       0.9455506413883192, -2.443640738782506}, {
       0.9455506413883192, -2.4436407387825065`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5536004058587259, -1.9478640024619405`}, {
        0.5536004058587259, -1.9478640024619405`}, {
        0.7024002705724839, -1.9652426683079602`}, {
        0.7024002705724839, -1.9652426683079602`}, {
        0.5536004058587259, -1.9478640024619405`}}], 
       PolygonBox[{{0.7024002705724839, -1.9652426683079602`}, {
        0.7024002705724839, -1.9652426683079602`}, {
        0.8512001352862419, -1.9826213341539802`}, {
        0.8512001352862419, -1.9826213341539802`}, {
        0.7024002705724839, -1.9652426683079602`}}], 
       PolygonBox[{{0.8512001352862419, -1.9826213341539802`}, {
        0.8512001352862419, -1.9826213341539802`}, {
        0.9999999999999999, -2.}, {1., -2.}, {
        0.8512001352862419, -1.9826213341539802`}}], 
       PolygonBox[{{1., -2.}, {1., -2.}, {
        1.148799864713758, -2.01737866584602}, {
        1.148799864713758, -2.01737866584602}, {1., -2.}}], 
       PolygonBox[{{1.148799864713758, -2.01737866584602}, {
        1.148799864713758, -2.01737866584602}, {
        1.2975997294275161`, -2.0347573316920395`}, {
        1.2975997294275161`, -2.0347573316920395`}, {
        1.148799864713758, -2.01737866584602}}], 
       PolygonBox[{{1.2975997294275161`, -2.0347573316920395`}, {
        1.2975997294275161`, -2.0347573316920395`}, {
        1.446399594141274, -2.0521359975380595`}, {
        1.446399594141274, -2.0521359975380595`}, {
        1.2975997294275161`, -2.0347573316920395`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5536004058587259, -1.9478640024619405`}, {
         0.7024002705724839, -1.9652426683079602`}, {
         0.8512001352862419, -1.9826213341539802`}, {1., -2.}, {
         1.148799864713758, -2.01737866584602}, {
         1.2975997294275161`, -2.0347573316920395`}, {
         1.446399594141274, -2.0521359975380595`}, {
         1.446399594141274, -2.0521359975380595`}, {
         1.2975997294275161`, -2.0347573316920395`}, {
         1.148799864713758, -2.01737866584602}, {1., -2.}, {
         0.8512001352862419, -1.9826213341539802`}, {
         0.7024002705724839, -1.9652426683079602`}, {
         0.553600405858726, -1.9478640024619405`}, {
         0.5536004058587259, -1.9478640024619405`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.4991510472470452, -2.391504741244447}, {
      0.6080497644704068, -1.5042232636794342`}, {
      1.5008489527529547`, -1.6084952587555532`}, {
      1.3919502355295932`, -2.4957767363205656`}, {
      0.4991510472470452, -2.391504741244447}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.4991510472470452, -2.391504741244447}, {
       0.6080497644704068, -1.5042232636794342`}, {
       1.5008489527529547`, -1.6084952587555532`}, {
       1.3919502355295932`, -2.4957767363205656`}, {
       0.4991510472470452, -2.391504741244447}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.9725506200210112, -1.4483782490010226`}, {
      0.9725506200210114, -1.4483782490010226`}, {
      0.9817004133473409, -1.2989188326673484`}, {
      0.9817004133473408, -1.2989188326673484`}, {
      0.9725506200210112, -1.4483782490010226`}}], 
     PolygonBox[{{0.9817004133473408, -1.2989188326673484`}, {
      0.9817004133473409, -1.2989188326673484`}, {
      0.9908502066736705, -1.1494594163336742`}, {
      0.9908502066736704, -1.1494594163336742`}, {
      0.9817004133473408, -1.2989188326673484`}}], 
     PolygonBox[{{0.9908502066736704, -1.1494594163336742`}, {
      0.9908502066736705, -1.1494594163336742`}, {1., -1.0000000000000002`}, {
      1., -1.}, {0.9908502066736704, -1.1494594163336742`}}], 
     PolygonBox[{{1., -1.}, {1., -1.}, {
      1.0091497933263296`, -0.8505405836663258}, {
      1.0091497933263296`, -0.8505405836663258}, {1., -1.}}], 
     PolygonBox[{{1.0091497933263296`, -0.8505405836663258}, {
      1.0091497933263296`, -0.8505405836663258}, {
      1.0182995866526592`, -0.7010811673326517}, {
      1.0182995866526592`, -0.7010811673326516}, {
      1.0091497933263296`, -0.8505405836663258}}], 
     PolygonBox[{{1.0182995866526592`, -0.7010811673326516}, {
      1.0182995866526592`, -0.7010811673326517}, {
      1.0274493799789888`, -0.5516217509989775}, {
      1.0274493799789888`, -0.5516217509989776}, {
      1.0182995866526592`, -0.7010811673326516}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.9725506200210112, -1.4483782490010226`}, {
       0.9817004133473408, -1.2989188326673484`}, {
       0.9908502066736704, -1.1494594163336742`}, {1., -1.}, {
       1.0091497933263296`, -0.8505405836663258}, {
       1.0182995866526592`, -0.7010811673326516}, {
       1.0274493799789888`, -0.5516217509989776}, {
       1.0274493799789888`, -0.5516217509989774}, {
       1.0182995866526592`, -0.7010811673326516}, {
       1.0091497933263296`, -0.8505405836663258}, {1., -1.}, {
       0.9908502066736704, -1.1494594163336742`}, {
       0.9817004133473408, -1.2989188326673484`}, {
       0.9725506200210113, -1.4483782490010224`}, {
       0.9725506200210112, -1.4483782490010226`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5510753755114947, -0.9734768523446755}, {
        0.5510753755114947, -0.9734768523446754}, {
        0.700716917007663, -0.9823179015631169}, {
        0.700716917007663, -0.9823179015631169}, {
        0.5510753755114947, -0.9734768523446755}}], 
       PolygonBox[{{0.700716917007663, -0.9823179015631169}, {
        0.700716917007663, -0.9823179015631169}, {
        0.8503584585038315, -0.9911589507815585}, {
        0.8503584585038315, -0.9911589507815585}, {
        0.700716917007663, -0.9823179015631169}}], 
       PolygonBox[{{0.8503584585038315, -0.9911589507815585}, {
        0.8503584585038315, -0.9911589507815585}, {0.9999999999999999, -1.}, {
        1., -1.}, {0.8503584585038315, -0.9911589507815585}}], 
       PolygonBox[{{1., -1.}, {1., -1.}, {
        1.1496415414961685`, -1.0088410492184414`}, {
        1.1496415414961685`, -1.0088410492184414`}, {1., -1.}}], 
       PolygonBox[{{1.1496415414961685`, -1.0088410492184414`}, {
        1.1496415414961685`, -1.0088410492184414`}, {
        1.299283082992337, -1.017682098436883}, {
        1.299283082992337, -1.017682098436883}, {
        1.1496415414961685`, -1.0088410492184414`}}], 
       PolygonBox[{{1.299283082992337, -1.017682098436883}, {
        1.299283082992337, -1.017682098436883}, {
        1.4489246244885052`, -1.0265231476553245`}, {
        1.4489246244885052`, -1.0265231476553245`}, {
        1.299283082992337, -1.017682098436883}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5510753755114947, -0.9734768523446755}, {
         0.700716917007663, -0.982317901563117}, {
         0.8503584585038315, -0.9911589507815585}, {1., -1.}, {
         1.1496415414961685`, -1.0088410492184414`}, {
         1.299283082992337, -1.017682098436883}, {
         1.4489246244885052`, -1.0265231476553245`}, {
         1.4489246244885052`, -1.0265231476553245`}, {
         1.299283082992337, -1.017682098436883}, {
         1.1496415414961685`, -1.0088410492184414`}, {1., -1.}, {
         0.8503584585038315, -0.9911589507815585}, {
         0.700716917007663, -0.982317901563117}, {
         0.5510753755114948, -0.9734768523446755}, {
         0.5510753755114947, -0.9734768523446755}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.523625995532506, -1.4218551013456981`}, {
      0.5785247554904833, -0.5250986033436529}, {
      1.476374004467494, -0.5781448986543019}, {
      1.4214752445095167`, -1.4749013966563471`}, {
      0.523625995532506, -1.4218551013456981`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.523625995532506, -1.4218551013456981`}, {
       0.5785247554904833, -0.5250986033436529}, {
       1.476374004467494, -0.5781448986543019}, {
       1.4214752445095167`, -1.4749013966563471`}, {
       0.523625995532506, -1.4218551013456981`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1., -0.45}, {1., -0.45}, {1., -0.3}, {
      1., -0.30000000000000004`}, {1., -0.45}}], 
     PolygonBox[{{1., -0.30000000000000004`}, {1., -0.3}, {
      1., -0.15000000000000008`}, {1., -0.15000000000000002`}, {
      1., -0.30000000000000004`}}], 
     PolygonBox[{{1., -0.15000000000000002`}, {1., -0.15000000000000008`}, {
      1., -1.1102230246251565`*^-16}, {1., 0.}, {1., -0.15000000000000002`}}],
      PolygonBox[{{1., 0.}, {1., 0.}, {1., 0.14999999999999997`}, {1., 
      0.14999999999999997`}, {1., 0.}}], 
     PolygonBox[{{1., 0.14999999999999997`}, {1., 0.14999999999999997`}, {1., 
      0.29999999999999993`}, {1., 0.3}, {1., 0.14999999999999997`}}], 
     PolygonBox[{{1., 0.3}, {1., 0.29999999999999993`}, {1., 
      0.44999999999999996`}, {1., 0.4499999999999999}, {1., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1., -0.45}, {1., -0.30000000000000004`}, {
       1., -0.15000000000000002`}, {1., -5.551115123125783*^-17}, {1., 
       0.14999999999999997`}, {1., 0.3}, {1., 0.4499999999999999}, {1., 
       0.45}, {1., 0.30000000000000004`}, {1., 0.15000000000000002`}, {1., 
       5.551115123125783*^-17}, {1., -0.14999999999999997`}, {1., -0.3}, {
       1., -0.4499999999999999}, {1., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5502195943040942, 0.}, {0.5502195943040942, 
        5.5109105961630896`*^-17}, {0.7001463962027294, 
        4.592425496802574*^-17}, {0.7001463962027294, 
        9.184850993605149*^-18}, {0.5502195943040942, 0.}}], 
       PolygonBox[{{0.7001463962027294, 9.184850993605149*^-18}, {
        0.7001463962027294, 4.592425496802574*^-17}, {0.8500731981013646, 
        3.67394039744206*^-17}, {0.8500731981013647, 
        1.8369701987210297`*^-17}, {0.7001463962027294, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{0.8500731981013647, 1.8369701987210297`*^-17}, {
        0.8500731981013646, 3.67394039744206*^-17}, {0.9999999999999999, 
        2.7554552980815454`*^-17}, {1., 2.7554552980815448`*^-17}, {
        0.8500731981013647, 1.8369701987210297`*^-17}}], 
       PolygonBox[{{1., 2.7554552980815448`*^-17}, {1., 
        2.7554552980815448`*^-17}, {1.1499268018986353`, 
        1.83697019872103*^-17}, {1.1499268018986353`, 
        3.6739403974420595`*^-17}, {1., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{1.1499268018986353`, 3.6739403974420595`*^-17}, {
        1.1499268018986353`, 1.83697019872103*^-17}, {1.2998536037972706`, 
        9.184850993605152*^-18}, {1.2998536037972706`, 
        4.592425496802574*^-17}, {1.1499268018986353`, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{1.2998536037972706`, 4.592425496802574*^-17}, {
        1.2998536037972706`, 9.184850993605153*^-18}, {1.4497804056959058`, 
        4.5887548728832574`*^-33}, {1.4497804056959058`, 
        5.510910596163089*^-17}, {1.2998536037972706`, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5502195943040942, 0.}, {0.7001463962027294, 0.}, {
         0.8500731981013647, 0.}, {1., 0.}, {1.1499268018986353`, 0.}, {
         1.2998536037972706`, 0.}, {1.4497804056959058`, 0.}, {
         1.4497804056959058`, 0.}, {1.2998536037972706`, 0.}, {
         1.1499268018986353`, 0.}, {1., 0.}, {0.8500731981013647, 0.}, {
         0.7001463962027294, 0.}, {0.5502195943040943, 0.}, {
         0.5502195943040942, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.5502195943040942, -0.45}, {0.5502195943040942, 0.45}, {
      1.4497804056959058`, 0.45}, {1.4497804056959058`, -0.45}, {
      0.5502195943040942, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5502195943040942, -0.45}, {0.5502195943040942, 0.45}, {
       1.4497804056959058`, 0.45}, {1.4497804056959058`, -0.45}, {
       0.5502195943040942, -0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.0274493799789888`, 0.5516217509989774}, {
      1.0274493799789888`, 0.5516217509989774}, {1.0182995866526592`, 
      0.7010811673326516}, {1.0182995866526592`, 0.7010811673326516}, {
      1.0274493799789888`, 0.5516217509989774}}], 
     PolygonBox[{{1.0182995866526592`, 0.7010811673326516}, {
      1.0182995866526592`, 0.7010811673326516}, {1.0091497933263296`, 
      0.8505405836663258}, {1.0091497933263296`, 0.8505405836663258}, {
      1.0182995866526592`, 0.7010811673326516}}], 
     PolygonBox[{{1.0091497933263296`, 0.8505405836663258}, {
      1.0091497933263296`, 0.8505405836663258}, {1., 0.9999999999999999}, {1.,
       1.}, {1.0091497933263296`, 0.8505405836663258}}], 
     PolygonBox[{{1., 1.}, {1., 1.}, {0.9908502066736705, 
      1.1494594163336742`}, {0.9908502066736704, 1.1494594163336742`}, {1., 
      1.}}], PolygonBox[{{0.9908502066736704, 1.1494594163336742`}, {
      0.9908502066736705, 1.1494594163336742`}, {0.9817004133473409, 
      1.2989188326673484`}, {0.9817004133473408, 1.2989188326673484`}, {
      0.9908502066736704, 1.1494594163336742`}}], 
     PolygonBox[{{0.9817004133473408, 1.2989188326673484`}, {
      0.9817004133473409, 1.2989188326673484`}, {0.9725506200210113, 
      1.4483782490010224`}, {0.9725506200210113, 1.4483782490010224`}, {
      0.9817004133473408, 1.2989188326673484`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.0274493799789888`, 0.5516217509989774}, {
       1.0182995866526592`, 0.7010811673326516}, {1.0091497933263296`, 
       0.8505405836663258}, {1., 1.}, {0.9908502066736704, 
       1.1494594163336742`}, {0.9817004133473408, 1.2989188326673484`}, {
       0.9725506200210113, 1.4483782490010224`}, {0.9725506200210112, 
       1.4483782490010226`}, {0.9817004133473408, 1.2989188326673484`}, {
       0.9908502066736704, 1.1494594163336742`}, {1., 1.}, {
       1.0091497933263296`, 0.8505405836663258}, {1.0182995866526592`, 
       0.7010811673326516}, {1.0274493799789888`, 0.5516217509989776}, {
       1.0274493799789888`, 0.5516217509989774}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5510753755114947, 0.9734768523446755}, {
        0.5510753755114947, 0.9734768523446755}, {0.700716917007663, 
        0.982317901563117}, {0.700716917007663, 0.982317901563117}, {
        0.5510753755114947, 0.9734768523446755}}], 
       PolygonBox[{{0.700716917007663, 0.982317901563117}, {0.700716917007663,
         0.982317901563117}, {0.8503584585038315, 0.9911589507815586}, {
        0.8503584585038315, 0.9911589507815585}, {0.700716917007663, 
        0.982317901563117}}], 
       PolygonBox[{{0.8503584585038315, 0.9911589507815585}, {
        0.8503584585038315, 0.9911589507815586}, {0.9999999999999999, 1.}, {
        1., 1.}, {0.8503584585038315, 0.9911589507815585}}], 
       PolygonBox[{{1., 1.}, {1., 1.}, {1.1496415414961685`, 
        1.0088410492184414`}, {1.1496415414961685`, 1.0088410492184416`}, {1.,
         1.}}], PolygonBox[{{1.1496415414961685`, 1.0088410492184416`}, {
        1.1496415414961685`, 1.0088410492184414`}, {1.299283082992337, 
        1.017682098436883}, {1.299283082992337, 1.017682098436883}, {
        1.1496415414961685`, 1.0088410492184416`}}], 
       PolygonBox[{{1.299283082992337, 1.017682098436883}, {1.299283082992337,
         1.017682098436883}, {1.4489246244885052`, 1.0265231476553245`}, {
        1.4489246244885052`, 1.0265231476553245`}, {1.299283082992337, 
        1.017682098436883}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5510753755114947, 0.9734768523446755}, {0.700716917007663,
          0.982317901563117}, {0.8503584585038315, 0.9911589507815585}, {1., 
         1.}, {1.1496415414961685`, 1.0088410492184414`}, {1.299283082992337, 
         1.017682098436883}, {1.4489246244885052`, 1.0265231476553245`}, {
         1.4489246244885052`, 1.0265231476553245`}, {1.299283082992337, 
         1.017682098436883}, {1.1496415414961685`, 1.0088410492184414`}, {1., 
         1.}, {0.8503584585038315, 0.9911589507815585}, {0.700716917007663, 
         0.982317901563117}, {0.5510753755114948, 0.9734768523446755}, {
         0.5510753755114947, 0.9734768523446755}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.5785247554904833, 0.5250986033436529}, {0.523625995532506,
       1.4218551013456981`}, {1.4214752445095167`, 1.4749013966563471`}, {
      1.476374004467494, 0.5781448986543019}, {0.5785247554904833, 
      0.5250986033436529}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5785247554904833, 0.5250986033436529}, {0.523625995532506, 
       1.4218551013456981`}, {1.4214752445095167`, 1.4749013966563471`}, {
       1.476374004467494, 0.5781448986543019}, {0.5785247554904833, 
       0.5250986033436529}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.0544493586116808`, 1.5563592612174937`}, {
      1.054449358611681, 1.5563592612174937`}, {1.0362995724077873`, 
      1.7042395074783292`}, {1.0362995724077873`, 1.704239507478329}, {
      1.0544493586116808`, 1.5563592612174937`}}], 
     PolygonBox[{{1.0362995724077873`, 1.704239507478329}, {
      1.0362995724077873`, 1.7042395074783292`}, {1.0181497862038937`, 
      1.8521197537391645`}, {1.0181497862038935`, 1.8521197537391645`}, {
      1.0362995724077873`, 1.704239507478329}}], 
     PolygonBox[{{1.0181497862038935`, 1.8521197537391645`}, {
      1.0181497862038937`, 1.8521197537391645`}, {1., 2.}, {1., 2.}, {
      1.0181497862038935`, 1.8521197537391645`}}], 
     PolygonBox[{{1., 2.}, {1., 2.}, {0.9818502137961065, 
      2.1478802462608355`}, {0.9818502137961064, 2.1478802462608355`}, {1., 
      2.}}], PolygonBox[{{0.9818502137961064, 2.1478802462608355`}, {
      0.9818502137961065, 2.1478802462608355`}, {0.9637004275922129, 
      2.295760492521671}, {0.9637004275922127, 2.295760492521671}, {
      0.9818502137961064, 2.1478802462608355`}}], 
     PolygonBox[{{0.9637004275922127, 2.295760492521671}, {0.9637004275922129,
       2.295760492521671}, {0.9455506413883192, 2.443640738782506}, {
      0.9455506413883192, 2.443640738782506}, {0.9637004275922127, 
      2.295760492521671}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.0544493586116808`, 1.5563592612174937`}, {
       1.0362995724077873`, 1.704239507478329}, {1.0181497862038935`, 
       1.8521197537391645`}, {1., 2.}, {0.9818502137961064, 
       2.1478802462608355`}, {0.9637004275922127, 2.295760492521671}, {
       0.9455506413883192, 2.443640738782506}, {0.9455506413883192, 
       2.4436407387825065`}, {0.9637004275922127, 2.295760492521671}, {
       0.9818502137961064, 2.1478802462608355`}, {1., 2.}, {
       1.0181497862038935`, 1.8521197537391645`}, {1.0362995724077873`, 
       1.7042395074783292`}, {1.0544493586116808`, 1.556359261217494}, {
       1.0544493586116808`, 1.5563592612174937`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5536004058587259, 1.9478640024619405`}, {
        0.5536004058587259, 1.9478640024619405`}, {0.7024002705724839, 
        1.9652426683079605`}, {0.7024002705724839, 1.9652426683079602`}, {
        0.5536004058587259, 1.9478640024619405`}}], 
       PolygonBox[{{0.7024002705724839, 1.9652426683079602`}, {
        0.7024002705724839, 1.9652426683079605`}, {0.8512001352862419, 
        1.9826213341539802`}, {0.8512001352862419, 1.9826213341539802`}, {
        0.7024002705724839, 1.9652426683079602`}}], 
       PolygonBox[{{0.8512001352862419, 1.9826213341539802`}, {
        0.8512001352862419, 1.9826213341539802`}, {0.9999999999999999, 2.}, {
        1., 2.}, {0.8512001352862419, 1.9826213341539802`}}], 
       PolygonBox[{{1., 2.}, {1., 2.}, {1.148799864713758, 
        2.01737866584602}, {1.148799864713758, 2.01737866584602}, {1., 2.}}], 
       PolygonBox[{{1.148799864713758, 2.01737866584602}, {1.148799864713758, 
        2.01737866584602}, {1.2975997294275161`, 2.0347573316920395`}, {
        1.2975997294275161`, 2.0347573316920395`}, {1.148799864713758, 
        2.01737866584602}}], 
       PolygonBox[{{1.2975997294275161`, 2.0347573316920395`}, {
        1.2975997294275161`, 2.0347573316920395`}, {1.446399594141274, 
        2.0521359975380595`}, {1.446399594141274, 2.0521359975380595`}, {
        1.2975997294275161`, 2.0347573316920395`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5536004058587259, 1.9478640024619405`}, {
         0.7024002705724839, 1.9652426683079602`}, {0.8512001352862419, 
         1.9826213341539802`}, {1., 2.}, {1.148799864713758, 
         2.01737866584602}, {1.2975997294275161`, 2.0347573316920395`}, {
         1.446399594141274, 2.0521359975380595`}, {1.446399594141274, 
         2.0521359975380595`}, {1.2975997294275161`, 2.0347573316920395`}, {
         1.148799864713758, 2.01737866584602}, {1., 2.}, {0.8512001352862419, 
         1.9826213341539802`}, {0.7024002705724839, 1.9652426683079602`}, {
         0.553600405858726, 1.9478640024619405`}, {0.5536004058587259, 
         1.9478640024619405`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.6080497644704068, 1.5042232636794342`}, {
      0.4991510472470452, 2.391504741244447}, {1.3919502355295932`, 
      2.4957767363205656`}, {1.5008489527529547`, 1.6084952587555532`}, {
      0.6080497644704068, 1.5042232636794342`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.6080497644704068, 1.5042232636794342`}, {0.4991510472470452,
        2.391504741244447}, {1.3919502355295932`, 2.4957767363205656`}, {
       1.5008489527529547`, 1.6084952587555532`}, {0.6080497644704068, 
       1.5042232636794342`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.0805880741140692`, 2.5638537638165455`}, {
      1.0805880741140692`, 2.5638537638165455`}, {1.0537253827427129`, 
      2.7092358425443637`}, {1.0537253827427129`, 2.7092358425443637`}, {
      1.0805880741140692`, 2.5638537638165455`}}], 
     PolygonBox[{{1.0537253827427129`, 2.7092358425443637`}, {
      1.0537253827427129`, 2.7092358425443637`}, {1.0268626913713566`, 
      2.854617921272182}, {1.0268626913713563`, 2.854617921272182}, {
      1.0537253827427129`, 2.7092358425443637`}}], 
     PolygonBox[{{1.0268626913713563`, 2.854617921272182}, {
      1.0268626913713566`, 2.854617921272182}, {1., 3.}, {1., 3.}, {
      1.0268626913713563`, 2.854617921272182}}], 
     PolygonBox[{{1., 3.}, {1., 3.}, {0.9731373086286437, 
      3.145382078727818}, {0.9731373086286436, 3.145382078727818}, {1., 3.}}],
      PolygonBox[{{0.9731373086286436, 3.145382078727818}, {
      0.9731373086286437, 3.145382078727818}, {0.9462746172572872, 
      3.2907641574556363`}, {0.9462746172572872, 3.2907641574556363`}, {
      0.9731373086286436, 3.145382078727818}}], 
     PolygonBox[{{0.9462746172572872, 3.2907641574556363`}, {
      0.9462746172572872, 3.2907641574556363`}, {0.9194119258859308, 
      3.4361462361834545`}, {0.9194119258859308, 3.436146236183454}, {
      0.9462746172572872, 3.2907641574556363`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.0805880741140692`, 2.5638537638165455`}, {
       1.0537253827427129`, 2.7092358425443637`}, {1.0268626913713563`, 
       2.854617921272182}, {1., 3.}, {0.9731373086286436, 
       3.145382078727818}, {0.9462746172572872, 3.2907641574556363`}, {
       0.9194119258859308, 3.436146236183454}, {0.9194119258859308, 
       3.4361462361834545`}, {0.9462746172572872, 3.2907641574556363`}, {
       0.9731373086286436, 3.145382078727818}, {1., 3.}, {1.0268626913713563`,
        2.854617921272182}, {1.0537253827427129`, 2.7092358425443637`}, {
       1.0805880741140692`, 2.563853763816546}, {1.0805880741140692`, 
       2.5638537638165455`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5576735557045728, 2.923960385498139}, {
        0.5576735557045728, 2.923960385498139}, {0.7051157038030484, 
        2.949306923665426}, {0.7051157038030484, 2.949306923665426}, {
        0.5576735557045728, 2.923960385498139}}], 
       PolygonBox[{{0.7051157038030484, 2.949306923665426}, {
        0.7051157038030484, 2.949306923665426}, {0.8525578519015242, 
        2.974653461832713}, {0.8525578519015242, 2.974653461832713}, {
        0.7051157038030484, 2.949306923665426}}], 
       PolygonBox[{{0.8525578519015242, 2.974653461832713}, {
        0.8525578519015242, 2.974653461832713}, {0.9999999999999999, 3.}, {1.,
         3.}, {0.8525578519015242, 2.974653461832713}}], 
       PolygonBox[{{1., 3.}, {1., 3.}, {1.1474421480984758`, 
        3.025346538167287}, {1.1474421480984758`, 3.025346538167287}, {1., 
        3.}}], PolygonBox[{{1.1474421480984758`, 3.025346538167287}, {
        1.1474421480984758`, 3.025346538167287}, {1.2948842961969516`, 
        3.050693076334574}, {1.2948842961969516`, 3.050693076334574}, {
        1.1474421480984758`, 3.025346538167287}}], 
       PolygonBox[{{1.2948842961969516`, 3.050693076334574}, {
        1.2948842961969516`, 3.050693076334574}, {1.4423264442954271`, 
        3.076039614501861}, {1.4423264442954271`, 3.0760396145018616`}, {
        1.2948842961969516`, 3.050693076334574}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5576735557045728, 2.923960385498139}, {0.7051157038030484,
          2.949306923665426}, {0.8525578519015242, 2.974653461832713}, {1., 
         3.}, {1.1474421480984758`, 3.025346538167287}, {1.2948842961969516`, 
         3.050693076334574}, {1.4423264442954271`, 3.076039614501861}, {
         1.4423264442954271`, 3.076039614501861}, {1.2948842961969516`, 
         3.050693076334574}, {1.1474421480984758`, 3.025346538167287}, {1., 
         3.}, {0.8525578519015242, 2.974653461832713}, {0.7051157038030484, 
         2.949306923665426}, {0.5576735557045729, 2.923960385498139}, {
         0.5576735557045728, 2.923960385498139}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.638261629818642, 2.4878141493146844`}, {
      0.47708548159050357`, 3.360106621681593}, {1.361738370181358, 
      3.5121858506853156`}, {1.5229145184094963`, 2.639893378318407}, {
      0.638261629818642, 2.4878141493146844`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.638261629818642, 2.4878141493146844`}, {
       0.47708548159050357`, 3.360106621681593}, {1.361738370181358, 
       3.5121858506853156`}, {1.5229145184094963`, 2.639893378318407}, {
       0.638261629818642, 2.4878141493146844`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.1055217240254478`, 3.573580586148541}, {1.105521724025448,
       3.573580586148541}, {1.0703478160169653`, 3.7157203907656937`}, {
      1.0703478160169653`, 3.7157203907656937`}, {1.1055217240254478`, 
      3.573580586148541}}], 
     PolygonBox[{{1.0703478160169653`, 3.7157203907656937`}, {
      1.0703478160169653`, 3.7157203907656937`}, {1.0351739080084827`, 
      3.857860195382847}, {1.0351739080084825`, 3.857860195382847}, {
      1.0703478160169653`, 3.7157203907656937`}}], 
     PolygonBox[{{1.0351739080084825`, 3.857860195382847}, {
      1.0351739080084827`, 3.857860195382847}, {1., 4.}, {1., 4.}, {
      1.0351739080084825`, 3.857860195382847}}], 
     PolygonBox[{{1., 4.}, {1., 4.}, {0.9648260919915175, 
      4.142139804617153}, {0.9648260919915174, 4.142139804617153}, {1., 4.}}],
      PolygonBox[{{0.9648260919915174, 4.142139804617153}, {
      0.9648260919915175, 4.142139804617153}, {0.9296521839830348, 
      4.284279609234306}, {0.9296521839830348, 4.284279609234306}, {
      0.9648260919915174, 4.142139804617153}}], 
     PolygonBox[{{0.9296521839830348, 4.284279609234306}, {0.9296521839830348,
       4.284279609234306}, {0.8944782759745522, 4.426419413851459}, {
      0.8944782759745522, 4.426419413851459}, {0.9296521839830348, 
      4.284279609234306}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.1055217240254478`, 3.573580586148541}, {1.0703478160169653`,
        3.7157203907656937`}, {1.0351739080084825`, 3.857860195382847}, {1., 
       4.}, {0.9648260919915174, 4.142139804617153}, {0.9296521839830348, 
       4.284279609234306}, {0.8944782759745522, 4.426419413851459}, {
       0.8944782759745522, 4.426419413851459}, {0.9296521839830347, 
       4.284279609234306}, {0.9648260919915174, 4.142139804617153}, {1., 
       4.}, {1.0351739080084825`, 3.857860195382847}, {1.0703478160169653`, 
       3.7157203907656937`}, {1.1055217240254478`, 3.573580586148541}, {
       1.1055217240254478`, 3.573580586148541}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5631108008182854, 3.902369834327319}, {
        0.5631108008182854, 3.902369834327319}, {0.7087405338788568, 
        3.9349132228848793`}, {0.7087405338788568, 3.9349132228848793`}, {
        0.5631108008182854, 3.902369834327319}}], 
       PolygonBox[{{0.7087405338788568, 3.9349132228848793`}, {
        0.7087405338788568, 3.9349132228848793`}, {0.8543702669394284, 
        3.9674566114424397`}, {0.8543702669394284, 3.9674566114424397`}, {
        0.7087405338788568, 3.9349132228848793`}}], 
       PolygonBox[{{0.8543702669394284, 3.9674566114424397`}, {
        0.8543702669394284, 3.9674566114424397`}, {0.9999999999999999, 4.}, {
        1., 4.}, {0.8543702669394284, 3.9674566114424397`}}], 
       PolygonBox[{{1., 4.}, {1., 4.}, {1.1456297330605716`, 
        4.032543388557561}, {1.1456297330605716`, 4.032543388557561}, {1., 
        4.}}], PolygonBox[{{1.1456297330605716`, 4.032543388557561}, {
        1.1456297330605716`, 4.032543388557561}, {1.2912594661211432`, 
        4.065086777115121}, {1.2912594661211432`, 4.065086777115121}, {
        1.1456297330605716`, 4.032543388557561}}], 
       PolygonBox[{{1.2912594661211432`, 4.065086777115121}, {
        1.2912594661211432`, 4.065086777115121}, {1.4368891991817145`, 
        4.0976301656726815`}, {1.4368891991817145`, 4.0976301656726815`}, {
        1.2912594661211432`, 4.065086777115121}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5631108008182854, 3.902369834327319}, {0.7087405338788568,
          3.9349132228848793`}, {0.8543702669394284, 3.9674566114424397`}, {
         1., 4.}, {1.1456297330605716`, 4.032543388557561}, {
         1.2912594661211432`, 4.065086777115121}, {1.4368891991817145`, 
         4.0976301656726815`}, {1.4368891991817145`, 4.0976301656726815`}, {
         1.2912594661211432`, 4.065086777115121}, {1.1456297330605716`, 
         4.032543388557561}, {1., 4.}, {0.8543702669394284, 
         3.9674566114424397`}, {0.7087405338788568, 3.9349132228848793`}, {
         0.5631108008182855, 3.902369834327319}, {0.5631108008182854, 
         3.902369834327319}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.6686325248437331, 3.4759504204758596`}, {
      0.45758907679283756`, 4.328789248178778}, {1.331367475156267, 
      4.52404957952414}, {1.5424109232071626`, 3.671210751821222}, {
      0.6686325248437331, 3.4759504204758596`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.6686325248437331, 3.4759504204758596`}, {
       0.45758907679283756`, 4.328789248178778}, {1.331367475156267, 
       4.52404957952414}, {1.5424109232071626`, 3.671210751821222}, {
       0.6686325248437331, 3.4759504204758596`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.1289932943409875`, 4.584934346559962}, {
      1.1289932943409877`, 4.584934346559963}, {1.0859955295606585`, 
      4.723289564373308}, {1.0859955295606585`, 4.723289564373308}, {
      1.1289932943409875`, 4.584934346559962}}], 
     PolygonBox[{{1.0859955295606585`, 4.723289564373308}, {
      1.0859955295606585`, 4.723289564373308}, {1.0429977647803292`, 
      4.861644782186654}, {1.0429977647803292`, 4.861644782186654}, {
      1.0859955295606585`, 4.723289564373308}}], 
     PolygonBox[{{1.0429977647803292`, 4.861644782186654}, {
      1.0429977647803292`, 4.861644782186654}, {1., 5.}, {1., 5.}, {
      1.0429977647803292`, 4.861644782186654}}], 
     PolygonBox[{{1., 5.}, {1., 5.}, {0.9570022352196709, 
      5.138355217813346}, {0.9570022352196709, 5.138355217813346}, {1., 5.}}],
      PolygonBox[{{0.9570022352196709, 5.138355217813346}, {
      0.9570022352196709, 5.138355217813346}, {0.9140044704393416, 
      5.276710435626692}, {0.9140044704393416, 5.276710435626692}, {
      0.9570022352196709, 5.138355217813346}}], 
     PolygonBox[{{0.9140044704393416, 5.276710435626692}, {0.9140044704393416,
       5.276710435626692}, {0.8710067056590125, 5.415065653440037}, {
      0.8710067056590125, 5.415065653440037}, {0.9140044704393416, 
      5.276710435626692}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.1289932943409875`, 4.584934346559962}, {1.0859955295606585`,
        4.723289564373308}, {1.0429977647803292`, 4.861644782186654}, {1., 
       5.}, {0.9570022352196709, 5.138355217813346}, {0.9140044704393416, 
       5.276710435626692}, {0.8710067056590125, 5.415065653440037}, {
       0.8710067056590125, 5.415065653440038}, {0.9140044704393416, 
       5.276710435626692}, {0.9570022352196708, 5.138355217813346}, {1., 
       5.}, {1.0429977647803292`, 4.861644782186654}, {1.0859955295606583`, 
       4.723289564373308}, {1.1289932943409875`, 4.584934346559963}, {
       1.1289932943409875`, 4.584934346559962}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0.5696873477287563, 4.883461451229845}, {
        0.5696873477287563, 4.883461451229845}, {0.7131248984858376, 
        4.92230763415323}, {0.7131248984858376, 4.92230763415323}, {
        0.5696873477287563, 4.883461451229845}}], 
       PolygonBox[{{0.7131248984858376, 4.92230763415323}, {
        0.7131248984858376, 4.92230763415323}, {0.8565624492429187, 
        4.961153817076615}, {0.8565624492429188, 4.961153817076615}, {
        0.7131248984858376, 4.92230763415323}}], 
       PolygonBox[{{0.8565624492429188, 4.961153817076615}, {
        0.8565624492429187, 4.961153817076615}, {0.9999999999999999, 5.}, {1.,
         5.}, {0.8565624492429188, 4.961153817076615}}], 
       PolygonBox[{{1., 5.}, {1., 5.}, {1.143437550757081, 
        5.038846182923385}, {1.143437550757081, 5.038846182923385}, {1., 
        5.}}], PolygonBox[{{1.143437550757081, 5.038846182923385}, {
        1.143437550757081, 5.038846182923385}, {1.2868751015141624`, 
        5.07769236584677}, {1.2868751015141624`, 5.07769236584677}, {
        1.143437550757081, 5.038846182923385}}], 
       PolygonBox[{{1.2868751015141624`, 5.07769236584677}, {
        1.2868751015141624`, 5.07769236584677}, {1.4303126522712435`, 
        5.116538548770155}, {1.4303126522712435`, 5.116538548770155}, {
        1.2868751015141624`, 5.07769236584677}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0.5696873477287563, 4.883461451229845}, {0.7131248984858376,
          4.92230763415323}, {0.8565624492429188, 4.961153817076615}, {1., 
         5.}, {1.143437550757081, 5.038846182923385}, {1.2868751015141624`, 
         5.07769236584677}, {1.4303126522712435`, 5.116538548770155}, {
         1.4303126522712437`, 5.116538548770155}, {1.2868751015141624`, 
         5.07769236584677}, {1.1434375507570813`, 5.038846182923385}, {1., 
         5.}, {0.8565624492429188, 4.961153817076615}, {0.7131248984858376, 
         4.92230763415323}, {0.5696873477287565, 4.883461451229845}, {
         0.5696873477287563, 4.883461451229845}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{0.6986806420697439, 4.468395797789808}, {0.4406940533877688,
       5.298527104669883}, {1.301319357930256, 5.531604202210192}, {
      1.5593059466122312`, 4.701472895330117}, {0.6986806420697439, 
      4.468395797789808}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.6986806420697439, 4.468395797789808}, {0.4406940533877688, 
       5.298527104669883}, {1.301319357930256, 5.531604202210192}, {
       1.5593059466122312`, 4.701472895330117}, {0.6986806420697439, 
       4.468395797789808}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.869252174881742, -5.415214614705815}, {
      1.869252174881742, -5.415214614705815}, {
      1.9128347832544945`, -5.27680974313721}, {
      1.9128347832544945`, -5.2768097431372105`}, {
      1.869252174881742, -5.415214614705815}}], 
     PolygonBox[{{1.9128347832544945`, -5.2768097431372105`}, {
      1.9128347832544945`, -5.27680974313721}, {
      1.9564173916272474`, -5.138404871568605}, {
      1.9564173916272471`, -5.138404871568605}, {
      1.9128347832544945`, -5.2768097431372105`}}], 
     PolygonBox[{{1.9564173916272471`, -5.138404871568605}, {
      1.9564173916272474`, -5.138404871568605}, {2., -5.}, {2., -5.}, {
      1.9564173916272471`, -5.138404871568605}}], 
     PolygonBox[{{2., -5.}, {2., -5.}, {
      2.043582608372753, -4.861595128431395}, {
      2.043582608372753, -4.861595128431395}, {2., -5.}}], 
     PolygonBox[{{2.043582608372753, -4.861595128431395}, {
      2.043582608372753, -4.861595128431395}, {
      2.0871652167455053`, -4.72319025686279}, {
      2.0871652167455053`, -4.72319025686279}, {
      2.043582608372753, -4.861595128431395}}], 
     PolygonBox[{{2.0871652167455053`, -4.72319025686279}, {
      2.0871652167455053`, -4.72319025686279}, {
      2.130747825118258, -4.584785385294185}, {
      2.130747825118258, -4.584785385294185}, {
      2.0871652167455053`, -4.72319025686279}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.869252174881742, -5.415214614705815}, {
       1.9128347832544945`, -5.2768097431372105`}, {
       1.9564173916272471`, -5.138404871568605}, {2., -5.}, {
       2.043582608372753, -4.861595128431395}, {
       2.0871652167455053`, -4.72319025686279}, {
       2.130747825118258, -4.584785385294185}, {
       2.130747825118258, -4.584785385294185}, {
       2.0871652167455057`, -4.7231902568627895`}, {
       2.043582608372753, -4.861595128431395}, {2., -5.}, {
       1.9564173916272474`, -5.138404871568605}, {
       1.9128347832544945`, -5.27680974313721}, {
       1.869252174881742, -5.415214614705815}, {
       1.869252174881742, -5.415214614705815}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5714121092718345`, -4.885974432860227}, {
        1.5714121092718345`, -4.885974432860227}, {
        1.7142747395145563`, -4.9239829552401515`}, {
        1.7142747395145563`, -4.9239829552401515`}, {
        1.5714121092718345`, -4.885974432860227}}], 
       PolygonBox[{{1.7142747395145563`, -4.9239829552401515`}, {
        1.7142747395145563`, -4.9239829552401515`}, {
        1.8571373697572782`, -4.961991477620075}, {
        1.8571373697572782`, -4.961991477620075}, {
        1.7142747395145563`, -4.9239829552401515`}}], 
       PolygonBox[{{1.8571373697572782`, -4.961991477620075}, {
        1.8571373697572782`, -4.961991477620075}, {2., -5.}, {2., -5.}, {
        1.8571373697572782`, -4.961991477620075}}], 
       PolygonBox[{{2., -5.}, {2., -5.}, {
        2.1428626302427216`, -5.038008522379925}, {
        2.1428626302427216`, -5.038008522379925}, {2., -5.}}], 
       PolygonBox[{{2.1428626302427216`, -5.038008522379925}, {
        2.1428626302427216`, -5.038008522379925}, {
        2.2857252604854437`, -5.0760170447598485`}, {
        2.2857252604854437`, -5.0760170447598485`}, {
        2.1428626302427216`, -5.038008522379925}}], 
       PolygonBox[{{2.2857252604854437`, -5.0760170447598485`}, {
        2.2857252604854437`, -5.0760170447598485`}, {
        2.4285878907281653`, -5.114025567139773}, {
        2.4285878907281653`, -5.114025567139773}, {
        2.2857252604854437`, -5.0760170447598485`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5714121092718345`, -4.885974432860227}, {
         1.7142747395145563`, -4.9239829552401515`}, {
         1.8571373697572782`, -4.961991477620075}, {2., -5.}, {
         2.1428626302427216`, -5.038008522379925}, {
         2.2857252604854437`, -5.0760170447598485`}, {
         2.4285878907281653`, -5.114025567139773}, {
         2.4285878907281653`, -5.114025567139773}, {
         2.2857252604854437`, -5.0760170447598485`}, {
         2.142862630242722, -5.038008522379925}, {2., -5.}, {
         1.8571373697572782`, -4.961991477620075}, {
         1.7142747395145563`, -4.9239829552401515`}, {
         1.5714121092718347`, -4.885974432860227}, {
         1.5714121092718345`, -4.885974432860227}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.4406642841535762`, -5.301189047566042}, {
      1.7021599343900928`, -4.470759818154412}, {
      2.559335715846424, -4.698810952433958}, {
      2.297840065609907, -5.529240181845588}, {
      1.4406642841535762`, -5.301189047566042}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.4406642841535762`, -5.301189047566042}, {
       1.7021599343900928`, -4.470759818154412}, {
       2.559335715846424, -4.698810952433958}, {
       2.297840065609907, -5.529240181845588}, {
       1.4406642841535762`, -5.301189047566042}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.892903738327715, -4.426467649779901}, {
      1.8929037383277152`, -4.426467649779901}, {
      1.9286024922184768`, -4.2843117665199335`}, {
      1.9286024922184766`, -4.2843117665199335`}, {
      1.892903738327715, -4.426467649779901}}], 
     PolygonBox[{{1.9286024922184766`, -4.2843117665199335`}, {
      1.9286024922184768`, -4.2843117665199335`}, {
      1.9643012461092384`, -4.142155883259967}, {
      1.9643012461092384`, -4.142155883259967}, {
      1.9286024922184766`, -4.2843117665199335`}}], 
     PolygonBox[{{1.9643012461092384`, -4.142155883259967}, {
      1.9643012461092384`, -4.142155883259967}, {2., -4.}, {2., -4.}, {
      1.9643012461092384`, -4.142155883259967}}], 
     PolygonBox[{{2., -4.}, {2., -4.}, {
      2.035698753890762, -3.8578441167400332`}, {
      2.035698753890762, -3.8578441167400332`}, {2., -4.}}], 
     PolygonBox[{{2.035698753890762, -3.8578441167400332`}, {
      2.035698753890762, -3.8578441167400332`}, {
      2.071397507781523, -3.7156882334800665`}, {
      2.071397507781523, -3.715688233480066}, {
      2.035698753890762, -3.8578441167400332`}}], 
     PolygonBox[{{2.071397507781523, -3.715688233480066}, {
      2.071397507781523, -3.7156882334800665`}, {
      2.107096261672285, -3.5735323502200993`}, {
      2.107096261672285, -3.5735323502200993`}, {
      2.071397507781523, -3.715688233480066}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.892903738327715, -4.426467649779901}, {
       1.9286024922184766`, -4.2843117665199335`}, {
       1.9643012461092384`, -4.142155883259967}, {2., -4.}, {
       2.035698753890762, -3.8578441167400332`}, {
       2.071397507781523, -3.715688233480066}, {
       2.107096261672285, -3.5735323502200993`}, {
       2.107096261672285, -3.5735323502200993`}, {
       2.071397507781523, -3.715688233480066}, {
       2.035698753890762, -3.8578441167400332`}, {2., -4.}, {
       1.9643012461092384`, -4.142155883259967}, {
       1.9286024922184766`, -4.2843117665199335`}, {
       1.892903738327715, -4.426467649779901}, {
       1.892903738327715, -4.426467649779901}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5645326466546545`, -3.9043143980160577`}, {
        1.5645326466546545`, -3.9043143980160577`}, {
        1.709688431103103, -3.9362095986773715`}, {
        1.709688431103103, -3.9362095986773715`}, {
        1.5645326466546545`, -3.9043143980160577`}}], 
       PolygonBox[{{1.709688431103103, -3.9362095986773715`}, {
        1.709688431103103, -3.9362095986773715`}, {
        1.8548442155515514`, -3.9681047993386858`}, {
        1.8548442155515514`, -3.9681047993386858`}, {
        1.709688431103103, -3.9362095986773715`}}], 
       PolygonBox[{{1.8548442155515514`, -3.9681047993386858`}, {
        1.8548442155515514`, -3.9681047993386858`}, {2., -4.}, {2., -4.}, {
        1.8548442155515514`, -3.9681047993386858`}}], 
       PolygonBox[{{2., -4.}, {2., -4.}, {
        2.1451557844484483`, -4.031895200661314}, {
        2.1451557844484483`, -4.031895200661314}, {2., -4.}}], 
       PolygonBox[{{2.1451557844484483`, -4.031895200661314}, {
        2.1451557844484483`, -4.031895200661314}, {
        2.2903115688968967`, -4.0637904013226285`}, {
        2.2903115688968967`, -4.0637904013226285`}, {
        2.1451557844484483`, -4.031895200661314}}], 
       PolygonBox[{{2.2903115688968967`, -4.0637904013226285`}, {
        2.2903115688968967`, -4.0637904013226285`}, {
        2.4354673533453455`, -4.095685601983942}, {
        2.4354673533453455`, -4.095685601983942}, {
        2.2903115688968967`, -4.0637904013226285`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5645326466546545`, -3.9043143980160577`}, {
         1.709688431103103, -3.9362095986773715`}, {
         1.8548442155515514`, -3.9681047993386858`}, {2., -4.}, {
         2.1451557844484483`, -4.031895200661314}, {
         2.2903115688968967`, -4.0637904013226285`}, {
         2.4354673533453455`, -4.095685601983942}, {
         2.4354673533453455`, -4.095685601983942}, {
         2.290311568896897, -4.0637904013226285`}, {
         2.1451557844484483`, -4.031895200661314}, {2., -4.}, {
         1.8548442155515517`, -3.9681047993386858`}, {
         1.709688431103103, -3.936209598677372}, {
         1.5645326466546547`, -3.9043143980160577`}, {
         1.5645326466546545`, -3.9043143980160577`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.4574363849823695`, -4.330782047795958}, {
      1.6716289083269396`, -3.477846748236157}, {
      2.5425636150176305`, -3.6692179522040416`}, {
      2.3283710916730604`, -4.522153251763843}, {
      1.4574363849823695`, -4.330782047795958}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.4574363849823695`, -4.330782047795958}, {
       1.6716289083269396`, -3.477846748236157}, {
       2.5425636150176305`, -3.6692179522040416`}, {
       2.3283710916730604`, -4.522153251763843}, {
       1.4574363849823695`, -4.330782047795958}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.9181179562782646`, -3.4361475544378655`}, {
      1.9181179562782646`, -3.4361475544378655`}, {
      1.9454119708521764`, -3.2907650362919103`}, {
      1.9454119708521764`, -3.2907650362919103`}, {
      1.9181179562782646`, -3.4361475544378655`}}], 
     PolygonBox[{{1.9454119708521764`, -3.2907650362919103`}, {
      1.9454119708521764`, -3.2907650362919103`}, {
      1.9727059854260882`, -3.145382518145955}, {
      1.9727059854260882`, -3.145382518145955}, {
      1.9454119708521764`, -3.2907650362919103`}}], 
     PolygonBox[{{1.9727059854260882`, -3.145382518145955}, {
      1.9727059854260882`, -3.145382518145955}, {2., -3.}, {2., -3.}, {
      1.9727059854260882`, -3.145382518145955}}], 
     PolygonBox[{{2., -3.}, {2., -3.}, {
      2.027294014573912, -2.854617481854045}, {
      2.027294014573912, -2.854617481854045}, {2., -3.}}], 
     PolygonBox[{{2.027294014573912, -2.854617481854045}, {
      2.027294014573912, -2.854617481854045}, {
      2.0545880291478236`, -2.7092349637080897`}, {
      2.0545880291478236`, -2.7092349637080897`}, {
      2.027294014573912, -2.854617481854045}}], 
     PolygonBox[{{2.0545880291478236`, -2.7092349637080897`}, {
      2.0545880291478236`, -2.7092349637080897`}, {
      2.0818820437217354`, -2.5638524455621345`}, {
      2.0818820437217354`, -2.5638524455621345`}, {
      2.0545880291478236`, -2.7092349637080897`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9181179562782646`, -3.4361475544378655`}, {
       1.9454119708521764`, -3.2907650362919103`}, {
       1.9727059854260882`, -3.145382518145955}, {2., -3.}, {
       2.027294014573912, -2.854617481854045}, {
       2.0545880291478236`, -2.7092349637080897`}, {
       2.0818820437217354`, -2.5638524455621345`}, {
       2.0818820437217354`, -2.5638524455621345`}, {
       2.0545880291478236`, -2.7092349637080897`}, {
       2.027294014573912, -2.854617481854045}, {2., -3.}, {
       1.9727059854260882`, -3.145382518145955}, {
       1.9454119708521764`, -3.2907650362919103`}, {
       1.9181179562782646`, -3.4361475544378655`}, {
       1.9181179562782646`, -3.4361475544378655`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5588209983435757`, -2.925363268601707}, {
        1.5588209983435757`, -2.925363268601707}, {
        1.705880665562384, -2.9502421790678044`}, {
        1.7058806655623837`, -2.9502421790678044`}, {
        1.5588209983435757`, -2.925363268601707}}], 
       PolygonBox[{{1.7058806655623837`, -2.9502421790678044`}, {
        1.705880665562384, -2.9502421790678044`}, {
        1.8529403327811917`, -2.975121089533902}, {
        1.852940332781192, -2.975121089533902}, {
        1.7058806655623837`, -2.9502421790678044`}}], 
       PolygonBox[{{1.852940332781192, -2.975121089533902}, {
        1.8529403327811917`, -2.975121089533902}, {2., -3.}, {2., -3.}, {
        1.852940332781192, -2.975121089533902}}], 
       PolygonBox[{{2., -3.}, {2., -3.}, {
        2.1470596672188083`, -3.024878910466098}, {
        2.1470596672188083`, -3.024878910466098}, {2., -3.}}], 
       PolygonBox[{{2.1470596672188083`, -3.024878910466098}, {
        2.1470596672188083`, -3.024878910466098}, {
        2.294119334437616, -3.0497578209321956`}, {
        2.294119334437616, -3.049757820932195}, {
        2.1470596672188083`, -3.024878910466098}}], 
       PolygonBox[{{2.294119334437616, -3.049757820932195}, {
        2.294119334437616, -3.0497578209321956`}, {
        2.4411790016564243`, -3.074636731398293}, {
        2.4411790016564243`, -3.074636731398293}, {
        2.294119334437616, -3.049757820932195}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5588209983435757`, -2.925363268601707}, {
         1.7058806655623837`, -2.9502421790678044`}, {
         1.852940332781192, -2.975121089533902}, {2., -3.}, {
         2.1470596672188083`, -3.024878910466098}, {
         2.294119334437616, -3.0497578209321956`}, {
         2.4411790016564243`, -3.074636731398293}, {
         2.4411790016564243`, -3.074636731398293}, {
         2.294119334437616, -3.0497578209321956`}, {
         2.1470596672188083`, -3.024878910466098}, {2., -3.}, {
         1.852940332781192, -2.975121089533902}, {
         1.705880665562384, -2.9502421790678044`}, {
         1.5588209983435757`, -2.925363268601707}, {
         1.5588209983435757`, -2.925363268601707}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.4769389546218403`, -3.3615108230395725`}, {
      1.640703042065311, -2.489215714163841}, {
      2.5230610453781597`, -2.6384891769604275`}, {
      2.359296957934689, -3.510784285836159}, {
      1.4769389546218403`, -3.3615108230395725`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.4769389546218403`, -3.3615108230395725`}, {
       1.640703042065311, -2.489215714163841}, {
       2.5230610453781597`, -2.6384891769604275`}, {
       2.359296957934689, -3.510784285836159}, {
       1.4769389546218403`, -3.3615108230395725`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.9446286321645672`, -2.4436316014098365`}, {
      1.9446286321645674`, -2.4436316014098365`}, {
      1.9630857547763783`, -2.295754400939891}, {
      1.963085754776378, -2.295754400939891}, {
      1.9446286321645672`, -2.4436316014098365`}}], 
     PolygonBox[{{1.963085754776378, -2.295754400939891}, {
      1.9630857547763783`, -2.295754400939891}, {
      1.9815428773881891`, -2.147877200469946}, {
      1.9815428773881891`, -2.1478772004699453`}, {
      1.963085754776378, -2.295754400939891}}], 
     PolygonBox[{{1.9815428773881891`, -2.1478772004699453`}, {
      1.9815428773881891`, -2.147877200469946}, {2., -2.}, {2., -2.}, {
      1.9815428773881891`, -2.1478772004699453`}}], 
     PolygonBox[{{2., -2.}, {2., -2.}, {
      2.018457122611811, -1.8521227995300544`}, {
      2.018457122611811, -1.8521227995300544`}, {2., -2.}}], 
     PolygonBox[{{2.018457122611811, -1.8521227995300544`}, {
      2.018457122611811, -1.8521227995300544`}, {
      2.0369142452236217`, -1.704245599060109}, {
      2.0369142452236217`, -1.7042455990601089`}, {
      2.018457122611811, -1.8521227995300544`}}], 
     PolygonBox[{{2.0369142452236217`, -1.7042455990601089`}, {
      2.0369142452236217`, -1.704245599060109}, {
      2.055371367835433, -1.5563683985901635`}, {
      2.055371367835433, -1.5563683985901635`}, {
      2.0369142452236217`, -1.7042455990601089`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9446286321645672`, -2.4436316014098365`}, {
       1.963085754776378, -2.295754400939891}, {
       1.9815428773881891`, -2.1478772004699453`}, {2., -2.}, {
       2.018457122611811, -1.8521227995300544`}, {
       2.0369142452236217`, -1.7042455990601089`}, {
       2.055371367835433, -1.5563683985901635`}, {
       2.055371367835433, -1.5563683985901635`}, {
       2.0369142452236217`, -1.7042455990601089`}, {
       2.018457122611811, -1.8521227995300544`}, {2., -2.}, {
       1.9815428773881891`, -2.1478772004699453`}, {
       1.963085754776378, -2.295754400939891}, {
       1.9446286321645672`, -2.4436316014098365`}, {
       1.9446286321645672`, -2.4436316014098365`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5545275870096076`, -1.9487651109635529`}, {
        1.5545275870096076`, -1.9487651109635529`}, {
        1.7030183913397383`, -1.9658434073090352`}, {
        1.7030183913397383`, -1.9658434073090352`}, {
        1.5545275870096076`, -1.9487651109635529`}}], 
       PolygonBox[{{1.7030183913397383`, -1.9658434073090352`}, {
        1.7030183913397383`, -1.9658434073090352`}, {
        1.851509195669869, -1.9829217036545175`}, {
        1.8515091956698693`, -1.9829217036545177`}, {
        1.7030183913397383`, -1.9658434073090352`}}], 
       PolygonBox[{{1.8515091956698693`, -1.9829217036545177`}, {
        1.851509195669869, -1.9829217036545175`}, {2., -2.}, {2., -2.}, {
        1.8515091956698693`, -1.9829217036545177`}}], 
       PolygonBox[{{2., -2.}, {2., -2.}, {
        2.1484908043301307`, -2.0170782963454825`}, {
        2.1484908043301307`, -2.0170782963454825`}, {2., -2.}}], 
       PolygonBox[{{2.1484908043301307`, -2.0170782963454825`}, {
        2.1484908043301307`, -2.0170782963454825`}, {
        2.2969816086602615`, -2.0341565926909646`}, {
        2.2969816086602615`, -2.0341565926909646`}, {
        2.1484908043301307`, -2.0170782963454825`}}], 
       PolygonBox[{{2.2969816086602615`, -2.0341565926909646`}, {
        2.2969816086602615`, -2.0341565926909646`}, {
        2.4454724129903926`, -2.051234889036447}, {
        2.445472412990392, -2.051234889036447}, {
        2.2969816086602615`, -2.0341565926909646`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5545275870096076`, -1.9487651109635529`}, {
         1.7030183913397383`, -1.9658434073090352`}, {
         1.8515091956698693`, -1.9829217036545177`}, {2., -2.}, {
         2.1484908043301307`, -2.0170782963454825`}, {
         2.2969816086602615`, -2.0341565926909646`}, {
         2.445472412990392, -2.051234889036447}, {
         2.4454724129903926`, -2.051234889036447}, {
         2.2969816086602615`, -2.0341565926909646`}, {
         2.1484908043301307`, -2.0170782963454825`}, {2., -2.}, {
         1.8515091956698693`, -1.9829217036545177`}, {
         1.7030183913397383`, -1.9658434073090352`}, {
         1.5545275870096076`, -1.9487651109635529`}, {
         1.5545275870096076`, -1.9487651109635529`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.4991562191741747`, -2.3923967123733894`}, {
      1.6098989548450404`, -1.5051335095537164`}, {
      2.500843780825825, -1.6076032876266106`}, {
      2.39010104515496, -2.4948664904462836`}, {
      1.4991562191741747`, -2.3923967123733894`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.4991562191741747`, -2.3923967123733894`}, {
       1.6098989548450404`, -1.5051335095537164`}, {
       2.500843780825825, -1.6076032876266106`}, {
       2.39010104515496, -2.4948664904462836`}, {
       1.4991562191741747`, -2.3923967123733894`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.972070577249549, -1.4483743280284576`}, {
      1.972070577249549, -1.4483743280284576`}, {
      1.9813803848330327`, -1.2989162186856384`}, {
      1.9813803848330327`, -1.2989162186856384`}, {
      1.972070577249549, -1.4483743280284576`}}], 
     PolygonBox[{{1.9813803848330327`, -1.2989162186856384`}, {
      1.9813803848330327`, -1.2989162186856384`}, {
      1.9906901924165163`, -1.1494581093428193`}, {
      1.9906901924165163`, -1.1494581093428193`}, {
      1.9813803848330327`, -1.2989162186856384`}}], 
     PolygonBox[{{1.9906901924165163`, -1.1494581093428193`}, {
      1.9906901924165163`, -1.1494581093428193`}, {
      2., -1.0000000000000002`}, {2., -1.}, {
      1.9906901924165163`, -1.1494581093428193`}}], 
     PolygonBox[{{2., -1.}, {2., -1.}, {
      2.0093098075834837`, -0.8505418906571808}, {
      2.0093098075834837`, -0.8505418906571808}, {2., -1.}}], 
     PolygonBox[{{2.0093098075834837`, -0.8505418906571808}, {
      2.0093098075834837`, -0.8505418906571808}, {
      2.0186196151669673`, -0.7010837813143616}, {
      2.0186196151669673`, -0.7010837813143616}, {
      2.0093098075834837`, -0.8505418906571808}}], 
     PolygonBox[{{2.0186196151669673`, -0.7010837813143616}, {
      2.0186196151669673`, -0.7010837813143616}, {
      2.027929422750451, -0.5516256719715423}, {
      2.027929422750451, -0.5516256719715424}, {
      2.0186196151669673`, -0.7010837813143616}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.972070577249549, -1.4483743280284576`}, {
       1.9813803848330327`, -1.2989162186856384`}, {
       1.9906901924165163`, -1.1494581093428193`}, {2., -1.}, {
       2.0093098075834837`, -0.8505418906571808}, {
       2.0186196151669673`, -0.7010837813143616}, {
       2.027929422750451, -0.5516256719715424}, {
       2.027929422750451, -0.5516256719715423}, {
       2.0186196151669673`, -0.7010837813143616}, {
       2.0093098075834837`, -0.8505418906571808}, {2., -1.}, {
       1.9906901924165163`, -1.1494581093428191`}, {
       1.9813803848330327`, -1.2989162186856384`}, {
       1.972070577249549, -1.4483743280284576`}, {
       1.972070577249549, -1.4483743280284576`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5518595299730515`, -0.9739153434016146}, {
        1.5518595299730515`, -0.9739153434016146}, {
        1.701239686648701, -0.9826102289344096}, {
        1.701239686648701, -0.9826102289344097}, {
        1.5518595299730515`, -0.9739153434016146}}], 
       PolygonBox[{{1.701239686648701, -0.9826102289344097}, {
        1.701239686648701, -0.9826102289344096}, {
        1.8506198433243504`, -0.9913051144672048}, {
        1.8506198433243504`, -0.9913051144672048}, {
        1.701239686648701, -0.9826102289344097}}], 
       PolygonBox[{{1.8506198433243504`, -0.9913051144672048}, {
        1.8506198433243504`, -0.9913051144672048}, {2., -1.}, {2., -1.}, {
        1.8506198433243504`, -0.9913051144672048}}], 
       PolygonBox[{{2., -1.}, {2., -1.}, {
        2.1493801566756496`, -1.008694885532795}, {
        2.1493801566756496`, -1.008694885532795}, {2., -1.}}], 
       PolygonBox[{{2.1493801566756496`, -1.008694885532795}, {
        2.1493801566756496`, -1.008694885532795}, {
        2.298760313351299, -1.0173897710655904`}, {
        2.2987603133512993`, -1.0173897710655901`}, {
        2.1493801566756496`, -1.008694885532795}}], 
       PolygonBox[{{2.2987603133512993`, -1.0173897710655901`}, {
        2.298760313351299, -1.0173897710655904`}, {
        2.4481404700269485`, -1.0260846565983854`}, {
        2.4481404700269485`, -1.0260846565983854`}, {
        2.2987603133512993`, -1.0173897710655901`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5518595299730515`, -0.9739153434016146}, {
         1.701239686648701, -0.9826102289344097}, {
         1.8506198433243504`, -0.9913051144672048}, {2., -1.}, {
         2.1493801566756496`, -1.008694885532795}, {
         2.2987603133512993`, -1.0173897710655904`}, {
         2.4481404700269485`, -1.0260846565983854`}, {
         2.4481404700269485`, -1.0260846565983854`}, {
         2.2987603133512993`, -1.0173897710655904`}, {
         2.1493801566756496`, -1.008694885532795}, {2., -1.}, {
         1.8506198433243506`, -0.9913051144672048}, {
         1.701239686648701, -0.9826102289344097}, {
         1.5518595299730515`, -0.9739153434016146}, {
         1.5518595299730515`, -0.9739153434016146}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.5239301072226004`, -1.4222896714300721`}, {
      1.5797889527235025`, -0.5255410153731569}, {
      2.4760698927773994`, -0.5777103285699278}, {
      2.4202110472764975`, -1.474458984626843}, {
      1.5239301072226004`, -1.4222896714300721`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5239301072226004`, -1.4222896714300721`}, {
       1.5797889527235025`, -0.5255410153731569}, {
       2.4760698927773994`, -0.5777103285699278}, {
       2.4202110472764975`, -1.474458984626843}, {
       1.5239301072226004`, -1.4222896714300721`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2., -0.45}, {2., -0.45}, {2., -0.3}, {
      2., -0.30000000000000004`}, {2., -0.45}}], 
     PolygonBox[{{2., -0.30000000000000004`}, {2., -0.3}, {
      2., -0.15000000000000008`}, {2., -0.15000000000000002`}, {
      2., -0.30000000000000004`}}], 
     PolygonBox[{{2., -0.15000000000000002`}, {2., -0.15000000000000008`}, {
      2., -1.1102230246251565`*^-16}, {2., 0.}, {2., -0.15000000000000002`}}],
      PolygonBox[{{2., 0.}, {2., 0.}, {2., 0.14999999999999997`}, {2., 
      0.14999999999999997`}, {2., 0.}}], 
     PolygonBox[{{2., 0.14999999999999997`}, {2., 0.14999999999999997`}, {2., 
      0.29999999999999993`}, {2., 0.3}, {2., 0.14999999999999997`}}], 
     PolygonBox[{{2., 0.3}, {2., 0.29999999999999993`}, {2., 
      0.44999999999999996`}, {2., 0.4499999999999999}, {2., 0.3}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2., -0.45}, {2., -0.30000000000000004`}, {
       2., -0.15000000000000002`}, {2., -5.551115123125783*^-17}, {2., 
       0.14999999999999997`}, {2., 0.3}, {2., 0.4499999999999999}, {2., 
       0.45}, {2., 0.30000000000000004`}, {2., 0.15000000000000002`}, {2., 
       5.551115123125783*^-17}, {2., -0.14999999999999997`}, {2., -0.3}, {
       2., -0.4499999999999999}, {2., -0.45}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5509541313373787`, 0.}, {1.5509541313373787`, 
        5.5109105961630896`*^-17}, {1.7006360875582525`, 
        4.592425496802574*^-17}, {1.7006360875582525`, 
        9.184850993605149*^-18}, {1.5509541313373787`, 0.}}], 
       PolygonBox[{{1.7006360875582525`, 9.184850993605149*^-18}, {
        1.7006360875582525`, 4.592425496802574*^-17}, {1.8503180437791262`, 
        3.67394039744206*^-17}, {1.8503180437791262`, 
        1.8369701987210297`*^-17}, {1.7006360875582525`, 
        9.184850993605149*^-18}}], 
       PolygonBox[{{1.8503180437791262`, 1.8369701987210297`*^-17}, {
        1.8503180437791262`, 3.67394039744206*^-17}, {2., 
        2.7554552980815454`*^-17}, {2., 2.7554552980815448`*^-17}, {
        1.8503180437791262`, 1.8369701987210297`*^-17}}], 
       PolygonBox[{{2., 2.7554552980815448`*^-17}, {2., 
        2.7554552980815448`*^-17}, {2.1496819562208738`, 
        1.83697019872103*^-17}, {2.1496819562208738`, 
        3.6739403974420595`*^-17}, {2., 2.7554552980815448`*^-17}}], 
       PolygonBox[{{2.1496819562208738`, 3.6739403974420595`*^-17}, {
        2.1496819562208738`, 1.83697019872103*^-17}, {2.2993639124417475`, 
        9.184850993605152*^-18}, {2.2993639124417475`, 
        4.592425496802574*^-17}, {2.1496819562208738`, 
        3.6739403974420595`*^-17}}], 
       PolygonBox[{{2.2993639124417475`, 4.592425496802574*^-17}, {
        2.2993639124417475`, 9.184850993605153*^-18}, {2.4490458686626213`, 
        4.5887548728832574`*^-33}, {2.4490458686626213`, 
        5.510910596163089*^-17}, {2.2993639124417475`, 
        4.592425496802574*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5509541313373787`, 0.}, {1.7006360875582525`, 0.}, {
         1.8503180437791262`, 0.}, {2., 0.}, {2.1496819562208738`, 0.}, {
         2.2993639124417475`, 0.}, {2.4490458686626213`, 0.}, {
         2.4490458686626213`, 0.}, {2.2993639124417475`, 0.}, {
         2.1496819562208738`, 0.}, {2., 0.}, {1.8503180437791262`, 0.}, {
         1.7006360875582525`, 0.}, {1.5509541313373787`, 0.}, {
         1.5509541313373787`, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.5509541313373787`, -0.45}, {1.5509541313373787`, 0.45}, {
      2.4490458686626213`, 0.45}, {2.4490458686626213`, -0.45}, {
      1.5509541313373787`, -0.45}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5509541313373787`, -0.45}, {1.5509541313373787`, 0.45}, {
       2.4490458686626213`, 0.45}, {2.4490458686626213`, -0.45}, {
       1.5509541313373787`, -0.45}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.027929422750451, 0.5516256719715423}, {2.027929422750451, 
      0.5516256719715423}, {2.0186196151669673`, 0.7010837813143616}, {
      2.0186196151669673`, 0.7010837813143616}, {2.027929422750451, 
      0.5516256719715423}}], 
     PolygonBox[{{2.0186196151669673`, 0.7010837813143616}, {
      2.0186196151669673`, 0.7010837813143616}, {2.0093098075834837`, 
      0.8505418906571807}, {2.0093098075834837`, 0.8505418906571808}, {
      2.0186196151669673`, 0.7010837813143616}}], 
     PolygonBox[{{2.0093098075834837`, 0.8505418906571808}, {
      2.0093098075834837`, 0.8505418906571807}, {2., 0.9999999999999999}, {2.,
       1.}, {2.0093098075834837`, 0.8505418906571808}}], 
     PolygonBox[{{2., 1.}, {2., 1.}, {1.9906901924165163`, 
      1.1494581093428191`}, {1.9906901924165163`, 1.1494581093428191`}, {2., 
      1.}}], PolygonBox[{{1.9906901924165163`, 1.1494581093428191`}, {
      1.9906901924165163`, 1.1494581093428191`}, {1.9813803848330327`, 
      1.2989162186856384`}, {1.9813803848330327`, 1.2989162186856384`}, {
      1.9906901924165163`, 1.1494581093428191`}}], 
     PolygonBox[{{1.9813803848330327`, 1.2989162186856384`}, {
      1.9813803848330327`, 1.2989162186856384`}, {1.972070577249549, 
      1.4483743280284576`}, {1.972070577249549, 1.4483743280284576`}, {
      1.9813803848330327`, 1.2989162186856384`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.027929422750451, 0.5516256719715423}, {2.0186196151669673`, 
       0.7010837813143616}, {2.0093098075834837`, 0.8505418906571808}, {2., 
       1.}, {1.9906901924165163`, 1.1494581093428191`}, {1.9813803848330327`, 
       1.2989162186856384`}, {1.972070577249549, 1.4483743280284576`}, {
       1.972070577249549, 1.4483743280284576`}, {1.9813803848330327`, 
       1.2989162186856384`}, {1.9906901924165163`, 1.1494581093428193`}, {2., 
       1.}, {2.0093098075834837`, 0.8505418906571808}, {2.0186196151669673`, 
       0.7010837813143616}, {2.027929422750451, 0.5516256719715424}, {
       2.027929422750451, 0.5516256719715423}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5518595299730515`, 0.9739153434016146}, {
        1.5518595299730515`, 0.9739153434016147}, {1.701239686648701, 
        0.9826102289344097}, {1.701239686648701, 0.9826102289344097}, {
        1.5518595299730515`, 0.9739153434016146}}], 
       PolygonBox[{{1.701239686648701, 0.9826102289344097}, {
        1.701239686648701, 0.9826102289344097}, {1.8506198433243504`, 
        0.9913051144672049}, {1.8506198433243504`, 0.9913051144672049}, {
        1.701239686648701, 0.9826102289344097}}], 
       PolygonBox[{{1.8506198433243504`, 0.9913051144672049}, {
        1.8506198433243504`, 0.9913051144672049}, {1.9999999999999998`, 1.}, {
        2., 1.}, {1.8506198433243504`, 0.9913051144672049}}], 
       PolygonBox[{{2., 1.}, {2., 1.}, {2.1493801566756496`, 
        1.008694885532795}, {2.1493801566756496`, 1.008694885532795}, {2., 
        1.}}], PolygonBox[{{2.1493801566756496`, 1.008694885532795}, {
        2.1493801566756496`, 1.008694885532795}, {2.298760313351299, 
        1.0173897710655904`}, {2.2987603133512993`, 1.0173897710655904`}, {
        2.1493801566756496`, 1.008694885532795}}], 
       PolygonBox[{{2.2987603133512993`, 1.0173897710655904`}, {
        2.298760313351299, 1.0173897710655904`}, {2.4481404700269485`, 
        1.0260846565983854`}, {2.4481404700269485`, 1.0260846565983854`}, {
        2.2987603133512993`, 1.0173897710655904`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5518595299730515`, 0.9739153434016146}, {
         1.701239686648701, 0.9826102289344097}, {1.8506198433243504`, 
         0.9913051144672048}, {2., 1.}, {2.1493801566756496`, 
         1.008694885532795}, {2.2987603133512993`, 1.0173897710655904`}, {
         2.4481404700269485`, 1.0260846565983854`}, {2.4481404700269485`, 
         1.0260846565983854`}, {2.2987603133512993`, 1.0173897710655904`}, {
         2.1493801566756496`, 1.008694885532795}, {2., 1.}, {
         1.8506198433243506`, 0.9913051144672048}, {1.701239686648701, 
         0.9826102289344097}, {1.5518595299730515`, 0.9739153434016146}, {
         1.5518595299730515`, 0.9739153434016146}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.5797889527235025`, 0.5255410153731569}, {
      1.5239301072226004`, 1.4222896714300721`}, {2.4202110472764975`, 
      1.474458984626843}, {2.4760698927773994`, 0.5777103285699278}, {
      1.5797889527235025`, 0.5255410153731569}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.5797889527235025`, 0.5255410153731569}, {
       1.5239301072226004`, 1.4222896714300721`}, {2.4202110472764975`, 
       1.474458984626843}, {2.4760698927773994`, 0.5777103285699278}, {
       1.5797889527235025`, 0.5255410153731569}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.055371367835433, 1.5563683985901635`}, {2.055371367835433,
       1.5563683985901635`}, {2.036914245223622, 1.7042455990601089`}, {
      2.0369142452236217`, 1.7042455990601089`}, {2.055371367835433, 
      1.5563683985901635`}}], 
     PolygonBox[{{2.0369142452236217`, 1.7042455990601089`}, {
      2.036914245223622, 1.7042455990601089`}, {2.018457122611811, 
      1.8521227995300544`}, {2.018457122611811, 1.8521227995300544`}, {
      2.0369142452236217`, 1.7042455990601089`}}], 
     PolygonBox[{{2.018457122611811, 1.8521227995300544`}, {2.018457122611811,
       1.8521227995300544`}, {2., 2.}, {2., 2.}, {2.018457122611811, 
      1.8521227995300544`}}], 
     PolygonBox[{{2., 2.}, {2., 2.}, {1.9815428773881891`, 
      2.1478772004699453`}, {1.9815428773881891`, 2.1478772004699453`}, {2., 
      2.}}], PolygonBox[{{1.9815428773881891`, 2.1478772004699453`}, {
      1.9815428773881891`, 2.1478772004699453`}, {1.9630857547763783`, 
      2.295754400939891}, {1.963085754776378, 2.295754400939891}, {
      1.9815428773881891`, 2.1478772004699453`}}], 
     PolygonBox[{{1.963085754776378, 2.295754400939891}, {1.9630857547763783`,
       2.295754400939891}, {1.9446286321645672`, 2.4436316014098365`}, {
      1.9446286321645672`, 2.4436316014098365`}, {1.963085754776378, 
      2.295754400939891}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.055371367835433, 1.5563683985901635`}, {2.0369142452236217`,
        1.7042455990601089`}, {2.018457122611811, 1.8521227995300544`}, {2., 
       2.}, {1.9815428773881891`, 2.1478772004699453`}, {1.963085754776378, 
       2.295754400939891}, {1.9446286321645672`, 2.4436316014098365`}, {
       1.9446286321645672`, 2.4436316014098365`}, {1.963085754776378, 
       2.295754400939891}, {1.9815428773881891`, 2.1478772004699453`}, {2., 
       2.}, {2.018457122611811, 1.8521227995300544`}, {2.0369142452236217`, 
       1.7042455990601089`}, {2.055371367835433, 1.5563683985901635`}, {
       2.055371367835433, 1.5563683985901635`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5545275870096076`, 1.9487651109635529`}, {
        1.5545275870096076`, 1.9487651109635529`}, {1.7030183913397383`, 
        1.9658434073090352`}, {1.7030183913397383`, 1.9658434073090352`}, {
        1.5545275870096076`, 1.9487651109635529`}}], 
       PolygonBox[{{1.7030183913397383`, 1.9658434073090352`}, {
        1.7030183913397383`, 1.9658434073090352`}, {1.851509195669869, 
        1.9829217036545177`}, {1.8515091956698693`, 1.9829217036545177`}, {
        1.7030183913397383`, 1.9658434073090352`}}], 
       PolygonBox[{{1.8515091956698693`, 1.9829217036545177`}, {
        1.851509195669869, 1.9829217036545177`}, {1.9999999999999998`, 2.}, {
        2., 2.}, {1.8515091956698693`, 1.9829217036545177`}}], 
       PolygonBox[{{2., 2.}, {2., 2.}, {2.1484908043301307`, 
        2.0170782963454825`}, {2.1484908043301307`, 2.0170782963454825`}, {2.,
         2.}}], PolygonBox[{{2.1484908043301307`, 2.0170782963454825`}, {
        2.1484908043301307`, 2.0170782963454825`}, {2.2969816086602615`, 
        2.0341565926909646`}, {2.2969816086602615`, 2.034156592690965}, {
        2.1484908043301307`, 2.0170782963454825`}}], 
       PolygonBox[{{2.2969816086602615`, 2.034156592690965}, {
        2.2969816086602615`, 2.0341565926909646`}, {2.4454724129903926`, 
        2.051234889036447}, {2.445472412990392, 2.051234889036447}, {
        2.2969816086602615`, 2.034156592690965}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5545275870096076`, 1.9487651109635529`}, {
         1.7030183913397383`, 1.9658434073090352`}, {1.8515091956698693`, 
         1.9829217036545177`}, {2., 2.}, {2.1484908043301307`, 
         2.0170782963454825`}, {2.2969816086602615`, 2.0341565926909646`}, {
         2.445472412990392, 2.051234889036447}, {2.4454724129903926`, 
         2.051234889036447}, {2.2969816086602615`, 2.0341565926909646`}, {
         2.1484908043301307`, 2.0170782963454825`}, {2., 2.}, {
         1.8515091956698693`, 1.9829217036545177`}, {1.7030183913397383`, 
         1.9658434073090352`}, {1.5545275870096076`, 1.9487651109635529`}, {
         1.5545275870096076`, 1.9487651109635529`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.6098989548450404`, 1.5051335095537164`}, {
      1.4991562191741747`, 2.3923967123733894`}, {2.39010104515496, 
      2.4948664904462836`}, {2.500843780825825, 1.6076032876266106`}, {
      1.6098989548450404`, 1.5051335095537164`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.6098989548450404`, 1.5051335095537164`}, {
       1.4991562191741747`, 2.3923967123733894`}, {2.39010104515496, 
       2.4948664904462836`}, {2.500843780825825, 1.6076032876266106`}, {
       1.6098989548450404`, 1.5051335095537164`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.0818820437217354`, 2.5638524455621345`}, {
      2.0818820437217354`, 2.5638524455621345`}, {2.0545880291478236`, 
      2.7092349637080897`}, {2.0545880291478236`, 2.7092349637080897`}, {
      2.0818820437217354`, 2.5638524455621345`}}], 
     PolygonBox[{{2.0545880291478236`, 2.7092349637080897`}, {
      2.0545880291478236`, 2.7092349637080897`}, {2.027294014573912, 
      2.854617481854045}, {2.027294014573912, 2.854617481854045}, {
      2.0545880291478236`, 2.7092349637080897`}}], 
     PolygonBox[{{2.027294014573912, 2.854617481854045}, {2.027294014573912, 
      2.854617481854045}, {2., 3.}, {2., 3.}, {2.027294014573912, 
      2.854617481854045}}], 
     PolygonBox[{{2., 3.}, {2., 3.}, {1.9727059854260882`, 
      3.145382518145955}, {1.9727059854260882`, 3.145382518145955}, {2., 
      3.}}], PolygonBox[{{1.9727059854260882`, 3.145382518145955}, {
      1.9727059854260882`, 3.145382518145955}, {1.9454119708521764`, 
      3.2907650362919103`}, {1.9454119708521764`, 3.2907650362919103`}, {
      1.9727059854260882`, 3.145382518145955}}], 
     PolygonBox[{{1.9454119708521764`, 3.2907650362919103`}, {
      1.9454119708521764`, 3.2907650362919103`}, {1.9181179562782646`, 
      3.4361475544378655`}, {1.9181179562782646`, 3.4361475544378655`}, {
      1.9454119708521764`, 3.2907650362919103`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0818820437217354`, 2.5638524455621345`}, {
       2.0545880291478236`, 2.7092349637080897`}, {2.027294014573912, 
       2.854617481854045}, {2., 3.}, {1.9727059854260882`, 
       3.145382518145955}, {1.9454119708521764`, 3.2907650362919103`}, {
       1.9181179562782646`, 3.4361475544378655`}, {1.9181179562782646`, 
       3.4361475544378655`}, {1.9454119708521764`, 3.2907650362919103`}, {
       1.9727059854260882`, 3.145382518145955}, {2., 3.}, {2.027294014573912, 
       2.854617481854045}, {2.0545880291478236`, 2.7092349637080897`}, {
       2.0818820437217354`, 2.5638524455621345`}, {2.0818820437217354`, 
       2.5638524455621345`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5588209983435757`, 2.925363268601707}, {
        1.5588209983435757`, 2.925363268601707}, {1.705880665562384, 
        2.950242179067805}, {1.7058806655623837`, 2.9502421790678044`}, {
        1.5588209983435757`, 2.925363268601707}}], 
       PolygonBox[{{1.7058806655623837`, 2.9502421790678044`}, {
        1.705880665562384, 2.950242179067805}, {1.8529403327811917`, 
        2.975121089533902}, {1.852940332781192, 2.975121089533902}, {
        1.7058806655623837`, 2.9502421790678044`}}], 
       PolygonBox[{{1.852940332781192, 2.975121089533902}, {
        1.8529403327811917`, 2.975121089533902}, {1.9999999999999998`, 3.}, {
        2., 3.}, {1.852940332781192, 2.975121089533902}}], 
       PolygonBox[{{2., 3.}, {2., 3.}, {2.1470596672188083`, 
        3.024878910466098}, {2.1470596672188083`, 3.024878910466098}, {2., 
        3.}}], PolygonBox[{{2.1470596672188083`, 3.024878910466098}, {
        2.1470596672188083`, 3.024878910466098}, {2.294119334437616, 
        3.0497578209321956`}, {2.294119334437616, 3.0497578209321956`}, {
        2.1470596672188083`, 3.024878910466098}}], 
       PolygonBox[{{2.294119334437616, 3.0497578209321956`}, {
        2.294119334437616, 3.0497578209321956`}, {2.4411790016564243`, 
        3.074636731398293}, {2.4411790016564243`, 3.074636731398293}, {
        2.294119334437616, 3.0497578209321956`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5588209983435757`, 2.925363268601707}, {
         1.7058806655623837`, 2.9502421790678044`}, {1.852940332781192, 
         2.975121089533902}, {2., 3.}, {2.1470596672188083`, 
         3.024878910466098}, {2.294119334437616, 3.0497578209321956`}, {
         2.4411790016564243`, 3.074636731398293}, {2.4411790016564243`, 
         3.074636731398293}, {2.294119334437616, 3.0497578209321956`}, {
         2.1470596672188083`, 3.024878910466098}, {2., 3.}, {
         1.852940332781192, 2.975121089533902}, {1.705880665562384, 
         2.9502421790678044`}, {1.5588209983435757`, 2.925363268601707}, {
         1.5588209983435757`, 2.925363268601707}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.640703042065311, 2.489215714163841}, {1.4769389546218403`,
       3.3615108230395725`}, {2.359296957934689, 3.510784285836159}, {
      2.5230610453781597`, 2.6384891769604275`}, {1.640703042065311, 
      2.489215714163841}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.640703042065311, 2.489215714163841}, {1.4769389546218403`, 
       3.3615108230395725`}, {2.359296957934689, 3.510784285836159}, {
       2.5230610453781597`, 2.6384891769604275`}, {1.640703042065311, 
       2.489215714163841}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.107096261672285, 3.5735323502200993`}, {2.107096261672285,
       3.5735323502200993`}, {2.0713975077815237`, 3.715688233480066}, {
      2.071397507781523, 3.715688233480066}, {2.107096261672285, 
      3.5735323502200993`}}], 
     PolygonBox[{{2.071397507781523, 3.715688233480066}, {2.0713975077815237`,
       3.715688233480066}, {2.035698753890762, 3.8578441167400332`}, {
      2.035698753890762, 3.8578441167400332`}, {2.071397507781523, 
      3.715688233480066}}], 
     PolygonBox[{{2.035698753890762, 3.8578441167400332`}, {2.035698753890762,
       3.8578441167400332`}, {2., 4.}, {2., 4.}, {2.035698753890762, 
      3.8578441167400332`}}], 
     PolygonBox[{{2., 4.}, {2., 4.}, {1.9643012461092384`, 
      4.142155883259967}, {1.9643012461092384`, 4.142155883259967}, {2., 
      4.}}], PolygonBox[{{1.9643012461092384`, 4.142155883259967}, {
      1.9643012461092384`, 4.142155883259967}, {1.9286024922184768`, 
      4.2843117665199335`}, {1.9286024922184766`, 4.2843117665199335`}, {
      1.9643012461092384`, 4.142155883259967}}], 
     PolygonBox[{{1.9286024922184766`, 4.2843117665199335`}, {
      1.9286024922184768`, 4.2843117665199335`}, {1.892903738327715, 
      4.426467649779901}, {1.892903738327715, 4.426467649779901}, {
      1.9286024922184766`, 4.2843117665199335`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.107096261672285, 3.5735323502200993`}, {2.071397507781523, 
       3.715688233480066}, {2.035698753890762, 3.8578441167400332`}, {2., 
       4.}, {1.9643012461092384`, 4.142155883259967}, {1.9286024922184766`, 
       4.2843117665199335`}, {1.892903738327715, 4.426467649779901}, {
       1.892903738327715, 4.426467649779901}, {1.9286024922184766`, 
       4.2843117665199335`}, {1.9643012461092384`, 4.142155883259967}, {2., 
       4.}, {2.035698753890762, 3.8578441167400332`}, {2.071397507781523, 
       3.715688233480066}, {2.107096261672285, 3.5735323502200993`}, {
       2.107096261672285, 3.5735323502200993`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5645326466546545`, 3.9043143980160577`}, {
        1.5645326466546545`, 3.9043143980160577`}, {1.709688431103103, 
        3.936209598677372}, {1.709688431103103, 3.936209598677372}, {
        1.5645326466546545`, 3.9043143980160577`}}], 
       PolygonBox[{{1.709688431103103, 3.936209598677372}, {1.709688431103103,
         3.936209598677372}, {1.8548442155515514`, 3.9681047993386858`}, {
        1.8548442155515514`, 3.9681047993386858`}, {1.709688431103103, 
        3.936209598677372}}], 
       PolygonBox[{{1.8548442155515514`, 3.9681047993386858`}, {
        1.8548442155515514`, 3.9681047993386858`}, {1.9999999999999998`, 
        4.}, {2., 4.}, {1.8548442155515514`, 3.9681047993386858`}}], 
       PolygonBox[{{2., 4.}, {2., 4.}, {2.1451557844484483`, 
        4.031895200661314}, {2.1451557844484483`, 4.031895200661314}, {2., 
        4.}}], PolygonBox[{{2.1451557844484483`, 4.031895200661314}, {
        2.1451557844484483`, 4.031895200661314}, {2.2903115688968967`, 
        4.0637904013226285`}, {2.2903115688968967`, 4.0637904013226285`}, {
        2.1451557844484483`, 4.031895200661314}}], 
       PolygonBox[{{2.2903115688968967`, 4.0637904013226285`}, {
        2.2903115688968967`, 4.0637904013226285`}, {2.4354673533453455`, 
        4.095685601983942}, {2.4354673533453455`, 4.095685601983942}, {
        2.2903115688968967`, 4.0637904013226285`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5645326466546545`, 3.9043143980160577`}, {
         1.709688431103103, 3.9362095986773715`}, {1.8548442155515514`, 
         3.9681047993386858`}, {2., 4.}, {2.1451557844484483`, 
         4.031895200661314}, {2.2903115688968967`, 4.0637904013226285`}, {
         2.4354673533453455`, 4.095685601983942}, {2.4354673533453455`, 
         4.095685601983942}, {2.290311568896897, 4.0637904013226285`}, {
         2.1451557844484483`, 4.031895200661314}, {2., 4.}, {
         1.8548442155515517`, 3.9681047993386858`}, {1.709688431103103, 
         3.936209598677372}, {1.5645326466546547`, 3.9043143980160577`}, {
         1.5645326466546545`, 3.9043143980160577`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.6716289083269396`, 3.477846748236157}, {
      1.4574363849823695`, 4.330782047795958}, {2.3283710916730604`, 
      4.522153251763843}, {2.5425636150176305`, 3.6692179522040416`}, {
      1.6716289083269396`, 3.477846748236157}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.6716289083269396`, 3.477846748236157}, {1.4574363849823695`,
        4.330782047795958}, {2.3283710916730604`, 4.522153251763843}, {
       2.5425636150176305`, 3.6692179522040416`}, {1.6716289083269396`, 
       3.477846748236157}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.130747825118258, 4.584785385294185}, {2.1307478251182586`,
       4.584785385294185}, {2.0871652167455057`, 4.72319025686279}, {
      2.0871652167455057`, 4.7231902568627895`}, {2.130747825118258, 
      4.584785385294185}}], 
     PolygonBox[{{2.0871652167455057`, 4.7231902568627895`}, {
      2.0871652167455057`, 4.72319025686279}, {2.043582608372753, 
      4.861595128431395}, {2.043582608372753, 4.861595128431395}, {
      2.0871652167455057`, 4.7231902568627895`}}], 
     PolygonBox[{{2.043582608372753, 4.861595128431395}, {2.043582608372753, 
      4.861595128431395}, {2., 5.}, {2., 5.}, {2.043582608372753, 
      4.861595128431395}}], 
     PolygonBox[{{2., 5.}, {2., 5.}, {1.9564173916272474`, 
      5.138404871568605}, {1.9564173916272474`, 5.138404871568605}, {2., 
      5.}}], PolygonBox[{{1.9564173916272474`, 5.138404871568605}, {
      1.9564173916272474`, 5.138404871568605}, {1.9128347832544945`, 
      5.27680974313721}, {1.9128347832544945`, 5.27680974313721}, {
      1.9564173916272474`, 5.138404871568605}}], 
     PolygonBox[{{1.9128347832544945`, 5.27680974313721}, {
      1.9128347832544945`, 5.27680974313721}, {1.869252174881742, 
      5.415214614705815}, {1.869252174881742, 5.415214614705815}, {
      1.9128347832544945`, 5.27680974313721}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.130747825118258, 4.584785385294185}, {2.0871652167455057`, 
       4.7231902568627895`}, {2.043582608372753, 4.861595128431395}, {2., 
       5.}, {1.9564173916272474`, 5.138404871568605}, {1.9128347832544945`, 
       5.27680974313721}, {1.869252174881742, 5.415214614705815}, {
       1.869252174881742, 5.415214614705815}, {1.9128347832544945`, 
       5.2768097431372105`}, {1.9564173916272471`, 5.138404871568605}, {2., 
       5.}, {2.043582608372753, 4.861595128431395}, {2.0871652167455053`, 
       4.72319025686279}, {2.130747825118258, 4.584785385294185}, {
       2.130747825118258, 4.584785385294185}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{1.5714121092718345`, 4.885974432860227}, {
        1.5714121092718345`, 4.885974432860227}, {1.7142747395145563`, 
        4.9239829552401515`}, {1.7142747395145563`, 4.9239829552401515`}, {
        1.5714121092718345`, 4.885974432860227}}], 
       PolygonBox[{{1.7142747395145563`, 4.9239829552401515`}, {
        1.7142747395145563`, 4.9239829552401515`}, {1.8571373697572782`, 
        4.961991477620075}, {1.8571373697572782`, 4.961991477620075}, {
        1.7142747395145563`, 4.9239829552401515`}}], 
       PolygonBox[{{1.8571373697572782`, 4.961991477620075}, {
        1.8571373697572782`, 4.961991477620075}, {1.9999999999999998`, 5.}, {
        2., 5.}, {1.8571373697572782`, 4.961991477620075}}], 
       PolygonBox[{{2., 5.}, {2., 5.}, {2.1428626302427216`, 
        5.038008522379925}, {2.1428626302427216`, 5.038008522379925}, {2., 
        5.}}], PolygonBox[{{2.1428626302427216`, 5.038008522379925}, {
        2.1428626302427216`, 5.038008522379925}, {2.2857252604854437`, 
        5.0760170447598485`}, {2.2857252604854437`, 5.0760170447598485`}, {
        2.1428626302427216`, 5.038008522379925}}], 
       PolygonBox[{{2.2857252604854437`, 5.0760170447598485`}, {
        2.2857252604854437`, 5.0760170447598485`}, {2.4285878907281653`, 
        5.114025567139773}, {2.4285878907281653`, 5.114025567139773}, {
        2.2857252604854437`, 5.0760170447598485`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{1.5714121092718345`, 4.885974432860227}, {
         1.7142747395145563`, 4.9239829552401515`}, {1.8571373697572782`, 
         4.961991477620075}, {2., 5.}, {2.1428626302427216`, 
         5.038008522379925}, {2.2857252604854437`, 5.0760170447598485`}, {
         2.4285878907281653`, 5.114025567139773}, {2.4285878907281653`, 
         5.114025567139773}, {2.2857252604854437`, 5.0760170447598485`}, {
         2.142862630242722, 5.038008522379925}, {2., 5.}, {
         1.8571373697572782`, 4.961991477620075}, {1.7142747395145563`, 
         4.9239829552401515`}, {1.5714121092718347`, 4.885974432860227}, {
         1.5714121092718345`, 4.885974432860227}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{1.7021599343900928`, 4.470759818154412}, {
      1.4406642841535762`, 5.301189047566042}, {2.297840065609907, 
      5.529240181845588}, {2.559335715846424, 4.698810952433958}, {
      1.7021599343900928`, 4.470759818154412}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.7021599343900928`, 4.470759818154412}, {1.4406642841535762`,
        5.301189047566042}, {2.297840065609907, 5.529240181845588}, {
       2.559335715846424, 4.698810952433958}, {1.7021599343900928`, 
       4.470759818154412}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.8677794592568007`, -5.415560304174549}, {
      2.8677794592568007`, -5.415560304174549}, {
      2.9118529728378673`, -5.2770402027830325`}, {
      2.9118529728378673`, -5.2770402027830325`}, {
      2.8677794592568007`, -5.415560304174549}}], 
     PolygonBox[{{2.9118529728378673`, -5.2770402027830325`}, {
      2.9118529728378673`, -5.2770402027830325`}, {
      2.9559264864189334`, -5.138520101391516}, {
      2.9559264864189334`, -5.138520101391516}, {
      2.9118529728378673`, -5.2770402027830325`}}], 
     PolygonBox[{{2.9559264864189334`, -5.138520101391516}, {
      2.9559264864189334`, -5.138520101391516}, {3., -5.}, {3., -5.}, {
      2.9559264864189334`, -5.138520101391516}}], 
     PolygonBox[{{3., -5.}, {3., -5.}, {
      3.0440735135810666`, -4.861479898608484}, {
      3.0440735135810666`, -4.861479898608484}, {3., -5.}}], 
     PolygonBox[{{3.0440735135810666`, -4.861479898608484}, {
      3.0440735135810666`, -4.861479898608484}, {
      3.0881470271621327`, -4.7229597972169675`}, {
      3.0881470271621327`, -4.7229597972169675`}, {
      3.0440735135810666`, -4.861479898608484}}], 
     PolygonBox[{{3.0881470271621327`, -4.7229597972169675`}, {
      3.0881470271621327`, -4.7229597972169675`}, {
      3.1322205407431993`, -4.584439695825451}, {
      3.1322205407431993`, -4.584439695825451}, {
      3.0881470271621327`, -4.7229597972169675`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8677794592568007`, -5.415560304174549}, {
       2.9118529728378673`, -5.2770402027830325`}, {
       2.9559264864189334`, -5.138520101391516}, {3., -5.}, {
       3.0440735135810666`, -4.861479898608484}, {
       3.0881470271621327`, -4.7229597972169675`}, {
       3.1322205407431993`, -4.584439695825451}, {
       3.1322205407431993`, -4.584439695825451}, {
       3.0881470271621327`, -4.7229597972169675`}, {
       3.0440735135810666`, -4.861479898608484}, {3., -5.}, {
       2.9559264864189334`, -5.138520101391516}, {
       2.9118529728378673`, -5.2770402027830325`}, {
       2.8677794592568007`, -5.415560304174549}, {
       2.8677794592568007`, -5.415560304174549}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.573739882665349, -4.888971345140399}, {
        2.573739882665349, -4.888971345140399}, {
        2.7158265884435657`, -4.925980896760265}, {
        2.7158265884435657`, -4.925980896760265}, {
        2.573739882665349, -4.888971345140399}}], 
       PolygonBox[{{2.7158265884435657`, -4.925980896760265}, {
        2.7158265884435657`, -4.925980896760265}, {
        2.857913294221783, -4.962990448380133}, {
        2.857913294221783, -4.962990448380133}, {
        2.7158265884435657`, -4.925980896760265}}], 
       PolygonBox[{{2.857913294221783, -4.962990448380133}, {
        2.857913294221783, -4.962990448380133}, {3., -5.}, {3., -5.}, {
        2.857913294221783, -4.962990448380133}}], 
       PolygonBox[{{3., -5.}, {3., -5.}, {
        3.142086705778217, -5.037009551619867}, {
        3.142086705778217, -5.037009551619867}, {3., -5.}}], 
       PolygonBox[{{3.142086705778217, -5.037009551619867}, {
        3.142086705778217, -5.037009551619867}, {
        3.284173411556434, -5.074019103239735}, {
        3.2841734115564343`, -5.074019103239735}, {
        3.142086705778217, -5.037009551619867}}], 
       PolygonBox[{{3.2841734115564343`, -5.074019103239735}, {
        3.284173411556434, -5.074019103239735}, {
        3.426260117334651, -5.111028654859601}, {
        3.426260117334651, -5.111028654859601}, {
        3.2841734115564343`, -5.074019103239735}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.573739882665349, -4.888971345140399}, {
         2.7158265884435657`, -4.925980896760265}, {
         2.857913294221783, -4.962990448380133}, {3., -5.}, {
         3.142086705778217, -5.037009551619867}, {
         3.2841734115564343`, -5.074019103239735}, {
         3.426260117334651, -5.111028654859601}, {
         3.426260117334651, -5.111028654859601}, {
         3.2841734115564343`, -5.074019103239735}, {
         3.142086705778217, -5.037009551619867}, {3., -5.}, {
         2.857913294221783, -4.962990448380133}, {
         2.7158265884435657`, -4.925980896760265}, {
         2.573739882665349, -4.888971345140399}, {
         2.573739882665349, -4.888971345140399}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.4415193419221497`, -5.3045316493149475`}, {
      2.7059604234085484`, -4.47341104096585}, {
      3.5584806580778503`, -4.6954683506850525`}, {
      3.2940395765914516`, -5.52658895903415}, {
      2.4415193419221497`, -5.3045316493149475`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4415193419221497`, -5.3045316493149475`}, {
       2.7059604234085484`, -4.47341104096585}, {
       3.5584806580778503`, -4.6954683506850525`}, {
       3.2940395765914516`, -5.52658895903415}, {
       2.4415193419221497`, -5.3045316493149475`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.891557308146282, -4.426653187402996}, {
      2.891557308146282, -4.426653187402996}, {
      2.9277048720975216`, -4.284435458268664}, {
      2.927704872097521, -4.284435458268664}, {
      2.891557308146282, -4.426653187402996}}], 
     PolygonBox[{{2.927704872097521, -4.284435458268664}, {
      2.9277048720975216`, -4.284435458268664}, {
      2.963852436048761, -4.142217729134332}, {
      2.963852436048761, -4.142217729134332}, {
      2.927704872097521, -4.284435458268664}}], 
     PolygonBox[{{2.963852436048761, -4.142217729134332}, {
      2.963852436048761, -4.142217729134332}, {3., -4.}, {3., -4.}, {
      2.963852436048761, -4.142217729134332}}], 
     PolygonBox[{{3., -4.}, {3., -4.}, {
      3.036147563951239, -3.857782270865668}, {
      3.036147563951239, -3.857782270865668}, {3., -4.}}], 
     PolygonBox[{{3.036147563951239, -3.857782270865668}, {
      3.036147563951239, -3.857782270865668}, {
      3.072295127902479, -3.715564541731336}, {
      3.072295127902479, -3.715564541731336}, {
      3.036147563951239, -3.857782270865668}}], 
     PolygonBox[{{3.072295127902479, -3.715564541731336}, {
      3.072295127902479, -3.715564541731336}, {
      3.108442691853718, -3.573346812597004}, {
      3.108442691853718, -3.573346812597004}, {
      3.072295127902479, -3.715564541731336}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.891557308146282, -4.426653187402996}, {
       2.927704872097521, -4.284435458268664}, {
       2.963852436048761, -4.142217729134332}, {3., -4.}, {
       3.036147563951239, -3.857782270865668}, {
       3.072295127902479, -3.715564541731336}, {
       3.108442691853718, -3.573346812597004}, {
       3.108442691853718, -3.573346812597004}, {
       3.072295127902479, -3.715564541731336}, {
       3.036147563951239, -3.857782270865668}, {3., -4.}, {
       2.963852436048761, -4.142217729134332}, {
       2.927704872097521, -4.284435458268664}, {
       2.891557308146282, -4.426653187402996}, {
       2.891557308146282, -4.426653187402996}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5665759995290798`, -3.9066874056604184`}, {
        2.5665759995290798`, -3.9066874056604184`}, {
        2.71105066635272, -3.9377916037736123`}, {
        2.71105066635272, -3.9377916037736123`}, {
        2.5665759995290798`, -3.9066874056604184`}}], 
       PolygonBox[{{2.71105066635272, -3.9377916037736123`}, {
        2.71105066635272, -3.9377916037736123`}, {
        2.85552533317636, -3.968895801886806}, {
        2.85552533317636, -3.968895801886806}, {
        2.71105066635272, -3.9377916037736123`}}], 
       PolygonBox[{{2.85552533317636, -3.968895801886806}, {
        2.85552533317636, -3.968895801886806}, {3., -4.}, {3., -4.}, {
        2.85552533317636, -3.968895801886806}}], 
       PolygonBox[{{3., -4.}, {3., -4.}, {
        3.14447466682364, -4.031104198113193}, {
        3.14447466682364, -4.031104198113193}, {3., -4.}}], 
       PolygonBox[{{3.14447466682364, -4.031104198113193}, {
        3.14447466682364, -4.031104198113193}, {
        3.28894933364728, -4.062208396226388}, {
        3.28894933364728, -4.062208396226388}, {
        3.14447466682364, -4.031104198113193}}], 
       PolygonBox[{{3.28894933364728, -4.062208396226388}, {
        3.28894933364728, -4.062208396226388}, {
        3.4334240004709202`, -4.093312594339581}, {
        3.4334240004709202`, -4.093312594339581}, {
        3.28894933364728, -4.062208396226388}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5665759995290798`, -3.9066874056604184`}, {
         2.71105066635272, -3.9377916037736123`}, {
         2.85552533317636, -3.968895801886806}, {3., -4.}, {
         3.14447466682364, -4.031104198113193}, {
         3.28894933364728, -4.062208396226388}, {
         3.4334240004709202`, -4.093312594339581}, {
         3.4334240004709202`, -4.093312594339581}, {
         3.28894933364728, -4.062208396226388}, {
         3.14447466682364, -4.031104198113193}, {3., -4.}, {
         2.85552533317636, -3.968895801886806}, {
         2.71105066635272, -3.9377916037736123`}, {
         2.5665759995290798`, -3.9066874056604184`}, {
         2.5665759995290798`, -3.9066874056604184`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.4581333076753618`, -4.333340593063415}, {
      2.675018691382798, -3.480034218257422}, {
      3.5418666923246382`, -3.666659406936585}, {
      3.324981308617202, -4.519965781742577}, {
      2.4581333076753618`, -4.333340593063415}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4581333076753618`, -4.333340593063415}, {
       2.675018691382798, -3.480034218257422}, {
       3.5418666923246382`, -3.666659406936585}, {
       3.324981308617202, -4.519965781742577}, {
       2.4581333076753618`, -4.333340593063415}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.916995547693319, -3.4362314620775116`}, {
      2.916995547693319, -3.4362314620775116`}, {
      2.9446636984622128`, -3.2908209747183412`}, {
      2.9446636984622128`, -3.2908209747183412`}, {
      2.916995547693319, -3.4362314620775116`}}], 
     PolygonBox[{{2.9446636984622128`, -3.2908209747183412`}, {
      2.9446636984622128`, -3.2908209747183412`}, {
      2.9723318492311064`, -3.145410487359171}, {
      2.9723318492311064`, -3.145410487359171}, {
      2.9446636984622128`, -3.2908209747183412`}}], 
     PolygonBox[{{2.9723318492311064`, -3.145410487359171}, {
      2.9723318492311064`, -3.145410487359171}, {3., -3.}, {3., -3.}, {
      2.9723318492311064`, -3.145410487359171}}], 
     PolygonBox[{{3., -3.}, {3., -3.}, {
      3.0276681507688936`, -2.8545895126408296`}, {
      3.0276681507688936`, -2.8545895126408296`}, {3., -3.}}], 
     PolygonBox[{{3.0276681507688936`, -2.8545895126408296`}, {
      3.0276681507688936`, -2.8545895126408296`}, {
      3.0553363015377872`, -2.7091790252816588`}, {
      3.0553363015377872`, -2.7091790252816588`}, {
      3.0276681507688936`, -2.8545895126408296`}}], 
     PolygonBox[{{3.0553363015377872`, -2.7091790252816588`}, {
      3.0553363015377872`, -2.7091790252816588`}, {
      3.083004452306681, -2.5637685379224884`}, {
      3.083004452306681, -2.5637685379224884`}, {
      3.0553363015377872`, -2.7091790252816588`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.916995547693319, -3.4362314620775116`}, {
       2.9446636984622128`, -3.2908209747183412`}, {
       2.9723318492311064`, -3.145410487359171}, {3., -3.}, {
       3.0276681507688936`, -2.8545895126408296`}, {
       3.0553363015377872`, -2.7091790252816588`}, {
       3.083004452306681, -2.5637685379224884`}, {
       3.083004452306681, -2.5637685379224884`}, {
       3.0553363015377872`, -2.7091790252816588`}, {
       3.0276681507688936`, -2.854589512640829}, {3., -3.}, {
       2.9723318492311064`, -3.1454104873591704`}, {
       2.9446636984622128`, -3.2908209747183412`}, {
       2.916995547693319, -3.4362314620775116`}, {
       2.916995547693319, -3.4362314620775116`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5606022601651173`, -2.927113976710316}, {
        2.5606022601651173`, -2.927113976710316}, {
        2.707068173443411, -2.951409317806877}, {
        2.707068173443411, -2.951409317806877}, {
        2.5606022601651173`, -2.927113976710316}}], 
       PolygonBox[{{2.707068173443411, -2.951409317806877}, {
        2.707068173443411, -2.951409317806877}, {
        2.8535340867217056`, -2.9757046589034384`}, {
        2.8535340867217056`, -2.975704658903439}, {
        2.707068173443411, -2.951409317806877}}], 
       PolygonBox[{{2.8535340867217056`, -2.975704658903439}, {
        2.8535340867217056`, -2.9757046589034384`}, {3., -3.}, {3., -3.}, {
        2.8535340867217056`, -2.975704658903439}}], 
       PolygonBox[{{3., -3.}, {3., -3.}, {
        3.1464659132782944`, -3.024295341096561}, {
        3.1464659132782944`, -3.024295341096561}, {3., -3.}}], 
       PolygonBox[{{3.1464659132782944`, -3.024295341096561}, {
        3.1464659132782944`, -3.024295341096561}, {
        3.292931826556589, -3.048590682193123}, {
        3.292931826556589, -3.048590682193123}, {
        3.1464659132782944`, -3.024295341096561}}], 
       PolygonBox[{{3.292931826556589, -3.048590682193123}, {
        3.292931826556589, -3.048590682193123}, {
        3.4393977398348827`, -3.072886023289684}, {
        3.4393977398348827`, -3.072886023289684}, {
        3.292931826556589, -3.048590682193123}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5606022601651173`, -2.927113976710316}, {
         2.707068173443411, -2.951409317806877}, {
         2.8535340867217056`, -2.975704658903439}, {3., -3.}, {
         3.1464659132782944`, -3.024295341096561}, {
         3.292931826556589, -3.048590682193123}, {
         3.4393977398348827`, -3.072886023289684}, {
         3.4393977398348827`, -3.072886023289684}, {
         3.292931826556589, -3.048590682193123}, {
         3.1464659132782944`, -3.024295341096561}, {3., -3.}, {
         2.8535340867217056`, -2.975704658903439}, {
         2.707068173443411, -2.951409317806877}, {
         2.5606022601651173`, -2.927113976710316}, {
         2.5606022601651173`, -2.927113976710316}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.477597807858436, -3.3633454387878277`}, {
      2.643606712471798, -2.490882514632804}, {
      3.522402192141564, -2.6366545612121723`}, {
      3.356393287528202, -3.509117485367196}, {
      2.477597807858436, -3.3633454387878277`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.477597807858436, -3.3633454387878277`}, {
       2.643606712471798, -2.490882514632804}, {
       3.522402192141564, -2.6366545612121723`}, {
       3.356393287528202, -3.509117485367196}, {
       2.477597807858436, -3.3633454387878277`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.943820711372146, -2.443660950882228}, {
      2.9438207113721466`, -2.443660950882228}, {
      2.9625471409147646`, -2.2957739672548185`}, {
      2.962547140914764, -2.2957739672548185`}, {
      2.943820711372146, -2.443660950882228}}], 
     PolygonBox[{{2.962547140914764, -2.2957739672548185`}, {
      2.9625471409147646`, -2.2957739672548185`}, {
      2.981273570457382, -2.1478869836274095`}, {
      2.981273570457382, -2.1478869836274095`}, {
      2.962547140914764, -2.2957739672548185`}}], 
     PolygonBox[{{2.981273570457382, -2.1478869836274095`}, {
      2.981273570457382, -2.1478869836274095`}, {3., -2.}, {3., -2.}, {
      2.981273570457382, -2.1478869836274095`}}], 
     PolygonBox[{{3., -2.}, {3., -2.}, {
      3.018726429542618, -1.8521130163725907`}, {
      3.018726429542618, -1.8521130163725907`}, {3., -2.}}], 
     PolygonBox[{{3.018726429542618, -1.8521130163725907`}, {
      3.018726429542618, -1.8521130163725907`}, {
      3.037452859085236, -1.7042260327451815`}, {
      3.037452859085236, -1.7042260327451815`}, {
      3.018726429542618, -1.8521130163725907`}}], 
     PolygonBox[{{3.037452859085236, -1.7042260327451815`}, {
      3.037452859085236, -1.7042260327451815`}, {
      3.056179288627854, -1.5563390491177722`}, {
      3.0561792886278534`, -1.5563390491177722`}, {
      3.037452859085236, -1.7042260327451815`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.943820711372146, -2.443660950882228}, {
       2.962547140914764, -2.2957739672548185`}, {
       2.981273570457382, -2.1478869836274095`}, {3., -2.}, {
       3.018726429542618, -1.8521130163725907`}, {
       3.037452859085236, -1.7042260327451815`}, {
       3.0561792886278534`, -1.5563390491177722`}, {
       3.056179288627854, -1.556339049117772}, {
       3.037452859085236, -1.7042260327451815`}, {
       3.018726429542618, -1.8521130163725907`}, {3., -2.}, {
       2.981273570457382, -2.1478869836274095`}, {
       2.962547140914764, -2.2957739672548185`}, {
       2.9438207113721466`, -2.4436609508822276`}, {
       2.943820711372146, -2.443660950882228}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.55609574249356, -1.9499115962367952`}, {
        2.55609574249356, -1.9499115962367952`}, {
        2.70406382832904, -1.9666077308245302`}, {
        2.70406382832904, -1.9666077308245302`}, {
        2.55609574249356, -1.9499115962367952`}}], 
       PolygonBox[{{2.70406382832904, -1.9666077308245302`}, {
        2.70406382832904, -1.9666077308245302`}, {
        2.85203191416452, -1.983303865412265}, {
        2.85203191416452, -1.983303865412265}, {
        2.70406382832904, -1.9666077308245302`}}], 
       PolygonBox[{{2.85203191416452, -1.983303865412265}, {
        2.85203191416452, -1.983303865412265}, {3., -2.}, {3., -2.}, {
        2.85203191416452, -1.983303865412265}}], 
       PolygonBox[{{3., -2.}, {3., -2.}, {
        3.1479680858354797`, -2.016696134587735}, {
        3.1479680858354797`, -2.016696134587735}, {3., -2.}}], 
       PolygonBox[{{3.1479680858354797`, -2.016696134587735}, {
        3.1479680858354797`, -2.016696134587735}, {
        3.29593617167096, -2.03339226917547}, {
        3.29593617167096, -2.0333922691754696`}, {
        3.1479680858354797`, -2.016696134587735}}], 
       PolygonBox[{{3.29593617167096, -2.0333922691754696`}, {
        3.29593617167096, -2.03339226917547}, {
        3.44390425750644, -2.050088403763205}, {
        3.44390425750644, -2.050088403763205}, {
        3.29593617167096, -2.0333922691754696`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.55609574249356, -1.9499115962367952`}, {
         2.70406382832904, -1.9666077308245302`}, {
         2.85203191416452, -1.983303865412265}, {3., -2.}, {
         3.1479680858354797`, -2.016696134587735}, {
         3.29593617167096, -2.03339226917547}, {
         3.44390425750644, -2.050088403763205}, {
         3.44390425750644, -2.050088403763205}, {
         3.29593617167096, -2.03339226917547}, {
         3.14796808583548, -2.016696134587735}, {3., -2.}, {
         2.8520319141645203`, -1.983303865412265}, {
         2.70406382832904, -1.9666077308245302`}, {
         2.55609574249356, -1.9499115962367952`}, {
         2.55609574249356, -1.9499115962367952`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.4999164538657066`, -2.3935725471190232`}, {
      2.612275031121414, -1.5062506453545674`}, {
      3.5000835461342934`, -1.6064274528809768`}, {
      3.387724968878586, -2.493749354645433}, {
      2.4999164538657066`, -2.3935725471190232`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4999164538657066`, -2.3935725471190232`}, {
       2.612275031121414, -1.5062506453545674`}, {
       3.5000835461342934`, -1.6064274528809768`}, {
       3.387724968878586, -2.493749354645433}, {
       2.4999164538657066`, -2.3935725471190232`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.9716473660469473`, -1.4483803026123172`}, {
      2.9716473660469473`, -1.4483803026123172`}, {
      2.9810982440312985`, -1.2989202017415447`}, {
      2.981098244031298, -1.2989202017415449`}, {
      2.9716473660469473`, -1.4483803026123172`}}], 
     PolygonBox[{{2.981098244031298, -1.2989202017415449`}, {
      2.9810982440312985`, -1.2989202017415447`}, {
      2.9905491220156493`, -1.1494601008707725`}, {
      2.9905491220156493`, -1.1494601008707723`}, {
      2.981098244031298, -1.2989202017415449`}}], 
     PolygonBox[{{2.9905491220156493`, -1.1494601008707723`}, {
      2.9905491220156493`, -1.1494601008707725`}, {
      3., -1.0000000000000002`}, {3., -1.}, {
      2.9905491220156493`, -1.1494601008707723`}}], 
     PolygonBox[{{3., -1.}, {3., -1.}, {
      3.0094508779843507`, -0.8505398991292277}, {
      3.0094508779843507`, -0.8505398991292277}, {3., -1.}}], 
     PolygonBox[{{3.0094508779843507`, -0.8505398991292277}, {
      3.0094508779843507`, -0.8505398991292277}, {
      3.018901755968702, -0.7010797982584553}, {
      3.018901755968702, -0.7010797982584552}, {
      3.0094508779843507`, -0.8505398991292277}}], 
     PolygonBox[{{3.018901755968702, -0.7010797982584552}, {
      3.018901755968702, -0.7010797982584553}, {
      3.0283526339530527`, -0.5516196973876828}, {
      3.0283526339530527`, -0.5516196973876829}, {
      3.018901755968702, -0.7010797982584552}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9716473660469473`, -1.4483803026123172`}, {
       2.981098244031298, -1.2989202017415449`}, {
       2.9905491220156493`, -1.1494601008707723`}, {3., -1.}, {
       3.0094508779843507`, -0.8505398991292277}, {
       3.018901755968702, -0.7010797982584552}, {
       3.0283526339530527`, -0.5516196973876829}, {
       3.0283526339530527`, -0.5516196973876828}, {
       3.018901755968702, -0.7010797982584551}, {
       3.0094508779843507`, -0.8505398991292276}, {3., -1.}, {
       2.9905491220156493`, -1.1494601008707723`}, {
       2.981098244031298, -1.2989202017415447`}, {
       2.9716473660469473`, -1.4483803026123172`}, {
       2.9716473660469473`, -1.4483803026123172`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5532881005546524`, -0.9744807449714737}, {
        2.5532881005546524`, -0.9744807449714736}, {
        2.7021920670364348`, -0.9829871633143158}, {
        2.7021920670364348`, -0.9829871633143158}, {
        2.5532881005546524`, -0.9744807449714737}}], 
       PolygonBox[{{2.7021920670364348`, -0.9829871633143158}, {
        2.7021920670364348`, -0.9829871633143158}, {
        2.851096033518217, -0.9914935816571578}, {
        2.8510960335182176`, -0.9914935816571578}, {
        2.7021920670364348`, -0.9829871633143158}}], 
       PolygonBox[{{2.8510960335182176`, -0.9914935816571578}, {
        2.851096033518217, -0.9914935816571578}, {3., -1.}, {3., -1.}, {
        2.8510960335182176`, -0.9914935816571578}}], 
       PolygonBox[{{3., -1.}, {3., -1.}, {
        3.1489039664817824`, -1.008506418342842}, {
        3.1489039664817824`, -1.008506418342842}, {3., -1.}}], 
       PolygonBox[{{3.1489039664817824`, -1.008506418342842}, {
        3.1489039664817824`, -1.008506418342842}, {
        3.2978079329635652`, -1.017012836685684}, {
        3.2978079329635652`, -1.017012836685684}, {
        3.1489039664817824`, -1.008506418342842}}], 
       PolygonBox[{{3.2978079329635652`, -1.017012836685684}, {
        3.2978079329635652`, -1.017012836685684}, {
        3.4467118994453476`, -1.0255192550285264`}, {
        3.4467118994453476`, -1.0255192550285261`}, {
        3.2978079329635652`, -1.017012836685684}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5532881005546524`, -0.9744807449714737}, {
         2.7021920670364348`, -0.9829871633143158}, {
         2.8510960335182176`, -0.991493581657158}, {3., -1.}, {
         3.1489039664817824`, -1.008506418342842}, {
         3.2978079329635652`, -1.017012836685684}, {
         3.4467118994453476`, -1.0255192550285264`}, {
         3.4467118994453476`, -1.0255192550285264`}, {
         3.2978079329635652`, -1.017012836685684}, {
         3.1489039664817824`, -1.008506418342842}, {3., -1.}, {
         2.8510960335182176`, -0.991493581657158}, {
         2.7021920670364348`, -0.9829871633143158}, {
         2.5532881005546524`, -0.9744807449714737}, {
         2.5532881005546524`, -0.9744807449714737}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.5249354666015997`, -1.4228610475837908`}, {
      2.5816407345077046`, -0.5261004423591564}, {
      3.4750645333984003`, -0.5771389524162092}, {
      3.4183592654922954`, -1.4738995576408436`}, {
      2.5249354666015997`, -1.4228610475837908`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5249354666015997`, -1.4228610475837908`}, {
       2.5816407345077046`, -0.5261004423591564}, {
       3.4750645333984003`, -0.5771389524162092}, {
       3.4183592654922954`, -1.4738995576408436`}, {
       2.5249354666015997`, -1.4228610475837908`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3., -0.4499999999999999}, {3., -0.4499999999999999}, {
      3., -0.29999999999999993`}, {3., -0.3}, {3., -0.4499999999999999}}], 
     PolygonBox[{{3., -0.3}, {3., -0.29999999999999993`}, {
      3., -0.15000000000000005`}, {3., -0.15}, {3., -0.3}}], 
     PolygonBox[{{3., -0.15}, {3., -0.15000000000000005`}, {
      3., -1.1102230246251563`*^-16}, {3., 0.}, {3., -0.15}}], 
     PolygonBox[{{3., 0.}, {3., 0.}, {3., 0.14999999999999994`}, {3., 
      0.14999999999999994`}, {3., 0.}}], 
     PolygonBox[{{3., 0.14999999999999994`}, {3., 0.14999999999999994`}, {3., 
      0.2999999999999999}, {3., 0.29999999999999993`}, {3., 
      0.14999999999999994`}}], 
     PolygonBox[{{3., 0.29999999999999993`}, {3., 0.2999999999999999}, {3., 
      0.44999999999999984`}, {3., 0.4499999999999998}, {3., 
      0.29999999999999993`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3., -0.4499999999999999}, {3., -0.3}, {3., -0.15}, {
       3., -5.5511151231257815`*^-17}, {3., 0.14999999999999994`}, {3., 
       0.29999999999999993`}, {3., 0.4499999999999998}, {3., 
       0.4499999999999999}, {3., 0.3}, {3., 0.15}, {3., 
       5.5511151231257815`*^-17}, {3., -0.14999999999999994`}, {
       3., -0.29999999999999993`}, {3., -0.4499999999999998}, {
       3., -0.4499999999999999}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5523340665952334`, 0.}, {2.5523340665952334`, 
        5.5109105961630883`*^-17}, {2.7015560443968223`, 
        4.592425496802573*^-17}, {2.7015560443968223`, 
        9.184850993605147*^-18}, {2.5523340665952334`, 0.}}], 
       PolygonBox[{{2.7015560443968223`, 9.184850993605147*^-18}, {
        2.7015560443968223`, 4.592425496802573*^-17}, {2.850778022198411, 
        3.6739403974420595`*^-17}, {2.850778022198411, 
        1.8369701987210294`*^-17}, {2.7015560443968223`, 
        9.184850993605147*^-18}}], 
       PolygonBox[{{2.850778022198411, 1.8369701987210294`*^-17}, {
        2.850778022198411, 3.6739403974420595`*^-17}, {3., 
        2.7554552980815448`*^-17}, {3., 2.7554552980815442`*^-17}, {
        2.850778022198411, 1.8369701987210294`*^-17}}], 
       PolygonBox[{{3., 2.7554552980815442`*^-17}, {3., 
        2.7554552980815442`*^-17}, {3.149221977801589, 
        1.8369701987210297`*^-17}, {3.149221977801589, 
        3.673940397442059*^-17}, {3., 2.7554552980815442`*^-17}}], 
       PolygonBox[{{3.149221977801589, 3.673940397442059*^-17}, {
        3.149221977801589, 1.8369701987210297`*^-17}, {3.2984439556031777`, 
        9.18485099360515*^-18}, {3.2984439556031777`, 
        4.592425496802573*^-17}, {3.149221977801589, 
        3.673940397442059*^-17}}], 
       PolygonBox[{{3.2984439556031777`, 4.592425496802573*^-17}, {
        3.2984439556031777`, 9.184850993605152*^-18}, {3.4476659334047666`, 
        4.588754872883257*^-33}, {3.4476659334047666`, 
        5.510910596163088*^-17}, {3.2984439556031777`, 
        4.592425496802573*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5523340665952334`, 0.}, {2.7015560443968223`, 0.}, {
         2.850778022198411, 0.}, {3., 0.}, {3.149221977801589, 0.}, {
         3.2984439556031777`, 0.}, {3.4476659334047666`, 0.}, {
         3.4476659334047666`, 0.}, {3.2984439556031777`, 0.}, {
         3.149221977801589, 0.}, {3., 0.}, {2.850778022198411, 0.}, {
         2.7015560443968223`, 0.}, {2.5523340665952334`, 0.}, {
         2.5523340665952334`, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.5523340665952334`, -0.4499999999999999}, {
      2.5523340665952334`, 0.4499999999999999}, {3.4476659334047666`, 
      0.4499999999999999}, {3.4476659334047666`, -0.4499999999999999}, {
      2.5523340665952334`, -0.4499999999999999}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5523340665952334`, -0.4499999999999999}, {
       2.5523340665952334`, 0.4499999999999999}, {3.4476659334047666`, 
       0.4499999999999999}, {3.4476659334047666`, -0.4499999999999999}, {
       2.5523340665952334`, -0.4499999999999999}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.0283526339530527`, 0.5516196973876828}, {
      3.0283526339530527`, 0.5516196973876828}, {3.018901755968702, 
      0.7010797982584552}, {3.018901755968702, 0.7010797982584551}, {
      3.0283526339530527`, 0.5516196973876828}}], 
     PolygonBox[{{3.018901755968702, 0.7010797982584551}, {3.018901755968702, 
      0.7010797982584552}, {3.0094508779843507`, 0.8505398991292276}, {
      3.0094508779843507`, 0.8505398991292276}, {3.018901755968702, 
      0.7010797982584551}}], 
     PolygonBox[{{3.0094508779843507`, 0.8505398991292276}, {
      3.0094508779843507`, 0.8505398991292276}, {3., 0.9999999999999999}, {3.,
       1.}, {3.0094508779843507`, 0.8505398991292276}}], 
     PolygonBox[{{3., 1.}, {3., 1.}, {2.9905491220156493`, 
      1.1494601008707723`}, {2.9905491220156493`, 1.1494601008707723`}, {3., 
      1.}}], PolygonBox[{{2.9905491220156493`, 1.1494601008707723`}, {
      2.9905491220156493`, 1.1494601008707723`}, {2.981098244031298, 
      1.2989202017415447`}, {2.981098244031298, 1.2989202017415447`}, {
      2.9905491220156493`, 1.1494601008707723`}}], 
     PolygonBox[{{2.981098244031298, 1.2989202017415447`}, {2.981098244031298,
       1.2989202017415447`}, {2.9716473660469473`, 1.4483803026123172`}, {
      2.9716473660469473`, 1.4483803026123172`}, {2.981098244031298, 
      1.2989202017415447`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0283526339530527`, 0.5516196973876828}, {3.018901755968702, 
       0.7010797982584551}, {3.0094508779843507`, 0.8505398991292276}, {3., 
       1.}, {2.9905491220156493`, 1.1494601008707723`}, {2.981098244031298, 
       1.2989202017415447`}, {2.9716473660469473`, 1.4483803026123172`}, {
       2.9716473660469473`, 1.4483803026123172`}, {2.981098244031298, 
       1.2989202017415449`}, {2.9905491220156493`, 1.1494601008707723`}, {3., 
       1.}, {3.0094508779843507`, 0.8505398991292277}, {3.018901755968702, 
       0.7010797982584552}, {3.0283526339530527`, 0.5516196973876829}, {
       3.0283526339530527`, 0.5516196973876828}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5532881005546524`, 0.9744807449714737}, {
        2.5532881005546524`, 0.9744807449714737}, {2.7021920670364348`, 
        0.9829871633143159}, {2.7021920670364348`, 0.9829871633143158}, {
        2.5532881005546524`, 0.9744807449714737}}], 
       PolygonBox[{{2.7021920670364348`, 0.9829871633143158}, {
        2.7021920670364348`, 0.9829871633143159}, {2.851096033518217, 
        0.991493581657158}, {2.8510960335182176`, 0.991493581657158}, {
        2.7021920670364348`, 0.9829871633143158}}], 
       PolygonBox[{{2.8510960335182176`, 0.991493581657158}, {
        2.851096033518217, 0.991493581657158}, {3., 1.}, {3., 1.}, {
        2.8510960335182176`, 0.991493581657158}}], 
       PolygonBox[{{3., 1.}, {3., 1.}, {3.1489039664817824`, 
        1.008506418342842}, {3.1489039664817824`, 1.008506418342842}, {3., 
        1.}}], PolygonBox[{{3.1489039664817824`, 1.008506418342842}, {
        3.1489039664817824`, 1.008506418342842}, {3.2978079329635652`, 
        1.017012836685684}, {3.2978079329635652`, 1.0170128366856843`}, {
        3.1489039664817824`, 1.008506418342842}}], 
       PolygonBox[{{3.2978079329635652`, 1.0170128366856843`}, {
        3.2978079329635652`, 1.017012836685684}, {3.4467118994453476`, 
        1.0255192550285264`}, {3.4467118994453476`, 1.0255192550285264`}, {
        3.2978079329635652`, 1.0170128366856843`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5532881005546524`, 0.9744807449714737}, {
         2.7021920670364348`, 0.9829871633143158}, {2.8510960335182176`, 
         0.991493581657158}, {3., 1.}, {3.1489039664817824`, 
         1.008506418342842}, {3.2978079329635652`, 1.017012836685684}, {
         3.4467118994453476`, 1.0255192550285264`}, {3.4467118994453476`, 
         1.0255192550285264`}, {3.2978079329635652`, 1.017012836685684}, {
         3.1489039664817824`, 1.008506418342842}, {3., 1.}, {
         2.8510960335182176`, 0.991493581657158}, {2.7021920670364348`, 
         0.9829871633143158}, {2.5532881005546524`, 0.9744807449714737}, {
         2.5532881005546524`, 0.9744807449714737}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.5816407345077046`, 0.5261004423591564}, {
      2.5249354666015997`, 1.4228610475837908`}, {3.4183592654922954`, 
      1.4738995576408436`}, {3.4750645333984003`, 0.5771389524162092}, {
      2.5816407345077046`, 0.5261004423591564}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5816407345077046`, 0.5261004423591564}, {
       2.5249354666015997`, 1.4228610475837908`}, {3.4183592654922954`, 
       1.4738995576408436`}, {3.4750645333984003`, 0.5771389524162092}, {
       2.5816407345077046`, 0.5261004423591564}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.056179288627854, 1.556339049117772}, {3.056179288627854, 
      1.556339049117772}, {3.037452859085236, 1.7042260327451815`}, {
      3.037452859085236, 1.7042260327451815`}, {3.056179288627854, 
      1.556339049117772}}], 
     PolygonBox[{{3.037452859085236, 1.7042260327451815`}, {3.037452859085236,
       1.7042260327451815`}, {3.018726429542618, 1.8521130163725905`}, {
      3.018726429542618, 1.8521130163725907`}, {3.037452859085236, 
      1.7042260327451815`}}], 
     PolygonBox[{{3.018726429542618, 1.8521130163725907`}, {3.018726429542618,
       1.8521130163725905`}, {3., 2.}, {3., 2.}, {3.018726429542618, 
      1.8521130163725907`}}], 
     PolygonBox[{{3., 2.}, {3., 2.}, {2.981273570457382, 
      2.1478869836274095`}, {2.981273570457382, 2.1478869836274095`}, {3., 
      2.}}], PolygonBox[{{2.981273570457382, 2.1478869836274095`}, {
      2.981273570457382, 2.1478869836274095`}, {2.962547140914764, 
      2.2957739672548185`}, {2.962547140914764, 2.2957739672548185`}, {
      2.981273570457382, 2.1478869836274095`}}], 
     PolygonBox[{{2.962547140914764, 2.2957739672548185`}, {2.962547140914764,
       2.2957739672548185`}, {2.943820711372146, 2.443660950882228}, {
      2.9438207113721466`, 2.4436609508822276`}, {2.962547140914764, 
      2.2957739672548185`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.056179288627854, 1.556339049117772}, {3.037452859085236, 
       1.7042260327451815`}, {3.018726429542618, 1.8521130163725907`}, {3., 
       2.}, {2.981273570457382, 2.1478869836274095`}, {2.962547140914764, 
       2.2957739672548185`}, {2.9438207113721466`, 2.4436609508822276`}, {
       2.943820711372146, 2.443660950882228}, {2.962547140914764, 
       2.2957739672548185`}, {2.981273570457382, 2.1478869836274095`}, {3., 
       2.}, {3.018726429542618, 1.8521130163725907`}, {3.037452859085236, 
       1.7042260327451815`}, {3.0561792886278534`, 1.5563390491177722`}, {
       3.056179288627854, 1.556339049117772}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.55609574249356, 1.9499115962367952`}, {2.55609574249356,
         1.9499115962367954`}, {2.70406382832904, 1.9666077308245302`}, {
        2.70406382832904, 1.9666077308245302`}, {2.55609574249356, 
        1.9499115962367952`}}], 
       PolygonBox[{{2.70406382832904, 1.9666077308245302`}, {2.70406382832904,
         1.9666077308245302`}, {2.85203191416452, 1.9833038654122652`}, {
        2.85203191416452, 1.9833038654122652`}, {2.70406382832904, 
        1.9666077308245302`}}], 
       PolygonBox[{{2.85203191416452, 1.9833038654122652`}, {2.85203191416452,
         1.9833038654122652`}, {3., 2.}, {3., 2.}, {2.85203191416452, 
        1.9833038654122652`}}], 
       PolygonBox[{{3., 2.}, {3., 2.}, {3.1479680858354797`, 
        2.016696134587735}, {3.1479680858354797`, 2.016696134587735}, {3., 
        2.}}], PolygonBox[{{3.1479680858354797`, 2.016696134587735}, {
        3.1479680858354797`, 2.016696134587735}, {3.29593617167096, 
        2.03339226917547}, {3.29593617167096, 2.03339226917547}, {
        3.1479680858354797`, 2.016696134587735}}], 
       PolygonBox[{{3.29593617167096, 2.03339226917547}, {3.29593617167096, 
        2.03339226917547}, {3.44390425750644, 2.050088403763205}, {
        3.44390425750644, 2.050088403763205}, {3.29593617167096, 
        2.03339226917547}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.55609574249356, 1.9499115962367952`}, {2.70406382832904, 
         1.9666077308245302`}, {2.85203191416452, 1.983303865412265}, {3., 
         2.}, {3.1479680858354797`, 2.016696134587735}, {3.29593617167096, 
         2.03339226917547}, {3.44390425750644, 2.050088403763205}, {
         3.44390425750644, 2.050088403763205}, {3.29593617167096, 
         2.03339226917547}, {3.14796808583548, 2.016696134587735}, {3., 2.}, {
         2.8520319141645203`, 1.983303865412265}, {2.70406382832904, 
         1.9666077308245302`}, {2.55609574249356, 1.9499115962367952`}, {
         2.55609574249356, 1.9499115962367952`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.612275031121414, 1.5062506453545674`}, {
      2.4999164538657066`, 2.3935725471190232`}, {3.387724968878586, 
      2.493749354645433}, {3.5000835461342934`, 1.6064274528809768`}, {
      2.612275031121414, 1.5062506453545674`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.612275031121414, 1.5062506453545674`}, {2.4999164538657066`,
        2.3935725471190232`}, {3.387724968878586, 2.493749354645433}, {
       3.5000835461342934`, 1.6064274528809768`}, {2.612275031121414, 
       1.5062506453545674`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.083004452306681, 2.5637685379224884`}, {
      3.0830044523066813`, 2.5637685379224884`}, {3.0553363015377872`, 
      2.7091790252816588`}, {3.0553363015377872`, 2.7091790252816588`}, {
      3.083004452306681, 2.5637685379224884`}}], 
     PolygonBox[{{3.0553363015377872`, 2.7091790252816588`}, {
      3.0553363015377872`, 2.7091790252816588`}, {3.0276681507688936`, 
      2.854589512640829}, {3.0276681507688936`, 2.854589512640829}, {
      3.0553363015377872`, 2.7091790252816588`}}], 
     PolygonBox[{{3.0276681507688936`, 2.854589512640829}, {
      3.0276681507688936`, 2.854589512640829}, {3., 3.}, {3., 3.}, {
      3.0276681507688936`, 2.854589512640829}}], 
     PolygonBox[{{3., 3.}, {3., 3.}, {2.9723318492311064`, 
      3.1454104873591704`}, {2.9723318492311064`, 3.1454104873591704`}, {3., 
      3.}}], PolygonBox[{{2.9723318492311064`, 3.1454104873591704`}, {
      2.9723318492311064`, 3.1454104873591704`}, {2.9446636984622128`, 
      3.2908209747183412`}, {2.9446636984622128`, 3.2908209747183412`}, {
      2.9723318492311064`, 3.1454104873591704`}}], 
     PolygonBox[{{2.9446636984622128`, 3.2908209747183412`}, {
      2.9446636984622128`, 3.2908209747183412`}, {2.916995547693319, 
      3.4362314620775116`}, {2.916995547693319, 3.4362314620775116`}, {
      2.9446636984622128`, 3.2908209747183412`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.083004452306681, 2.5637685379224884`}, {3.0553363015377872`,
        2.7091790252816588`}, {3.0276681507688936`, 2.854589512640829}, {3., 
       3.}, {2.9723318492311064`, 3.1454104873591704`}, {2.9446636984622128`, 
       3.2908209747183412`}, {2.916995547693319, 3.4362314620775116`}, {
       2.916995547693319, 3.4362314620775116`}, {2.9446636984622128`, 
       3.2908209747183412`}, {2.9723318492311064`, 3.145410487359171}, {3., 
       3.}, {3.0276681507688936`, 2.8545895126408296`}, {3.0553363015377872`, 
       2.7091790252816588`}, {3.083004452306681, 2.5637685379224884`}, {
       3.083004452306681, 2.5637685379224884`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5606022601651173`, 2.927113976710316}, {
        2.5606022601651173`, 2.927113976710316}, {2.707068173443411, 
        2.951409317806877}, {2.707068173443411, 2.951409317806877}, {
        2.5606022601651173`, 2.927113976710316}}], 
       PolygonBox[{{2.707068173443411, 2.951409317806877}, {2.707068173443411,
         2.951409317806877}, {2.8535340867217056`, 2.975704658903439}, {
        2.8535340867217056`, 2.975704658903439}, {2.707068173443411, 
        2.951409317806877}}], 
       PolygonBox[{{2.8535340867217056`, 2.975704658903439}, {
        2.8535340867217056`, 2.975704658903439}, {3., 3.}, {3., 3.}, {
        2.8535340867217056`, 2.975704658903439}}], 
       PolygonBox[{{3., 3.}, {3., 3.}, {3.1464659132782944`, 
        3.024295341096561}, {3.1464659132782944`, 3.024295341096561}, {3., 
        3.}}], PolygonBox[{{3.1464659132782944`, 3.024295341096561}, {
        3.1464659132782944`, 3.024295341096561}, {3.292931826556589, 
        3.048590682193123}, {3.292931826556589, 3.048590682193123}, {
        3.1464659132782944`, 3.024295341096561}}], 
       PolygonBox[{{3.292931826556589, 3.048590682193123}, {3.292931826556589,
         3.048590682193123}, {3.4393977398348827`, 3.072886023289684}, {
        3.4393977398348827`, 3.072886023289684}, {3.292931826556589, 
        3.048590682193123}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5606022601651173`, 2.927113976710316}, {2.707068173443411,
          2.951409317806877}, {2.8535340867217056`, 2.975704658903439}, {3., 
         3.}, {3.1464659132782944`, 3.024295341096561}, {3.292931826556589, 
         3.048590682193123}, {3.4393977398348827`, 3.072886023289684}, {
         3.4393977398348827`, 3.072886023289684}, {3.292931826556589, 
         3.048590682193123}, {3.1464659132782944`, 3.024295341096561}, {3., 
         3.}, {2.8535340867217056`, 2.975704658903439}, {2.707068173443411, 
         2.951409317806877}, {2.5606022601651173`, 2.927113976710316}, {
         2.5606022601651173`, 2.927113976710316}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.643606712471798, 2.490882514632804}, {2.477597807858436, 
      3.3633454387878277`}, {3.356393287528202, 3.509117485367196}, {
      3.522402192141564, 2.6366545612121723`}, {2.643606712471798, 
      2.490882514632804}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.643606712471798, 2.490882514632804}, {2.477597807858436, 
       3.3633454387878277`}, {3.356393287528202, 3.509117485367196}, {
       3.522402192141564, 2.6366545612121723`}, {2.643606712471798, 
       2.490882514632804}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.108442691853718, 3.573346812597004}, {3.108442691853718, 
      3.573346812597004}, {3.072295127902479, 3.715564541731336}, {
      3.072295127902479, 3.715564541731336}, {3.108442691853718, 
      3.573346812597004}}], 
     PolygonBox[{{3.072295127902479, 3.715564541731336}, {3.072295127902479, 
      3.715564541731336}, {3.0361475639512396`, 3.857782270865668}, {
      3.036147563951239, 3.857782270865668}, {3.072295127902479, 
      3.715564541731336}}], 
     PolygonBox[{{3.036147563951239, 3.857782270865668}, {3.0361475639512396`,
       3.857782270865668}, {3., 4.}, {3., 4.}, {3.036147563951239, 
      3.857782270865668}}], 
     PolygonBox[{{3., 4.}, {3., 4.}, {2.963852436048761, 4.142217729134332}, {
      2.963852436048761, 4.142217729134332}, {3., 4.}}], 
     PolygonBox[{{2.963852436048761, 4.142217729134332}, {2.963852436048761, 
      4.142217729134332}, {2.927704872097521, 4.284435458268664}, {
      2.927704872097521, 4.284435458268664}, {2.963852436048761, 
      4.142217729134332}}], 
     PolygonBox[{{2.927704872097521, 4.284435458268664}, {2.927704872097521, 
      4.284435458268664}, {2.891557308146282, 4.426653187402996}, {
      2.891557308146282, 4.426653187402996}, {2.927704872097521, 
      4.284435458268664}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.108442691853718, 3.573346812597004}, {3.072295127902479, 
       3.715564541731336}, {3.036147563951239, 3.857782270865668}, {3., 4.}, {
       2.963852436048761, 4.142217729134332}, {2.927704872097521, 
       4.284435458268664}, {2.891557308146282, 4.426653187402996}, {
       2.891557308146282, 4.426653187402996}, {2.927704872097521, 
       4.284435458268664}, {2.963852436048761, 4.142217729134332}, {3., 4.}, {
       3.036147563951239, 3.857782270865668}, {3.072295127902479, 
       3.715564541731336}, {3.108442691853718, 3.573346812597004}, {
       3.108442691853718, 3.573346812597004}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.5665759995290798`, 3.9066874056604184`}, {
        2.5665759995290798`, 3.9066874056604184`}, {2.71105066635272, 
        3.9377916037736123`}, {2.71105066635272, 3.9377916037736123`}, {
        2.5665759995290798`, 3.9066874056604184`}}], 
       PolygonBox[{{2.71105066635272, 3.9377916037736123`}, {2.71105066635272,
         3.9377916037736123`}, {2.85552533317636, 3.968895801886806}, {
        2.85552533317636, 3.968895801886806}, {2.71105066635272, 
        3.9377916037736123`}}], 
       PolygonBox[{{2.85552533317636, 3.968895801886806}, {2.85552533317636, 
        3.968895801886806}, {3., 4.}, {3., 4.}, {2.85552533317636, 
        3.968895801886806}}], 
       PolygonBox[{{3., 4.}, {3., 4.}, {3.14447466682364, 
        4.031104198113193}, {3.14447466682364, 4.031104198113193}, {3., 4.}}],
        PolygonBox[{{3.14447466682364, 4.031104198113193}, {3.14447466682364, 
        4.031104198113193}, {3.28894933364728, 4.062208396226388}, {
        3.28894933364728, 4.062208396226388}, {3.14447466682364, 
        4.031104198113193}}], 
       PolygonBox[{{3.28894933364728, 4.062208396226388}, {3.28894933364728, 
        4.062208396226388}, {3.4334240004709202`, 4.093312594339581}, {
        3.4334240004709202`, 4.093312594339581}, {3.28894933364728, 
        4.062208396226388}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.5665759995290798`, 3.9066874056604184`}, {
         2.71105066635272, 3.9377916037736123`}, {2.85552533317636, 
         3.968895801886806}, {3., 4.}, {3.14447466682364, 
         4.031104198113193}, {3.28894933364728, 4.062208396226388}, {
         3.4334240004709202`, 4.093312594339581}, {3.4334240004709202`, 
         4.093312594339581}, {3.28894933364728, 4.062208396226388}, {
         3.14447466682364, 4.031104198113193}, {3., 4.}, {2.85552533317636, 
         3.968895801886806}, {2.71105066635272, 3.9377916037736123`}, {
         2.5665759995290798`, 3.9066874056604184`}, {2.5665759995290798`, 
         3.9066874056604184`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.675018691382798, 3.480034218257422}, {2.4581333076753618`,
       4.333340593063415}, {3.324981308617202, 4.519965781742577}, {
      3.5418666923246382`, 3.666659406936585}, {2.675018691382798, 
      3.480034218257422}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.675018691382798, 3.480034218257422}, {2.4581333076753618`, 
       4.333340593063415}, {3.324981308617202, 4.519965781742577}, {
       3.5418666923246382`, 3.666659406936585}, {2.675018691382798, 
       3.480034218257422}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.1322205407431993`, 4.584439695825451}, {
      3.1322205407431993`, 4.584439695825451}, {3.088147027162133, 
      4.7229597972169675`}, {3.0881470271621327`, 4.7229597972169675`}, {
      3.1322205407431993`, 4.584439695825451}}], 
     PolygonBox[{{3.0881470271621327`, 4.7229597972169675`}, {
      3.088147027162133, 4.7229597972169675`}, {3.0440735135810666`, 
      4.861479898608484}, {3.0440735135810666`, 4.861479898608484}, {
      3.0881470271621327`, 4.7229597972169675`}}], 
     PolygonBox[{{3.0440735135810666`, 4.861479898608484}, {
      3.0440735135810666`, 4.861479898608484}, {3., 5.}, {3., 5.}, {
      3.0440735135810666`, 4.861479898608484}}], 
     PolygonBox[{{3., 5.}, {3., 5.}, {2.9559264864189334`, 
      5.138520101391516}, {2.9559264864189334`, 5.138520101391516}, {3., 
      5.}}], PolygonBox[{{2.9559264864189334`, 5.138520101391516}, {
      2.9559264864189334`, 5.138520101391516}, {2.9118529728378673`, 
      5.2770402027830325`}, {2.9118529728378673`, 5.2770402027830325`}, {
      2.9559264864189334`, 5.138520101391516}}], 
     PolygonBox[{{2.9118529728378673`, 5.2770402027830325`}, {
      2.9118529728378673`, 5.2770402027830325`}, {2.8677794592568007`, 
      5.415560304174549}, {2.8677794592568007`, 5.415560304174549}, {
      2.9118529728378673`, 5.2770402027830325`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1322205407431993`, 4.584439695825451}, {3.0881470271621327`,
        4.7229597972169675`}, {3.0440735135810666`, 4.861479898608484}, {3., 
       5.}, {2.9559264864189334`, 5.138520101391516}, {2.9118529728378673`, 
       5.2770402027830325`}, {2.8677794592568007`, 5.415560304174549}, {
       2.8677794592568007`, 5.415560304174549}, {2.9118529728378673`, 
       5.2770402027830325`}, {2.9559264864189334`, 5.138520101391516}, {3., 
       5.}, {3.0440735135810666`, 4.861479898608484}, {3.0881470271621327`, 
       4.7229597972169675`}, {3.1322205407431993`, 4.584439695825451}, {
       3.1322205407431993`, 4.584439695825451}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{2.573739882665349, 4.888971345140399}, {2.573739882665349,
         4.888971345140399}, {2.7158265884435657`, 4.925980896760265}, {
        2.7158265884435657`, 4.925980896760265}, {2.573739882665349, 
        4.888971345140399}}], 
       PolygonBox[{{2.7158265884435657`, 4.925980896760265}, {
        2.7158265884435657`, 4.925980896760265}, {2.857913294221783, 
        4.962990448380133}, {2.857913294221783, 4.962990448380133}, {
        2.7158265884435657`, 4.925980896760265}}], 
       PolygonBox[{{2.857913294221783, 4.962990448380133}, {2.857913294221783,
         4.962990448380133}, {3., 5.}, {3., 5.}, {2.857913294221783, 
        4.962990448380133}}], 
       PolygonBox[{{3., 5.}, {3., 5.}, {3.142086705778217, 
        5.037009551619867}, {3.142086705778217, 5.037009551619867}, {3., 
        5.}}], PolygonBox[{{3.142086705778217, 5.037009551619867}, {
        3.142086705778217, 5.037009551619867}, {3.284173411556434, 
        5.074019103239735}, {3.2841734115564343`, 5.074019103239735}, {
        3.142086705778217, 5.037009551619867}}], 
       PolygonBox[{{3.2841734115564343`, 5.074019103239735}, {
        3.284173411556434, 5.074019103239735}, {3.426260117334651, 
        5.111028654859601}, {3.426260117334651, 5.111028654859601}, {
        3.2841734115564343`, 5.074019103239735}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{2.573739882665349, 4.888971345140399}, {2.7158265884435657`,
          4.925980896760265}, {2.857913294221783, 4.962990448380133}, {3., 
         5.}, {3.142086705778217, 5.037009551619867}, {3.2841734115564343`, 
         5.074019103239735}, {3.426260117334651, 5.111028654859601}, {
         3.426260117334651, 5.111028654859601}, {3.2841734115564343`, 
         5.074019103239735}, {3.142086705778217, 5.037009551619867}, {3., 
         5.}, {2.857913294221783, 4.962990448380133}, {2.7158265884435657`, 
         4.925980896760265}, {2.573739882665349, 4.888971345140399}, {
         2.573739882665349, 4.888971345140399}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{2.7059604234085484`, 4.47341104096585}, {
      2.4415193419221497`, 5.3045316493149475`}, {3.2940395765914516`, 
      5.52658895903415}, {3.5584806580778503`, 4.6954683506850525`}, {
      2.7059604234085484`, 4.47341104096585}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7059604234085484`, 4.47341104096585}, {2.4415193419221497`, 
       5.3045316493149475`}, {3.2940395765914516`, 5.52658895903415}, {
       3.5584806580778503`, 4.6954683506850525`}, {2.7059604234085484`, 
       4.47341104096585}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.8666649194187164`, -5.416125973605159}, {
      3.8666649194187164`, -5.416125973605159}, {
      3.911109946279144, -5.277417315736773}, {
      3.911109946279144, -5.277417315736773}, {
      3.8666649194187164`, -5.416125973605159}}], 
     PolygonBox[{{3.911109946279144, -5.277417315736773}, {
      3.911109946279144, -5.277417315736773}, {
      3.9555549731395723`, -5.138708657868387}, {
      3.9555549731395723`, -5.138708657868387}, {
      3.911109946279144, -5.277417315736773}}], 
     PolygonBox[{{3.9555549731395723`, -5.138708657868387}, {
      3.9555549731395723`, -5.138708657868387}, {4., -5.}, {4., -5.}, {
      3.9555549731395723`, -5.138708657868387}}], 
     PolygonBox[{{4., -5.}, {4., -5.}, {
      4.044445026860428, -4.861291342131613}, {
      4.044445026860428, -4.861291342131613}, {4., -5.}}], 
     PolygonBox[{{4.044445026860428, -4.861291342131613}, {
      4.044445026860428, -4.861291342131613}, {
      4.0888900537208555`, -4.7225826842632275`}, {
      4.0888900537208555`, -4.722582684263227}, {
      4.044445026860428, -4.861291342131613}}], 
     PolygonBox[{{4.0888900537208555`, -4.722582684263227}, {
      4.0888900537208555`, -4.7225826842632275`}, {
      4.133335080581284, -4.583874026394841}, {
      4.133335080581284, -4.583874026394841}, {
      4.0888900537208555`, -4.722582684263227}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8666649194187164`, -5.416125973605159}, {
       3.911109946279144, -5.277417315736773}, {
       3.9555549731395723`, -5.138708657868387}, {4., -5.}, {
       4.044445026860428, -4.861291342131613}, {
       4.0888900537208555`, -4.722582684263227}, {
       4.133335080581284, -4.583874026394841}, {
       4.133335080581284, -4.583874026394841}, {
       4.0888900537208555`, -4.722582684263227}, {
       4.044445026860428, -4.861291342131613}, {4., -5.}, {
       3.9555549731395723`, -5.138708657868387}, {
       3.911109946279144, -5.277417315736773}, {
       3.8666649194187164`, -5.416125973605159}, {
       3.8666649194187164`, -5.416125973605159}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5767723830849816`, -4.892478233005866}, {
        3.5767723830849816`, -4.892478233005866}, {
        3.7178482553899874`, -4.928318822003911}, {
        3.7178482553899874`, -4.928318822003911}, {
        3.5767723830849816`, -4.892478233005866}}], 
       PolygonBox[{{3.7178482553899874`, -4.928318822003911}, {
        3.7178482553899874`, -4.928318822003911}, {
        3.8589241276949937`, -4.964159411001956}, {
        3.8589241276949937`, -4.964159411001956}, {
        3.7178482553899874`, -4.928318822003911}}], 
       PolygonBox[{{3.8589241276949937`, -4.964159411001956}, {
        3.8589241276949937`, -4.964159411001956}, {4., -5.}, {4., -5.}, {
        3.8589241276949937`, -4.964159411001956}}], 
       PolygonBox[{{4., -5.}, {4., -5.}, {
        4.141075872305006, -5.035840588998044}, {
        4.141075872305006, -5.035840588998044}, {4., -5.}}], 
       PolygonBox[{{4.141075872305006, -5.035840588998044}, {
        4.141075872305006, -5.035840588998044}, {
        4.282151744610013, -5.071681177996089}, {
        4.282151744610013, -5.071681177996089}, {
        4.141075872305006, -5.035840588998044}}], 
       PolygonBox[{{4.282151744610013, -5.071681177996089}, {
        4.282151744610013, -5.071681177996089}, {
        4.423227616915018, -5.107521766994134}, {
        4.423227616915018, -5.107521766994134}, {
        4.282151744610013, -5.071681177996089}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5767723830849816`, -4.892478233005866}, {
         3.7178482553899874`, -4.928318822003911}, {
         3.8589241276949937`, -4.964159411001956}, {4., -5.}, {
         4.141075872305006, -5.035840588998044}, {
         4.282151744610013, -5.071681177996089}, {
         4.423227616915018, -5.107521766994134}, {
         4.423227616915018, -5.107521766994134}, {
         4.282151744610013, -5.071681177996089}, {
         4.141075872305006, -5.035840588998044}, {4., -5.}, {
         3.8589241276949937`, -4.964159411001956}, {
         3.7178482553899874`, -4.928318822003911}, {
         3.5767723830849816`, -4.892478233005866}, {
         3.5767723830849816`, -4.892478233005866}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.443437302503698, -5.308604206611026}, {
      3.710107463666265, -4.476352259400707}, {
      4.556562697496302, -4.691395793388974}, {
      4.289892536333735, -5.523647740599293}, {
      3.443437302503698, -5.308604206611026}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.443437302503698, -5.308604206611026}, {
       3.710107463666265, -4.476352259400707}, {
       4.556562697496302, -4.691395793388974}, {
       4.289892536333735, -5.523647740599293}, {
       3.443437302503698, -5.308604206611026}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.89050744445111, -4.4269948118783935`}, {
      3.89050744445111, -4.4269948118783935`}, {
      3.927004962967407, -4.284663207918929}, {
      3.9270049629674064`, -4.284663207918929}, {
      3.89050744445111, -4.4269948118783935`}}], 
     PolygonBox[{{3.9270049629674064`, -4.284663207918929}, {
      3.927004962967407, -4.284663207918929}, {
      3.963502481483703, -4.142331603959464}, {
      3.963502481483703, -4.142331603959464}, {
      3.9270049629674064`, -4.284663207918929}}], 
     PolygonBox[{{3.963502481483703, -4.142331603959464}, {
      3.963502481483703, -4.142331603959464}, {4., -4.}, {4., -4.}, {
      3.963502481483703, -4.142331603959464}}], 
     PolygonBox[{{4., -4.}, {4., -4.}, {
      4.036497518516296, -3.8576683960405354`}, {
      4.036497518516296, -3.8576683960405354`}, {4., -4.}}], 
     PolygonBox[{{4.036497518516296, -3.8576683960405354`}, {
      4.036497518516296, -3.8576683960405354`}, {
      4.072995037032594, -3.715336792081071}, {
      4.072995037032594, -3.715336792081071}, {
      4.036497518516296, -3.8576683960405354`}}], 
     PolygonBox[{{4.072995037032594, -3.715336792081071}, {
      4.072995037032594, -3.715336792081071}, {
      4.10949255554889, -3.5730051881216065`}, {
      4.10949255554889, -3.5730051881216065`}, {
      4.072995037032594, -3.715336792081071}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.89050744445111, -4.4269948118783935`}, {
       3.9270049629674064`, -4.284663207918929}, {
       3.963502481483703, -4.142331603959464}, {4., -4.}, {
       4.036497518516296, -3.8576683960405354`}, {
       4.072995037032594, -3.715336792081071}, {
       4.10949255554889, -3.5730051881216065`}, {
       4.10949255554889, -3.5730051881216065`}, {
       4.072995037032594, -3.715336792081071}, {
       4.036497518516296, -3.8576683960405354`}, {4., -4.}, {
       3.963502481483703, -4.142331603959464}, {
       3.9270049629674064`, -4.284663207918929}, {
       3.89050744445111, -4.4269948118783935`}, {
       3.89050744445111, -4.4269948118783935`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5693581990138235`, -3.909519002501583}, {
        3.5693581990138235`, -3.909519002501583}, {
        3.712905466009216, -3.9396793350010553`}, {
        3.712905466009216, -3.9396793350010553`}, {
        3.5693581990138235`, -3.909519002501583}}], 
       PolygonBox[{{3.712905466009216, -3.9396793350010553`}, {
        3.712905466009216, -3.9396793350010553`}, {
        3.8564527330046077`, -3.9698396675005276`}, {
        3.8564527330046077`, -3.9698396675005276`}, {
        3.712905466009216, -3.9396793350010553`}}], 
       PolygonBox[{{3.8564527330046077`, -3.9698396675005276`}, {
        3.8564527330046077`, -3.9698396675005276`}, {4., -4.}, {4., -4.}, {
        3.8564527330046077`, -3.9698396675005276`}}], 
       PolygonBox[{{4., -4.}, {4., -4.}, {
        4.143547266995392, -4.030160332499472}, {
        4.143547266995392, -4.030160332499472}, {4., -4.}}], 
       PolygonBox[{{4.143547266995392, -4.030160332499472}, {
        4.143547266995392, -4.030160332499472}, {
        4.287094533990784, -4.060320664998945}, {
        4.287094533990785, -4.060320664998945}, {
        4.143547266995392, -4.030160332499472}}], 
       PolygonBox[{{4.287094533990785, -4.060320664998945}, {
        4.287094533990784, -4.060320664998945}, {
        4.4306418009861765`, -4.090480997498417}, {
        4.4306418009861765`, -4.090480997498417}, {
        4.287094533990785, -4.060320664998945}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5693581990138235`, -3.909519002501583}, {
         3.712905466009216, -3.9396793350010553`}, {
         3.8564527330046077`, -3.9698396675005276`}, {4., -4.}, {
         4.143547266995392, -4.030160332499472}, {
         4.287094533990785, -4.060320664998945}, {
         4.4306418009861765`, -4.090480997498417}, {
         4.4306418009861765`, -4.090480997498417}, {
         4.287094533990785, -4.060320664998945}, {
         4.143547266995392, -4.030160332499472}, {4., -4.}, {
         3.856452733004608, -3.9698396675005276`}, {
         3.712905466009216, -3.9396793350010553`}, {
         3.5693581990138235`, -3.909519002501583}, {
         3.5693581990138235`, -3.909519002501583}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.4598656434649335`, -4.336513814379977}, {
      3.678850754562714, -3.4825241906231894`}, {
      4.5401343565350665`, -3.6634861856200236`}, {
      4.321149245437287, -4.51747580937681}, {
      3.4598656434649335`, -4.336513814379977}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4598656434649335`, -4.336513814379977}, {
       3.678850754562714, -3.4825241906231894`}, {
       4.5401343565350665`, -3.6634861856200236`}, {
       4.321149245437287, -4.51747580937681}, {
       3.4598656434649335`, -4.336513814379977}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.916100877358713, -3.436410638638441}, {
      3.916100877358713, -3.436410638638441}, {
      3.9440672515724753`, -3.290940425758961}, {
      3.9440672515724753`, -3.290940425758961}, {
      3.916100877358713, -3.436410638638441}}], 
     PolygonBox[{{3.9440672515724753`, -3.290940425758961}, {
      3.9440672515724753`, -3.290940425758961}, {
      3.9720336257862376`, -3.1454702128794807`}, {
      3.9720336257862376`, -3.1454702128794807`}, {
      3.9440672515724753`, -3.290940425758961}}], 
     PolygonBox[{{3.9720336257862376`, -3.1454702128794807`}, {
      3.9720336257862376`, -3.1454702128794807`}, {4., -3.}, {4., -3.}, {
      3.9720336257862376`, -3.1454702128794807`}}], 
     PolygonBox[{{4., -3.}, {4., -3.}, {
      4.027966374213762, -2.8545297871205197`}, {
      4.027966374213762, -2.8545297871205197`}, {4., -3.}}], 
     PolygonBox[{{4.027966374213762, -2.8545297871205197`}, {
      4.027966374213762, -2.8545297871205197`}, {
      4.055932748427525, -2.709059574241039}, {
      4.055932748427525, -2.709059574241039}, {
      4.027966374213762, -2.8545297871205197`}}], 
     PolygonBox[{{4.055932748427525, -2.709059574241039}, {
      4.055932748427525, -2.709059574241039}, {
      4.083899122641287, -2.563589361361559}, {
      4.083899122641287, -2.563589361361559}, {
      4.055932748427525, -2.709059574241039}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.916100877358713, -3.436410638638441}, {
       3.9440672515724753`, -3.290940425758961}, {
       3.9720336257862376`, -3.1454702128794807`}, {4., -3.}, {
       4.027966374213762, -2.8545297871205197`}, {
       4.055932748427525, -2.709059574241039}, {
       4.083899122641287, -2.563589361361559}, {
       4.083899122641287, -2.563589361361559}, {
       4.055932748427525, -2.709059574241039}, {
       4.027966374213762, -2.8545297871205193`}, {4., -3.}, {
       3.9720336257862376`, -3.1454702128794803`}, {
       3.9440672515724753`, -3.290940425758961}, {
       3.916100877358713, -3.436410638638441}, {
       3.916100877358713, -3.436410638638441}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5631485346619574`, -2.9292420202153147`}, {
        3.5631485346619574`, -2.929242020215314}, {
        3.708765689774638, -2.9528280134768763`}, {
        3.708765689774638, -2.9528280134768763`}, {
        3.5631485346619574`, -2.9292420202153147`}}], 
       PolygonBox[{{3.708765689774638, -2.9528280134768763`}, {
        3.708765689774638, -2.9528280134768763`}, {
        3.854382844887319, -2.976414006738438}, {
        3.854382844887319, -2.976414006738438}, {
        3.708765689774638, -2.9528280134768763`}}], 
       PolygonBox[{{3.854382844887319, -2.976414006738438}, {
        3.854382844887319, -2.976414006738438}, {4., -3.}, {4., -3.}, {
        3.854382844887319, -2.976414006738438}}], 
       PolygonBox[{{4., -3.}, {4., -3.}, {
        4.145617155112681, -3.0235859932615616`}, {
        4.145617155112681, -3.0235859932615616`}, {4., -3.}}], 
       PolygonBox[{{4.145617155112681, -3.0235859932615616`}, {
        4.145617155112681, -3.0235859932615616`}, {
        4.291234310225362, -3.0471719865231237`}, {
        4.291234310225362, -3.0471719865231237`}, {
        4.145617155112681, -3.0235859932615616`}}], 
       PolygonBox[{{4.291234310225362, -3.0471719865231237`}, {
        4.291234310225362, -3.0471719865231237`}, {
        4.436851465338043, -3.0707579797846853`}, {
        4.436851465338043, -3.0707579797846853`}, {
        4.291234310225362, -3.0471719865231237`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5631485346619574`, -2.9292420202153147`}, {
         3.708765689774638, -2.9528280134768763`}, {
         3.854382844887319, -2.9764140067384384`}, {4., -3.}, {
         4.145617155112681, -3.0235859932615616`}, {
         4.291234310225362, -3.0471719865231237`}, {
         4.436851465338043, -3.0707579797846853`}, {
         4.436851465338043, -3.0707579797846853`}, {
         4.291234310225362, -3.0471719865231237`}, {
         4.145617155112681, -3.0235859932615616`}, {4., -3.}, {
         3.854382844887319, -2.9764140067384384`}, {
         3.708765689774638, -2.9528280134768763`}, {
         3.5631485346619574`, -2.9292420202153147`}, {
         3.5631485346619574`, -2.9292420202153147`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.4792494120206703`, -3.365652658853756}, {
      3.6470476573032444`, -2.492831381576873}, {
      4.52075058797933, -2.634347341146244}, {
      4.352952342696756, -3.507168618423127}, {
      3.4792494120206703`, -3.365652658853756}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4792494120206703`, -3.365652658853756}, {
       3.6470476573032444`, -2.492831381576873}, {
       4.52075058797933, -2.634347341146244}, {
       4.352952342696756, -3.507168618423127}, {
       3.4792494120206703`, -3.365652658853756}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.943166839324925, -2.4437352115023008`}, {
      3.9431668393249253`, -2.4437352115023008`}, {
      3.9621112262166167`, -2.295823474334867}, {
      3.9621112262166167`, -2.2958234743348673`}, {
      3.943166839324925, -2.4437352115023008`}}], 
     PolygonBox[{{3.9621112262166167`, -2.2958234743348673`}, {
      3.9621112262166167`, -2.295823474334867}, {
      3.9810556131083086`, -2.1479117371674334`}, {
      3.981055613108308, -2.1479117371674334`}, {
      3.9621112262166167`, -2.2958234743348673`}}], 
     PolygonBox[{{3.981055613108308, -2.1479117371674334`}, {
      3.9810556131083086`, -2.1479117371674334`}, {4., -2.}, {4., -2.}, {
      3.981055613108308, -2.1479117371674334`}}], 
     PolygonBox[{{4., -2.}, {4., -2.}, {
      4.018944386891691, -1.8520882628325666`}, {
      4.018944386891691, -1.8520882628325666`}, {4., -2.}}], 
     PolygonBox[{{4.018944386891691, -1.8520882628325666`}, {
      4.018944386891691, -1.8520882628325666`}, {
      4.037888773783384, -1.704176525665133}, {
      4.037888773783384, -1.704176525665133}, {
      4.018944386891691, -1.8520882628325666`}}], 
     PolygonBox[{{4.037888773783384, -1.704176525665133}, {
      4.037888773783384, -1.704176525665133}, {
      4.056833160675075, -1.5562647884976992`}, {
      4.056833160675075, -1.5562647884976994`}, {
      4.037888773783384, -1.704176525665133}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.943166839324925, -2.4437352115023008`}, {
       3.9621112262166167`, -2.2958234743348673`}, {
       3.981055613108308, -2.1479117371674334`}, {4., -2.}, {
       4.018944386891691, -1.8520882628325666`}, {
       4.037888773783384, -1.704176525665133}, {
       4.056833160675075, -1.5562647884976994`}, {
       4.056833160675075, -1.5562647884976992`}, {
       4.037888773783384, -1.704176525665133}, {
       4.018944386891691, -1.8520882628325663`}, {4., -2.}, {
       3.981055613108308, -2.1479117371674334`}, {
       3.9621112262166167`, -2.295823474334867}, {
       3.943166839324925, -2.4437352115023008`}, {
       3.943166839324925, -2.4437352115023008`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5584469708890527`, -1.9513270719938736`}, {
        3.5584469708890527`, -1.9513270719938736`}, {
        3.7056313139260353`, -1.967551381329249}, {
        3.7056313139260353`, -1.967551381329249}, {
        3.5584469708890527`, -1.9513270719938736`}}], 
       PolygonBox[{{3.7056313139260353`, -1.967551381329249}, {
        3.7056313139260353`, -1.967551381329249}, {
        3.8528156569630174`, -1.9837756906646244`}, {
        3.8528156569630174`, -1.9837756906646244`}, {
        3.7056313139260353`, -1.967551381329249}}], 
       PolygonBox[{{3.8528156569630174`, -1.9837756906646244`}, {
        3.8528156569630174`, -1.9837756906646244`}, {4., -2.}, {4., -2.}, {
        3.8528156569630174`, -1.9837756906646244`}}], 
       PolygonBox[{{4., -2.}, {4., -2.}, {
        4.147184343036982, -2.0162243093353753`}, {
        4.147184343036982, -2.0162243093353753`}, {4., -2.}}], 
       PolygonBox[{{4.147184343036982, -2.0162243093353753`}, {
        4.147184343036982, -2.0162243093353753`}, {
        4.294368686073964, -2.032448618670751}, {
        4.294368686073964, -2.032448618670751}, {
        4.147184343036982, -2.0162243093353753`}}], 
       PolygonBox[{{4.294368686073964, -2.032448618670751}, {
        4.294368686073964, -2.032448618670751}, {
        4.441553029110947, -2.0486729280061264`}, {
        4.441553029110947, -2.0486729280061264`}, {
        4.294368686073964, -2.032448618670751}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5584469708890527`, -1.9513270719938736`}, {
         3.7056313139260353`, -1.967551381329249}, {
         3.8528156569630174`, -1.9837756906646244`}, {4., -2.}, {
         4.147184343036982, -2.0162243093353753`}, {
         4.294368686073964, -2.032448618670751}, {
         4.441553029110947, -2.0486729280061264`}, {
         4.441553029110947, -2.0486729280061264`}, {
         4.294368686073965, -2.032448618670751}, {
         4.147184343036982, -2.0162243093353753`}, {4., -2.}, {
         3.852815656963018, -1.9837756906646244`}, {
         3.7056313139260353`, -1.9675513813292491`}, {
         3.558446970889053, -1.9513270719938736`}, {
         3.5584469708890527`, -1.9513270719938736`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.501613810213978, -2.3950622834961743`}, {
      3.615280131564128, -1.5075918604915728`}, {
      4.4983861897860224`, -1.6049377165038257`}, {
      4.384719868435872, -2.492408139508427}, {
      3.501613810213978, -2.3950622834961743`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.501613810213978, -2.3950622834961743`}, {
       3.615280131564128, -1.5075918604915728`}, {
       4.4983861897860224`, -1.6049377165038257`}, {
       4.384719868435872, -2.492408139508427}, {
       3.501613810213978, -2.3950622834961743`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.9713017628409095`, -1.448397910860311}, {
      3.9713017628409095`, -1.448397910860311}, {
      3.98086784189394, -1.2989319405735407`}, {
      3.9808678418939394`, -1.2989319405735409`}, {
      3.9713017628409095`, -1.448397910860311}}], 
     PolygonBox[{{3.9808678418939394`, -1.2989319405735409`}, {
      3.98086784189394, -1.2989319405735407`}, {
      3.9904339209469697`, -1.1494659702867704`}, {
      3.9904339209469697`, -1.1494659702867704`}, {
      3.9808678418939394`, -1.2989319405735409`}}], 
     PolygonBox[{{3.9904339209469697`, -1.1494659702867704`}, {
      3.9904339209469697`, -1.1494659702867704`}, {
      4., -1.0000000000000002`}, {4., -1.}, {
      3.9904339209469697`, -1.1494659702867704`}}], 
     PolygonBox[{{4., -1.}, {4., -1.}, {
      4.00956607905303, -0.8505340297132297}, {
      4.00956607905303, -0.8505340297132297}, {4., -1.}}], 
     PolygonBox[{{4.00956607905303, -0.8505340297132297}, {
      4.00956607905303, -0.8505340297132297}, {
      4.019132158106061, -0.7010680594264593}, {
      4.019132158106061, -0.7010680594264593}, {
      4.00956607905303, -0.8505340297132297}}], 
     PolygonBox[{{4.019132158106061, -0.7010680594264593}, {
      4.019132158106061, -0.7010680594264593}, {
      4.028698237159091, -0.551602089139689}, {
      4.028698237159091, -0.5516020891396891}, {
      4.019132158106061, -0.7010680594264593}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9713017628409095`, -1.448397910860311}, {
       3.9808678418939394`, -1.2989319405735409`}, {
       3.9904339209469697`, -1.1494659702867704`}, {4., -1.}, {
       4.00956607905303, -0.8505340297132297}, {
       4.019132158106061, -0.7010680594264593}, {
       4.028698237159091, -0.5516020891396891}, {
       4.028698237159091, -0.5516020891396889}, {
       4.019132158106061, -0.7010680594264592}, {
       4.00956607905303, -0.8505340297132296}, {4., -1.}, {
       3.9904339209469697`, -1.1494659702867702`}, {
       3.9808678418939394`, -1.2989319405735407`}, {
       3.9713017628409095`, -1.4483979108603109`}, {
       3.9713017628409095`, -1.448397910860311}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.555510159655889, -0.9751861989999671}, {
        3.555510159655889, -0.9751861989999671}, {
        3.7036734397705926`, -0.9834574659999781}, {
        3.7036734397705926`, -0.9834574659999781}, {
        3.555510159655889, -0.9751861989999671}}], 
       PolygonBox[{{3.7036734397705926`, -0.9834574659999781}, {
        3.7036734397705926`, -0.9834574659999781}, {
        3.8518367198852963`, -0.991728732999989}, {
        3.8518367198852963`, -0.991728732999989}, {
        3.7036734397705926`, -0.9834574659999781}}], 
       PolygonBox[{{3.8518367198852963`, -0.991728732999989}, {
        3.8518367198852963`, -0.991728732999989}, {4., -1.}, {4., -1.}, {
        3.8518367198852963`, -0.991728732999989}}], 
       PolygonBox[{{4., -1.}, {4., -1.}, {
        4.148163280114703, -1.008271267000011}, {
        4.148163280114703, -1.008271267000011}, {4., -1.}}], 
       PolygonBox[{{4.148163280114703, -1.008271267000011}, {
        4.148163280114703, -1.008271267000011}, {
        4.296326560229407, -1.0165425340000218`}, {
        4.296326560229407, -1.0165425340000218`}, {
        4.148163280114703, -1.008271267000011}}], 
       PolygonBox[{{4.296326560229407, -1.0165425340000218`}, {
        4.296326560229407, -1.0165425340000218`}, {
        4.4444898403441115`, -1.024813801000033}, {
        4.444489840344111, -1.024813801000033}, {
        4.296326560229407, -1.0165425340000218`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.555510159655889, -0.9751861989999671}, {
         3.7036734397705926`, -0.9834574659999781}, {
         3.8518367198852963`, -0.991728732999989}, {4., -1.}, {
         4.148163280114703, -1.008271267000011}, {
         4.296326560229407, -1.016542534000022}, {
         4.444489840344111, -1.024813801000033}, {
         4.4444898403441115`, -1.024813801000033}, {
         4.296326560229407, -1.016542534000022}, {
         4.148163280114704, -1.008271267000011}, {4., -1.}, {
         3.8518367198852963`, -0.991728732999989}, {
         3.7036734397705926`, -0.9834574659999781}, {
         3.555510159655889, -0.9751861989999671}, {
         3.555510159655889, -0.9751861989999671}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.5268119224967984`, -1.4235841098602782`}, {
      3.5842083968149794`, -0.5267882881396561}, {
      4.473188077503202, -0.5764158901397218}, {
      4.415791603185021, -1.473211711860344}, {
      3.5268119224967984`, -1.4235841098602782`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5268119224967984`, -1.4235841098602782`}, {
       3.5842083968149794`, -0.5267882881396561}, {
       4.473188077503202, -0.5764158901397218}, {
       4.415791603185021, -1.473211711860344}, {
       3.5268119224967984`, -1.4235841098602782`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4., -0.4499999999999999}, {4., -0.4499999999999999}, {
      4., -0.29999999999999993`}, {4., -0.3}, {4., -0.4499999999999999}}], 
     PolygonBox[{{4., -0.3}, {4., -0.29999999999999993`}, {
      4., -0.15000000000000005`}, {4., -0.15}, {4., -0.3}}], 
     PolygonBox[{{4., -0.15}, {4., -0.15000000000000005`}, {
      4., -1.1102230246251563`*^-16}, {4., 0.}, {4., -0.15}}], 
     PolygonBox[{{4., 0.}, {4., 0.}, {4., 0.14999999999999994`}, {4., 
      0.14999999999999994`}, {4., 0.}}], 
     PolygonBox[{{4., 0.14999999999999994`}, {4., 0.14999999999999994`}, {4., 
      0.2999999999999999}, {4., 0.29999999999999993`}, {4., 
      0.14999999999999994`}}], 
     PolygonBox[{{4., 0.29999999999999993`}, {4., 0.2999999999999999}, {4., 
      0.44999999999999984`}, {4., 0.4499999999999998}, {4., 
      0.29999999999999993`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4., -0.4499999999999999}, {4., -0.3}, {4., -0.15}, {
       4., -5.5511151231257815`*^-17}, {4., 0.14999999999999994`}, {4., 
       0.29999999999999993`}, {4., 0.4499999999999998}, {4., 
       0.4499999999999999}, {4., 0.3}, {4., 0.15}, {4., 
       5.5511151231257815`*^-17}, {4., -0.14999999999999994`}, {
       4., -0.29999999999999993`}, {4., -0.4499999999999998}, {
       4., -0.4499999999999999}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.554510871386728, 0.}, {3.554510871386728, 
        5.5109105961630883`*^-17}, {3.7030072475911524`, 
        4.592425496802573*^-17}, {3.703007247591152, 
        9.184850993605147*^-18}, {3.554510871386728, 0.}}], 
       PolygonBox[{{3.703007247591152, 9.184850993605147*^-18}, {
        3.7030072475911524`, 4.592425496802573*^-17}, {3.851503623795576, 
        3.6739403974420595`*^-17}, {3.851503623795576, 
        1.8369701987210294`*^-17}, {3.703007247591152, 
        9.184850993605147*^-18}}], 
       PolygonBox[{{3.851503623795576, 1.8369701987210294`*^-17}, {
        3.851503623795576, 3.6739403974420595`*^-17}, {4., 
        2.7554552980815448`*^-17}, {4., 2.7554552980815442`*^-17}, {
        3.851503623795576, 1.8369701987210294`*^-17}}], 
       PolygonBox[{{4., 2.7554552980815442`*^-17}, {4., 
        2.7554552980815442`*^-17}, {4.148496376204424, 
        1.8369701987210297`*^-17}, {4.148496376204424, 
        3.673940397442059*^-17}, {4., 2.7554552980815442`*^-17}}], 
       PolygonBox[{{4.148496376204424, 3.673940397442059*^-17}, {
        4.148496376204424, 1.8369701987210297`*^-17}, {4.296992752408848, 
        9.18485099360515*^-18}, {4.296992752408848, 4.592425496802573*^-17}, {
        4.148496376204424, 3.673940397442059*^-17}}], 
       PolygonBox[{{4.296992752408848, 4.592425496802573*^-17}, {
        4.296992752408848, 9.184850993605152*^-18}, {4.445489128613271, 
        4.588754872883257*^-33}, {4.445489128613271, 
        5.510910596163088*^-17}, {4.296992752408848, 
        4.592425496802573*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.554510871386728, 0.}, {3.703007247591152, 0.}, {
         3.851503623795576, 0.}, {4., 0.}, {4.148496376204424, 0.}, {
         4.296992752408848, 0.}, {4.445489128613271, 0.}, {4.445489128613271, 
         0.}, {4.296992752408848, 0.}, {4.148496376204424, 0.}, {4., 0.}, {
         3.851503623795576, 0.}, {3.7030072475911524`, 0.}, {
         3.5545108713867286`, 0.}, {3.554510871386728, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.554510871386728, -0.4499999999999999}, {3.554510871386728,
       0.4499999999999999}, {4.445489128613271, 0.4499999999999999}, {
      4.445489128613271, -0.4499999999999999}, {
      3.554510871386728, -0.4499999999999999}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.554510871386728, -0.4499999999999999}, {3.554510871386728, 
       0.4499999999999999}, {4.445489128613271, 0.4499999999999999}, {
       4.445489128613271, -0.4499999999999999}, {
       3.554510871386728, -0.4499999999999999}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.028698237159091, 0.5516020891396889}, {4.028698237159091, 
      0.5516020891396889}, {4.019132158106061, 0.7010680594264593}, {
      4.019132158106061, 0.7010680594264592}, {4.028698237159091, 
      0.5516020891396889}}], 
     PolygonBox[{{4.019132158106061, 0.7010680594264592}, {4.019132158106061, 
      0.7010680594264593}, {4.00956607905303, 0.8505340297132296}, {
      4.00956607905303, 0.8505340297132296}, {4.019132158106061, 
      0.7010680594264592}}], 
     PolygonBox[{{4.00956607905303, 0.8505340297132296}, {4.00956607905303, 
      0.8505340297132296}, {4., 0.9999999999999999}, {4., 1.}, {
      4.00956607905303, 0.8505340297132296}}], 
     PolygonBox[{{4., 1.}, {4., 1.}, {3.9904339209469697`, 
      1.1494659702867702`}, {3.9904339209469697`, 1.1494659702867702`}, {4., 
      1.}}], PolygonBox[{{3.9904339209469697`, 1.1494659702867702`}, {
      3.9904339209469697`, 1.1494659702867702`}, {3.9808678418939394`, 
      1.2989319405735407`}, {3.9808678418939394`, 1.2989319405735407`}, {
      3.9904339209469697`, 1.1494659702867702`}}], 
     PolygonBox[{{3.9808678418939394`, 1.2989319405735407`}, {
      3.9808678418939394`, 1.2989319405735407`}, {3.9713017628409095`, 
      1.448397910860311}, {3.9713017628409095`, 1.4483979108603109`}, {
      3.9808678418939394`, 1.2989319405735407`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.028698237159091, 0.5516020891396889}, {4.019132158106061, 
       0.7010680594264592}, {4.00956607905303, 0.8505340297132296}, {4., 
       1.}, {3.9904339209469697`, 1.1494659702867702`}, {3.9808678418939394`, 
       1.2989319405735407`}, {3.9713017628409095`, 1.4483979108603109`}, {
       3.9713017628409095`, 1.448397910860311}, {3.9808678418939394`, 
       1.2989319405735409`}, {3.9904339209469697`, 1.1494659702867704`}, {4., 
       1.}, {4.00956607905303, 0.8505340297132297}, {4.019132158106061, 
       0.7010680594264593}, {4.028698237159091, 0.5516020891396891}, {
       4.028698237159091, 0.5516020891396889}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.555510159655889, 0.9751861989999671}, {
        3.555510159655889, 0.9751861989999672}, {3.7036734397705926`, 
        0.9834574659999781}, {3.7036734397705926`, 0.9834574659999781}, {
        3.555510159655889, 0.9751861989999671}}], 
       PolygonBox[{{3.7036734397705926`, 0.9834574659999781}, {
        3.7036734397705926`, 0.9834574659999781}, {3.8518367198852963`, 
        0.9917287329999891}, {3.8518367198852963`, 0.9917287329999891}, {
        3.7036734397705926`, 0.9834574659999781}}], 
       PolygonBox[{{3.8518367198852963`, 0.9917287329999891}, {
        3.8518367198852963`, 0.9917287329999891}, {4., 1.}, {4., 1.}, {
        3.8518367198852963`, 0.9917287329999891}}], 
       PolygonBox[{{4., 1.}, {4., 1.}, {4.148163280114703, 
        1.008271267000011}, {4.148163280114703, 1.008271267000011}, {4., 
        1.}}], PolygonBox[{{4.148163280114703, 1.008271267000011}, {
        4.148163280114703, 1.008271267000011}, {4.296326560229407, 
        1.016542534000022}, {4.296326560229407, 1.016542534000022}, {
        4.148163280114703, 1.008271267000011}}], 
       PolygonBox[{{4.296326560229407, 1.016542534000022}, {4.296326560229407,
         1.016542534000022}, {4.4444898403441115`, 1.024813801000033}, {
        4.444489840344111, 1.024813801000033}, {4.296326560229407, 
        1.016542534000022}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.555510159655889, 0.9751861989999671}, {
         3.7036734397705926`, 0.9834574659999781}, {3.8518367198852963`, 
         0.991728732999989}, {4., 1.}, {4.148163280114703, 
         1.008271267000011}, {4.296326560229407, 1.016542534000022}, {
         4.444489840344111, 1.024813801000033}, {4.4444898403441115`, 
         1.024813801000033}, {4.296326560229407, 1.016542534000022}, {
         4.148163280114704, 1.008271267000011}, {4., 1.}, {
         3.8518367198852963`, 0.991728732999989}, {3.7036734397705926`, 
         0.9834574659999781}, {3.555510159655889, 0.9751861989999671}, {
         3.555510159655889, 0.9751861989999671}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.5842083968149794`, 0.5267882881396561}, {
      3.5268119224967984`, 1.4235841098602782`}, {4.415791603185021, 
      1.473211711860344}, {4.473188077503202, 0.5764158901397218}, {
      3.5842083968149794`, 0.5267882881396561}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5842083968149794`, 0.5267882881396561}, {
       3.5268119224967984`, 1.4235841098602782`}, {4.415791603185021, 
       1.473211711860344}, {4.473188077503202, 0.5764158901397218}, {
       3.5842083968149794`, 0.5267882881396561}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.056833160675075, 1.5562647884976992`}, {4.056833160675075,
       1.5562647884976992`}, {4.037888773783384, 1.704176525665133}, {
      4.037888773783384, 1.704176525665133}, {4.056833160675075, 
      1.5562647884976992`}}], 
     PolygonBox[{{4.037888773783384, 1.704176525665133}, {4.037888773783384, 
      1.704176525665133}, {4.018944386891691, 1.8520882628325663`}, {
      4.018944386891691, 1.8520882628325663`}, {4.037888773783384, 
      1.704176525665133}}], 
     PolygonBox[{{4.018944386891691, 1.8520882628325663`}, {4.018944386891691,
       1.8520882628325663`}, {4., 2.}, {4., 2.}, {4.018944386891691, 
      1.8520882628325663`}}], 
     PolygonBox[{{4., 2.}, {4., 2.}, {3.9810556131083086`, 
      2.1479117371674334`}, {3.981055613108308, 2.1479117371674334`}, {4., 
      2.}}], PolygonBox[{{3.981055613108308, 2.1479117371674334`}, {
      3.9810556131083086`, 2.1479117371674334`}, {3.9621112262166167`, 
      2.295823474334867}, {3.9621112262166167`, 2.295823474334867}, {
      3.981055613108308, 2.1479117371674334`}}], 
     PolygonBox[{{3.9621112262166167`, 2.295823474334867}, {
      3.9621112262166167`, 2.295823474334867}, {3.943166839324925, 
      2.4437352115023008`}, {3.943166839324925, 2.4437352115023008`}, {
      3.9621112262166167`, 2.295823474334867}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.056833160675075, 1.5562647884976992`}, {4.037888773783384, 
       1.704176525665133}, {4.018944386891691, 1.8520882628325663`}, {4., 
       2.}, {3.981055613108308, 2.1479117371674334`}, {3.9621112262166167`, 
       2.295823474334867}, {3.943166839324925, 2.4437352115023008`}, {
       3.943166839324925, 2.4437352115023008`}, {3.9621112262166167`, 
       2.2958234743348673`}, {3.981055613108308, 2.1479117371674334`}, {4., 
       2.}, {4.018944386891691, 1.8520882628325666`}, {4.037888773783384, 
       1.704176525665133}, {4.056833160675075, 1.5562647884976994`}, {
       4.056833160675075, 1.5562647884976992`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5584469708890527`, 1.9513270719938736`}, {
        3.5584469708890527`, 1.9513270719938736`}, {3.7056313139260353`, 
        1.9675513813292491`}, {3.7056313139260353`, 1.9675513813292491`}, {
        3.5584469708890527`, 1.9513270719938736`}}], 
       PolygonBox[{{3.7056313139260353`, 1.9675513813292491`}, {
        3.7056313139260353`, 1.9675513813292491`}, {3.8528156569630174`, 
        1.9837756906646244`}, {3.8528156569630174`, 1.9837756906646244`}, {
        3.7056313139260353`, 1.9675513813292491`}}], 
       PolygonBox[{{3.8528156569630174`, 1.9837756906646244`}, {
        3.8528156569630174`, 1.9837756906646244`}, {4., 2.}, {4., 2.}, {
        3.8528156569630174`, 1.9837756906646244`}}], 
       PolygonBox[{{4., 2.}, {4., 2.}, {4.147184343036982, 
        2.0162243093353753`}, {4.147184343036982, 2.0162243093353753`}, {4., 
        2.}}], PolygonBox[{{4.147184343036982, 2.0162243093353753`}, {
        4.147184343036982, 2.0162243093353753`}, {4.294368686073964, 
        2.032448618670751}, {4.294368686073964, 2.032448618670751}, {
        4.147184343036982, 2.0162243093353753`}}], 
       PolygonBox[{{4.294368686073964, 2.032448618670751}, {4.294368686073964,
         2.032448618670751}, {4.441553029110947, 2.0486729280061264`}, {
        4.441553029110947, 2.0486729280061264`}, {4.294368686073964, 
        2.032448618670751}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5584469708890527`, 1.9513270719938736`}, {
         3.7056313139260353`, 1.967551381329249}, {3.8528156569630174`, 
         1.9837756906646244`}, {4., 2.}, {4.147184343036982, 
         2.0162243093353753`}, {4.294368686073964, 2.032448618670751}, {
         4.441553029110947, 2.0486729280061264`}, {4.441553029110947, 
         2.0486729280061264`}, {4.294368686073965, 2.032448618670751}, {
         4.147184343036982, 2.0162243093353753`}, {4., 2.}, {
         3.852815656963018, 1.9837756906646244`}, {3.7056313139260353`, 
         1.9675513813292491`}, {3.558446970889053, 1.9513270719938736`}, {
         3.5584469708890527`, 1.9513270719938736`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.615280131564128, 1.5075918604915728`}, {3.501613810213978,
       2.3950622834961743`}, {4.384719868435872, 2.492408139508427}, {
      4.4983861897860224`, 1.6049377165038257`}, {3.615280131564128, 
      1.5075918604915728`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.615280131564128, 1.5075918604915728`}, {3.501613810213978, 
       2.3950622834961743`}, {4.384719868435872, 2.492408139508427}, {
       4.4983861897860224`, 1.6049377165038257`}, {3.615280131564128, 
       1.5075918604915728`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.083899122641287, 2.563589361361559}, {4.083899122641287, 
      2.563589361361559}, {4.055932748427525, 2.709059574241039}, {
      4.055932748427525, 2.709059574241039}, {4.083899122641287, 
      2.563589361361559}}], 
     PolygonBox[{{4.055932748427525, 2.709059574241039}, {4.055932748427525, 
      2.709059574241039}, {4.027966374213762, 2.8545297871205193`}, {
      4.027966374213762, 2.8545297871205193`}, {4.055932748427525, 
      2.709059574241039}}], 
     PolygonBox[{{4.027966374213762, 2.8545297871205193`}, {4.027966374213762,
       2.8545297871205193`}, {4., 3.}, {4., 3.}, {4.027966374213762, 
      2.8545297871205193`}}], 
     PolygonBox[{{4., 3.}, {4., 3.}, {3.9720336257862376`, 
      3.1454702128794803`}, {3.9720336257862376`, 3.1454702128794803`}, {4., 
      3.}}], PolygonBox[{{3.9720336257862376`, 3.1454702128794803`}, {
      3.9720336257862376`, 3.1454702128794803`}, {3.9440672515724753`, 
      3.290940425758961}, {3.9440672515724753`, 3.290940425758961}, {
      3.9720336257862376`, 3.1454702128794803`}}], 
     PolygonBox[{{3.9440672515724753`, 3.290940425758961}, {
      3.9440672515724753`, 3.290940425758961}, {3.916100877358713, 
      3.436410638638441}, {3.916100877358713, 3.436410638638441}, {
      3.9440672515724753`, 3.290940425758961}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.083899122641287, 2.563589361361559}, {4.055932748427525, 
       2.709059574241039}, {4.027966374213762, 2.8545297871205193`}, {4., 
       3.}, {3.9720336257862376`, 3.1454702128794803`}, {3.9440672515724753`, 
       3.290940425758961}, {3.916100877358713, 3.436410638638441}, {
       3.916100877358713, 3.436410638638441}, {3.9440672515724753`, 
       3.290940425758961}, {3.9720336257862376`, 3.1454702128794807`}, {4., 
       3.}, {4.027966374213762, 2.8545297871205197`}, {4.055932748427525, 
       2.709059574241039}, {4.083899122641287, 2.563589361361559}, {
       4.083899122641287, 2.563589361361559}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5631485346619574`, 2.9292420202153147`}, {
        3.5631485346619574`, 2.9292420202153147`}, {3.708765689774638, 
        2.9528280134768763`}, {3.708765689774638, 2.9528280134768763`}, {
        3.5631485346619574`, 2.9292420202153147`}}], 
       PolygonBox[{{3.708765689774638, 2.9528280134768763`}, {
        3.708765689774638, 2.9528280134768763`}, {3.854382844887319, 
        2.9764140067384384`}, {3.854382844887319, 2.9764140067384384`}, {
        3.708765689774638, 2.9528280134768763`}}], 
       PolygonBox[{{3.854382844887319, 2.9764140067384384`}, {
        3.854382844887319, 2.9764140067384384`}, {4., 3.}, {4., 3.}, {
        3.854382844887319, 2.9764140067384384`}}], 
       PolygonBox[{{4., 3.}, {4., 3.}, {4.145617155112681, 
        3.023585993261562}, {4.145617155112681, 3.023585993261562}, {4., 
        3.}}], PolygonBox[{{4.145617155112681, 3.023585993261562}, {
        4.145617155112681, 3.023585993261562}, {4.291234310225362, 
        3.0471719865231237`}, {4.291234310225362, 3.0471719865231237`}, {
        4.145617155112681, 3.023585993261562}}], 
       PolygonBox[{{4.291234310225362, 3.0471719865231237`}, {
        4.291234310225362, 3.0471719865231237`}, {4.436851465338043, 
        3.0707579797846853`}, {4.436851465338043, 3.070757979784686}, {
        4.291234310225362, 3.0471719865231237`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5631485346619574`, 2.9292420202153147`}, {
         3.708765689774638, 2.9528280134768763`}, {3.854382844887319, 
         2.9764140067384384`}, {4., 3.}, {4.145617155112681, 
         3.0235859932615616`}, {4.291234310225362, 3.0471719865231237`}, {
         4.436851465338043, 3.0707579797846853`}, {4.436851465338043, 
         3.0707579797846853`}, {4.291234310225362, 3.0471719865231237`}, {
         4.145617155112681, 3.0235859932615616`}, {4., 3.}, {
         3.854382844887319, 2.9764140067384384`}, {3.708765689774638, 
         2.9528280134768763`}, {3.5631485346619574`, 2.9292420202153147`}, {
         3.5631485346619574`, 2.9292420202153147`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.6470476573032444`, 2.492831381576873}, {
      3.4792494120206703`, 3.365652658853756}, {4.352952342696756, 
      3.507168618423127}, {4.52075058797933, 2.634347341146244}, {
      3.6470476573032444`, 2.492831381576873}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6470476573032444`, 2.492831381576873}, {3.4792494120206703`,
        3.365652658853756}, {4.352952342696756, 3.507168618423127}, {
       4.52075058797933, 2.634347341146244}, {3.6470476573032444`, 
       2.492831381576873}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.10949255554889, 3.5730051881216065`}, {4.10949255554889, 
      3.5730051881216065`}, {4.072995037032594, 3.715336792081071}, {
      4.072995037032594, 3.715336792081071}, {4.10949255554889, 
      3.5730051881216065`}}], 
     PolygonBox[{{4.072995037032594, 3.715336792081071}, {4.072995037032594, 
      3.715336792081071}, {4.036497518516297, 3.8576683960405354`}, {
      4.036497518516296, 3.8576683960405354`}, {4.072995037032594, 
      3.715336792081071}}], 
     PolygonBox[{{4.036497518516296, 3.8576683960405354`}, {4.036497518516297,
       3.8576683960405354`}, {4., 4.}, {4., 4.}, {4.036497518516296, 
      3.8576683960405354`}}], 
     PolygonBox[{{4., 4.}, {4., 4.}, {3.963502481483703, 4.142331603959464}, {
      3.963502481483703, 4.142331603959464}, {4., 4.}}], 
     PolygonBox[{{3.963502481483703, 4.142331603959464}, {3.963502481483703, 
      4.142331603959464}, {3.9270049629674064`, 4.284663207918929}, {
      3.9270049629674064`, 4.284663207918929}, {3.963502481483703, 
      4.142331603959464}}], 
     PolygonBox[{{3.9270049629674064`, 4.284663207918929}, {
      3.9270049629674064`, 4.284663207918929}, {3.89050744445111, 
      4.4269948118783935`}, {3.89050744445111, 4.4269948118783935`}, {
      3.9270049629674064`, 4.284663207918929}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.10949255554889, 3.5730051881216065`}, {4.072995037032594, 
       3.715336792081071}, {4.036497518516296, 3.8576683960405354`}, {4., 
       4.}, {3.963502481483703, 4.142331603959464}, {3.9270049629674064`, 
       4.284663207918929}, {3.89050744445111, 4.4269948118783935`}, {
       3.89050744445111, 4.4269948118783935`}, {3.9270049629674064`, 
       4.284663207918929}, {3.963502481483703, 4.142331603959464}, {4., 4.}, {
       4.036497518516296, 3.8576683960405354`}, {4.072995037032594, 
       3.715336792081071}, {4.10949255554889, 3.5730051881216065`}, {
       4.10949255554889, 3.5730051881216065`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5693581990138235`, 3.909519002501583}, {
        3.5693581990138235`, 3.909519002501583}, {3.712905466009216, 
        3.9396793350010553`}, {3.712905466009216, 3.9396793350010553`}, {
        3.5693581990138235`, 3.909519002501583}}], 
       PolygonBox[{{3.712905466009216, 3.9396793350010553`}, {
        3.712905466009216, 3.9396793350010553`}, {3.8564527330046077`, 
        3.9698396675005276`}, {3.8564527330046077`, 3.9698396675005276`}, {
        3.712905466009216, 3.9396793350010553`}}], 
       PolygonBox[{{3.8564527330046077`, 3.9698396675005276`}, {
        3.8564527330046077`, 3.9698396675005276`}, {4., 4.}, {4., 4.}, {
        3.8564527330046077`, 3.9698396675005276`}}], 
       PolygonBox[{{4., 4.}, {4., 4.}, {4.143547266995392, 
        4.030160332499472}, {4.143547266995392, 4.030160332499472}, {4., 
        4.}}], 
       PolygonBox[{{4.143547266995392, 4.030160332499472}, {4.143547266995392,
         4.030160332499472}, {4.287094533990784, 4.060320664998945}, {
        4.287094533990785, 4.060320664998945}, {4.143547266995392, 
        4.030160332499472}}], 
       PolygonBox[{{4.287094533990785, 4.060320664998945}, {4.287094533990784,
         4.060320664998945}, {4.4306418009861765`, 4.090480997498417}, {
        4.4306418009861765`, 4.090480997498417}, {4.287094533990785, 
        4.060320664998945}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5693581990138235`, 3.909519002501583}, {3.712905466009216,
          3.9396793350010553`}, {3.8564527330046077`, 3.9698396675005276`}, {
         4., 4.}, {4.143547266995392, 4.030160332499472}, {4.287094533990785, 
         4.060320664998945}, {4.4306418009861765`, 4.090480997498417}, {
         4.4306418009861765`, 4.090480997498417}, {4.287094533990785, 
         4.060320664998945}, {4.143547266995392, 4.030160332499472}, {4., 
         4.}, {3.856452733004608, 3.9698396675005276`}, {3.712905466009216, 
         3.9396793350010553`}, {3.5693581990138235`, 3.909519002501583}, {
         3.5693581990138235`, 3.909519002501583}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.678850754562714, 3.4825241906231894`}, {
      3.4598656434649335`, 4.336513814379977}, {4.321149245437287, 
      4.51747580937681}, {4.5401343565350665`, 3.6634861856200236`}, {
      3.678850754562714, 3.4825241906231894`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.678850754562714, 3.4825241906231894`}, {3.4598656434649335`,
        4.336513814379977}, {4.321149245437287, 4.51747580937681}, {
       4.5401343565350665`, 3.6634861856200236`}, {3.678850754562714, 
       3.4825241906231894`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.133335080581284, 4.583874026394841}, {4.133335080581284, 
      4.583874026394841}, {4.0888900537208555`, 4.722582684263227}, {
      4.0888900537208555`, 4.722582684263227}, {4.133335080581284, 
      4.583874026394841}}], 
     PolygonBox[{{4.0888900537208555`, 4.722582684263227}, {
      4.0888900537208555`, 4.722582684263227}, {4.044445026860428, 
      4.861291342131613}, {4.044445026860428, 4.861291342131613}, {
      4.0888900537208555`, 4.722582684263227}}], 
     PolygonBox[{{4.044445026860428, 4.861291342131613}, {4.044445026860428, 
      4.861291342131613}, {4., 5.}, {4., 5.}, {4.044445026860428, 
      4.861291342131613}}], 
     PolygonBox[{{4., 5.}, {4., 5.}, {3.9555549731395723`, 
      5.138708657868387}, {3.9555549731395723`, 5.138708657868387}, {4., 
      5.}}], PolygonBox[{{3.9555549731395723`, 5.138708657868387}, {
      3.9555549731395723`, 5.138708657868387}, {3.911109946279144, 
      5.2774173157367725`}, {3.911109946279144, 5.277417315736773}, {
      3.9555549731395723`, 5.138708657868387}}], 
     PolygonBox[{{3.911109946279144, 5.277417315736773}, {3.911109946279144, 
      5.2774173157367725`}, {3.8666649194187164`, 5.416125973605159}, {
      3.8666649194187164`, 5.416125973605159}, {3.911109946279144, 
      5.277417315736773}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.133335080581284, 4.583874026394841}, {4.0888900537208555`, 
       4.722582684263227}, {4.044445026860428, 4.861291342131613}, {4., 5.}, {
       3.9555549731395723`, 5.138708657868387}, {3.911109946279144, 
       5.277417315736773}, {3.8666649194187164`, 5.416125973605159}, {
       3.8666649194187164`, 5.416125973605159}, {3.911109946279144, 
       5.277417315736773}, {3.9555549731395723`, 5.138708657868387}, {4., 
       5.}, {4.044445026860428, 4.861291342131613}, {4.0888900537208555`, 
       4.722582684263227}, {4.133335080581284, 4.583874026394841}, {
       4.133335080581284, 4.583874026394841}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{3.5767723830849816`, 4.892478233005866}, {
        3.5767723830849816`, 4.892478233005866}, {3.7178482553899874`, 
        4.928318822003911}, {3.7178482553899874`, 4.928318822003911}, {
        3.5767723830849816`, 4.892478233005866}}], 
       PolygonBox[{{3.7178482553899874`, 4.928318822003911}, {
        3.7178482553899874`, 4.928318822003911}, {3.8589241276949937`, 
        4.964159411001956}, {3.8589241276949937`, 4.964159411001956}, {
        3.7178482553899874`, 4.928318822003911}}], 
       PolygonBox[{{3.8589241276949937`, 4.964159411001956}, {
        3.8589241276949937`, 4.964159411001956}, {4., 5.}, {4., 5.}, {
        3.8589241276949937`, 4.964159411001956}}], 
       PolygonBox[{{4., 5.}, {4., 5.}, {4.141075872305006, 
        5.035840588998044}, {4.141075872305006, 5.035840588998044}, {4., 
        5.}}], PolygonBox[{{4.141075872305006, 5.035840588998044}, {
        4.141075872305006, 5.035840588998044}, {4.282151744610013, 
        5.071681177996089}, {4.282151744610013, 5.071681177996089}, {
        4.141075872305006, 5.035840588998044}}], 
       PolygonBox[{{4.282151744610013, 5.071681177996089}, {4.282151744610013,
         5.071681177996089}, {4.423227616915018, 5.107521766994134}, {
        4.423227616915018, 5.107521766994134}, {4.282151744610013, 
        5.071681177996089}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{3.5767723830849816`, 4.892478233005866}, {
         3.7178482553899874`, 4.928318822003911}, {3.8589241276949937`, 
         4.964159411001956}, {4., 5.}, {4.141075872305006, 
         5.035840588998044}, {4.282151744610013, 5.071681177996089}, {
         4.423227616915018, 5.107521766994134}, {4.423227616915018, 
         5.107521766994134}, {4.282151744610013, 5.071681177996089}, {
         4.141075872305006, 5.035840588998044}, {4., 5.}, {
         3.8589241276949937`, 4.964159411001956}, {3.7178482553899874`, 
         4.928318822003911}, {3.5767723830849816`, 4.892478233005866}, {
         3.5767723830849816`, 4.892478233005866}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{3.710107463666265, 4.476352259400707}, {3.443437302503698, 
      5.308604206611026}, {4.289892536333735, 5.523647740599293}, {
      4.556562697496302, 4.691395793388974}, {3.710107463666265, 
      4.476352259400707}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.710107463666265, 4.476352259400707}, {3.443437302503698, 
       5.308604206611026}, {4.289892536333735, 5.523647740599293}, {
       4.556562697496302, 4.691395793388974}, {3.710107463666265, 
       4.476352259400707}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.865989359316708, -5.416928888763165}, {
      4.865989359316708, -5.416928888763165}, {
      4.9106595728778055`, -5.277952592508776}, {
      4.9106595728778055`, -5.277952592508776}, {
      4.865989359316708, -5.416928888763165}}], 
     PolygonBox[{{4.9106595728778055`, -5.277952592508776}, {
      4.9106595728778055`, -5.277952592508776}, {
      4.955329786438902, -5.138976296254389}, {
      4.955329786438902, -5.138976296254389}, {
      4.9106595728778055`, -5.277952592508776}}], 
     PolygonBox[{{4.955329786438902, -5.138976296254389}, {
      4.955329786438902, -5.138976296254389}, {5., -5.}, {5., -5.}, {
      4.955329786438902, -5.138976296254389}}], 
     PolygonBox[{{5., -5.}, {5., -5.}, {
      5.044670213561098, -4.861023703745611}, {
      5.044670213561098, -4.861023703745611}, {5., -5.}}], 
     PolygonBox[{{5.044670213561098, -4.861023703745611}, {
      5.044670213561098, -4.861023703745611}, {
      5.0893404271221945`, -4.722047407491224}, {
      5.0893404271221945`, -4.722047407491224}, {
      5.044670213561098, -4.861023703745611}}], 
     PolygonBox[{{5.0893404271221945`, -4.722047407491224}, {
      5.0893404271221945`, -4.722047407491224}, {
      5.134010640683292, -4.583071111236835}, {
      5.134010640683292, -4.583071111236835}, {
      5.0893404271221945`, -4.722047407491224}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.865989359316708, -5.416928888763165}, {
       4.9106595728778055`, -5.277952592508776}, {
       4.955329786438902, -5.138976296254389}, {5., -5.}, {
       5.044670213561098, -4.861023703745611}, {
       5.0893404271221945`, -4.722047407491224}, {
       5.134010640683292, -4.583071111236835}, {
       5.134010640683292, -4.583071111236835}, {
       5.0893404271221945`, -4.722047407491224}, {
       5.044670213561098, -4.861023703745611}, {5., -5.}, {
       4.955329786438902, -5.138976296254389}, {
       4.9106595728778055`, -5.277952592508776}, {
       4.865989359316708, -5.416928888763165}, {
       4.865989359316708, -5.416928888763165}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.5806133268275735`, -4.896503865297461}, {
        4.5806133268275735`, -4.896503865297461}, {
        4.720408884551715, -4.931002576864974}, {
        4.720408884551715, -4.931002576864974}, {
        4.5806133268275735`, -4.896503865297461}}], 
       PolygonBox[{{4.720408884551715, -4.931002576864974}, {
        4.720408884551715, -4.931002576864974}, {
        4.860204442275857, -4.9655012884324865`}, {
        4.860204442275858, -4.9655012884324865`}, {
        4.720408884551715, -4.931002576864974}}], 
       PolygonBox[{{4.860204442275858, -4.9655012884324865`}, {
        4.860204442275857, -4.9655012884324865`}, {5., -5.}, {5., -5.}, {
        4.860204442275858, -4.9655012884324865`}}], 
       PolygonBox[{{5., -5.}, {5., -5.}, {
        5.139795557724142, -5.034498711567513}, {
        5.139795557724142, -5.034498711567513}, {5., -5.}}], 
       PolygonBox[{{5.139795557724142, -5.034498711567513}, {
        5.139795557724142, -5.034498711567513}, {
        5.279591115448285, -5.068997423135026}, {
        5.279591115448285, -5.068997423135026}, {
        5.139795557724142, -5.034498711567513}}], 
       PolygonBox[{{5.279591115448285, -5.068997423135026}, {
        5.279591115448285, -5.068997423135026}, {
        5.4193866731724265`, -5.103496134702539}, {
        5.4193866731724265`, -5.103496134702539}, {
        5.279591115448285, -5.068997423135026}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.5806133268275735`, -4.896503865297461}, {
         4.720408884551715, -4.931002576864974}, {
         4.860204442275858, -4.965501288432487}, {5., -5.}, {
         5.139795557724142, -5.034498711567513}, {
         5.279591115448285, -5.068997423135026}, {
         5.4193866731724265`, -5.103496134702539}, {
         5.4193866731724265`, -5.103496134702539}, {
         5.279591115448285, -5.068997423135026}, {
         5.139795557724142, -5.034498711567513}, {5., -5.}, {
         4.860204442275858, -4.965501288432487}, {
         4.720408884551715, -4.931002576864974}, {
         4.5806133268275735`, -4.896503865297461}, {
         4.5806133268275735`, -4.896503865297461}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.446602686144281, -5.313432754060626}, {
      4.714623967510865, -4.4795749765342965`}, {
      5.553397313855719, -4.686567245939374}, {
      5.285376032489135, -5.5204250234657035`}, {
      4.446602686144281, -5.313432754060626}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.446602686144281, -5.313432754060626}, {
       4.714623967510865, -4.4795749765342965`}, {
       5.553397313855719, -4.686567245939374}, {
       5.285376032489135, -5.5204250234657035`}, {
       4.446602686144281, -5.313432754060626}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.889828083677382, -4.427507394723118}, {
      4.889828083677382, -4.427507394723118}, {
      4.926552055784922, -4.285004929815412}, {
      4.926552055784922, -4.285004929815412}, {
      4.889828083677382, -4.427507394723118}}], 
     PolygonBox[{{4.926552055784922, -4.285004929815412}, {
      4.926552055784922, -4.285004929815412}, {
      4.96327602789246, -4.142502464907706}, {
      4.96327602789246, -4.142502464907706}, {
      4.926552055784922, -4.285004929815412}}], 
     PolygonBox[{{4.96327602789246, -4.142502464907706}, {
      4.96327602789246, -4.142502464907706}, {5., -4.}, {5., -4.}, {
      4.96327602789246, -4.142502464907706}}], 
     PolygonBox[{{5., -4.}, {5., -4.}, {
      5.03672397210754, -3.857497535092294}, {
      5.03672397210754, -3.857497535092294}, {5., -4.}}], 
     PolygonBox[{{5.03672397210754, -3.857497535092294}, {
      5.03672397210754, -3.857497535092294}, {
      5.073447944215078, -3.7149950701845884`}, {
      5.073447944215078, -3.7149950701845884`}, {
      5.03672397210754, -3.857497535092294}}], 
     PolygonBox[{{5.073447944215078, -3.7149950701845884`}, {
      5.073447944215078, -3.7149950701845884`}, {
      5.110171916322618, -3.5724926052768824`}, {
      5.110171916322618, -3.5724926052768824`}, {
      5.073447944215078, -3.7149950701845884`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.889828083677382, -4.427507394723118}, {
       4.926552055784922, -4.285004929815412}, {
       4.96327602789246, -4.142502464907706}, {5., -4.}, {
       5.03672397210754, -3.857497535092294}, {
       5.073447944215078, -3.7149950701845884`}, {
       5.110171916322618, -3.5724926052768824`}, {
       5.110171916322618, -3.5724926052768824`}, {
       5.073447944215078, -3.714995070184588}, {
       5.03672397210754, -3.857497535092294}, {5., -4.}, {
       4.96327602789246, -4.142502464907706}, {
       4.926552055784922, -4.285004929815412}, {
       4.889828083677382, -4.427507394723118}, {
       4.889828083677382, -4.427507394723118}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.573002008838895, -3.9128244511869608`}, {
        4.573002008838895, -3.9128244511869608`}, {
        4.715334672559263, -3.941882967457974}, {
        4.715334672559263, -3.941882967457974}, {
        4.573002008838895, -3.9128244511869608`}}], 
       PolygonBox[{{4.715334672559263, -3.941882967457974}, {
        4.715334672559263, -3.941882967457974}, {
        4.857667336279632, -3.970941483728987}, {
        4.857667336279632, -3.970941483728987}, {
        4.715334672559263, -3.941882967457974}}], 
       PolygonBox[{{4.857667336279632, -3.970941483728987}, {
        4.857667336279632, -3.970941483728987}, {5., -4.}, {5., -4.}, {
        4.857667336279632, -3.970941483728987}}], 
       PolygonBox[{{5., -4.}, {5., -4.}, {
        5.142332663720368, -4.0290585162710135`}, {
        5.142332663720368, -4.029058516271013}, {5., -4.}}], 
       PolygonBox[{{5.142332663720368, -4.029058516271013}, {
        5.142332663720368, -4.0290585162710135`}, {
        5.284665327440736, -4.058117032542026}, {
        5.284665327440737, -4.058117032542026}, {
        5.142332663720368, -4.029058516271013}}], 
       PolygonBox[{{5.284665327440737, -4.058117032542026}, {
        5.284665327440736, -4.058117032542026}, {
        5.426997991161105, -4.08717554881304}, {
        5.426997991161105, -4.08717554881304}, {
        5.284665327440737, -4.058117032542026}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.573002008838895, -3.9128244511869608`}, {
         4.715334672559263, -3.941882967457974}, {
         4.857667336279632, -3.970941483728987}, {5., -4.}, {
         5.142332663720368, -4.0290585162710135`}, {
         5.284665327440737, -4.058117032542026}, {
         5.426997991161105, -4.08717554881304}, {
         5.426997991161105, -4.08717554881304}, {
         5.284665327440737, -4.058117032542026}, {
         5.142332663720368, -4.0290585162710135`}, {5., -4.}, {
         4.857667336279632, -3.970941483728987}, {
         4.715334672559263, -3.941882967457974}, {
         4.573002008838895, -3.9128244511869608`}, {
         4.573002008838895, -3.9128244511869608`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.462830092516277, -4.340331845910078}, {
      4.683173925161513, -3.485317056463843}, {
      5.537169907483723, -3.6596681540899216`}, {
      5.316826074838487, -4.514682943536157}, {
      4.462830092516277, -4.340331845910078}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.462830092516277, -4.340331845910078}, {
       4.683173925161513, -3.485317056463843}, {
       5.537169907483723, -3.6596681540899216`}, {
       5.316826074838487, -4.514682943536157}, {
       4.462830092516277, -4.340331845910078}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.915495681804043, -3.4366955918959663`}, {
      4.915495681804043, -3.4366955918959663`}, {
      4.943663787869363, -3.2911303945973107`}, {
      4.943663787869362, -3.2911303945973107`}, {
      4.915495681804043, -3.4366955918959663`}}], 
     PolygonBox[{{4.943663787869362, -3.2911303945973107`}, {
      4.943663787869363, -3.2911303945973107`}, {
      4.971831893934681, -3.1455651972986556`}, {
      4.971831893934681, -3.1455651972986556`}, {
      4.943663787869362, -3.2911303945973107`}}], 
     PolygonBox[{{4.971831893934681, -3.1455651972986556`}, {
      4.971831893934681, -3.1455651972986556`}, {5., -3.}, {5., -3.}, {
      4.971831893934681, -3.1455651972986556`}}], 
     PolygonBox[{{5., -3.}, {5., -3.}, {
      5.028168106065319, -2.854434802701345}, {
      5.028168106065319, -2.854434802701345}, {5., -3.}}], 
     PolygonBox[{{5.028168106065319, -2.854434802701345}, {
      5.028168106065319, -2.854434802701345}, {
      5.056336212130638, -2.7088696054026893`}, {
      5.056336212130638, -2.7088696054026893`}, {
      5.028168106065319, -2.854434802701345}}], 
     PolygonBox[{{5.056336212130638, -2.7088696054026893`}, {
      5.056336212130638, -2.7088696054026893`}, {
      5.084504318195957, -2.5633044081040337`}, {
      5.084504318195957, -2.563304408104034}, {
      5.056336212130638, -2.7088696054026893`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.915495681804043, -3.4366955918959663`}, {
       4.943663787869362, -3.2911303945973107`}, {
       4.971831893934681, -3.1455651972986556`}, {5., -3.}, {
       5.028168106065319, -2.854434802701345}, {
       5.056336212130638, -2.7088696054026893`}, {
       5.084504318195957, -2.563304408104034}, {
       5.084504318195957, -2.5633044081040337`}, {
       5.056336212130638, -2.7088696054026893`}, {
       5.028168106065319, -2.8544348027013444`}, {5., -3.}, {
       4.971831893934681, -3.145565197298655}, {
       4.943663787869362, -3.2911303945973107`}, {
       4.915495681804043, -3.436695591895966}, {
       4.915495681804043, -3.4366955918959663`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.5665999994623245`, -2.93176525646807}, {
        4.5665999994623245`, -2.93176525646807}, {
        4.711066666308216, -2.9545101709787134`}, {
        4.711066666308216, -2.9545101709787134`}, {
        4.5665999994623245`, -2.93176525646807}}], 
       PolygonBox[{{4.711066666308216, -2.9545101709787134`}, {
        4.711066666308216, -2.9545101709787134`}, {
        4.855533333154108, -2.9772550854893565`}, {
        4.855533333154108, -2.9772550854893565`}, {
        4.711066666308216, -2.9545101709787134`}}], 
       PolygonBox[{{4.855533333154108, -2.9772550854893565`}, {
        4.855533333154108, -2.9772550854893565`}, {5., -3.}, {5., -3.}, {
        4.855533333154108, -2.9772550854893565`}}], 
       PolygonBox[{{5., -3.}, {5., -3.}, {
        5.144466666845892, -3.0227449145106435`}, {
        5.144466666845892, -3.0227449145106435`}, {5., -3.}}], 
       PolygonBox[{{5.144466666845892, -3.0227449145106435`}, {
        5.144466666845892, -3.0227449145106435`}, {
        5.288933333691784, -3.0454898290212866`}, {
        5.288933333691784, -3.0454898290212866`}, {
        5.144466666845892, -3.0227449145106435`}}], 
       PolygonBox[{{5.288933333691784, -3.0454898290212866`}, {
        5.288933333691784, -3.0454898290212866`}, {
        5.4334000005376755`, -3.06823474353193}, {
        5.433400000537675, -3.06823474353193}, {
        5.288933333691784, -3.0454898290212866`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.5665999994623245`, -2.93176525646807}, {
         4.711066666308216, -2.9545101709787134`}, {
         4.855533333154108, -2.9772550854893565`}, {5., -3.}, {
         5.144466666845892, -3.0227449145106435`}, {
         5.288933333691784, -3.0454898290212866`}, {
         5.433400000537675, -3.06823474353193}, {
         5.4334000005376755`, -3.06823474353193}, {
         5.288933333691784, -3.0454898290212866`}, {
         5.144466666845892, -3.0227449145106435`}, {5., -3.}, {
         4.855533333154108, -2.9772550854893565`}, {
         4.711066666308216, -2.9545101709787134`}, {
         4.566599999462325, -2.93176525646807}, {
         4.5665999994623245`, -2.93176525646807}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.482095681266368, -3.368460848364036}, {
      4.651104317658282, -2.495069664572104}, {
      5.517904318733632, -2.631539151635964}, {
      5.348895682341718, -3.504930335427896}, {
      4.482095681266368, -3.368460848364036}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.482095681266368, -3.368460848364036}, {
       4.651104317658282, -2.495069664572104}, {
       5.517904318733632, -2.631539151635964}, {
       5.348895682341718, -3.504930335427896}, {
       4.482095681266368, -3.368460848364036}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.942711522202292, -2.4438598759561367`}, {
      4.942711522202292, -2.4438598759561367`}, {
      4.961807681468195, -2.2959065839707575`}, {
      4.961807681468195, -2.2959065839707575`}, {
      4.942711522202292, -2.4438598759561367`}}], 
     PolygonBox[{{4.961807681468195, -2.2959065839707575`}, {
      4.961807681468195, -2.2959065839707575`}, {
      4.980903840734098, -2.1479532919853788`}, {
      4.980903840734097, -2.1479532919853788`}, {
      4.961807681468195, -2.2959065839707575`}}], 
     PolygonBox[{{4.980903840734097, -2.1479532919853788`}, {
      4.980903840734098, -2.1479532919853788`}, {5., -2.}, {5., -2.}, {
      4.980903840734097, -2.1479532919853788`}}], 
     PolygonBox[{{5., -2.}, {5., -2.}, {
      5.019096159265903, -1.8520467080146212`}, {
      5.019096159265903, -1.8520467080146212`}, {5., -2.}}], 
     PolygonBox[{{5.019096159265903, -1.8520467080146212`}, {
      5.019096159265903, -1.8520467080146212`}, {
      5.038192318531805, -1.7040934160292425`}, {
      5.038192318531805, -1.7040934160292425`}, {
      5.019096159265903, -1.8520467080146212`}}], 
     PolygonBox[{{5.038192318531805, -1.7040934160292425`}, {
      5.038192318531805, -1.7040934160292425`}, {
      5.057288477797708, -1.5561401240438635`}, {
      5.057288477797708, -1.5561401240438637`}, {
      5.038192318531805, -1.7040934160292425`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.942711522202292, -2.4438598759561367`}, {
       4.961807681468195, -2.2959065839707575`}, {
       4.980903840734097, -2.1479532919853788`}, {5., -2.}, {
       5.019096159265903, -1.8520467080146212`}, {
       5.038192318531805, -1.7040934160292425`}, {
       5.057288477797708, -1.5561401240438637`}, {
       5.057288477797708, -1.5561401240438635`}, {
       5.038192318531805, -1.7040934160292422`}, {
       5.019096159265903, -1.8520467080146212`}, {5., -2.}, {
       4.980903840734097, -2.1479532919853788`}, {
       4.961807681468195, -2.2959065839707575`}, {
       4.942711522202292, -2.4438598759561363`}, {
       4.942711522202292, -2.4438598759561367`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.56173551333006, -1.95302723312573}, {
        4.56173551333006, -1.9530272331257297`}, {
        4.707823675553373, -1.9686848220838198`}, {
        4.707823675553373, -1.9686848220838198`}, {
        4.56173551333006, -1.95302723312573}}], 
       PolygonBox[{{4.707823675553373, -1.9686848220838198`}, {
        4.707823675553373, -1.9686848220838198`}, {
        4.853911837776686, -1.98434241104191}, {
        4.853911837776686, -1.98434241104191}, {
        4.707823675553373, -1.9686848220838198`}}], 
       PolygonBox[{{4.853911837776686, -1.98434241104191}, {
        4.853911837776686, -1.98434241104191}, {5., -2.}, {5., -2.}, {
        4.853911837776686, -1.98434241104191}}], 
       PolygonBox[{{5., -2.}, {5., -2.}, {
        5.146088162223314, -2.01565758895809}, {
        5.146088162223314, -2.01565758895809}, {5., -2.}}], 
       PolygonBox[{{5.146088162223314, -2.01565758895809}, {
        5.146088162223314, -2.01565758895809}, {
        5.292176324446627, -2.03131517791618}, {
        5.292176324446627, -2.03131517791618}, {
        5.146088162223314, -2.01565758895809}}], 
       PolygonBox[{{5.292176324446627, -2.03131517791618}, {
        5.292176324446627, -2.03131517791618}, {
        5.43826448666994, -2.04697276687427}, {
        5.43826448666994, -2.04697276687427}, {
        5.292176324446627, -2.03131517791618}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.56173551333006, -1.95302723312573}, {
         4.707823675553373, -1.9686848220838198`}, {
         4.853911837776686, -1.98434241104191}, {5., -2.}, {
         5.146088162223314, -2.01565758895809}, {
         5.292176324446627, -2.03131517791618}, {
         5.43826448666994, -2.04697276687427}, {
         5.43826448666994, -2.04697276687427}, {
         5.292176324446627, -2.03131517791618}, {
         5.146088162223314, -2.01565758895809}, {5., -2.}, {
         4.853911837776686, -1.98434241104191}, {
         4.707823675553373, -1.9686848220838198`}, {
         4.56173551333006, -1.95302723312573}, {
         4.56173551333006, -1.95302723312573}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.504447035532352, -2.396887109081866}, {
      4.619023991127767, -1.5091673571695932`}, {
      5.495552964467648, -1.6031128909181338`}, {
      5.380976008872233, -2.490832642830407}, {
      4.504447035532352, -2.396887109081866}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.504447035532352, -2.396887109081866}, {
       4.619023991127767, -1.5091673571695932`}, {
       5.495552964467648, -1.6031128909181338`}, {
       5.380976008872233, -2.490832642830407}, {
       4.504447035532352, -2.396887109081866}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.97105710406142, -1.448428666283699}, {
      4.97105710406142, -1.448428666283699}, {
      4.980704736040947, -1.2989524441891325`}, {
      4.980704736040947, -1.2989524441891327`}, {
      4.97105710406142, -1.448428666283699}}], 
     PolygonBox[{{4.980704736040947, -1.2989524441891327`}, {
      4.980704736040947, -1.2989524441891325`}, {
      4.990352368020473, -1.1494762220945665`}, {
      4.990352368020473, -1.1494762220945662`}, {
      4.980704736040947, -1.2989524441891327`}}], 
     PolygonBox[{{4.990352368020473, -1.1494762220945662`}, {
      4.990352368020473, -1.1494762220945665`}, {5., -1.0000000000000002`}, {
      5., -1.}, {4.990352368020473, -1.1494762220945662`}}], 
     PolygonBox[{{5., -1.}, {5., -1.}, {
      5.009647631979527, -0.8505237779054338}, {
      5.009647631979527, -0.8505237779054338}, {5., -1.}}], 
     PolygonBox[{{5.009647631979527, -0.8505237779054338}, {
      5.009647631979527, -0.8505237779054338}, {
      5.019295263959053, -0.7010475558108675}, {
      5.019295263959053, -0.7010475558108674}, {
      5.009647631979527, -0.8505237779054338}}], 
     PolygonBox[{{5.019295263959053, -0.7010475558108674}, {
      5.019295263959053, -0.7010475558108675}, {
      5.02894289593858, -0.5515713337163011}, {
      5.02894289593858, -0.5515713337163012}, {
      5.019295263959053, -0.7010475558108674}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.97105710406142, -1.448428666283699}, {
       4.980704736040947, -1.2989524441891327`}, {
       4.990352368020473, -1.1494762220945662`}, {5., -1.}, {
       5.009647631979527, -0.8505237779054338}, {
       5.019295263959053, -0.7010475558108674}, {
       5.02894289593858, -0.5515713337163012}, {
       5.02894289593858, -0.5515713337163011}, {
       5.019295263959053, -0.7010475558108673}, {
       5.009647631979527, -0.8505237779054337}, {5., -1.}, {
       4.990352368020473, -1.1494762220945662`}, {
       4.980704736040947, -1.2989524441891325`}, {
       4.97105710406142, -1.4484286662836987`}, {
       4.97105710406142, -1.448428666283699}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.558689111507046, -0.9760408675092029}, {
        4.558689111507046, -0.9760408675092028}, {
        4.705792741004697, -0.9840272450061353}, {
        4.705792741004697, -0.9840272450061353}, {
        4.558689111507046, -0.9760408675092029}}], 
       PolygonBox[{{4.705792741004697, -0.9840272450061353}, {
        4.705792741004697, -0.9840272450061353}, {
        4.852896370502348, -0.9920136225030676}, {
        4.852896370502348, -0.9920136225030676}, {
        4.705792741004697, -0.9840272450061353}}], 
       PolygonBox[{{4.852896370502348, -0.9920136225030676}, {
        4.852896370502348, -0.9920136225030676}, {5., -1.}, {5., -1.}, {
        4.852896370502348, -0.9920136225030676}}], 
       PolygonBox[{{5., -1.}, {5., -1.}, {
        5.147103629497652, -1.0079863774969324`}, {
        5.147103629497652, -1.0079863774969324`}, {5., -1.}}], 
       PolygonBox[{{5.147103629497652, -1.0079863774969324`}, {
        5.147103629497652, -1.0079863774969324`}, {
        5.294207258995303, -1.0159727549938646`}, {
        5.294207258995303, -1.0159727549938646`}, {
        5.147103629497652, -1.0079863774969324`}}], 
       PolygonBox[{{5.294207258995303, -1.0159727549938646`}, {
        5.294207258995303, -1.0159727549938646`}, {
        5.441310888492954, -1.023959132490797}, {
        5.441310888492954, -1.023959132490797}, {
        5.294207258995303, -1.0159727549938646`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.558689111507046, -0.9760408675092029}, {
         4.705792741004697, -0.9840272450061353}, {
         4.852896370502348, -0.9920136225030676}, {5., -1.}, {
         5.147103629497652, -1.0079863774969324`}, {
         5.294207258995303, -1.0159727549938646`}, {
         5.441310888492954, -1.023959132490797}, {
         5.441310888492954, -1.023959132490797}, {
         5.294207258995303, -1.0159727549938649`}, {
         5.147103629497652, -1.0079863774969324`}, {5., -1.}, {
         4.852896370502348, -0.9920136225030677}, {
         4.705792741004697, -0.9840272450061353}, {
         4.558689111507046, -0.9760408675092029}, {
         4.558689111507046, -0.9760408675092029}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.529746215568466, -1.4244695337929019`}, {
      4.587632007445626, -0.527612201225504}, {
      5.470253784431534, -0.5755304662070981}, {
      5.412367992554374, -1.472387798774496}, {
      4.529746215568466, -1.4244695337929019`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.529746215568466, -1.4244695337929019`}, {
       4.587632007445626, -0.527612201225504}, {
       5.470253784431534, -0.5755304662070981}, {
       5.412367992554374, -1.472387798774496}, {
       4.529746215568466, -1.4244695337929019`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5., -0.4499999999999999}, {5., -0.4499999999999999}, {
      5., -0.29999999999999993`}, {5., -0.3}, {5., -0.4499999999999999}}], 
     PolygonBox[{{5., -0.3}, {5., -0.29999999999999993`}, {
      5., -0.15000000000000005`}, {5., -0.15}, {5., -0.3}}], 
     PolygonBox[{{5., -0.15}, {5., -0.15000000000000005`}, {
      5., -1.1102230246251563`*^-16}, {5., 0.}, {5., -0.15}}], 
     PolygonBox[{{5., 0.}, {5., 0.}, {5., 0.14999999999999994`}, {5., 
      0.14999999999999994`}, {5., 0.}}], 
     PolygonBox[{{5., 0.14999999999999994`}, {5., 0.14999999999999994`}, {5., 
      0.2999999999999999}, {5., 0.29999999999999993`}, {5., 
      0.14999999999999994`}}], 
     PolygonBox[{{5., 0.29999999999999993`}, {5., 0.2999999999999999}, {5., 
      0.44999999999999984`}, {5., 0.4499999999999998}, {5., 
      0.29999999999999993`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5., -0.4499999999999999}, {5., -0.3}, {5., -0.15}, {
       5., -5.5511151231257815`*^-17}, {5., 0.14999999999999994`}, {5., 
       0.29999999999999993`}, {5., 0.4499999999999998}, {5., 
       0.4499999999999999}, {5., 0.3}, {5., 0.15}, {5., 
       5.5511151231257815`*^-17}, {5., -0.14999999999999994`}, {
       5., -0.29999999999999993`}, {5., -0.4499999999999998}, {
       5., -0.4499999999999999}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.557651133210165, 0.}, {4.557651133210165, 
        5.5109105961630883`*^-17}, {4.705100755473443, 
        4.592425496802573*^-17}, {4.705100755473443, 
        9.184850993605147*^-18}, {4.557651133210165, 0.}}], 
       PolygonBox[{{4.705100755473443, 9.184850993605147*^-18}, {
        4.705100755473443, 4.592425496802573*^-17}, {4.852550377736722, 
        3.6739403974420595`*^-17}, {4.852550377736722, 
        1.8369701987210294`*^-17}, {4.705100755473443, 
        9.184850993605147*^-18}}], 
       PolygonBox[{{4.852550377736722, 1.8369701987210294`*^-17}, {
        4.852550377736722, 3.6739403974420595`*^-17}, {5., 
        2.7554552980815448`*^-17}, {5., 2.7554552980815442`*^-17}, {
        4.852550377736722, 1.8369701987210294`*^-17}}], 
       PolygonBox[{{5., 2.7554552980815442`*^-17}, {5., 
        2.7554552980815442`*^-17}, {5.147449622263278, 
        1.8369701987210297`*^-17}, {5.147449622263278, 
        3.673940397442059*^-17}, {5., 2.7554552980815442`*^-17}}], 
       PolygonBox[{{5.147449622263278, 3.673940397442059*^-17}, {
        5.147449622263278, 1.8369701987210297`*^-17}, {5.294899244526557, 
        9.18485099360515*^-18}, {5.294899244526557, 4.592425496802573*^-17}, {
        5.147449622263278, 3.673940397442059*^-17}}], 
       PolygonBox[{{5.294899244526557, 4.592425496802573*^-17}, {
        5.294899244526557, 9.184850993605152*^-18}, {5.442348866789835, 
        4.588754872883257*^-33}, {5.442348866789835, 
        5.510910596163088*^-17}, {5.294899244526557, 
        4.592425496802573*^-17}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.557651133210165, 0.}, {4.705100755473443, 0.}, {
         4.852550377736722, 0.}, {5., 0.}, {5.147449622263278, 0.}, {
         5.294899244526557, 0.}, {5.442348866789835, 0.}, {5.442348866789835, 
         0.}, {5.294899244526557, 0.}, {5.147449622263278, 0.}, {5., 0.}, {
         4.852550377736722, 0.}, {4.705100755473443, 0.}, {4.557651133210165, 
         0.}, {4.557651133210165, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.557651133210165, -0.4499999999999999}, {4.557651133210165,
       0.4499999999999999}, {5.442348866789835, 0.4499999999999999}, {
      5.442348866789835, -0.4499999999999999}, {
      4.557651133210165, -0.4499999999999999}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.557651133210165, -0.4499999999999999}, {4.557651133210165, 
       0.4499999999999999}, {5.442348866789835, 0.4499999999999999}, {
       5.442348866789835, -0.4499999999999999}, {
       4.557651133210165, -0.4499999999999999}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5.02894289593858, 0.5515713337163011}, {5.02894289593858, 
      0.5515713337163011}, {5.019295263959053, 0.7010475558108674}, {
      5.019295263959053, 0.7010475558108673}, {5.02894289593858, 
      0.5515713337163011}}], 
     PolygonBox[{{5.019295263959053, 0.7010475558108673}, {5.019295263959053, 
      0.7010475558108674}, {5.009647631979527, 0.8505237779054337}, {
      5.009647631979527, 0.8505237779054337}, {5.019295263959053, 
      0.7010475558108673}}], 
     PolygonBox[{{5.009647631979527, 0.8505237779054337}, {5.009647631979527, 
      0.8505237779054337}, {5., 0.9999999999999999}, {5., 1.}, {
      5.009647631979527, 0.8505237779054337}}], 
     PolygonBox[{{5., 1.}, {5., 1.}, {4.990352368020473, 
      1.1494762220945662`}, {4.990352368020473, 1.1494762220945662`}, {5., 
      1.}}], PolygonBox[{{4.990352368020473, 1.1494762220945662`}, {
      4.990352368020473, 1.1494762220945662`}, {4.980704736040947, 
      1.2989524441891325`}, {4.980704736040947, 1.2989524441891325`}, {
      4.990352368020473, 1.1494762220945662`}}], 
     PolygonBox[{{4.980704736040947, 1.2989524441891325`}, {4.980704736040947,
       1.2989524441891325`}, {4.97105710406142, 1.448428666283699}, {
      4.97105710406142, 1.4484286662836987`}, {4.980704736040947, 
      1.2989524441891325`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.02894289593858, 0.5515713337163011}, {5.019295263959053, 
       0.7010475558108673}, {5.009647631979527, 0.8505237779054337}, {5., 
       1.}, {4.990352368020473, 1.1494762220945662`}, {4.980704736040947, 
       1.2989524441891325`}, {4.97105710406142, 1.4484286662836987`}, {
       4.97105710406142, 1.448428666283699}, {4.980704736040947, 
       1.2989524441891327`}, {4.990352368020473, 1.1494762220945662`}, {5., 
       1.}, {5.009647631979527, 0.8505237779054338}, {5.019295263959053, 
       0.7010475558108674}, {5.02894289593858, 0.5515713337163012}, {
       5.02894289593858, 0.5515713337163011}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.558689111507046, 0.9760408675092029}, {
        4.558689111507046, 0.9760408675092029}, {4.705792741004697, 
        0.9840272450061353}, {4.705792741004697, 0.9840272450061353}, {
        4.558689111507046, 0.9760408675092029}}], 
       PolygonBox[{{4.705792741004697, 0.9840272450061353}, {
        4.705792741004697, 0.9840272450061353}, {4.852896370502348, 
        0.9920136225030677}, {4.852896370502348, 0.9920136225030677}, {
        4.705792741004697, 0.9840272450061353}}], 
       PolygonBox[{{4.852896370502348, 0.9920136225030677}, {
        4.852896370502348, 0.9920136225030677}, {5., 1.}, {5., 1.}, {
        4.852896370502348, 0.9920136225030677}}], 
       PolygonBox[{{5., 1.}, {5., 1.}, {5.147103629497652, 
        1.0079863774969324`}, {5.147103629497652, 1.0079863774969324`}, {5., 
        1.}}], PolygonBox[{{5.147103629497652, 1.0079863774969324`}, {
        5.147103629497652, 1.0079863774969324`}, {5.294207258995303, 
        1.0159727549938649`}, {5.294207258995303, 1.0159727549938649`}, {
        5.147103629497652, 1.0079863774969324`}}], 
       PolygonBox[{{5.294207258995303, 1.0159727549938649`}, {
        5.294207258995303, 1.0159727549938649`}, {5.441310888492954, 
        1.023959132490797}, {5.441310888492954, 1.023959132490797}, {
        5.294207258995303, 1.0159727549938649`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.558689111507046, 0.9760408675092029}, {4.705792741004697, 
         0.9840272450061353}, {4.852896370502348, 0.9920136225030676}, {5., 
         1.}, {5.147103629497652, 1.0079863774969324`}, {5.294207258995303, 
         1.0159727549938646`}, {5.441310888492954, 1.023959132490797}, {
         5.441310888492954, 1.023959132490797}, {5.294207258995303, 
         1.0159727549938649`}, {5.147103629497652, 1.0079863774969324`}, {5., 
         1.}, {4.852896370502348, 0.9920136225030677}, {4.705792741004697, 
         0.9840272450061353}, {4.558689111507046, 0.9760408675092029}, {
         4.558689111507046, 0.9760408675092029}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.587632007445626, 0.527612201225504}, {4.529746215568466, 
      1.4244695337929019`}, {5.412367992554374, 1.472387798774496}, {
      5.470253784431534, 0.5755304662070981}, {4.587632007445626, 
      0.527612201225504}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.587632007445626, 0.527612201225504}, {4.529746215568466, 
       1.4244695337929019`}, {5.412367992554374, 1.472387798774496}, {
       5.470253784431534, 0.5755304662070981}, {4.587632007445626, 
       0.527612201225504}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5.057288477797708, 1.5561401240438635`}, {5.057288477797708,
       1.5561401240438635`}, {5.038192318531805, 1.7040934160292425`}, {
      5.038192318531805, 1.7040934160292422`}, {5.057288477797708, 
      1.5561401240438635`}}], 
     PolygonBox[{{5.038192318531805, 1.7040934160292422`}, {5.038192318531805,
       1.7040934160292425`}, {5.019096159265903, 1.852046708014621}, {
      5.019096159265903, 1.8520467080146212`}, {5.038192318531805, 
      1.7040934160292422`}}], 
     PolygonBox[{{5.019096159265903, 1.8520467080146212`}, {5.019096159265903,
       1.852046708014621}, {5., 2.}, {5., 2.}, {5.019096159265903, 
      1.8520467080146212`}}], 
     PolygonBox[{{5., 2.}, {5., 2.}, {4.980903840734097, 
      2.1479532919853788`}, {4.980903840734097, 2.1479532919853788`}, {5., 
      2.}}], PolygonBox[{{4.980903840734097, 2.1479532919853788`}, {
      4.980903840734097, 2.1479532919853788`}, {4.961807681468195, 
      2.2959065839707575`}, {4.961807681468195, 2.2959065839707575`}, {
      4.980903840734097, 2.1479532919853788`}}], 
     PolygonBox[{{4.961807681468195, 2.2959065839707575`}, {4.961807681468195,
       2.2959065839707575`}, {4.942711522202292, 2.4438598759561363`}, {
      4.942711522202292, 2.4438598759561363`}, {4.961807681468195, 
      2.2959065839707575`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.057288477797708, 1.5561401240438635`}, {5.038192318531805, 
       1.7040934160292422`}, {5.019096159265903, 1.8520467080146212`}, {5., 
       2.}, {4.980903840734097, 2.1479532919853788`}, {4.961807681468195, 
       2.2959065839707575`}, {4.942711522202292, 2.4438598759561363`}, {
       4.942711522202292, 2.4438598759561367`}, {4.961807681468195, 
       2.2959065839707575`}, {4.980903840734097, 2.1479532919853788`}, {5., 
       2.}, {5.019096159265903, 1.8520467080146212`}, {5.038192318531805, 
       1.7040934160292425`}, {5.057288477797708, 1.5561401240438637`}, {
       5.057288477797708, 1.5561401240438635`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.56173551333006, 1.95302723312573}, {4.56173551333006, 
        1.95302723312573}, {4.707823675553373, 1.96868482208382}, {
        4.707823675553373, 1.9686848220838198`}, {4.56173551333006, 
        1.95302723312573}}], 
       PolygonBox[{{4.707823675553373, 1.9686848220838198`}, {
        4.707823675553373, 1.96868482208382}, {4.853911837776686, 
        1.98434241104191}, {4.853911837776686, 1.98434241104191}, {
        4.707823675553373, 1.9686848220838198`}}], 
       PolygonBox[{{4.853911837776686, 1.98434241104191}, {4.853911837776686, 
        1.98434241104191}, {5., 2.}, {5., 2.}, {4.853911837776686, 
        1.98434241104191}}], 
       PolygonBox[{{5., 2.}, {5., 2.}, {5.146088162223314, 
        2.01565758895809}, {5.146088162223314, 2.01565758895809}, {5., 2.}}], 
       PolygonBox[{{5.146088162223314, 2.01565758895809}, {5.146088162223314, 
        2.01565758895809}, {5.292176324446627, 2.03131517791618}, {
        5.292176324446627, 2.03131517791618}, {5.146088162223314, 
        2.01565758895809}}], 
       PolygonBox[{{5.292176324446627, 2.03131517791618}, {5.292176324446627, 
        2.03131517791618}, {5.43826448666994, 2.04697276687427}, {
        5.43826448666994, 2.04697276687427}, {5.292176324446627, 
        2.03131517791618}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.56173551333006, 1.95302723312573}, {4.707823675553373, 
         1.9686848220838198`}, {4.853911837776686, 1.98434241104191}, {5., 
         2.}, {5.146088162223314, 2.01565758895809}, {5.292176324446627, 
         2.03131517791618}, {5.43826448666994, 2.04697276687427}, {
         5.43826448666994, 2.04697276687427}, {5.292176324446627, 
         2.03131517791618}, {5.146088162223314, 2.01565758895809}, {5., 2.}, {
         4.853911837776686, 1.98434241104191}, {4.707823675553373, 
         1.9686848220838198`}, {4.56173551333006, 1.95302723312573}, {
         4.56173551333006, 1.95302723312573}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.619023991127767, 1.5091673571695932`}, {4.504447035532352,
       2.396887109081866}, {5.380976008872233, 2.490832642830407}, {
      5.495552964467648, 1.6031128909181338`}, {4.619023991127767, 
      1.5091673571695932`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.619023991127767, 1.5091673571695932`}, {4.504447035532352, 
       2.396887109081866}, {5.380976008872233, 2.490832642830407}, {
       5.495552964467648, 1.6031128909181338`}, {4.619023991127767, 
       1.5091673571695932`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5.084504318195957, 2.5633044081040337`}, {5.084504318195957,
       2.5633044081040337`}, {5.056336212130638, 2.7088696054026893`}, {
      5.056336212130638, 2.7088696054026893`}, {5.084504318195957, 
      2.5633044081040337`}}], 
     PolygonBox[{{5.056336212130638, 2.7088696054026893`}, {5.056336212130638,
       2.7088696054026893`}, {5.028168106065319, 2.8544348027013444`}, {
      5.028168106065319, 2.8544348027013444`}, {5.056336212130638, 
      2.7088696054026893`}}], 
     PolygonBox[{{5.028168106065319, 2.8544348027013444`}, {5.028168106065319,
       2.8544348027013444`}, {5., 3.}, {5., 3.}, {5.028168106065319, 
      2.8544348027013444`}}], 
     PolygonBox[{{5., 3.}, {5., 3.}, {4.971831893934681, 3.145565197298655}, {
      4.971831893934681, 3.145565197298655}, {5., 3.}}], 
     PolygonBox[{{4.971831893934681, 3.145565197298655}, {4.971831893934681, 
      3.145565197298655}, {4.943663787869362, 3.2911303945973107`}, {
      4.943663787869362, 3.2911303945973107`}, {4.971831893934681, 
      3.145565197298655}}], 
     PolygonBox[{{4.943663787869362, 3.2911303945973107`}, {4.943663787869362,
       3.2911303945973107`}, {4.915495681804043, 3.4366955918959663`}, {
      4.915495681804043, 3.436695591895966}, {4.943663787869362, 
      3.2911303945973107`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.084504318195957, 2.5633044081040337`}, {5.056336212130638, 
       2.7088696054026893`}, {5.028168106065319, 2.8544348027013444`}, {5., 
       3.}, {4.971831893934681, 3.145565197298655}, {4.943663787869362, 
       3.2911303945973107`}, {4.915495681804043, 3.436695591895966}, {
       4.915495681804043, 3.4366955918959663`}, {4.943663787869362, 
       3.2911303945973107`}, {4.971831893934681, 3.1455651972986556`}, {5., 
       3.}, {5.028168106065319, 2.854434802701345}, {5.056336212130638, 
       2.7088696054026893`}, {5.084504318195957, 2.563304408104034}, {
       5.084504318195957, 2.5633044081040337`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.5665999994623245`, 2.93176525646807}, {
        4.5665999994623245`, 2.93176525646807}, {4.711066666308216, 
        2.9545101709787134`}, {4.711066666308216, 2.9545101709787134`}, {
        4.5665999994623245`, 2.93176525646807}}], 
       PolygonBox[{{4.711066666308216, 2.9545101709787134`}, {
        4.711066666308216, 2.9545101709787134`}, {4.855533333154108, 
        2.9772550854893565`}, {4.855533333154108, 2.9772550854893565`}, {
        4.711066666308216, 2.9545101709787134`}}], 
       PolygonBox[{{4.855533333154108, 2.9772550854893565`}, {
        4.855533333154108, 2.9772550854893565`}, {5., 3.}, {5., 3.}, {
        4.855533333154108, 2.9772550854893565`}}], 
       PolygonBox[{{5., 3.}, {5., 3.}, {5.144466666845892, 
        3.0227449145106435`}, {5.144466666845892, 3.0227449145106435`}, {5., 
        3.}}], PolygonBox[{{5.144466666845892, 3.0227449145106435`}, {
        5.144466666845892, 3.0227449145106435`}, {5.288933333691784, 
        3.0454898290212866`}, {5.288933333691784, 3.0454898290212866`}, {
        5.144466666845892, 3.0227449145106435`}}], 
       PolygonBox[{{5.288933333691784, 3.0454898290212866`}, {
        5.288933333691784, 3.0454898290212866`}, {5.4334000005376755`, 
        3.06823474353193}, {5.433400000537675, 3.06823474353193}, {
        5.288933333691784, 3.0454898290212866`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.5665999994623245`, 2.93176525646807}, {4.711066666308216, 
         2.9545101709787134`}, {4.855533333154108, 2.9772550854893565`}, {5., 
         3.}, {5.144466666845892, 3.0227449145106435`}, {5.288933333691784, 
         3.0454898290212866`}, {5.433400000537675, 3.06823474353193}, {
         5.4334000005376755`, 3.06823474353193}, {5.288933333691784, 
         3.0454898290212866`}, {5.144466666845892, 3.0227449145106435`}, {5., 
         3.}, {4.855533333154108, 2.9772550854893565`}, {4.711066666308216, 
         2.9545101709787134`}, {4.566599999462325, 2.93176525646807}, {
         4.5665999994623245`, 2.93176525646807}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.651104317658282, 2.495069664572104}, {4.482095681266368, 
      3.368460848364036}, {5.348895682341718, 3.504930335427896}, {
      5.517904318733632, 2.631539151635964}, {4.651104317658282, 
      2.495069664572104}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.651104317658282, 2.495069664572104}, {4.482095681266368, 
       3.368460848364036}, {5.348895682341718, 3.504930335427896}, {
       5.517904318733632, 2.631539151635964}, {4.651104317658282, 
       2.495069664572104}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5.110171916322618, 3.5724926052768824`}, {5.110171916322618,
       3.5724926052768824`}, {5.073447944215078, 3.7149950701845884`}, {
      5.073447944215078, 3.714995070184588}, {5.110171916322618, 
      3.5724926052768824`}}], 
     PolygonBox[{{5.073447944215078, 3.714995070184588}, {5.073447944215078, 
      3.7149950701845884`}, {5.03672397210754, 3.857497535092294}, {
      5.03672397210754, 3.857497535092294}, {5.073447944215078, 
      3.714995070184588}}], 
     PolygonBox[{{5.03672397210754, 3.857497535092294}, {5.03672397210754, 
      3.857497535092294}, {5., 4.}, {5., 4.}, {5.03672397210754, 
      3.857497535092294}}], 
     PolygonBox[{{5., 4.}, {5., 4.}, {4.96327602789246, 4.142502464907706}, {
      4.96327602789246, 4.142502464907706}, {5., 4.}}], 
     PolygonBox[{{4.96327602789246, 4.142502464907706}, {4.96327602789246, 
      4.142502464907706}, {4.926552055784922, 4.285004929815412}, {
      4.926552055784922, 4.285004929815412}, {4.96327602789246, 
      4.142502464907706}}], 
     PolygonBox[{{4.926552055784922, 4.285004929815412}, {4.926552055784922, 
      4.285004929815412}, {4.889828083677382, 4.427507394723118}, {
      4.889828083677382, 4.427507394723118}, {4.926552055784922, 
      4.285004929815412}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.110171916322618, 3.5724926052768824`}, {5.073447944215078, 
       3.714995070184588}, {5.03672397210754, 3.857497535092294}, {5., 4.}, {
       4.96327602789246, 4.142502464907706}, {4.926552055784922, 
       4.285004929815412}, {4.889828083677382, 4.427507394723118}, {
       4.889828083677382, 4.427507394723118}, {4.926552055784922, 
       4.285004929815412}, {4.96327602789246, 4.142502464907706}, {5., 4.}, {
       5.03672397210754, 3.857497535092294}, {5.073447944215078, 
       3.7149950701845884`}, {5.110171916322618, 3.5724926052768824`}, {
       5.110171916322618, 3.5724926052768824`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.573002008838895, 3.9128244511869608`}, {
        4.573002008838895, 3.9128244511869608`}, {4.715334672559263, 
        3.941882967457974}, {4.715334672559263, 3.941882967457974}, {
        4.573002008838895, 3.9128244511869608`}}], 
       PolygonBox[{{4.715334672559263, 3.941882967457974}, {4.715334672559263,
         3.941882967457974}, {4.857667336279632, 3.970941483728987}, {
        4.857667336279632, 3.970941483728987}, {4.715334672559263, 
        3.941882967457974}}], 
       PolygonBox[{{4.857667336279632, 3.970941483728987}, {4.857667336279632,
         3.970941483728987}, {5., 4.}, {5., 4.}, {4.857667336279632, 
        3.970941483728987}}], 
       PolygonBox[{{5., 4.}, {5., 4.}, {5.142332663720368, 
        4.0290585162710135`}, {5.142332663720368, 4.0290585162710135`}, {5., 
        4.}}], PolygonBox[{{5.142332663720368, 4.0290585162710135`}, {
        5.142332663720368, 4.0290585162710135`}, {5.284665327440736, 
        4.058117032542026}, {5.284665327440737, 4.058117032542026}, {
        5.142332663720368, 4.0290585162710135`}}], 
       PolygonBox[{{5.284665327440737, 4.058117032542026}, {5.284665327440736,
         4.058117032542026}, {5.426997991161105, 4.08717554881304}, {
        5.426997991161105, 4.08717554881304}, {5.284665327440737, 
        4.058117032542026}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.573002008838895, 3.9128244511869608`}, {4.715334672559263,
          3.941882967457974}, {4.857667336279632, 3.970941483728987}, {5., 
         4.}, {5.142332663720368, 4.0290585162710135`}, {5.284665327440737, 
         4.058117032542026}, {5.426997991161105, 4.08717554881304}, {
         5.426997991161105, 4.08717554881304}, {5.284665327440737, 
         4.058117032542026}, {5.142332663720368, 4.0290585162710135`}, {5., 
         4.}, {4.857667336279632, 3.970941483728987}, {4.715334672559263, 
         3.941882967457974}, {4.573002008838895, 3.9128244511869608`}, {
         4.573002008838895, 3.9128244511869608`}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.683173925161513, 3.485317056463843}, {4.462830092516277, 
      4.340331845910078}, {5.316826074838487, 4.514682943536157}, {
      5.537169907483723, 3.6596681540899216`}, {4.683173925161513, 
      3.485317056463843}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683173925161513, 3.485317056463843}, {4.462830092516277, 
       4.340331845910078}, {5.316826074838487, 4.514682943536157}, {
       5.537169907483723, 3.6596681540899216`}, {4.683173925161513, 
       3.485317056463843}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{5.134010640683292, 4.583071111236835}, {5.134010640683292, 
      4.583071111236835}, {5.0893404271221945`, 4.722047407491224}, {
      5.0893404271221945`, 4.722047407491224}, {5.134010640683292, 
      4.583071111236835}}], 
     PolygonBox[{{5.0893404271221945`, 4.722047407491224}, {
      5.0893404271221945`, 4.722047407491224}, {5.044670213561098, 
      4.861023703745611}, {5.044670213561098, 4.861023703745611}, {
      5.0893404271221945`, 4.722047407491224}}], 
     PolygonBox[{{5.044670213561098, 4.861023703745611}, {5.044670213561098, 
      4.861023703745611}, {5., 5.}, {5., 5.}, {5.044670213561098, 
      4.861023703745611}}], 
     PolygonBox[{{5., 5.}, {5., 5.}, {4.955329786438902, 5.138976296254389}, {
      4.955329786438902, 5.138976296254389}, {5., 5.}}], 
     PolygonBox[{{4.955329786438902, 5.138976296254389}, {4.955329786438902, 
      5.138976296254389}, {4.9106595728778055`, 5.277952592508776}, {
      4.9106595728778055`, 5.277952592508776}, {4.955329786438902, 
      5.138976296254389}}], 
     PolygonBox[{{4.9106595728778055`, 5.277952592508776}, {
      4.9106595728778055`, 5.277952592508776}, {4.865989359316708, 
      5.416928888763165}, {4.865989359316708, 5.416928888763165}, {
      4.9106595728778055`, 5.277952592508776}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.134010640683292, 4.583071111236835}, {5.0893404271221945`, 
       4.722047407491224}, {5.044670213561098, 4.861023703745611}, {5., 5.}, {
       4.955329786438902, 5.138976296254389}, {4.9106595728778055`, 
       5.277952592508776}, {4.865989359316708, 5.416928888763165}, {
       4.865989359316708, 5.416928888763165}, {4.9106595728778055`, 
       5.277952592508776}, {4.955329786438902, 5.138976296254389}, {5., 5.}, {
       5.044670213561098, 4.861023703745611}, {5.0893404271221945`, 
       4.722047407491224}, {5.134010640683292, 4.583071111236835}, {
       5.134010640683292, 4.583071111236835}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{4.5806133268275735`, 4.896503865297461}, {
        4.5806133268275735`, 4.896503865297461}, {4.720408884551715, 
        4.931002576864974}, {4.720408884551715, 4.931002576864974}, {
        4.5806133268275735`, 4.896503865297461}}], 
       PolygonBox[{{4.720408884551715, 4.931002576864974}, {4.720408884551715,
         4.931002576864974}, {4.860204442275857, 4.965501288432487}, {
        4.860204442275858, 4.965501288432487}, {4.720408884551715, 
        4.931002576864974}}], 
       PolygonBox[{{4.860204442275858, 4.965501288432487}, {4.860204442275857,
         4.965501288432487}, {5., 5.}, {5., 5.}, {4.860204442275858, 
        4.965501288432487}}], 
       PolygonBox[{{5., 5.}, {5., 5.}, {5.139795557724142, 
        5.034498711567513}, {5.139795557724142, 5.0344987115675135`}, {5., 
        5.}}], PolygonBox[{{5.139795557724142, 5.0344987115675135`}, {
        5.139795557724142, 5.034498711567513}, {5.279591115448285, 
        5.068997423135026}, {5.279591115448285, 5.068997423135026}, {
        5.139795557724142, 5.0344987115675135`}}], 
       PolygonBox[{{5.279591115448285, 5.068997423135026}, {5.279591115448285,
         5.068997423135026}, {5.4193866731724265`, 5.103496134702539}, {
        5.4193866731724265`, 5.103496134702539}, {5.279591115448285, 
        5.068997423135026}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{4.5806133268275735`, 4.896503865297461}, {4.720408884551715,
          4.931002576864974}, {4.860204442275858, 4.965501288432487}, {5., 
         5.}, {5.139795557724142, 5.034498711567513}, {5.279591115448285, 
         5.068997423135026}, {5.4193866731724265`, 5.103496134702539}, {
         5.4193866731724265`, 5.103496134702539}, {5.279591115448285, 
         5.068997423135026}, {5.139795557724142, 5.034498711567513}, {5., 
         5.}, {4.860204442275858, 4.965501288432487}, {4.720408884551715, 
         4.931002576864974}, {4.5806133268275735`, 4.896503865297461}, {
         4.5806133268275735`, 4.896503865297461}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{4.714623967510865, 4.4795749765342965`}, {4.446602686144281,
       5.313432754060626}, {5.285376032489135, 5.5204250234657035`}, {
      5.553397313855719, 4.686567245939374}, {4.714623967510865, 
      4.4795749765342965`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.714623967510865, 4.4795749765342965`}, {4.446602686144281, 
       5.313432754060626}, {5.285376032489135, 5.5204250234657035`}, {
       5.553397313855719, 4.686567245939374}, {4.714623967510865, 
       4.4795749765342965`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404678300234*^9, 3.566101176905066*^9, 
  3.61472773141376*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[262]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[Mirror[{.9,.9}], CreateClones->clonedplaces];", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[263]:="],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.115723631026773, -5.416880522567345, 
      0.1237686193102157}, {-5.115723631026773, -5.416880522567345, 
      0.1237686193102157}, {-5.077149087351182, -5.277920348378229, 
      0.08251241287347712}, {-5.077149087351183, -5.277920348378229, 
      0.08251241287347713}, {-5.115723631026773, -5.416880522567345, 
      0.1237686193102157}}], 
     Polygon3DBox[{{-5.077149087351183, -5.277920348378229, 
      0.08251241287347713}, {-5.077149087351182, -5.277920348378229, 
      0.08251241287347712}, {-5.038574543675591, -5.138960174189115, 
      0.041256206436738586`}, {-5.038574543675591, -5.138960174189115, 
      0.041256206436738566`}, {-5.077149087351183, -5.277920348378229, 
      0.08251241287347713}}], 
     Polygon3DBox[{{-5.038574543675591, -5.138960174189115, 
      0.041256206436738566`}, {-5.038574543675591, -5.138960174189115, 
      0.041256206436738586`}, {-5., -5., 2.900154308769605*^-17}, {-5., -5., 
      0.}, {-5.038574543675591, -5.138960174189115, 0.041256206436738566`}}], 
     Polygon3DBox[{{-5., -5., 
      0.}, {-5., -5., -1.5341837754744402`*^-18}, {-4.961425456324409, \
-4.861039825810885, -0.04125620643673855}, {-4.961425456324409, \
-4.861039825810885, -0.04125620643673855}, {-5., -5., 0.}}], 
     Polygon3DBox[{{-4.961425456324409, -4.861039825810885, \
-0.04125620643673855}, {-4.961425456324409, -4.861039825810885, \
-0.04125620643673855}, {-4.922850912648817, -4.722079651621771, \
-0.0825124128734771}, {-4.922850912648817, -4.722079651621771, \
-0.08251241287347712}, {-4.961425456324409, -4.861039825810885, \
-0.04125620643673855}}], 
     Polygon3DBox[{{-4.922850912648817, -4.722079651621771, \
-0.08251241287347712}, {-4.922850912648817, -4.722079651621771, \
-0.0825124128734771}, {-4.884276368973227, -4.583119477432656, \
-0.12376861931021568`}, {-4.884276368973227, -4.583119477432656, \
-0.12376861931021566`}, {-4.922850912648817, -4.722079651621771, \
-0.08251241287347712}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7WmeXYUCZyoE3Ae9ejVaIHmGNN7/is32+/K3qO
NoO/yIF1W++oTZcRPcBkd25Sh/xW+7u650Qb1EUOXI/Km+zdJwIVX2rPAAYi
B2D0GmNGVfdZhTbKlwxf1d8QPqC5dGLOlkLhAwwQ9fvdliRf+b9B+ECQl/LN
jMdCBxgh5u/PKpu6r75T+ED1+y2usqFCBxgg7oGLV0HFoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHhZurdBwg7rTHld4AgAlc5t6
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.432463165002302, -4.876231380689784, 
        0.012527561224531013`}, {-5.432463165002302, -4.876231380689784, 
        0.012527561224530998`}, {-5.2883087766682015`, -4.917487587126523, 
        0.008351707483020662}, {-5.2883087766682015`, -4.917487587126523, 
        0.008351707483020674}, {-5.432463165002302, -4.876231380689784, 
        0.012527561224531013`}}], 
       Polygon3DBox[{{-5.2883087766682015`, -4.917487587126523, 
        0.008351707483020674}, {-5.2883087766682015`, -4.917487587126523, 
        0.008351707483020662}, {-5.144154388334101, -4.9587437935632614`, 
        0.004175853741510329}, {-5.144154388334101, -4.9587437935632614`, 
        0.0041758537415103325`}, {-5.2883087766682015`, -4.917487587126523, 
        0.008351707483020674}}], 
       Polygon3DBox[{{-5.144154388334101, -4.9587437935632614`, 
        0.0041758537415103325`}, {-5.144154388334101, -4.9587437935632614`, 
        0.004175853741510329}, {-5., -5., -4.487889526129226*^-18}, {-5., \
-5., -7.578642173657147*^-18}, {-5.144154388334101, -4.9587437935632614`, 
        0.0041758537415103325`}}], 
       Polygon3DBox[{{-5., -5., -7.578642173657147*^-18}, {-5., -5., \
-7.578642173657147*^-18}, {-4.8558456116659, -5.0412562064367386`, \
-0.004175853741510342}, {-4.8558456116659, -5.0412562064367386`, \
-0.004175853741510347}, {-5., -5., -7.578642173657147*^-18}}], 
       Polygon3DBox[{{-4.8558456116659, -5.0412562064367386`, \
-0.004175853741510347}, {-4.8558456116659, -5.0412562064367386`, \
-0.004175853741510342}, {-4.7116912233317985`, -5.082512412873477, \
-0.008351707483020675}, {-4.7116912233317985`, -5.082512412873477, \
-0.008351707483020686}, {-4.8558456116659, -5.0412562064367386`, \
-0.004175853741510347}}], 
       Polygon3DBox[{{-4.7116912233317985`, -5.082512412873477, \
-0.008351707483020686}, {-4.7116912233317985`, -5.082512412873477, \
-0.008351707483020675}, {-4.567536834997698, -5.123768619310216, \
-0.012527561224531011`}, {-4.567536834997698, -5.123768619310216, \
-0.012527561224531025`}, {-4.7116912233317985`, -5.082512412873477, \
-0.008351707483020686}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQofqEwUOMezotPe/lB1
lpW66AGO41vuNq4WPrDsNZfJZqlGe4WHtqZzJ4scaEm+9e7AVZh4oT0DGIgc
gNEi9/aEXW20sXkod+hUUo7wgZo5qoL2WiIHlkLU7z9o2zL16A2hAz8svJXq
QmDijfsXxbglaLgKHSi5WmC8t07kQDnEPRjiUHdimAN15/4HaPZC3bkfhzv3
yKP5C+pOjHCAutMePdyg7sQQh4UnAE8rnsw=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.548186796029076, -5.293111903257128, 
      0.1362961805347467}, {-5.316739533975529, -4.4593508581224395`, \
-0.11124105808568469`}, {-4.451813203970924, -4.706888096742872, \
-0.1362961805347467}, {-4.683260466024471, -5.5406491418775605`, 
      0.11124105808568469`}, {-5.548186796029076, -5.293111903257128, 
      0.1362961805347467}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}, {-5.316739533975529, -4.4593508581224395`, \
-0.11124105808568469`}, {-4.451813203970924, -4.706888096742872, \
-0.1362961805347467}, {-4.683260466024471, -5.5406491418775605`, 
       0.11124105808568469`}, {-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.0940256399592485`, -4.427940085673643, 
      0.10259854825429525`}, {-5.0940256399592485`, -4.427940085673643, 
      0.10259854825429525`}, {-5.062683759972832, -4.2852933904490955`, 
      0.06839903216953015}, {-5.062683759972832, -4.2852933904490955`, 
      0.06839903216953017}, {-5.0940256399592485`, -4.427940085673643, 
      0.10259854825429525`}}], 
     Polygon3DBox[{{-5.062683759972832, -4.2852933904490955`, 
      0.06839903216953017}, {-5.062683759972832, -4.2852933904490955`, 
      0.06839903216953015}, {-5.0313418799864165`, -4.142646695224547, 
      0.03419951608476509}, {-5.0313418799864165`, -4.142646695224547, 
      0.03419951608476508}, {-5.062683759972832, -4.2852933904490955`, 
      0.06839903216953017}}], 
     Polygon3DBox[{{-5.0313418799864165`, -4.142646695224547, 
      0.03419951608476508}, {-5.0313418799864165`, -4.142646695224547, 
      0.03419951608476509}, {-5., -4., 2.1984624289858703`*^-17}, {-5., -4., 
      0.}, {-5.0313418799864165`, -4.142646695224547, 0.03419951608476508}}], 
     Polygon3DBox[{{-5., -4., 
      0.}, {-5., -4., -3.328102502371016*^-18}, {-4.9686581200135835`, \
-3.8573533047754522`, -0.034199516084765076`}, {-4.9686581200135835`, \
-3.8573533047754522`, -0.034199516084765076`}, {-5., -4., 0.}}], 
     Polygon3DBox[{{-4.9686581200135835`, -3.8573533047754522`, \
-0.034199516084765076`}, {-4.9686581200135835`, -3.8573533047754522`, \
-0.034199516084765076`}, {-4.937316240027168, -3.714706609550905, \
-0.06839903216953015}, {-4.937316240027168, -3.7147066095509045`, \
-0.06839903216953015}, {-4.9686581200135835`, -3.8573533047754522`, \
-0.034199516084765076`}}], 
     Polygon3DBox[{{-4.937316240027168, -3.7147066095509045`, \
-0.06839903216953015}, {-4.937316240027168, -3.714706609550905, \
-0.06839903216953015}, {-4.9059743600407515`, -3.572059914326357, \
-0.10259854825429524`}, {-4.9059743600407515`, -3.572059914326357, \
-0.10259854825429522`}, {-4.937316240027168, -3.7147066095509045`, \
-0.06839903216953015}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJYofOTokSByoLmM6a3pNsED9zviGJ8577JP9X6j
beAgcmDtz7DPyiqCB16x2ofNbNpov1n1m6iEgsiBazWrfwpOEoCKL7RnAAOR
AxBa4IBB/L7+/3q5Nr63OF89vy98IJhtJc+d23wHXkLU75+9RfjK+f3CB5bx
BEnu2M4LFd+4/0Wf7L7t84UP/BL6rTplMs+BuxD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAHZ9ong=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.437304244059274, -3.8974014517457047`, 
        0.02717601927909476}, {-5.437304244059274, -3.8974014517457047`, 
        0.027176019279094746`}, {-5.2915361627061825`, -3.93160096783047, 
        0.018117346186063164`}, {-5.2915361627061825`, -3.93160096783047, 
        0.018117346186063175`}, {-5.437304244059274, -3.8974014517457047`, 
        0.02717601927909476}}], 
       Polygon3DBox[{{-5.2915361627061825`, -3.93160096783047, 
        0.018117346186063175`}, {-5.2915361627061825`, -3.93160096783047, 
        0.018117346186063164`}, {-5.145768081353092, -3.9658004839152348`, 
        0.009058673093031584}, {-5.145768081353092, -3.9658004839152348`, 
        0.009058673093031586}, {-5.2915361627061825`, -3.93160096783047, 
        0.018117346186063175`}}], 
       Polygon3DBox[{{-5.145768081353092, -3.9658004839152348`, 
        0.009058673093031586}, {-5.145768081353092, -3.9658004839152348`, 
        0.009058673093031584}, {-5., -4., 
        4.2241577445130206`*^-19}, {-5., -4., -6.282349185839397*^-18}, \
{-5.145768081353092, -3.9658004839152348`, 0.009058673093031586}}], 
       Polygon3DBox[{{-5., -4., -6.282349185839397*^-18}, {-5., -4., \
-6.282349185839397*^-18}, {-4.854231918646908, -4.034199516084765, \
-0.009058673093031589}, {-4.854231918646908, -4.034199516084765, \
-0.009058673093031594}, {-5., -4., -6.282349185839397*^-18}}], 
       Polygon3DBox[{{-4.854231918646908, -4.034199516084765, \
-0.009058673093031594}, {-4.854231918646908, -4.034199516084765, \
-0.009058673093031589}, {-4.7084638372938175`, -4.0683990321695305`, \
-0.018117346186063175`}, {-4.7084638372938175`, -4.0683990321695305`, \
-0.018117346186063185`}, {-4.854231918646908, -4.034199516084765, \
-0.009058673093031594}}], 
       Polygon3DBox[{{-4.7084638372938175`, -4.0683990321695305`, \
-0.018117346186063185`}, {-4.7084638372938175`, -4.0683990321695305`, \
-0.018117346186063175`}, {-4.562695755940726, -4.102598548254295, \
-0.027176019279094757`}, {-4.562695755940726, -4.102598548254295, \
-0.027176019279094767`}, {-4.7084638372938175`, -4.0683990321695305`, \
-0.018117346186063185`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMt/QFVO4wT7ldn2kzdt
LOnQEj1wkd3P9HUx/wEpkYLWqN5J9l43I6xcpooceMG8fNbXnTDxJnsGMBA5
AKEFDlwpS7037bWfzTa15Ud3Zwkf4KlbY8SqLHBAAqJ+f66vX3f5VaEDEn8i
UrncBA5IQszfr1zyNcDYQeiAchXrDP5MgQPKEPdgiEPdiWEO1J370e2FunM/
DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AugqWTQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.531329884018523, -4.325341537419348, 
      0.12977456753339}, {-5.343278604100026, -3.469461366072062, \
-0.07542252897520049}, {-4.468670115981477, -3.6746584625806524`, \
-0.12977456753339}, {-4.656721395899974, -4.5305386339279385`, 
      0.07542252897520049}, {-5.531329884018523, -4.325341537419348, 
      0.12977456753339}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.531329884018523, -4.325341537419348, 
       0.12977456753339}, {-5.343278604100026, -3.469461366072062, \
-0.07542252897520049}, {-4.468670115981477, -3.6746584625806524`, \
-0.12977456753339}, {-4.656721395899974, -4.5305386339279385`, 
       0.07542252897520049}, {-5.531329884018523, -4.325341537419348, 
       0.12977456753339}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.071399969738751, -3.4371859536992355`, 
      0.07918640166970196}, {-5.071399969738751, -3.4371859536992355`, 
      0.07918640166970195}, {-5.047599979825834, -3.291457302466157, 
      0.05279093444646797}, {-5.047599979825834, -3.291457302466157, 
      0.052790934446467985`}, {-5.071399969738751, -3.4371859536992355`, 
      0.07918640166970196}}], 
     Polygon3DBox[{{-5.047599979825834, -3.291457302466157, 
      0.052790934446467985`}, {-5.047599979825834, -3.291457302466157, 
      0.05279093444646797}, {-5.023799989912917, -3.1457286512330787`, 
      0.026395467223233996`}, {-5.023799989912917, -3.1457286512330787`, 
      0.026395467223233993`}, {-5.047599979825834, -3.291457302466157, 
      0.052790934446467985`}}], 
     Polygon3DBox[{{-5.023799989912917, -3.1457286512330787`, 
      0.026395467223233993`}, {-5.023799989912917, -3.1457286512330787`, 
      0.026395467223233996`}, {-5., -3., 1.471822879814065*^-17}, {-5., -3., 
      0.}, {-5.023799989912917, -3.1457286512330787`, 
      0.026395467223233993`}}], 
     Polygon3DBox[{{-5., -3., 
      0.}, {-5., -3., -4.818341506508028*^-18}, {-4.976200010087083, \
-2.8542713487669213`, -0.026395467223233986`}, {-4.976200010087083, \
-2.8542713487669213`, -0.026395467223233982`}, {-5., -3., 0.}}], 
     Polygon3DBox[{{-4.976200010087083, -2.8542713487669213`, \
-0.026395467223233982`}, {-4.976200010087083, -2.8542713487669213`, \
-0.026395467223233986`}, {-4.952400020174166, -2.708542697533843, \
-0.052790934446467964`}, {-4.952400020174166, -2.708542697533843, \
-0.05279093444646798}, {-4.976200010087083, -2.8542713487669213`, \
-0.026395467223233982`}}], 
     Polygon3DBox[{{-4.952400020174166, -2.708542697533843, \
-0.05279093444646798}, {-4.952400020174166, -2.708542697533843, \
-0.052790934446467964`}, {-4.928600030261249, -2.5628140463007645`, \
-0.07918640166970196}, {-4.928600030261249, -2.5628140463007645`, \
-0.07918640166970195}, {-4.952400020174166, -2.708542697533843, \
-0.05279093444646798}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC66dVtI1lPkgJFrdmR0PfcB5imlsf2uW+wXTpzE
s89A5ICi3qcJz0O4DmyQ+nQxk321/UUPT7Z4CZEDguKVJ4q1OKHis+0ZwEDk
AITmOPD8gGeLbluajf72bT8XPBc+8P5Fm3nPVbYDayHq98fn5X52PC984P5F
3nyJ1awH1kPM39+nqvL20TbhA+d2TVm2pIHlABPEPRjiUHdimAN15350e6Hu
3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwCxsaBB
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.441227271248425, -2.920813598330298, 
        0.03934474421410929}, {-5.441227271248425, -2.920813598330298, 
        0.03934474421410928}, {-5.294151514165616, -2.947209065553532, 
        0.02622982947607285}, {-5.294151514165616, -2.947209065553532, 
        0.026229829476072865`}, {-5.441227271248425, -2.920813598330298, 
        0.03934474421410929}}], 
       Polygon3DBox[{{-5.294151514165616, -2.947209065553532, 
        0.026229829476072865`}, {-5.294151514165616, -2.947209065553532, 
        0.02622982947607285}, {-5.147075757082808, -2.973604532776766, 
        0.013114914738036429`}, {-5.147075757082808, -2.973604532776766, 
        0.013114914738036429`}, {-5.294151514165616, -2.947209065553532, 
        0.026229829476072865`}}], 
       Polygon3DBox[{{-5.147075757082808, -2.973604532776766, 
        0.013114914738036429`}, {-5.147075757082808, -2.973604532776766, 
        0.013114914738036429`}, {-5., -3., 
        4.858218205069373*^-18}, {-5., -3., -4.848768667039857*^-18}, \
{-5.147075757082808, -2.973604532776766, 0.013114914738036429`}}], 
       Polygon3DBox[{{-5., -3., -4.848768667039857*^-18}, {-5., -3., \
-4.848768667039857*^-18}, {-4.852924242917192, -3.026395467223234, \
-0.01311491473803643}, {-4.852924242917192, -3.026395467223234, \
-0.013114914738036434`}, {-5., -3., -4.848768667039857*^-18}}], 
       Polygon3DBox[{{-4.852924242917192, -3.026395467223234, \
-0.013114914738036434`}, {-4.852924242917192, -3.026395467223234, \
-0.01311491473803643}, {-4.705848485834384, -3.052790934446468, \
-0.026229829476072854`}, {-4.705848485834384, -3.052790934446468, \
-0.026229829476072865`}, {-4.852924242917192, -3.026395467223234, \
-0.013114914738036434`}}], 
       Polygon3DBox[{{-4.705848485834384, -3.052790934446468, \
-0.026229829476072865`}, {-4.705848485834384, -3.052790934446468, \
-0.026229829476072854`}, {-4.558772728751576, -3.079186401669702, \
-0.03934474421410929}, {-4.558772728751576, -3.079186401669702, \
-0.03934474421410929}, {-4.705848485834384, -3.052790934446468, \
-0.026229829476072865`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewHnCaFdf9TWWLPs+Qr
r5mu6IGp5jsiHk1mPxAlIcf/7/Yse7ZLv9hmTxM5cFo6RufjSZh4lz0DGIgc
gNAcB+Znvkv8lxhm80uX9WdKpvAB0yeLL/OZcRwIh6jf/yWa69PJS0IHsk+4
L5fN4TgQATF//7tO/td6NkIHFqx5XaWziOOAI8Q9+9+iiUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1p70QWrhB3WmPKzwBhR2gJQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.512627240987176, -3.3579995520295336`, 
      0.11853114588381125`}, {-5.369827301509674, -2.4836276446310626`, \
-0.03984165745559268}, {-4.487372759012824, -2.6420004479704664`, \
-0.11853114588381125`}, {-4.630172698490326, -3.5163723553689374`, 
      0.03984165745559268}, {-5.512627240987176, -3.3579995520295336`, 
      0.11853114588381125`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}, {-5.369827301509674, -2.4836276446310626`, \
-0.03984165745559268}, {-4.487372759012824, -2.6420004479704664`, \
-0.11853114588381125`}, {-4.630172698490326, -3.5163723553689374`, 
       0.03984165745559268}, {-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.048033365168029, -2.444168992879824, 
      0.05391383491050878}, {-5.048033365168029, -2.444168992879824, 
      0.053913834910508766`}, {-5.032022243445353, -2.296112661919883, 
      0.03594255660700585}, {-5.032022243445353, -2.296112661919883, 
      0.03594255660700586}, {-5.048033365168029, -2.444168992879824, 
      0.05391383491050878}}], 
     Polygon3DBox[{{-5.032022243445353, -2.296112661919883, 
      0.03594255660700586}, {-5.032022243445353, -2.296112661919883, 
      0.03594255660700585}, {-5.016011121722676, -2.1480563309599416`, 
      0.017971278303502928`}, {-5.016011121722676, -2.148056330959941, 
      0.01797127830350293}, {-5.032022243445353, -2.296112661919883, 
      0.03594255660700586}}], 
     Polygon3DBox[{{-5.016011121722676, -2.148056330959941, 
      0.01797127830350293}, {-5.016011121722676, -2.1480563309599416`, 
      0.017971278303502928`}, {-5., -2., 7.36304567013023*^-18}, {-5., -2., 
      0.}, {-5.016011121722676, -2.148056330959941, 0.01797127830350293}}], 
     Polygon3DBox[{{-5., -2., 
      0.}, {-5., -2., -5.938372299533417*^-18}, {-4.983988878277324, \
-1.8519436690400588`, -0.017971278303502928`}, {-4.983988878277324, \
-1.8519436690400588`, -0.017971278303502924`}, {-5., -2., 0.}}], 
     Polygon3DBox[{{-4.983988878277324, -1.8519436690400588`, \
-0.017971278303502924`}, {-4.983988878277324, -1.8519436690400588`, \
-0.017971278303502928`}, {-4.967977756554647, -1.7038873380801174`, \
-0.03594255660700585}, {-4.967977756554647, -1.7038873380801174`, \
-0.035942556607005856`}, {-4.983988878277324, -1.8519436690400588`, \
-0.017971278303502924`}}], 
     Polygon3DBox[{{-4.967977756554647, -1.7038873380801174`, \
-0.035942556607005856`}, {-4.967977756554647, -1.7038873380801174`, \
-0.03594255660700585}, {-4.951966634831971, -1.555831007120176, \
-0.05391383491050877}, {-4.951966634831971, -1.555831007120176, \
-0.053913834910508766`}, {-4.967977756554647, -1.7038873380801174`, \
-0.035942556607005856`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7GO2mFvqHIgYR2ocoVvcwHLI1rpGfMWm3fH5dY
cEpB5MBrlu0BBXFMBy6dCRISSF9k777ewCJVQORAaVO0hoU+I1R8kj0DGIgc
gNAMB2JC7xcfXR1nszPg/PFZ74UPiP32WN+/8O/+CxD1+wsXzus3vS98QPvb
xDh559/7L0LM36/1KTf8wjnhAw4fb/Guf/JjvznEPRjiUHfCzdGCmgN1536Y
vaJQe6Hu3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwDMJZ9O
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.44411932046949, -1.9460861650894912`, 
        0.04849048969603271}, {-5.44411932046949, -1.9460861650894912`, 
        0.0484904896960327}, {-5.2960795469796595`, -1.964057443392994, 
        0.032326993130688465`}, {-5.2960795469796595`, -1.964057443392994, 
        0.03232699313068848}, {-5.44411932046949, -1.9460861650894912`, 
        0.04849048969603271}}], 
       Polygon3DBox[{{-5.2960795469796595`, -1.964057443392994, 
        0.03232699313068848}, {-5.2960795469796595`, -1.964057443392994, 
        0.032326993130688465`}, {-5.14803977348983, -1.9820287216964971`, 
        0.01616349656534424}, {-5.14803977348983, -1.9820287216964971`, 
        0.016163496565344236`}, {-5.2960795469796595`, -1.964057443392994, 
        0.03232699313068848}}], 
       Polygon3DBox[{{-5.14803977348983, -1.9820287216964971`, 
        0.016163496565344236`}, {-5.14803977348983, -1.9820287216964971`, 
        0.01616349656534424}, {-5., -2., 
        8.662120429217534*^-18}, {-5., -2., -3.3012702676456704`*^-18}, \
{-5.14803977348983, -1.9820287216964971`, 0.016163496565344236`}}], 
       Polygon3DBox[{{-5., -2., -3.3012702676456704`*^-18}, {-5., -2., \
-3.3012702676456704`*^-18}, {-4.85196022651017, -2.017971278303503, \
-0.016163496565344236`}, {-4.85196022651017, -2.017971278303503, \
-0.016163496565344236`}, {-5., -2., -3.3012702676456704`*^-18}}], 
       Polygon3DBox[{{-4.85196022651017, -2.017971278303503, \
-0.016163496565344236`}, {-4.85196022651017, -2.017971278303503, \
-0.016163496565344236`}, {-4.7039204530203405`, -2.0359425566070057`, \
-0.032326993130688465`}, {-4.7039204530203405`, -2.0359425566070057`, \
-0.03232699313068848}, {-4.85196022651017, -2.017971278303503, \
-0.016163496565344236`}}], 
       Polygon3DBox[{{-4.7039204530203405`, -2.0359425566070057`, \
-0.03232699313068848}, {-4.7039204530203405`, -2.0359425566070057`, \
-0.032326993130688465`}, {-4.55588067953051, -2.053913834910509, \
-0.0484904896960327}, {-4.55588067953051, -2.053913834910509, \
-0.0484904896960327}, {-4.7039204530203405`, -2.0359425566070057`, \
-0.03232699313068848}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/3W667dG3f5RX2qtq8
Vfr6ogdmZubWH8/5v1+9pOeJZu8C+8lT2fZOny5y4OyWbfuTt8HEJ9gzgIHI
AQjNcOCV2KuaD1OjbXKzfjplZAgfmLVUReGcCsMBVYj6/bevfGq9cEHogLG3
p8McT4YDahDz93vYvzlhYSl04OyH3ISsPIYD5hD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAOcOq2o=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.492152685637519, -2.390255157969315, 
      0.10240432460654149`}, {-5.39608595530146, -1.5019171722096671`, \
-0.005423345214476072}, {-4.507847314362481, -1.6097448420306848`, \
-0.10240432460654149`}, {-4.60391404469854, -2.498082827790333, 
      0.005423345214476072}, {-5.492152685637519, -2.390255157969315, 
      0.10240432460654149`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}, {-5.39608595530146, -1.5019171722096671`, \
-0.005423345214476072}, {-4.507847314362481, -1.6097448420306848`, \
-0.10240432460654149`}, {-4.60391404469854, -2.498082827790333, 
       0.005423345214476072}, {-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.02414962427121, -1.4485210978244876`, 
      0.027306051598058115`}, {-5.02414962427121, -1.4485210978244876`, 
      0.0273060515980581}, {-5.01609974951414, -1.299014065216325, 
      0.0182040343987054}, {-5.01609974951414, -1.299014065216325, 
      0.018204034398705413`}, {-5.02414962427121, -1.4485210978244876`, 
      0.027306051598058115`}}], 
     Polygon3DBox[{{-5.01609974951414, -1.299014065216325, 
      0.018204034398705413`}, {-5.01609974951414, -1.299014065216325, 
      0.0182040343987054}, {-5.00804987475707, -1.1495070326081627`, 
      0.009102017199352701}, {-5.00804987475707, -1.1495070326081624`, 
      0.009102017199352707}, {-5.01609974951414, -1.299014065216325, 
      0.018204034398705413`}}], 
     Polygon3DBox[{{-5.00804987475707, -1.1495070326081624`, 
      0.009102017199352707}, {-5.00804987475707, -1.1495070326081627`, 
      0.009102017199352701}, {-5., -1.0000000000000002`, 
      1.0274022701855382`*^-19}, {-5., -1., 
      0.}, {-5.00804987475707, -1.1495070326081624`, 0.009102017199352707}}], 
     Polygon3DBox[{{-5., -1., 
      0.}, {-5., -1., -6.634105816485149*^-18}, {-4.99195012524293, \
-0.8504929673918376, -0.009102017199352708}, {-4.99195012524293, \
-0.8504929673918376, -0.009102017199352703}, {-5., -1., 0.}}], 
     Polygon3DBox[{{-4.99195012524293, -0.8504929673918376, \
-0.009102017199352703}, {-4.99195012524293, -0.8504929673918376, \
-0.009102017199352708}, {-4.98390025048586, -0.7009859347836751, \
-0.01820403439870541}, {-4.98390025048586, -0.7009859347836751, \
-0.01820403439870541}, {-4.99195012524293, -0.8504929673918376, \
-0.009102017199352703}}], 
     Polygon3DBox[{{-4.98390025048586, -0.7009859347836751, \
-0.01820403439870541}, {-4.98390025048586, -0.7009859347836751, \
-0.01820403439870541}, {-4.97585037572879, -0.5514789021755127, \
-0.027306051598058115`}, {-4.97585037572879, -0.5514789021755127, \
-0.02730605159805811}, {-4.98390025048586, -0.7009859347836751, \
-0.01820403439870541}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64dHPtLgmRAxJ92aUqut/3t9xNkpL7Nts+oOdZ
cY2AyIFdcZ9+HDrxZX+k3XRBkSWT7DXcPlvacYgciNWvrElM+QQVb7JnAAOR
AxD6w/7JQn+Olwn629zYyXPs4HfhA24LedltzV/vD4eo37+hWLKn+b3wgR4n
ab6qvGf7IyDm7+/QVQtyfS584NJjDdHtSx/ub4a4By5+ESoOdSfcnG6oOVB3
7ke3F+rO/TjcuQfdX1B3YoQD1J32sHATh4Yb1J32uMITAN4Goo8=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.445892160646057, -0.9726939484019419, 
        0.05417158499172228}, {-5.445892160646057, -0.9726939484019418, 
        0.05417158499172228}, {-5.297261440430704, -0.9817959656012946, 
        0.03611438999448152}, {-5.297261440430704, -0.9817959656012946, 
        0.03611438999448153}, {-5.445892160646057, -0.9726939484019419, 
        0.05417158499172228}}], 
       Polygon3DBox[{{-5.297261440430704, -0.9817959656012946, 
        0.03611438999448153}, {-5.297261440430704, -0.9817959656012946, 
        0.03611438999448152}, {-5.148630720215352, -0.9908979828006472, 
        0.018057194997240768`}, {-5.148630720215352, -0.9908979828006472, 
        0.018057194997240764`}, {-5.297261440430704, -0.9817959656012946, 
        0.03611438999448153}}], 
       Polygon3DBox[{{-5.148630720215352, -0.9908979828006472, 
        0.018057194997240764`}, {-5.148630720215352, -0.9908979828006472, 
        0.018057194997240768`}, {-5., -1., 
        1.1692995663042871`*^-17}, {-5., -1., -1.672013434345717*^-18}, \
{-5.148630720215352, -0.9908979828006472, 0.018057194997240764`}}], 
       Polygon3DBox[{{-5., -1., -1.672013434345717*^-18}, {-5., -1., \
-1.672013434345717*^-18}, {-4.851369279784648, -1.0091020171993528`, \
-0.018057194997240757`}, {-4.851369279784648, -1.0091020171993528`, \
-0.01805719499724076}, {-5., -1., -1.672013434345717*^-18}}], 
       Polygon3DBox[{{-4.851369279784648, -1.0091020171993528`, \
-0.01805719499724076}, {-4.851369279784648, -1.0091020171993528`, \
-0.018057194997240757`}, {-4.702738559569296, -1.0182040343987053`, \
-0.036114389994481515`}, {-4.702738559569296, -1.0182040343987053`, \
-0.03611438999448152}, {-4.851369279784648, -1.0091020171993528`, \
-0.01805719499724076}}], 
       Polygon3DBox[{{-4.702738559569296, -1.0182040343987053`, \
-0.03611438999448152}, {-4.702738559569296, -1.0182040343987053`, \
-0.036114389994481515`}, {-4.554107839353944, -1.027306051598058, \
-0.054171584991722276`}, {-4.554107839353944, -1.027306051598058, \
-0.05417158499172227}, {-4.702738559569296, -1.0182040343987053`, \
-0.03611438999448152}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/3b3lx6XDCntX2TDxT
fFMNRA/wuhXH3896v7/yw8PrU2sX2TOynVpmNEPkAPvinevzt8LEJ9kzgIHI
AQj9Yf+JCRVC/hfjbP7/NI08my58oFZPWcND9cP+coj6/f8+Z2+adV7owM8Y
t4AJXh/2V0DM3//37ULuDHOhA2XdmRU38j/s3wRxz/4/aOJQd2KYA3XnfnR7
oe7cj8Ode9D9BXUnRjhA3WnPjBZuUHfa4wpPAIesugg=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.470041784917267, -1.4212150462264295`, 
      0.0814776365897804}, {-5.421742536374846, -0.5241728505774544, 
      0.026865533393664168`}, {-4.529958215082733, -0.5787849537735706, \
-0.0814776365897804}, {-4.578257463625154, -1.4758271494225457`, \
-0.026865533393664168`}, {-5.470041784917267, -1.4212150462264295`, 
      0.0814776365897804}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}, {-5.421742536374846, -0.5241728505774544, 
       0.026865533393664168`}, {-4.529958215082733, -0.5787849537735706, \
-0.0814776365897804}, {-4.578257463625154, -1.4758271494225457`, \
-0.026865533393664168`}, {-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5., -0.45, 
      0.}, {-5., -0.45, -1.3740257225098643`*^-17}, {-5., -0.3, \
-1.1450214354248867`*^-17}, {-5., -0.30000000000000004`, 0.}, {-5., -0.45, 
      0.}}], Polygon3DBox[{{-5., -0.30000000000000004`, 
      0.}, {-5., -0.3, -1.1450214354248867`*^-17}, {-5., \
-0.15000000000000008`, -9.160171483399096*^-18}, {-5., -0.15000000000000002`, 
      0.}, {-5., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{-5., -0.15000000000000002`, 
      0.}, {-5., -0.15000000000000008`, -9.160171483399096*^-18}, {-5., \
-1.1102230246251565`*^-16, -6.870128612549323*^-18}, {-5., 0., 
      0.}, {-5., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{-5., 0., 0.}, {-5., 0., -6.8701286125493215`*^-18}, {-5., 
      0.14999999999999997`, -4.580085741699548*^-18}, {-5., 
      0.14999999999999997`, 0.}, {-5., 0., 0.}}], 
     Polygon3DBox[{{-5., 0.14999999999999997`, 0.}, {-5., 
      0.14999999999999997`, -4.580085741699548*^-18}, {-5., 
      0.29999999999999993`, -2.2900428708497745`*^-18}, {-5., 0.3, 0.}, {-5., 
      0.14999999999999997`, 0.}}], 
     Polygon3DBox[{{-5., 0.3, 0.}, {-5., 
      0.29999999999999993`, -2.290042870849775*^-18}, {-5., 
      0.44999999999999996`, -1.1441062451682506`*^-33}, {-5., 
      0.4499999999999999, 0.}, {-5., 0.3, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOXD2DAjc2c+AAkQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDq/UMU
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.446489549934516, 0., 
        0.05609885737938949}, {-5.446489549934516, 5.5109105961630896`*^-17, 
        0.05609885737938949}, {-5.297659699956344, 4.592425496802574*^-17, 
        0.03739923825292633}, {-5.297659699956344, 9.184850993605149*^-18, 
        0.037399238252926334`}, {-5.446489549934516, 0., 
        0.05609885737938949}}], 
       Polygon3DBox[{{-5.297659699956344, 9.184850993605149*^-18, 
        0.037399238252926334`}, {-5.297659699956344, 4.592425496802574*^-17, 
        0.03739923825292633}, {-5.148829849978172, 3.67394039744206*^-17, 
        0.018699619126463174`}, {-5.148829849978172, 1.8369701987210297`*^-17,
         0.018699619126463167`}, {-5.297659699956344, 9.184850993605149*^-18, 
        0.037399238252926334`}}], 
       Polygon3DBox[{{-5.148829849978172, 1.8369701987210297`*^-17, 
        0.018699619126463167`}, {-5.148829849978172, 3.67394039744206*^-17, 
        0.018699619126463174`}, {-5., 2.7554552980815454`*^-17, 
        1.3840498470613574`*^-17}, {-5., 2.7554552980815448`*^-17, 
        0.}, {-5.148829849978172, 1.8369701987210297`*^-17, 
        0.018699619126463167`}}], 
       Polygon3DBox[{{-5., 2.7554552980815448`*^-17, 0.}, {-5., 
        2.7554552980815448`*^-17, 0.}, {-4.851170150021828, 
        1.83697019872103*^-17, -0.01869961912646316}, {-4.851170150021828, 
        3.6739403974420595`*^-17, -0.01869961912646316}, {-5., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{-4.851170150021828, 
        3.6739403974420595`*^-17, -0.01869961912646316}, {-4.851170150021828, 
        1.83697019872103*^-17, -0.01869961912646316}, {-4.702340300043656, 
        9.184850993605152*^-18, -0.03739923825292632}, {-4.702340300043656, 
        4.592425496802574*^-17, -0.03739923825292633}, {-4.851170150021828, 
        3.6739403974420595`*^-17, -0.01869961912646316}}], 
       Polygon3DBox[{{-4.702340300043656, 
        4.592425496802574*^-17, -0.03739923825292633}, {-4.702340300043656, 
        9.184850993605153*^-18, -0.03739923825292632}, {-4.553510450065484, 
        4.5887548728832574`*^-33, -0.05609885737938948}, {-4.553510450065484, 
        5.510910596163089*^-17, -0.05609885737938947}, {-4.702340300043656, 
        4.592425496802574*^-17, -0.03739923825292633}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH76tLrP5KToAQYoUNaZ7P13xxp755lBW84aIMTz
ZJOM/qkutl/ko3krbYYImvhkewgPIZ7Qtvjfn5fxNnGbr6nOTBeGi+dA1O/f
m7bW2+i8EFw8F2L+fmmplsLTZghxRYh7MMSh7sQwB+rO/ej2Qt25H4c796D7
C+pOjHCAutMePdyg7sQQh4UnAIbCbzw=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.446489549934516, -0.45, 
      0.05609885737938949}, {-5.446489549934516, 0.45, 
      0.05609885737938949}, {-4.553510450065484, 
      0.45, -0.05609885737938949}, {-4.553510450065484, -0.45, \
-0.05609885737938949}, {-5.446489549934516, -0.45, 0.05609885737938949}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.446489549934516, -0.45, 
       0.05609885737938949}, {-5.446489549934516, 0.45, 
       0.05609885737938949}, {-4.553510450065484, 
       0.45, -0.05609885737938949}, {-4.553510450065484, -0.45, \
-0.05609885737938949}, {-5.446489549934516, -0.45, 
       0.05609885737938949}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.97585037572879, 
      0.5514789021755125, -0.027306051598058115`}, {-4.975850375728789, 
      0.5514789021755125, -0.02730605159805813}, {-4.98390025048586, 
      0.7009859347836751, -0.01820403439870542}, {-4.98390025048586, 
      0.700985934783675, -0.018204034398705413`}, {-4.97585037572879, 
      0.5514789021755125, -0.027306051598058115`}}], 
     Polygon3DBox[{{-4.98390025048586, 
      0.700985934783675, -0.018204034398705413`}, {-4.98390025048586, 
      0.7009859347836751, -0.01820403439870542}, {-4.99195012524293, 
      0.8504929673918374, -0.009102017199352719}, {-4.99195012524293, 
      0.8504929673918376, -0.009102017199352707}, {-4.98390025048586, 
      0.700985934783675, -0.018204034398705413`}}], 
     Polygon3DBox[{{-4.99195012524293, 
      0.8504929673918376, -0.009102017199352707}, {-4.99195012524293, 
      0.8504929673918374, -0.009102017199352719}, {-5., 
      0.9999999999999999, -1.3370951859988855`*^-17}, {-5., 1., 
      0.}, {-4.99195012524293, 0.8504929673918376, -0.009102017199352707}}], 
     Polygon3DBox[{{-5., 1., 0.}, {-5., 
      1., -6.634105816485149*^-18}, {-5.00804987475707, 1.1495070326081624`, 
      0.009102017199352698}, {-5.00804987475707, 1.1495070326081624`, 
      0.009102017199352703}, {-5., 1., 0.}}], 
     Polygon3DBox[{{-5.00804987475707, 1.1495070326081624`, 
      0.009102017199352703}, {-5.00804987475707, 1.1495070326081624`, 
      0.009102017199352698}, {-5.01609974951414, 1.299014065216325, 
      0.018204034398705403`}, {-5.01609974951414, 1.299014065216325, 
      0.01820403439870541}, {-5.00804987475707, 1.1495070326081624`, 
      0.009102017199352703}}], 
     Polygon3DBox[{{-5.01609974951414, 1.299014065216325, 
      0.01820403439870541}, {-5.01609974951414, 1.299014065216325, 
      0.018204034398705403`}, {-5.02414962427121, 1.4485210978244873`, 
      0.027306051598058115`}, {-5.02414962427121, 1.4485210978244873`, 
      0.02730605159805811}, {-5.01609974951414, 1.299014065216325, 
      0.01820403439870541}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO7QVQtyfS584OJjDdHtSx/at9xNkpL7Nnv/hmLJ
nub3wge6naT5qvKe2UfaTRcUWTJp/42dPMcOfhc+4LaQl93W/DVUvGk/AxiI
HIDQH+wnC/05Xibov0fD7bOlHYfIgVj9yprElE/24RD19gE9z4prBEQO7Ir7
9OPQiS/2ERDz7Ssu3Vy7S0LkgHhfdqmK7nf7Zoh74OISUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw6EHGg5Qd+6HhdslaLhB3bkfV3gCAPXvm6U=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.445892160646057, 0.9726939484019419, 
        0.05417158499172228}, {-5.445892160646057, 0.9726939484019419, 
        0.05417158499172228}, {-5.297261440430704, 0.9817959656012947, 
        0.03611438999448152}, {-5.297261440430704, 0.9817959656012946, 
        0.03611438999448153}, {-5.445892160646057, 0.9726939484019419, 
        0.05417158499172228}}], 
       Polygon3DBox[{{-5.297261440430704, 0.9817959656012946, 
        0.03611438999448153}, {-5.297261440430704, 0.9817959656012947, 
        0.03611438999448152}, {-5.148630720215352, 0.9908979828006473, 
        0.018057194997240775`}, {-5.148630720215352, 0.9908979828006473, 
        0.018057194997240764`}, {-5.297261440430704, 0.9817959656012946, 
        0.03611438999448153}}], 
       Polygon3DBox[{{-5.148630720215352, 0.9908979828006473, 
        0.018057194997240764`}, {-5.148630720215352, 0.9908979828006473, 
        0.018057194997240775`}, {-5., 1., 1.5037022531734306`*^-17}, {-5., 1.,
         1.672013434345717*^-18}, {-5.148630720215352, 0.9908979828006473, 
        0.018057194997240764`}}], 
       Polygon3DBox[{{-5., 1., 1.672013434345717*^-18}, {-5., 1., 
        1.672013434345717*^-18}, {-4.851369279784648, 
        1.0091020171993528`, -0.018057194997240757`}, {-4.851369279784648, 
        1.0091020171993528`, -0.018057194997240754`}, {-5., 1., 
        1.672013434345717*^-18}}], 
       Polygon3DBox[{{-4.851369279784648, 
        1.0091020171993528`, -0.018057194997240754`}, {-4.851369279784648, 
        1.0091020171993528`, -0.018057194997240757`}, {-4.702738559569296, 
        1.0182040343987053`, -0.036114389994481515`}, {-4.702738559569296, 
        1.0182040343987055`, -0.03611438999448152}, {-4.851369279784648, 
        1.0091020171993528`, -0.018057194997240754`}}], 
       Polygon3DBox[{{-4.702738559569296, 
        1.0182040343987055`, -0.03611438999448152}, {-4.702738559569296, 
        1.0182040343987053`, -0.036114389994481515`}, {-4.554107839353944, 
        1.027306051598058, -0.054171584991722276`}, {-4.554107839353944, 
        1.027306051598058, -0.05417158499172227}, {-4.702738559569296, 
        1.0182040343987055`, -0.03611438999448152}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/tt7y4dDhhz2p7Jp4p
vqkGogd43Yrj72e9t6/88PD61NpF9oxsp5YZzRA5wL545/r8rTDxSfYMYCBy
AEJ/sD8xoULI/2Kczf+fppFn04UP1Oopa3iofrAvh6jf/+9z9qZZ54UO/Ixx
C5jg9cG+AmL+/r9vF3JnmAsdKOvOrLiR/8F+E8Q9+/+giUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz0zWrhB3WmPKzwBV+GyiA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.421742536374846, 0.5241728505774544, 
      0.026865533393664168`}, {-5.470041784917267, 1.4212150462264295`, 
      0.0814776365897804}, {-4.578257463625154, 
      1.4758271494225457`, -0.026865533393664168`}, {-4.529958215082733, 
      0.5787849537735706, -0.0814776365897804}, {-5.421742536374846, 
      0.5241728505774544, 0.026865533393664168`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.421742536374846, 0.5241728505774544, 
       0.026865533393664168`}, {-5.470041784917267, 1.4212150462264295`, 
       0.0814776365897804}, {-4.578257463625154, 
       1.4758271494225457`, -0.026865533393664168`}, {-4.529958215082733, 
       0.5787849537735706, -0.0814776365897804}, {-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.951966634831971, 
      1.555831007120176, -0.05391383491050878}, {-4.951966634831971, 
      1.555831007120176, -0.053913834910508794`}, {-4.967977756554647, 
      1.7038873380801174`, -0.03594255660700586}, {-4.967977756554647, 
      1.7038873380801172`, -0.03594255660700586}, {-4.951966634831971, 
      1.555831007120176, -0.05391383491050878}}], 
     Polygon3DBox[{{-4.967977756554647, 
      1.7038873380801172`, -0.03594255660700586}, {-4.967977756554647, 
      1.7038873380801174`, -0.03594255660700586}, {-4.983988878277324, 
      1.8519436690400586`, -0.017971278303502942`}, {-4.983988878277324, 
      1.8519436690400586`, -0.01797127830350293}, {-4.967977756554647, 
      1.7038873380801172`, -0.03594255660700586}}], 
     Polygon3DBox[{{-4.983988878277324, 
      1.8519436690400586`, -0.01797127830350293}, {-4.983988878277324, 
      1.8519436690400586`, -0.017971278303502942`}, {-5., 
      2., -1.9239790269197065`*^-17}, {-5., 2., 0.}, {-4.983988878277324, 
      1.8519436690400586`, -0.01797127830350293}}], 
     Polygon3DBox[{{-5., 2., 0.}, {-5., 
      2., -5.938372299533417*^-18}, {-5.016011121722676, 2.148056330959941, 
      0.01797127830350292}, {-5.016011121722676, 2.148056330959941, 
      0.017971278303502924`}, {-5., 2., 0.}}], 
     Polygon3DBox[{{-5.016011121722676, 2.148056330959941, 
      0.017971278303502924`}, {-5.016011121722676, 2.148056330959941, 
      0.01797127830350292}, {-5.032022243445353, 2.2961126619198824`, 
      0.03594255660700585}, {-5.032022243445353, 2.296112661919883, 
      0.035942556607005856`}, {-5.016011121722676, 2.148056330959941, 
      0.017971278303502924`}}], 
     Polygon3DBox[{{-5.032022243445353, 2.296112661919883, 
      0.035942556607005856`}, {-5.032022243445353, 2.2961126619198824`, 
      0.03594255660700585}, {-5.048033365168029, 2.444168992879824, 
      0.05391383491050877}, {-5.048033365168029, 2.444168992879824, 
      0.053913834910508766`}, {-5.032022243445353, 2.296112661919883, 
      0.035942556607005856`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb6lBt+4ZzwAYePt3jXP/lhb2lcIz1j1ur9hQvn
9ZveFz6g9W1inLzzb/tLZ4KEBNIX7d8ZcP74rPfCB0R/e6zvX/gXKj5pPwMY
iByA0AwOMaH3i4+ujtvjvt7AIlVA5EBpU7SGhT6jwwWIevv+uMSCUwoiB16z
bA8oiGNyuAgx3/4a76QV+oYiBxLahSpX9DI7mEPcgyEOdSeGOVB32qPbC3Wn
PQ532sD8JQb1F9Sd8HDQhoYD1J370cMN6k4McVh4AgAZpptG
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.44411932046949, 1.9460861650894912`, 
        0.04849048969603271}, {-5.44411932046949, 1.9460861650894912`, 
        0.048490489696032715`}, {-5.2960795469796595`, 1.9640574433929943`, 
        0.03232699313068848}, {-5.2960795469796595`, 1.964057443392994, 
        0.03232699313068848}, {-5.44411932046949, 1.9460861650894912`, 
        0.04849048969603271}}], 
       Polygon3DBox[{{-5.2960795469796595`, 1.964057443392994, 
        0.03232699313068848}, {-5.2960795469796595`, 1.9640574433929943`, 
        0.03232699313068848}, {-5.14803977348983, 1.9820287216964971`, 
        0.016163496565344247`}, {-5.14803977348983, 1.9820287216964971`, 
        0.016163496565344243`}, {-5.2960795469796595`, 1.964057443392994, 
        0.03232699313068848}}], 
       Polygon3DBox[{{-5.14803977348983, 1.9820287216964971`, 
        0.016163496565344243`}, {-5.14803977348983, 1.9820287216964971`, 
        0.016163496565344247`}, {-5., 2., 1.5264660964508877`*^-17}, {-5., 2.,
         3.3012702676456704`*^-18}, {-5.14803977348983, 1.9820287216964971`, 
        0.016163496565344243`}}], 
       Polygon3DBox[{{-5., 2., 3.3012702676456704`*^-18}, {-5., 2., 
        3.3012702676456704`*^-18}, {-4.85196022651017, 
        2.017971278303503, -0.01616349656534423}, {-4.85196022651017, 
        2.017971278303503, -0.01616349656534423}, {-5., 2., 
        3.3012702676456704`*^-18}}], 
       Polygon3DBox[{{-4.85196022651017, 
        2.017971278303503, -0.01616349656534423}, {-4.85196022651017, 
        2.017971278303503, -0.01616349656534423}, {-4.7039204530203405`, 
        2.0359425566070057`, -0.032326993130688465`}, {-4.7039204530203405`, 
        2.0359425566070057`, -0.032326993130688465`}, {-4.85196022651017, 
        2.017971278303503, -0.01616349656534423}}], 
       Polygon3DBox[{{-4.7039204530203405`, 
        2.0359425566070057`, -0.032326993130688465`}, {-4.7039204530203405`, 
        2.0359425566070057`, -0.032326993130688465`}, {-4.55588067953051, 
        2.053913834910509, -0.0484904896960327}, {-4.55588067953051, 
        2.053913834910509, -0.04849048969603269}, {-4.7039204530203405`, 
        2.0359425566070057`, -0.032326993130688465`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/tLdddurbv8gp7VW3e
Kn190QMzM3Prj+f8t1cv6Xmi2bvAfvJUtr3Tp4scOLtl2/7kbTDxCfYMYCBy
AEIzOLwSe1XzYWq0TW7WT6eMDOEDs5aqKJxTYXBQhajff/vKp9YLF4QOGHt7
OszxZHBQg5i/38P+zQkLS6EDZz/kJmTlMTiYQ9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBt0Oj6g==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.39608595530146, 
      1.5019171722096671`, -0.005423345214476072}, {-5.492152685637519, 
      2.390255157969315, 0.10240432460654149`}, {-4.60391404469854, 
      2.498082827790333, 0.005423345214476072}, {-4.507847314362481, 
      1.6097448420306848`, -0.10240432460654149`}, {-5.39608595530146, 
      1.5019171722096671`, -0.005423345214476072}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}, {-5.492152685637519, 
       2.390255157969315, 0.10240432460654149`}, {-4.60391404469854, 
       2.498082827790333, 0.005423345214476072}, {-4.507847314362481, 
       1.6097448420306848`, -0.10240432460654149`}, {-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.928600030261249, 
      2.5628140463007645`, -0.07918640166970196}, {-4.928600030261249, 
      2.5628140463007645`, -0.07918640166970198}, {-4.952400020174166, 
      2.708542697533843, -0.052790934446467985`}, {-4.952400020174166, 
      2.708542697533843, -0.052790934446467985`}, {-4.928600030261249, 
      2.5628140463007645`, -0.07918640166970196}}], 
     Polygon3DBox[{{-4.952400020174166, 
      2.708542697533843, -0.052790934446467985`}, {-4.952400020174166, 
      2.708542697533843, -0.052790934446467985`}, {-4.976200010087083, 
      2.8542713487669213`, -0.02639546722323401}, {-4.976200010087083, 
      2.8542713487669213`, -0.026395467223233993`}, {-4.952400020174166, 
      2.708542697533843, -0.052790934446467985`}}], 
     Polygon3DBox[{{-4.976200010087083, 
      2.8542713487669213`, -0.026395467223233993`}, {-4.976200010087083, 
      2.8542713487669213`, -0.02639546722323401}, {-5., 
      3., -2.435491181115671*^-17}, {-5., 3., 0.}, {-4.976200010087083, 
      2.8542713487669213`, -0.026395467223233993`}}], 
     Polygon3DBox[{{-5., 3., 0.}, {-5., 
      3., -4.818341506508028*^-18}, {-5.023799989912917, 3.1457286512330787`, 
      0.02639546722323398}, {-5.023799989912917, 3.1457286512330787`, 
      0.026395467223233982`}, {-5., 3., 0.}}], 
     Polygon3DBox[{{-5.023799989912917, 3.1457286512330787`, 
      0.026395467223233982`}, {-5.023799989912917, 3.1457286512330787`, 
      0.02639546722323398}, {-5.047599979825834, 3.291457302466157, 
      0.052790934446467964`}, {-5.047599979825834, 3.291457302466157, 
      0.05279093444646798}, {-5.023799989912917, 3.1457286512330787`, 
      0.026395467223233982`}}], 
     Polygon3DBox[{{-5.047599979825834, 3.291457302466157, 
      0.05279093444646798}, {-5.047599979825834, 3.291457302466157, 
      0.052790934446467964`}, {-5.071399969738751, 3.4371859536992355`, 
      0.07918640166970196}, {-5.071399969738751, 3.4371859536992355`, 
      0.07918640166970195}, {-5.047599979825834, 3.291457302466157, 
      0.05279093444646798}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO5TVXn7aJvwgXO7pixb0sDiwDylNLbfdcv++Lzc
z47nhQ/cv8ibL7Ga1WGD1KeLmeyr9+tv3/ZzwXPhA+9ftJn3XGWDis/ezwAG
IgcgNIfD8wOeLbptaXsueniyxUuIHBAUrzxRrMXpsBai3n7hxEk8+wxEDijq
fZrwPITLYT3EfPuiW7eFZD1FDhi5ZkdG13M7MEHcgyEOdSeGOVB32qPbC3Wn
PQ532qD7C+pOjHCAunM/erhB3YkhDgtPAPxcm8c=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.441227271248425, 2.920813598330298, 
        0.03934474421410929}, {-5.441227271248425, 2.920813598330298, 
        0.039344744214109294`}, {-5.294151514165616, 2.947209065553532, 
        0.026229829476072865`}, {-5.294151514165616, 2.947209065553532, 
        0.026229829476072865`}, {-5.441227271248425, 2.920813598330298, 
        0.03934474421410929}}], 
       Polygon3DBox[{{-5.294151514165616, 2.947209065553532, 
        0.026229829476072865`}, {-5.294151514165616, 2.947209065553532, 
        0.026229829476072865`}, {-5.147075757082808, 2.973604532776766, 
        0.013114914738036443`}, {-5.147075757082808, 2.973604532776766, 
        0.013114914738036436`}, {-5.294151514165616, 2.947209065553532, 
        0.026229829476072865`}}], 
       Polygon3DBox[{{-5.147075757082808, 2.973604532776766, 
        0.013114914738036436`}, {-5.147075757082808, 2.973604532776766, 
        0.013114914738036443`}, {-5., 3., 1.455575553914909*^-17}, {-5., 3., 
        4.848768667039857*^-18}, {-5.147075757082808, 2.973604532776766, 
        0.013114914738036436`}}], 
       Polygon3DBox[{{-5., 3., 4.848768667039857*^-18}, {-5., 3., 
        4.848768667039857*^-18}, {-4.852924242917192, 
        3.026395467223234, -0.013114914738036424`}, {-4.852924242917192, 
        3.026395467223234, -0.01311491473803642}, {-5., 3., 
        4.848768667039857*^-18}}], 
       Polygon3DBox[{{-4.852924242917192, 
        3.026395467223234, -0.01311491473803642}, {-4.852924242917192, 
        3.026395467223234, -0.013114914738036424`}, {-4.705848485834384, 
        3.052790934446468, -0.026229829476072854`}, {-4.705848485834384, 
        3.052790934446468, -0.02622982947607285}, {-4.852924242917192, 
        3.026395467223234, -0.01311491473803642}}], 
       Polygon3DBox[{{-4.705848485834384, 
        3.052790934446468, -0.02622982947607285}, {-4.705848485834384, 
        3.052790934446468, -0.026229829476072854`}, {-4.558772728751576, 
        3.079186401669702, -0.03934474421410929}, {-4.558772728751576, 
        3.079186401669702, -0.03934474421410927}, {-4.705848485834384, 
        3.052790934446468, -0.02622982947607285}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewOTpPCuv+pLLHnWfKV
10xX9MBU8x0RjyazO0RJyPH/uz3Lnu3SL7bZ00QOnJaO0fl4EibeZc8ABiIH
IDSHw/zMd4n/EsNsfumy/kzJFD5g+mTxZT4zDodwiPr9X6K5Pp28JHQg+4T7
ctkcDocIiPn733Xyv9azETqwYM3rKp1FHA6OEPfsf4smDnUnhjlQd+5Htxfq
zv043LkH3V9Qd2KEA9Sd9kJo4QZ1pz2u8AQAVVKYpQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.369827301509674, 
      2.4836276446310626`, -0.03984165745559268}, {-5.512627240987176, 
      3.3579995520295336`, 0.11853114588381125`}, {-4.630172698490326, 
      3.5163723553689374`, 0.03984165745559268}, {-4.487372759012824, 
      2.6420004479704664`, -0.11853114588381125`}, {-5.369827301509674, 
      2.4836276446310626`, -0.03984165745559268}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}, {-5.512627240987176, 
       3.3579995520295336`, 0.11853114588381125`}, {-4.630172698490326, 
       3.5163723553689374`, 0.03984165745559268}, {-4.487372759012824, 
       2.6420004479704664`, -0.11853114588381125`}, {-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.9059743600407515`, 
      3.572059914326357, -0.10259854825429525`}, {-4.9059743600407515`, 
      3.572059914326357, -0.10259854825429525`}, {-4.937316240027168, 
      3.7147066095509045`, -0.06839903216953015}, {-4.937316240027168, 
      3.7147066095509045`, -0.06839903216953017}, {-4.9059743600407515`, 
      3.572059914326357, -0.10259854825429525`}}], 
     Polygon3DBox[{{-4.937316240027168, 
      3.7147066095509045`, -0.06839903216953017}, {-4.937316240027168, 
      3.7147066095509045`, -0.06839903216953015}, {-4.9686581200135835`, 
      3.8573533047754522`, -0.034199516084765104`}, {-4.9686581200135835`, 
      3.8573533047754522`, -0.03419951608476508}, {-4.937316240027168, 
      3.7147066095509045`, -0.06839903216953017}}], 
     Polygon3DBox[{{-4.9686581200135835`, 
      3.8573533047754522`, -0.03419951608476508}, {-4.9686581200135835`, 
      3.8573533047754522`, -0.034199516084765104`}, {-5., 
      4., -2.864082929460074*^-17}, {-5., 4., 0.}, {-4.9686581200135835`, 
      3.8573533047754522`, -0.03419951608476508}}], 
     Polygon3DBox[{{-5., 4., 0.}, {-5., 
      4., -3.328102502371016*^-18}, {-5.0313418799864165`, 4.142646695224547, 
      0.034199516084765076`}, {-5.0313418799864165`, 4.142646695224547, 
      0.034199516084765076`}, {-5., 4., 0.}}], 
     Polygon3DBox[{{-5.0313418799864165`, 4.142646695224547, 
      0.034199516084765076`}, {-5.0313418799864165`, 4.142646695224547, 
      0.034199516084765076`}, {-5.062683759972832, 4.2852933904490955`, 
      0.06839903216953015}, {-5.062683759972832, 4.2852933904490955`, 
      0.06839903216953015}, {-5.0313418799864165`, 4.142646695224547, 
      0.034199516084765076`}}], 
     Polygon3DBox[{{-5.062683759972832, 4.2852933904490955`, 
      0.06839903216953015}, {-5.062683759972832, 4.2852933904490955`, 
      0.06839903216953015}, {-5.0940256399592485`, 4.427940085673643, 
      0.10259854825429524`}, {-5.0940256399592485`, 4.427940085673643, 
      0.10259854825429522`}, {-5.062683759972832, 4.2852933904490955`, 
      0.06839903216953015}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7RJ7tv+3zhA7+EfqtOmczjcL8jjvGZ8679s7cI
Xzm/X/jAMp4gyR3beR1esdqHzWzauN/3Fuer5/eFDwSzreS5c5sPKr5wPwMY
iByA0AIOBvH7+v/r5e7ZrPpNVEJB5MC1mtU/BScJOLyEqLdP9X6jbeAgcmDt
z7DPyiqCUPGN9hKFjxw9EkQONJcxvTXdJuhwF+IeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHdihAPUnfvRww3qTgxxWHgCAL+ynUU=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.437304244059274, 3.8974014517457047`, 
        0.02717601927909476}, {-5.437304244059274, 3.8974014517457047`, 
        0.027176019279094774`}, {-5.2915361627061825`, 3.93160096783047, 
        0.018117346186063185`}, {-5.2915361627061825`, 3.93160096783047, 
        0.01811734618606318}, {-5.437304244059274, 3.8974014517457047`, 
        0.02717601927909476}}], 
       Polygon3DBox[{{-5.2915361627061825`, 3.93160096783047, 
        0.01811734618606318}, {-5.2915361627061825`, 3.93160096783047, 
        0.018117346186063185`}, {-5.145768081353092, 3.9658004839152348`, 
        0.009058673093031601}, {-5.145768081353092, 3.9658004839152348`, 
        0.009058673093031593}, {-5.2915361627061825`, 3.93160096783047, 
        0.01811734618606318}}], 
       Polygon3DBox[{{-5.145768081353092, 3.9658004839152348`, 
        0.009058673093031593}, {-5.145768081353092, 3.9658004839152348`, 
        0.009058673093031601}, {-5., 4., 1.2987114146130098`*^-17}, {-5., 4., 
        6.282349185839397*^-18}, {-5.145768081353092, 3.9658004839152348`, 
        0.009058673093031593}}], 
       Polygon3DBox[{{-5., 4., 6.282349185839397*^-18}, {-5., 4., 
        6.282349185839397*^-18}, {-4.854231918646908, 
        4.034199516084765, -0.009058673093031582}, {-4.854231918646908, 
        4.034199516084765, -0.009058673093031577}, {-5., 4., 
        6.282349185839397*^-18}}], 
       Polygon3DBox[{{-4.854231918646908, 
        4.034199516084765, -0.009058673093031577}, {-4.854231918646908, 
        4.034199516084765, -0.009058673093031582}, {-4.7084638372938175`, 
        4.0683990321695305`, -0.018117346186063168`}, {-4.7084638372938175`, 
        4.0683990321695305`, -0.018117346186063164`}, {-4.854231918646908, 
        4.034199516084765, -0.009058673093031577}}], 
       Polygon3DBox[{{-4.7084638372938175`, 
        4.0683990321695305`, -0.018117346186063164`}, {-4.7084638372938175`, 
        4.0683990321695305`, -0.018117346186063168`}, {-4.562695755940726, 
        4.102598548254295, -0.027176019279094757`}, {-4.562695755940726, 
        4.102598548254296, -0.02717601927909474}, {-4.7084638372938175`, 
        4.0683990321695305`, -0.018117346186063164`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMvvoCqncYL9ymz7yZs2
lnRoiR64yO5n+rqY30FKpKA1qneSvdfNCCuXqSIHXjAvn/V1J0y8yZ4BDEQO
QGgBhytlqfemvfaz2aa2/OjuLOEDPHVrjFiVBRwkIOr35/r6dZdfFTog8Sci
lctNwEESYv5+5ZKvAcYOQgeUq1hn8GcKOChD3IMhDnUnhjlQd+5Htxfqzv04
3LkH3V9Qd2KEA9Sd9ujhBnUnhjgsPAGKP47N
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.343278604100026, 
      3.469461366072062, -0.07542252897520049}, {-5.531329884018523, 
      4.325341537419348, 0.12977456753339}, {-4.656721395899974, 
      4.5305386339279385`, 0.07542252897520049}, {-4.468670115981477, 
      3.6746584625806524`, -0.12977456753339}, {-5.343278604100026, 
      3.469461366072062, -0.07542252897520049}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}, {-5.531329884018523, 
       4.325341537419348, 0.12977456753339}, {-4.656721395899974, 
       4.5305386339279385`, 0.07542252897520049}, {-4.468670115981477, 
       3.6746584625806524`, -0.12977456753339}, {-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.884276368973227, 
      4.583119477432655, -0.1237686193102157}, {-4.884276368973227, 
      4.583119477432656, -0.1237686193102157}, {-4.922850912648817, 
      4.722079651621771, -0.08251241287347712}, {-4.922850912648817, 
      4.722079651621771, -0.08251241287347713}, {-4.884276368973227, 
      4.583119477432655, -0.1237686193102157}}], 
     Polygon3DBox[{{-4.922850912648817, 
      4.722079651621771, -0.08251241287347713}, {-4.922850912648817, 
      4.722079651621771, -0.08251241287347712}, {-4.961425456324409, 
      4.861039825810885, -0.041256206436738586`}, {-4.961425456324409, 
      4.861039825810885, -0.041256206436738566`}, {-4.922850912648817, 
      4.722079651621771, -0.08251241287347713}}], 
     Polygon3DBox[{{-4.961425456324409, 
      4.861039825810885, -0.041256206436738566`}, {-4.961425456324409, 
      4.861039825810885, -0.041256206436738586`}, {-5., 
      5., -3.2069910638644934`*^-17}, {-5., 5., 0.}, {-4.961425456324409, 
      4.861039825810885, -0.041256206436738566`}}], 
     Polygon3DBox[{{-5., 5., 0.}, {-5., 
      5., -1.5341837754744402`*^-18}, {-5.038574543675591, 5.138960174189115, 
      0.04125620643673855}, {-5.038574543675591, 5.138960174189115, 
      0.04125620643673855}, {-5., 5., 0.}}], 
     Polygon3DBox[{{-5.038574543675591, 5.138960174189115, 
      0.04125620643673855}, {-5.038574543675591, 5.138960174189115, 
      0.04125620643673855}, {-5.077149087351183, 5.277920348378229, 
      0.0825124128734771}, {-5.077149087351183, 5.277920348378229, 
      0.08251241287347712}, {-5.038574543675591, 5.138960174189115, 
      0.04125620643673855}}], 
     Polygon3DBox[{{-5.077149087351183, 5.277920348378229, 
      0.08251241287347712}, {-5.077149087351183, 5.277920348378229, 
      0.0825124128734771}, {-5.115723631026773, 5.416880522567344, 
      0.12376861931021568`}, {-5.115723631026773, 5.416880522567344, 
      0.12376861931021566`}, {-5.077149087351183, 5.277920348378229, 
      0.08251241287347712}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM4qm7qvvlP4QNX7La6yoUIOzLGmd3zW79/vtiT5
yv8NwgeCvJRvZjwWcmCyOzepQ37rfuVLhq/qbwgf0Fw6MWdLoTBUfOl+BjAQ
OQClHdYYM6q6zyrcc1f3nGiDusiB61F5k737RBwYIOrtd0XP0WbwFzmwbusd
tekyog6MEPPtp3VmOTaUiRxoFfDe9WiVqAMDxD1w8TaoONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/bBwq4aGG9Sd+3GFJwBRVpSe
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-5.432463165002302, 4.876231380689784, 
        0.012527561224531013`}, {-5.432463165002302, 4.876231380689784, 
        0.012527561224531029`}, {-5.2883087766682015`, 4.917487587126523, 
        0.008351707483020686}, {-5.2883087766682015`, 4.917487587126523, 
        0.008351707483020677}, {-5.432463165002302, 4.876231380689784, 
        0.012527561224531013`}}], 
       Polygon3DBox[{{-5.2883087766682015`, 4.917487587126523, 
        0.008351707483020677}, {-5.2883087766682015`, 4.917487587126523, 
        0.008351707483020686}, {-5.144154388334101, 4.9587437935632614`, 
        0.00417585374151035}, {-5.144154388334101, 4.9587437935632614`, 
        0.004175853741510343}, {-5.2883087766682015`, 4.917487587126523, 
        0.008351707483020677}}], 
       Polygon3DBox[{{-5.144154388334101, 4.9587437935632614`, 
        0.004175853741510343}, {-5.144154388334101, 4.9587437935632614`, 
        0.00417585374151035}, {-5., 5., 1.066939482118507*^-17}, {-5., 5., 
        7.578642173657147*^-18}, {-5.144154388334101, 4.9587437935632614`, 
        0.004175853741510343}}], 
       Polygon3DBox[{{-5., 5., 7.578642173657147*^-18}, {-5., 5., 
        7.578642173657147*^-18}, {-4.8558456116659, 
        5.0412562064367386`, -0.004175853741510332}, {-4.8558456116659, 
        5.0412562064367386`, -0.0041758537415103264`}, {-5., 5., 
        7.578642173657147*^-18}}], 
       Polygon3DBox[{{-4.8558456116659, 
        5.0412562064367386`, -0.0041758537415103264`}, {-4.8558456116659, 
        5.0412562064367386`, -0.004175853741510332}, {-4.7116912233317985`, 
        5.082512412873477, -0.008351707483020672}, {-4.7116912233317985`, 
        5.082512412873477, -0.008351707483020662}, {-4.8558456116659, 
        5.0412562064367386`, -0.0041758537415103264`}}], 
       Polygon3DBox[{{-4.7116912233317985`, 
        5.082512412873477, -0.008351707483020662}, {-4.7116912233317985`, 
        5.082512412873477, -0.008351707483020672}, {-4.567536834997698, 
        5.123768619310216, -0.012527561224531011`}, {-4.567536834997698, 
        5.123768619310216, -0.012527561224530994`}, {-4.7116912233317985`, 
        5.082512412873477, -0.008351707483020662}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQo7VCYKnONZ0Wlvf6g6
y0pd9ADH8S13G1cLOyx7zWWyWarRXuGhrencySIHWpJvvTtwFSZeaM8ABiIH
oLSDyL09YVcbbWweyh06lZQjfKBmjqqgvZaIw1KI+v0HbVumHr0hdOCHhbdS
XQhMvHH/ohi3BA1XoQMlVwuM99aJOJRD3IMhDnUnhjlQd+5/gGYv1J37cbhz
jzyav6DuxAgHqDvt0cMN6k4McVh4AgAfYJdM
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-5.316739533975529, 
      4.4593508581224395`, -0.11124105808568469`}, {-5.548186796029076, 
      5.293111903257128, 0.1362961805347467}, {-4.683260466024471, 
      5.5406491418775605`, 0.11124105808568469`}, {-4.451813203970924, 
      4.706888096742872, -0.1362961805347467}, {-5.316739533975529, 
      4.4593508581224395`, -0.11124105808568469`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}, {-5.548186796029076, 
       5.293111903257128, 0.1362961805347467}, {-4.683260466024471, 
       5.5406491418775605`, 0.11124105808568469`}, {-4.451813203970924, 
       4.706888096742872, -0.1362961805347467}, {-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.118057072591385, -5.416370172410978, 
      0.1232818199800984}, {-4.118057072591385, -5.416370172410978, 
      0.1232818199800984}, {-4.0787047150609235`, -5.277580114940652, 
      0.08218787998673227}, {-4.0787047150609235`, -5.277580114940652, 
      0.08218787998673228}, {-4.118057072591385, -5.416370172410978, 
      0.1232818199800984}}], 
     Polygon3DBox[{{-4.0787047150609235`, -5.277580114940652, 
      0.08218787998673228}, {-4.0787047150609235`, -5.277580114940652, 
      0.08218787998673227}, {-4.039352357530461, -5.138790057470326, 
      0.041093939993366156`}, {-4.039352357530461, -5.138790057470326, 
      0.04109393999336614}, {-4.0787047150609235`, -5.277580114940652, 
      0.08218787998673228}}], 
     Polygon3DBox[{{-4.039352357530461, -5.138790057470326, 
      0.04109393999336614}, {-4.039352357530461, -5.138790057470326, 
      0.041093939993366156`}, {-4., -5., 3.01789804886315*^-17}, {-4., -5., 
      0.}, {-4.039352357530461, -5.138790057470326, 0.04109393999336614}}], 
     Polygon3DBox[{{-4., -5., 
      0.}, {-4., -5., -2.366450801682588*^-19}, {-3.9606476424695383`, \
-4.861209942529674, -0.04109393999336613}, {-3.9606476424695383`, \
-4.861209942529674, -0.04109393999336613}, {-4., -5., 0.}}], 
     Polygon3DBox[{{-3.9606476424695383`, -4.861209942529674, \
-0.04109393999336613}, {-3.9606476424695383`, -4.861209942529674, \
-0.04109393999336613}, {-3.9212952849390765`, -4.722419885059348, \
-0.08218787998673226}, {-3.9212952849390765`, -4.722419885059348, \
-0.08218787998673227}, {-3.9606476424695383`, -4.861209942529674, \
-0.04109393999336613}}], 
     Polygon3DBox[{{-3.9212952849390765`, -4.722419885059348, \
-0.08218787998673227}, {-3.9212952849390765`, -4.722419885059348, \
-0.08218787998673226}, {-3.881942927408615, -4.583629827589022, \
-0.12328181998009839`}, {-3.881942927408615, -4.583629827589022, \
-0.12328181998009838`}, {-3.9212952849390765`, -4.722419885059348, \
-0.08218787998673227}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4Yy/7lcYXAgfvKbh9jVokeqGlk3Jnav99e8SXL
j+kBAgemHtL7ZisjemDl6tUXnLm22k8oYfrjrSFwwCtR/LdcnwhUfKk9AxgI
HIDQIgd4+Ptv9HYU2twX+82esZ7/wLZ5L1geFgofWA5Rv3+f7jf+C3H8B7Jt
L3Ieeix0YAXE/P1zXT6KW/DxH1C8s5NvcajQgSqIezDEoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBrdqOh
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.432779226478679, -4.8767181800199015`, 
        0.0019323537229919703`}, {-4.432779226478679, -4.8767181800199015`, 
        0.001932353722991955}, {-4.288519484319119, -4.917812120013267, 
        0.0012882358153279677`}, {-4.28851948431912, -4.917812120013267, 
        0.0012882358153279779`}, {-4.432779226478679, -4.8767181800199015`, 
        0.0019323537229919703`}}], 
       Polygon3DBox[{{-4.28851948431912, -4.917812120013267, 
        0.0012882358153279779`}, {-4.288519484319119, -4.917812120013267, 
        0.0012882358153279677`}, {-4.1442597421595595`, -4.958906060006634, 
        0.0006441179076639804}, {-4.1442597421595595`, -4.958906060006634, 
        0.0006441179076639852}, {-4.28851948431912, -4.917812120013267, 
        0.0012882358153279779`}}], 
       Polygon3DBox[{{-4.1442597421595595`, -4.958906060006634, 
        0.0006441179076639852}, {-4.1442597421595595`, -4.958906060006634, 
        0.0006441179076639804}, {-4., -5., -7.072091290476426*^-18}, {-4., \
-5., -7.548834311584386*^-18}, {-4.1442597421595595`, -4.958906060006634, 
        0.0006441179076639852}}], 
       Polygon3DBox[{{-4., -5., -7.548834311584386*^-18}, {-4., -5., \
-7.548834311584386*^-18}, {-3.8557402578404405`, -5.041093939993366, \
-0.0006441179076639949}, {-3.8557402578404405`, -5.041093939993366, \
-0.000644117907664}, {-4., -5., -7.548834311584386*^-18}}], 
       Polygon3DBox[{{-3.8557402578404405`, -5.041093939993366, \
-0.000644117907664}, {-3.8557402578404405`, -5.041093939993366, \
-0.0006441179076639949}, {-3.7114805156808806`, -5.082187879986733, \
-0.0012882358153279824`}, {-3.7114805156808806`, -5.082187879986733, \
-0.0012882358153279928`}, {-3.8557402578404405`, -5.041093939993366, \
-0.000644117907664}}], 
       Polygon3DBox[{{-3.7114805156808806`, -5.082187879986733, \
-0.0012882358153279928`}, {-3.7114805156808806`, -5.082187879986733, \
-0.0012882358153279824`}, {-3.5672207735213206`, -5.1232818199800985`, \
-0.00193235372299197}, {-3.567220773521321, -5.1232818199800985`, \
-0.001932353722991985}, {-3.7114805156808806`, -5.082187879986733, \
-0.0012882358153279928`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUPNP+6yfRwRby99eKr
ywrVBQ8EBu79cG218IF1gRPXOEiH2s+9mHV5x2SBAytXxFW8vgoTd7VnAAOB
AxBa5IDAEeWnW6cJ2hyL0Yrsu8F3IDx8YbuIlsiB1RD1+7t3hmyS2ch7YP06
J37NEJEDayHm7w8Uq+de3clzgI3tyTTbOpEDjRD37A9AE4e6E8McqDv3H0Wz
F+rO/TjcuQfdX1B32luhhQPUnfbo4QZ1J4Y4LDwBfGOi6w==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.550836299070064, -5.293088352430879, 
      0.12521417370309038`}, {-4.314722153887294, -4.460348007608924, \
-0.12134946625710644`}, {-3.449163700929936, -4.706911647569121, \
-0.12521417370309038`}, {-3.685277846112706, -5.539651992391076, 
      0.12134946625710644`}, {-4.550836299070064, -5.293088352430879, 
      0.12521417370309038`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}, {-4.314722153887294, -4.460348007608924, \
-0.12134946625710644`}, {-3.449163700929936, -4.706911647569121, \
-0.12521417370309038`}, {-3.685277846112706, -5.539651992391076, 
       0.12134946625710644`}, {-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.096014437278273, -4.427554247956007, 
      0.10236499835837552`}, {-4.096014437278273, -4.427554247956007, 
      0.10236499835837552`}, {-4.064009624852182, -4.285036165304004, 
      0.06824333223891701}, {-4.064009624852182, -4.285036165304004, 
      0.06824333223891703}, {-4.096014437278273, -4.427554247956007, 
      0.10236499835837552`}}], 
     Polygon3DBox[{{-4.064009624852182, -4.285036165304004, 
      0.06824333223891703}, {-4.064009624852182, -4.285036165304004, 
      0.06824333223891701}, {-4.032004812426091, -4.1425180826520025`, 
      0.03412166611945853}, {-4.032004812426091, -4.1425180826520025`, 
      0.034121666119458514`}, {-4.064009624852182, -4.285036165304004, 
      0.06824333223891703}}], 
     Polygon3DBox[{{-4.032004812426091, -4.1425180826520025`, 
      0.034121666119458514`}, {-4.032004812426091, -4.1425180826520025`, 
      0.03412166611945853}, {-4., -4., 2.319270279903791*^-17}, {-4., -4., 
      0.}, {-4.032004812426091, -4.1425180826520025`, 
      0.034121666119458514`}}], 
     Polygon3DBox[{{-4., -4., 
      0.}, {-4., -4., -2.062403443892057*^-18}, {-3.967995187573909, \
-3.857481917347998, -0.0341216661194585}, {-3.967995187573909, \
-3.857481917347998, -0.0341216661194585}, {-4., -4., 0.}}], 
     Polygon3DBox[{{-3.967995187573909, -3.857481917347998, \
-0.0341216661194585}, {-3.967995187573909, -3.857481917347998, \
-0.0341216661194585}, {-3.9359903751478176`, -3.714963834695996, \
-0.068243332238917}, {-3.9359903751478176`, -3.714963834695996, \
-0.06824333223891701}, {-3.967995187573909, -3.857481917347998, \
-0.0341216661194585}}], 
     Polygon3DBox[{{-3.9359903751478176`, -3.714963834695996, \
-0.06824333223891701}, {-3.9359903751478176`, -3.714963834695996, \
-0.068243332238917}, {-3.9039855627217266`, -3.5724457520439934`, \
-0.10236499835837552`}, {-3.9039855627217266`, -3.572445752043994, \
-0.10236499835837551`}, {-3.9359903751478176`, -3.714963834695996, \
-0.06824333223891701}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA42vzA7MEngwJxPD45f2Cp4QNzPZMN0k1325lWm
e7sdBQ7sXejQ+kBZ8MDue0oKqRUb7WX2zrp3VEHgwP2ABU4fJgpAxRfaM4CB
wAEY/VDW6sFf2Vybk62nnEr28R9wjttfJX+H78BOiPr9E7mntr6o4T/Qtqfu
q90O3gO7IObvj5oYfyLGmv/ASSm7grgpPAfEIO6Bi5+AikPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AfqOk/Q==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.437878744053974, -3.8976350016416244`, 
        0.01684080214252781}, {-4.437878744053974, -3.8976350016416244`, 
        0.016840802142527797`}, {-4.29191916270265, -3.931756667761083, 
        0.011227201428351864`}, {-4.29191916270265, -3.931756667761083, 
        0.011227201428351874`}, {-4.437878744053974, -3.8976350016416244`, 
        0.01684080214252781}}], 
       Polygon3DBox[{{-4.29191916270265, -3.931756667761083, 
        0.011227201428351874`}, {-4.29191916270265, -3.931756667761083, 
        0.011227201428351864`}, {-4.145959581351325, -3.9658783338805415`, 
        0.005613600714175931}, {-4.145959581351325, -3.9658783338805415`, 
        0.0056136007141759335`}, {-4.29191916270265, -3.931756667761083, 
        0.011227201428351874`}}], 
       Polygon3DBox[{{-4.145959581351325, -3.9658783338805415`, 
        0.0056136007141759335`}, {-4.145959581351325, -3.9658783338805415`, 
        0.005613600714175931}, {-4., -4., -2.113149203261869*^-18}, {-4., \
-4., -6.2680483792154325`*^-18}, {-4.145959581351325, -3.9658783338805415`, 
        0.0056136007141759335`}}], 
       Polygon3DBox[{{-4., -4., -6.2680483792154325`*^-18}, {-4., -4., \
-6.2680483792154325`*^-18}, {-3.854040418648675, -4.034121666119458, \
-0.0056136007141759404`}, {-3.854040418648675, -4.034121666119458, \
-0.005613600714175945}, {-4., -4., -6.2680483792154325`*^-18}}], 
       Polygon3DBox[{{-3.854040418648675, -4.034121666119458, \
-0.005613600714175945}, {-3.854040418648675, -4.034121666119458, \
-0.0056136007141759404`}, {-3.7080808372973504`, -4.068243332238917, \
-0.011227201428351874`}, {-3.7080808372973504`, -4.068243332238917, \
-0.011227201428351884`}, {-3.854040418648675, -4.034121666119458, \
-0.005613600714175945}}], 
       Polygon3DBox[{{-3.7080808372973504`, -4.068243332238917, \
-0.011227201428351884`}, {-3.7080808372973504`, -4.068243332238917, \
-0.011227201428351874`}, {-3.5621212559460256`, -4.102364998358375, \
-0.01684080214252781}, {-3.5621212559460256`, -4.102364998358375, \
-0.01684080214252782}, {-3.7080808372973504`, -4.068243332238917, \
-0.011227201428351884`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj/+AgvJhye12E+1PdSTf
fqMleIDr5b9rNiX8Bxpvriv3/Ndmn3pkY27ZVIEDrSX12XK7YOJl9gxgIHAA
RjtsFbS01XS2MSufoyJ8le/AXleHUx+UBA7UQ9Tvz3ln4am2ivdAdXfDlIeu
AgcaIObvX5R6NdeynueAxcUDcZcyBA7IQ9yDIQ51J4Y5UHfuR7cX6s79ONy5
B91fUHdihAPUnfbo4QZ1J4Y4LDwB/I2ewA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.533893181332248, -4.3251892495976305`, 
      0.11920580050090333`}, {-4.341864306775701, -3.470080753685618, \
-0.08552419621584771}, {-3.466106818667752, -3.674810750402369, \
-0.11920580050090333`}, {-3.658135693224299, -4.529919246314382, 
      0.08552419621584771}, {-4.533893181332248, -4.3251892495976305`, 
      0.11920580050090333`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}, {-4.341864306775701, -3.470080753685618, \
-0.08552419621584771}, {-3.466106818667752, -3.674810750402369, \
-0.11920580050090333`}, {-3.658135693224299, -4.529919246314382, 
       0.08552419621584771}, {-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.072968589955883, -3.436939417382768, 
      0.07911719419353518}, {-4.072968589955882, -3.436939417382768, 
      0.07911719419353516}, {-4.048645726637255, -3.291292944921845, 
      0.05274479612902344}, {-4.048645726637255, -3.2912929449218455`, 
      0.05274479612902346}, {-4.072968589955883, -3.436939417382768, 
      0.07911719419353518}}], 
     Polygon3DBox[{{-4.048645726637255, -3.2912929449218455`, 
      0.05274479612902346}, {-4.048645726637255, -3.291292944921845, 
      0.05274479612902344}, {-4.024322863318627, -3.1456464724609225`, 
      0.026372398064511738`}, {-4.024322863318628, -3.1456464724609225`, 
      0.02637239806451173}, {-4.048645726637255, -3.2912929449218455`, 
      0.05274479612902346}}], 
     Polygon3DBox[{{-4.024322863318628, -3.1456464724609225`, 
      0.02637239806451173}, {-4.024322863318627, -3.1456464724609225`, 
      0.026372398064511738`}, {-4., -3., 1.593509529640489*^-17}, {-4., -3., 
      0.}, {-4.024322863318628, -3.1456464724609225`, 0.02637239806451173}}], 
     Polygon3DBox[{{-4., -3., 
      0.}, {-4., -3., -3.584400400795662*^-18}, {-3.9756771366813726`, \
-2.8543535275390775`, -0.026372398064511724`}, {-3.9756771366813726`, \
-2.8543535275390775`, -0.02637239806451172}, {-4., -3., 0.}}], 
     Polygon3DBox[{{-3.9756771366813726`, -2.8543535275390775`, \
-0.02637239806451172}, {-3.9756771366813726`, -2.8543535275390775`, \
-0.026372398064511724`}, {-3.951354273362745, -2.708707055078155, \
-0.05274479612902344}, {-3.951354273362745, -2.708707055078155, \
-0.05274479612902345}, {-3.9756771366813726`, -2.8543535275390775`, \
-0.02637239806451172}}], 
     Polygon3DBox[{{-3.951354273362745, -2.708707055078155, \
-0.05274479612902345}, {-3.951354273362745, -2.708707055078155, \
-0.05274479612902344}, {-3.9270314100441177`, -2.563060582617232, \
-0.07911719419353518}, {-3.9270314100441177`, -2.563060582617232, \
-0.07911719419353516}, {-3.951354273362745, -2.708707055078155, \
-0.05274479612902345}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF72W9d9h5fAAaMP98Vv1XEfOHx2jiOb4xZ7yb/F
+hcMBQ6Uf7VPnRjCdSBa6OKaWMbV9r3/doq/kBA4sPvX/E0eWpxQ8dn2DGAg
cABCcxxY8CQiVbkxzeY5U88F/XP8B1xZE3y3X2U7EAFRv/8cq8TC+Dn8B7q4
DszKW816IBJi/v6tHEsK+7P4D5zjV3ih2shy4BDEPRjiUHfCzemEmgN15350
e6Hu3I/DnXvQ/QV1JzwcyqDhAHWnPXq4Qd2JIQ4LTwBENJ2Z
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.442022402120948, -2.920882805806465, 
        0.029268850441541684`}, {-4.442022402120948, -2.920882805806465, 
        0.029268850441541674`}, {-4.2946816014139655`, -2.9472552038709767`, 
        0.01951256696102778}, {-4.2946816014139655`, -2.9472552038709767`, 
        0.01951256696102779}, {-4.442022402120948, -2.920882805806465, 
        0.029268850441541684`}}], 
       Polygon3DBox[{{-4.2946816014139655`, -2.9472552038709767`, 
        0.01951256696102779}, {-4.2946816014139655`, -2.9472552038709767`, 
        0.01951256696102778}, {-4.147340800706983, -2.973627601935488, 
        0.009756283480513892}, {-4.147340800706982, -2.973627601935488, 
        0.009756283480513892}, {-4.2946816014139655`, -2.9472552038709767`, 
        0.01951256696102779}}], 
       Polygon3DBox[{{-4.147340800706982, -2.973627601935488, 
        0.009756283480513892}, {-4.147340800706983, -2.973627601935488, 
        0.009756283480513892}, {-4., -3., 
        2.3765694385594347`*^-18}, {-4., -3., -4.8445309313316205`*^-18}, \
{-4.147340800706982, -2.973627601935488, 0.009756283480513892}}], 
       Polygon3DBox[{{-4., -3., -4.8445309313316205`*^-18}, {-4., -3., \
-4.8445309313316205`*^-18}, {-3.8526591992930173`, -3.026372398064512, \
-0.009756283480513895}, {-3.8526591992930173`, -3.026372398064512, \
-0.009756283480513899}, {-4., -3., -4.8445309313316205`*^-18}}], 
       Polygon3DBox[{{-3.8526591992930173`, -3.026372398064512, \
-0.009756283480513899}, {-3.8526591992930173`, -3.026372398064512, \
-0.009756283480513895}, {-3.7053183985860345`, -3.0527447961290233`, \
-0.019512566961027784`}, {-3.7053183985860345`, -3.0527447961290233`, \
-0.019512566961027794`}, {-3.8526591992930173`, -3.026372398064512, \
-0.009756283480513899}}], 
       Polygon3DBox[{{-3.7053183985860345`, -3.0527447961290233`, \
-0.019512566961027794`}, {-3.7053183985860345`, -3.0527447961290233`, \
-0.019512566961027784`}, {-3.557977597879052, -3.079117194193535, \
-0.02926885044154168}, {-3.557977597879052, -3.079117194193535, \
-0.029268850441541688`}, {-3.7053183985860345`, -3.0527447961290233`, \
-0.019512566961027794`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9Hst+oKrogO/yH3PtrS2b
mQ/qCh7Yvtun89dk9gPLF141lvo92X7unIOND6YJHLgdu8zl70mYeLM9AxgI
HIDQHAcSNt65OnVZgM3RYzV/7C7xHVBdFLmbyYzjwFKI+v1dvT9/1C7hPeDp
srmMNYfjwDKI+fsDQsq+7injOZD3jMeIYxHHgQqIe/b7o4lD3YlhDtSd+9Ht
hbpzPw537kH3F9SdGOEAdac9erhB3YkhDgtPAFgJs7M=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.5149909920768305`, -3.357822223189233, 
      0.10838604463507687`}, {-4.369053812165066, -2.4839433884236968`, \
-0.04984834375199349}, {-3.4850090079231695`, -2.642177776810767, \
-0.10838604463507687`}, {-3.630946187834934, -3.5160566115763032`, 
      0.04984834375199349}, {-4.5149909920768305`, -3.357822223189233, 
      0.10838604463507687`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}, {-4.369053812165066, -2.4839433884236968`, \
-0.04984834375199349}, {-3.4850090079231695`, -2.642177776810767, \
-0.10838604463507687`}, {-3.630946187834934, -3.5160566115763032`, 
       0.04984834375199349}, {-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.04911807263465, -2.444049074423594, 
      0.053924339997878296`}, {-4.04911807263465, -2.444049074423594, 
      0.05392433999787829}, {-4.032745381756433, -2.296032716282396, 
      0.03594955999858552}, {-4.032745381756434, -2.296032716282396, 
      0.03594955999858553}, {-4.04911807263465, -2.444049074423594, 
      0.053924339997878296`}}], 
     Polygon3DBox[{{-4.032745381756434, -2.296032716282396, 
      0.03594955999858553}, {-4.032745381756433, -2.296032716282396, 
      0.03594955999858552}, {-4.0163726908782165`, -2.148016358141198, 
      0.017974779999292766`}, {-4.0163726908782165`, -2.148016358141198, 
      0.017974779999292766`}, {-4.032745381756434, -2.296032716282396, 
      0.03594955999858553}}], 
     Polygon3DBox[{{-4.0163726908782165`, -2.148016358141198, 
      0.017974779999292766`}, {-4.0163726908782165`, -2.148016358141198, 
      0.017974779999292766`}, {-4., -2., 8.572506060030125*^-18}, {-4., -2., 
      0.}, {-4.0163726908782165`, -2.148016358141198, 
      0.017974779999292766`}}], 
     Polygon3DBox[{{-4., -2., 
      0.}, {-4., -2., -4.731503685160928*^-18}, {-3.983627309121783, \
-1.851983641858802, -0.017974779999292763`}, {-3.983627309121783, \
-1.851983641858802, -0.01797477999929276}, {-4., -2., 0.}}], 
     Polygon3DBox[{{-3.983627309121783, -1.851983641858802, \
-0.01797477999929276}, {-3.983627309121783, -1.851983641858802, \
-0.017974779999292763`}, {-3.9672546182435666`, -1.703967283717604, \
-0.03594955999858552}, {-3.9672546182435666`, -1.703967283717604, \
-0.035949559998585526`}, {-3.983627309121783, -1.851983641858802, \
-0.01797477999929276}}], 
     Polygon3DBox[{{-3.9672546182435666`, -1.703967283717604, \
-0.035949559998585526`}, {-3.9672546182435666`, -1.703967283717604, \
-0.03594955999858552}, {-3.9508819273653497`, -1.5559509255764061`, \
-0.05392433999787829}, {-3.9508819273653497`, -1.5559509255764061`, \
-0.05392433999787828}, {-3.9672546182435666`, -1.703967283717604, \
-0.035949559998585526`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP6Vx8fkYyRwwGf/45mZvcwHpiyon/lj9mr75V/i
GDsUBQ7cvTI9zS2O6UDygf8Cv9MX2QdXrWc4IiBwIP+Vt7GyPiNUfJI9AxgI
HIDQDAf8X4fI+K6Ns4nkXviv/B7/AWXtjJk7F/7dnwhRv3+zmNPf93v4D7iF
XTAqdv69Pwli/n4epce/02fzH8hstDij8/TH/kkQ92CIQ92JYQ7UnfvR7YW6
cz8Od+6B+SsP6i+oOzHCAepOe1i4eUPDDepOe1zhCQC0oq21
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.445083645356384, -1.9460756600021216`, 
        0.038635659591444535`}, {-4.445083645356384, -1.9460756600021216`, 
        0.03863565959144453}, {-4.2967224302375895`, -1.9640504400014145`, 
        0.025757106394296347`}, {-4.2967224302375895`, -1.9640504400014145`, 
        0.025757106394296358`}, {-4.445083645356384, -1.9460756600021216`, 
        0.038635659591444535`}}], 
       Polygon3DBox[{{-4.2967224302375895`, -1.9640504400014145`, 
        0.025757106394296358`}, {-4.2967224302375895`, -1.9640504400014145`, 
        0.025757106394296347`}, {-4.148361215118794, -1.9820252200007071`, 
        0.012878553197148179`}, {-4.148361215118794, -1.9820252200007071`, 
        0.012878553197148177`}, {-4.2967224302375895`, -1.9640504400014145`, 
        0.025757106394296358`}}], 
       Polygon3DBox[{{-4.148361215118794, -1.9820252200007071`, 
        0.012878553197148177`}, {-4.148361215118794, -1.9820252200007071`, 
        0.012878553197148179`}, {-4., -2., 
        6.2301306701624574`*^-18}, {-4., -2., -3.301913518726762*^-18}, \
{-4.148361215118794, -1.9820252200007071`, 0.012878553197148177`}}], 
       Polygon3DBox[{{-4., -2., -3.301913518726762*^-18}, {-4., -2., \
-3.301913518726762*^-18}, {-3.8516387848812053`, -2.017974779999293, \
-0.012878553197148177`}, {-3.8516387848812053`, -2.017974779999293, \
-0.01287855319714818}, {-4., -2., -3.301913518726762*^-18}}], 
       Polygon3DBox[{{-3.8516387848812053`, -2.017974779999293, \
-0.01287855319714818}, {-3.8516387848812053`, -2.017974779999293, \
-0.012878553197148177`}, {-3.703277569762411, -2.0359495599985857`, \
-0.02575710639429635}, {-3.703277569762411, -2.0359495599985853`, \
-0.02575710639429636}, {-3.8516387848812053`, -2.017974779999293, \
-0.01287855319714818}}], 
       Polygon3DBox[{{-3.703277569762411, -2.0359495599985853`, \
-0.02575710639429636}, {-3.703277569762411, -2.0359495599985857`, \
-0.02575710639429635}, {-3.554916354643616, -2.053924339997878, \
-0.03863565959144453}, {-3.554916354643616, -2.053924339997878, \
-0.038635659591444535`}, {-3.703277569762411, -2.0359495599985853`, \
-0.02575710639429636}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/3x+men8N7YrH97gJz
xhv6ggf+MlaoH8j5v//yxEw1oYRZ9rE7ZjO8mS5w4B/DHuGEbTDxLnsGMBA4
AKEZDtzyW3tq569QG9f+E//UL/AdaPyv+O28CsOBixD1+7vlJv71X8B7gOm/
85v5ngwHLkHM339hbeSf8gKeA03/Uh/l5zEciIW4B0Mc6s79XWjmQN25H91e
qDv343DnHnR/Qd2JEQ5Qd9qjhxvUnRjisPAEAIcMpkw=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.494201717991034, -2.3901247344257155`, 
      0.09255999958932283}, {-4.3959655727217335`, -1.5020265855785278`, \
-0.01528868040643376}, {-3.505798282008966, -1.6098752655742845`, \
-0.09255999958932283}, {-3.6040344272782665`, -2.4979734144214722`, 
      0.01528868040643376}, {-4.494201717991034, -2.3901247344257155`, 
      0.09255999958932283}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}, {-4.3959655727217335`, -1.5020265855785278`, \
-0.01528868040643376}, {-3.505798282008966, -1.6098752655742845`, \
-0.09255999958932283}, {-3.6040344272782665`, -2.4979734144214722`, 
       0.01528868040643376}, {-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.0247041546611975`, -1.4484894578920566`, 
      0.027329670729169756`}, {-4.0247041546611975`, -1.4484894578920566`, 
      0.027329670729169746`}, {-4.016469436440798, -1.2989929719280378`, 
      0.018219780486113158`}, {-4.016469436440798, -1.2989929719280378`, 
      0.018219780486113172`}, {-4.0247041546611975`, -1.4484894578920566`, 
      0.027329670729169756`}}], 
     Polygon3DBox[{{-4.016469436440798, -1.2989929719280378`, 
      0.018219780486113172`}, {-4.016469436440798, -1.2989929719280378`, 
      0.018219780486113158`}, {-4.0082347182203995`, -1.1494964859640189`, 
      0.009109890243056583}, {-4.0082347182203995`, -1.1494964859640189`, 
      0.009109890243056586}, {-4.016469436440798, -1.2989929719280378`, 
      0.018219780486113172`}}], 
     Polygon3DBox[{{-4.0082347182203995`, -1.1494964859640189`, 
      0.009109890243056586}, {-4.0082347182203995`, -1.1494964859640189`, 
      0.009109890243056583}, {-4., -1.0000000000000002`, 
      1.2972246231756698`*^-18}, {-4., -1., 
      0.}, {-4.0082347182203995`, -1.1494964859640189`, 
      0.009109890243056586}}], 
     Polygon3DBox[{{-4., -1., 
      0.}, {-4., -1., -5.445448643257318*^-18}, {-3.9917652817796005`, \
-0.8505035140359812, -0.009109890243056586}, {-3.991765281779601, \
-0.8505035140359812, -0.009109890243056583}, {-4., -1., 0.}}], 
     Polygon3DBox[{{-3.991765281779601, -0.8505035140359812, \
-0.009109890243056583}, {-3.9917652817796005`, -0.8505035140359812, \
-0.009109890243056586}, {-3.9835305635592015`, -0.7010070280719625, \
-0.01821978048611317}, {-3.9835305635592015`, -0.7010070280719624, \
-0.01821978048611317}, {-3.991765281779601, -0.8505035140359812, \
-0.009109890243056583}}], 
     Polygon3DBox[{{-3.9835305635592015`, -0.7010070280719624, \
-0.01821978048611317}, {-3.9835305635592015`, -0.7010070280719625, \
-0.01821978048611317}, {-3.9752958453388025`, -0.5515105421079436, \
-0.027329670729169753`}, {-3.9752958453388025`, -0.5515105421079436, \
-0.02732967072916975}, {-3.9835305635592015`, -0.7010070280719624, \
-0.01821978048611317}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5JPMjtIylwIOyLsgez7vf9F7l/qPv/mW3vO007
9q6AwIEniw7dWnPiy/6H7AFHTVZMslc/PXVdHofAgaLAxNywlE9Q8SZ7BjAQ
OAChP+wvS2r9HC7hb7M588oipff8B2RjbVWDzV/vvw9Rvz/18gpX13v8Byx3
VXkty3u2/wHE/P0StrUv0s/yHwgT35H/c+nD/ech7oGLh0LFoe6Em2MBNQfq
zv0we2Wg9kLduR+HO/eg+wvqToxwgLrTHhZuodBwg7rTHld4AgAMeqjF
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.446962986985003, -0.9726703292708302, 
        0.044465462589284126`}, {-4.446962986985003, -0.9726703292708302, 
        0.044465462589284126`}, {-4.297975324656669, -0.9817802195138868, 
        0.02964364172618941}, {-4.297975324656669, -0.9817802195138868, 
        0.02964364172618942}, {-4.446962986985003, -0.9726703292708302, 
        0.044465462589284126`}}], 
       Polygon3DBox[{{-4.297975324656669, -0.9817802195138868, 
        0.02964364172618942}, {-4.297975324656669, -0.9817802195138868, 
        0.02964364172618941}, {-4.148987662328334, -0.9908901097569434, 
        0.014821820863094713`}, {-4.148987662328334, -0.9908901097569434, 
        0.014821820863094708`}, {-4.297975324656669, -0.9817802195138868, 
        0.02964364172618942}}], 
       Polygon3DBox[{{-4.148987662328334, -0.9908901097569434, 
        0.014821820863094708`}, {-4.148987662328334, -0.9908901097569434, 
        0.014821820863094713`}, {-4., -1., 
        9.296891503706727*^-18}, {-4., -1., -1.6734596890114426`*^-18}, \
{-4.148987662328334, -0.9908901097569434, 0.014821820863094708`}}], 
       Polygon3DBox[{{-4., -1., -1.6734596890114426`*^-18}, {-4., -1., \
-1.6734596890114426`*^-18}, {-3.8510123376716656`, -1.0091098902430566`, \
-0.014821820863094706`}, {-3.8510123376716656`, -1.0091098902430566`, \
-0.014821820863094706`}, {-4., -1., -1.6734596890114426`*^-18}}], 
       Polygon3DBox[{{-3.8510123376716656`, -1.0091098902430566`, \
-0.014821820863094706`}, {-3.8510123376716656`, -1.0091098902430566`, \
-0.014821820863094706`}, {-3.7020246753433312`, -1.018219780486113, \
-0.02964364172618941}, {-3.7020246753433312`, -1.018219780486113, \
-0.029643641726189416`}, {-3.8510123376716656`, -1.0091098902430566`, \
-0.014821820863094706`}}], 
       Polygon3DBox[{{-3.7020246753433312`, -1.018219780486113, \
-0.029643641726189416`}, {-3.7020246753433312`, -1.018219780486113, \
-0.02964364172618941}, {-3.553037013014997, -1.0273296707291697`, \
-0.04446546258928412}, {-3.553037013014997, -1.0273296707291697`, \
-0.04446546258928411}, {-3.7020246753433312`, -1.018219780486113, \
-0.029643641726189416`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7vn77NLlz3yDL7iJWd
hQqGggcO1l+N3Jf1fv8pj39yz6Pm2a+5csRiwgyBAw/2v9KJ3woT77NnAAOB
AxD6w/6g55dnHvCOtFkRVtZ3/xzfAYEFXZkBqh/2H4eo3x+w9o3M/rm8BxQc
RC8v8Pqw/wTE/P0/mJNXz8vhOaD/YL7Nx/wP+6dC3IMhDnUnhjlQd+5Htxfq
zv043LkH5q+HUH9B3YkRDlB32sPCbRE03KDutMcVngBF/rXf
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.471667141646201, -1.4211597871628867`, 
      0.07179513331845389}, {-4.422258832323806, -0.5241808713787737, 
      0.01713579186011437}, {-3.5283328583537994`, -0.5788402128371133, \
-0.07179513331845389}, {-3.5777411676761943`, -1.4758191286212263`, \
-0.01713579186011437}, {-4.471667141646201, -1.4211597871628867`, 
      0.07179513331845389}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}, {-4.422258832323806, -0.5241808713787737, 
       0.01713579186011437}, {-3.5283328583537994`, -0.5788402128371133, \
-0.07179513331845389}, {-3.5777411676761943`, -1.4758191286212263`, \
-0.01713579186011437}, {-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4., -0.45, 
      0.}, {-4., -0.45, -1.1375786854206067`*^-17}, {-4., -0.3, \
-9.479822378505054*^-18}, {-4., -0.30000000000000004`, 0.}, {-4., -0.45, 
      0.}}], Polygon3DBox[{{-4., -0.30000000000000004`, 
      0.}, {-4., -0.3, -9.479822378505054*^-18}, {-4., -0.15000000000000008`, \
-7.583857902804046*^-18}, {-4., -0.15000000000000002`, 
      0.}, {-4., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{-4., -0.15000000000000002`, 
      0.}, {-4., -0.15000000000000008`, -7.583857902804046*^-18}, {-4., \
-1.1102230246251565`*^-16, -5.687893427103035*^-18}, {-4., 0., 
      0.}, {-4., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{-4., 0., 0.}, {-4., 0., -5.6878934271030336`*^-18}, {-4., 
      0.14999999999999997`, -3.791928951402023*^-18}, {-4., 
      0.14999999999999997`, 0.}, {-4., 0., 0.}}], 
     Polygon3DBox[{{-4., 0.14999999999999997`, 0.}, {-4., 
      0.14999999999999997`, -3.791928951402023*^-18}, {-4., 
      0.29999999999999993`, -1.8959644757010116`*^-18}, {-4., 0.3, 0.}, {-4., 
      0.14999999999999997`, 0.}}], 
     Polygon3DBox[{{-4., 0.3, 0.}, {-4., 
      0.29999999999999993`, -1.895964475701012*^-18}, {-4., 
      0.44999999999999996`, -9.472245366575815*^-34}, {-4., 
      0.4499999999999999, 0.}, {-4., 0.3, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOHD2DAjc2c+AAgQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQC/ZULY
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.4475967445892515`, 0., 
        0.04644517448674317}, {-4.4475967445892515`, 5.5109105961630896`*^-17,
         0.04644517448674317}, {-4.298397829726168, 4.592425496802574*^-17, 
        0.030963449657828778`}, {-4.298397829726168, 9.184850993605149*^-18, 
        0.030963449657828785`}, {-4.4475967445892515`, 0., 
        0.04644517448674317}}], 
       Polygon3DBox[{{-4.298397829726168, 9.184850993605149*^-18, 
        0.030963449657828785`}, {-4.298397829726168, 4.592425496802574*^-17, 
        0.030963449657828778`}, {-4.149198914863084, 3.67394039744206*^-17, 
        0.015481724828914398`}, {-4.149198914863084, 1.8369701987210297`*^-17,
         0.015481724828914393`}, {-4.298397829726168, 9.184850993605149*^-18, 
        0.030963449657828785`}}], 
       Polygon3DBox[{{-4.149198914863084, 1.8369701987210297`*^-17, 
        0.015481724828914393`}, {-4.149198914863084, 3.67394039744206*^-17, 
        0.015481724828914398`}, {-4., 2.7554552980815454`*^-17, 
        1.1458778243981145`*^-17}, {-4., 2.7554552980815448`*^-17, 
        0.}, {-4.149198914863084, 1.8369701987210297`*^-17, 
        0.015481724828914393`}}], 
       Polygon3DBox[{{-4., 2.7554552980815448`*^-17, 0.}, {-4., 
        2.7554552980815448`*^-17, 0.}, {-3.850801085136916, 
        1.83697019872103*^-17, -0.015481724828914386`}, {-3.850801085136916, 
        3.6739403974420595`*^-17, -0.015481724828914386`}, {-4., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{-3.850801085136916, 
        3.6739403974420595`*^-17, -0.015481724828914386`}, \
{-3.850801085136916, 
        1.83697019872103*^-17, -0.015481724828914386`}, {-3.701602170273832, 
        9.184850993605152*^-18, -0.03096344965782877}, {-3.701602170273832, 
        4.592425496802574*^-17, -0.030963449657828778`}, {-3.850801085136916, 
        3.6739403974420595`*^-17, -0.015481724828914386`}}], 
       Polygon3DBox[{{-3.701602170273832, 
        4.592425496802574*^-17, -0.030963449657828778`}, {-3.701602170273832, 
        9.184850993605153*^-18, -0.03096344965782877}, {-3.552403255410748, 
        4.5887548728832574`*^-33, -0.046445174486743165`}, \
{-3.552403255410748, 
        5.510910596163089*^-17, -0.04644517448674316}, {-3.701602170273832, 
        4.592425496802574*^-17, -0.030963449657828778`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHax4j8bdkrwAAMUHG/5UrTy+HJ7vZp4435DhPjW
6NnvHm6Zby++b/3M4zME0MT77SE8hPgBRZ05gjlRNpeaF5wpOMcHF98IUb9/
KbvjzIdzeOHimyHm7y/vfpgalM0DFz8KcQ+GONSdGOZA3bkf3V6oO/fjcOce
dH9B3YkRDlB32qOHG9SdGOKw8AQAllp+eA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.4475967445892515`, -0.45, 
      0.04644517448674317}, {-4.4475967445892515`, 0.45, 
      0.04644517448674317}, {-3.552403255410748, 
      0.45, -0.04644517448674317}, {-3.552403255410748, -0.45, \
-0.04644517448674317}, {-4.4475967445892515`, -0.45, 0.04644517448674317}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.4475967445892515`, -0.45, 
       0.04644517448674317}, {-4.4475967445892515`, 0.45, 0.04644517448674317}
       , {-3.552403255410748, 
       0.45, -0.04644517448674317}, {-3.552403255410748, -0.45, \
-0.04644517448674317}, {-4.4475967445892515`, -0.45, 
       0.04644517448674317}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.9752958453388025`, 
      0.5515105421079435, -0.027329670729169756`}, {-3.975295845338802, 
      0.5515105421079435, -0.027329670729169767`}, {-3.9835305635592015`, 
      0.7010070280719624, -0.01821978048611318}, {-3.9835305635592015`, 
      0.7010070280719622, -0.018219780486113172`}, {-3.9752958453388025`, 
      0.5515105421079435, -0.027329670729169756`}}], 
     Polygon3DBox[{{-3.9835305635592015`, 
      0.7010070280719622, -0.018219780486113172`}, {-3.9835305635592015`, 
      0.7010070280719624, -0.01821978048611318}, {-3.9917652817796005`, 
      0.8505035140359811, -0.009109890243056596}, {-3.991765281779601, 
      0.8505035140359811, -0.009109890243056586}, {-3.9835305635592015`, 
      0.7010070280719622, -0.018219780486113172`}}], 
     Polygon3DBox[{{-3.991765281779601, 
      0.8505035140359811, -0.009109890243056586}, {-3.9917652817796005`, 
      0.8505035140359811, -0.009109890243056596}, {-4., 
      0.9999999999999999, -1.2188121909690309`*^-17}, {-4., 1., 
      0.}, {-3.991765281779601, 0.8505035140359811, -0.009109890243056586}}], 
     Polygon3DBox[{{-4., 1., 0.}, {-4., 
      1., -5.445448643257318*^-18}, {-4.0082347182203995`, 
      1.1494964859640189`, 0.009109890243056579}, {-4.0082347182203995`, 
      1.1494964859640189`, 0.009109890243056583}, {-4., 1., 0.}}], 
     Polygon3DBox[{{-4.0082347182203995`, 1.1494964859640189`, 
      0.009109890243056583}, {-4.0082347182203995`, 1.1494964859640189`, 
      0.009109890243056579}, {-4.016469436440798, 1.2989929719280375`, 
      0.01821978048611316}, {-4.016469436440798, 1.2989929719280378`, 
      0.01821978048611317}, {-4.0082347182203995`, 1.1494964859640189`, 
      0.009109890243056583}}], 
     Polygon3DBox[{{-4.016469436440798, 1.2989929719280378`, 
      0.01821978048611317}, {-4.016469436440798, 1.2989929719280375`, 
      0.01821978048611316}, {-4.0247041546611975`, 1.4484894578920564`, 
      0.027329670729169753`}, {-4.0247041546611975`, 1.4484894578920564`, 
      0.02732967072916975}, {-4.016469436440798, 1.2989929719280378`, 
      0.01821978048611317}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJawrX2Rfpb/QKj4jvyfSx/aX+T+oe7/Z/b+1Msr
XF3v8R+w2FXltSzvmf1D9oCjJism7d+ceWWR0nv+AzKxtqrB5q+h4k37GcBA
4ACE/mBfltT6OVzCf4/66anr8jgEDhQFJuaGpXyyvw9Rb+87TTv2roDAgSeL
Dt1ac+KL/QOI+fYliQe5fSQFDoR+UfZg1v1ufx7iHrh4GFQc6k4Mc6DutEe3
F+pOexzutIH5SxbqL6g74eFgCQ0HqDv3w8ItDBpuUHfuxxWeAEtUo+I=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.446962986985003, 0.9726703292708302, 
        0.044465462589284126`}, {-4.446962986985003, 0.9726703292708303, 
        0.044465462589284126`}, {-4.297975324656669, 0.9817802195138868, 
        0.029643641726189416`}, {-4.297975324656669, 0.9817802195138868, 
        0.02964364172618942}, {-4.446962986985003, 0.9726703292708302, 
        0.044465462589284126`}}], 
       Polygon3DBox[{{-4.297975324656669, 0.9817802195138868, 
        0.02964364172618942}, {-4.297975324656669, 0.9817802195138868, 
        0.029643641726189416`}, {-4.148987662328334, 0.9908901097569435, 
        0.014821820863094717`}, {-4.148987662328334, 0.9908901097569435, 
        0.014821820863094711`}, {-4.297975324656669, 0.9817802195138868, 
        0.02964364172618942}}], 
       Polygon3DBox[{{-4.148987662328334, 0.9908901097569435, 
        0.014821820863094711`}, {-4.148987662328334, 0.9908901097569435, 
        0.014821820863094717`}, {-4., 1., 1.2643810881729613`*^-17}, {-4., 1.,
         1.6734596890114426`*^-18}, {-4.148987662328334, 0.9908901097569435, 
        0.014821820863094711`}}], 
       Polygon3DBox[{{-4., 1., 1.6734596890114426`*^-18}, {-4., 1., 
        1.6734596890114426`*^-18}, {-3.8510123376716656`, 
        1.0091098902430566`, -0.014821820863094703`}, {-3.8510123376716656`, 
        1.0091098902430566`, -0.014821820863094703`}, {-4., 1., 
        1.6734596890114426`*^-18}}], 
       Polygon3DBox[{{-3.8510123376716656`, 
        1.0091098902430566`, -0.014821820863094703`}, {-3.8510123376716656`, 
        1.0091098902430566`, -0.014821820863094703`}, {-3.7020246753433312`, 
        1.0182197804861133`, -0.02964364172618941}, {-3.7020246753433312`, 
        1.0182197804861133`, -0.02964364172618941}, {-3.8510123376716656`, 
        1.0091098902430566`, -0.014821820863094703`}}], 
       Polygon3DBox[{{-3.7020246753433312`, 
        1.0182197804861133`, -0.02964364172618941}, {-3.7020246753433312`, 
        1.0182197804861133`, -0.02964364172618941}, {-3.553037013014997, 
        1.0273296707291697`, -0.04446546258928412}, {-3.553037013014997, 
        1.0273296707291697`, -0.04446546258928411}, {-3.7020246753433312`, 
        1.0182197804861133`, -0.02964364172618941}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7bT99mF657ZJl9xMrO
QgVDwQMH669G7st6b3/K45/c86h59muuHLGYMEPgwIP9r3Tit8LE++wZwEDg
AIT+YB/0/PLMA96RNivCyvrun+M7ILCgKzNA9YP9cYj6/QFr38jsn8t7QMFB
9PICrw/2JyDm7//BnLx6Xg7PAf0H820+5n+wnwpxD4Y41J0Y5kDduR/dXqg7
9+Nw5x6Yvx5C/QV1J0Y4QN1pDwu3RdBwg7rTHld4AgAWM65f
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.422258832323806, 0.5241808713787737, 
      0.01713579186011437}, {-4.471667141646201, 1.4211597871628867`, 
      0.07179513331845389}, {-3.5777411676761943`, 
      1.4758191286212263`, -0.01713579186011437}, {-3.5283328583537994`, 
      0.5788402128371133, -0.07179513331845389}, {-4.422258832323806, 
      0.5241808713787737, 0.01713579186011437}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.422258832323806, 0.5241808713787737, 
       0.01713579186011437}, {-4.471667141646201, 1.4211597871628867`, 
       0.07179513331845389}, {-3.5777411676761943`, 
       1.4758191286212263`, -0.01713579186011437}, {-3.5283328583537994`, 
       0.5788402128371133, -0.07179513331845389}, {-4.422258832323806, 
       0.5241808713787737, 0.01713579186011437}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.9508819273653497`, 
      1.5559509255764061`, -0.053924339997878296`}, {-3.9508819273653497`, 
      1.5559509255764061`, -0.0539243399978783}, {-3.9672546182435666`, 
      1.703967283717604, -0.03594955999858553}, {-3.9672546182435666`, 
      1.703967283717604, -0.03594955999858553}, {-3.9508819273653497`, 
      1.5559509255764061`, -0.053924339997878296`}}], 
     Polygon3DBox[{{-3.9672546182435666`, 
      1.703967283717604, -0.03594955999858553}, {-3.9672546182435666`, 
      1.703967283717604, -0.03594955999858553}, {-3.983627309121783, 
      1.851983641858802, -0.01797477999929278}, {-3.983627309121783, 
      1.851983641858802, -0.017974779999292766`}, {-3.9672546182435666`, 
      1.703967283717604, -0.03594955999858553}}], 
     Polygon3DBox[{{-3.983627309121783, 
      1.851983641858802, -0.017974779999292766`}, {-3.983627309121783, 
      1.851983641858802, -0.01797477999929278}, {-4., 
      2., -1.8035513430351983`*^-17}, {-4., 2., 0.}, {-3.983627309121783, 
      1.851983641858802, -0.017974779999292766`}}], 
     Polygon3DBox[{{-4., 2., 0.}, {-4., 
      2., -4.731503685160928*^-18}, {-4.0163726908782165`, 
      2.1480163581411977`, 0.017974779999292756`}, {-4.0163726908782165`, 
      2.1480163581411977`, 0.01797477999929276}, {-4., 2., 0.}}], 
     Polygon3DBox[{{-4.0163726908782165`, 2.1480163581411977`, 
      0.01797477999929276}, {-4.0163726908782165`, 2.1480163581411977`, 
      0.017974779999292756`}, {-4.032745381756433, 2.296032716282396, 
      0.03594955999858552}, {-4.032745381756434, 2.296032716282396, 
      0.035949559998585526`}, {-4.0163726908782165`, 2.1480163581411977`, 
      0.01797477999929276}}], 
     Polygon3DBox[{{-4.032745381756434, 2.296032716282396, 
      0.035949559998585526`}, {-4.032745381756433, 2.296032716282396, 
      0.03594955999858552}, {-4.04911807263465, 2.444049074423594, 
      0.05392433999787829}, {-4.04911807263465, 2.4440490744235936`, 
      0.05392433999787828}, {-4.032745381756434, 2.296032716282396, 
      0.035949559998585526`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZRevw7fTb/gcxGizM6T3/YT1lQP/PH7NX7N4s5
/X2/h/+AW9gFo2Ln3/bJB/4L/E5ftD+Se+G/8nv8B5S1M2buXPgXKj5pPwMY
CByA0AwO/q9DZHzXxu0JrlrPcERA4EDeK29jZX1Gh0SIevvlX+IYOxQFDty9
Mj3NLY7JIQlivv2vPD4mHyOBA977H8/M7GV2mARxD1zcByoOdSeGOVB32sPs
zYfaC3WnPQ532qD7C+pOjHCAunM/erhB3YkhDgtPAO1TqEI=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.445083645356384, 1.9460756600021216`, 
        0.038635659591444535`}, {-4.445083645356384, 1.9460756600021218`, 
        0.03863565959144454}, {-4.2967224302375895`, 1.9640504400014145`, 
        0.02575710639429636}, {-4.2967224302375895`, 1.9640504400014145`, 
        0.025757106394296358`}, {-4.445083645356384, 1.9460756600021216`, 
        0.038635659591444535`}}], 
       Polygon3DBox[{{-4.2967224302375895`, 1.9640504400014145`, 
        0.025757106394296358`}, {-4.2967224302375895`, 1.9640504400014145`, 
        0.02575710639429636}, {-4.148361215118794, 1.9820252200007074`, 
        0.01287855319714819}, {-4.148361215118794, 1.9820252200007074`, 
        0.01287855319714818}, {-4.2967224302375895`, 1.9640504400014145`, 
        0.025757106394296358`}}], 
       Polygon3DBox[{{-4.148361215118794, 1.9820252200007074`, 
        0.01287855319714818}, {-4.148361215118794, 1.9820252200007074`, 
        0.01287855319714819}, {-4., 2., 1.2833957707615983`*^-17}, {-4., 2., 
        3.301913518726762*^-18}, {-4.148361215118794, 1.9820252200007074`, 
        0.01287855319714818}}], 
       Polygon3DBox[{{-4., 2., 3.301913518726762*^-18}, {-4., 2., 
        3.301913518726762*^-18}, {-3.8516387848812053`, 
        2.017974779999293, -0.012878553197148174`}, {-3.8516387848812053`, 
        2.017974779999293, -0.01287855319714817}, {-4., 2., 
        3.301913518726762*^-18}}], 
       Polygon3DBox[{{-3.8516387848812053`, 
        2.017974779999293, -0.01287855319714817}, {-3.8516387848812053`, 
        2.017974779999293, -0.012878553197148174`}, {-3.703277569762411, 
        2.0359495599985857`, -0.02575710639429635}, {-3.703277569762411, 
        2.0359495599985857`, -0.025757106394296347`}, {-3.8516387848812053`, 
        2.017974779999293, -0.01287855319714817}}], 
       Polygon3DBox[{{-3.703277569762411, 
        2.0359495599985857`, -0.025757106394296347`}, {-3.703277569762411, 
        2.0359495599985857`, -0.02575710639429635}, {-3.554916354643616, 
        2.053924339997878, -0.03863565959144453}, {-3.554916354643616, 
        2.053924339997878, -0.03863565959144452}, {-3.703277569762411, 
        2.0359495599985857`, -0.025757106394296347`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/t43TPz+E9sdh+d4E5
4w19wQN/GSvUD+T8t788MVNNKGGWfeyO2Qxvpgsc+MewRzhhG0y8y54BDAQO
QGgGh1t+a0/t/BVq49p/4p/6Bb4Djf8Vv51XYXC4CFG/v1tu4l//BbwHmP47
v5nvyeBwCWL+/gtrI/+UF/AcaPqX+ig/j8EhFuIeDHGoO/d3oZkDded+dHuh
7tyPw5170P0FdSdGOEDdaY8eblB3YojDwhMAV0GezA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.3959655727217335`, 
      1.5020265855785278`, -0.01528868040643376}, {-4.494201717991034, 
      2.3901247344257155`, 0.09255999958932283}, {-3.6040344272782665`, 
      2.4979734144214722`, 0.01528868040643376}, {-3.505798282008966, 
      1.6098752655742845`, -0.09255999958932283}, {-4.3959655727217335`, 
      1.5020265855785278`, -0.01528868040643376}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}, {-4.494201717991034, 
       2.3901247344257155`, 0.09255999958932283}, {-3.6040344272782665`, 
       2.4979734144214722`, 0.01528868040643376}, {-3.505798282008966, 
       1.6098752655742845`, -0.09255999958932283}, {-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.9270314100441177`, 
      2.563060582617232, -0.07911719419353518}, {-3.9270314100441177`, 
      2.563060582617232, -0.07911719419353519}, {-3.951354273362745, 
      2.708707055078155, -0.052744796129023455`}, {-3.951354273362745, 
      2.7087070550781545`, -0.05274479612902346}, {-3.9270314100441177`, 
      2.563060582617232, -0.07911719419353518}}], 
     Polygon3DBox[{{-3.951354273362745, 
      2.7087070550781545`, -0.05274479612902346}, {-3.951354273362745, 
      2.708707055078155, -0.052744796129023455`}, {-3.9756771366813726`, 
      2.8543535275390775`, -0.026372398064511745`}, {-3.9756771366813726`, 
      2.8543535275390775`, -0.02637239806451173}, {-3.951354273362745, 
      2.7087070550781545`, -0.05274479612902346}}], 
     Polygon3DBox[{{-3.9756771366813726`, 
      2.8543535275390775`, -0.02637239806451173}, {-3.9756771366813726`, 
      2.8543535275390775`, -0.026372398064511745`}, {-4., 
      3., -2.310389609799622*^-17}, {-4., 3., 0.}, {-3.9756771366813726`, 
      2.8543535275390775`, -0.02637239806451173}}], 
     Polygon3DBox[{{-4., 3., 0.}, {-4., 
      3., -3.584400400795662*^-18}, {-4.024322863318627, 3.1456464724609225`, 
      0.026372398064511717`}, {-4.024322863318628, 3.1456464724609225`, 
      0.02637239806451172}, {-4., 3., 0.}}], 
     Polygon3DBox[{{-4.024322863318628, 3.1456464724609225`, 
      0.02637239806451172}, {-4.024322863318627, 3.1456464724609225`, 
      0.026372398064511717`}, {-4.048645726637255, 3.291292944921845, 
      0.05274479612902344}, {-4.048645726637255, 3.291292944921845, 
      0.05274479612902345}, {-4.024322863318628, 3.1456464724609225`, 
      0.02637239806451172}}], 
     Polygon3DBox[{{-4.048645726637255, 3.291292944921845, 
      0.05274479612902345}, {-4.048645726637255, 3.291292944921845, 
      0.05274479612902344}, {-4.072968589955883, 3.436939417382768, 
      0.07911719419353518}, {-4.072968589955883, 3.436939417382768, 
      0.07911719419353516}, {-4.048645726637255, 3.291292944921845, 
      0.05274479612902345}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7KsaSwP4v/wDl+hReqjSwOh8/OcWRz3LL/HKvE
wvg5/Ac6uQ7MylvN6hAtdHFNLOPq/c+Zei7on+M/4Mqa4Lv9KhtUfPZ+BjAQ
OAChORwWPIlIVW5M29P7b6f4CwmBA7t/zd/kocXpEAFRby/5t1j/gqHAgbKv
9qkTQ7gcIiHm2y/7reu+w0vggNGH++K36rgdDkHcgyEOdSfcnHKoOVB32qPb
C3WnPQ532qD7C+pOeDh0QcMB6s796OEGdSeGOCw8AVQNlWA=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.442022402120948, 2.920882805806465, 
        0.029268850441541684`}, {-4.442022402120948, 2.920882805806465, 
        0.029268850441541695`}, {-4.2946816014139655`, 2.9472552038709767`, 
        0.019512566961027794`}, {-4.2946816014139655`, 2.9472552038709767`, 
        0.01951256696102779}, {-4.442022402120948, 2.920882805806465, 
        0.029268850441541684`}}], 
       Polygon3DBox[{{-4.2946816014139655`, 2.9472552038709767`, 
        0.01951256696102779}, {-4.2946816014139655`, 2.9472552038709767`, 
        0.019512566961027794`}, {-4.147340800706983, 2.973627601935488, 
        0.009756283480513906}, {-4.147340800706982, 2.973627601935488, 
        0.009756283480513899}, {-4.2946816014139655`, 2.9472552038709767`, 
        0.01951256696102779}}], 
       Polygon3DBox[{{-4.147340800706982, 2.973627601935488, 
        0.009756283480513899}, {-4.147340800706983, 2.973627601935488, 
        0.009756283480513906}, {-4., 3., 1.2065631301222679`*^-17}, {-4., 3., 
        4.8445309313316205`*^-18}, {-4.147340800706982, 2.973627601935488, 
        0.009756283480513899}}], 
       Polygon3DBox[{{-4., 3., 4.8445309313316205`*^-18}, {-4., 3., 
        4.8445309313316205`*^-18}, {-3.8526591992930173`, 
        3.026372398064512, -0.009756283480513888}, {-3.8526591992930173`, 
        3.026372398064512, -0.009756283480513885}, {-4., 3., 
        4.8445309313316205`*^-18}}], 
       Polygon3DBox[{{-3.8526591992930173`, 
        3.026372398064512, -0.009756283480513885}, {-3.8526591992930173`, 
        3.026372398064512, -0.009756283480513888}, {-3.7053183985860345`, 
        3.0527447961290233`, -0.019512566961027784`}, {-3.7053183985860345`, 
        3.0527447961290233`, -0.01951256696102778}, {-3.8526591992930173`, 
        3.026372398064512, -0.009756283480513885}}], 
       Polygon3DBox[{{-3.7053183985860345`, 
        3.0527447961290233`, -0.01951256696102778}, {-3.7053183985860345`, 
        3.0527447961290233`, -0.019512566961027784`}, {-3.557977597879052, 
        3.079117194193535, -0.02926885044154168}, {-3.557977597879052, 
        3.079117194193535, -0.029268850441541667`}, {-3.7053183985860345`, 
        3.0527447961290233`, -0.01951256696102778}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9HsvuUFV0wHf5j7n21pbN
zAd1BQ9s3+3T+Wsyu8PyhVeNpX5Ptp8752Djg2kCB27HLnP5exIm3mzPAAYC
ByA0h0PCxjtXpy4LsDl6rOaP3SW+A6qLInczmXE4LIWo39/V+/NH7RLeA54u
m8tYczgclkHM3x8QUvZ1TxnPgbxnPEYcizgcKiDu2e+PJg51J4Y5UHfuR7cX
6s79ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBKD6sMw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.369053812165066, 
      2.4839433884236968`, -0.04984834375199349}, {-4.5149909920768305`, 
      3.357822223189233, 0.10838604463507687`}, {-3.630946187834934, 
      3.5160566115763032`, 0.04984834375199349}, {-3.4850090079231695`, 
      2.642177776810767, -0.10838604463507687`}, {-4.369053812165066, 
      2.4839433884236968`, -0.04984834375199349}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}, {-4.5149909920768305`, 
       3.357822223189233, 0.10838604463507687`}, {-3.630946187834934, 
       3.5160566115763032`, 0.04984834375199349}, {-3.4850090079231695`, 
       2.642177776810767, -0.10838604463507687`}, {-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.9039855627217266`, 
      3.5724457520439934`, -0.10236499835837552`}, {-3.9039855627217266`, 
      3.5724457520439934`, -0.10236499835837552`}, {-3.9359903751478176`, 
      3.714963834695996, -0.06824333223891701}, {-3.9359903751478176`, 
      3.714963834695996, -0.06824333223891703}, {-3.9039855627217266`, 
      3.5724457520439934`, -0.10236499835837552`}}], 
     Polygon3DBox[{{-3.9359903751478176`, 
      3.714963834695996, -0.06824333223891703}, {-3.9359903751478176`, 
      3.714963834695996, -0.06824333223891701}, {-3.9679951875739086`, 
      3.857481917347998, -0.03412166611945853}, {-3.967995187573909, 
      3.857481917347998, -0.034121666119458514`}, {-3.9359903751478176`, 
      3.714963834695996, -0.06824333223891703}}], 
     Polygon3DBox[{{-3.967995187573909, 
      3.857481917347998, -0.034121666119458514`}, {-3.9679951875739086`, 
      3.857481917347998, -0.03412166611945853}, {-4., 
      4., -2.7317509686822027`*^-17}, {-4., 4., 0.}, {-3.967995187573909, 
      3.857481917347998, -0.034121666119458514`}}], 
     Polygon3DBox[{{-4., 4., 0.}, {-4., 
      4., -2.062403443892057*^-18}, {-4.032004812426091, 4.1425180826520025`, 
      0.0341216661194585}, {-4.032004812426091, 4.1425180826520025`, 
      0.0341216661194585}, {-4., 4., 0.}}], 
     Polygon3DBox[{{-4.032004812426091, 4.1425180826520025`, 
      0.0341216661194585}, {-4.032004812426091, 4.1425180826520025`, 
      0.0341216661194585}, {-4.064009624852182, 4.285036165304004, 
      0.068243332238917}, {-4.064009624852182, 4.285036165304004, 
      0.06824333223891701}, {-4.032004812426091, 4.1425180826520025`, 
      0.0341216661194585}}], 
     Polygon3DBox[{{-4.064009624852182, 4.285036165304004, 
      0.06824333223891701}, {-4.064009624852182, 4.285036165304004, 
      0.068243332238917}, {-4.096014437278273, 4.427554247956007, 
      0.10236499835837552`}, {-4.096014437278273, 4.427554247956007, 
      0.10236499835837551`}, {-4.064009624852182, 4.285036165304004, 
      0.06824333223891701}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII6aGH8ixpr/wAkpu4K4KTwO4n4mG6ab7No/kXtq
64sa/gNte+q+2u3gddh9T0khtWLj/pOtp5xK9vEfcI7bXyV/hw8qvnA/AxgI
HIDSDg9lrR78lc3dI7N31r2jCgIH7gcscPowUcBhJ0S9vXmV6d5uR4EDexc6
tD5QFnTYBTHfPtj8wuzAJIEDcz49OH5hq6CDGMQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/fDwu0kNNyg7tyPKzwBhSqbwA==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.437878744053974, 3.8976350016416244`, 
        0.01684080214252781}, {-4.437878744053974, 3.8976350016416244`, 
        0.016840802142527825`}, {-4.29191916270265, 3.931756667761083, 
        0.011227201428351884`}, {-4.29191916270265, 3.931756667761083, 
        0.011227201428351877`}, {-4.437878744053974, 3.8976350016416244`, 
        0.01684080214252781}}], 
       Polygon3DBox[{{-4.29191916270265, 3.931756667761083, 
        0.011227201428351877`}, {-4.29191916270265, 3.931756667761083, 
        0.011227201428351884`}, {-4.145959581351325, 3.9658783338805415`, 
        0.005613600714175948}, {-4.145959581351325, 3.9658783338805415`, 
        0.005613600714175942}, {-4.29191916270265, 3.931756667761083, 
        0.011227201428351877`}}], 
       Polygon3DBox[{{-4.145959581351325, 3.9658783338805415`, 
        0.005613600714175942}, {-4.145959581351325, 3.9658783338805415`, 
        0.005613600714175948}, {-4., 4., 1.0422947555168999`*^-17}, {-4., 4., 
        6.2680483792154325`*^-18}, {-4.145959581351325, 3.9658783338805415`, 
        0.005613600714175942}}], 
       Polygon3DBox[{{-4., 4., 6.2680483792154325`*^-18}, {-4., 4., 
        6.2680483792154325`*^-18}, {-3.854040418648675, 
        4.034121666119458, -0.005613600714175932}, {-3.854040418648675, 
        4.034121666119458, -0.0056136007141759274`}, {-4., 4., 
        6.2680483792154325`*^-18}}], 
       Polygon3DBox[{{-3.854040418648675, 
        4.034121666119458, -0.0056136007141759274`}, {-3.854040418648675, 
        4.034121666119458, -0.005613600714175932}, {-3.7080808372973504`, 
        4.068243332238917, -0.01122720142835187}, {-3.7080808372973504`, 
        4.068243332238917, -0.011227201428351864`}, {-3.854040418648675, 
        4.034121666119458, -0.0056136007141759274`}}], 
       Polygon3DBox[{{-3.7080808372973504`, 
        4.068243332238917, -0.011227201428351864`}, {-3.7080808372973504`, 
        4.068243332238917, -0.01122720142835187}, {-3.5621212559460256`, 
        4.102364998358375, -0.01684080214252781}, {-3.5621212559460256`, 
        4.102364998358375, -0.016840802142527794`}, {-3.7080808372973504`, 
        4.068243332238917, -0.011227201428351864`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj99BQfmw5Ha7ifanOpJv
v9ESPMD18t81mxJ+h8ab68o9/7XZpx7ZmFs2VeBAa0l9ttwumHiZPQMYCByA
0g4OWwUtbTWdbczK56gIX+U7sNfV4dQHJQGHeoj6/TnvLDzVVvEeqO5umPLQ
VcChAWL+/kWpV3Mt63kOWFw8EHcpQ8BBHuIeDHGoOzHMgbpzP7q9UHfux+HO
Pej+groTIxyg7rRHDzeoOzHEYeEJAMzCl0A=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.341864306775701, 
      3.470080753685618, -0.08552419621584771}, {-4.533893181332248, 
      4.3251892495976305`, 0.11920580050090333`}, {-3.658135693224299, 
      4.529919246314382, 0.08552419621584771}, {-3.466106818667752, 
      3.674810750402369, -0.11920580050090333`}, {-4.341864306775701, 
      3.470080753685618, -0.08552419621584771}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}, {-4.533893181332248, 
       4.3251892495976305`, 0.11920580050090333`}, {-3.658135693224299, 
       4.529919246314382, 0.08552419621584771}, {-3.466106818667752, 
       3.674810750402369, -0.11920580050090333`}, {-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.881942927408615, 
      4.583629827589022, -0.1232818199800984}, {-3.881942927408615, 
      4.583629827589022, -0.1232818199800984}, {-3.9212952849390765`, 
      4.722419885059348, -0.08218787998673227}, {-3.9212952849390765`, 
      4.722419885059348, -0.08218787998673228}, {-3.881942927408615, 
      4.583629827589022, -0.1232818199800984}}], 
     Polygon3DBox[{{-3.9212952849390765`, 
      4.722419885059348, -0.08218787998673228}, {-3.9212952849390765`, 
      4.722419885059348, -0.08218787998673227}, {-3.9606476424695383`, 
      4.861209942529674, -0.041093939993366156`}, {-3.9606476424695383`, 
      4.861209942529674, -0.04109393999336614}, {-3.9212952849390765`, 
      4.722419885059348, -0.08218787998673228}}], 
     Polygon3DBox[{{-3.9606476424695383`, 
      4.861209942529674, -0.04109393999336614}, {-3.9606476424695383`, 
      4.861209942529674, -0.041093939993366156`}, {-4., 
      5., -3.0652270648968017`*^-17}, {-4., 5., 0.}, {-3.9606476424695383`, 
      4.861209942529674, -0.04109393999336614}}], 
     Polygon3DBox[{{-4., 5., 0.}, {-4., 
      5., -2.366450801682588*^-19}, {-4.039352357530461, 5.138790057470326, 
      0.04109393999336613}, {-4.039352357530461, 5.138790057470326, 
      0.04109393999336613}, {-4., 5., 0.}}], 
     Polygon3DBox[{{-4.039352357530461, 5.138790057470326, 
      0.04109393999336613}, {-4.039352357530461, 5.138790057470326, 
      0.04109393999336613}, {-4.0787047150609235`, 5.277580114940652, 
      0.08218787998673226}, {-4.0787047150609235`, 5.277580114940652, 
      0.08218787998673227}, {-4.039352357530461, 5.138790057470326, 
      0.04109393999336613}}], 
     Polygon3DBox[{{-4.0787047150609235`, 5.277580114940652, 
      0.08218787998673227}, {-4.0787047150609235`, 5.277580114940652, 
      0.08218787998673226}, {-4.118057072591385, 5.416370172410978, 
      0.12328181998009839`}, {-4.118057072591385, 5.416370172410978, 
      0.12328181998009838`}, {-4.0787047150609235`, 5.277580114940652, 
      0.08218787998673227}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7r8lHcgo//gOKdnXyLQ4UcahoZd6b279+/T/cb
/4U4/gPZthc5Dz0Wcli5evUFZ66t+++L/WbPWM9/YNu8FywPC4Wh4kv3M4CB
wAEILeLAw99/o7ejcM+EEqY/3hoCB7wSxX/L9Yk4LIeot1d8yfJjeoDAgamH
9L7Zyog6rICYb78xlv3L4wqBA/eV3T7GrBJ1qIK4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAHIEmuU=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-4.432779226478679, 4.8767181800199015`, 
        0.0019323537229919703`}, {-4.432779226478679, 4.8767181800199015`, 
        0.0019323537229919854`}, {-4.288519484319119, 4.917812120013267, 
        0.0012882358153279928`}, {-4.28851948431912, 4.917812120013267, 
        0.001288235815327983}, {-4.432779226478679, 4.8767181800199015`, 
        0.0019323537229919703`}}], 
       Polygon3DBox[{{-4.28851948431912, 4.917812120013267, 
        0.001288235815327983}, {-4.288519484319119, 4.917812120013267, 
        0.0012882358153279928`}, {-4.1442597421595595`, 4.958906060006634, 
        0.0006441179076640005}, {-4.1442597421595595`, 4.958906060006634, 
        0.0006441179076639952}, {-4.28851948431912, 4.917812120013267, 
        0.001288235815327983}}], 
       Polygon3DBox[{{-4.1442597421595595`, 4.958906060006634, 
        0.0006441179076639952}, {-4.1442597421595595`, 4.958906060006634, 
        0.0006441179076640005}, {-4., 5., 8.02557733269235*^-18}, {-4., 5., 
        7.548834311584386*^-18}, {-4.1442597421595595`, 4.958906060006634, 
        0.0006441179076639952}}], 
       Polygon3DBox[{{-4., 5., 7.548834311584386*^-18}, {-4., 5., 
        7.548834311584386*^-18}, {-3.8557402578404405`, 
        5.041093939993366, -0.0006441179076639849}, {-3.8557402578404405`, 
        5.041093939993366, -0.0006441179076639798}, {-4., 5., 
        7.548834311584386*^-18}}], 
       Polygon3DBox[{{-3.8557402578404405`, 
        5.041093939993366, -0.0006441179076639798}, {-3.8557402578404405`, 
        5.041093939993366, -0.0006441179076639849}, {-3.7114805156808806`, 
        5.082187879986733, -0.0012882358153279772`}, {-3.7114805156808806`, 
        5.082187879986733, -0.0012882358153279677`}, {-3.8557402578404405`, 
        5.041093939993366, -0.0006441179076639798}}], 
       Polygon3DBox[{{-3.7114805156808806`, 
        5.082187879986733, -0.0012882358153279677`}, {-3.7114805156808806`, 
        5.082187879986733, -0.0012882358153279772`}, {-3.5672207735213206`, 
        5.1232818199800985`, -0.00193235372299197}, {-3.567220773521321, 
        5.1232818199800985`, -0.0019323537229919547`}, {-3.7114805156808806`, 
        5.082187879986733, -0.0012882358153279677`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUdmn/dZHq4It7eevHV
ZYXqggcCA/d+uLZa2GFd4MQ1DtKh9nMvZl3eMVngwMoVcRWvr8LEXe0ZwEDg
AIQWcRA4ovx06zRBm2MxWpF9N/gOhIcvbBfREnFYDVG/v3tnyCaZjbwH1q9z
4tcMEXFYCzF/f6BYPffqTp4DbGxPptnWiTg0QtyzPwBNHOpODHOg7tx/FM1e
qDv343DnHnR/Qd1pb4UWDlB32qOHG9SdGOKw8AQATJibaw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-4.314722153887294, 
      4.460348007608924, -0.12134946625710644`}, {-4.550836299070064, 
      5.293088352430879, 0.12521417370309038`}, {-3.685277846112706, 
      5.539651992391076, 0.12134946625710644`}, {-3.449163700929936, 
      4.706911647569121, -0.12521417370309038`}, {-4.314722153887294, 
      4.460348007608924, -0.12134946625710644`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}, {-4.550836299070064, 
       5.293088352430879, 0.12521417370309038`}, {-3.685277846112706, 
       5.539651992391076, 0.12134946625710644`}, {-3.449163700929936, 
       4.706911647569121, -0.12521417370309038`}, {-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.1203827253456273`, -5.415916369125761, 
      0.12256252825232783`}, {-3.120382725345627, -5.415916369125761, 
      0.12256252825232783`}, {-3.080255150230418, -5.2772775794171745`, 
      0.08170835216821855}, {-3.080255150230418, -5.2772775794171745`, 
      0.08170835216821856}, {-3.1203827253456273`, -5.415916369125761, 
      0.12256252825232783`}}], 
     Polygon3DBox[{{-3.080255150230418, -5.2772775794171745`, 
      0.08170835216821856}, {-3.080255150230418, -5.2772775794171745`, 
      0.08170835216821855}, {-3.040127575115209, -5.138638789708588, 
      0.040854176084109295`}, {-3.0401275751152093`, -5.138638789708587, 
      0.04085417608410928}, {-3.080255150230418, -5.2772775794171745`, 
      0.08170835216821856}}], 
     Polygon3DBox[{{-3.0401275751152093`, -5.138638789708587, 
      0.04085417608410928}, {-3.040127575115209, -5.138638789708588, 
      0.040854176084109295`}, {-3., -5., 3.1373790572537656`*^-17}, {-3., -5.,
       0.}, {-3.0401275751152093`, -5.138638789708587, 0.04085417608410928}}],
      Polygon3DBox[{{-3., -5., 0.}, {-3., -5., 
      1.1356259454253022`*^-18}, {-2.9598724248847907`, -4.861361210291413, \
-0.04085417608410927}, {-2.9598724248847907`, -4.861361210291413, \
-0.04085417608410927}, {-3., -5., 0.}}], 
     Polygon3DBox[{{-2.9598724248847907`, -4.861361210291413, \
-0.04085417608410927}, {-2.9598724248847907`, -4.861361210291413, \
-0.04085417608410927}, {-2.919744849769582, -4.7227224205828255`, \
-0.08170835216821853}, {-2.919744849769582, -4.7227224205828255`, \
-0.08170835216821855}, {-2.9598724248847907`, -4.861361210291413, \
-0.04085417608410927}}], 
     Polygon3DBox[{{-2.919744849769582, -4.7227224205828255`, \
-0.08170835216821855}, {-2.919744849769582, -4.7227224205828255`, \
-0.08170835216821853}, {-2.8796172746543727`, -4.584083630874239, \
-0.12256252825232782`}, {-2.8796172746543727`, -4.584083630874239, \
-0.1225625282523278}, {-2.919744849769582, -4.7227224205828255`, \
-0.08170835216821855}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ7/si8+xvHgZkCvL+frhQ9IMHfz+SUsN+ec9ab
8zFLOA4IcsctfycteiAtPn7NtVdb7Fl9v6XrBXEc6GBdH/y9VwQqvsSeAQw4
DkBokQP155f0x+YV2vzexDnj4lr2AxW/AtZwFAkfSIGo3/89VdhgcTT7gfdf
FkYIPhE6kAoxf/8nCdkTJZzsB9Lff2KRChM6IAZxD4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBAADoqNh
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4328884804176623`, -4.8774374717476725`, \
-0.009273089565219696}, {-3.4328884804176623`, -4.8774374717476725`, \
-0.009273089565219711}, {-3.2885923202784415`, -4.918291647831781, \
-0.006182059710146476}, {-3.2885923202784415`, -4.918291647831781, \
-0.006182059710146467}, {-3.4328884804176623`, -4.8774374717476725`, \
-0.009273089565219696}}], 
       Polygon3DBox[{{-3.2885923202784415`, -4.918291647831781, \
-0.006182059710146467}, {-3.2885923202784415`, -4.918291647831781, \
-0.006182059710146476}, {-3.1442961601392208`, -4.9591458239158905`, \
-0.003091029855073243}, {-3.1442961601392208`, -4.9591458239158905`, \
-0.0030910298550732374`}, {-3.2885923202784415`, -4.918291647831781, \
-0.006182059710146467}}], 
       Polygon3DBox[{{-3.1442961601392208`, -4.9591458239158905`, \
-0.0030910298550732374`}, {-3.1442961601392208`, -4.9591458239158905`, \
-0.003091029855073243}, {-3., -5., -9.79261207258506*^-18}, {-3., -5., \
-7.504790395981016*^-18}, {-3.1442961601392208`, -4.9591458239158905`, \
-0.0030910298550732374`}}], 
       Polygon3DBox[{{-3., -5., -7.504790395981016*^-18}, {-3., -5., \
-7.504790395981016*^-18}, {-2.8557038398607792`, -5.0408541760841095`, 
        0.0030910298550732257`}, {-2.8557038398607792`, -5.0408541760841095`, 
        0.003091029855073221}, {-3., -5., -7.504790395981016*^-18}}], 
       Polygon3DBox[{{-2.8557038398607792`, -5.0408541760841095`, 
        0.003091029855073221}, {-2.8557038398607792`, -5.0408541760841095`, 
        0.0030910298550732257`}, {-2.7114076797215585`, -5.081708352168219, 
        0.006182059710146459}, {-2.7114076797215585`, -5.081708352168219, 
        0.006182059710146451}, {-2.8557038398607792`, -5.0408541760841095`, 
        0.003091029855073221}}], 
       Polygon3DBox[{{-2.7114076797215585`, -5.081708352168219, 
        0.006182059710146451}, {-2.7114076797215585`, -5.081708352168219, 
        0.006182059710146459}, {-2.5671115195823377`, -5.1225625282523275`, 
        0.009273089565219694}, {-2.5671115195823377`, -5.1225625282523275`, 
        0.009273089565219677}, {-2.7114076797215585`, -5.081708352168219, 
        0.006182059710146451}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQPhHwIYj76t2k/y4nu
Wk5/rgNNTX5LQ9YIHzg2NY8lJqhyP9OTo/ta1DkPODouD9K6BhPP3M8ABhwH
ILTIAZVLbJHfJU33/JO2cqy+wXZg/76ItVc1RQ4chqi3/2Ne0vRtA+uButqN
UauDRQ4chZhv/yt43eHCTpYDNjZcHI21IgeCIO7BEIe6E8McqDvt0e2FutMe
hztt0P0FdSdGOEDduR893KDuxBCHhScAWr2f1g==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.5532712057632896`, -5.293353840873434, 
      0.11328943868710814`}, {-3.312505755072035, -4.46152110262191, \
-0.13183561781754752`}, {-2.4467287942367104`, -4.706646159126566, \
-0.11328943868710814`}, {-2.687494244927965, -5.53847889737809, 
      0.13183561781754752`}, {-3.5532712057632896`, -5.293353840873434, 
      0.11328943868710814`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}, {-3.312505755072035, -4.46152110262191, \
-0.13183561781754752`}, {-2.4467287942367104`, -4.706646159126566, \
-0.11328943868710814`}, {-2.687494244927965, -5.53847889737809, 
       0.13183561781754752`}, {-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.098007462709227, -4.427202585799375, 
      0.10194355271240892`}, {-3.098007462709227, -4.427202585799375, 
      0.10194355271240892`}, {-3.0653383084728176`, -4.2848017238662495`, 
      0.06796236847493928}, {-3.065338308472818, -4.2848017238662495`, 
      0.06796236847493929}, {-3.098007462709227, -4.427202585799375, 
      0.10194355271240892`}}], 
     Polygon3DBox[{{-3.065338308472818, -4.2848017238662495`, 
      0.06796236847493929}, {-3.0653383084728176`, -4.2848017238662495`, 
      0.06796236847493928}, {-3.032669154236409, -4.142400861933125, 
      0.03398118423746965}, {-3.032669154236409, -4.142400861933125, 
      0.033981184237469646`}, {-3.065338308472818, -4.2848017238662495`, 
      0.06796236847493929}}], 
     Polygon3DBox[{{-3.032669154236409, -4.142400861933125, 
      0.033981184237469646`}, {-3.032669154236409, -4.142400861933125, 
      0.03398118423746965}, {-3., -4., 2.4433170398633463`*^-17}, {-3., -4., 
      0.}, {-3.032669154236409, -4.142400861933125, 0.033981184237469646`}}], 
     Polygon3DBox[{{-3., -4., 
      0.}, {-3., -4., -7.179583643453604*^-19}, {-2.967330845763591, \
-3.8575991380668753`, -0.03398118423746963}, {-2.967330845763591, \
-3.8575991380668753`, -0.03398118423746963}, {-3., -4., 0.}}], 
     Polygon3DBox[{{-2.967330845763591, -3.8575991380668753`, \
-0.03398118423746963}, {-2.967330845763591, -3.8575991380668753`, \
-0.03398118423746963}, {-2.934661691527182, -3.7151982761337505`, \
-0.06796236847493926}, {-2.934661691527182, -3.7151982761337505`, \
-0.06796236847493928}, {-2.967330845763591, -3.8575991380668753`, \
-0.03398118423746963}}], 
     Polygon3DBox[{{-2.934661691527182, -3.7151982761337505`, \
-0.06796236847493928}, {-2.934661691527182, -3.7151982761337505`, \
-0.06796236847493926}, {-2.901992537290773, -3.5727974142006254`, \
-0.1019435527124089}, {-2.901992537290773, -3.572797414200626, \
-0.10194355271240889`}, {-2.934661691527182, -3.7151982761337505`, \
-0.06796236847493928}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP545ofSjhMcB3okrWeUbBU8cFXsA8NPiV32CzsC
xC+0chyITVMXWKwseKA/5Wvo79SN9gEuK7hfOHEc0N8s3HFxogBUfKE9Axhw
HIDQAgemL3fu9/2fY7Nhd/gX8b3sBxbPvPE+5g7fgV6I+v3x5etf6FexH3Az
3nh/5w7eA30Q8/fzG7PfdTdnP/DyTOd5sak8By5D3AMXfwEVh7oTwxyoO/ej
2wt1534c7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDdFqzl
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4382614998780574`, -3.898056447287591, 
        0.005862574946876364}, {-3.4382614998780574`, -3.898056447287591, 
        0.005862574946876352}, {-3.2921743332520386`, -3.9320376315250605`, 
        0.003908383297917565}, {-3.2921743332520386`, -3.932037631525061, 
        0.003908383297917575}, {-3.4382614998780574`, -3.898056447287591, 
        0.005862574946876364}}], 
       Polygon3DBox[{{-3.2921743332520386`, -3.932037631525061, 
        0.003908383297917575}, {-3.2921743332520386`, -3.9320376315250605`, 
        0.003908383297917565}, {-3.1460871666260193`, -3.9660188157625305`, 
        0.001954191648958781}, {-3.1460871666260193`, -3.9660188157625305`, 
        0.001954191648958784}, {-3.2921743332520386`, -3.932037631525061, 
        0.003908383297917575}}], 
       Polygon3DBox[{{-3.1460871666260193`, -3.9660188157625305`, 
        0.001954191648958784}, {-3.1460871666260193`, -3.9660188157625305`, 
        0.001954191648958781}, {-3., -4., -4.795849900678555*^-18}, {-3., \
-4., -6.242242276148053*^-18}, {-3.1460871666260193`, -3.9660188157625305`, 
        0.001954191648958784}}], 
       Polygon3DBox[{{-3., -4., -6.242242276148053*^-18}, {-3., -4., \
-6.242242276148053*^-18}, {-2.8539128333739807`, -4.0339811842374695`, \
-0.0019541916489587917`}, {-2.8539128333739807`, -4.0339811842374695`, \
-0.0019541916489587956`}, {-3., -4., -6.242242276148053*^-18}}], 
       Polygon3DBox[{{-2.8539128333739807`, -4.0339811842374695`, \
-0.0019541916489587956`}, {-2.8539128333739807`, -4.0339811842374695`, \
-0.0019541916489587917`}, {-2.707825666747962, -4.067962368474939, \
-0.0039083832979175765`}, {-2.7078256667479614`, -4.067962368474939, \
-0.003908383297917586}, {-2.8539128333739807`, -4.0339811842374695`, \
-0.0019541916489587956`}}], 
       Polygon3DBox[{{-2.7078256667479614`, -4.067962368474939, \
-0.003908383297917586}, {-2.707825666747962, -4.067962368474939, \
-0.0039083832979175765`}, {-2.5617385001219426`, -4.101943552712409, \
-0.0058625749468763635`}, {-2.5617385001219426`, -4.101943552712409, \
-0.005862574946876375}, {-2.7078256667479614`, -4.067962368474939, \
-0.003908383297917586}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwHGE6s+RXFXGHfkWRQ
Hx/GdeBOSIDqhRL+A6tvyS63YSqwdzGcsV9fm/NAntYKoYxdMPEEewYw4DgA
oQUOyIi3i6Wu07LZcy7d4cIVtgMnX63+dlpJ4MBKiPr9FXPPNyxYyXpg0tXw
t9NdBQ6sgpi/3zTH/GBBHcuB6APMT5IzBA78Ow52D4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBADqD5zw
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.5362689625872843`, -4.325259033086965, 
      0.10780612765928528`}, {-3.3402540371688305`, -3.4708538614882167`, \
-0.09608097776553255}, {-2.4637310374127157`, -3.6747409669130344`, \
-0.10780612765928528`}, {-2.6597459628311695`, -4.529146138511783, 
      0.09608097776553255}, {-3.5362689625872843`, -4.325259033086965, 
      0.10780612765928528`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}, {-3.3402540371688305`, -3.4708538614882167`, \
-0.09608097776553255}, {-2.4637310374127157`, -3.6747409669130344`, \
-0.10780612765928528`}, {-2.6597459628311695`, -4.529146138511783, 
       0.09608097776553255}, {-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.0745474784257523`, -3.4367108084914983`, 
      0.07890718096006065}, {-3.0745474784257523`, -3.4367108084914983`, 
      0.07890718096006065}, {-3.0496983189505014`, -3.2911405389943322`, 
      0.05260478730670709}, {-3.0496983189505014`, -3.2911405389943322`, 
      0.052604787306707104`}, {-3.0745474784257523`, -3.4367108084914983`, 
      0.07890718096006065}}], 
     Polygon3DBox[{{-3.0496983189505014`, -3.2911405389943322`, 
      0.052604787306707104`}, {-3.0496983189505014`, -3.2911405389943322`, 
      0.05260478730670709}, {-3.0248491594752505`, -3.145570269497166, 
      0.02630239365335356}, {-3.024849159475251, -3.145570269497166, 
      0.026302393653353552`}, {-3.0496983189505014`, -3.2911405389943322`, 
      0.052604787306707104`}}], 
     Polygon3DBox[{{-3.024849159475251, -3.145570269497166, 
      0.026302393653353552`}, {-3.0248491594752505`, -3.145570269497166, 
      0.02630239365335356}, {-3., -3., 1.7198795697817222`*^-17}, {-3., -3., 
      0.}, {-3.024849159475251, -3.145570269497166, 0.026302393653353552`}}], 
     Polygon3DBox[{{-3., -3., 
      0.}, {-3., -3., -2.268886326654577*^-18}, {-2.975150840524749, \
-2.854429730502834, -0.026302393653353545`}, {-2.975150840524749, \
-2.854429730502834, -0.026302393653353545`}, {-3., -3., 0.}}], 
     Polygon3DBox[{{-2.975150840524749, -2.854429730502834, \
-0.026302393653353545`}, {-2.975150840524749, -2.854429730502834, \
-0.026302393653353545`}, {-2.9503016810494986`, -2.7088594610056678`, \
-0.05260478730670709}, {-2.9503016810494986`, -2.7088594610056678`, \
-0.0526047873067071}, {-2.975150840524749, -2.854429730502834, \
-0.026302393653353545`}}], 
     Polygon3DBox[{{-2.9503016810494986`, -2.7088594610056678`, \
-0.0526047873067071}, {-2.9503016810494986`, -2.7088594610056678`, \
-0.05260478730670709}, {-2.9254525215742477`, -2.5632891915085017`, \
-0.07890718096006064}, {-2.9254525215742477`, -2.5632891915085017`, \
-0.07890718096006064}, {-2.9503016810494986`, -2.7088594610056678`, \
-0.0526047873067071}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62WS9yzQyOA4/smmyS6rgPTJ+z5KKT8Rb7n+Ul
1idSOQ680VxT6xjCdeDUBYNDzO9X2f+13iX7xIjjwDeRa/sUtDih4rPsGcCA
4wCM/rtWo/xGYZoN8xHXR9Jn2Q9wvdZ0vH+V7cAJiPr97B3dR8xnsR8QuRbc
tG8164GTEPP3c/lcXBaczn5A7mDt4bmNLAemQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBXi+qQw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4426402739770836`, -2.9210928190399392`, 
        0.018526862832894054`}, {-3.4426402739770836`, -2.9210928190399392`, 
        0.018526862832894044`}, {-3.295093515984722, -2.947395212693293, 
        0.012351241888596027`}, {-3.295093515984722, -2.947395212693293, 
        0.012351241888596036`}, {-3.4426402739770836`, -2.9210928190399392`, 
        0.018526862832894054`}}], 
       Polygon3DBox[{{-3.295093515984722, -2.947395212693293, 
        0.012351241888596036`}, {-3.295093515984722, -2.947395212693293, 
        0.012351241888596027`}, {-3.147546757992361, -2.9736976063466463`, 
        0.006175620944298015}, {-3.147546757992361, -2.9736976063466463`, 
        0.006175620944298015}, {-3.295093515984722, -2.947395212693293, 
        0.012351241888596036`}}], 
       Polygon3DBox[{{-3.147546757992361, -2.9736976063466463`, 
        0.006175620944298015}, {-3.147546757992361, -2.9736976063466463`, 
        0.006175620944298015}, {-3., -3., -2.607936204792897*^-19}, {-3., \
-3., -4.831671329623962*^-18}, {-3.147546757992361, -2.9736976063466463`, 
        0.006175620944298015}}], 
       Polygon3DBox[{{-3., -3., -4.831671329623962*^-18}, {-3., -3., \
-4.831671329623962*^-18}, {-2.852453242007639, -3.0263023936533537`, \
-0.00617562094429802}, {-2.852453242007639, -3.0263023936533533`, \
-0.006175620944298022}, {-3., -3., -4.831671329623962*^-18}}], 
       Polygon3DBox[{{-2.852453242007639, -3.0263023936533533`, \
-0.006175620944298022}, {-2.852453242007639, -3.0263023936533537`, \
-0.00617562094429802}, {-2.704906484015278, -3.052604787306707, \
-0.012351241888596034`}, {-2.704906484015278, -3.052604787306707, \
-0.012351241888596045`}, {-2.852453242007639, -3.0263023936533533`, \
-0.006175620944298022}}], 
       Polygon3DBox[{{-2.704906484015278, -3.052604787306707, \
-0.012351241888596045`}, {-2.704906484015278, -3.052604787306707, \
-0.012351241888596034`}, {-2.557359726022917, -3.0789071809600608`, \
-0.01852686283289405}, {-2.557359726022917, -3.0789071809600608`, \
-0.01852686283289406}, {-2.704906484015278, -3.052604787306707, \
-0.012351241888596045`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gP1L68vX3Lj0n2XCHO
fyNjuA7stfn+wXkK+4G/D8/Pn+3dac+6auE/HT3OA3Hzqn8onoKJV9ozgAHH
ARgdZKPLGi7iavM7NI7x8kW2A4sSW9jvmXIc+AVRv//b6j1MyxazHnA+zMG/
J5vjwB+I+fs/MkqzVJayHHiq0is2ayHHgRqIe/Z/QBOHuhPDHKg796PbC3Xn
fhzu3IPuL6g7McIB6k57frRwg7rTHld4AgAvILGg
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.517187752402836, -3.357803627531438, 
      0.0974340437929547}, {-3.3680927955513313`, -2.484382010548441, \
-0.0603803181271666}, {-2.482812247597164, -2.642196372468562, \
-0.0974340437929547}, {-2.6319072044486687`, -3.515617989451559, 
      0.0603803181271666}, {-3.517187752402836, -3.357803627531438, 
      0.0974340437929547}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}, {-3.3680927955513313`, -2.484382010548441, \
-0.0603803181271666}, {-2.482812247597164, -2.642196372468562, \
-0.0974340437929547}, {-2.6319072044486687`, -3.515617989451559, 
       0.0603803181271666}, {-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.0502134135558063`, -2.4439365891396965`, 
      0.05384160029276379}, {-3.0502134135558063`, -2.4439365891396965`, 
      0.05384160029276378}, {-3.0334756090372044`, -2.295957726093131, 
      0.035894400195175855`}, {-3.0334756090372044`, -2.295957726093131, 
      0.03589440019517587}, {-3.0502134135558063`, -2.4439365891396965`, 
      0.05384160029276379}}], 
     Polygon3DBox[{{-3.0334756090372044`, -2.295957726093131, 
      0.03589440019517587}, {-3.0334756090372044`, -2.295957726093131, 
      0.035894400195175855`}, {-3.016737804518602, -2.1479788630465655`, 
      0.017947200097587934`}, {-3.016737804518602, -2.1479788630465655`, 
      0.017947200097587934`}, {-3.0334756090372044`, -2.295957726093131, 
      0.03589440019517587}}], 
     Polygon3DBox[{{-3.016737804518602, -2.1479788630465655`, 
      0.017947200097587934`}, {-3.016737804518602, -2.1479788630465655`, 
      0.017947200097587934`}, {-3., -2., 9.842314981394239*^-18}, {-3., -2., 
      0.}, {-3.016737804518602, -2.1479788630465655`, 
      0.017947200097587934`}}], 
     Polygon3DBox[{{-3., -2., 
      0.}, {-3., -2., -3.441281535870412*^-18}, {-2.983262195481398, \
-1.8520211369534345`, -0.01794720009758793}, {-2.983262195481398, \
-1.8520211369534345`, -0.017947200097587927`}, {-3., -2., 0.}}], 
     Polygon3DBox[{{-2.983262195481398, -1.8520211369534345`, \
-0.017947200097587927`}, {-2.983262195481398, -1.8520211369534345`, \
-0.01794720009758793}, {-2.9665243909627956`, -1.704042273906869, \
-0.035894400195175855`}, {-2.9665243909627956`, -1.704042273906869, \
-0.03589440019517586}, {-2.983262195481398, -1.8520211369534345`, \
-0.017947200097587927`}}], 
     Polygon3DBox[{{-2.9665243909627956`, -1.704042273906869, \
-0.03589440019517586}, {-2.9665243909627956`, -1.704042273906869, \
-0.035894400195175855`}, {-2.9497865864441937`, -1.5560634108603035`, \
-0.05384160029276378}, {-2.9497865864441937`, -1.5560634108603035`, \
-0.053841600292763775`}, {-2.9665243909627956`, -1.704042273906869, \
-0.03589440019517586}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4M9/C6lsZxoPFS3AK9XuYDbm+uByhMXG0faGVw
p8+F40BYzxRR+TimAwYeT00PJCyy15CVyHNX4jig7Xaqi1+fESo+yZ4BDDgO
QGiGA34VlyMdFsbZ3Hj0fOKOu+wHVhVnv3qw8O9+PYj6/euPnlcu3M1+IOT5
tSsHnX/v14eYv799xfatmjPZD/yLctq/6OmP/S4Q98DF/0LFoe6EmxMMNQfq
zv3o9kLduR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBnoag1
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4458827884659806`, -1.9461583997072363`, 
        0.028100196222015737`}, {-3.4458827884659806`, -1.9461583997072363`, 
        0.02810019622201573}, {-3.297255192310654, -1.964105599804824, 
        0.01873346414801048}, {-3.297255192310654, -1.964105599804824, 
        0.01873346414801049}, {-3.4458827884659806`, -1.9461583997072363`, 
        0.028100196222015737`}}], 
       Polygon3DBox[{{-3.297255192310654, -1.964105599804824, 
        0.01873346414801049}, {-3.297255192310654, -1.964105599804824, 
        0.01873346414801048}, {-3.148627596155327, -1.982052799902412, 
        0.009366732074005244}, {-3.1486275961553267`, -1.982052799902412, 
        0.009366732074005244}, {-3.297255192310654, -1.964105599804824, 
        0.01873346414801049}}], 
       Polygon3DBox[{{-3.1486275961553267`, -1.982052799902412, 
        0.009366732074005244}, {-3.148627596155327, -1.982052799902412, 
        0.009366732074005244}, {-3., -2., 
        3.63592723639516*^-18}, {-3., -2., -3.2968471729752188`*^-18}, \
{-3.1486275961553267`, -1.982052799902412, 0.009366732074005244}}], 
       Polygon3DBox[{{-3., -2., -3.2968471729752188`*^-18}, {-3., -2., \
-3.2968471729752188`*^-18}, {-2.8513724038446733`, -2.0179472000975878`, \
-0.009366732074005244}, {-2.8513724038446733`, -2.0179472000975878`, \
-0.009366732074005247}, {-3., -2., -3.2968471729752188`*^-18}}], 
       Polygon3DBox[{{-2.8513724038446733`, -2.0179472000975878`, \
-0.009366732074005247}, {-2.8513724038446733`, -2.0179472000975878`, \
-0.009366732074005244}, {-2.702744807689346, -2.035894400195176, \
-0.018733464148010484`}, {-2.702744807689346, -2.035894400195176, \
-0.018733464148010495`}, {-2.8513724038446733`, -2.0179472000975878`, \
-0.009366732074005247}}], 
       Polygon3DBox[{{-2.702744807689346, -2.035894400195176, \
-0.018733464148010495`}, {-2.702744807689346, -2.035894400195176, \
-0.018733464148010484`}, {-2.5541172115340194`, -2.0538416002927637`, \
-0.028100196222015733`}, {-2.5541172115340194`, -2.0538416002927637`, \
-0.028100196222015737`}, {-2.702744807689346, -2.035894400195176, \
-0.018733464148010495`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/v/zlJ2d7n2Bz760E9
IccTuA7suxrw72fO//3LeHLr7+pNts/WdFuVbMB54H6Wxv+abTDxZnsGMOA4
AKEZDoiIctcf++FvM/XaztA559kOTDiV3XBQheHAEoj6/Zpri1dbzGc9oDj1
OkOzJ8OBpRDz9+9r1mW8msdyYGO8c6NLHsOB7xD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9Sd8HDYDw0HqDvt0cMN6k4McVh4AgAmcqfC
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.496096202021787, -2.3900949888469327`, 
      0.08194179651477952}, {-3.3956693749101743`, -1.5022218105675396`, \
-0.025741404070748052`}, {-2.503903797978213, -1.6099050111530673`, \
-0.08194179651477952}, {-2.6043306250898257`, -2.49777818943246, 
      0.025741404070748052`}, {-3.496096202021787, -2.3900949888469327`, 
      0.08194179651477952}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}, {-3.3956693749101743`, -1.5022218105675396`, \
-0.025741404070748052`}, {-2.503903797978213, -1.6099050111530673`, \
-0.08194179651477952}, {-2.6043306250898257`, -2.49777818943246, 
       0.025741404070748052`}, {-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.025265228437042, -1.4484595816658583`, 
      0.027306992586285952`}, {-3.025265228437042, -1.4484595816658583`, 
      0.027306992586285946`}, {-3.0168434856246944`, -1.2989730544439055`, 
      0.018204661724190628`}, {-3.016843485624695, -1.2989730544439055`, 
      0.01820466172419064}, {-3.025265228437042, -1.4484595816658583`, 
      0.027306992586285952`}}], 
     Polygon3DBox[{{-3.016843485624695, -1.2989730544439055`, 
      0.01820466172419064}, {-3.0168434856246944`, -1.2989730544439055`, 
      0.018204661724190628`}, {-3.0084217428123474`, -1.1494865272219528`, 
      0.009102330862095317}, {-3.0084217428123474`, -1.1494865272219528`, 
      0.00910233086209532}, {-3.016843485624695, -1.2989730544439055`, 
      0.01820466172419064}}], 
     Polygon3DBox[{{-3.0084217428123474`, -1.1494865272219528`, 
      0.00910233086209532}, {-3.0084217428123474`, -1.1494865272219528`, 
      0.009102330862095317}, {-3., -1.0000000000000002`, 
      2.5645840370418824`*^-18}, {-3., -1., 
      0.}, {-3.0084217428123474`, -1.1494865272219528`, 
      0.00910233086209532}}], 
     Polygon3DBox[{{-3., -1., 
      0.}, {-3., -1., -4.1724941635276984`*^-18}, {-2.9915782571876526`, \
-0.8505134727780472, -0.00910233086209532}, {-2.9915782571876526`, \
-0.8505134727780472, -0.009102330862095316}, {-3., -1., 0.}}], 
     Polygon3DBox[{{-2.9915782571876526`, -0.8505134727780472, \
-0.009102330862095316}, {-2.9915782571876526`, -0.8505134727780472, \
-0.00910233086209532}, {-2.983156514375305, -0.7010269455560945, \
-0.01820466172419063}, {-2.983156514375305, -0.7010269455560945, \
-0.018204661724190635`}, {-2.9915782571876526`, -0.8505134727780472, \
-0.009102330862095316}}], 
     Polygon3DBox[{{-2.983156514375305, -0.7010269455560945, \
-0.018204661724190635`}, {-2.983156514375305, -0.7010269455560945, \
-0.01820466172419063}, {-2.974734771562958, -0.5515404183341417, \
-0.027306992586285952`}, {-2.974734771562958, -0.5515404183341417, \
-0.02730699258628595}, {-2.983156514375305, -0.7010269455560945, \
-0.018204661724190635`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO573ue4z5jjwIEg3y+Pdb7vn3K7wCH222x7Ltf4
a3VKHAcaeox/TD/xZf/O51+17JZMsm9dpJ9tL8hxwOGY5B/vlE9Q8SZ7BjDg
OAChP+w3bnL5tEfQ36Y69sKUA+/YDzQUn2HPMH+9fztE/f5vuxZoNt5lP8Dw
fAb/hbxn+3dAzN9fJFG4z/EMUH1UqrjFsof7J0PcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8ARi2tic=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4478766516405615`, -0.972693007413714, 
        0.03407100044219077}, {-3.4478766516405615`, -0.972693007413714, 
        0.03407100044219077}, {-3.298584434427041, -0.9817953382758093, 
        0.02271400029479384}, {-3.298584434427041, -0.9817953382758093, 
        0.02271400029479385}, {-3.4478766516405615`, -0.972693007413714, 
        0.03407100044219077}}], 
       Polygon3DBox[{{-3.298584434427041, -0.9817953382758093, 
        0.02271400029479385}, {-3.298584434427041, -0.9817953382758093, 
        0.02271400029479384}, {-3.1492922172135205`, -0.9908976691379047, 
        0.011357000147396927`}, {-3.1492922172135205`, -0.9908976691379047, 
        0.011357000147396924`}, {-3.298584434427041, -0.9817953382758093, 
        0.02271400029479385}}], 
       Polygon3DBox[{{-3.1492922172135205`, -0.9908976691379047, 
        0.011357000147396924`}, {-3.1492922172135205`, -0.9908976691379047, 
        0.011357000147396927`}, {-3., -1., 
        6.73379764961746*^-18}, {-3., -1., -1.67207105325678*^-18}, \
{-3.1492922172135205`, -0.9908976691379047, 0.011357000147396924`}}], 
       Polygon3DBox[{{-3., -1., -1.67207105325678*^-18}, {-3., -1., \
-1.67207105325678*^-18}, {-2.8507077827864795`, -1.0091023308620952`, \
-0.011357000147396922`}, {-2.8507077827864795`, -1.0091023308620952`, \
-0.011357000147396922`}, {-3., -1., -1.67207105325678*^-18}}], 
       Polygon3DBox[{{-2.8507077827864795`, -1.0091023308620952`, \
-0.011357000147396922`}, {-2.8507077827864795`, -1.0091023308620952`, \
-0.011357000147396922`}, {-2.701415565572959, -1.0182046617241907`, \
-0.02271400029479384}, {-2.701415565572959, -1.0182046617241907`, \
-0.022714000294793847`}, {-2.8507077827864795`, -1.0091023308620952`, \
-0.011357000147396922`}}], 
       Polygon3DBox[{{-2.701415565572959, -1.0182046617241907`, \
-0.022714000294793847`}, {-2.701415565572959, -1.0182046617241907`, \
-0.02271400029479384}, {-2.5521233483594385`, -1.0273069925862859`, \
-0.03407100044219077}, {-2.5521233483594385`, -1.0273069925862859`, \
-0.03407100044219076}, {-2.701415565572959, -1.0182046617241907`, \
-0.022714000294793847`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff7T/t4CB4sXGg/b3W6
TUMy14FDASv47mW9379799aDYU7T7c9fNZY7YMh5IFEjhD1/K0y83Z4BDDgO
QOgP+wtkDn37lBhsY6h15qH9ObYD51+H1niofti/A6J+f1LIjMP1c1gPzL++
+scErw/7d0LM3z+5LmXp/iyWA3mHGUtv5n/YfwriHgxxqDsxzIG6cz+6vVB3
7sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBdsrFT
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.4731418800776033`, -1.4211525890795724`, 
      0.06137799302847672}, {-3.4226114232035196`, -0.5242334257478558, 
      0.006764007855904815}, {-2.5268581199223967`, -0.5788474109204276, \
-0.06137799302847672}, {-2.5773885767964804`, -1.4757665742521442`, \
-0.006764007855904815}, {-3.4731418800776033`, -1.4211525890795724`, 
      0.06137799302847672}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}, {-3.4226114232035196`, -0.5242334257478558, 
       0.006764007855904815}, {-2.5268581199223967`, -0.5788474109204276, \
-0.06137799302847672}, {-2.5773885767964804`, -1.4757665742521442`, \
-0.006764007855904815}, {-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3., -0.45, 
      0.}, {-3., -0.45, -8.842141003572888*^-18}, {-3., -0.3, \
-7.36845083631074*^-18}, {-3., -0.30000000000000004`, 0.}, {-3., -0.45, 0.}}],
      Polygon3DBox[{{-3., -0.30000000000000004`, 
      0.}, {-3., -0.3, -7.36845083631074*^-18}, {-3., -0.15000000000000008`, \
-5.894760669048593*^-18}, {-3., -0.15000000000000002`, 
      0.}, {-3., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{-3., -0.15000000000000002`, 
      0.}, {-3., -0.15000000000000008`, -5.894760669048593*^-18}, {-3., \
-1.1102230246251565`*^-16, -4.421070501786446*^-18}, {-3., 0., 
      0.}, {-3., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{-3., 0., 0.}, {-3., 0., -4.421070501786444*^-18}, {-3., 
      0.14999999999999997`, -2.9473803345242965`*^-18}, {-3., 
      0.14999999999999997`, 0.}, {-3., 0., 0.}}], 
     Polygon3DBox[{{-3., 0.14999999999999997`, 0.}, {-3., 
      0.14999999999999997`, -2.9473803345242965`*^-18}, {-3., 
      0.29999999999999993`, -1.4736901672621486`*^-18}, {-3., 0.3, 0.}, {-3., 
      0.14999999999999997`, 0.}}], 
     Polygon3DBox[{{-3., 0.3, 0.}, {-3., 
      0.29999999999999993`, -1.4736901672621488`*^-18}, {-3., 
      0.44999999999999996`, -7.362561396861607*^-34}, {-3., 
      0.4499999999999999, 0.}, {-3., 0.3, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgOHD2DAjc2c+AAjgOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQBoNUJg
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.44854958885624, 0., 
        0.03610078028101299}, {-3.44854958885624, 5.5109105961630896`*^-17, 
        0.03610078028101299}, {-3.2990330592374932`, 4.592425496802574*^-17, 
        0.02406718685400866}, {-3.2990330592374937`, 9.184850993605149*^-18, 
        0.024067186854008663`}, {-3.44854958885624, 0., 
        0.03610078028101299}}], 
       Polygon3DBox[{{-3.2990330592374937`, 9.184850993605149*^-18, 
        0.024067186854008663`}, {-3.2990330592374932`, 4.592425496802574*^-17,
         0.02406718685400866}, {-3.149516529618747, 3.67394039744206*^-17, 
        0.012033593427004337`}, {-3.149516529618747, 1.8369701987210297`*^-17,
         0.012033593427004332`}, {-3.2990330592374937`, 
        9.184850993605149*^-18, 0.024067186854008663`}}], 
       Polygon3DBox[{{-3.149516529618747, 1.8369701987210297`*^-17, 
        0.012033593427004332`}, {-3.149516529618747, 3.67394039744206*^-17, 
        0.012033593427004337`}, {-3., 2.7554552980815454`*^-17, 
        8.906648327758767*^-18}, {-3., 2.7554552980815448`*^-17, 
        0.}, {-3.149516529618747, 1.8369701987210297`*^-17, 
        0.012033593427004332`}}], 
       Polygon3DBox[{{-3., 2.7554552980815448`*^-17, 0.}, {-3., 
        2.7554552980815448`*^-17, 0.}, {-2.850483470381253, 
        1.83697019872103*^-17, -0.012033593427004326`}, {-2.850483470381253, 
        3.6739403974420595`*^-17, -0.012033593427004326`}, {-3., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{-2.850483470381253, 
        3.6739403974420595`*^-17, -0.012033593427004326`}, \
{-2.850483470381253, 
        1.83697019872103*^-17, -0.012033593427004326`}, {-2.7009669407625068`,
         9.184850993605152*^-18, -0.024067186854008653`}, \
{-2.7009669407625068`, 
        4.592425496802574*^-17, -0.02406718685400866}, {-2.850483470381253, 
        3.6739403974420595`*^-17, -0.012033593427004326`}}], 
       Polygon3DBox[{{-2.7009669407625068`, 
        4.592425496802574*^-17, -0.02406718685400866}, {-2.7009669407625068`, 
        9.184850993605153*^-18, -0.024067186854008653`}, {-2.55145041114376, 
        4.5887548728832574`*^-33, -0.03610078028101298}, {-2.55145041114376, 
        5.510910596163089*^-17, -0.03610078028101298}, {-2.7009669407625068`, 
        4.592425496802574*^-17, -0.02406718685400866}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF6is01r4TTuAwxQ4NEaqnu2epF93olzhdkpXHDx
xJjjEwWXzrA3T3m+w9SIE028wx7C44CLByipLenrDLE5OVvC/dRZNrh4HET9
/snmhn1TZrPCxRMg5u+Puex5NS6TBS7uDnEPhjjUnfsnoZkDded+dHuh7tyP
w5170P0Fdad9Llo4QN1pjx5uUHdiiMPCEwDGkGug
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.44854958885624, -0.45, 
      0.03610078028101299}, {-3.44854958885624, 0.45, 
      0.03610078028101299}, {-2.55145041114376, 
      0.45, -0.03610078028101299}, {-2.55145041114376, -0.45, \
-0.03610078028101299}, {-3.44854958885624, -0.45, 0.03610078028101299}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.44854958885624, -0.45, 
       0.03610078028101299}, {-3.44854958885624, 0.45, 
       0.03610078028101299}, {-2.55145041114376, 
       0.45, -0.03610078028101299}, {-2.55145041114376, -0.45, \
-0.03610078028101299}, {-3.44854958885624, -0.45, 0.03610078028101299}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.974734771562958, 
      0.5515404183341417, -0.027306992586285952`}, {-2.9747347715629577`, 
      0.5515404183341417, -0.02730699258628596}, {-2.983156514375305, 
      0.7010269455560945, -0.018204661724190642`}, {-2.983156514375305, 
      0.7010269455560945, -0.01820466172419064}, {-2.974734771562958, 
      0.5515404183341417, -0.027306992586285952`}}], 
     Polygon3DBox[{{-2.983156514375305, 
      0.7010269455560945, -0.01820466172419064}, {-2.983156514375305, 
      0.7010269455560945, -0.018204661724190642`}, {-2.9915782571876526`, 
      0.8505134727780471, -0.009102330862095328}, {-2.9915782571876526`, 
      0.8505134727780472, -0.00910233086209532}, {-2.983156514375305, 
      0.7010269455560945, -0.01820466172419064}}], 
     Polygon3DBox[{{-2.9915782571876526`, 
      0.8505134727780472, -0.00910233086209532}, {-2.9915782571876526`, 
      0.8505134727780471, -0.009102330862095328}, {-3., 
      0.9999999999999999, -1.0909572364097282`*^-17}, {-3., 1., 
      0.}, {-2.9915782571876526`, 0.8505134727780472, -0.00910233086209532}}],
      Polygon3DBox[{{-3., 1., 0.}, {-3., 
      1., -4.1724941635276984`*^-18}, {-3.0084217428123474`, 
      1.1494865272219528`, 0.009102330862095312}, {-3.0084217428123474`, 
      1.1494865272219528`, 0.009102330862095316}, {-3., 1., 0.}}], 
     Polygon3DBox[{{-3.0084217428123474`, 1.1494865272219528`, 
      0.009102330862095316}, {-3.0084217428123474`, 1.1494865272219528`, 
      0.009102330862095312}, {-3.0168434856246944`, 1.2989730544439055`, 
      0.01820466172419063}, {-3.016843485624695, 1.2989730544439055`, 
      0.018204661724190635`}, {-3.0084217428123474`, 1.1494865272219528`, 
      0.009102330862095316}}], 
     Polygon3DBox[{{-3.016843485624695, 1.2989730544439055`, 
      0.018204661724190635`}, {-3.0168434856246944`, 1.2989730544439055`, 
      0.01820466172419063}, {-3.025265228437042, 1.4484595816658583`, 
      0.027306992586285952`}, {-3.025265228437042, 1.4484595816658583`, 
      0.02730699258628595}, {-3.016843485624695, 1.2989730544439055`, 
      0.018204661724190635`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6SKNzneIb9QENUqrjFsof2U24XOMR+m73/264F
mo132Q8wPJ/BfyHvmf3O51+17JZM2l8de2HKgXdA9cVn2DPMX0PFm/YzgAHH
AQj9wd64yeXTHkH/Pa2L9LPtBTkOOByT/OOd8sl+O0S9PZdr/LU6JY4DDT3G
P6af+GK/A2K+fd/zPsd9xhwHDgT5fnms891+MsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEACBnrXM=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4478766516405615`, 0.972693007413714, 
        0.03407100044219077}, {-3.4478766516405615`, 0.9726930074137141, 
        0.03407100044219077}, {-3.298584434427041, 0.9817953382758094, 
        0.022714000294793847`}, {-3.298584434427041, 0.9817953382758093, 
        0.02271400029479385}, {-3.4478766516405615`, 0.972693007413714, 
        0.03407100044219077}}], 
       Polygon3DBox[{{-3.298584434427041, 0.9817953382758093, 
        0.02271400029479385}, {-3.298584434427041, 0.9817953382758094, 
        0.022714000294793847`}, {-3.1492922172135205`, 0.9908976691379047, 
        0.01135700014739693}, {-3.1492922172135205`, 0.9908976691379047, 
        0.011357000147396927`}, {-3.298584434427041, 0.9817953382758093, 
        0.02271400029479385}}], 
       Polygon3DBox[{{-3.1492922172135205`, 0.9908976691379047, 
        0.011357000147396927`}, {-3.1492922172135205`, 0.9908976691379047, 
        0.01135700014739693}, {-3., 1., 1.007793975613102*^-17}, {-3., 1., 
        1.67207105325678*^-18}, {-3.1492922172135205`, 0.9908976691379047, 
        0.011357000147396927`}}], 
       Polygon3DBox[{{-3., 1., 1.67207105325678*^-18}, {-3., 1., 
        1.67207105325678*^-18}, {-2.8507077827864795`, 
        1.0091023308620954`, -0.011357000147396918`}, {-2.8507077827864795`, 
        1.0091023308620954`, -0.011357000147396918`}, {-3., 1., 
        1.67207105325678*^-18}}], 
       Polygon3DBox[{{-2.8507077827864795`, 
        1.0091023308620954`, -0.011357000147396918`}, {-2.8507077827864795`, 
        1.0091023308620954`, -0.011357000147396918`}, {-2.701415565572959, 
        1.0182046617241907`, -0.02271400029479384}, {-2.701415565572959, 
        1.0182046617241907`, -0.02271400029479384}, {-2.8507077827864795`, 
        1.0091023308620954`, -0.011357000147396918`}}], 
       Polygon3DBox[{{-2.701415565572959, 
        1.0182046617241907`, -0.02271400029479384}, {-2.701415565572959, 
        1.0182046617241907`, -0.02271400029479384}, {-2.5521233483594385`, 
        1.0273069925862859`, -0.03407100044219077}, {-2.5521233483594385`, 
        1.027306992586286, -0.03407100044219076}, {-2.701415565572959, 
        1.0182046617241907`, -0.02271400029479384}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff2p308BA8WLrSftzrd
piGZ68ChgBV897Le2+/evfVgmNN0+/NXjeUOGHIeSNQIYc/fChNvt2cAA44D
EPqDfYHMoW+fEoNtDLXOPLQ/x3bg/OvQGg/VD/Y7IOr3J4XMOFw/h/XA/Our
f0zw+mC/E2L+/sl1KUv3Z7EcyDvMWHoz/4P9KYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnAC3nqdM=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.4226114232035196`, 0.5242334257478558, 
      0.006764007855904815}, {-3.4731418800776033`, 1.4211525890795724`, 
      0.06137799302847672}, {-2.5773885767964804`, 
      1.4757665742521442`, -0.006764007855904815}, {-2.5268581199223967`, 
      0.5788474109204276, -0.06137799302847672}, {-3.4226114232035196`, 
      0.5242334257478558, 0.006764007855904815}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.4226114232035196`, 0.5242334257478558, 
       0.006764007855904815}, {-3.4731418800776033`, 1.4211525890795724`, 
       0.06137799302847672}, {-2.5773885767964804`, 
       1.4757665742521442`, -0.006764007855904815}, {-2.5268581199223967`, 
       0.5788474109204276, -0.06137799302847672}, {-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.9497865864441937`, 
      1.5560634108603033`, -0.05384160029276379}, {-2.9497865864441932`, 
      1.5560634108603033`, -0.053841600292763796`}, {-2.9665243909627956`, 
      1.704042273906869, -0.03589440019517587}, {-2.9665243909627956`, 
      1.7040422739068688`, -0.03589440019517587}, {-2.9497865864441937`, 
      1.5560634108603033`, -0.05384160029276379}}], 
     Polygon3DBox[{{-2.9665243909627956`, 
      1.7040422739068688`, -0.03589440019517587}, {-2.9665243909627956`, 
      1.704042273906869, -0.03589440019517587}, {-2.9832621954813976`, 
      1.8520211369534343`, -0.01794720009758794}, {-2.983262195481398, 
      1.8520211369534345`, -0.017947200097587934`}, {-2.9665243909627956`, 
      1.7040422739068688`, -0.03589440019517587}}], 
     Polygon3DBox[{{-2.983262195481398, 
      1.8520211369534345`, -0.017947200097587934`}, {-2.9832621954813976`, 
      1.8520211369534343`, -0.01794720009758794}, {-3., 
      2., -1.6724878053135065`*^-17}, {-3., 2., 0.}, {-2.983262195481398, 
      1.8520211369534345`, -0.017947200097587934`}}], 
     Polygon3DBox[{{-3., 2., 0.}, {-3., 
      2., -3.441281535870412*^-18}, {-3.016737804518602, 2.1479788630465655`, 
      0.017947200097587924`}, {-3.016737804518602, 2.1479788630465655`, 
      0.017947200097587927`}, {-3., 2., 0.}}], 
     Polygon3DBox[{{-3.016737804518602, 2.1479788630465655`, 
      0.017947200097587927`}, {-3.016737804518602, 2.1479788630465655`, 
      0.017947200097587924`}, {-3.0334756090372044`, 2.295957726093131, 
      0.035894400195175855`}, {-3.0334756090372044`, 2.295957726093131, 
      0.03589440019517586}, {-3.016737804518602, 2.1479788630465655`, 
      0.017947200097587927`}}], 
     Polygon3DBox[{{-3.0334756090372044`, 2.295957726093131, 
      0.03589440019517586}, {-3.0334756090372044`, 2.295957726093131, 
      0.035894400195175855`}, {-3.0502134135558063`, 2.4439365891396965`, 
      0.05384160029276378}, {-3.0502134135558063`, 2.4439365891396965`, 
      0.053841600292763775`}, {-3.0334756090372044`, 2.295957726093131, 
      0.03589440019517586}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG5fsX2r5kz2A3+jnPYvevrD3u3N9QCFiav3rz96
XrlwN/uB4OfXrhx0/m1v4PHU9EDCov03Hj2fuOMu+4FVxdmvHiz8CxWftJ8B
DDgOQGgGB7+Ky5EOC+P2aMhK5LkrcRzQdjvVxa/P6KAHUW8faGVwp8+F40BY
zxRR+TgmB32I+faV4R5e19I4DjReilug18vs4AJxD4Y41J0Y5kDdaY9uL9Sd
9jjcaYPuL6g74eEQAg0HqDv3w8LtHzTcoO7cjys8Aa+lo7o=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4458827884659806`, 1.9461583997072363`, 
        0.028100196222015737`}, {-3.4458827884659806`, 1.9461583997072363`, 
        0.028100196222015743`}, {-3.297255192310654, 1.9641055998048242`, 
        0.018733464148010495`}, {-3.297255192310654, 1.9641055998048242`, 
        0.01873346414801049}, {-3.4458827884659806`, 1.9461583997072363`, 
        0.028100196222015737`}}], 
       Polygon3DBox[{{-3.297255192310654, 1.9641055998048242`, 
        0.01873346414801049}, {-3.297255192310654, 1.9641055998048242`, 
        0.018733464148010495`}, {-3.148627596155327, 1.982052799902412, 
        0.009366732074005254}, {-3.1486275961553267`, 1.982052799902412, 
        0.009366732074005247}, {-3.297255192310654, 1.9641055998048242`, 
        0.01873346414801049}}], 
       Polygon3DBox[{{-3.1486275961553267`, 1.982052799902412, 
        0.009366732074005247}, {-3.148627596155327, 1.982052799902412, 
        0.009366732074005254}, {-3., 2., 1.0229621582345598`*^-17}, {-3., 2., 
        3.2968471729752188`*^-18}, {-3.1486275961553267`, 1.982052799902412, 
        0.009366732074005247}}], 
       Polygon3DBox[{{-3., 2., 3.2968471729752188`*^-18}, {-3., 2., 
        3.2968471729752188`*^-18}, {-2.8513724038446733`, 
        2.0179472000975878`, -0.00936673207400524}, {-2.8513724038446733`, 
        2.0179472000975878`, -0.009366732074005237}, {-3., 2., 
        3.2968471729752188`*^-18}}], 
       Polygon3DBox[{{-2.8513724038446733`, 
        2.0179472000975878`, -0.009366732074005237}, {-2.8513724038446733`, 
        2.0179472000975878`, -0.00936673207400524}, {-2.702744807689346, 
        2.035894400195176, -0.018733464148010484`}, {-2.702744807689346, 
        2.035894400195176, -0.01873346414801048}, {-2.8513724038446733`, 
        2.0179472000975878`, -0.009366732074005237}}], 
       Polygon3DBox[{{-2.702744807689346, 
        2.035894400195176, -0.01873346414801048}, {-2.702744807689346, 
        2.035894400195176, -0.018733464148010484`}, {-2.5541172115340194`, 
        2.0538416002927637`, -0.028100196222015733`}, {-2.5541172115340194`, 
        2.0538416002927637`, -0.028100196222015723`}, {-2.702744807689346, 
        2.035894400195176, -0.01873346414801048}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/b/5ykbO9zbI799aCe
kOMJXAf2XQ349zPnv/0yntz6u3qT7bM13VYlG3AeuJ+l8b9mG0y82Z4BDDgO
QGgGBxFR7vpjP/xtpl7bGTrnPNuBCaeyGw6qMDgsgajfr7m2eLXFfNYDilOv
MzR7MjgshZi/f1+zLuPVPJYDG+OdG13yGBy+Q9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHfCw2E/NByg7rRHDzeoOzHEYeEJAPaYoEI=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.3956693749101743`, 
      1.5022218105675396`, -0.025741404070748052`}, {-3.496096202021787, 
      2.3900949888469327`, 0.08194179651477952}, {-2.6043306250898257`, 
      2.49777818943246, 0.025741404070748052`}, {-2.503903797978213, 
      1.6099050111530673`, -0.08194179651477952}, {-3.3956693749101743`, 
      1.5022218105675396`, -0.025741404070748052`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}, {-3.496096202021787, 
       2.3900949888469327`, 0.08194179651477952}, {-2.6043306250898257`, 
       2.49777818943246, 0.025741404070748052`}, {-2.503903797978213, 
       1.6099050111530673`, -0.08194179651477952}, {-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.9254525215742477`, 
      2.5632891915085017`, -0.07890718096006065}, {-2.9254525215742477`, 
      2.5632891915085017`, -0.07890718096006065}, {-2.9503016810494986`, 
      2.7088594610056678`, -0.052604787306707104`}, {-2.9503016810494986`, 
      2.7088594610056678`, -0.052604787306707104`}, {-2.9254525215742477`, 
      2.5632891915085017`, -0.07890718096006065}}], 
     Polygon3DBox[{{-2.9503016810494986`, 
      2.7088594610056678`, -0.052604787306707104`}, {-2.9503016810494986`, 
      2.7088594610056678`, -0.052604787306707104`}, {-2.975150840524749, 
      2.854429730502834, -0.026302393653353566`}, {-2.975150840524749, 
      2.854429730502834, -0.026302393653353552`}, {-2.9503016810494986`, 
      2.7088594610056678`, -0.052604787306707104`}}], 
     Polygon3DBox[{{-2.975150840524749, 
      2.854429730502834, -0.026302393653353552`}, {-2.975150840524749, 
      2.854429730502834, -0.026302393653353566`}, {-3., 
      3., -2.1736568351126376`*^-17}, {-3., 3., 0.}, {-2.975150840524749, 
      2.854429730502834, -0.026302393653353552`}}], 
     Polygon3DBox[{{-3., 3., 0.}, {-3., 
      3., -2.268886326654577*^-18}, {-3.024849159475251, 3.145570269497166, 
      0.026302393653353545`}, {-3.024849159475251, 3.145570269497166, 
      0.026302393653353545`}, {-3., 3., 0.}}], 
     Polygon3DBox[{{-3.024849159475251, 3.145570269497166, 
      0.026302393653353545`}, {-3.024849159475251, 3.145570269497166, 
      0.026302393653353545`}, {-3.0496983189505014`, 3.2911405389943322`, 
      0.05260478730670709}, {-3.0496983189505014`, 3.2911405389943322`, 
      0.0526047873067071}, {-3.024849159475251, 3.145570269497166, 
      0.026302393653353545`}}], 
     Polygon3DBox[{{-3.0496983189505014`, 3.2911405389943322`, 
      0.0526047873067071}, {-3.0496983189505014`, 3.2911405389943322`, 
      0.05260478730670709}, {-3.0745474784257523`, 3.4367108084914983`, 
      0.07890718096006064}, {-3.0745474784257523`, 3.4367108084914983`, 
      0.07890718096006064}, {-3.0496983189505014`, 3.2911405389943322`, 
      0.0526047873067071}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIObyubgsOJ39gNzB2sNzG1kcps9ZctHJeMt+9o7u
I+az2A+IXAtu2rea1eHUBYNDzO9X7Wc+4vpI+iz7Aa7Xmo73r7JBxWftZwAD
jgNQ2uHvWo3yG4Vpe/5a75J9YsRx4JvItX0KWpwOJyDq7X+Wl1ifSOU48EZz
Ta1jCJfDSYj59t8260WumcFx4JFdk01SHbfDNIh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+5HDzeoOzHEYeEJAHHOos0=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4426402739770836`, 2.9210928190399392`, 
        0.018526862832894054`}, {-3.4426402739770836`, 2.9210928190399392`, 
        0.018526862832894064`}, {-3.295093515984722, 2.947395212693293, 
        0.012351241888596045`}, {-3.295093515984722, 2.947395212693293, 
        0.01235124188859604}, {-3.4426402739770836`, 2.9210928190399392`, 
        0.018526862832894054`}}], 
       Polygon3DBox[{{-3.295093515984722, 2.947395212693293, 
        0.01235124188859604}, {-3.295093515984722, 2.947395212693293, 
        0.012351241888596045`}, {-3.147546757992361, 2.9736976063466463`, 
        0.0061756209442980275`}, {-3.147546757992361, 2.9736976063466463`, 
        0.006175620944298022}, {-3.295093515984722, 2.947395212693293, 
        0.01235124188859604}}], 
       Polygon3DBox[{{-3.147546757992361, 2.9736976063466463`, 
        0.006175620944298022}, {-3.147546757992361, 2.9736976063466463`, 
        0.0061756209442980275`}, {-3., 3., 9.402549038768638*^-18}, {-3., 3., 
        4.831671329623962*^-18}, {-3.147546757992361, 2.9736976063466463`, 
        0.006175620944298022}}], 
       Polygon3DBox[{{-3., 3., 4.831671329623962*^-18}, {-3., 3., 
        4.831671329623962*^-18}, {-2.852453242007639, 
        3.0263023936533537`, -0.006175620944298013}, {-2.852453242007639, 
        3.0263023936533537`, -0.00617562094429801}, {-3., 3., 
        4.831671329623962*^-18}}], 
       Polygon3DBox[{{-2.852453242007639, 
        3.0263023936533537`, -0.00617562094429801}, {-2.852453242007639, 
        3.0263023936533537`, -0.006175620944298013}, {-2.704906484015278, 
        3.052604787306707, -0.01235124188859603}, {-2.704906484015278, 
        3.052604787306707, -0.012351241888596027`}, {-2.852453242007639, 
        3.0263023936533537`, -0.00617562094429801}}], 
       Polygon3DBox[{{-2.704906484015278, 
        3.052604787306707, -0.012351241888596027`}, {-2.704906484015278, 
        3.052604787306707, -0.01235124188859603}, {-2.557359726022917, 
        3.0789071809600608`, -0.01852686283289405}, {-2.557359726022917, 
        3.0789071809600608`, -0.01852686283289404}, {-2.704906484015278, 
        3.052604787306707, -0.012351241888596027`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gdal/e3r7lxyR7rhDn
v5ExXAf22nz/4DyF3eHvw/PzZ3t32rOuWvhPR4/zQNy86h+Kp2DilfYMYMBx
AEo7BNnosoaLuNr8Do1jvHyR7cCixBb2e6YcDr8g6vd/W72Hadli1gPOhzn4
92RzOPyBmL//I6M0S2Upy4GnKr1isxZyONRA3LP/A5o41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfa86OFG9Sd9rjCEwD/Rqog
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.3680927955513313`, 
      2.484382010548441, -0.0603803181271666}, {-3.517187752402836, 
      3.357803627531438, 0.0974340437929547}, {-2.6319072044486687`, 
      3.515617989451559, 0.0603803181271666}, {-2.482812247597164, 
      2.642196372468562, -0.0974340437929547}, {-3.3680927955513313`, 
      2.484382010548441, -0.0603803181271666}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}, {-3.517187752402836, 
       3.357803627531438, 0.0974340437929547}, {-2.6319072044486687`, 
       3.515617989451559, 0.0603803181271666}, {-2.482812247597164, 
       2.642196372468562, -0.0974340437929547}, {-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.901992537290773, 
      3.5727974142006254`, -0.10194355271240892`}, {-2.901992537290773, 
      3.5727974142006254`, -0.10194355271240892`}, {-2.934661691527182, 
      3.7151982761337505`, -0.06796236847493928}, {-2.934661691527182, 
      3.7151982761337505`, -0.06796236847493929}, {-2.901992537290773, 
      3.5727974142006254`, -0.10194355271240892`}}], 
     Polygon3DBox[{{-2.934661691527182, 
      3.7151982761337505`, -0.06796236847493929}, {-2.934661691527182, 
      3.7151982761337505`, -0.06796236847493928}, {-2.9673308457635907`, 
      3.8575991380668753`, -0.03398118423746965}, {-2.967330845763591, 
      3.8575991380668753`, -0.033981184237469646`}, {-2.934661691527182, 
      3.7151982761337505`, -0.06796236847493929}}], 
     Polygon3DBox[{{-2.967330845763591, 
      3.8575991380668753`, -0.033981184237469646`}, {-2.9673308457635907`, 
      3.8575991380668753`, -0.03398118423746965}, {-3., 
      4., -2.5869087127324183`*^-17}, {-3., 4., 0.}, {-2.967330845763591, 
      3.8575991380668753`, -0.033981184237469646`}}], 
     Polygon3DBox[{{-3., 4., 0.}, {-3., 
      4., -7.179583643453604*^-19}, {-3.032669154236409, 4.142400861933125, 
      0.03398118423746963}, {-3.032669154236409, 4.142400861933125, 
      0.03398118423746963}, {-3., 4., 0.}}], 
     Polygon3DBox[{{-3.032669154236409, 4.142400861933125, 
      0.03398118423746963}, {-3.032669154236409, 4.142400861933125, 
      0.03398118423746963}, {-3.065338308472818, 4.2848017238662495`, 
      0.06796236847493926}, {-3.065338308472818, 4.2848017238662495`, 
      0.06796236847493928}, {-3.032669154236409, 4.142400861933125, 
      0.03398118423746963}}], 
     Polygon3DBox[{{-3.065338308472818, 4.2848017238662495`, 
      0.06796236847493928}, {-3.065338308472818, 4.2848017238662495`, 
      0.06796236847493926}, {-3.098007462709227, 4.427202585799375, 
      0.1019435527124089}, {-3.098007462709227, 4.427202585799375, 
      0.10194355271240889`}, {-3.065338308472818, 4.2848017238662495`, 
      0.06796236847493928}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmEG3MftfdnP3AizOd58Wm8jhcFfvA8FNi1/748vUv
9KvYD7gZb7y/cwevQ3/K19DfqRv3b9gd/kV8L/uBxTNvvI+5wwcVX7ifAQw4
DkBoAYfpy537ff/n7AlwWcH9wonjgP5m4Y6LEwUceiHq7Rd2BIhfaOU4EJum
LrBYWdChD2K+/cczP5R2nOA40CNpPaNkq6DDZYh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+6HhdtLaLhB3bkfV3gCANZ+pEI=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4382614998780574`, 3.898056447287591, 
        0.005862574946876364}, {-3.4382614998780574`, 3.898056447287591, 
        0.0058625749468763765`}, {-3.2921743332520386`, 3.932037631525061, 
        0.003908383297917586}, {-3.2921743332520386`, 3.932037631525061, 
        0.003908383297917578}, {-3.4382614998780574`, 3.898056447287591, 
        0.005862574946876364}}], 
       Polygon3DBox[{{-3.2921743332520386`, 3.932037631525061, 
        0.003908383297917578}, {-3.2921743332520386`, 3.932037631525061, 
        0.003908383297917586}, {-3.1460871666260193`, 3.9660188157625305`, 
        0.0019541916489587974`}, {-3.1460871666260193`, 3.9660188157625305`, 
        0.0019541916489587926`}, {-3.2921743332520386`, 3.932037631525061, 
        0.003908383297917578}}], 
       Polygon3DBox[{{-3.1460871666260193`, 3.9660188157625305`, 
        0.0019541916489587926`}, {-3.1460871666260193`, 3.9660188157625305`, 
        0.0019541916489587974`}, {-3., 4., 7.688634651617553*^-18}, {-3., 4., 
        6.242242276148053*^-18}, {-3.1460871666260193`, 3.9660188157625305`, 
        0.0019541916489587926`}}], 
       Polygon3DBox[{{-3., 4., 6.242242276148053*^-18}, {-3., 4., 
        6.242242276148053*^-18}, {-2.8539128333739807`, 
        4.0339811842374695`, -0.001954191648958783}, {-2.8539128333739807`, 
        4.0339811842374695`, -0.001954191648958779}, {-3., 4., 
        6.242242276148053*^-18}}], 
       Polygon3DBox[{{-2.8539128333739807`, 
        4.0339811842374695`, -0.001954191648958779}, {-2.8539128333739807`, 
        4.0339811842374695`, -0.001954191648958783}, {-2.707825666747962, 
        4.067962368474939, -0.003908383297917573}, {-2.7078256667479614`, 
        4.067962368474939, -0.003908383297917565}, {-2.8539128333739807`, 
        4.0339811842374695`, -0.001954191648958779}}], 
       Polygon3DBox[{{-2.7078256667479614`, 
        4.067962368474939, -0.003908383297917565}, {-2.707825666747962, 
        4.067962368474939, -0.003908383297917573}, {-2.5617385001219426`, 
        4.101943552712409, -0.0058625749468763635`}, {-2.5617385001219426`, 
        4.101943552712409, -0.0058625749468763505`}, {-2.7078256667479614`, 
        4.067962368474939, -0.003908383297917565}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwODCfW/IpirrDvSDKo
jw/jOnAnJED1Qgm/w+pbssttmArsXQxn7NfX5jyQp7VCKGMXTDzBngEMOA5A
aAEHGfF2sdR1WjZ7zqU7XLjCduDkq9XfTisJOKyEqN9fMfd8w4KVrAcmXQ1/
O91VwGEVxPz9pjnmBwvqWA5EH2B+kpwh4PDvONg9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITALpElXA=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.3402540371688305`, 
      3.4708538614882167`, -0.09608097776553255}, {-3.5362689625872843`, 
      4.325259033086965, 0.10780612765928528`}, {-2.6597459628311695`, 
      4.529146138511783, 0.09608097776553255}, {-2.4637310374127157`, 
      3.6747409669130344`, -0.10780612765928528`}, {-3.3402540371688305`, 
      3.4708538614882167`, -0.09608097776553255}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}, {-3.5362689625872843`, 
       4.325259033086965, 0.10780612765928528`}, {-2.6597459628311695`, 
       4.529146138511783, 0.09608097776553255}, {-2.4637310374127157`, 
       3.6747409669130344`, -0.10780612765928528`}, {-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.8796172746543727`, 
      4.584083630874239, -0.12256252825232783`}, {-2.8796172746543727`, 
      4.584083630874239, -0.12256252825232783`}, {-2.919744849769582, 
      4.7227224205828255`, -0.08170835216821855}, {-2.919744849769582, 
      4.7227224205828255`, -0.08170835216821856}, {-2.8796172746543727`, 
      4.584083630874239, -0.12256252825232783`}}], 
     Polygon3DBox[{{-2.919744849769582, 
      4.7227224205828255`, -0.08170835216821856}, {-2.919744849769582, 
      4.7227224205828255`, -0.08170835216821855}, {-2.9598724248847907`, 
      4.861361210291413, -0.040854176084109295`}, {-2.9598724248847907`, 
      4.861361210291413, -0.04085417608410928}, {-2.919744849769582, 
      4.7227224205828255`, -0.08170835216821856}}], 
     Polygon3DBox[{{-2.9598724248847907`, 
      4.861361210291413, -0.04085417608410928}, {-2.9598724248847907`, 
      4.861361210291413, -0.040854176084109295`}, {-3., 
      5., -2.9102538681687055`*^-17}, {-3., 5., 0.}, {-2.9598724248847907`, 
      4.861361210291413, -0.04085417608410928}}], 
     Polygon3DBox[{{-3., 5., 0.}, {-3., 5., 
      1.1356259454253022`*^-18}, {-3.040127575115209, 5.138638789708587, 
      0.04085417608410927}, {-3.0401275751152093`, 5.138638789708587, 
      0.04085417608410927}, {-3., 5., 0.}}], 
     Polygon3DBox[{{-3.0401275751152093`, 5.138638789708587, 
      0.04085417608410927}, {-3.040127575115209, 5.138638789708587, 
      0.04085417608410927}, {-3.080255150230418, 5.2772775794171745`, 
      0.08170835216821853}, {-3.080255150230418, 5.2772775794171745`, 
      0.08170835216821855}, {-3.0401275751152093`, 5.138638789708587, 
      0.04085417608410927}}], 
     Polygon3DBox[{{-3.080255150230418, 5.2772775794171745`, 
      0.08170835216821855}, {-3.080255150230418, 5.2772775794171745`, 
      0.08170835216821853}, {-3.1203827253456273`, 5.415916369125761, 
      0.12256252825232782`}, {-3.1203827253456273`, 5.415916369125761, 
      0.1225625282523278}, {-3.080255150230418, 5.2772775794171745`, 
      0.08170835216821855}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4kIXuihJP9QPr7TyxSYUIOEvz9TE4J+/d/TxU2
WBzNfuD9l4URgk+EHNLi49dce7Vl/+9NnDMurmU/UPErYA1HkTBUfMl+BjDg
OAChRRzqzy/pj80r3MPq+y1dL4jjQAfr+uDvvSIOKRD19pyz3pyPWcJxQJA7
bvk7aVGHVIj59nzPH5l3f+M4MFOA9/fTlaIOYhD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAA9Zmrc=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-3.4328884804176623`, 
        4.8774374717476725`, -0.009273089565219696}, {-3.4328884804176623`, 
        4.8774374717476725`, -0.00927308956521968}, {-3.2885923202784415`, 
        4.918291647831781, -0.006182059710146451}, {-3.2885923202784415`, 
        4.918291647831781, -0.006182059710146462}, {-3.4328884804176623`, 
        4.8774374717476725`, -0.009273089565219696}}], 
       Polygon3DBox[{{-3.2885923202784415`, 
        4.918291647831781, -0.006182059710146462}, {-3.2885923202784415`, 
        4.918291647831781, -0.006182059710146451}, {-3.1442961601392208`, 
        4.9591458239158905`, -0.003091029855073223}, {-3.1442961601392208`, 
        4.9591458239158905`, -0.003091029855073227}, {-3.2885923202784415`, 
        4.918291647831781, -0.006182059710146462}}], 
       Polygon3DBox[{{-3.1442961601392208`, 
        4.9591458239158905`, -0.003091029855073227}, {-3.1442961601392208`, 
        4.9591458239158905`, -0.003091029855073223}, {-3., 5., 
        5.216968719376976*^-18}, {-3., 5., 
        7.504790395981016*^-18}, {-3.1442961601392208`, 
        4.9591458239158905`, -0.003091029855073227}}], 
       Polygon3DBox[{{-3., 5., 7.504790395981016*^-18}, {-3., 5., 
        7.504790395981016*^-18}, {-2.8557038398607792`, 5.0408541760841095`, 
        0.003091029855073236}, {-2.8557038398607792`, 5.0408541760841095`, 
        0.003091029855073241}, {-3., 5., 7.504790395981016*^-18}}], 
       Polygon3DBox[{{-2.8557038398607792`, 5.0408541760841095`, 
        0.003091029855073241}, {-2.8557038398607792`, 5.0408541760841095`, 
        0.003091029855073236}, {-2.7114076797215585`, 5.081708352168219, 
        0.006182059710146464}, {-2.7114076797215585`, 5.081708352168219, 
        0.006182059710146476}, {-2.8557038398607792`, 5.0408541760841095`, 
        0.003091029855073241}}], 
       Polygon3DBox[{{-2.7114076797215585`, 5.081708352168219, 
        0.006182059710146476}, {-2.7114076797215585`, 5.081708352168219, 
        0.006182059710146464}, {-2.5671115195823377`, 5.1225625282523275`, 
        0.009273089565219694}, {-2.5671115195823377`, 5.1225625282523275`, 
        0.009273089565219708}, {-2.7114076797215585`, 5.081708352168219, 
        0.006182059710146476}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQdQj4EMR/927Sf5UR3
Lac/14GmJr+lIWuEHY5NzWOJCarcz/Tk6L4Wdc4Djo7Lg7SuwcQz9zOAAccB
CC3ioHKJLfK7pOmef9JWjtU32A7s3xex9qqmiMNhiHr7P+YlTd82sB6oq90Y
tTpYxOEoxHz7X8HrDhd2shywseHiaKwVcQiCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAq8phW
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-3.312505755072035, 
      4.46152110262191, -0.13183561781754752`}, {-3.5532712057632896`, 
      5.293353840873434, 0.11328943868710814`}, {-2.687494244927965, 
      5.53847889737809, 0.13183561781754752`}, {-2.4467287942367104`, 
      4.706646159126566, -0.11328943868710814`}, {-3.312505755072035, 
      4.46152110262191, -0.13183561781754752`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}, {-3.5532712057632896`, 
       5.293353840873434, 0.11328943868710814`}, {-2.687494244927965, 
       5.53847889737809, 0.13183561781754752`}, {-2.4467287942367104`, 
       4.706646159126566, -0.11328943868710814`}, {-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.122675395370443, -5.415537047668212, 
      0.12157182809307357`}, {-2.1226753953704427`, -5.415537047668212, 
      0.12157182809307357`}, {-2.0817835969136285`, -5.277024698445475, 
      0.08104788539538237}, {-2.0817835969136285`, -5.277024698445475, 
      0.08104788539538238}, {-2.122675395370443, -5.415537047668212, 
      0.12157182809307357`}}], 
     Polygon3DBox[{{-2.0817835969136285`, -5.277024698445475, 
      0.08104788539538238}, {-2.0817835969136285`, -5.277024698445475, 
      0.08104788539538237}, {-2.0408917984568142`, -5.138512349222737, 
      0.04052394269769121}, {-2.0408917984568142`, -5.138512349222737, 
      0.04052394269769119}, {-2.0817835969136285`, -5.277024698445475, 
      0.08104788539538238}}], 
     Polygon3DBox[{{-2.0408917984568142`, -5.138512349222737, 
      0.04052394269769119}, {-2.0408917984568142`, -5.138512349222737, 
      0.04052394269769121}, {-2., -5., 3.258290325535842*^-17}, {-2., -5., 
      0.}, {-2.0408917984568142`, -5.138512349222737, 0.04052394269769119}}], 
     Polygon3DBox[{{-2., -5., 0.}, {-2., -5., 
      2.5891604343135925`*^-18}, {-1.9591082015431858`, -4.861487650777263, \
-0.040523942697691176`}, {-1.9591082015431858`, -4.861487650777263, \
-0.040523942697691176`}, {-2., -5., 0.}}], 
     Polygon3DBox[{{-1.9591082015431858`, -4.861487650777263, \
-0.040523942697691176`}, {-1.9591082015431858`, -4.861487650777263, \
-0.040523942697691176`}, {-1.9182164030863713`, -4.722975301554525, \
-0.08104788539538235}, {-1.9182164030863713`, -4.722975301554525, \
-0.08104788539538237}, {-1.9591082015431858`, -4.861487650777263, \
-0.040523942697691176`}}], 
     Polygon3DBox[{{-1.9182164030863713`, -4.722975301554525, \
-0.08104788539538237}, {-1.9182164030863713`, -4.722975301554525, \
-0.08104788539538235}, {-1.877324604629557, -4.584462952331788, \
-0.12157182809307356`}, {-1.877324604629557, -4.584462952331788, \
-0.12157182809307353`}, {-1.9182164030863713`, -4.722975301554525, \
-0.08104788539538237}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ4gd9PG9jfDgcXcFt1NK0UPHAo8djFEfr891/4J
GnXLGQ4cYr8Qs0Za9IDOQ72Hvfu32LfGe4jsD2Y48JA5Q+9arwhUfIk9AwQc
gFAiB/zT/kzw9iq0+eaQf70x4v9++T/TL2oWCR/Qgqjf/7rx3jrmjf/22/3Q
Xxz8ROiANsT8/Q8P+ba1cv7bH/vleEltmNCB/RD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdad9P1q4Qd1pjys8AehjrlY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.4327508547046017`, -4.8784281719069265`, \
-0.021142099388299276`}, {-2.4327508547046017`, -4.8784281719069265`, \
-0.02114209938829929}, {-2.288500569803068, -4.918952114604617, \
-0.014094732925532863`}, {-2.288500569803068, -4.918952114604617, \
-0.014094732925532854`}, {-2.4327508547046017`, -4.8784281719069265`, \
-0.021142099388299276`}}], 
       Polygon3DBox[{{-2.288500569803068, -4.918952114604617, \
-0.014094732925532854`}, {-2.288500569803068, -4.918952114604617, \
-0.014094732925532863`}, {-2.144250284901534, -4.959476057302309, \
-0.007047366462766438}, {-2.144250284901534, -4.959476057302309, \
-0.007047366462766431}, {-2.288500569803068, -4.918952114604617, \
-0.014094732925532854`}}], 
       Polygon3DBox[{{-2.144250284901534, -4.959476057302309, \
-0.007047366462766431}, {-2.144250284901534, -4.959476057302309, \
-0.007047366462766438}, {-2., -5., -1.2660226513656697`*^-17}, {-2., -5., \
-7.444127507033741*^-18}, {-2.144250284901534, -4.959476057302309, \
-0.007047366462766431}}], 
       Polygon3DBox[{{-2., -5., -7.444127507033741*^-18}, {-2., -5., \
-7.444127507033741*^-18}, {-1.855749715098466, -5.040523942697691, 
        0.007047366462766418}, {-1.855749715098466, -5.040523942697691, 
        0.007047366462766414}, {-2., -5., -7.444127507033741*^-18}}], 
       Polygon3DBox[{{-1.855749715098466, -5.040523942697691, 
        0.007047366462766414}, {-1.855749715098466, -5.040523942697691, 
        0.007047366462766418}, {-1.7114994301969322`, -5.081047885395383, 
        0.014094732925532845`}, {-1.7114994301969322`, -5.081047885395383, 
        0.014094732925532838`}, {-1.855749715098466, -5.040523942697691, 
        0.007047366462766414}}], 
       Polygon3DBox[{{-1.7114994301969322`, -5.081047885395383, 
        0.014094732925532838`}, {-1.7114994301969322`, -5.081047885395383, 
        0.014094732925532845`}, {-1.567249145295398, -5.1215718280930735`, 
        0.021142099388299272`}, {-1.5672491452953983`, -5.1215718280930735`, 
        0.02114209938829926}, {-1.7114994301969322`, -5.081047885395383, 
        0.014094732925532838`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUPLJc/4uq2bOr+M8WM
yTf9mA5Uu1SfYFwrfMBUawP75rs9+5/tbNiYo854wG6R7ZOGazDxmv0MEHAA
QokcuHZWyFCUz2OPSc+/OWob/+4/FHtIul5T5IARRL19hsRfS9+k3/tbd7eY
/wsSOWACMd9+zpLf14qFf+53l3QPrq0RObAM4h772WjiUHfap6OZA3WnPbq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAEkooqA=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.555426250075045, -5.2939652195751385`, 
      0.10042972870477429`}, {-2.310075459334159, -4.462891124238714, \
-0.14271392748137285`}, {-1.4445737499249551`, -4.7060347804248615`, \
-0.10042972870477429`}, {-1.689924540665841, -5.537108875761286, 
      0.14271392748137285`}, {-2.555426250075045, -5.2939652195751385`, 
      0.10042972870477429`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}, {-2.310075459334159, -4.462891124238714, \
-0.14271392748137285`}, {-1.4445737499249551`, -4.7060347804248615`, \
-0.10042972870477429`}, {-1.689924540665841, -5.537108875761286, 
       0.14271392748137285`}, {-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.099984579182302, -4.426897555491506, 
      0.10129936347832735`}, {-2.099984579182302, -4.426897555491506, 
      0.10129936347832735`}, {-2.066656386121535, -4.284598370327671, 
      0.06753290898555156}, {-2.066656386121535, -4.284598370327671, 
      0.06753290898555157}, {-2.099984579182302, -4.426897555491506, 
      0.10129936347832735`}}], 
     Polygon3DBox[{{-2.066656386121535, -4.284598370327671, 
      0.06753290898555157}, {-2.066656386121535, -4.284598370327671, 
      0.06753290898555156}, {-2.0333281930607674`, -4.142299185163836, 
      0.0337664544927758}, {-2.0333281930607674`, -4.142299185163836, 
      0.03376645449277579}, {-2.066656386121535, -4.284598370327671, 
      0.06753290898555157}}], 
     Polygon3DBox[{{-2.0333281930607674`, -4.142299185163836, 
      0.03376645449277579}, {-2.0333281930607674`, -4.142299185163836, 
      0.0337664544927758}, {-2., -4., 2.570537997169414*^-17}, {-2., -4., 
      0.}, {-2.0333281930607674`, -4.142299185163836, 0.03376645449277579}}], 
     Polygon3DBox[{{-2., -4., 0.}, {-2., -4., 
      7.131831464693154*^-19}, {-1.9666718069392326`, -3.8577008148361647`, \
-0.03376645449277577}, {-1.9666718069392326`, -3.8577008148361647`, \
-0.03376645449277577}, {-2., -4., 0.}}], 
     Polygon3DBox[{{-1.9666718069392326`, -3.8577008148361647`, \
-0.03376645449277577}, {-1.9666718069392326`, -3.8577008148361647`, \
-0.03376645449277577}, {-1.9333436138784652`, -3.7154016296723293`, \
-0.06753290898555155}, {-1.9333436138784652`, -3.7154016296723293`, \
-0.06753290898555156}, {-1.9666718069392326`, -3.8577008148361647`, \
-0.03376645449277577}}], 
     Polygon3DBox[{{-1.9333436138784652`, -3.7154016296723293`, \
-0.06753290898555156}, {-1.9333436138784652`, -3.7154016296723293`, \
-0.06753290898555155}, {-1.9000154208176978`, -3.573102444508494, \
-0.10129936347832734`}, {-1.9000154208176978`, -3.573102444508494, \
-0.10129936347832733`}, {-1.9333436138784652`, -3.7154016296723293`, \
-0.06753290898555156}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Vybv9yBmGA/YB/xaqbBU8ULHLzvfgu532Nhs3
qzR3MByoNw05mKsseOC3Wr3xNc+N9vNuRE5ydGE4cEBq1YNtEwWg4gvtGSDg
AIQSOOAzrY4h9UKOzRE/n9s15f/3N55abTfpDt+BnxD1+zvmztj2892//UxT
w2tVdvIe+AUxf7/PmycTy9L+7W+OZ96zbSrPgTKIe+DiTVBxqDsxzIG6cz+6
vVB37sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBS1bE6
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.438411364870582, -3.8987006365216725`, \
-0.00582358233382769}, {-2.438411364870582, -3.8987006365216725`, \
-0.005823582333827702}, {-2.292274243247055, -3.9324670910144484`, \
-0.003882388222551804}, {-2.292274243247055, -3.9324670910144484`, \
-0.003882388222551796}, {-2.438411364870582, -3.8987006365216725`, \
-0.00582358233382769}}], 
       Polygon3DBox[{{-2.292274243247055, -3.9324670910144484`, \
-0.003882388222551796}, {-2.292274243247055, -3.9324670910144484`, \
-0.003882388222551804}, {-2.1461371216235277`, -3.966233545507224, \
-0.001941194111275906}, {-2.1461371216235277`, -3.966233545507224, \
-0.001941194111275901}, {-2.292274243247055, -3.9324670910144484`, \
-0.003882388222551796}}], 
       Polygon3DBox[{{-2.1461371216235277`, -3.966233545507224, \
-0.001941194111275901}, {-2.1461371216235277`, -3.966233545507224, \
-0.001941194111275906}, {-2., -4., -7.639569327040075*^-18}, {-2., -4., \
-6.202797061969894*^-18}, {-2.1461371216235277`, -3.966233545507224, \
-0.001941194111275901}}], 
       Polygon3DBox[{{-2., -4., -6.202797061969894*^-18}, {-2., -4., \
-6.202797061969894*^-18}, {-1.8538628783764726`, -4.033766454492776, 
        0.0019411941112758922`}, {-1.8538628783764726`, -4.033766454492776, 
        0.001941194111275888}, {-2., -4., -6.202797061969894*^-18}}], 
       Polygon3DBox[{{-1.8538628783764726`, -4.033766454492776, 
        0.001941194111275888}, {-1.8538628783764726`, -4.033766454492776, 
        0.0019411941112758922`}, {-1.7077257567529451`, -4.067532908985552, 
        0.0038823882225517904`}, {-1.7077257567529451`, -4.067532908985552, 
        0.003882388222551783}, {-1.8538628783764726`, -4.033766454492776, 
        0.001941194111275888}}], 
       Polygon3DBox[{{-1.7077257567529451`, -4.067532908985552, 
        0.003882388222551783}, {-1.7077257567529451`, -4.067532908985552, 
        0.0038823882225517904`}, {-1.5615886351294177`, -4.1012993634783275`, 
        0.005823582333827689}, {-1.5615886351294177`, -4.1012993634783275`, 
        0.005823582333827677}, {-1.7077257567529451`, -4.067532908985552, 
        0.003882388222551783}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgPnFq99Vf5rfL93Wse
PpgcxnTgBFuK38ZS/gM7+939vp7N3+92reCDpzbjgRRmo+U3dsHE4/czQMAB
CCVw4Mj3CWLfG7T2lAbLyees/Lvf71/amslKAge2QdTbv1pmY3cj6Pf+OX/O
Rqi7ChzYATHfPv5XVKzLnx/7X/0yYd2dLnDgJMQ9GOJQd2KYA3WnPbq9UHfa
43CnjSuav6DuxAgHqDv3o4cb1J0Y4rDwBABBeLcr
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.5383959440528843`, -4.325598192013179, 
      0.09547578114449966}, {-2.3384267856882803`, -3.4718030810301665`, \
-0.10712294581215505`}, {-1.4616040559471155`, -3.674401807986821, \
-0.09547578114449966}, {-1.66157321431172, -4.528196918969834, 
      0.10712294581215505`}, {-2.5383959440528843`, -4.325598192013179, 
      0.09547578114449966}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}, {-2.3384267856882803`, -3.4718030810301665`, \
-0.10712294581215505`}, {-1.4616040559471155`, -3.674401807986821, \
-0.09547578114449966}, {-1.66157321431172, -4.528196918969834, 
       0.10712294581215505`}, {-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.076121685070304, -3.436507564016404, 
      0.07852792890763323}, {-2.076121685070304, -3.436507564016404, 
      0.07852792890763323}, {-2.050747790046869, -3.291005042677603, 
      0.05235195260508881}, {-2.0507477900468696`, -3.291005042677603, 
      0.05235195260508882}, {-2.076121685070304, -3.436507564016404, 
      0.07852792890763323}}], 
     Polygon3DBox[{{-2.0507477900468696`, -3.291005042677603, 
      0.05235195260508882}, {-2.050747790046869, -3.291005042677603, 
      0.05235195260508881}, {-2.0253738950234346`, -3.1455025213388015`, 
      0.02617597630254442}, {-2.0253738950234346`, -3.1455025213388015`, 
      0.02617597630254441}, {-2.0507477900468696`, -3.291005042677603, 
      0.05235195260508882}}], 
     Polygon3DBox[{{-2.0253738950234346`, -3.1455025213388015`, 
      0.02617597630254441}, {-2.0253738950234346`, -3.1455025213388015`, 
      0.02617597630254442}, {-2., -3., 1.8511484920893896`*^-17}, {-2., -3., 
      0.}, {-2.0253738950234346`, -3.1455025213388015`, 
      0.02617597630254441}}], 
     Polygon3DBox[{{-2., -3., 
      0.}, {-2., -3., -8.626294678576207*^-19}, {-1.9746261049765652`, \
-2.8544974786611985`, -0.026175976302544403`}, {-1.9746261049765652`, \
-2.8544974786611985`, -0.026175976302544403`}, {-2., -3., 0.}}], 
     Polygon3DBox[{{-1.9746261049765652`, -2.8544974786611985`, \
-0.026175976302544403`}, {-1.9746261049765652`, -2.8544974786611985`, \
-0.026175976302544403`}, {-1.9492522099531306`, -2.708994957322397, \
-0.052351952605088806`}, {-1.9492522099531306`, -2.708994957322397, \
-0.05235195260508881}, {-1.9746261049765652`, -2.8544974786611985`, \
-0.026175976302544403`}}], 
     Polygon3DBox[{{-1.9492522099531306`, -2.708994957322397, \
-0.05235195260508881}, {-1.9492522099531306`, -2.708994957322397, \
-0.052351952605088806`}, {-1.9238783149296959`, -2.563492435983596, \
-0.07852792890763322}, {-1.9238783149296959`, -2.563492435983596, \
-0.0785279289076332}, {-1.9492522099531306`, -2.708994957322397, \
-0.05235195260508881}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6nOn/909kMB7Y41q/9Xst9QFammi1Daov9/sMi
pe/SGQ6c015V/CuY60CN6hKOB2dX2d9P7LL6bsxw4LnoVcu/mpxQ8Vn2DBBw
AEJxHLCRv7fRKizNxtHmdZfgjP/7JV9pHWO6xnagCqJ+f3PFNVFlg//7ja6E
9rCuYT1QDTF//5EtBxeYnPi332dfQxBHE8sBaYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnANnAoq4=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.443039216995193, -2.9214720710923667`, 
        0.007043904156351177}, {-2.443039216995193, -2.9214720710923667`, 
        0.007043904156351167}, {-2.2953594779967954`, -2.947648047394911, 
        0.0046959361042341104`}, {-2.2953594779967954`, -2.947648047394911, 
        0.004695936104234117}, {-2.443039216995193, -2.9214720710923667`, 
        0.007043904156351177}}], 
       Polygon3DBox[{{-2.2953594779967954`, -2.947648047394911, 
        0.004695936104234117}, {-2.2953594779967954`, -2.947648047394911, 
        0.0046959361042341104`}, {-2.1476797389983977`, -2.9738240236974556`, 
        0.002347968052117054}, {-2.1476797389983977`, -2.9738240236974556`, 
        0.0023479680521170565`}, {-2.2953594779967954`, -2.947648047394911, 
        0.004695936104234117}}], 
       Polygon3DBox[{{-2.1476797389983977`, -2.9738240236974556`, 
        0.0023479680521170565`}, {-2.1476797389983977`, -2.9738240236974556`, 
        0.002347968052117054}, {-2., -3., -3.070603377323772*^-18}, {-2., \
-3., -4.808448839020197*^-18}, {-2.1476797389983977`, -2.9738240236974556`, 
        0.0023479680521170565`}}], 
       Polygon3DBox[{{-2., -3., -4.808448839020197*^-18}, {-2., -3., \
-4.808448839020197*^-18}, {-1.8523202610016023`, -3.0261759763025444`, \
-0.0023479680521170617`}, {-1.8523202610016023`, -3.0261759763025444`, \
-0.002347968052117065}, {-2., -3., -4.808448839020197*^-18}}], 
       Polygon3DBox[{{-1.8523202610016023`, -3.0261759763025444`, \
-0.002347968052117065}, {-1.8523202610016023`, -3.0261759763025444`, \
-0.0023479680521170617`}, {-1.7046405220032046`, -3.052351952605089, \
-0.004695936104234119}, {-1.7046405220032046`, -3.052351952605089, \
-0.004695936104234126}, {-1.8523202610016023`, -3.0261759763025444`, \
-0.002347968052117065}}], 
       Polygon3DBox[{{-1.7046405220032046`, -3.052351952605089, \
-0.004695936104234126}, {-1.7046405220032046`, -3.052351952605089, \
-0.004695936104234119}, {-1.556960783004807, -3.0785279289076333`, \
-0.007043904156351176}, {-1.556960783004807, -3.0785279289076333`, \
-0.007043904156351185}, {-1.7046405220032046`, -3.052351952605089, \
-0.004695936104234126}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewHlk04O1/wVo39nCqR
vKcxTAey8u/Wn5jCfqAg4d5+bptiez9bru1FeowHtm5/Z59yCiaebM8AAQcg
FMcB9t+P5ePZDWxSWl9PlFr8d7+3h+CB2aYcB/Ig6vef4LqubOr2e/+0CUoN
5tkcB/Ih5u/XmXBoq//LH/sf3jB2uLyA48ASiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA8ayh1w==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.5191609020654973`, -3.357979635108771, 
      0.0855718330639844}, {-2.366917531924889, -2.4849645070759623`, \
-0.07148402475128206}, {-1.4808390979345027`, -2.642020364891229, \
-0.0855718330639844}, {-1.633082468075111, -3.5150354929240377`, 
      0.07148402475128206}, {-2.5191609020654973`, -3.357979635108771, 
      0.0855718330639844}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}, {-2.366917531924889, -2.4849645070759623`, \
-0.07148402475128206}, {-1.4808390979345027`, -2.642020364891229, \
-0.0855718330639844}, {-1.633082468075111, -3.5150354929240377`, 
       0.07148402475128206}, {-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.0513095581746894`, -2.44383497634162, 
      0.053645531181561}, {-2.051309558174689, -2.44383497634162, 
      0.05364553118156099}, {-2.0342063721164596`, -2.2958899842277467`, 
      0.035763687454374}, {-2.0342063721164596`, -2.2958899842277467`, 
      0.035763687454374006`}, {-2.0513095581746894`, -2.44383497634162, 
      0.053645531181561}}], 
     Polygon3DBox[{{-2.0342063721164596`, -2.2958899842277467`, 
      0.035763687454374006`}, {-2.0342063721164596`, -2.2958899842277467`, 
      0.035763687454374}, {-2.01710318605823, -2.1479449921138736`, 
      0.017881843727187006`}, {-2.01710318605823, -2.147944992113873, 
      0.017881843727187003`}, {-2.0342063721164596`, -2.2958899842277467`, 
      0.035763687454374006`}}], 
     Polygon3DBox[{{-2.01710318605823, -2.147944992113873, 
      0.017881843727187003`}, {-2.01710318605823, -2.1479449921138736`, 
      0.017881843727187006`}, {-2., -2., 1.1177618374721513`*^-17}, {-2., -2.,
       0.}, {-2.01710318605823, -2.147944992113873, 0.017881843727187003`}}], 
     Polygon3DBox[{{-2., -2., 
      0.}, {-2., -2., -2.0576047110597747`*^-18}, {-1.9828968139417702`, \
-1.8520550078861266`, -0.017881843727186996`}, {-1.9828968139417702`, \
-1.8520550078861266`, -0.017881843727186996`}, {-2., -2., 0.}}], 
     Polygon3DBox[{{-1.9828968139417702`, -1.8520550078861266`, \
-0.017881843727186996`}, {-1.9828968139417702`, -1.8520550078861266`, \
-0.017881843727186996`}, {-1.9657936278835404`, -1.7041100157722535`, \
-0.03576368745437399}, {-1.9657936278835404`, -1.7041100157722533`, \
-0.035763687454374}, {-1.9828968139417702`, -1.8520550078861266`, \
-0.017881843727186996`}}], 
     Polygon3DBox[{{-1.9657936278835404`, -1.7041100157722533`, \
-0.035763687454374}, {-1.9657936278835404`, -1.7041100157722535`, \
-0.03576368745437399}, {-1.9486904418253108`, -1.5561650236583802`, \
-0.053645531181561}, {-1.9486904418253108`, -1.5561650236583802`, \
-0.05364553118156099}, {-1.9657936278835404`, -1.7041100157722533`, \
-0.035763687454374}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62IuiPSCbDgYRVilE/e5gP+G1kCMktX22/pKDn
L68bw4HXx7In/o5lOmBaxmAxz3+RfZDFsX9sygwHSh9vPfFXjxEqPsmeAQIO
wOhwqbDYTS1xNjH9xUyfdv7fL2o5JY9l0d/9xhD1+3fIPWd5Uvx/v1aRxl0O
l9/7TSDm7xddF8V+Tff/fofVe7x5n/3Y7wtxD4Y41J0Y5kDduR/dXqg79+Nw
5x50f0HdiREOUHfao4cb1J0Y4rDwBAC52J69
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.446474929456423, -1.946354468818439, 
        0.016801617515289788`}, {-2.446474929456423, -1.9463544688184389`, 
        0.01680161751528978}, {-2.2976499529709487`, -1.964236312545626, 
        0.01120107834352652}, {-2.297649952970949, -1.964236312545626, 
        0.011201078343526526`}, {-2.446474929456423, -1.946354468818439, 
        0.016801617515289788`}}], 
       Polygon3DBox[{{-2.297649952970949, -1.964236312545626, 
        0.011201078343526526`}, {-2.2976499529709487`, -1.964236312545626, 
        0.01120107834352652}, {-2.1488249764854745`, -1.982118156272813, 
        0.0056005391717632615`}, {-2.1488249764854745`, -1.982118156272813, 
        0.0056005391717632615`}, {-2.297649952970949, -1.964236312545626, 
        0.011201078343526526`}}], 
       Polygon3DBox[{{-2.1488249764854745`, -1.982118156272813, 
        0.0056005391717632615`}, {-2.1488249764854745`, -1.982118156272813, 
        0.0056005391717632615`}, {-2., -2., 
        8.603902900348745*^-19}, {-2., -2., -3.2848414025029106`*^-18}, \
{-2.1488249764854745`, -1.982118156272813, 0.0056005391717632615`}}], 
       Polygon3DBox[{{-2., -2., -3.2848414025029106`*^-18}, {-2., -2., \
-3.2848414025029106`*^-18}, {-1.8511750235145257`, -2.017881843727187, \
-0.005600539171763264}, {-1.8511750235145257`, -2.017881843727187, \
-0.005600539171763266}, {-2., -2., -3.2848414025029106`*^-18}}], 
       Polygon3DBox[{{-1.8511750235145257`, -2.017881843727187, \
-0.005600539171763266}, {-1.8511750235145257`, -2.017881843727187, \
-0.005600539171763264}, {-1.7023500470290513`, -2.035763687454374, \
-0.011201078343526525`}, {-1.7023500470290511`, -2.035763687454374, \
-0.01120107834352653}, {-1.8511750235145257`, -2.017881843727187, \
-0.005600539171763266}}], 
       Polygon3DBox[{{-1.7023500470290511`, -2.035763687454374, \
-0.01120107834352653}, {-1.7023500470290513`, -2.035763687454374, \
-0.011201078343526525`}, {-1.5535250705435768`, -2.053645531181561, \
-0.016801617515289788`}, {-1.5535250705435768`, -2.053645531181561, \
-0.01680161751528979}, {-1.7023500470290511`, -2.035763687454374, \
-0.01120107834352653}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7v12H7V1ZoMtHeLyTX
Z1oi0wG/P/Z8zbn/9z/fFOQ5/UObvfoqM7XTBowH1P/Jtx/cBhMvs2eAgAMw
OuvVkfTLss42m1dP2pw57+/+NwwFNvNVGA48gajfnxqumn7Z5vf+m4wPKuw8
GQ48hZi/X4J5h5Tt7R/7jzIFbL2by3BAG+IeDHGoOzHMgbpz/yY0e6Hu3I/D
nXvQ/QV1p70vWjhA3WmPHm5Qd2KIw8ITADZMq2Y=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.4977844876311126`, -2.390189445160059, 
      0.07044714869685079}, {-2.395165371281734, -1.502519492476819, \
-0.03684391366627121}, {-1.5022155123688876`, -1.609810554839941, \
-0.07044714869685079}, {-1.604834628718266, -2.497480507523181, 
      0.03684391366627121}, {-2.4977844876311126`, -2.390189445160059, 
      0.07044714869685079}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}, {-2.395165371281734, -1.502519492476819, \
-0.03684391366627121}, {-1.5022155123688876`, -1.609810554839941, \
-0.07044714869685079}, {-1.604834628718266, -2.497480507523181, 
       0.03684391366627121}, {-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.0258279869764584`, -1.4484323484908068`, 
      0.02722763147545933}, {-2.0258279869764584`, -1.4484323484908068`, 
      0.027227631475459323`}, {-2.0172186579843054`, -1.298954898993871, 
      0.01815175431697288}, {-2.0172186579843054`, -1.298954898993871, 
      0.018151754316972888`}, {-2.0258279869764584`, -1.4484323484908068`, 
      0.02722763147545933}}], 
     Polygon3DBox[{{-2.0172186579843054`, -1.298954898993871, 
      0.018151754316972888`}, {-2.0172186579843054`, -1.298954898993871, 
      0.01815175431697288}, {-2.0086093289921525`, -1.1494774494969358`, 
      0.009075877158486444}, {-2.008609328992153, -1.1494774494969355`, 
      0.009075877158486444}, {-2.0172186579843054`, -1.298954898993871, 
      0.018151754316972888`}}], 
     Polygon3DBox[{{-2.008609328992153, -1.1494774494969355`, 
      0.009075877158486444}, {-2.0086093289921525`, -1.1494774494969358`, 
      0.009075877158486444}, {-2., -1.0000000000000002`, 
      3.912938843685099*^-18}, {-2., -1., 
      0.}, {-2.008609328992153, -1.1494774494969355`, 0.009075877158486444}}],
      Polygon3DBox[{{-2., -1., 
      0.}, {-2., -1., -2.804559682995694*^-18}, {-1.9913906710078473`, \
-0.8505225505030645, -0.009075877158486442}, {-1.9913906710078473`, \
-0.8505225505030645, -0.00907587715848644}, {-2., -1., 0.}}], 
     Polygon3DBox[{{-1.9913906710078473`, -0.8505225505030645, \
-0.00907587715848644}, {-1.9913906710078473`, -0.8505225505030645, \
-0.009075877158486442}, {-1.9827813420156943`, -0.7010451010061289, \
-0.01815175431697288}, {-1.9827813420156943`, -0.7010451010061289, \
-0.018151754316972885`}, {-1.9913906710078473`, -0.8505225505030645, \
-0.00907587715848644}}], 
     Polygon3DBox[{{-1.9827813420156943`, -0.7010451010061289, \
-0.018151754316972885`}, {-1.9827813420156943`, -0.7010451010061289, \
-0.01815175431697288}, {-1.9741720130235416`, -0.5515676515091933, \
-0.027227631475459327`}, {-1.9741720130235416`, -0.5515676515091934, \
-0.027227631475459323`}, {-1.9827813420156943`, -0.7010451010061289, \
-0.018151754316972885`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPYT3e371IThwKoTn1OP63zf/9XlQ1b/w9n2ncnq
nc7KDAeOtS5613Liy/6fugvmxE+bZH904+QjCwUZDjx2Cix3SvkEFW+yZ4CA
AxDqw/55PglR83/52ZTPuVG2587//VZVsYLV5q/3f4eo3//WYuPbip3/95d8
2aX0Le/Z/h8Q8/enXO1MMZ32f/+6PAmTwmUP93+GuAcuvgYqDnUn3JxiqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwWwkNN6g77XGFJwB/9sFU
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.4485913527490135`, -0.9727723685245406, 
        0.022900967731662204`}, {-2.4485913527490135`, -0.9727723685245406, 
        0.0229009677316622}, {-2.2990609018326755`, -0.9818482456830271, 
        0.015267311821108132`}, {-2.299060901832676, -0.9818482456830271, 
        0.015267311821108139`}, {-2.4485913527490135`, -0.9727723685245406, 
        0.022900967731662204`}}], 
       Polygon3DBox[{{-2.299060901832676, -0.9818482456830271, 
        0.015267311821108139`}, {-2.2990609018326755`, -0.9818482456830271, 
        0.015267311821108132`}, {-2.149530450916338, -0.9909241228415135, 
        0.007633655910554069}, {-2.149530450916338, -0.9909241228415135, 
        0.007633655910554068}, {-2.299060901832676, -0.9818482456830271, 
        0.015267311821108139`}}], 
       Polygon3DBox[{{-2.149530450916338, -0.9909241228415135, 
        0.007633655910554068}, {-2.149530450916338, -0.9909241228415135, 
        0.007633655910554069}, {-2., -1., 
        3.982828782569444*^-18}, {-2., -1., -1.6672115867392496`*^-18}, \
{-2.149530450916338, -0.9909241228415135, 0.007633655910554068}}], 
       Polygon3DBox[{{-2., -1., -1.6672115867392496`*^-18}, {-2., -1., \
-1.6672115867392496`*^-18}, {-1.8504695490836622`, -1.0090758771584865`, \
-0.007633655910554067}, {-1.8504695490836622`, -1.0090758771584865`, \
-0.007633655910554068}, {-2., -1., -1.6672115867392496`*^-18}}], 
       Polygon3DBox[{{-1.8504695490836622`, -1.0090758771584865`, \
-0.007633655910554068}, {-1.8504695490836622`, -1.0090758771584865`, \
-0.007633655910554067}, {-1.7009390981673245`, -1.018151754316973, \
-0.015267311821108132`}, {-1.7009390981673242`, -1.018151754316973, \
-0.015267311821108139`}, {-1.8504695490836622`, -1.0090758771584865`, \
-0.007633655910554068}}], 
       Polygon3DBox[{{-1.7009390981673242`, -1.018151754316973, \
-0.015267311821108139`}, {-1.7009390981673245`, -1.018151754316973, \
-0.015267311821108132`}, {-1.5514086472509865`, -1.0272276314754594`, \
-0.0229009677316622}, {-1.5514086472509865`, -1.0272276314754594`, \
-0.0229009677316622}, {-1.7009390981673242`, -1.018151754316973, \
-0.015267311821108139`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7zfn6Vy8W1k8XT7RYLH
uapSmA5M+CfF7Jv9fv+T1oPPy1367S92JLPaGjEe8KjvbVy2FSZeb88AAQcg
1If9k96ffp3M52UT/87ia+vsv/tjHCz366h+2P8Aon7/3juFr7jNf+/f0VBU
F+n1Yf8jiPn7ZU6vuj/x0o/9IgdX27blf9ifAXEPhjjUnRjmQN25Pw7NXqg7
9+Nw5x50f0Hdab8QLRyg7rRHDzeoOzHEYeEJAGNTuuo=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.474419339725472, -1.4212047170153475`, 
      0.05012859920712154}, {-2.422763365772555, -0.5243400200337339, \
-0.004326663743797126}, {-1.525580660274528, -0.5787952829846525, \
-0.05012859920712154}, {-1.5772366342274449`, -1.4756599799662662`, 
      0.004326663743797126}, {-2.474419339725472, -1.4212047170153475`, 
      0.05012859920712154}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}, {-2.422763365772555, -0.5243400200337339, \
-0.004326663743797126}, {-1.525580660274528, -0.5787952829846525, \
-0.05012859920712154}, {-1.5772366342274449`, -1.4756599799662662`, 
       0.004326663743797126}, {-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2., -0.45, 
      0.}, {-2., -0.45, -6.117559435892654*^-18}, {-2., -0.3, \
-5.097966196577212*^-18}, {-2., -0.30000000000000004`, 0.}, {-2., -0.45, 
      0.}}], Polygon3DBox[{{-2., -0.30000000000000004`, 
      0.}, {-2., -0.3, -5.097966196577212*^-18}, {-2., -0.15000000000000008`, \
-4.07837295726177*^-18}, {-2., -0.15000000000000002`, 
      0.}, {-2., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{-2., -0.15000000000000002`, 
      0.}, {-2., -0.15000000000000008`, -4.07837295726177*^-18}, {-2., \
-1.1102230246251565`*^-16, -3.058779717946328*^-18}, {-2., 0., 
      0.}, {-2., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{-2., 0., 0.}, {-2., 0., -3.058779717946327*^-18}, {-2., 
      0.14999999999999997`, -2.039186478630885*^-18}, {-2., 
      0.14999999999999997`, 0.}, {-2., 0., 0.}}], 
     Polygon3DBox[{{-2., 0.14999999999999997`, 0.}, {-2., 
      0.14999999999999997`, -2.039186478630885*^-18}, {-2., 
      0.29999999999999993`, -1.0195932393154427`*^-18}, {-2., 0.3, 0.}, {-2., 
      0.14999999999999997`, 0.}}], 
     Polygon3DBox[{{-2., 0.3, 0.}, {-2., 
      0.29999999999999993`, -1.0195932393154427`*^-18}, {-2., 
      0.44999999999999996`, -5.093891505180682*^-34}, {-2., 
      0.4499999999999999, 0.}, {-2., 0.3, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjg4cPYMCNzZz4AKDpgYg8BlHOKHMcQh1IQ96OJG
EPX26OLGEPMxxE9D3IMhfhaHuAkOc0xw2At1pw0Od2L4yxhHOJzGEW7o4QkA
EQVB6A==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.4493063074013928`, 0., 
        0.024976831851240444`}, {-2.4493063074013928`, 
        5.5109105961630896`*^-17, 
        0.024976831851240444`}, {-2.2995375382675953`, 4.592425496802574*^-17,
         0.016651221234160296`}, {-2.2995375382675953`, 
        9.184850993605149*^-18, 0.0166512212341603}, {-2.4493063074013928`, 
        0., 0.024976831851240444`}}], 
       Polygon3DBox[{{-2.2995375382675953`, 9.184850993605149*^-18, 
        0.0166512212341603}, {-2.2995375382675953`, 4.592425496802574*^-17, 
        0.016651221234160296`}, {-2.1497687691337974`, 3.67394039744206*^-17, 
        0.008325610617080152}, {-2.1497687691337974`, 
        1.8369701987210297`*^-17, 0.00832561061708015}, {-2.2995375382675953`,
         9.184850993605149*^-18, 0.0166512212341603}}], 
       Polygon3DBox[{{-2.1497687691337974`, 1.8369701987210297`*^-17, 
        0.00832561061708015}, {-2.1497687691337974`, 3.67394039744206*^-17, 
        0.008325610617080152}, {-2., 2.7554552980815454`*^-17, 
        6.162189734097359*^-18}, {-2., 2.7554552980815448`*^-17, 
        0.}, {-2.1497687691337974`, 1.8369701987210297`*^-17, 
        0.00832561061708015}}], 
       Polygon3DBox[{{-2., 2.7554552980815448`*^-17, 0.}, {-2., 
        2.7554552980815448`*^-17, 0.}, {-1.8502312308662026`, 
        1.83697019872103*^-17, -0.008325610617080146}, {-1.8502312308662026`, 
        3.6739403974420595`*^-17, -0.008325610617080146}, {-2., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{-1.8502312308662026`, 
        3.6739403974420595`*^-17, -0.008325610617080146}, \
{-1.8502312308662026`, 
        1.83697019872103*^-17, -0.008325610617080146}, {-1.700462461732405, 
        9.184850993605152*^-18, -0.016651221234160293`}, {-1.700462461732405, 
        4.592425496802574*^-17, -0.016651221234160296`}, \
{-1.8502312308662026`, 3.6739403974420595`*^-17, -0.008325610617080146}}], 
       Polygon3DBox[{{-1.700462461732405, 
        4.592425496802574*^-17, -0.016651221234160296`}, {-1.700462461732405, 
        9.184850993605153*^-18, -0.016651221234160293`}, \
{-1.5506936925986072`, 
        4.5887548728832574`*^-33, -0.02497683185124044}, \
{-1.5506936925986072`, 
        5.510910596163089*^-17, -0.024976831851240437`}, {-1.700462461732405, 
        4.592425496802574*^-17, -0.016651221234160296`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5PP/hcdwbzAQYoaDh+9Xzb5Jn2X12uvS9OZYKL
M7b2dbHwTrSvUnr9facRI5p4oz2UCxdnMJ4xkT3bx4Znt6ZAz6y/+2HC/1vA
6veLlwUrSJj+hoszQMzfr2RYa7Dk/A+4eB3EPRjiUHfuF0MzB+rO/dxo9kLd
CeOju3MPur+g7sQIB6g77dHDDepODHFYeAIAnIBtHA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.4493063074013928`, -0.45, 
      0.024976831851240444`}, {-2.4493063074013928`, 0.45, 
      0.024976831851240444`}, {-1.5506936925986072`, 
      0.45, -0.024976831851240444`}, {-1.5506936925986072`, -0.45, \
-0.024976831851240444`}, {-2.4493063074013928`, -0.45, 
      0.024976831851240444`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.4493063074013928`, -0.45, 
       0.024976831851240444`}, {-2.4493063074013928`, 0.45, 
       0.024976831851240444`}, {-1.5506936925986072`, 
       0.45, -0.024976831851240444`}, {-1.5506936925986072`, -0.45, \
-0.024976831851240444`}, {-2.4493063074013928`, -0.45, 
       0.024976831851240444`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.9741720130235416`, 
      0.5515676515091932, -0.02722763147545933}, {-1.9741720130235416`, 
      0.5515676515091932, -0.027227631475459337`}, {-1.9827813420156943`, 
      0.7010451010061289, -0.018151754316972888`}, {-1.9827813420156943`, 
      0.7010451010061288, -0.018151754316972888`}, {-1.9741720130235416`, 
      0.5515676515091932, -0.02722763147545933}}], 
     Polygon3DBox[{{-1.9827813420156943`, 
      0.7010451010061288, -0.018151754316972888`}, {-1.9827813420156943`, 
      0.7010451010061289, -0.018151754316972888`}, {-1.991390671007847, 
      0.8505225505030644, -0.009075877158486451}, {-1.9913906710078473`, 
      0.8505225505030645, -0.009075877158486444}, {-1.9827813420156943`, 
      0.7010451010061288, -0.018151754316972888`}}], 
     Polygon3DBox[{{-1.9913906710078473`, 
      0.8505225505030645, -0.009075877158486444}, {-1.991390671007847, 
      0.8505225505030644, -0.009075877158486451}, {-2., 
      0.9999999999999999, -9.522058209676488*^-18}, {-2., 1., 
      0.}, {-1.9913906710078473`, 
      0.8505225505030645, -0.009075877158486444}}], 
     Polygon3DBox[{{-2., 1., 0.}, {-2., 
      1., -2.804559682995694*^-18}, {-2.008609328992153, 1.1494774494969355`, 
      0.009075877158486439}, {-2.008609328992153, 1.1494774494969355`, 
      0.00907587715848644}, {-2., 1., 0.}}], 
     Polygon3DBox[{{-2.008609328992153, 1.1494774494969355`, 
      0.00907587715848644}, {-2.008609328992153, 1.1494774494969355`, 
      0.009075877158486439}, {-2.0172186579843054`, 1.298954898993871, 
      0.01815175431697288}, {-2.0172186579843054`, 1.298954898993871, 
      0.018151754316972885`}, {-2.008609328992153, 1.1494774494969355`, 
      0.00907587715848644}}], 
     Polygon3DBox[{{-2.0172186579843054`, 1.298954898993871, 
      0.018151754316972885`}, {-2.0172186579843054`, 1.298954898993871, 
      0.01815175431697288}, {-2.0258279869764584`, 1.4484323484908068`, 
      0.027227631475459327`}, {-2.0258279869764584`, 1.4484323484908066`, 
      0.027227631475459323`}, {-2.0172186579843054`, 1.298954898993871, 
      0.018151754316972885`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE652pliOu3//jV5EiaFyx7af3X5kNX/cPb+txYb
31bs/L+/+MsupW95z+x/6i6YEz9t0v7yOTfK9tz5v9+qKlaw2vw1VLxpPwME
HIBQH+zn+SREzf/lt+foxslHFgoyHHjsFFjulPLJ/jtEvX1nsnqnszLDgWOt
i961nPhi/wNivr2f6G7fpyYMB1ae+Jx6XOe7/WeIe+Diq6DiUHdimAN1pz26
vVB32uNwpw26v6DuhIdDCTQcoO7cDwu3ddBwg7pzP67wBACrErpp
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.4485913527490135`, 0.9727723685245406, 
        0.022900967731662204`}, {-2.4485913527490135`, 0.9727723685245407, 
        0.022900967731662208`}, {-2.2990609018326755`, 0.9818482456830272, 
        0.015267311821108139`}, {-2.299060901832676, 0.9818482456830271, 
        0.015267311821108139`}, {-2.4485913527490135`, 0.9727723685245406, 
        0.022900967731662204`}}], 
       Polygon3DBox[{{-2.299060901832676, 0.9818482456830271, 
        0.015267311821108139`}, {-2.2990609018326755`, 0.9818482456830272, 
        0.015267311821108139`}, {-2.149530450916338, 0.9909241228415135, 
        0.0076336559105540745`}, {-2.149530450916338, 0.9909241228415135, 
        0.00763365591055407}, {-2.299060901832676, 0.9818482456830271, 
        0.015267311821108139`}}], 
       Polygon3DBox[{{-2.149530450916338, 0.9909241228415135, 
        0.00763365591055407}, {-2.149530450916338, 0.9909241228415135, 
        0.0076336559105540745`}, {-2., 1., 7.317251956047944*^-18}, {-2., 1., 
        1.6672115867392496`*^-18}, {-2.149530450916338, 0.9909241228415135, 
        0.00763365591055407}}], 
       Polygon3DBox[{{-2., 1., 1.6672115867392496`*^-18}, {-2., 1., 
        1.6672115867392496`*^-18}, {-1.8504695490836622`, 
        1.0090758771584865`, -0.007633655910554065}, {-1.8504695490836622`, 
        1.0090758771584865`, -0.007633655910554063}, {-2., 1., 
        1.6672115867392496`*^-18}}], 
       Polygon3DBox[{{-1.8504695490836622`, 
        1.0090758771584865`, -0.007633655910554063}, {-1.8504695490836622`, 
        1.0090758771584865`, -0.007633655910554065}, {-1.7009390981673245`, 
        1.018151754316973, -0.015267311821108132`}, {-1.7009390981673242`, 
        1.018151754316973, -0.015267311821108132`}, {-1.8504695490836622`, 
        1.0090758771584865`, -0.007633655910554063}}], 
       Polygon3DBox[{{-1.7009390981673242`, 
        1.018151754316973, -0.015267311821108132`}, {-1.7009390981673245`, 
        1.018151754316973, -0.015267311821108132`}, {-1.5514086472509865`, 
        1.0272276314754594`, -0.0229009677316622}, {-1.5514086472509865`, 
        1.0272276314754594`, -0.022900967731662194`}, {-1.7009390981673242`, 
        1.018151754316973, -0.015267311821108132`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7y3z1K5+DayeLr9IsHj
XFUpTAcm/JNi9s1+b/+k9eDzcpd++4sdyay2RowHPOp7G5dthYnX2zNAwAEI
9cF+0vvTr5P5vGzi31l8bZ39d3+Mg+V+HdUP9g8g6vfvvVP4itv89/4dDUV1
kV4f7B9BzN8vc3rV/YmXfuwXObjati3/g30GxD0Y4lB3YpgDdef+ODR7oe7c
j8Ode9D9BXWn/UK0cIC60x493KDuxBCHhScAM4izag==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.422763365772555, 
      0.5243400200337339, -0.004326663743797126}, {-2.474419339725472, 
      1.4212047170153475`, 0.05012859920712154}, {-1.5772366342274449`, 
      1.4756599799662662`, 0.004326663743797126}, {-1.525580660274528, 
      0.5787952829846525, -0.05012859920712154}, {-2.422763365772555, 
      0.5243400200337339, -0.004326663743797126}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}, {-2.474419339725472, 
       1.4212047170153475`, 0.05012859920712154}, {-1.5772366342274449`, 
       1.4756599799662662`, 0.004326663743797126}, {-1.525580660274528, 
       0.5787952829846525, -0.05012859920712154}, {-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.9486904418253108`, 
      1.5561650236583802`, -0.053645531181561}, {-1.9486904418253106`, 
      1.5561650236583802`, -0.053645531181561006`}, {-1.9657936278835404`, 
      1.7041100157722533`, -0.035763687454374}, {-1.9657936278835404`, 
      1.7041100157722533`, -0.035763687454374006`}, {-1.9486904418253108`, 
      1.5561650236583802`, -0.053645531181561}}], 
     Polygon3DBox[{{-1.9657936278835404`, 
      1.7041100157722533`, -0.035763687454374006`}, {-1.9657936278835404`, 
      1.7041100157722533`, -0.035763687454374}, {-1.9828968139417702`, 
      1.8520550078861266`, -0.017881843727187013`}, {-1.9828968139417702`, 
      1.8520550078861266`, -0.017881843727187003`}, {-1.9657936278835404`, 
      1.7041100157722533`, -0.035763687454374006`}}], 
     Polygon3DBox[{{-1.9828968139417702`, 
      1.8520550078861266`, -0.017881843727187003`}, {-1.9828968139417702`, 
      1.8520550078861266`, -0.017881843727187013`}, {-2., 
      2., -1.5292827796841065`*^-17}, {-2., 2., 0.}, {-1.9828968139417702`, 
      1.8520550078861266`, -0.017881843727187003`}}], 
     Polygon3DBox[{{-2., 2., 0.}, {-2., 
      2., -2.0576047110597747`*^-18}, {-2.01710318605823, 2.147944992113873, 
      0.017881843727186996`}, {-2.01710318605823, 2.147944992113873, 
      0.017881843727186996`}, {-2., 2., 0.}}], 
     Polygon3DBox[{{-2.01710318605823, 2.147944992113873, 
      0.017881843727186996`}, {-2.01710318605823, 2.147944992113873, 
      0.017881843727186996`}, {-2.0342063721164596`, 2.2958899842277467`, 
      0.03576368745437399}, {-2.0342063721164596`, 2.2958899842277467`, 
      0.035763687454374}, {-2.01710318605823, 2.147944992113873, 
      0.017881843727186996`}}], 
     Polygon3DBox[{{-2.0342063721164596`, 2.2958899842277467`, 
      0.035763687454374}, {-2.0342063721164596`, 2.2958899842277467`, 
      0.03576368745437399}, {-2.0513095581746894`, 2.44383497634162, 
      0.053645531181561}, {-2.0513095581746894`, 2.44383497634162, 
      0.05364553118156099}, {-2.0342063721164596`, 2.2958899842277467`, 
      0.035763687454374}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBZdF8V+Tff/fofVe7x5n/2w99vIEJJbvnr/Drnn
LE+K/+/XKtK4y+Hy2960jMFinv+i/TH9xUyfdv7fL2o5JY9l0V+o+KT9DBBw
AEo7hEuFxW5qidsTZHHsH5syw4HSx1tP/NVjdDCGqLdfUtDzl9eN4cDrY9kT
f8cyOZhAzLf/tiLoj0gmw4GEVYpRP3uYHXwh7sEQh7oTwxyoO+3R7YW60x6H
O23Q/QV1J0Y4QN25Hz3coO7EEIeFJwDbRJhI
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.446474929456423, 1.946354468818439, 
        0.016801617515289788`}, {-2.446474929456423, 1.946354468818439, 
        0.016801617515289795`}, {-2.2976499529709487`, 1.9642363125456261`, 
        0.01120107834352653}, {-2.297649952970949, 1.964236312545626, 
        0.01120107834352653}, {-2.446474929456423, 1.946354468818439, 
        0.016801617515289788`}}], 
       Polygon3DBox[{{-2.297649952970949, 1.964236312545626, 
        0.01120107834352653}, {-2.2976499529709487`, 1.9642363125456261`, 
        0.01120107834352653}, {-2.1488249764854745`, 1.982118156272813, 
        0.00560053917176327}, {-2.1488249764854745`, 1.982118156272813, 
        0.005600539171763267}, {-2.297649952970949, 1.964236312545626, 
        0.01120107834352653}}], 
       Polygon3DBox[{{-2.1488249764854745`, 1.982118156272813, 
        0.005600539171763267}, {-2.1488249764854745`, 1.982118156272813, 
        0.00560053917176327}, {-2., 2., 7.430073095040696*^-18}, {-2., 2., 
        3.2848414025029106`*^-18}, {-2.1488249764854745`, 1.982118156272813, 
        0.005600539171763267}}], 
       Polygon3DBox[{{-2., 2., 3.2848414025029106`*^-18}, {-2., 2., 
        3.2848414025029106`*^-18}, {-1.8511750235145257`, 
        2.017881843727187, -0.005600539171763259}, {-1.8511750235145257`, 
        2.017881843727187, -0.005600539171763257}, {-2., 2., 
        3.2848414025029106`*^-18}}], 
       Polygon3DBox[{{-1.8511750235145257`, 
        2.017881843727187, -0.005600539171763257}, {-1.8511750235145257`, 
        2.017881843727187, -0.005600539171763259}, {-1.7023500470290513`, 
        2.035763687454374, -0.011201078343526521`}, {-1.7023500470290511`, 
        2.035763687454374, -0.01120107834352652}, {-1.8511750235145257`, 
        2.017881843727187, -0.005600539171763257}}], 
       Polygon3DBox[{{-1.7023500470290511`, 
        2.035763687454374, -0.01120107834352652}, {-1.7023500470290513`, 
        2.035763687454374, -0.011201078343526521`}, {-1.5535250705435768`, 
        2.053645531181561, -0.016801617515289788`}, {-1.5535250705435768`, 
        2.053645531181561, -0.016801617515289777`}, {-1.7023500470290511`, 
        2.035763687454374, -0.01120107834352652}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7b67D9Kys0mWjvF5Lr
My2R6YDfH3u+5tz/9s83BXlO/9Bmr77KTO20AeMB9X/y7Qe3wcTL7Bkg4ACU
dsh6dST9sqyzzebVkzZnzvu7/w1Dgc18FQaHJxD1+1PDVdMv2/zef5PxQYWd
J4PDU4j5+yWYd0jZ3v6x/yhTwNa7uQwO2hD3YIhD3YlhDtSd+zeh2Qt1534c
7tyD7i+oO+190cIB6k579HCDuhNDHBaeAAaBo+Y=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.395165371281734, 
      1.502519492476819, -0.03684391366627121}, {-2.4977844876311126`, 
      2.390189445160059, 0.07044714869685079}, {-1.604834628718266, 
      2.497480507523181, 0.03684391366627121}, {-1.5022155123688876`, 
      1.609810554839941, -0.07044714869685079}, {-2.395165371281734, 
      1.502519492476819, -0.03684391366627121}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}, {-2.4977844876311126`, 
       2.390189445160059, 0.07044714869685079}, {-1.604834628718266, 
       2.497480507523181, 0.03684391366627121}, {-1.5022155123688876`, 
       1.609810554839941, -0.07044714869685079}, {-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.9238783149296959`, 
      2.563492435983596, -0.07852792890763323}, {-1.9238783149296959`, 
      2.563492435983596, -0.07852792890763323}, {-1.9492522099531304`, 
      2.708994957322397, -0.05235195260508881}, {-1.9492522099531306`, 
      2.708994957322397, -0.05235195260508882}, {-1.9238783149296959`, 
      2.563492435983596, -0.07852792890763323}}], 
     Polygon3DBox[{{-1.9492522099531306`, 
      2.708994957322397, -0.05235195260508882}, {-1.9492522099531304`, 
      2.708994957322397, -0.05235195260508881}, {-1.9746261049765652`, 
      2.8544974786611985`, -0.02617597630254442}, {-1.9746261049765652`, 
      2.8544974786611985`, -0.02617597630254441}, {-1.9492522099531306`, 
      2.708994957322397, -0.05235195260508882}}], 
     Polygon3DBox[{{-1.9746261049765652`, 
      2.8544974786611985`, -0.02617597630254441}, {-1.9746261049765652`, 
      2.8544974786611985`, -0.02617597630254442}, {-2., 
      3., -2.0236743856609135`*^-17}, {-2., 3., 0.}, {-1.9746261049765652`, 
      2.8544974786611985`, -0.02617597630254441}}], 
     Polygon3DBox[{{-2., 3., 0.}, {-2., 
      3., -8.626294678576207*^-19}, {-2.0253738950234346`, 
      3.1455025213388015`, 0.026175976302544403`}, {-2.0253738950234346`, 
      3.1455025213388015`, 0.026175976302544403`}, {-2., 3., 0.}}], 
     Polygon3DBox[{{-2.0253738950234346`, 3.1455025213388015`, 
      0.026175976302544403`}, {-2.0253738950234346`, 3.1455025213388015`, 
      0.026175976302544403`}, {-2.0507477900468696`, 3.291005042677603, 
      0.052351952605088806`}, {-2.0507477900468696`, 3.291005042677603, 
      0.05235195260508881}, {-2.0253738950234346`, 3.1455025213388015`, 
      0.026175976302544403`}}], 
     Polygon3DBox[{{-2.0507477900468696`, 3.291005042677603, 
      0.05235195260508881}, {-2.0507477900468696`, 3.291005042677603, 
      0.052351952605088806`}, {-2.076121685070304, 3.436507564016404, 
      0.07852792890763322}, {-2.076121685070304, 3.436507564016404, 
      0.0785279289076332}, {-2.0507477900468696`, 3.291005042677603, 
      0.05235195260508881}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6y5eACkxP/9vvsawjiaGJxkJWpZsuQ2rK/ueKa
qLLB//1GV0J7WNewOtSoLuF4cHbVfkeb112CM/7vl3yldYzpGhtUfNZ+Bgg4
AKE4HGzk7220Ckvbcz+xy+q7McOB56JXLf9qcjpUQdTb7z8sUvouneHAOe1V
xb+CuRyqIebbz1Odv/7pbIYDWxzr136v5XaQhrgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4ACOubuQ==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.443039216995193, 2.9214720710923667`, 
        0.007043904156351177}, {-2.443039216995193, 2.9214720710923667`, 
        0.0070439041563511865`}, {-2.2953594779967954`, 2.947648047394911, 
        0.004695936104234126}, {-2.2953594779967954`, 2.947648047394911, 
        0.004695936104234121}, {-2.443039216995193, 2.9214720710923667`, 
        0.007043904156351177}}], 
       Polygon3DBox[{{-2.2953594779967954`, 2.947648047394911, 
        0.004695936104234121}, {-2.2953594779967954`, 2.947648047394911, 
        0.004695936104234126}, {-2.1476797389983977`, 2.9738240236974556`, 
        0.002347968052117067}, {-2.1476797389983977`, 2.9738240236974556`, 
        0.0023479680521170626`}, {-2.2953594779967954`, 2.947648047394911, 
        0.004695936104234121}}], 
       Polygon3DBox[{{-2.1476797389983977`, 2.9738240236974556`, 
        0.0023479680521170626`}, {-2.1476797389983977`, 2.9738240236974556`, 
        0.002347968052117067}, {-2., 3., 6.546294300716623*^-18}, {-2., 3., 
        4.808448839020197*^-18}, {-2.1476797389983977`, 2.9738240236974556`, 
        0.0023479680521170626`}}], 
       Polygon3DBox[{{-2., 3., 4.808448839020197*^-18}, {-2., 3., 
        4.808448839020197*^-18}, {-1.8523202610016023`, 
        3.0261759763025444`, -0.0023479680521170557`}, {-1.8523202610016023`, 
        3.0261759763025444`, -0.002347968052117052}, {-2., 3., 
        4.808448839020197*^-18}}], 
       Polygon3DBox[{{-1.8523202610016023`, 
        3.0261759763025444`, -0.002347968052117052}, {-1.8523202610016023`, 
        3.0261759763025444`, -0.0023479680521170557`}, {-1.7046405220032046`, 
        3.052351952605089, -0.004695936104234116}, {-1.7046405220032046`, 
        3.052351952605089, -0.0046959361042341104`}, {-1.8523202610016023`, 
        3.0261759763025444`, -0.002347968052117052}}], 
       Polygon3DBox[{{-1.7046405220032046`, 
        3.052351952605089, -0.0046959361042341104`}, {-1.7046405220032046`, 
        3.052351952605089, -0.004695936104234116}, {-1.556960783004807, 
        3.0785279289076333`, -0.007043904156351176}, {-1.556960783004807, 
        3.0785279289076333`, -0.007043904156351166}, {-1.7046405220032046`, 
        3.052351952605089, -0.0046959361042341104`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewOyyacnS94q8Z+TpVI
3tMYpgNZ+XfrT0xhdyhIuLef26bY3s+Wa3uRHuOBrdvf2aecgokn2zNAwAEI
xeHA/vuxfDy7gU1K6+uJUov/7vf2EDww25TDIQ+ifv8JruvKpm6/90+boNRg
ns3hkA8xf7/OhENb/V/+2P/whrHD5QUcDksg7sEQh7oTwxyoO/ej2wt1534c
7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDB4ZpX
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.366917531924889, 
      2.4849645070759623`, -0.07148402475128206}, {-2.5191609020654973`, 
      3.357979635108771, 0.0855718330639844}, {-1.633082468075111, 
      3.5150354929240377`, 0.07148402475128206}, {-1.4808390979345027`, 
      2.642020364891229, -0.0855718330639844}, {-2.366917531924889, 
      2.4849645070759623`, -0.07148402475128206}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}, {-2.5191609020654973`, 
       3.357979635108771, 0.0855718330639844}, {-1.633082468075111, 
       3.5150354929240377`, 0.07148402475128206}, {-1.4808390979345027`, 
       2.642020364891229, -0.0855718330639844}, {-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.9000154208176978`, 
      3.5731024445084936`, -0.10129936347832735`}, {-1.9000154208176978`, 
      3.5731024445084936`, -0.10129936347832735`}, {-1.9333436138784652`, 
      3.7154016296723293`, -0.06753290898555156}, {-1.9333436138784652`, 
      3.7154016296723293`, -0.06753290898555157}, {-1.9000154208176978`, 
      3.5731024445084936`, -0.10129936347832735`}}], 
     Polygon3DBox[{{-1.9333436138784652`, 
      3.7154016296723293`, -0.06753290898555157}, {-1.9333436138784652`, 
      3.7154016296723293`, -0.06753290898555156}, {-1.9666718069392326`, 
      3.8577008148361647`, -0.0337664544927758}, {-1.9666718069392326`, 
      3.8577008148361647`, -0.03376645449277579}, {-1.9333436138784652`, 
      3.7154016296723293`, -0.06753290898555157}}], 
     Polygon3DBox[{{-1.9666718069392326`, 
      3.8577008148361647`, -0.03376645449277579}, {-1.9666718069392326`, 
      3.8577008148361647`, -0.0337664544927758}, {-2., 
      4., -2.427901367875551*^-17}, {-2., 4., 0.}, {-1.9666718069392326`, 
      3.8577008148361647`, -0.03376645449277579}}], 
     Polygon3DBox[{{-2., 4., 0.}, {-2., 4., 
      7.131831464693154*^-19}, {-2.0333281930607674`, 4.142299185163836, 
      0.03376645449277577}, {-2.0333281930607674`, 4.142299185163836, 
      0.03376645449277577}, {-2., 4., 0.}}], 
     Polygon3DBox[{{-2.0333281930607674`, 4.142299185163836, 
      0.03376645449277577}, {-2.0333281930607674`, 4.142299185163836, 
      0.03376645449277577}, {-2.066656386121535, 4.284598370327671, 
      0.06753290898555155}, {-2.066656386121535, 4.284598370327671, 
      0.06753290898555156}, {-2.0333281930607674`, 4.142299185163836, 
      0.03376645449277577}}], 
     Polygon3DBox[{{-2.066656386121535, 4.284598370327671, 
      0.06753290898555156}, {-2.066656386121535, 4.284598370327671, 
      0.06753290898555155}, {-2.099984579182302, 4.426897555491506, 
      0.10129936347832734`}, {-2.099984579182302, 4.426897555491506, 
      0.10129936347832733`}, {-2.066656386121535, 4.284598370327671, 
      0.06753290898555156}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZ582RiWdq//U3xzHu2TeVxqNhl53vw3c79HXNn
bPv57t9+pqnhtSo7eR1+q9UbX/PcuP+In8/tmvL/+xtPrbabdIcPKr5wPwME
HIBQAg4+0+oYUi/k7Jl3I3KSowvDgQNSqx5smyjg8BOi3t5m42aV5g6GA/Wm
IQdzlQUdfkHMt7/Vybv9yBmGA/YB/xaqbBV0KIO4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+WLg1Q8MN6s79uMITAIPwqug=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.438411364870582, 
        3.8987006365216725`, -0.00582358233382769}, {-2.438411364870582, 
        3.8987006365216725`, -0.005823582333827678}, {-2.292274243247055, 
        3.9324670910144484`, -0.003882388222551783}, {-2.292274243247055, 
        3.9324670910144484`, -0.0038823882225517917`}, {-2.438411364870582, 
        3.8987006365216725`, -0.00582358233382769}}], 
       Polygon3DBox[{{-2.292274243247055, 
        3.9324670910144484`, -0.0038823882225517917`}, {-2.292274243247055, 
        3.9324670910144484`, -0.003882388222551783}, {-2.1461371216235277`, 
        3.966233545507224, -0.0019411941112758896`}, {-2.1461371216235277`, 
        3.966233545507224, -0.0019411941112758928`}, {-2.292274243247055, 
        3.9324670910144484`, -0.0038823882225517917`}}], 
       Polygon3DBox[{{-2.1461371216235277`, 
        3.966233545507224, -0.0019411941112758928`}, {-2.1461371216235277`, 
        3.966233545507224, -0.0019411941112758896`}, {-2., 4., 
        4.7660247968997165`*^-18}, {-2., 4., 
        6.202797061969894*^-18}, {-2.1461371216235277`, 
        3.966233545507224, -0.0019411941112758928`}}], 
       Polygon3DBox[{{-2., 4., 6.202797061969894*^-18}, {-2., 4., 
        6.202797061969894*^-18}, {-1.8538628783764726`, 4.033766454492776, 
        0.0019411941112759004`}, {-1.8538628783764726`, 4.033766454492776, 
        0.0019411941112759045`}, {-2., 4., 6.202797061969894*^-18}}], 
       Polygon3DBox[{{-1.8538628783764726`, 4.033766454492776, 
        0.0019411941112759045`}, {-1.8538628783764726`, 4.033766454492776, 
        0.0019411941112759004`}, {-1.7077257567529451`, 4.067532908985552, 
        0.0038823882225517948`}, {-1.7077257567529451`, 4.067532908985552, 
        0.003882388222551804}, {-1.8538628783764726`, 4.033766454492776, 
        0.0019411941112759045`}}], 
       Polygon3DBox[{{-1.7077257567529451`, 4.067532908985552, 
        0.003882388222551804}, {-1.7077257567529451`, 4.067532908985552, 
        0.0038823882225517948`}, {-1.5615886351294177`, 4.1012993634783275`, 
        0.005823582333827689}, {-1.5615886351294177`, 4.1012993634783275`, 
        0.0058235823338277015`}, {-1.7077257567529451`, 4.067532908985552, 
        0.003882388222551804}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgdTq3e+qv8Vvn+7jUP
H0wOYzpwgi3Fb2Mpv8POfne/r2fz97tdK/jgqc14IIXZaPmNXTDx+P0MEHAA
Qgk4HPk+Qex7g9ae0mA5+ZyVf/f7/UtbM1lJwGEbRL39q2U2djeCfu+f8+ds
hLqrgMMOiPn28b+iYl3+/Nj/6pcJ6+50AYeTEPdgiEPdiWEO1J326PZC3WmP
w502rmj+groTIxyg7tyPHm5Qd2KIw8ITABGtr6s=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.3384267856882803`, 
      3.4718030810301665`, -0.10712294581215505`}, {-2.5383959440528843`, 
      4.325598192013179, 0.09547578114449966}, {-1.66157321431172, 
      4.528196918969834, 0.10712294581215505`}, {-1.4616040559471155`, 
      3.674401807986821, -0.09547578114449966}, {-2.3384267856882803`, 
      3.4718030810301665`, -0.10712294581215505`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}, {-2.5383959440528843`, 
       4.325598192013179, 0.09547578114449966}, {-1.66157321431172, 
       4.528196918969834, 0.10712294581215505`}, {-1.4616040559471155`, 
       3.674401807986821, -0.09547578114449966}, {-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.877324604629557, 
      4.584462952331788, -0.12157182809307357`}, {-1.8773246046295569`, 
      4.584462952331788, -0.12157182809307357`}, {-1.9182164030863713`, 
      4.722975301554525, -0.08104788539538237}, {-1.9182164030863713`, 
      4.722975301554525, -0.08104788539538238}, {-1.877324604629557, 
      4.584462952331788, -0.12157182809307357`}}], 
     Polygon3DBox[{{-1.9182164030863713`, 
      4.722975301554525, -0.08104788539538238}, {-1.9182164030863713`, 
      4.722975301554525, -0.08104788539538237}, {-1.9591082015431855`, 
      4.861487650777263, -0.04052394269769121}, {-1.9591082015431858`, 
      4.861487650777263, -0.04052394269769119}, {-1.9182164030863713`, 
      4.722975301554525, -0.08104788539538238}}], 
     Polygon3DBox[{{-1.9591082015431858`, 
      4.861487650777263, -0.04052394269769119}, {-1.9591082015431855`, 
      4.861487650777263, -0.04052394269769121}, {-2., 
      5., -2.740458238673123*^-17}, {-2., 5., 0.}, {-1.9591082015431858`, 
      4.861487650777263, -0.04052394269769119}}], 
     Polygon3DBox[{{-2., 5., 0.}, {-2., 5., 
      2.5891604343135925`*^-18}, {-2.0408917984568142`, 5.138512349222737, 
      0.040523942697691176`}, {-2.0408917984568142`, 5.138512349222737, 
      0.040523942697691176`}, {-2., 5., 0.}}], 
     Polygon3DBox[{{-2.0408917984568142`, 5.138512349222737, 
      0.040523942697691176`}, {-2.0408917984568142`, 5.138512349222737, 
      0.040523942697691176`}, {-2.0817835969136285`, 5.277024698445475, 
      0.08104788539538235}, {-2.0817835969136285`, 5.277024698445475, 
      0.08104788539538237}, {-2.0408917984568142`, 5.138512349222737, 
      0.040523942697691176`}}], 
     Polygon3DBox[{{-2.0817835969136285`, 5.277024698445475, 
      0.08104788539538237}, {-2.0817835969136285`, 5.277024698445475, 
      0.08104788539538235}, {-2.1226753953704427`, 5.415537047668212, 
      0.12157182809307356`}, {-2.1226753953704427`, 5.415537047668212, 
      0.12157182809307353`}, {-2.0817835969136285`, 5.277024698445475, 
      0.08104788539538237}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH54yLetlfPf/tgvx0tqw4QcDgUeuxgiv3//68Z7
65g3/ttv90N/cfATIQedh3oPe/dv2f/NIf96Y8T//fJ/pl/ULBKGii/ZzwAB
ByCUiIN/2p8J3l6Fe1rjPUT2BzMceMicoXetV8RBC6Lenmv/BI265QwHDrFf
iFkjLeqgDTHfvl/upo3tb4YDi7ktuptWijrsh7jHfgKaONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/ejhBnUnhjgsPAEuVakc
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-2.4327508547046017`, 
        4.8784281719069265`, -0.021142099388299276`}, {-2.4327508547046017`, 
        4.8784281719069265`, -0.021142099388299262`}, {-2.288500569803068, 
        4.918952114604617, -0.014094732925532838`}, {-2.288500569803068, 
        4.918952114604617, -0.01409473292553285}, {-2.4327508547046017`, 
        4.8784281719069265`, -0.021142099388299276`}}], 
       Polygon3DBox[{{-2.288500569803068, 
        4.918952114604617, -0.01409473292553285}, {-2.288500569803068, 
        4.918952114604617, -0.014094732925532838`}, {-2.144250284901534, 
        4.959476057302309, -0.007047366462766419}, {-2.144250284901534, 
        4.959476057302309, -0.007047366462766421}, {-2.288500569803068, 
        4.918952114604617, -0.01409473292553285}}], 
       Polygon3DBox[{{-2.144250284901534, 
        4.959476057302309, -0.007047366462766421}, {-2.144250284901534, 
        4.959476057302309, -0.007047366462766419}, {-2., 5., 
        2.2280285004107885`*^-18}, {-2., 5., 
        7.444127507033741*^-18}, {-2.144250284901534, 
        4.959476057302309, -0.007047366462766421}}], 
       Polygon3DBox[{{-2., 5., 7.444127507033741*^-18}, {-2., 5., 
        7.444127507033741*^-18}, {-1.855749715098466, 5.040523942697691, 
        0.007047366462766429}, {-1.855749715098466, 5.040523942697691, 
        0.007047366462766433}, {-2., 5., 7.444127507033741*^-18}}], 
       Polygon3DBox[{{-1.855749715098466, 5.040523942697691, 
        0.007047366462766433}, {-1.855749715098466, 5.040523942697691, 
        0.007047366462766429}, {-1.7114994301969322`, 5.081047885395383, 
        0.014094732925532849`}, {-1.7114994301969322`, 5.081047885395383, 
        0.014094732925532863`}, {-1.855749715098466, 5.040523942697691, 
        0.007047366462766433}}], 
       Polygon3DBox[{{-1.7114994301969322`, 5.081047885395383, 
        0.014094732925532863`}, {-1.7114994301969322`, 5.081047885395383, 
        0.014094732925532849`}, {-1.567249145295398, 5.1215718280930735`, 
        0.021142099388299272`}, {-1.5672491452953983`, 5.1215718280930735`, 
        0.021142099388299286`}, {-1.7114994301969322`, 5.081047885395383, 
        0.014094732925532863`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUdlssfcXVbNnX/mWLG
5Jt+TAeqXapPMK4VdjDV2sC++W7P/mc7GzbmqDMesFtk+6ThGky8Zj8DBByA
UCIO184KGYryeewx6fk3R23j3/2HYg9J12uKOBhB1NtnSPy19E36vb91d4v5
vyARBxOI+fZzlvy+Viz8c7+7pHtwbY2IwzKIe+xno4lD3WmfjmYO1J326PZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAGV2bIA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-2.310075459334159, 
      4.462891124238714, -0.14271392748137285`}, {-2.555426250075045, 
      5.2939652195751385`, 0.10042972870477429`}, {-1.689924540665841, 
      5.537108875761286, 0.14271392748137285`}, {-1.4445737499249551`, 
      4.7060347804248615`, -0.10042972870477429`}, {-2.310075459334159, 
      4.462891124238714, -0.14271392748137285`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}, {-2.555426250075045, 
       5.2939652195751385`, 0.10042972870477429`}, {-1.689924540665841, 
       5.537108875761286, 0.14271392748137285`}, {-1.4445737499249551`, 
       4.7060347804248615`, -0.10042972870477429`}, {-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.1249029946161069`, -5.415252911740647, 
      0.12026745705652335`}, {-1.1249029946161067`, -5.415252911740648, 
      0.12026745705652336`}, {-1.0832686630774044`, -5.276835274493765, 
      0.0801783047043489}, {-1.0832686630774047`, -5.276835274493765, 
      0.08017830470434892}, {-1.1249029946161069`, -5.415252911740647, 
      0.12026745705652335`}}], 
     Polygon3DBox[{{-1.0832686630774047`, -5.276835274493765, 
      0.08017830470434892}, {-1.0832686630774044`, -5.276835274493765, 
      0.0801783047043489}, {-1.0416343315387022`, -5.138417637246882, 
      0.04008915235217448}, {-1.0416343315387022`, -5.138417637246882, 
      0.04008915235217446}, {-1.0832686630774047`, -5.276835274493765, 
      0.08017830470434892}}], 
     Polygon3DBox[{{-1.0416343315387022`, -5.138417637246882, 
      0.04008915235217446}, {-1.0416343315387022`, -5.138417637246882, 
      0.04008915235217448}, {-1., -5., 3.380234696220412*^-17}, {-1., -5., 
      0.}, {-1.0416343315387022`, -5.138417637246882, 0.04008915235217446}}], 
     Polygon3DBox[{{-1., -5., 0.}, {-1., -5., 
      4.130413642810902*^-18}, {-0.9583656684612977, -4.861582362753118, \
-0.040089152352174445`}, {-0.9583656684612977, -4.861582362753118, \
-0.040089152352174445`}, {-1., -5., 0.}}], 
     Polygon3DBox[{{-0.9583656684612977, -4.861582362753118, \
-0.040089152352174445`}, {-0.9583656684612977, -4.861582362753118, \
-0.040089152352174445`}, {-0.9167313369225955, -4.723164725506235, \
-0.08017830470434889}, {-0.9167313369225955, -4.723164725506235, \
-0.0801783047043489}, {-0.9583656684612977, -4.861582362753118, \
-0.040089152352174445`}}], 
     Polygon3DBox[{{-0.9167313369225955, -4.723164725506235, \
-0.0801783047043489}, {-0.9167313369225955, -4.723164725506235, \
-0.08017830470434889}, {-0.8750970053838931, -4.584747088259353, \
-0.12026745705652334`}, {-0.8750970053838931, -4.584747088259353, \
-0.12026745705652332`}, {-0.9167313369225955, -4.723164725506235, \
-0.0801783047043489}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILY7HuAx6//H/bt/6fJbrBQ9sHvTFambJ/fZ1+t3
twqGftx/KfDklipp0QN1Z3r3TGjbYr9/+tFDHas+7H+5IiVqb68IVHyJPQMY
fNgPoUUOZGiVfTorVWjTeKGk6t2qd/vFw2cvdSoSPlADUb+feeHLL3dC3+7X
W2fm3fpE6EAtxPz9LYVx+acZ3ux3Zb304XiY0IGdEPdgiEPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08A8orAVQ==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4323172471057517`, -4.879732542943477, \
-0.03372738691422422}, {-1.4323172471057517`, -4.879732542943477, \
-0.033727386914224236`}, {-1.288211498070501, -4.919821695295651, \
-0.022484924609482825`}, {-1.288211498070501, -4.919821695295651, \
-0.02248492460948282}, {-1.4323172471057517`, -4.879732542943477, \
-0.03372738691422422}}], 
       Polygon3DBox[{{-1.288211498070501, -4.919821695295651, \
-0.02248492460948282}, {-1.288211498070501, -4.919821695295651, \
-0.022484924609482825`}, {-1.1441057490352506`, -4.9599108476478255`, \
-0.011242462304741423`}, {-1.1441057490352506`, -4.9599108476478255`, \
-0.011242462304741414`}, {-1.288211498070501, -4.919821695295651, \
-0.02248492460948282}}], 
       Polygon3DBox[{{-1.1441057490352506`, -4.9599108476478255`, \
-0.011242462304741414`}, {-1.1441057490352506`, -4.9599108476478255`, \
-0.011242462304741423`}, {-1., -5., -1.56853514857627*^-17}, {-1., -5., \
-7.364257816293155*^-18}, {-1.1441057490352506`, -4.9599108476478255`, \
-0.011242462304741414`}}], 
       Polygon3DBox[{{-1., -5., -7.364257816293155*^-18}, {-1., -5., \
-7.364257816293155*^-18}, {-0.8558942509647495, -5.0400891523521745`, 
        0.011242462304741399`}, {-0.8558942509647495, -5.0400891523521745`, 
        0.011242462304741394`}, {-1., -5., -7.364257816293155*^-18}}], 
       Polygon3DBox[{{-0.8558942509647495, -5.0400891523521745`, 
        0.011242462304741394`}, {-0.8558942509647495, -5.0400891523521745`, 
        0.011242462304741399`}, {-0.7117885019294989, -5.080178304704349, 
        0.022484924609482804`}, {-0.7117885019294989, -5.080178304704349, 
        0.022484924609482797`}, {-0.8558942509647495, -5.0400891523521745`, 
        0.011242462304741394`}}], 
       Polygon3DBox[{{-0.7117885019294989, -5.080178304704349, 
        0.022484924609482797`}, {-0.7117885019294989, -5.080178304704349, 
        0.022484924609482804`}, {-0.5676827528942485, -5.120267457056523, 
        0.033727386914224215`}, {-0.5676827528942485, -5.120267457056523, 
        0.0337273869142242}, {-0.7117885019294989, -5.080178304704349, 
        0.022484924609482797`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBE+IJHY67/dZeF+yS0v
VjTP+bL/3AnevU/XCh9Q1Enf78k2fT9vVMkVR79P+9OftN37dA0m3r6fAQw+
QGmRA0eXNMi/0A/e89xbPLwm+fX+mdKViryaIgfkIOrtz03XW/fj2LP9Ruaf
nKSCRA7IQ8y33/bYlbVU69H+00HZKerVIgfEIe6x34omDnUnhjlQd9qj2wt1
pz0Od9rwoPkL6k6McIC6c78qWrhB3bkfV3gCAENxo/8=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.5572202417218586`, -5.294985454684124, 
      0.08654007014229913}, {-1.3074142524896448`, -4.464479631202829, \
-0.15399484397074759`}, {-0.44277975827814153`, -4.705014545315876, \
-0.08654007014229913}, {-0.6925857475103553, -5.535520368797171, 
      0.15399484397074759`}, {-1.5572202417218586`, -5.294985454684124, 
      0.08654007014229913}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}, {-1.3074142524896448`, -4.464479631202829, \
-0.15399484397074759`}, {-0.44277975827814153`, -4.705014545315876, \
-0.08654007014229913}, {-0.6925857475103553, -5.535520368797171, 
       0.15399484397074759`}, {-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.1019196239073528`, -4.4266538045272394`, 
      0.10039383120996832`}, {-1.1019196239073528`, -4.4266538045272394`, 
      0.10039383120996832`}, {-1.067946415938235, -4.284435869684827, 
      0.06692922080664555}, {-1.0679464159382352`, -4.284435869684827, 
      0.06692922080664557}, {-1.1019196239073528`, -4.4266538045272394`, 
      0.10039383120996832`}}], 
     Polygon3DBox[{{-1.0679464159382352`, -4.284435869684827, 
      0.06692922080664557}, {-1.067946415938235, -4.284435869684827, 
      0.06692922080664555}, {-1.0339732079691175`, -4.142217934842414, 
      0.03346461040332279}, {-1.0339732079691175`, -4.142217934842413, 
      0.033464610403322784`}, {-1.0679464159382352`, -4.284435869684827, 
      0.06692922080664557}}], 
     Polygon3DBox[{{-1.0339732079691175`, -4.142217934842413, 
      0.033464610403322784`}, {-1.0339732079691175`, -4.142217934842414, 
      0.03346461040332279}, {-1., -4., 2.700795659986308*^-17}, {-1., -4., 
      0.}, {-1.0339732079691175`, -4.142217934842413, 
      0.033464610403322784`}}], 
     Polygon3DBox[{{-1., -4., 0.}, {-1., -4., 
      2.2391692799434193`*^-18}, {-0.9660267920308824, -3.8577820651575867`, \
-0.03346461040332277}, {-0.9660267920308824, -3.8577820651575867`, \
-0.03346461040332277}, {-1., -4., 0.}}], 
     Polygon3DBox[{{-0.9660267920308824, -3.8577820651575867`, \
-0.03346461040332277}, {-0.9660267920308824, -3.8577820651575867`, \
-0.03346461040332277}, {-0.9320535840617648, -3.7155641303151734`, \
-0.06692922080664554}, {-0.9320535840617649, -3.7155641303151734`, \
-0.06692922080664555}, {-0.9660267920308824, -3.8577820651575867`, \
-0.03346461040332277}}], 
     Polygon3DBox[{{-0.9320535840617649, -3.7155641303151734`, \
-0.06692922080664555}, {-0.9320535840617648, -3.7155641303151734`, \
-0.06692922080664554}, {-0.8980803760926472, -3.57334619547276, \
-0.10039383120996831`}, {-0.8980803760926472, -3.5733461954727606`, \
-0.10039383120996831`}, {-0.9320535840617649, -3.7155641303151734`, \
-0.06692922080664555}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmEM29o6Js4cf9botU9jzZInggNvzI34zNO+23xqj+
9hP7uF8/R0LDWVnwwKsnTf9clTbaR62bVKve/WG/uBnPlIUTBaDiC+0ZwODD
fggtcKClVn9FSV+OjffiWywbX77bf3Hy8+t77vAdeAFRv3+621bOpMtv9y9S
P7++cifvgZcQ8/c/etnPJ7z3zf6S3dvazabxHIiBuAcuXgwVh7pz/zQ0c6Du
3I9uL9Sd+3G4cw+6v6DuxAgHqDvt0cMN6k4McVh4AgBFtrmQ
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4382770431043812`, -3.8996061687900316`, \
-0.018284204731539053`}, {-1.4382770431043812`, -3.8996061687900316`, \
-0.018284204731539067`}, {-1.2921846954029208`, -3.9330707791933546`, \
-0.012189469821026045`}, {-1.2921846954029208`, -3.9330707791933546`, \
-0.012189469821026038`}, {-1.4382770431043812`, -3.8996061687900316`, \
-0.018284204731539053`}}], 
       Polygon3DBox[{{-1.2921846954029208`, -3.9330707791933546`, \
-0.012189469821026038`}, {-1.2921846954029208`, -3.9330707791933546`, \
-0.012189469821026045`}, {-1.1460923477014604`, -3.966535389596677, \
-0.006094734910513029}, {-1.1460923477014604`, -3.966535389596677, \
-0.006094734910513023}, {-1.2921846954029208`, -3.9330707791933546`, \
-0.012189469821026038`}}], 
       Polygon3DBox[{{-1.1460923477014604`, -3.966535389596677, \
-0.006094734910513023}, {-1.1460923477014604`, -3.966535389596677, \
-0.006094734910513029}, {-1., -4., -1.0658359220030233`*^-17}, {-1., -4., \
-6.147349202271368*^-18}, {-1.1460923477014604`, -3.966535389596677, \
-0.006094734910513023}}], 
       Polygon3DBox[{{-1., -4., -6.147349202271368*^-18}, {-1., -4., \
-6.147349202271368*^-18}, {-0.8539076522985396, -4.033464610403323, 
        0.006094734910513012}, {-0.8539076522985396, -4.033464610403323, 
        0.006094734910513009}, {-1., -4., -6.147349202271368*^-18}}], 
       Polygon3DBox[{{-0.8539076522985396, -4.033464610403323, 
        0.006094734910513009}, {-0.8539076522985396, -4.033464610403323, 
        0.006094734910513012}, {-0.7078153045970793, -4.066929220806646, 
        0.012189469821026032`}, {-0.7078153045970792, -4.066929220806646, 
        0.012189469821026025`}, {-0.8539076522985396, -4.033464610403323, 
        0.006094734910513009}}], 
       Polygon3DBox[{{-0.7078153045970792, -4.066929220806646, 
        0.012189469821026025`}, {-0.7078153045970793, -4.066929220806646, 
        0.012189469821026032`}, {-0.561722956895619, -4.100393831209968, 
        0.01828420473153905}, {-0.561722956895619, -4.100393831209968, 
        0.018284204731539036`}, {-0.7078153045970792, -4.066929220806646, 
        0.012189469821026025`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPEf8LydbSqxc9J+k+hP
t0+u+bL/5gvuC2/L+A8kqTz9eOpbx/5Zuj/fpoR92p/zhfVF2W6YeMV+BjD4
AKUFDgTOeym38qzLnjNLeFXMgl/vP8X6t9tFSeBAAkS9/QxPaY+cZc/2T+H+
Jd7pInAgEWK+fdo7jZxFPx/ujxX8vvhsmsABD4h77FPRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3YkRDlB37j+LFm5Qd+7HFZ4Atma6Pw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.5401966670117337`, -4.3262599733172715`, 
      0.08210962647842927}, {-1.3363574191970282`, -3.4729523642627917`, \
-0.11867803594150737`}, {-0.45980333298826614`, -3.6737400266827285`, \
-0.08210962647842927}, {-0.6636425808029717, -4.527047635737208, 
      0.11867803594150737`}, {-1.5401966670117337`, -4.3262599733172715`, 
      0.08210962647842927}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}, {-1.3363574191970282`, -3.4729523642627917`, \
-0.11867803594150737`}, {-0.45980333298826614`, -3.6737400266827285`, \
-0.08210962647842927}, {-0.6636425808029717, -4.527047635737208, 
       0.11867803594150737`}, {-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.0776714352856203`, -3.436338567286028, 
      0.07794743638791615}, {-1.07767143528562, -3.436338567286028, 
      0.07794743638791615}, {-1.05178095685708, -3.2908923781906854`, 
      0.0519649575919441}, {-1.0517809568570802`, -3.2908923781906854`, 
      0.051964957591944104`}, {-1.0776714352856203`, -3.436338567286028, 
      0.07794743638791615}}], 
     Polygon3DBox[{{-1.0517809568570802`, -3.2908923781906854`, 
      0.051964957591944104`}, {-1.05178095685708, -3.2908923781906854`, 
      0.0519649575919441}, {-1.02589047842854, -3.1454461890953427`, 
      0.025982478795972062`}, {-1.02589047842854, -3.1454461890953427`, 
      0.025982478795972052`}, {-1.0517809568570802`, -3.2908923781906854`, 
      0.051964957591944104`}}], 
     Polygon3DBox[{{-1.02589047842854, -3.1454461890953427`, 
      0.025982478795972052`}, {-1.02589047842854, -3.1454461890953427`, 
      0.025982478795972062`}, {-1., -3., 1.9874907008916532`*^-17}, {-1., -3.,
       0.}, {-1.02589047842854, -3.1454461890953427`, 
      0.025982478795972052`}}], 
     Polygon3DBox[{{-1., -3., 0.}, {-1., -3., 
      6.440095448344769*^-19}, {-0.9741095215714599, -2.8545538109046573`, \
-0.02598247879597204}, {-0.9741095215714599, -2.8545538109046573`, \
-0.02598247879597204}, {-1., -3., 0.}}], 
     Polygon3DBox[{{-0.9741095215714599, -2.8545538109046573`, \
-0.02598247879597204}, {-0.9741095215714599, -2.8545538109046573`, \
-0.02598247879597204}, {-0.9482190431429198, -2.7091076218093146`, \
-0.05196495759194408}, {-0.9482190431429199, -2.7091076218093146`, \
-0.0519649575919441}, {-0.9741095215714599, -2.8545538109046573`, \
-0.02598247879597204}}], 
     Polygon3DBox[{{-0.9482190431429199, -2.7091076218093146`, \
-0.0519649575919441}, {-0.9482190431429198, -2.7091076218093146`, \
-0.05196495759194408}, {-0.9223285647143799, -2.563661432713972, \
-0.07794743638791614}, {-0.9223285647143799, -2.563661432713972, \
-0.07794743638791612}, {-0.9482190431429199, -2.7091076218093146`, \
-0.0519649575919441}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC7WVEtXsfu4/94FZeH5tdwHuG6I/4r5stl+kfQR
F4krH/ZPeSCetD+Y60By6alFarNX2V/kTVLiyfqw3+sD98b7mpxQ8Vn2DGDw
YT+E5jigvn1F+1ftNJu4J9a7n2u/37+N/4ufwjW2AwkQ9fv3nigvOx/+bn+O
/Iu5DmtYDyRBzN8vvXaz4fbmt/uV9O+8SWhiOcABcQ+GONSd+/egmQN15350
e6Hu3I/DnXvQ/QV1J0Y4QN1pX4QWblB32uMKTwDIp64Z
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.443166495626191, -2.922052563612084, \
-0.005258737011217123}, {-1.443166495626191, -2.922052563612084, \
-0.0052587370112171326`}, {-1.2954443304174605`, -2.9480350424080557`, \
-0.0035058246741447563`}, {-1.2954443304174608`, -2.9480350424080557`, \
-0.003505824674144751}, {-1.443166495626191, -2.922052563612084, \
-0.005258737011217123}}], 
       Polygon3DBox[{{-1.2954443304174608`, -2.9480350424080557`, \
-0.003505824674144751}, {-1.2954443304174605`, -2.9480350424080557`, \
-0.0035058246741447563`}, {-1.1477221652087304`, -2.974017521204028, \
-0.0017529123370723816`}, {-1.1477221652087304`, -2.974017521204028, \
-0.001752912337072378}, {-1.2954443304174608`, -2.9480350424080557`, \
-0.003505824674144751}}], 
       Polygon3DBox[{{-1.1477221652087304`, -2.974017521204028, \
-0.001752912337072378}, {-1.1477221652087304`, -2.974017521204028, \
-0.0017529123370723816`}, {-1., -3., -6.070319681555002*^-18}, {-1., -3., \
-4.7729039237101715`*^-18}, {-1.1477221652087304`, -2.974017521204028, \
-0.001752912337072378}}], 
       Polygon3DBox[{{-1., -3., -4.7729039237101715`*^-18}, {-1., -3., \
-4.7729039237101715`*^-18}, {-0.8522778347912697, -3.025982478795972, 
        0.0017529123370723708`}, {-0.8522778347912697, -3.025982478795972, 
        0.0017529123370723678`}, {-1., -3., -4.7729039237101715`*^-18}}], 
       Polygon3DBox[{{-0.8522778347912697, -3.025982478795972, 
        0.0017529123370723678`}, {-0.8522778347912697, -3.025982478795972, 
        0.0017529123370723708`}, {-0.7045556695825395, -3.051964957591944, 
        0.0035058246741447464`}, {-0.7045556695825395, -3.051964957591944, 
        0.0035058246741447407`}, {-0.8522778347912697, -3.025982478795972, 
        0.0017529123370723678`}}], 
       Polygon3DBox[{{-0.7045556695825395, -3.051964957591944, 
        0.0035058246741447407`}, {-0.7045556695825395, -3.051964957591944, 
        0.0035058246741447464`}, {-0.5568335043738092, -3.077947436387916, 
        0.005258737011217123}, {-0.5568335043738093, -3.077947436387916, 
        0.005258737011217113}, {-0.7045556695825395, -3.051964957591944, 
        0.0035058246741447407`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBPYD9/9sLtfvKt3/6Hnf
VeVdX/ZrXStJnTyV/YB2oKuX/Y6c/R+Lj78SjP20XzR716aTp2DiMfsZwOAD
lOY48EOiP+P+O/U98hKFWndcX+9/PcXV18yU44AGRL29ncGjkB3dz/Zf0+ye
lZPFcUATYr59nEdw/ZSLD/cf2Hfh+aL5HAfuQdxjH4MmDnWnvS2aOVB32suh
2Qt1pz0Od9p8QPMX1J37H6KFA9Sd+y+ihRvUnftxhScAOA2p7A==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.520837930911811, -3.358391130898112, 
      0.07268869937669903}, {-1.3654950603405707`, -2.485713996326056, \
-0.08320617339913328}, {-0.4791620690881889, -2.641608869101888, \
-0.07268869937669903}, {-0.6345049396594293, -3.514286003673944, 
      0.08320617339913328}, {-1.520837930911811, -3.358391130898112, 
      0.07268869937669903}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}, {-1.3654950603405707`, -2.485713996326056, \
-0.08320617339913328}, {-0.4791620690881889, -2.641608869101888, \
-0.07268869937669903}, {-0.6345049396594293, -3.514286003673944, 
       0.08320617339913328}, {-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.052393314703181, -2.443748393960468, 
      0.05331325756243699}, {-1.052393314703181, -2.443748393960468, 
      0.05331325756243699}, {-1.0349288764687872`, -2.295832262640312, 
      0.035542171708291326`}, {-1.0349288764687874`, -2.295832262640312, 
      0.03554217170829133}, {-1.052393314703181, -2.443748393960468, 
      0.05331325756243699}}], 
     Polygon3DBox[{{-1.0349288764687874`, -2.295832262640312, 
      0.03554217170829133}, {-1.0349288764687872`, -2.295832262640312, 
      0.035542171708291326`}, {-1.0174644382343936`, -2.147916131320156, 
      0.017771085854145673`}, {-1.0174644382343936`, -2.147916131320156, 
      0.017771085854145666`}, {-1.0349288764687874`, -2.295832262640312, 
      0.03554217170829133}}], 
     Polygon3DBox[{{-1.0174644382343936`, -2.147916131320156, 
      0.017771085854145666`}, {-1.0174644382343936`, -2.147916131320156, 
      0.017771085854145673`}, {-1., -2., 1.2583574522634654`*^-17}, {-1., -2.,
       0.}, {-1.0174644382343936`, -2.147916131320156, 
      0.017771085854145666`}}], 
     Polygon3DBox[{{-1., -2., 
      0.}, {-1., -2., -5.696712692739672*^-19}, {-0.9825355617656063, \
-1.852083868679844, -0.01777108585414566}, {-0.9825355617656063, \
-1.852083868679844, -0.01777108585414566}, {-1., -2., 0.}}], 
     Polygon3DBox[{{-0.9825355617656063, -1.852083868679844, \
-0.01777108585414566}, {-0.9825355617656063, -1.852083868679844, \
-0.01777108585414566}, {-0.9650711235312126, -1.7041677373596882`, \
-0.03554217170829132}, {-0.9650711235312127, -1.7041677373596882`, \
-0.035542171708291326`}, {-0.9825355617656063, -1.852083868679844, \
-0.01777108585414566}}], 
     Polygon3DBox[{{-0.9650711235312127, -1.7041677373596882`, \
-0.035542171708291326`}, {-0.9650711235312126, -1.7041677373596882`, \
-0.03554217170829132}, {-0.947606685296819, -1.5562516060395322`, \
-0.05331325756243699}, {-0.947606685296819, -1.5562516060395322`, \
-0.05331325756243698}, {-0.9650711235312127, -1.7041677373596882`, \
-0.035542171708291326`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5/Nyh+1rUP+9dttv16uof5QABHpPAD79X2oS8f
ThHs/7C/REnT724s04GHUdZJU40W2a/6UnCqw/3DfquJIsvf6TFCxSfZM4DB
h/0QmuHA6TdJfn4hcTarxeSy3xW8399z99pGpUV/99+HqN8frmtz7c7Dd/sl
d69NdnX5vf8BxPz9TC5RjqeD3u1fOqNFNOPZj/3+EPdgiEPdCTdHAmoO1J37
0e2FunM/DnfuQfcX1J0Y4QB1pz0s3NZCww3qTntc4QkAh1iyzg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4468065107841634`, -1.9466867424375631`, 
        0.004651718925575885}, {-1.4468065107841634`, -1.946686742437563, 
        0.004651718925575878}, {-1.2978710071894421`, -1.9644578282917087`, 
        0.0031011459503839174`}, {-1.2978710071894421`, -1.9644578282917087`, 
        0.003101145950383922}, {-1.4468065107841634`, -1.9466867424375631`, 
        0.004651718925575885}}], 
       Polygon3DBox[{{-1.2978710071894421`, -1.9644578282917087`, 
        0.003101145950383922}, {-1.2978710071894421`, -1.9644578282917087`, 
        0.0031011459503839174`}, {-1.1489355035947213`, -1.9822289141458542`, 
        0.001550572975191958}, {-1.148935503594721, -1.9822289141458542`, 
        0.0015505729751919596`}, {-1.2978710071894421`, -1.9644578282917087`, 
        0.003101145950383922}}], 
       Polygon3DBox[{{-1.148935503594721, -1.9822289141458542`, 
        0.0015505729751919596`}, {-1.1489355035947213`, -1.9822289141458542`, 
        0.001550572975191958}, {-1., -2., -2.1168409656847465`*^-18}, {-1., \
-2., -3.264495511297844*^-18}, {-1.148935503594721, -1.9822289141458542`, 
        0.0015505729751919596`}}], 
       Polygon3DBox[{{-1., -2., -3.264495511297844*^-18}, {-1., -2., \
-3.264495511297844*^-18}, {-0.8510644964052789, -2.0177710858541458`, \
-0.0015505729751919633`}, {-0.8510644964052789, -2.0177710858541458`, \
-0.0015505729751919654`}, {-1., -2., -3.264495511297844*^-18}}], 
       Polygon3DBox[{{-0.8510644964052789, -2.0177710858541458`, \
-0.0015505729751919654`}, {-0.8510644964052789, -2.0177710858541458`, \
-0.0015505729751919633`}, {-0.7021289928105579, -2.035542171708291, \
-0.0031011459503839235`}, {-0.7021289928105579, -2.035542171708291, \
-0.0031011459503839287`}, {-0.8510644964052789, -2.0177710858541458`, \
-0.0015505729751919654`}}], 
       Polygon3DBox[{{-0.7021289928105579, -2.035542171708291, \
-0.0031011459503839287`}, {-0.7021289928105579, -2.035542171708291, \
-0.0031011459503839235`}, {-0.5531934892158368, -2.053313257562437, \
-0.004651718925575884}, {-0.5531934892158368, -2.053313257562437, \
-0.00465171892557589}, {-0.7021289928105579, -2.035542171708291, \
-0.0031011459503839287`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/vv85f67WOt9je7tGS
ZJEjX/Zrqr4Lyc77v19e9A/v5PRMe/nCS4ZcSZ/2TxEqX2W6HSYeac8ABh/2
Q2iGAzMFg8yWaqvaHJKNnvPa+vX+bWVHtFJVGA7IQNTvb7HeZnG9/Nn+nLcd
oac8GA7IQczf7xYpePXQ5of7FVN8G/RzGQ5chbhnvyuaONSd+5vRzIG6cz+6
vVB37sfhzj0wf02F+gvqToxwgLrTPhYt3KDutMcVngDY0aCt
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.4991998254873442`, -2.3904351363980307`, 
      0.057964976488012875`}, {-1.3944131960809822`, -1.502938348477095, \
-0.0486615386368611}, {-0.5008001745126557, -1.609564863601969, \
-0.057964976488012875`}, {-0.6055868039190176, -2.497061651522905, 
      0.0486615386368611}, {-1.4991998254873442`, -2.3904351363980307`, 
      0.057964976488012875`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}, {-1.3944131960809822`, -1.502938348477095, \
-0.0486615386368611}, {-0.5008001745126557, -1.609564863601969, \
-0.057964976488012875`}, {-0.6055868039190176, -2.497061651522905, 
       0.0486615386368611}, {-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.0263858473362126`, -1.4484088295723214`, 
      0.027079671747104638`}, {-1.0263858473362126`, -1.4484088295723214`, 
      0.027079671747104635`}, {-1.0175905648908083`, -1.2989392197148808`, 
      0.018053114498069754`}, {-1.0175905648908086`, -1.298939219714881, 
      0.01805311449806976}, {-1.0263858473362126`, -1.4484088295723214`, 
      0.027079671747104638`}}], 
     Polygon3DBox[{{-1.0175905648908086`, -1.298939219714881, 
      0.01805311449806976}, {-1.0175905648908083`, -1.2989392197148808`, 
      0.018053114498069754`}, {-1.008795282445404, -1.1494696098574406`, 
      0.009026557249034882}, {-1.0087952824454043`, -1.1494696098574404`, 
      0.00902655724903488}, {-1.0175905648908086`, -1.298939219714881, 
      0.01805311449806976}}], 
     Polygon3DBox[{{-1.0087952824454043`, -1.1494696098574404`, 
      0.00902655724903488}, {-1.008795282445404, -1.1494696098574406`, 
      0.009026557249034882}, {-1., -1.0000000000000002`, 
      5.3508880655613765`*^-18}, {-1., -1., 
      0.}, {-1.0087952824454043`, -1.1494696098574404`, 
      0.00902655724903488}}], 
     Polygon3DBox[{{-1., -1., 
      0.}, {-1., -1., -1.3301063950890472`*^-18}, {-0.9912047175545957, \
-0.8505303901425596, -0.009026557249034879}, {-0.9912047175545957, \
-0.8505303901425596, -0.009026557249034877}, {-1., -1., 0.}}], 
     Polygon3DBox[{{-0.9912047175545957, -0.8505303901425596, \
-0.009026557249034877}, {-0.9912047175545957, -0.8505303901425596, \
-0.009026557249034879}, {-0.9824094351091915, -0.7010607802851192, \
-0.018053114498069754`}, {-0.9824094351091915, -0.7010607802851191, \
-0.018053114498069758`}, {-0.9912047175545957, -0.8505303901425596, \
-0.009026557249034877}}], 
     Polygon3DBox[{{-0.9824094351091915, -0.7010607802851191, \
-0.018053114498069758`}, {-0.9824094351091915, -0.7010607802851192, \
-0.018053114498069754`}, {-0.9736141526637873, -0.5515911704276787, \
-0.027079671747104635`}, {-0.9736141526637873, -0.5515911704276788, \
-0.02707967174710463}, {-0.9824094351091915, -0.7010607802851191, \
-0.018053114498069758`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDbT+zZBOOfDfmnmJXvW6Xzf/9lQk+nYrtn2VSf9
uHk9Puzfu+ZQbcmJL/t/nC5gbKmZZL83ZXkrm8qH/XFhD+2sUj5BxZvsGcDg
w34Y/TFYcG3beT+bNrONXz5tf7/fJdi2qdv89f5vEPX7eXOTXj7Nf7+/fVkV
i3j+s/3fIebvn7xY+N4N9ff7z/zc3rZo2cP9HyHugYufgopD3Qk3pw1qDtSd
+2H2OkPthbpzPw537kH3F9Sd8HDYAw0HqDvtYeEmBQ03qDvtcYUnADNouvs=

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4490531449080963`, -0.9729203282528953, 
        0.010861142951707538`}, {-1.4490531449080963`, -0.9729203282528953, 
        0.010861142951707535`}, {-1.299368763272064, -0.9819468855019302, 
        0.007240761967805022}, {-1.299368763272064, -0.9819468855019302, 
        0.0072407619678050246`}, {-1.4490531449080963`, -0.9729203282528953, 
        0.010861142951707538`}}], 
       Polygon3DBox[{{-1.299368763272064, -0.9819468855019302, 
        0.0072407619678050246`}, {-1.299368763272064, -0.9819468855019302, 
        0.007240761967805022}, {-1.1496843816360323`, -0.9909734427509651, 
        0.0036203809839025123`}, {-1.149684381636032, -0.9909734427509651, 
        0.0036203809839025114`}, {-1.299368763272064, -0.9819468855019302, 
        0.0072407619678050246`}}], 
       Polygon3DBox[{{-1.149684381636032, -0.9909734427509651, 
        0.0036203809839025114`}, {-1.1496843816360323`, -0.9909734427509651, 
        0.0036203809839025123`}, {-1., -1., 
        1.0214685511431293`*^-18}, {-1., -1., -1.6581516663526353`*^-18}, \
{-1.149684381636032, -0.9909734427509651, 0.0036203809839025114`}}], 
       Polygon3DBox[{{-1., -1., -1.6581516663526353`*^-18}, {-1., -1., \
-1.6581516663526353`*^-18}, {-0.850315618363968, -1.009026557249035, \
-0.0036203809839025127`}, {-0.850315618363968, -1.009026557249035, \
-0.0036203809839025136`}, {-1., -1., -1.6581516663526353`*^-18}}], 
       Polygon3DBox[{{-0.850315618363968, -1.009026557249035, \
-0.0036203809839025136`}, {-0.850315618363968, -1.009026557249035, \
-0.0036203809839025127`}, {-0.7006312367279359, -1.0180531144980698`, \
-0.007240761967805024}, {-0.7006312367279359, -1.0180531144980698`, \
-0.007240761967805027}, {-0.850315618363968, -1.009026557249035, \
-0.0036203809839025136`}}], 
       Polygon3DBox[{{-0.7006312367279359, -1.0180531144980698`, \
-0.007240761967805027}, {-0.7006312367279359, -1.0180531144980698`, \
-0.007240761967805024}, {-0.5509468550919039, -1.0270796717471047`, \
-0.010861142951707536`}, {-0.5509468550919039, -1.0270796717471047`, \
-0.010861142951707538`}, {-0.7006312367279359, -1.0180531144980698`, \
-0.007240761967805027}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr3f/3C70btYuzb7RxrV
z8xOfdm/oPLLfemc9/t1vs6wrV1Ra184xbZYOvXT/gs2v97zboOJ59ozgMGH
/TB6ieIqDuHtFjZy11skT5q+3j/jIRPHT5UP+zUh6vfbrOM0npT9bL/BYVaB
T54f9mtDzN8f1drnE73w4f4TSzgkXud92H8f4p79kWjiUHfut0YzB+rO/ej2
Qt25H4c796D7C+pOjHCAutM+GC3coO60xxWeAOT6uVI=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.475438992244309, -1.4213291578252167`, 
      0.03794081469881218}, {-1.4226672975718835`, -0.524511498680574, \
-0.0162185287953971}, {-0.524561007755691, -0.5786708421747833, \
-0.03794081469881218}, {-0.5773327024281165, -1.4754885013194259`, 
      0.0162185287953971}, {-1.475438992244309, -1.4213291578252167`, 
      0.03794081469881218}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}, {-1.4226672975718835`, -0.524511498680574, \
-0.0162185287953971}, {-0.524561007755691, -0.5786708421747833, \
-0.03794081469881218}, {-0.5773327024281165, -1.4754885013194259`, 
       0.0162185287953971}, {-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1., -0.45, 
      0.}, {-0.9999999999999999, -0.45, -3.1784602735159007`*^-18}, \
{-0.9999999999999999, -0.3, -2.6487168945965838`*^-18}, {-1., \
-0.30000000000000004`, 0.}, {-1., -0.45, 0.}}], 
     Polygon3DBox[{{-1., -0.30000000000000004`, 
      0.}, {-0.9999999999999999, -0.3, -2.6487168945965838`*^-18}, \
{-0.9999999999999999, -0.15000000000000008`, -2.1189735156772672`*^-18}, \
{-1., -0.15000000000000002`, 0.}, {-1., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{-1., -0.15000000000000002`, 
      0.}, {-0.9999999999999999, -0.15000000000000008`, \
-2.1189735156772672`*^-18}, {-1., -1.1102230246251565`*^-16, \
-1.5892301367579507`*^-18}, {-1., 0., 0.}, {-1., -0.15000000000000002`, 0.}}],
      Polygon3DBox[{{-1., 0., 0.}, {-1., 0., -1.5892301367579503`*^-18}, {-1.,
       0.14999999999999997`, -1.0594867578386336`*^-18}, {-1., 
      0.14999999999999997`, 0.}, {-1., 0., 0.}}], 
     Polygon3DBox[{{-1., 0.14999999999999997`, 0.}, {-1., 
      0.14999999999999997`, -1.0594867578386336`*^-18}, {-1., 
      0.29999999999999993`, -5.297433789193169*^-19}, {-1., 0.3, 0.}, {-1., 
      0.14999999999999997`, 0.}}], 
     Polygon3DBox[{{-1., 0.3, 0.}, {-1., 
      0.29999999999999993`, -5.29743378919317*^-19}, {-1., 
      0.44999999999999996`, -2.646599833885294*^-34}, {-1., 
      0.4499999999999999, 0.}, {-1., 0.3, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4sP/sGRC4s58BBXzYb2IMApdxiB/GEIfQE/ag
ixtB1NujixtDzMcQPw1xD4b4WRziJjjMMcFhL9SdNjjcieEvYxzhcBpHuKGH
JwA+ZE/p
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4498128457508597`, 0., 
        0.012977048875352748`}, {-1.4498128457508597`, 
        5.5109105961630896`*^-17, 
        0.012977048875352748`}, {-1.2998752305005732`, 4.592425496802574*^-17,
         0.008651365916901832}, {-1.2998752305005732`, 9.184850993605149*^-18,
         0.008651365916901833}, {-1.4498128457508597`, 0., 
        0.012977048875352748`}}], 
       Polygon3DBox[{{-1.2998752305005732`, 9.184850993605149*^-18, 
        0.008651365916901833}, {-1.2998752305005732`, 4.592425496802574*^-17, 
        0.008651365916901832}, {-1.1499376152502867`, 3.67394039744206*^-17, 
        0.004325682958450918}, {-1.1499376152502867`, 
        1.8369701987210297`*^-17, 
        0.004325682958450917}, {-1.2998752305005732`, 9.184850993605149*^-18, 
        0.008651365916901833}}], 
       Polygon3DBox[{{-1.1499376152502867`, 1.8369701987210297`*^-17, 
        0.004325682958450917}, {-1.1499376152502867`, 3.67394039744206*^-17, 
        0.004325682958450918}, {-1., 2.7554552980815454`*^-17, 
        3.2016485451339142`*^-18}, {-1., 2.7554552980815448`*^-17, 
        0.}, {-1.1499376152502867`, 1.8369701987210297`*^-17, 
        0.004325682958450917}}], 
       Polygon3DBox[{{-1., 2.7554552980815448`*^-17, 0.}, {-1., 
        2.7554552980815448`*^-17, 0.}, {-0.8500623847497135, 
        1.83697019872103*^-17, -0.004325682958450915}, {-0.8500623847497135, 
        3.6739403974420595`*^-17, -0.004325682958450915}, {-1., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{-0.8500623847497135, 
        3.6739403974420595`*^-17, -0.004325682958450915}, \
{-0.8500623847497135, 
        1.83697019872103*^-17, -0.004325682958450915}, {-0.7001247694994269, 
        9.184850993605152*^-18, -0.00865136591690183}, {-0.7001247694994268, 
        4.592425496802574*^-17, -0.008651365916901832}, {-0.8500623847497135, 
        3.6739403974420595`*^-17, -0.004325682958450915}}], 
       Polygon3DBox[{{-0.7001247694994268, 
        4.592425496802574*^-17, -0.008651365916901832}, {-0.7001247694994269, 
        9.184850993605153*^-18, -0.00865136591690183}, {-0.5501871542491403, 
        4.5887548728832574`*^-33, -0.012977048875352747`}, \
{-0.5501871542491403, 
        5.510910596163089*^-17, -0.012977048875352745`}, {-0.7001247694994268,
         4.592425496802574*^-17, -0.008651365916901832}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5SjP2SZ/R9PwMUrA1XZdk2ucveXMzuh+eZL3Dx
Equ8tee2N9rLcMv/UUn7hCZeaA/hfYCLH9i2/fTadlubUy8Psm8zfg0XL4Ko
3z/pcjN/TvozuHgxxPz9MXtdxZVmP4SLr4a4B0Mc6k4Mc6Du3H8SzV6oO/fj
cOceaTR/Qd2JEQ5Qd9qjhxvUnRjisPAEAG+9eME=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.4498128457508597`, -0.45, 
      0.012977048875352748`}, {-1.4498128457508597`, 0.45, 
      0.012977048875352748`}, {-0.5501871542491403, 
      0.45, -0.012977048875352748`}, {-0.5501871542491403, -0.45, \
-0.012977048875352748`}, {-1.4498128457508597`, -0.45, 
      0.012977048875352748`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.4498128457508597`, -0.45, 
       0.012977048875352748`}, {-1.4498128457508597`, 0.45, 
       0.012977048875352748`}, {-0.5501871542491403, 
       0.45, -0.012977048875352748`}, {-0.5501871542491403, -0.45, \
-0.012977048875352748`}, {-1.4498128457508597`, -0.45, 
       0.012977048875352748`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.9736141526637873, 
      0.5515911704276786, -0.027079671747104638`}, {-0.9736141526637871, 
      0.5515911704276786, -0.02707967174710464}, {-0.9824094351091914, 
      0.7010607802851191, -0.01805311449806976}, {-0.9824094351091915, 
      0.701060780285119, -0.01805311449806976}, {-0.9736141526637873, 
      0.5515911704276786, -0.027079671747104638`}}], 
     Polygon3DBox[{{-0.9824094351091915, 
      0.701060780285119, -0.01805311449806976}, {-0.9824094351091914, 
      0.7010607802851191, -0.01805311449806976}, {-0.9912047175545957, 
      0.8505303901425595, -0.009026557249034886}, {-0.9912047175545957, 
      0.8505303901425595, -0.00902655724903488}, {-0.9824094351091915, 
      0.701060780285119, -0.01805311449806976}}], 
     Polygon3DBox[{{-0.9912047175545957, 
      0.8505303901425595, -0.00902655724903488}, {-0.9912047175545957, 
      0.8505303901425595, -0.009026557249034886}, {-0.9999999999999999, 
      0.9999999999999999, -8.011100855739472*^-18}, {-1., 1., 
      0.}, {-0.9912047175545957, 0.8505303901425595, -0.00902655724903488}}], 
     Polygon3DBox[{{-1., 1., 0.}, {-1., 
      1., -1.3301063950890472`*^-18}, {-1.0087952824454043`, 
      1.1494696098574404`, 0.009026557249034875}, {-1.0087952824454043`, 
      1.1494696098574404`, 0.009026557249034877}, {-1., 1., 0.}}], 
     Polygon3DBox[{{-1.0087952824454043`, 1.1494696098574404`, 
      0.009026557249034877}, {-1.0087952824454043`, 1.1494696098574404`, 
      0.009026557249034875}, {-1.0175905648908083`, 1.2989392197148808`, 
      0.018053114498069754`}, {-1.0175905648908086`, 1.2989392197148808`, 
      0.018053114498069758`}, {-1.0087952824454043`, 1.1494696098574404`, 
      0.009026557249034877}}], 
     Polygon3DBox[{{-1.0175905648908086`, 1.2989392197148808`, 
      0.018053114498069758`}, {-1.0175905648908083`, 1.2989392197148808`, 
      0.018053114498069754`}, {-1.0263858473362126`, 1.4484088295723212`, 
      0.027079671747104635`}, {-1.0263858473362126`, 1.4484088295723212`, 
      0.02707967174710463}, {-1.0175905648908086`, 1.2989392197148808`, 
      0.018053114498069758`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ68WPjeDfX3+0/93N62aNlD+8+GmkzHds3ez5ub
9PJp/vv9bcuqWMTzn9n/OF3A2FIzaX+b2cYvn7a/3+8cbNvUbf4aKt60nwEM
PsBo+4/Bgmvbzvvt2ZuyvJVN5cP+uLCHdlYpn+y/QdTbV5304+b1+LB/z5pD
tSUnvth/h5hvb6b3bYJwzof9UsxL9qzT+W7/EeIeuLg0VBzqTrg5e6HmQN1p
j24v1J32ONxpA/OXC9RfUHfCw6EdGg5Qd+6HhdsZaLhB3bkfV3gCAH/3tpE=

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4490531449080963`, 0.9729203282528953, 
        0.010861142951707538`}, {-1.4490531449080963`, 0.9729203282528954, 
        0.010861142951707542`}, {-1.299368763272064, 0.9819468855019303, 
        0.007240761967805027}, {-1.299368763272064, 0.9819468855019302, 
        0.007240761967805026}, {-1.4490531449080963`, 0.9729203282528953, 
        0.010861142951707538`}}], 
       Polygon3DBox[{{-1.299368763272064, 0.9819468855019302, 
        0.007240761967805026}, {-1.299368763272064, 0.9819468855019303, 
        0.007240761967805027}, {-1.1496843816360323`, 0.9909734427509651, 
        0.0036203809839025166`}, {-1.149684381636032, 0.9909734427509651, 
        0.003620380983902514}, {-1.299368763272064, 0.9819468855019302, 
        0.007240761967805026}}], 
       Polygon3DBox[{{-1.149684381636032, 0.9909734427509651, 
        0.003620380983902514}, {-1.1496843816360323`, 0.9909734427509651, 
        0.0036203809839025166`}, {-1.0000000000000002`, 1., 
        4.337771883848401*^-18}, {-1., 1., 
        1.6581516663526353`*^-18}, {-1.149684381636032, 0.9909734427509651, 
        0.003620380983902514}}], 
       Polygon3DBox[{{-1., 1., 1.6581516663526353`*^-18}, {-1., 1., 
        1.6581516663526353`*^-18}, {-0.850315618363968, 
        1.009026557249035, -0.00362038098390251}, {-0.850315618363968, 
        1.009026557249035, -0.0036203809839025092`}, {-1., 1., 
        1.6581516663526353`*^-18}}], 
       Polygon3DBox[{{-0.850315618363968, 
        1.009026557249035, -0.0036203809839025092`}, {-0.850315618363968, 
        1.009026557249035, -0.00362038098390251}, {-0.7006312367279359, 
        1.0180531144980698`, -0.007240761967805022}, {-0.7006312367279359, 
        1.0180531144980698`, -0.007240761967805022}, {-0.850315618363968, 
        1.009026557249035, -0.0036203809839025092`}}], 
       Polygon3DBox[{{-0.7006312367279359, 
        1.0180531144980698`, -0.007240761967805022}, {-0.7006312367279359, 
        1.0180531144980698`, -0.007240761967805022}, {-0.5509468550919039, 
        1.0270796717471047`, -0.010861142951707536`}, {-0.5509468550919039, 
        1.0270796717471047`, -0.010861142951707531`}, {-0.7006312367279359, 
        1.0180531144980698`, -0.007240761967805022}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr23f7jd6F2sXZv9I43q
Z2anvuxfUPnlvnTOe3udrzNsa1fU2hdOsS2WTv20/4LNr/e822DiufYMYPBh
P5S2X6K4ikN4u4WN3PUWyZOmr/fPeMjE8VPlg70mRP1+m3WcxpOyn+03OMwq
8Mnzg702xPz9Ua19PtELH+4/sYRD4nXeB/v7EPfsj0QTh7pzvzWaOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J32wWjhBnWnPa7wBAC1L7HS
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.4226672975718835`, 
      0.524511498680574, -0.0162185287953971}, {-1.475438992244309, 
      1.4213291578252167`, 0.03794081469881218}, {-0.5773327024281165, 
      1.4754885013194259`, 0.0162185287953971}, {-0.524561007755691, 
      0.5786708421747833, -0.03794081469881218}, {-1.4226672975718835`, 
      0.524511498680574, -0.0162185287953971}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}, {-1.475438992244309, 
       1.4213291578252167`, 0.03794081469881218}, {-0.5773327024281165, 
       1.4754885013194259`, 0.0162185287953971}, {-0.524561007755691, 
       0.5786708421747833, -0.03794081469881218}, {-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.947606685296819, 
      1.5562516060395322`, -0.05331325756243699}, {-0.9476066852968189, 
      1.5562516060395322`, -0.05331325756243699}, {-0.9650711235312126, 
      1.7041677373596882`, -0.035542171708291326`}, {-0.9650711235312127, 
      1.704167737359688, -0.03554217170829133}, {-0.947606685296819, 
      1.5562516060395322`, -0.05331325756243699}}], 
     Polygon3DBox[{{-0.9650711235312127, 
      1.704167737359688, -0.03554217170829133}, {-0.9650711235312126, 
      1.7041677373596882`, -0.035542171708291326`}, {-0.9825355617656063, 
      1.852083868679844, -0.017771085854145673`}, {-0.9825355617656063, 
      1.852083868679844, -0.017771085854145666`}, {-0.9650711235312127, 
      1.704167737359688, -0.03554217170829133}}], 
     Polygon3DBox[{{-0.9825355617656063, 
      1.852083868679844, -0.017771085854145666`}, {-0.9825355617656063, 
      1.852083868679844, -0.017771085854145673`}, {-0.9999999999999999, 
      2., -1.3722917061182589`*^-17}, {-1., 2., 0.}, {-0.9825355617656063, 
      1.852083868679844, -0.017771085854145666`}}], 
     Polygon3DBox[{{-1., 2., 0.}, {-1., 
      2., -5.696712692739672*^-19}, {-1.0174644382343936`, 2.147916131320156, 
      0.01777108585414566}, {-1.0174644382343936`, 2.147916131320156, 
      0.01777108585414566}, {-1., 2., 0.}}], 
     Polygon3DBox[{{-1.0174644382343936`, 2.147916131320156, 
      0.01777108585414566}, {-1.0174644382343936`, 2.147916131320156, 
      0.01777108585414566}, {-1.0349288764687874`, 2.295832262640312, 
      0.03554217170829132}, {-1.0349288764687874`, 2.295832262640312, 
      0.035542171708291326`}, {-1.0174644382343936`, 2.147916131320156, 
      0.01777108585414566}}], 
     Polygon3DBox[{{-1.0349288764687874`, 2.295832262640312, 
      0.035542171708291326`}, {-1.0349288764687874`, 2.295832262640312, 
      0.03554217170829132}, {-1.052393314703181, 2.443748393960468, 
      0.05331325756243699}, {-1.052393314703181, 2.4437483939604676`, 
      0.05331325756243698}, {-1.0349288764687874`, 2.295832262640312, 
      0.035542171708291326`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZyiXI8HfRu/9IZLaIZz37YB3BECj/wXr0/XNfm
2p2H7/ZL7F6b7Ory2/5hlHXSVKNF+1eLyWW/K3i/v+futY1Ki/5CxSftZwCD
D1CaweH0myQ/v5C4Pau+FJzqcP+w32qiyPJ3eowO9yHq7UNfPpwi2P9hf4mS
pt/dWCaHBxDz7f/fDYqfde3D/rWbbb+e7mF28Ie4By6+DioOdSeGOVB32qPb
C3WnPQ532qD7C+pOeDhIQsMB6s796OEGdSeGOCw8AXyEqfs=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4468065107841634`, 1.9466867424375631`, 
        0.004651718925575885}, {-1.4468065107841634`, 1.9466867424375631`, 
        0.004651718925575892}, {-1.2978710071894421`, 1.9644578282917087`, 
        0.0031011459503839287`}, {-1.2978710071894421`, 1.9644578282917087`, 
        0.003101145950383925}, {-1.4468065107841634`, 1.9466867424375631`, 
        0.004651718925575885}}], 
       Polygon3DBox[{{-1.2978710071894421`, 1.9644578282917087`, 
        0.003101145950383925}, {-1.2978710071894421`, 1.9644578282917087`, 
        0.0031011459503839287`}, {-1.1489355035947213`, 1.9822289141458544`, 
        0.0015505729751919667`}, {-1.148935503594721, 1.9822289141458544`, 
        0.001550572975191964}, {-1.2978710071894421`, 1.9644578282917087`, 
        0.003101145950383925}}], 
       Polygon3DBox[{{-1.148935503594721, 1.9822289141458544`, 
        0.001550572975191964}, {-1.1489355035947213`, 1.9822289141458544`, 
        0.0015505729751919667`}, {-1.0000000000000002`, 2., 
        4.412150056910943*^-18}, {-1., 2., 
        3.264495511297844*^-18}, {-1.148935503594721, 1.9822289141458544`, 
        0.001550572975191964}}], 
       Polygon3DBox[{{-1., 2., 3.264495511297844*^-18}, {-1., 2., 
        3.264495511297844*^-18}, {-0.8510644964052789, 
        2.0177710858541458`, -0.001550572975191959}, {-0.8510644964052789, 
        2.0177710858541458`, -0.0015505729751919568`}, {-1., 2., 
        3.264495511297844*^-18}}], 
       Polygon3DBox[{{-0.8510644964052789, 
        2.0177710858541458`, -0.0015505729751919568`}, {-0.8510644964052789, 
        2.0177710858541458`, -0.001550572975191959}, {-0.7021289928105579, 
        2.0355421717082915`, -0.003101145950383921}, {-0.7021289928105579, 
        2.0355421717082915`, -0.0031011459503839174`}, {-0.8510644964052789, 
        2.0177710858541458`, -0.0015505729751919568`}}], 
       Polygon3DBox[{{-0.7021289928105579, 
        2.0355421717082915`, -0.0031011459503839174`}, {-0.7021289928105579, 
        2.0355421717082915`, -0.003101145950383921}, {-0.5531934892158368, 
        2.053313257562437, -0.004651718925575884}, {-0.5531934892158368, 
        2.053313257562437, -0.004651718925575876}, {-0.7021289928105579, 
        2.0355421717082915`, -0.0031011459503839174`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/bX+ev9VrHW2xv92hJ
ssiRL/s1Vd+FZOf9t5cX/cM7OT3TXr7wkiFX0qf9U4TKV5luh4lH2jOAwYf9
EJrBYaZgkNlSbVWbQ7LRc15bv96/reyIVqoKg4MMRP3+FuttFtfLn+3PedsR
esqDwUEOYv5+t0jBq4c2P9yvmOLboJ/L4HAV4p79rmjiUHfub0YzB+rO/ej2
Qt25H4c798D8NRXqL6g7McIB6k77WLRwg7rTHld4AgCpBpkt
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.3944131960809822`, 
      1.502938348477095, -0.0486615386368611}, {-1.4991998254873442`, 
      2.3904351363980307`, 0.057964976488012875`}, {-0.6055868039190176, 
      2.497061651522905, 0.0486615386368611}, {-0.5008001745126557, 
      1.609564863601969, -0.057964976488012875`}, {-1.3944131960809822`, 
      1.502938348477095, -0.0486615386368611}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}, {-1.4991998254873442`, 
       2.3904351363980307`, 0.057964976488012875`}, {-0.6055868039190176, 
       2.497061651522905, 0.0486615386368611}, {-0.5008001745126557, 
       1.609564863601969, -0.057964976488012875`}, {-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.9223285647143799, 
      2.563661432713972, -0.07794743638791615}, {-0.9223285647143797, 
      2.563661432713972, -0.07794743638791615}, {-0.9482190431429198, 
      2.7091076218093146`, -0.0519649575919441}, {-0.9482190431429198, 
      2.7091076218093146`, -0.051964957591944104`}, {-0.9223285647143799, 
      2.563661432713972, -0.07794743638791615}}], 
     Polygon3DBox[{{-0.9482190431429198, 
      2.7091076218093146`, -0.051964957591944104`}, {-0.9482190431429198, 
      2.7091076218093146`, -0.0519649575919441}, {-0.9741095215714599, 
      2.8545538109046573`, -0.025982478795972062`}, {-0.9741095215714599, 
      2.8545538109046573`, -0.025982478795972052`}, {-0.9482190431429198, 
      2.7091076218093146`, -0.051964957591944104`}}], 
     Polygon3DBox[{{-0.9741095215714599, 
      2.8545538109046573`, -0.025982478795972052`}, {-0.9741095215714599, 
      2.8545538109046573`, -0.025982478795972062`}, {-0.9999999999999999, 
      3., -1.858688791924758*^-17}, {-1., 3., 0.}, {-0.9741095215714599, 
      2.8545538109046573`, -0.025982478795972052`}}], 
     Polygon3DBox[{{-1., 3., 0.}, {-1., 3., 
      6.440095448344769*^-19}, {-1.02589047842854, 3.1454461890953427`, 
      0.02598247879597204}, {-1.02589047842854, 3.1454461890953427`, 
      0.02598247879597204}, {-1., 3., 0.}}], 
     Polygon3DBox[{{-1.02589047842854, 3.1454461890953427`, 
      0.02598247879597204}, {-1.02589047842854, 3.1454461890953427`, 
      0.02598247879597204}, {-1.0517809568570802`, 3.2908923781906854`, 
      0.05196495759194408}, {-1.0517809568570802`, 3.2908923781906854`, 
      0.0519649575919441}, {-1.02589047842854, 3.1454461890953427`, 
      0.02598247879597204}}], 
     Polygon3DBox[{{-1.0517809568570802`, 3.2908923781906854`, 
      0.0519649575919441}, {-1.0517809568570802`, 3.2908923781906854`, 
      0.05196495759194408}, {-1.0776714352856203`, 3.436338567286028, 
      0.07794743638791614}, {-1.07767143528562, 3.436338567286028, 
      0.07794743638791612}, {-1.0517809568570802`, 3.2908923781906854`, 
      0.0519649575919441}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZeu9lwe/Pb/Ur6d94kNLE4cN0Q/xXzZfP+PSfK
y86Hv9ufI/9irsMaVofk0lOL1Gav2h/3xHr3c+33+7fxf/FTuMYGFZ+1nwEM
PkBpDgf17Svav2qn7bnIm6TEk/Vhv9cH7o33NTkdEiDq7RdJH3GRuPJh/5QH
4kn7g7kckiDm2xdpqqWr2H3cf++CsvD8Wm4HDoh77IvRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3bl/L1o4QN25Hz3coO7EEIeFJwAEq6hk
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.443166495626191, 
        2.922052563612084, -0.005258737011217123}, {-1.443166495626191, 
        2.922052563612084, -0.0052587370112171135`}, {-1.2954443304174605`, 
        2.948035042408056, -0.0035058246741447407`}, {-1.2954443304174608`, 
        2.9480350424080557`, -0.0035058246741447477`}, {-1.443166495626191, 
        2.922052563612084, -0.005258737011217123}}], 
       Polygon3DBox[{{-1.2954443304174608`, 
        2.9480350424080557`, -0.0035058246741447477`}, {-1.2954443304174605`, 
        2.948035042408056, -0.0035058246741447407`}, {-1.1477221652087304`, 
        2.974017521204028, -0.001752912337072369}, {-1.1477221652087304`, 
        2.974017521204028, -0.0017529123370723715`}, {-1.2954443304174608`, 
        2.9480350424080557`, -0.0035058246741447477`}}], 
       Polygon3DBox[{{-1.1477221652087304`, 
        2.974017521204028, -0.0017529123370723715`}, {-1.1477221652087304`, 
        2.974017521204028, -0.001752912337072369}, {-1.0000000000000002`, 3., 
        3.475488165865344*^-18}, {-1., 3., 
        4.7729039237101715`*^-18}, {-1.1477221652087304`, 
        2.974017521204028, -0.0017529123370723715`}}], 
       Polygon3DBox[{{-1., 3., 4.7729039237101715`*^-18}, {-1., 3., 
        4.7729039237101715`*^-18}, {-0.8522778347912697, 3.025982478795972, 
        0.0017529123370723773`}, {-0.8522778347912697, 3.025982478795972, 
        0.0017529123370723803`}, {-1., 3., 4.7729039237101715`*^-18}}], 
       Polygon3DBox[{{-0.8522778347912697, 3.025982478795972, 
        0.0017529123370723803`}, {-0.8522778347912697, 3.025982478795972, 
        0.0017529123370723773`}, {-0.7045556695825395, 3.0519649575919443`, 
        0.00350582467414475}, {-0.7045556695825395, 3.0519649575919443`, 
        0.0035058246741447563`}, {-0.8522778347912697, 3.025982478795972, 
        0.0017529123370723803`}}], 
       Polygon3DBox[{{-0.7045556695825395, 3.0519649575919443`, 
        0.0035058246741447563`}, {-0.7045556695825395, 3.0519649575919443`, 
        0.00350582467414475}, {-0.5568335043738092, 3.077947436387916, 
        0.005258737011217123}, {-0.5568335043738093, 3.077947436387916, 
        0.005258737011217132}, {-0.7045556695825395, 3.0519649575919443`, 
        0.0035058246741447563`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBHaH+382l+t3le5/9Lzv
qvKuL/u1rpWkTp7K7qAd6OplvyNn/8fi468EYz/tF83etenkKZh4zH4GMPgA
pTkcfkj0Z9x/p75HXqJQ647r6/2vp7j6mplyOGhA1NvbGTwK2dH9bP81ze5Z
OVkcDpoQ8+3jPILrp1x8uP/AvgvPF83ncLgHcY99DJo41J32tmjmQN1pL4dm
L9Sd9jjcafMBzV9Qd+5/iBYOUHfuv4gWblB37scVngAIQqJs
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.3654950603405707`, 
      2.485713996326056, -0.08320617339913328}, {-1.520837930911811, 
      3.358391130898112, 0.07268869937669903}, {-0.6345049396594293, 
      3.514286003673944, 0.08320617339913328}, {-0.4791620690881889, 
      2.641608869101888, -0.07268869937669903}, {-1.3654950603405707`, 
      2.485713996326056, -0.08320617339913328}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}, {-1.520837930911811, 
       3.358391130898112, 0.07268869937669903}, {-0.6345049396594293, 
       3.514286003673944, 0.08320617339913328}, {-0.4791620690881889, 
       2.641608869101888, -0.07268869937669903}, {-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.8980803760926472, 
      3.57334619547276, -0.10039383120996832`}, {-0.8980803760926471, 
      3.57334619547276, -0.10039383120996832`}, {-0.9320535840617648, 
      3.7155641303151734`, -0.06692922080664555}, {-0.9320535840617648, 
      3.7155641303151734`, -0.06692922080664557}, {-0.8980803760926472, 
      3.57334619547276, -0.10039383120996832`}}], 
     Polygon3DBox[{{-0.9320535840617648, 
      3.7155641303151734`, -0.06692922080664557}, {-0.9320535840617648, 
      3.7155641303151734`, -0.06692922080664555}, {-0.9660267920308823, 
      3.8577820651575867`, -0.03346461040332279}, {-0.9660267920308824, 
      3.8577820651575867`, -0.033464610403322784`}, {-0.9320535840617648, 
      3.7155641303151734`, -0.06692922080664557}}], 
     Polygon3DBox[{{-0.9660267920308824, 
      3.8577820651575867`, -0.033464610403322784`}, {-0.9660267920308823, 
      3.8577820651575867`, -0.03346461040332279}, {-0.9999999999999999, 
      4., -2.2529618039976242`*^-17}, {-1., 4., 0.}, {-0.9660267920308824, 
      3.8577820651575867`, -0.033464610403322784`}}], 
     Polygon3DBox[{{-1., 4., 0.}, {-1., 4., 
      2.2391692799434193`*^-18}, {-1.0339732079691175`, 4.142217934842413, 
      0.03346461040332277}, {-1.0339732079691175`, 4.142217934842413, 
      0.03346461040332277}, {-1., 4., 0.}}], 
     Polygon3DBox[{{-1.0339732079691175`, 4.142217934842413, 
      0.03346461040332277}, {-1.0339732079691175`, 4.142217934842413, 
      0.03346461040332277}, {-1.0679464159382352`, 4.284435869684827, 
      0.06692922080664554}, {-1.0679464159382352`, 4.284435869684827, 
      0.06692922080664555}, {-1.0339732079691175`, 4.142217934842413, 
      0.03346461040332277}}], 
     Polygon3DBox[{{-1.0679464159382352`, 4.284435869684827, 
      0.06692922080664555}, {-1.0679464159382352`, 4.284435869684827, 
      0.06692922080664554}, {-1.1019196239073528`, 4.4266538045272394`, 
      0.10039383120996831`}, {-1.1019196239073528`, 4.4266538045272394`, 
      0.10039383120996831`}, {-1.0679464159382352`, 4.284435869684827, 
      0.06692922080664555}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH70sp9PeO+b/cW7t7WbTeNxiA0/8jdj887909y2
ciZdfrt/kfr59ZU7eR1ePWn656q0cb/34lssG1++239x8vPre+7wQcUX7mcA
gw9QWsChpVZ/RUlfzp6odZNq1bs/7Bc345mycKKAwwuIevutMaq//cQ+7tfP
kdBwVhZ0eAkx356fe0dF2cKP+90Wqex5skXQIQbiHgxxqDsxzIG60x7dXqg7
7XG40wbdX1B37p+OFg5Qd+6HhVsJNNyg7tyPKzwBfomzNA==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4382770431043812`, 
        3.8996061687900316`, -0.018284204731539053`}, {-1.4382770431043812`, 
        3.8996061687900316`, -0.01828420473153904}, {-1.2921846954029208`, 
        3.9330707791933546`, -0.012189469821026025`}, {-1.2921846954029208`, 
        3.9330707791933546`, -0.012189469821026035`}, {-1.4382770431043812`, 
        3.8996061687900316`, -0.018284204731539053`}}], 
       Polygon3DBox[{{-1.2921846954029208`, 
        3.9330707791933546`, -0.012189469821026035`}, {-1.2921846954029208`, 
        3.9330707791933546`, -0.012189469821026025`}, {-1.1460923477014604`, 
        3.966535389596677, -0.006094734910513013}, {-1.1460923477014604`, 
        3.966535389596677, -0.006094734910513014}, {-1.2921846954029208`, 
        3.9330707791933546`, -0.012189469821026035`}}], 
       Polygon3DBox[{{-1.1460923477014604`, 
        3.966535389596677, -0.006094734910513014}, {-1.1460923477014604`, 
        3.966535389596677, -0.006094734910513013}, {-1.0000000000000002`, 4., 
        1.6363391845125063`*^-18}, {-1., 4., 
        6.147349202271368*^-18}, {-1.1460923477014604`, 
        3.966535389596677, -0.006094734910513014}}], 
       Polygon3DBox[{{-1., 4., 6.147349202271368*^-18}, {-1., 4., 
        6.147349202271368*^-18}, {-0.8539076522985396, 4.033464610403323, 
        0.006094734910513021}, {-0.8539076522985396, 4.033464610403323, 
        0.0060947349105130244`}, {-1., 4., 6.147349202271368*^-18}}], 
       Polygon3DBox[{{-0.8539076522985396, 4.033464610403323, 
        0.0060947349105130244`}, {-0.8539076522985396, 4.033464610403323, 
        0.006094734910513021}, {-0.7078153045970793, 4.066929220806646, 
        0.012189469821026035`}, {-0.7078153045970792, 4.066929220806646, 
        0.012189469821026045`}, {-0.8539076522985396, 4.033464610403323, 
        0.0060947349105130244`}}], 
       Polygon3DBox[{{-0.7078153045970792, 4.066929220806646, 
        0.012189469821026045`}, {-0.7078153045970793, 4.066929220806646, 
        0.012189469821026035`}, {-0.561722956895619, 4.100393831209968, 
        0.01828420473153905}, {-0.561722956895619, 4.100393831209969, 
        0.018284204731539064`}, {-0.7078153045970792, 4.066929220806646, 
        0.012189469821026045`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPE7eN7ONpXYOWm/SfSn
2yfXfNl/8wX3hbdl/A5JKk8/nvrWsX+W7s+3KWGf9ud8YX1RthsmXrGfAQw+
QGkBh8B5L+VWnnXZc2YJr4pZ8Ov9p1j/drsoCTgkQNTbz/CU9shZ9mz/FO5f
4p0uAg6JEPPt095p5Cz6+XB/rOD3xWfTBBw8IO6xT0UTh7oTwxyoO+3R7YW6
0x6HO23Q/QV1J0Y4QN25/yxauEHduR9XeAIAhpuyvw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.3363574191970282`, 
      3.4729523642627917`, -0.11867803594150737`}, {-1.5401966670117337`, 
      4.3262599733172715`, 0.08210962647842927}, {-0.6636425808029717, 
      4.527047635737208, 0.11867803594150737`}, {-0.45980333298826614`, 
      3.6737400266827285`, -0.08210962647842927}, {-1.3363574191970282`, 
      3.4729523642627917`, -0.11867803594150737`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}, {-1.5401966670117337`, 
       4.3262599733172715`, 0.08210962647842927}, {-0.6636425808029717, 
       4.527047635737208, 0.11867803594150737`}, {-0.45980333298826614`, 
       3.6737400266827285`, -0.08210962647842927}, {-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.8750970053838931, 
      4.584747088259353, -0.12026745705652335`}, {-0.875097005383893, 
      4.584747088259353, -0.12026745705652334`}, {-0.9167313369225953, 
      4.723164725506235, -0.0801783047043489}, {-0.9167313369225955, 
      4.723164725506235, -0.08017830470434892}, {-0.8750970053838931, 
      4.584747088259353, -0.12026745705652335`}}], 
     Polygon3DBox[{{-0.9167313369225955, 
      4.723164725506235, -0.08017830470434892}, {-0.9167313369225953, 
      4.723164725506235, -0.0801783047043489}, {-0.9583656684612977, 
      4.861582362753118, -0.040089152352174466`}, {-0.9583656684612977, 
      4.861582362753118, -0.04008915235217446}, {-0.9167313369225955, 
      4.723164725506235, -0.08017830470434892}}], 
     Polygon3DBox[{{-0.9583656684612977, 
      4.861582362753118, -0.04008915235217446}, {-0.9583656684612977, 
      4.861582362753118, -0.040089152352174466`}, {-0.9999999999999999, 
      5., -2.5541519676582315`*^-17}, {-1., 5., 0.}, {-0.9583656684612977, 
      4.861582362753118, -0.04008915235217446}}], 
     Polygon3DBox[{{-1., 5., 0.}, {-1., 5., 
      4.130413642810902*^-18}, {-1.0416343315387022`, 5.138417637246882, 
      0.040089152352174445`}, {-1.0416343315387022`, 5.138417637246882, 
      0.040089152352174445`}, {-1., 5., 0.}}], 
     Polygon3DBox[{{-1.0416343315387022`, 5.138417637246882, 
      0.040089152352174445`}, {-1.0416343315387022`, 5.138417637246882, 
      0.040089152352174445`}, {-1.0832686630774044`, 5.276835274493765, 
      0.08017830470434889}, {-1.0832686630774047`, 5.276835274493765, 
      0.0801783047043489}, {-1.0416343315387022`, 5.138417637246882, 
      0.040089152352174445`}}], 
     Polygon3DBox[{{-1.0832686630774047`, 5.276835274493765, 
      0.0801783047043489}, {-1.0832686630774044`, 5.276835274493765, 
      0.08017830470434889}, {-1.1249029946161069`, 5.415252911740647, 
      0.12026745705652334`}, {-1.1249029946161069`, 5.415252911740647, 
      0.12026745705652332`}, {-1.0832686630774047`, 5.276835274493765, 
      0.0801783047043489}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG4pjMs/zfBmvyvrpQ/Hw4Qcdm+6InXz5L79zAtf
frkT+na/3joz79YnQg51Z3r3TGjbsr/xQknVu1Xv9ouHz17qVCQMFV+ynwEM
PkBpEYcMrbJPZ6UK9+yffvRQx6oP+1+uSIna2yviUANRb1+v390qGPpx/6XA
k1uqpEUdaiHm29sdD/CY9f/j/t2/dPktVoo67IS4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAAzVuPs=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-1.4323172471057517`, 
        4.879732542943477, -0.03372738691422422}, {-1.4323172471057517`, 
        4.879732542943477, -0.03372738691422421}, {-1.288211498070501, 
        4.919821695295651, -0.022484924609482797`}, {-1.288211498070501, 
        4.919821695295651, -0.022484924609482815`}, {-1.4323172471057517`, 
        4.879732542943477, -0.03372738691422422}}], 
       Polygon3DBox[{{-1.288211498070501, 
        4.919821695295651, -0.022484924609482815`}, {-1.288211498070501, 
        4.919821695295651, -0.022484924609482797`}, {-1.1441057490352506`, 
        4.9599108476478255`, -0.011242462304741402`}, {-1.1441057490352506`, 
        4.9599108476478255`, -0.011242462304741404`}, {-1.288211498070501, 
        4.919821695295651, -0.022484924609482815`}}], 
       Polygon3DBox[{{-1.1441057490352506`, 
        4.9599108476478255`, -0.011242462304741404`}, {-1.1441057490352506`, 
        4.9599108476478255`, -0.011242462304741402`}, {-1.0000000000000002`, 
        5., -9.568358531763859*^-19}, {-1., 5., 
        7.364257816293155*^-18}, {-1.1441057490352506`, 
        4.9599108476478255`, -0.011242462304741404`}}], 
       Polygon3DBox[{{-1., 5., 7.364257816293155*^-18}, {-1., 5., 
        7.364257816293155*^-18}, {-0.8558942509647495, 5.0400891523521745`, 
        0.011242462304741409`}, {-0.8558942509647495, 5.0400891523521745`, 
        0.011242462304741414`}, {-1., 5., 7.364257816293155*^-18}}], 
       Polygon3DBox[{{-0.8558942509647495, 5.0400891523521745`, 
        0.011242462304741414`}, {-0.8558942509647495, 5.0400891523521745`, 
        0.011242462304741409`}, {-0.7117885019294989, 5.080178304704349, 
        0.02248492460948281}, {-0.7117885019294989, 5.080178304704349, 
        0.022484924609482825`}, {-0.8558942509647495, 5.0400891523521745`, 
        0.011242462304741414`}}], 
       Polygon3DBox[{{-0.7117885019294989, 5.080178304704349, 
        0.022484924609482825`}, {-0.7117885019294989, 5.080178304704349, 
        0.02248492460948281}, {-0.5676827528942485, 5.120267457056523, 
        0.033727386914224215`}, {-0.5676827528942485, 5.120267457056523, 
        0.03372738691422423}, {-0.7117885019294989, 5.080178304704349, 
        0.022484924609482825`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBF2kEjs9d/usnC/5JYX
K5rnfNl/7gTv3qdrhR0UddL3e7JN388bVXLF0e/T/vQnbfc+XYOJt+9nAIMP
UFrE4eiSBvkX+sF7nnuLh9ckv94/U7pSkVdTxEEOot7+3HS9dT+OPdtvZP7J
SSpIxEEeYr79tseurKVaj/afDspOUa8WcRCHuMd+K5o41J0Y5kDdaY9uL9Sd
9jjcacOD5i+oOzHCAerO/apo4QZ1535c4QkAE6acfw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-1.3074142524896448`, 
      4.464479631202829, -0.15399484397074759`}, {-1.5572202417218586`, 
      5.294985454684124, 0.08654007014229913}, {-0.6925857475103553, 
      5.535520368797171, 0.15399484397074759`}, {-0.44277975827814153`, 
      4.705014545315876, -0.08654007014229913}, {-1.3074142524896448`, 
      4.464479631202829, -0.15399484397074759`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}, {-1.5572202417218586`, 
       5.294985454684124, 0.08654007014229913}, {-0.6925857475103553, 
       5.535520368797171, 0.15399484397074759`}, {-0.44277975827814153`, 
       4.705014545315876, -0.08654007014229913}, {-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.12702537303504904`, -5.415087291346398, 
      0.11860478560334935`}, {-0.12702537303504893`, -5.415087291346399, 
      0.11860478560334936`}, {-0.08468358202336594, -5.276724860897599, 
      0.07906985706889957}, {-0.08468358202336604, -5.276724860897599, 
      0.07906985706889957}, {-0.12702537303504904`, -5.415087291346398, 
      0.11860478560334935`}}], 
     Polygon3DBox[{{-0.08468358202336604, -5.276724860897599, 
      0.07906985706889957}, {-0.08468358202336594, -5.276724860897599, 
      0.07906985706889957}, {-0.042341791011682964`, -5.1383624304488, 
      0.03953492853444981}, {-0.04234179101168302, -5.138362430448799, 
      0.03953492853444979}, {-0.08468358202336604, -5.276724860897599, 
      0.07906985706889957}}], 
     Polygon3DBox[{{-0.04234179101168302, -5.138362430448799, 
      0.03953492853444979}, {-0.042341791011682964`, -5.1383624304488, 
      0.03953492853444981}, {2.150773786538172*^-17, -5., 
      3.502712881496442*^-17}, {0., -5., 
      0.}, {-0.04234179101168302, -5.138362430448799, 0.03953492853444979}}], 
     Polygon3DBox[{{0., -5., 0.}, {5.284695872207303*^-17, -5., 
      5.765403524393586*^-18}, {
      0.04234179101168303, -4.861637569551201, -0.039534928534449766`}, {
      0.042341791011683, -4.861637569551201, -0.03953492853444977}, {0., -5., 
      0.}}], Polygon3DBox[{{
      0.042341791011683, -4.861637569551201, -0.03953492853444977}, {
      0.04234179101168303, -4.861637569551201, -0.039534928534449766`}, {
      0.08468358202336601, -4.723275139102401, -0.07906985706889955}, {
      0.08468358202336602, -4.723275139102401, -0.07906985706889956}, {
      0.042341791011683, -4.861637569551201, -0.03953492853444977}}], 
     Polygon3DBox[{{
      0.08468358202336602, -4.723275139102401, -0.07906985706889956}, {
      0.08468358202336601, -4.723275139102401, -0.07906985706889955}, {
      0.12702537303504902`, -4.584912708653602, -0.11860478560334933`}, {
      0.12702537303504902`, -4.584912708653602, -0.11860478560334932`}, {
      0.08468358202336602, -4.723275139102401, -0.07906985706889956}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczqwf7Hr1CU8K0UPSB8OkH4Us8/+UabP
/ktrt+7P1eM7HCsteiDjuqnQG9stUPGl+83E2x+u6xWBii+xf8Yk6nVLoGgP
AxiIHLjWcX2ny70Cm/sQ9fanXlTIBRYJH0iDqN//EGK+/eSLH20WPRE6kA4x
f38GxD32sbuyoj+HCR2QhLhnfyaaONSd+x+hmQN1J1QcYS/Unfuh7rRBc+ee
+2j+grrT/iFaOEDdaZ+BFm5Qd9rjCk8A7DCuRg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.43152816598930516`, -4.881395214396651, \
-0.04707809246231391}, {-0.43152816598930516`, -4.881395214396651, \
-0.047078092462313925`}, {-0.2876854439928701, -4.9209301429311, \
-0.03138539497487595}, {-0.28768544399287016`, -4.9209301429311, \
-0.03138539497487594}, {-0.43152816598930516`, -4.881395214396651, \
-0.04707809246231391}}], 
       Polygon3DBox[{{-0.28768544399287016`, -4.9209301429311, \
-0.03138539497487594}, {-0.2876854439928701, -4.9209301429311, \
-0.03138539497487595}, {-0.1438427219964351, -4.96046507146555, \
-0.015692697487437988`}, {-0.14384272199643508`, -4.96046507146555, \
-0.015692697487437974`}, {-0.28768544399287016`, -4.9209301429311, \
-0.03138539497487594}}], 
       Polygon3DBox[{{-0.14384272199643508`, -4.96046507146555, \
-0.015692697487437974`}, {-0.1438427219964351, -4.96046507146555, \
-0.015692697487437988`}, {-9.868694043190486*^-17, -5., \
-1.887737793198898*^-17}, {
        7.778060824893566*^-18, -5., -7.262448552634993*^-18}, \
{-0.14384272199643508`, -4.96046507146555, -0.015692697487437974`}}], 
       Polygon3DBox[{{7.778060824893566*^-18, -5., -7.262448552634993*^-18}, {
        7.778060824893566*^-18, -5., -7.262448552634993*^-18}, {
        0.14384272199643502`, -5.03953492853445, 0.015692697487437963`}, {
        0.14384272199643502`, -5.03953492853445, 0.015692697487437957`}, {
        7.778060824893566*^-18, -5., -7.262448552634993*^-18}}], 
       Polygon3DBox[{{0.14384272199643502`, -5.03953492853445, 
        0.015692697487437957`}, {0.14384272199643502`, -5.03953492853445, 
        0.015692697487437963`}, {0.28768544399287005`, -5.0790698570689, 
        0.031385394974875934`}, {0.2876854439928701, -5.0790698570689, 
        0.03138539497487592}, {0.14384272199643502`, -5.03953492853445, 
        0.015692697487437957`}}], 
       Polygon3DBox[{{0.2876854439928701, -5.0790698570689, 
        0.03138539497487592}, {0.28768544399287005`, -5.0790698570689, 
        0.031385394974875934`}, {0.4315281659893051, -5.118604785603349, 
        0.047078092462313904`}, {0.43152816598930505`, -5.118604785603349, 
        0.047078092462313884`}, {0.2876854439928701, -5.0790698570689, 
        0.03138539497487592}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAkfuLb8+7J5Uiv2f2eO
Ny3IvLR/kcZ2f471wgee5P+S3C+4ACp+aH/glNvqLddh4hP2v4+ex7x7fd8e
BjAQOaCWurDB7kTUnq8Q9fbrs1VuVGuIHHgMUW//DWK+fdx1jw3fA2DiC+zf
Q9xjz+Oc21FcKXLgCsQ99h/RxKHutP+OZg7UnVBxhL1Qd9pD3WmD5k6br2j+
grpz/ze0cIC6c/97tHCDunM/rvAEANbYspU=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.5585535390243542, -5.296482505743049, 
      0.07152669314103544}, {-0.3045027929542561, -4.466307923050252, \
-0.16568287806566326`}, {
      0.5585535390243542, -4.703517494256951, -0.07152669314103544}, {
      0.3045027929542561, -5.533692076949748, 
      0.16568287806566326`}, {-0.5585535390243542, -5.296482505743049, 
      0.07152669314103544}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}, {-0.3045027929542561, -4.466307923050252, \
-0.16568287806566326`}, {
       0.5585535390243542, -4.703517494256951, -0.07152669314103544}, {
       0.3045027929542561, -5.533692076949748, 
       0.16568287806566326`}, {-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.10377923337074094`, -4.426488166154326, 
      0.0991852552111543}, {-0.10377923337074083`, -4.426488166154326, 
      0.09918525521115432}, {-0.06918615558049386, -4.284325444102883, 
      0.06612350347410287}, {-0.06918615558049396, -4.284325444102883, 
      0.06612350347410288}, {-0.10377923337074094`, -4.426488166154326, 
      0.0991852552111543}}], 
     Polygon3DBox[{{-0.06918615558049396, -4.284325444102883, 
      0.06612350347410288}, {-0.06918615558049386, -4.284325444102883, 
      0.06612350347410287}, {-0.03459307779024692, -4.142162722051442, 
      0.033061751737051455`}, {-0.03459307779024698, -4.142162722051442, 
      0.03306175173705144}, {-0.06918615558049396, -4.284325444102883, 
      0.06612350347410288}}], 
     Polygon3DBox[{{-0.03459307779024698, -4.142162722051442, 
      0.03306175173705144}, {-0.03459307779024692, -4.142162722051442, 
      0.033061751737051455`}, {2.801043716368183*^-17, -4., 
      2.833860218723067*^-17}, {0., -4., 
      0.}, {-0.03459307779024698, -4.142162722051442, 0.03306175173705144}}], 
     Polygon3DBox[{{0., -4., 0.}, {5.3614458133936034`*^-17, -4., 
      3.8679901786204944`*^-18}, {
      0.034593077790247, -3.8578372779485584`, -0.03306175173705143}, {
      0.034593077790246965`, -3.8578372779485584`, -0.03306175173705143}, {
      0., -4., 0.}}], 
     Polygon3DBox[{{
      0.034593077790246965`, -3.8578372779485584`, -0.03306175173705143}, {
      0.034593077790247, -3.8578372779485584`, -0.03306175173705143}, {
      0.06918615558049394, -3.7156745558971163`, -0.06612350347410285}, {
      0.06918615558049394, -3.7156745558971163`, -0.06612350347410287}, {
      0.034593077790246965`, -3.8578372779485584`, -0.03306175173705143}}], 
     Polygon3DBox[{{
      0.06918615558049394, -3.7156745558971163`, -0.06612350347410287}, {
      0.06918615558049394, -3.7156745558971163`, -0.06612350347410285}, {
      0.10377923337074092`, -3.5735118338456746`, -0.09918525521115429}, {
      0.10377923337074091`, -3.5735118338456746`, -0.09918525521115427}, {
      0.06918615558049394, -3.7156745558971163`, -0.06612350347410287}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeKu/bp84QE7twgeUJyRUGySstM+5n6v
sP62jftPxPWbqikLHhAXeO1T8XYDVHzh/pT1x6UmTxSAii+wfyc3XeFnS+4e
BjAQOHBe6q5WsVmOTRREvb3FwoJTN+/wHRCFqN8fDTHfPt/p4ZTNO3kPiEHM
388BcY/98seB8b3TeA7IQ9yznwtNHOrO/TFo5kDdCRVH2At1536oO23Q3Lkn
Cs1fUHfaR6OFA9Sd9lB37teBhhvUnfa4whMASwOmrw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4377952742885909, -3.9008147447888457`, \
-0.031584536711430106`}, {-0.4377952742885909, -3.9008147447888457`, \
-0.03158453671143012}, {-0.2918635161923939, -3.933876496525897, \
-0.02105635780762008}, {-0.291863516192394, -3.933876496525897, \
-0.021056357807620076`}, {-0.4377952742885909, -3.9008147447888457`, \
-0.031584536711430106`}}], 
       Polygon3DBox[{{-0.291863516192394, -3.933876496525897, \
-0.021056357807620076`}, {-0.2918635161923939, -3.933876496525897, \
-0.02105635780762008}, {-0.14593175809619705`, -3.9669382482629487`, \
-0.010528178903810049`}, {-0.145931758096197, -3.9669382482629487`, \
-0.01052817890381004}, {-0.291863516192394, -3.933876496525897, \
-0.021056357807620076`}}], 
       Polygon3DBox[{{-0.145931758096197, -3.9669382482629487`, \
-0.01052817890381004}, {-0.14593175809619705`, -3.9669382482629487`, \
-0.010528178903810049`}, {-1.0165655327667877`*^-16, -4., \
-1.38657630167695*^-17}, {
        6.354645298272203*^-18, -4., -6.073345265847672*^-18}, \
{-0.145931758096197, -3.9669382482629487`, -0.01052817890381004}}], 
       Polygon3DBox[{{6.354645298272203*^-18, -4., -6.073345265847672*^-18}, {
        6.354645298272203*^-18, -4., -6.073345265847672*^-18}, {
        0.14593175809619693`, -4.033061751737051, 0.010528178903810028`}, {
        0.14593175809619693`, -4.033061751737051, 0.010528178903810022`}, {
        6.354645298272203*^-18, -4., -6.073345265847672*^-18}}], 
       Polygon3DBox[{{0.14593175809619693`, -4.033061751737051, 
        0.010528178903810022`}, {0.14593175809619693`, -4.033061751737051, 
        0.010528178903810028`}, {0.29186351619239387`, -4.066123503474103, 
        0.02105635780762006}, {0.2918635161923939, -4.066123503474103, 
        0.02105635780762006}, {0.14593175809619693`, -4.033061751737051, 
        0.010528178903810022`}}], 
       Polygon3DBox[{{0.2918635161923939, -4.066123503474103, 
        0.02105635780762006}, {0.29186351619239387`, -4.066123503474103, 
        0.02105635780762006}, {0.43779527428859083`, -4.099185255211154, 
        0.0315845367114301}, {0.4377952742885908, -4.099185255211154, 
        0.031584536711430085`}, {0.2918635161923939, -4.066123503474103, 
        0.02105635780762006}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwHfFwrDG5qL9gv6GET
8GTtpf31y2fYTqngP5AWs8DhTP9UqPih/QeCz8h57YGJt+4/qsR/+6Ji/x4G
MBA4ELKo9cGV74F7+CHq7RWuzfxwS1HgQDJEvb0AxHx7hzXGD7c6CxxIhZhv
LwZxj31C09mLE1IFDnhD3GMPdad9IlQc6k57QTRzoO6EiiPshbrTHupOGzR3
2vCj+Qvqzv0CaOEAded+MbRwg7pzP67wBADkramf
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.5415745076593318, -4.327302910943171, 
      0.0676007184997242}, {-0.33401604091785, -3.4743265786345203`, \
-0.13076979192258442`}, {
      0.5415745076593318, -3.672697089056829, -0.0676007184997242}, {
      0.33401604091785, -4.52567342136548, 
      0.13076979192258442`}, {-0.5415745076593318, -4.327302910943171, 
      0.0676007184997242}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}, {-0.33401604091785, -3.4743265786345203`, \
-0.13076979192258442`}, {
       0.5415745076593318, -3.672697089056829, -0.0676007184997242}, {
       0.33401604091785, -4.52567342136548, 
       0.13076979192258442`}, {-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.07917108577043312, -3.4362141970266387`, 
      0.07713049649999423}, {-0.07917108577043301, -3.4362141970266387`, 
      0.07713049649999423}, {-0.05278072384695533, -3.2908094646844255`, 
      0.051420330999996156`}, {-0.052780723846955424`, -3.290809464684426, 
      0.05142033099999616}, {-0.07917108577043312, -3.4362141970266387`, 
      0.07713049649999423}}], 
     Polygon3DBox[{{-0.052780723846955424`, -3.290809464684426, 
      0.05142033099999616}, {-0.05278072384695533, -3.2908094646844255`, 
      0.051420330999996156`}, {-0.02639036192347765, -3.1454047323422127`, 
      0.02571016549999809}, {-0.026390361923477712`, -3.1454047323422127`, 
      0.02571016549999808}, {-0.052780723846955424`, -3.290809464684426, 
      0.05142033099999616}}], 
     Polygon3DBox[{{-0.026390361923477712`, -3.1454047323422127`, 
      0.02571016549999808}, {-0.02639036192347765, -3.1454047323422127`, 
      0.02571016549999809}, {3.471368212298017*^-17, -3., 
      2.129014906046945*^-17}, {0., -3., 
      0.}, {-0.026390361923477712`, -3.1454047323422127`, 
      0.02571016549999808}}], 
     Polygon3DBox[{{0., -3., 0.}, {5.424647374673748*^-17, -3., 
      2.2608039237886424`*^-18}, {
      0.026390361923477736`, -2.8545952676577873`, -0.02571016549999807}, {
      0.0263903619234777, -2.8545952676577873`, -0.02571016549999807}, {
      0., -3., 0.}}], 
     Polygon3DBox[{{
      0.0263903619234777, -2.8545952676577873`, -0.02571016549999807}, {
      0.026390361923477736`, -2.8545952676577873`, -0.02571016549999807}, {
      0.052780723846955424`, -2.7091905353155745`, -0.05142033099999614}, {
      0.05278072384695542, -2.7091905353155745`, -0.05142033099999615}, {
      0.0263903619234777, -2.8545952676577873`, -0.02571016549999807}}], 
     Polygon3DBox[{{
      0.05278072384695542, -2.7091905353155745`, -0.05142033099999615}, {
      0.052780723846955424`, -2.7091905353155745`, -0.05142033099999614}, {
      0.07917108577043312, -2.5637858029733613`, -0.07713049649999422}, {
      0.07917108577043311, -2.5637858029733613`, -0.0771304964999942}, {
      0.05278072384695542, -2.7091905353155745`, -0.05142033099999615}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2bJf1K7oXmwt9wGzh3//X9q32X5D0ART
YbbV+3fWLXw5OZjrgKfO3/+Hg1dBxWfvj9l/4ctJTU6o+Cz75y4/GAVa0/Yw
gAHHgYn+K1ZVfEi1WQtRb7/EQZ/b7BrbATeI+v3rIebbezTGieWsYT3gDjF/
PxPEPfavD/YqLmpiOWACcc9+ZjRxqDv3Q91p7w41B+pOqDjCXqg790PdaYPm
zj1r0fwFdac91J37d0DDAepOeya0cIO60x5XeAIAsqysoQ==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4429560734123993, -2.9228695035000056`, \
-0.01846086500501779}, {-0.4429560734123993, -2.9228695035000056`, \
-0.018460865005017802`}, {-0.2953040489415995, -2.948579669000004, \
-0.012307243336678535`}, {-0.29530404894159956`, -2.948579669000004, \
-0.01230724333667853}, {-0.4429560734123993, -2.9228695035000056`, \
-0.01846086500501779}}], 
       Polygon3DBox[{{-0.29530404894159956`, -2.948579669000004, \
-0.01230724333667853}, {-0.2953040489415995, -2.948579669000004, \
-0.012307243336678535`}, {-0.14765202447079984`, -2.9742898345000017`, \
-0.0061536216683392726`}, {-0.14765202447079978`, -2.9742898345000017`, \
-0.006153621668339267}, {-0.29530404894159956`, -2.948579669000004, \
-0.01230724333667853}}], 
       Polygon3DBox[{{-0.14765202447079978`, -2.9742898345000017`, \
-0.006153621668339267}, {-0.14765202447079984`, -2.9742898345000017`, \
-0.0061536216683392726`}, {-1.0443662062797688`*^-16, -3., \
-9.277475756783217*^-18}, {
        4.8478308386890745`*^-18, -3., -4.722880782768203*^-18}, \
{-0.14765202447079978`, -2.9742898345000017`, -0.006153621668339267}}], 
       Polygon3DBox[{{
        4.8478308386890745`*^-18, -3., -4.722880782768203*^-18}, {
        4.8478308386890745`*^-18, -3., -4.722880782768203*^-18}, {
        0.14765202447079973`, -3.0257101654999983`, 0.006153621668339259}, {
        0.14765202447079973`, -3.025710165499998, 0.006153621668339256}, {
        4.8478308386890745`*^-18, -3., -4.722880782768203*^-18}}], 
       Polygon3DBox[{{0.14765202447079973`, -3.025710165499998, 
        0.006153621668339256}, {0.14765202447079973`, -3.0257101654999983`, 
        0.006153621668339259}, {0.29530404894159945`, -3.051420330999996, 
        0.012307243336678523`}, {0.2953040489415995, -3.051420330999996, 
        0.012307243336678517`}, {0.14765202447079973`, -3.025710165499998, 
        0.006153621668339256}}], 
       Polygon3DBox[{{0.2953040489415995, -3.051420330999996, 
        0.012307243336678517`}, {0.29530404894159945`, -3.051420330999996, 
        0.012307243336678523`}, {0.44295607341239923`, -3.0771304964999944`, 
        0.018460865005017788`}, {0.4429560734123992, -3.0771304964999944`, 
        0.018460865005017774`}, {0.2953040489415995, -3.051420330999996, 
        0.012307243336678517`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewHTrmfX5v+fNL+U+qq
X5yeXdrvz83wYcM09gM74kVsu0w6oeKH9i9nZaiIOA0Tr9z/643tmyP1/XsY
wIDjQN6vCXdlGV33nICot4/89b99uQnHgW0Q9fYnIebbb/zyn98/k+PAdoj5
9msg7rHnev9/+re5HAdOQNxjvw5NHOpO+1No5kDdCRVH2At1pz3UnTZo7rQ5
geYvqDv3n0QLB6g7969BCzeoO/fjCk8AxEqwGg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.5221271591828324, -3.3590837005266443`, 
      0.05866963149497644}, {-0.36378498764196615`, -2.4866553064733674`, \
-0.09559136150501202}, {
      0.5221271591828324, -2.6409162994733557`, -0.05866963149497644}, {
      0.36378498764196615`, -3.5133446935266326`, 
      0.09559136150501202}, {-0.5221271591828324, -3.3590837005266443`, 
      0.05866963149497644}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}, {-0.36378498764196615`, -2.4866553064733674`, \
-0.09559136150501202}, {
       0.5221271591828324, -2.6409162994733557`, -0.05866963149497644}, {
       0.36378498764196615`, -3.5133446935266326`, 
       0.09559136150501202}, {-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.053447346893498573`, -2.443681761282597, 
      0.05281927503495759}, {-0.05344734689349846, -2.443681761282597, 
      0.05281927503495759}, {-0.035631564595665625`, -2.295787840855065, 
      0.035212850023305056`}, {-0.03563156459566572, -2.295787840855065, 
      0.03521285002330506}, {-0.053447346893498573`, -2.443681761282597, 
      0.05281927503495759}}], 
     Polygon3DBox[{{-0.03563156459566572, -2.295787840855065, 
      0.03521285002330506}, {-0.035631564595665625`, -2.295787840855065, 
      0.035212850023305056`}, {-0.017815782297832795`, -2.1478939204275322`, 
      0.01760642501165254}, {-0.01781578229783286, -2.1478939204275322`, 
      0.01760642501165253}, {-0.03563156459566572, -2.295787840855065, 
      0.03521285002330506}}], 
     Polygon3DBox[{{-0.01781578229783286, -2.1478939204275322`, 
      0.01760642501165253}, {-0.017815782297832795`, -2.1478939204275322`, 
      0.01760642501165254}, {4.153207462178052*^-17, -2., 
      1.4065084139716076`*^-17}, {0., -2., 
      0.}, {-0.01781578229783286, -2.1478939204275322`, 
      0.01760642501165253}}], 
     Polygon3DBox[{{0., -2., 0.}, {5.471840242762272*^-17, -2., 
      1.0337118535341577`*^-18}, {
      0.017815782297832893`, -1.8521060795724678`, -0.017606425011652525`}, {
      0.017815782297832854`, -1.8521060795724678`, -0.017606425011652525`}, {
      0., -2., 0.}}], 
     Polygon3DBox[{{
      0.017815782297832854`, -1.8521060795724678`, -0.017606425011652525`}, {
      0.017815782297832893`, -1.8521060795724678`, -0.017606425011652525`}, {
      0.03563156459566573, -1.7042121591449353`, -0.03521285002330505}, {
      0.035631564595665716`, -1.7042121591449353`, -0.035212850023305056`}, {
      0.017815782297832854`, -1.8521060795724678`, -0.017606425011652525`}}], 
     Polygon3DBox[{{
      0.035631564595665716`, -1.7042121591449353`, -0.035212850023305056`}, {
      0.03563156459566573, -1.7042121591449353`, -0.03521285002330505}, {
      0.05344734689349857, -1.5563182387174028`, -0.052819275034957584`}, {
      0.05344734689349856, -1.5563182387174028`, -0.05281927503495758}, {
      0.035631564595665716`, -1.7042121591449353`, -0.035212850023305056`}}], \

     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHb1/vNBX1hX9jAfuOGy/6gC92r72kme
L33sFu03Nf/BfCyW6YB1c71eNvsiqPik/bOk/zA+1mOEik+yV/lyvuVqetwe
Bgg4wGNQ7xvLE2dTDVFvf+YE+x/LRX/3W0LU76+BmG8/fSL/j2KX3/utIObv
3wFxj31SlPiXtc9+7L8Gcc/+XWjiUHfuh7rTfhrUHKg7oeKT7E9D7YW6cz/U
nTZo7txTjeYvqDvta9DCAepO+x1o4QZ1pz2u8AQA1z2orw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4468096635349866, -1.9471807249650424`, \
-0.008440897851150783}, {-0.4468096635349866, -1.9471807249650424`, \
-0.00844089785115079}, {-0.29787310902332437`, -1.964787149976695, \
-0.0056272652341005265`}, {-0.2978731090233244, -1.964787149976695, \
-0.005627265234100523}, {-0.4468096635349866, -1.9471807249650424`, \
-0.008440897851150783}}], 
       Polygon3DBox[{{-0.2978731090233244, -1.964787149976695, \
-0.005627265234100523}, {-0.29787310902332437`, -1.964787149976695, \
-0.0056272652341005265`}, {-0.14893655451166227`, -1.9823935749883475`, \
-0.0028136326170502667`}, {-0.1489365545116622, -1.9823935749883475`, \
-0.0028136326170502633`}, {-0.2978731090233244, -1.964787149976695, \
-0.005627265234100523}}], 
       Polygon3DBox[{{-0.1489365545116622, -1.9823935749883475`, \
-0.0028136326170502633`}, {-0.14893655451166227`, -1.9823935749883475`, \
-0.0028136326170502667`}, {-1.0696248856998934`*^-16, -2., \
-5.316754281432584*^-18}, {
        3.2727061148020633`*^-18, -2., -3.2342478052422258`*^-18}, \
{-0.1489365545116622, -1.9823935749883475`, -0.0028136326170502633`}}], 
       Polygon3DBox[{{
        3.2727061148020633`*^-18, -2., -3.2342478052422258`*^-18}, {
        3.2727061148020633`*^-18, -2., -3.2342478052422258`*^-18}, {
        0.14893655451166216`, -2.0176064250116523`, 0.002813632617050258}, {
        0.14893655451166216`, -2.0176064250116523`, 0.002813632617050256}, {
        3.2727061148020633`*^-18, -2., -3.2342478052422258`*^-18}}], 
       Polygon3DBox[{{0.14893655451166216`, -2.0176064250116523`, 
        0.002813632617050256}, {0.14893655451166216`, -2.0176064250116523`, 
        0.002813632617050258}, {0.2978731090233243, -2.035212850023305, 
        0.00562726523410052}, {0.29787310902332437`, -2.035212850023305, 
        0.005627265234100516}, {0.14893655451166216`, -2.0176064250116523`, 
        0.002813632617050256}}], 
       Polygon3DBox[{{0.29787310902332437`, -2.035212850023305, 
        0.005627265234100516}, {0.2978731090233243, -2.035212850023305, 
        0.00562726523410052}, {0.4468096635349865, -2.0528192750349574`, 
        0.008440897851150781}, {0.44680966353498647`, -2.0528192750349574`, 
        0.008440897851150774}, {0.29787310902332437`, -2.035212850023305, 
        0.005627265234100516}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv5/f/fag4plno3791in
x0cJXN7/jLln2ZH8//v5J4U3zeUph4of3v+Z0S340XaYePr+xzvCvrw+2r+H
AQIO8PjPe6NrarxnF0S9Pdv/mGt8KgwHeCHq7XdDzLfn/bdzjawHwwE+iPn2
0yHusRf+K9ask8NwoAviHvuZaOJQd9rvQTMH6k6oOMJeqDvtoe60QXOnzS40
f0HduX83WjhA3bl/Olq4Qd25H1d4AgDUiKoI
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.5002570104284851, -2.3908624862476398`, 
      0.04437837718380681}, {-0.393362316641488, -1.5034989636824452`, \
-0.061260172886108376`}, {
      0.5002570104284851, -1.6091375137523605`, -0.04437837718380681}, {
      0.393362316641488, -2.4965010363175546`, 
      0.061260172886108376`}, {-0.5002570104284851, -2.3908624862476398`, 
      0.04437837718380681}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}, {-0.393362316641488, -1.5034989636824452`, \
-0.061260172886108376`}, {
       0.5002570104284851, -1.6091375137523605`, -0.04437837718380681}, {
       0.393362316641488, -2.4965010363175546`, 
       0.061260172886108376`}, {-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.026930083315269002`, -1.4483903023154623`, 
      0.02684971884547469}, {-0.02693008331526889, -1.4483903023154623`, 
      0.02684971884547469}, {-0.01795338887684591, -1.2989268682103083`, 
      0.01789981256364979}, {-0.017953388876846003`, -1.2989268682103083`, 
      0.017899812563649795`}, {-0.026930083315269002`, -1.4483903023154623`, 
      0.02684971884547469}}], 
     Polygon3DBox[{{-0.017953388876846003`, -1.2989268682103083`, 
      0.017899812563649795`}, {-0.01795338887684591, -1.2989268682103083`, 
      0.01789981256364979}, {-0.008976694438422932, -1.1494634341051542`, 
      0.0089499062818249}, {-0.008976694438423001, -1.1494634341051542`, 
      0.008949906281824897}, {-0.017953388876846003`, -1.2989268682103083`, 
      0.017899812563649795`}}], 
     Polygon3DBox[{{-0.008976694438423001, -1.1494634341051542`, 
      0.008949906281824897}, {-0.008976694438422932, -1.1494634341051542`, 
      0.0089499062818249}, {4.836620616162607*^-17, -1.0000000000000002`, 
      6.887233720870877*^-18}, {0., -1., 
      0.}, {-0.008976694438423001, -1.1494634341051542`, 
      0.008949906281824897}}], 
     Polygon3DBox[{{0., -1., 0.}, {5.501029472866726*^-17, -1., 
      2.6297237265799405`*^-19}, {
      0.008976694438423034, -0.8505365658948459, -0.008949906281824894}, {
      0.008976694438422998, -0.8505365658948459, -0.008949906281824894}, {
      0., -1., 0.}}], 
     Polygon3DBox[{{
      0.008976694438422998, -0.8505365658948459, -0.008949906281824894}, {
      0.008976694438423034, -0.8505365658948459, -0.008949906281824894}, {
      0.017953388876846013`, -0.7010731317896919, -0.017899812563649788`}, {
      0.017953388876846, -0.7010731317896918, -0.01789981256364979}, {
      0.008976694438422998, -0.8505365658948459, -0.008949906281824894}}], 
     Polygon3DBox[{{
      0.017953388876846, -0.7010731317896918, -0.01789981256364979}, {
      0.017953388876846013`, -0.7010731317896919, -0.017899812563649788`}, {
      0.026930083315269, -0.5516096976845377, -0.026849718845474685`}, {
      0.026930083315268995`, -0.5516096976845377, -0.02684971884547468}, {
      0.017953388876846, -0.7010731317896918, -0.01789981256364979}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzx7f89cF//ZOt/3zyxLUayrm20f6BfQ
EZ80aX/cPt2u9BNf9u/56SQWEjIJKt60X/++2FHjlE9Q8SZ7Q93bvV8W++1h
AIMP+x97San29PjZ+EPU2y92vFQ6w/z1/l0Q9fsDIObbuzYveW2Q/2z/boj5
+8sh7rF/caQs8eSyh/unQ9yzvxJNHOrO/VB32rtAzYG6EyreZL8Iai/Unfuh
7rRBc+cefzR/Qd1pH4AWDlB32pejhRvUnfa4whMApP+t+Q==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4491931450518433, -0.9731502811545253, \
-0.0021473323805776953`}, {-0.4491931450518433, -0.9731502811545253, \
-0.0021473323805776988`}, {-0.29946209670122886`, -0.9821001874363502, \
-0.001431554920385133}, {-0.2994620967012289, -0.9821001874363502, \
-0.001431554920385131}, {-0.4491931450518433, -0.9731502811545253, \
-0.0021473323805776953`}}], 
       Polygon3DBox[{{-0.2994620967012289, -0.9821001874363502, \
-0.001431554920385131}, {-0.29946209670122886`, -0.9821001874363502, \
-0.001431554920385133}, {-0.14973104835061452`, -0.9910500937181751, \
-0.0007157774601925677}, {-0.14973104835061446`, -0.9910500937181751, \
-0.0007157774601925663}, {-0.2994620967012289, -0.9821001874363502, \
-0.001431554920385131}}], 
       Polygon3DBox[{{-0.14973104835061446`, -0.9910500937181751, \
-0.0007157774601925663}, {-0.14973104835061452`, -0.9910500937181751, \
-0.0007157774601925677}, {-1.0917424623676902`*^-16, -1., \
-2.1738528566481823`*^-18}, {
        1.6489920166407863`*^-18, -1., -1.6440711121058472`*^-18}, \
{-0.14973104835061446`, -0.9910500937181751, -0.0007157774601925663}}], 
       Polygon3DBox[{{
        1.6489920166407863`*^-18, -1., -1.6440711121058472`*^-18}, {
        1.6489920166407863`*^-18, -1., -1.6440711121058472`*^-18}, {
        0.1497310483506144, -1.0089499062818248`, 0.0007157774601925639}, {
        0.1497310483506144, -1.0089499062818248`, 0.0007157774601925628}, {
        1.6489920166407863`*^-18, -1., -1.6440711121058472`*^-18}}], 
       Polygon3DBox[{{0.1497310483506144, -1.0089499062818248`, 
        0.0007157774601925628}, {0.1497310483506144, -1.0089499062818248`, 
        0.0007157774601925639}, {0.2994620967012288, -1.0178998125636498`, 
        0.0014315549203851293`}, {0.29946209670122886`, -1.0178998125636498`, 
        0.0014315549203851273`}, {0.1497310483506144, -1.0089499062818248`, 
        0.0007157774601925628}}], 
       Polygon3DBox[{{0.29946209670122886`, -1.0178998125636498`, 
        0.0014315549203851273`}, {0.2994620967012288, -1.0178998125636498`, 
        0.0014315549203851293`}, {0.44919314505184327`, -1.0268497188454746`, 
        0.002147332380577695}, {0.4491931450518432, -1.0268497188454746`, 
        0.0021473323805776914`}, {0.29946209670122886`, -1.0178998125636498`, 
        0.0014315549203851273`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXm/f94SFW+P6Yn7V3i/
E0zWurzf6IVvfGzu+/11tw1SEkrCoeKH90t+WbZ+3TaYuPv+gxq9J/w/9u9h
AIMP+ycnXl6xtFt4zzKIevvPrTorVqh82F8DUW+/HGK+/XPuyIBAzw/7ayHm
21dC3GN/a2Lrj5+5H/bPhbjHvhpNHOpO+xVo5kDdCRVH2At1pz3UnTZo7rRZ
huYvqDv3L0cLB6g791eihRvUnftxhScA8QS5Lg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.47612322836711235`, -1.4215405834699877`, 
      0.024702386464896992`}, {-0.4222630617365743, -0.5247599788390629, \
-0.028997051226052385`}, {
      0.47612322836711235`, -0.5784594165300123, -0.024702386464896992`}, {
      0.4222630617365743, -1.475240021160937, 
      0.028997051226052385`}, {-0.47612322836711235`, -1.4215405834699877`, 
      0.024702386464896992`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}, {-0.4222630617365743, -0.5247599788390629, \
-0.028997051226052385`}, {
       0.47612322836711235`, -0.5784594165300123, -0.024702386464896992`}, {
       0.4222630617365743, -1.475240021160937, 
       0.028997051226052385`}, {-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0., -0.45, 0.}, {1.1021821192326179`*^-16, -0.45, 0.}, {
      9.184850993605148*^-17, -0.3, 0.}, {0., -0.30000000000000004`, 0.}, {
      0., -0.45, 0.}}], 
     Polygon3DBox[{{0., -0.30000000000000004`, 0.}, {
      9.184850993605148*^-17, -0.3, 0.}, {
      7.34788079488412*^-17, -0.15000000000000008`, 0.}, {
      0., -0.15000000000000002`, 0.}, {0., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{0., -0.15000000000000002`, 0.}, {
      7.34788079488412*^-17, -0.15000000000000008`, 0.}, {
      5.510910596163091*^-17, -1.1102230246251565`*^-16, 0.}, {0., 0., 0.}, {
      0., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {5.5109105961630896`*^-17, 0., 0.}, {
      3.67394039744206*^-17, 0.14999999999999997`, 0.}, {0., 
      0.14999999999999997`, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0., 0.14999999999999997`, 0.}, {3.67394039744206*^-17, 
      0.14999999999999997`, 0.}, {1.8369701987210304`*^-17, 
      0.29999999999999993`, 0.}, {0., 0.3, 0.}, {0., 0.14999999999999997`, 
      0.}}], Polygon3DBox[{{0., 0.3, 0.}, {1.8369701987210307`*^-17, 
      0.29999999999999993`, 0.}, {9.177509745766515*^-33, 
      0.44999999999999996`, 0.}, {0., 0.4499999999999999, 0.}, {0., 0.3, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgQ4ewYE7uxnQAMmxiBwGYf4YQxxCJiwB13ECKLe
Hl3cGGI+hvhpiHswxM/iEDfBYY4JDnuh7rTB4U4MfxnjCIfTOMINPTwB7z42
qA==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.45, 0., 0.}, {-0.45, 5.5109105961630896`*^-17, 
        0.}, {-0.3, 4.592425496802574*^-17, 0.}, {-0.30000000000000004`, 
        9.184850993605149*^-18, 0.}, {-0.45, 0., 0.}}], 
       Polygon3DBox[{{-0.30000000000000004`, 9.184850993605149*^-18, 
        0.}, {-0.3, 4.592425496802574*^-17, 0.}, {-0.15000000000000008`, 
        3.67394039744206*^-17, 0.}, {-0.15000000000000002`, 
        1.8369701987210297`*^-17, 0.}, {-0.30000000000000004`, 
        9.184850993605149*^-18, 0.}}], 
       Polygon3DBox[{{-0.15000000000000002`, 1.8369701987210297`*^-17, 
        0.}, {-0.15000000000000008`, 3.67394039744206*^-17, 
        0.}, {-1.1102230246251565`*^-16, 2.7554552980815454`*^-17, 0.}, {0., 
        2.7554552980815448`*^-17, 0.}, {-0.15000000000000002`, 
        1.8369701987210297`*^-17, 0.}}], 
       Polygon3DBox[{{0., 2.7554552980815448`*^-17, 0.}, {0., 
        2.7554552980815448`*^-17, 0.}, {0.14999999999999997`, 
        1.83697019872103*^-17, 0.}, {0.14999999999999997`, 
        3.6739403974420595`*^-17, 0.}, {0., 2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{0.14999999999999997`, 3.6739403974420595`*^-17, 0.}, {
        0.14999999999999997`, 1.83697019872103*^-17, 0.}, {
        0.29999999999999993`, 9.184850993605152*^-18, 0.}, {0.3, 
        4.592425496802574*^-17, 0.}, {0.14999999999999997`, 
        3.6739403974420595`*^-17, 0.}}], 
       Polygon3DBox[{{0.3, 4.592425496802574*^-17, 0.}, {0.29999999999999993`,
         9.184850993605153*^-18, 0.}, {0.44999999999999996`, 
        4.5887548728832574`*^-33, 0.}, {0.4499999999999999, 
        5.510910596163089*^-17, 0.}, {0.3, 4.592425496802574*^-17, 0.}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID57BgTu7GdAAybGIHAZh/hhDHEImLAHXcQIot4e
XdwYYj6G+GmIezDEz+IQN8FhjgkOe6HutMHhTgx/GeMIh9M4wg1XeAIAlqw2
qA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.45, -0.45, 0.}, {-0.45, 0.45, 0.}, {0.45, 0.45, 0.}, {
      0.45, -0.45, 0.}, {-0.45, -0.45, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.45, -0.45, 0.}, {-0.45, 0.45, 0.}, {0.45, 0.45, 0.}, {
       0.45, -0.45, 0.}, {-0.45, -0.45, 0.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.026930083315269002`, 
      0.5516096976845377, -0.02684971884547469}, {0.026930083315269113`, 
      0.5516096976845377, -0.02684971884547469}, {0.01795338887684609, 
      0.7010731317896918, -0.01789981256364979}, {0.017953388876846003`, 
      0.7010731317896917, -0.017899812563649795`}, {0.026930083315269002`, 
      0.5516096976845377, -0.02684971884547469}}], 
     Polygon3DBox[{{0.017953388876846003`, 
      0.7010731317896917, -0.017899812563649795`}, {0.01795338887684609, 
      0.7010731317896918, -0.01789981256364979}, {0.008976694438423078, 
      0.8505365658948458, -0.0089499062818249}, {0.008976694438423001, 
      0.8505365658948458, -0.008949906281824897}, {0.017953388876846003`, 
      0.7010731317896917, -0.017899812563649795`}}], 
     Polygon3DBox[{{0.008976694438423001, 
      0.8505365658948458, -0.008949906281824897}, {0.008976694438423078, 
      0.8505365658948458, -0.0089499062818249}, {6.165438329570848*^-17, 
      0.9999999999999999, -6.361288975554889*^-18}, {0., 1., 0.}, {
      0.008976694438423001, 0.8505365658948458, -0.008949906281824897}}], 
     Polygon3DBox[{{0., 1., 0.}, {5.501029472866726*^-17, 1., 
      2.6297237265799405`*^-19}, {-0.008976694438422961, 1.1494634341051542`, 
      0.008949906281824894}, {-0.008976694438422998, 1.1494634341051542`, 
      0.008949906281824894}, {0., 1., 0.}}], 
     Polygon3DBox[{{-0.008976694438422998, 1.1494634341051542`, 
      0.008949906281824894}, {-0.008976694438422961, 1.1494634341051542`, 
      0.008949906281824894}, {-0.01795338887684598, 1.2989268682103081`, 
      0.017899812563649788`}, {-0.017953388876846, 1.2989268682103083`, 
      0.01789981256364979}, {-0.008976694438422998, 1.1494634341051542`, 
      0.008949906281824894}}], 
     Polygon3DBox[{{-0.017953388876846, 1.2989268682103083`, 
      0.01789981256364979}, {-0.01795338887684598, 1.2989268682103081`, 
      0.017899812563649788`}, {-0.026930083315269, 1.4483903023154623`, 
      0.026849718845474685`}, {-0.026930083315268995`, 1.4483903023154623`, 
      0.02684971884547468}, {-0.017953388876846, 1.2989268682103083`, 
      0.01789981256364979}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzzb/sWRssSTyx7azyxLUayrm70/0C+g
Iz5pkr1L85LXBvnP7Pf8dBILCZkEFW+yX+R4qXSG+WuoeNN+Q93bvV8W+9kw
gMEH+8deUqo9PX57/CHq9+vfFztqnPLJfhdEvX0AxPz9cft0u9JPfLHfDTHf
vhzinv09c138Z+t8t58OcY99JZo41J32gWjmQN0JFUfYC3WnPdSde9DcaQN1
p/1iqL+g7twPdae9KzQcoO7cX44WblB37scVngB+HafS
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4491931450518433, 
        0.9731502811545253, -0.0021473323805776953`}, {-0.4491931450518433, 
        0.9731502811545254, -0.002147332380577692}, {-0.29946209670122886`, 
        0.9821001874363503, -0.0014315549203851273`}, {-0.2994620967012289, 
        0.9821001874363502, -0.0014315549203851297`}, {-0.4491931450518433, 
        0.9731502811545253, -0.0021473323805776953`}}], 
       Polygon3DBox[{{-0.2994620967012289, 
        0.9821001874363502, -0.0014315549203851297`}, {-0.29946209670122886`, 
        0.9821001874363503, -0.0014315549203851273`}, {-0.14973104835061452`, 
        0.9910500937181751, -0.0007157774601925633}, {-0.14973104835061446`, 
        0.9910500937181751, -0.0007157774601925641}, {-0.2994620967012289, 
        0.9821001874363502, -0.0014315549203851297`}}], 
       Polygon3DBox[{{-0.14973104835061446`, 
        0.9910500937181751, -0.0007157774601925641}, {-0.14973104835061452`, 
        0.9910500937181751, -0.0007157774601925633}, {-1.124722302700506*^-16,
         1., 1.114289367563513*^-18}, {-1.6489920166407863`*^-18, 1., 
        1.6440711121058472`*^-18}, {-0.14973104835061446`, 
        0.9910500937181751, -0.0007157774601925641}}], 
       Polygon3DBox[{{-1.6489920166407863`*^-18, 1., 
        1.6440711121058472`*^-18}, {-1.6489920166407863`*^-18, 1., 
        1.6440711121058472`*^-18}, {0.1497310483506144, 1.008949906281825, 
        0.000715777460192566}, {0.1497310483506144, 1.008949906281825, 
        0.0007157774601925671}, {-1.6489920166407863`*^-18, 1., 
        1.6440711121058472`*^-18}}], 
       Polygon3DBox[{{0.1497310483506144, 1.008949906281825, 
        0.0007157774601925671}, {0.1497310483506144, 1.008949906281825, 
        0.000715777460192566}, {0.2994620967012288, 1.0178998125636498`, 
        0.0014315549203851306`}, {0.29946209670122886`, 1.0178998125636498`, 
        0.001431554920385133}, {0.1497310483506144, 1.008949906281825, 
        0.0007157774601925671}}], 
       Polygon3DBox[{{0.29946209670122886`, 1.0178998125636498`, 
        0.001431554920385133}, {0.2994620967012288, 1.0178998125636498`, 
        0.0014315549203851306`}, {0.44919314505184327`, 1.0268497188454746`, 
        0.002147332380577695}, {0.4491931450518432, 1.0268497188454748`, 
        0.0021473323805776983`}, {0.29946209670122886`, 1.0178998125636498`, 
        0.001431554920385133}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXlvP2+JirfH9MT9K7zf
CSZrXd5v9MI3Pjb3vX3dbYOUhJJwqPjh/ZJflq1ftw0m7r7/oEbvCf+P/XsY
wOCD/eTEyyuWdgvvWQZRb/+5VWfFCpUP9jUQ9fbLIebbP+eODAj0/GBfCzHf
vhLiHvtbE1t//Mz9YD8X4h77ajRxqDvtV6CZA3UnVBxhL9Sd9lB32qC502YZ
mr+g7ty/HC0coO7cX4kWblB37scVngDBObGu
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.4222630617365743, 
      0.5247599788390629, -0.028997051226052385`}, {-0.47612322836711235`, 
      1.4215405834699877`, 0.024702386464896992`}, {0.4222630617365743, 
      1.475240021160937, 0.028997051226052385`}, {0.47612322836711235`, 
      0.5784594165300123, -0.024702386464896992`}, {-0.4222630617365743, 
      0.5247599788390629, -0.028997051226052385`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}, {-0.47612322836711235`, 
       1.4215405834699877`, 0.024702386464896992`}, {0.4222630617365743, 
       1.475240021160937, 0.028997051226052385`}, {0.47612322836711235`, 
       0.5784594165300123, -0.024702386464896992`}, {-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.053447346893498573`, 
      1.5563182387174028`, -0.05281927503495759}, {0.053447346893498685`, 
      1.5563182387174028`, -0.05281927503495759}, {0.035631564595665806`, 
      1.7042121591449353`, -0.035212850023305056`}, {0.03563156459566572, 
      1.704212159144935, -0.03521285002330506}, {0.053447346893498573`, 
      1.5563182387174028`, -0.05281927503495759}}], 
     Polygon3DBox[{{0.03563156459566572, 
      1.704212159144935, -0.03521285002330506}, {0.035631564595665806`, 
      1.7042121591449353`, -0.035212850023305056`}, {0.01781578229783294, 
      1.8521060795724675`, -0.01760642501165254}, {0.01781578229783286, 
      1.8521060795724675`, -0.01760642501165253}, {0.03563156459566572, 
      1.704212159144935, -0.03521285002330506}}], 
     Polygon3DBox[{{0.01781578229783286, 
      1.8521060795724675`, -0.01760642501165253}, {0.01781578229783294, 
      1.8521060795724675`, -0.01760642501165254}, {6.790473023346494*^-17, 
      2., -1.199766043264776*^-17}, {0., 2., 0.}, {0.01781578229783286, 
      1.8521060795724675`, -0.01760642501165253}}], 
     Polygon3DBox[{{0., 2., 0.}, {5.471840242762272*^-17, 2., 
      1.0337118535341577`*^-18}, {-0.017815782297832816`, 2.1478939204275322`,
       0.017606425011652525`}, {-0.017815782297832854`, 2.1478939204275322`, 
      0.017606425011652525`}, {0., 2., 0.}}], 
     Polygon3DBox[{{-0.017815782297832854`, 2.1478939204275322`, 
      0.017606425011652525`}, {-0.017815782297832816`, 2.1478939204275322`, 
      0.017606425011652525`}, {-0.03563156459566569, 2.2957878408550645`, 
      0.03521285002330505}, {-0.035631564595665716`, 2.295787840855065, 
      0.035212850023305056`}, {-0.017815782297832854`, 2.1478939204275322`, 
      0.017606425011652525`}}], 
     Polygon3DBox[{{-0.035631564595665716`, 2.295787840855065, 
      0.035212850023305056`}, {-0.03563156459566569, 2.2957878408550645`, 
      0.03521285002330505}, {-0.05344734689349857, 2.443681761282597, 
      0.052819275034957584`}, {-0.05344734689349856, 2.443681761282597, 
      0.05281927503495758}, {-0.035631564595665716`, 2.295787840855065, 
      0.035212850023305056`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHa1fVKU+Je1z37Y33DZf1SBe/X+2kme
L33sFtlPm8j/o9jlt711c71eNvsiqPgk+9Mn2P9YLvoLFZ+0X+XL+Zar6XE2
DBDgwGNQ7xvLE7enGqJ+/yzpP4yP9RgdLCHq7Wsg5u83Nf/BfCyWycEKYr79
Doh79p8P+sK6sofZ4RrEPfa70MSh7rSvRTMH6k6oOMJeqDvtoe7cg+ZOG6g7
7c9A/QV1536oO+2nQ8MB6s79O9DCDerO/bjCEwClbqIu
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4468096635349866, 
        1.9471807249650424`, -0.008440897851150783}, {-0.4468096635349866, 
        1.9471807249650426`, -0.008440897851150776}, {-0.29787310902332437`, 
        1.964787149976695, -0.005627265234100516}, {-0.2978731090233244, 
        1.964787149976695, -0.005627265234100521}, {-0.4468096635349866, 
        1.9471807249650424`, -0.008440897851150783}}], 
       Polygon3DBox[{{-0.2978731090233244, 
        1.964787149976695, -0.005627265234100521}, {-0.29787310902332437`, 
        1.964787149976695, -0.005627265234100516}, {-0.14893655451166227`, 
        1.9823935749883475`, -0.002813632617050258}, {-0.1489365545116622, 
        1.9823935749883475`, -0.002813632617050259}, {-0.2978731090233244, 
        1.964787149976695, -0.005627265234100521}}], 
       Polygon3DBox[{{-0.1489365545116622, 
        1.9823935749883475`, -0.002813632617050259}, {-0.14893655451166227`, 
        1.9823935749883475`, -0.002813632617050258}, \
{-1.1350790079959346`*^-16, 2., 
        1.1517413290518697`*^-18}, {-3.2727061148020633`*^-18, 2., 
        3.2342478052422258`*^-18}, {-0.1489365545116622, 
        1.9823935749883475`, -0.002813632617050259}}], 
       Polygon3DBox[{{-3.2727061148020633`*^-18, 2., 
        3.2342478052422258`*^-18}, {-3.2727061148020633`*^-18, 2., 
        3.2342478052422258`*^-18}, {0.14893655451166216`, 2.0176064250116523`,
         0.0028136326170502624`}, {0.14893655451166216`, 2.0176064250116528`, 
        0.0028136326170502646`}, {-3.2727061148020633`*^-18, 2., 
        3.2342478052422258`*^-18}}], 
       Polygon3DBox[{{0.14893655451166216`, 2.0176064250116528`, 
        0.0028136326170502646`}, {0.14893655451166216`, 2.0176064250116523`, 
        0.0028136326170502624`}, {0.2978731090233243, 2.035212850023305, 
        0.005627265234100521}, {0.29787310902332437`, 2.035212850023305, 
        0.0056272652341005265`}, {0.14893655451166216`, 2.0176064250116528`, 
        0.0028136326170502646`}}], 
       Polygon3DBox[{{0.29787310902332437`, 2.035212850023305, 
        0.0056272652341005265`}, {0.2978731090233243, 2.035212850023305, 
        0.005627265234100521}, {0.4468096635349865, 2.0528192750349574`, 
        0.008440897851150781}, {0.44680966353498647`, 2.0528192750349574`, 
        0.008440897851150788}, {0.29787310902332437`, 2.035212850023305, 
        0.0056272652341005265`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv7fvnvtQcUyz8b9e6zT
46MELu9/xtyz7Ej+f3v+SeFNc3nKoeKH939mdAt+tB0mnr7/8Y6wL6+P9u9h
gAAHHv95b3RNjffsgqi3Z/sfc41PhcGBF6LefjfEfHvefzvXyHowOPBBzLef
DnGPvfBfsWadHAaHLoh77GeiiUPdab8HzRyoO6HiCHuh7rSHutMGzZ02u9D8
BXXn/t1o4QB15/7paOEGded+XOEJAKS9oog=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.393362316641488, 
      1.5034989636824452`, -0.061260172886108376`}, {-0.5002570104284851, 
      2.3908624862476398`, 0.04437837718380681}, {0.393362316641488, 
      2.4965010363175546`, 0.061260172886108376`}, {0.5002570104284851, 
      1.6091375137523605`, -0.04437837718380681}, {-0.393362316641488, 
      1.5034989636824452`, -0.061260172886108376`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}, {-0.5002570104284851, 
       2.3908624862476398`, 0.04437837718380681}, {0.393362316641488, 
       2.4965010363175546`, 0.061260172886108376`}, {0.5002570104284851, 
       1.6091375137523605`, -0.04437837718380681}, {-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.07917108577043312, 
      2.5637858029733613`, -0.07713049649999423}, {0.07917108577043323, 
      2.5637858029733613`, -0.07713049649999423}, {0.05278072384695551, 
      2.7091905353155745`, -0.05142033099999614}, {0.052780723846955424`, 
      2.709190535315574, -0.05142033099999616}, {0.07917108577043312, 
      2.5637858029733613`, -0.07713049649999423}}], 
     Polygon3DBox[{{0.052780723846955424`, 
      2.709190535315574, -0.05142033099999616}, {0.05278072384695551, 
      2.7091905353155745`, -0.05142033099999614}, {0.026390361923477795`, 
      2.8545952676577873`, -0.025710165499998085`}, {0.026390361923477712`, 
      2.8545952676577873`, -0.02571016549999808}, {0.052780723846955424`, 
      2.709190535315574, -0.05142033099999616}}], 
     Polygon3DBox[{{0.026390361923477712`, 
      2.8545952676577873`, -0.02571016549999808}, {0.026390361923477795`, 
      2.8545952676577873`, -0.025710165499998085`}, {7.377926537049482*^-17, 
      3., -1.6768541212892168`*^-17}, {0., 3., 0.}, {0.026390361923477712`, 
      2.8545952676577873`, -0.02571016549999808}}], 
     Polygon3DBox[{{0., 3., 0.}, {5.424647374673748*^-17, 3., 
      2.2608039237886424`*^-18}, {-0.026390361923477667`, 3.1454047323422127`,
       0.02571016549999807}, {-0.0263903619234777, 3.1454047323422127`, 
      0.02571016549999807}, {0., 3., 0.}}], 
     Polygon3DBox[{{-0.0263903619234777, 3.1454047323422127`, 
      0.02571016549999807}, {-0.026390361923477667`, 3.1454047323422127`, 
      0.02571016549999807}, {-0.05278072384695538, 3.2908094646844255`, 
      0.05142033099999614}, {-0.05278072384695542, 3.2908094646844255`, 
      0.05142033099999615}, {-0.0263903619234777, 3.1454047323422127`, 
      0.02571016549999807}}], 
     Polygon3DBox[{{-0.05278072384695542, 3.2908094646844255`, 
      0.05142033099999615}, {-0.05278072384695538, 3.2908094646844255`, 
      0.05142033099999614}, {-0.07917108577043312, 3.4362141970266387`, 
      0.07713049649999422}, {-0.07917108577043311, 3.4362141970266387`, 
      0.0771304964999942}, {-0.05278072384695542, 3.2908094646844255`, 
      0.05142033099999615}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2WL/+mCv4qImFgezh3//X9q3ef+GoAmm
wmyr7d0b48Ry1rA6eOr8/X84eBVUfLb9Egd9brNrbFDxWfufu/xgFGhNs2EA
Aw6Hif4rVlV8SN2zFqJ+f8z+C19OanI6uEHU26+HmL9/R93Cl5ODuRzcIebb
M0Hcs1/UruhebC23gwnEPfbMaOJQd9pD3bl/J9QcqDuh4gh7oe60h7pzD5o7
bdai+Qvqzv1Qd9p7QMMB6s79TGjhBnXnflzhCQCJrKYb
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4429560734123993, 
        2.9228695035000056`, -0.01846086500501779}, {-0.4429560734123993, 
        2.9228695035000056`, -0.01846086500501778}, {-0.2953040489415995, 
        2.948579669000004, -0.012307243336678517`}, {-0.29530404894159956`, 
        2.948579669000004, -0.012307243336678526`}, {-0.4429560734123993, 
        2.9228695035000056`, -0.01846086500501779}}], 
       Polygon3DBox[{{-0.29530404894159956`, 
        2.948579669000004, -0.012307243336678526`}, {-0.2953040489415995, 
        2.948579669000004, -0.012307243336678517`}, {-0.14765202447079984`, 
        2.9742898345000017`, -0.00615362166833926}, {-0.14765202447079978`, 
        2.9742898345000017`, -0.00615362166833926}, {-0.29530404894159956`, 
        2.948579669000004, -0.012307243336678526`}}], 
       Polygon3DBox[{{-0.14765202447079978`, 
        2.9742898345000017`, -0.00615362166833926}, {-0.14765202447079984`, 
        2.9742898345000017`, -0.00615362166833926}, \
{-1.1413228230535503`*^-16, 3., 
        1.6828580875319207`*^-19}, {-4.8478308386890745`*^-18, 3., 
        4.722880782768203*^-18}, {-0.14765202447079978`, 
        2.9742898345000017`, -0.00615362166833926}}], 
       Polygon3DBox[{{-4.8478308386890745`*^-18, 3., 
        4.722880782768203*^-18}, {-4.8478308386890745`*^-18, 3., 
        4.722880782768203*^-18}, {0.14765202447079973`, 3.0257101654999983`, 
        0.006153621668339266}, {0.14765202447079973`, 3.0257101654999983`, 
        0.006153621668339268}, {-4.8478308386890745`*^-18, 3., 
        4.722880782768203*^-18}}], 
       Polygon3DBox[{{0.14765202447079973`, 3.0257101654999983`, 
        0.006153621668339268}, {0.14765202447079973`, 3.0257101654999983`, 
        0.006153621668339266}, {0.29530404894159945`, 3.051420330999996, 
        0.012307243336678526`}, {0.2953040489415995, 3.051420330999996, 
        0.012307243336678535`}, {0.14765202447079973`, 3.0257101654999983`, 
        0.006153621668339268}}], 
       Polygon3DBox[{{0.2953040489415995, 3.051420330999996, 
        0.012307243336678535`}, {0.29530404894159945`, 3.051420330999996, 
        0.012307243336678526`}, {0.44295607341239923`, 3.0771304964999944`, 
        0.018460865005017788`}, {0.4429560734123992, 3.0771304964999944`, 
        0.018460865005017795`}, {0.2953040489415995, 3.051420330999996, 
        0.012307243336678535`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewOp9zPr01/Pmn/KXXV
L07PLu3352b4sGEau8OOeBHbLpNOqPih/ctZGSoiTsPEK/f/emP75kh9/x4G
MOBwyPs14a4so+ueExD19pG//rcvN+Fw2AZRb38SYr79xi//+f0zORy2Q8y3
XwNxjz3X+//Tv83lcDgBcY/9OjRxqDvtT6GZA3UnVBxhL9Sd9lB32qC50+YE
mr+g7tx/Ei0coO7cvwYt3KDu3I8rPAGUf6ia
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.36378498764196615`, 
      2.4866553064733674`, -0.09559136150501202}, {-0.5221271591828324, 
      3.3590837005266443`, 0.05866963149497644}, {0.36378498764196615`, 
      3.5133446935266326`, 0.09559136150501202}, {0.5221271591828324, 
      2.6409162994733557`, -0.05866963149497644}, {-0.36378498764196615`, 
      2.4866553064733674`, -0.09559136150501202}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}, {-0.5221271591828324, 
       3.3590837005266443`, 0.05866963149497644}, {0.36378498764196615`, 
       3.5133446935266326`, 0.09559136150501202}, {0.5221271591828324, 
       2.6409162994733557`, -0.05866963149497644}, {-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.10377923337074094`, 
      3.5735118338456746`, -0.0991852552111543}, {0.10377923337074105`, 
      3.5735118338456746`, -0.09918525521115429}, {0.06918615558049403, 
      3.7156745558971163`, -0.06612350347410287}, {0.06918615558049396, 
      3.7156745558971163`, -0.06612350347410288}, {0.10377923337074094`, 
      3.5735118338456746`, -0.0991852552111543}}], 
     Polygon3DBox[{{0.06918615558049396, 
      3.7156745558971163`, -0.06612350347410288}, {0.06918615558049403, 
      3.7156745558971163`, -0.06612350347410287}, {0.03459307779024706, 
      3.8578372779485584`, -0.03306175173705144}, {0.03459307779024698, 
      3.8578372779485584`, -0.03306175173705144}, {0.06918615558049396, 
      3.7156745558971163`, -0.06612350347410288}}], 
     Polygon3DBox[{{0.03459307779024698, 
      3.8578372779485584`, -0.03306175173705144}, {0.03459307779024706, 
      3.8578372779485584`, -0.03306175173705144}, {7.921847910419026*^-17, 
      4., -2.060262182998968*^-17}, {0., 4., 0.}, {0.03459307779024698, 
      3.8578372779485584`, -0.03306175173705144}}], 
     Polygon3DBox[{{0., 4., 0.}, {5.3614458133936034`*^-17, 4., 
      3.8679901786204944`*^-18}, {-0.03459307779024693, 4.142162722051442, 
      0.03306175173705143}, {-0.034593077790246965`, 4.142162722051442, 
      0.03306175173705143}, {0., 4., 0.}}], 
     Polygon3DBox[{{-0.034593077790246965`, 4.142162722051442, 
      0.03306175173705143}, {-0.03459307779024693, 4.142162722051442, 
      0.03306175173705143}, {-0.06918615558049392, 4.284325444102883, 
      0.06612350347410285}, {-0.06918615558049394, 4.284325444102883, 
      0.06612350347410287}, {-0.034593077790246965`, 4.142162722051442, 
      0.03306175173705143}}], 
     Polygon3DBox[{{-0.06918615558049394, 4.284325444102883, 
      0.06612350347410287}, {-0.06918615558049392, 4.284325444102883, 
      0.06612350347410285}, {-0.10377923337074092`, 4.426488166154326, 
      0.09918525521115429}, {-0.10377923337074091`, 4.426488166154325, 
      0.09918525521115427}, {-0.06918615558049394, 4.284325444102883, 
      0.06612350347410287}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeIu++WPA+N7p/E4KM5IKDZJ2bk/5n6v
sP62jfb5Tg+nbN7J6yAu8Nqn4u0GqPhCe4uFBadu3uGDii/Y/05uusLPllwb
BjAQcDgvdVer2CxnTxRE/f6U9celJk8UcBCFqLePhpi//0Rcv6masqCDGMR8
ew6Ie/br8IUH7Nwi6CAPcY891J37daHiUHfax6CZA3UnVBxhL9Sd9lB37kFz
p00Umr+g7twfjRYOUHfu50ALN6g79+MKTwAjjqA4
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.4377952742885909, 
        3.9008147447888457`, -0.031584536711430106`}, {-0.4377952742885909, 
        3.9008147447888457`, -0.03158453671143009}, {-0.2918635161923939, 
        3.933876496525897, -0.02105635780762006}, {-0.291863516192394, 
        3.933876496525897, -0.02105635780762007}, {-0.4377952742885909, 
        3.9008147447888457`, -0.031584536711430106`}}], 
       Polygon3DBox[{{-0.291863516192394, 
        3.933876496525897, -0.02105635780762007}, {-0.2918635161923939, 
        3.933876496525897, -0.02105635780762006}, {-0.14593175809619705`, 
        3.9669382482629487`, -0.010528178903810031`}, {-0.145931758096197, 
        3.9669382482629487`, -0.010528178903810033`}, {-0.291863516192394, 
        3.933876496525897, -0.02105635780762007}}], 
       Polygon3DBox[{{-0.145931758096197, 
        3.9669382482629487`, -0.010528178903810033`}, {-0.14593175809619705`, 
        3.9669382482629487`, -0.010528178903810031`}, \
{-1.1436584387322319`*^-16, 
        4., -1.7190724850741538`*^-18}, {-6.354645298272203*^-18, 4., 
        6.073345265847672*^-18}, {-0.145931758096197, 
        3.9669382482629487`, -0.010528178903810033`}}], 
       Polygon3DBox[{{-6.354645298272203*^-18, 4., 
        6.073345265847672*^-18}, {-6.354645298272203*^-18, 4., 
        6.073345265847672*^-18}, {0.14593175809619693`, 4.033061751737051, 
        0.010528178903810035`}, {0.14593175809619693`, 4.033061751737051, 
        0.01052817890381004}, {-6.354645298272203*^-18, 4., 
        6.073345265847672*^-18}}], 
       Polygon3DBox[{{0.14593175809619693`, 4.033061751737051, 
        0.01052817890381004}, {0.14593175809619693`, 4.033061751737051, 
        0.010528178903810035`}, {0.29186351619239387`, 4.066123503474103, 
        0.021056357807620066`}, {0.2918635161923939, 4.066123503474103, 
        0.02105635780762008}, {0.14593175809619693`, 4.033061751737051, 
        0.01052817890381004}}], 
       Polygon3DBox[{{0.2918635161923939, 4.066123503474103, 
        0.02105635780762008}, {0.29186351619239387`, 4.066123503474103, 
        0.021056357807620066`}, {0.43779527428859083`, 4.099185255211154, 
        0.0315845367114301}, {0.4377952742885908, 4.099185255211155, 
        0.03158453671143011}, {0.2918635161923939, 4.066123503474103, 
        0.02105635780762008}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwOPq4VBje1F+wX9LAJ
eLL20v765TNsp1TwO6TFLHA40z8VKn5o/4HgM3Jee2DirfuPKvHfvqjYv4cB
DAQcQha1PrjyPXAPP0S9vcK1mR9uKQo4JEPU2wtAzLd3WGP8cKuzgEMqxHx7
MYh77BOazl6ckCrg4A1xjz3UnfaJUHGoO+0F0cyBuhMqjrAX6k57qDtt0Nxp
w4/mL6g79wughQPUnfvF0MIN6s79uMITALTioh8=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.33401604091785, 
      3.4743265786345203`, -0.13076979192258442`}, {-0.5415745076593318, 
      4.327302910943171, 0.0676007184997242}, {0.33401604091785, 
      4.52567342136548, 0.13076979192258442`}, {0.5415745076593318, 
      3.672697089056829, -0.0676007184997242}, {-0.33401604091785, 
      3.4743265786345203`, -0.13076979192258442`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}, {-0.5415745076593318, 
       4.327302910943171, 0.0676007184997242}, {0.33401604091785, 
       4.52567342136548, 0.13076979192258442`}, {0.5415745076593318, 
       3.672697089056829, -0.0676007184997242}, {-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.12702537303504904`, 
      4.584912708653602, -0.11860478560334935`}, {0.12702537303504916`, 
      4.584912708653602, -0.11860478560334933`}, {0.08468358202336611, 
      4.723275139102401, -0.07906985706889955}, {0.08468358202336604, 
      4.723275139102401, -0.07906985706889957}, {0.12702537303504904`, 
      4.584912708653602, -0.11860478560334935`}}], 
     Polygon3DBox[{{0.08468358202336604, 
      4.723275139102401, -0.07906985706889957}, {0.08468358202336611, 
      4.723275139102401, -0.07906985706889955}, {0.0423417910116831, 
      4.8616375695512, -0.039534928534449794`}, {0.04234179101168302, 
      4.861637569551201, -0.03953492853444979}, {0.08468358202336604, 
      4.723275139102401, -0.07906985706889957}}], 
     Polygon3DBox[{{0.04234179101168302, 
      4.861637569551201, -0.03953492853444979}, {0.0423417910116831, 
      4.8616375695512, -0.039534928534449794`}, {8.418617957876437*^-17, 
      5., -2.3496321766177242`*^-17}, {0., 5., 0.}, {0.04234179101168302, 
      4.861637569551201, -0.03953492853444979}}], 
     Polygon3DBox[{{0., 5., 0.}, {5.284695872207303*^-17, 5., 
      5.765403524393586*^-18}, {-0.042341791011682964`, 5.138362430448799, 
      0.03953492853444978}, {-0.042341791011683, 5.138362430448799, 
      0.03953492853444977}, {0., 5., 0.}}], 
     Polygon3DBox[{{-0.042341791011683, 5.138362430448799, 
      0.03953492853444977}, {-0.042341791011682964`, 5.138362430448799, 
      0.03953492853444978}, {-0.08468358202336598, 5.276724860897599, 
      0.07906985706889955}, {-0.08468358202336602, 5.276724860897599, 
      0.07906985706889956}, {-0.042341791011683, 5.138362430448799, 
      0.03953492853444977}}], 
     Polygon3DBox[{{-0.08468358202336602, 5.276724860897599, 
      0.07906985706889956}, {-0.08468358202336598, 5.276724860897599, 
      0.07906985706889955}, {-0.12702537303504902`, 5.415087291346398, 
      0.11860478560334933`}, {-0.12702537303504902`, 5.415087291346398, 
      0.11860478560334932`}, {-0.08468358202336602, 5.276724860897599, 
      0.07906985706889956}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczpgH7srK/pzmJCD9OEA6Ucx+/Y/yvTZ
f2ntVvvJFz/aLHoi5JBx3VToje0WqPhS+1MvKuQCi4Sh4kv2P2MS9bolUGTD
AAYiDtc6ru90uVew5z5E/X4z8faH63pFHNIg6u0fQszfn6vHdzhWWtQhHWK+
fQbEPfsXu05dwrNS1EES4h77TDRxqDvtH6GZA3UnVBxhL9Sd9lB37kFzp819
NH9B3bn/IVo4QN25PwMt3KDu3I8rPAG39qcS
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{-0.43152816598930516`, 
        4.881395214396651, -0.04707809246231391}, {-0.43152816598930516`, 
        4.881395214396651, -0.0470780924623139}, {-0.2876854439928701, 
        4.9209301429311, -0.03138539497487592}, {-0.28768544399287016`, 
        4.9209301429311, -0.03138539497487594}, {-0.43152816598930516`, 
        4.881395214396651, -0.04707809246231391}}], 
       Polygon3DBox[{{-0.28768544399287016`, 
        4.9209301429311, -0.03138539497487594}, {-0.2876854439928701, 
        4.9209301429311, -0.03138539497487592}, {-0.1438427219964351, 
        4.96046507146555, -0.015692697487437967`}, {-0.14384272199643508`, 
        4.96046507146555, -0.015692697487437967`}, {-0.28768544399287016`, 
        4.9209301429311, -0.03138539497487594}}], 
       Polygon3DBox[{{-0.14384272199643508`, 
        4.96046507146555, -0.015692697487437967`}, {-0.1438427219964351, 
        4.96046507146555, -0.015692697487437967`}, {-1.14243062081692*^-16, 
        5., -4.35248082671899*^-18}, {-7.778060824893566*^-18, 5., 
        7.262448552634993*^-18}, {-0.14384272199643508`, 
        4.96046507146555, -0.015692697487437967`}}], 
       Polygon3DBox[{{-7.778060824893566*^-18, 5., 
        7.262448552634993*^-18}, {-7.778060824893566*^-18, 5., 
        7.262448552634993*^-18}, {0.14384272199643502`, 5.03953492853445, 
        0.01569269748743797}, {0.14384272199643502`, 5.03953492853445, 
        0.015692697487437977`}, {-7.778060824893566*^-18, 5., 
        7.262448552634993*^-18}}], 
       Polygon3DBox[{{0.14384272199643502`, 5.03953492853445, 
        0.015692697487437977`}, {0.14384272199643502`, 5.03953492853445, 
        0.01569269748743797}, {0.28768544399287005`, 5.0790698570689, 
        0.031385394974875934`}, {0.2876854439928701, 5.0790698570689, 
        0.03138539497487595}, {0.14384272199643502`, 5.03953492853445, 
        0.015692697487437977`}}], 
       Polygon3DBox[{{0.2876854439928701, 5.0790698570689, 
        0.03138539497487595}, {0.28768544399287005`, 5.0790698570689, 
        0.031385394974875934`}, {0.4315281659893051, 5.118604785603349, 
        0.047078092462313904`}, {0.43152816598930505`, 5.118604785603349, 
        0.04707809246231391}, {0.2876854439928701, 5.0790698570689, 
        0.03138539497487595}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAk7XFv+fdk8qRX7vzPH
mxZkXtq/SGO7P8d6YYcn+b8k9wsugIof2h845bZ6y3WY+IT976PnMe9e37eH
AQxEHNRSFzbYnYja8xWi3n59tsqNag0Rh8cQ9fbfIObbx1332PA9ACa+wP49
xD32PM65HcWVIg5XIO6x/4gmDnWn/Xc0c6DuhIoj7IW60x7qThs0d9p8RfMX
1J37v6GFA9Sd+9+jhRvUnftxhScApw2rFQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{-0.3045027929542561, 
      4.466307923050252, -0.16568287806566326`}, {-0.5585535390243542, 
      5.296482505743049, 0.07152669314103544}, {0.3045027929542561, 
      5.533692076949748, 0.16568287806566326`}, {0.5585535390243542, 
      4.703517494256951, -0.07152669314103544}, {-0.3045027929542561, 
      4.466307923050252, -0.16568287806566326`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}, {-0.5585535390243542, 
       5.296482505743049, 0.07152669314103544}, {0.3045027929542561, 
       5.533692076949748, 0.16568287806566326`}, {0.5585535390243542, 
       4.703517494256951, -0.07152669314103544}, {-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.8710067056590125, -5.415065653440038, 
      0.11653854877015467`}, {0.8710067056590125, -5.415065653440038, 
      0.11653854877015468`}, {0.9140044704393417, -5.276710435626692, 
      0.07769236584676979}, {0.9140044704393416, -5.276710435626692, 
      0.07769236584676979}, {0.8710067056590125, -5.415065653440038, 
      0.11653854877015467`}}], 
     Polygon3DBox[{{0.9140044704393416, -5.276710435626692, 
      0.07769236584676979}, {0.9140044704393417, -5.276710435626692, 
      0.07769236584676979}, {0.9570022352196709, -5.138355217813346, 
      0.03884618292338492}, {0.9570022352196708, -5.138355217813346, 
      0.038846182923384896`}, {0.9140044704393416, -5.276710435626692, 
      0.07769236584676979}}], 
     Polygon3DBox[{{0.9570022352196708, -5.138355217813346, 
      0.038846182923384896`}, {0.9570022352196709, -5.138355217813346, 
      0.03884618292338492}, {1., -5., 3.625113852598769*^-17}, {1., -5., 
      0.}, {0.9570022352196708, -5.138355217813346, 0.038846182923384896`}}], 
     Polygon3DBox[{{1., -5., 0.}, {1., -5., 7.499187392426035*^-18}, {
      1.0429977647803292`, -4.861644782186654, -0.038846182923384875`}, {
      1.0429977647803292`, -4.861644782186654, -0.03884618292338488}, {
      1., -5., 0.}}], 
     Polygon3DBox[{{
      1.0429977647803292`, -4.861644782186654, -0.03884618292338488}, {
      1.0429977647803292`, -4.861644782186654, -0.038846182923384875`}, {
      1.0859955295606583`, -4.723289564373308, -0.07769236584676976}, {
      1.0859955295606583`, -4.723289564373308, -0.07769236584676978}, {
      1.0429977647803292`, -4.861644782186654, -0.03884618292338488}}], 
     Polygon3DBox[{{
      1.0859955295606583`, -4.723289564373308, -0.07769236584676978}, {
      1.0859955295606583`, -4.723289564373308, -0.07769236584676976}, {
      1.1289932943409875`, -4.584934346559963, -0.11653854877015465`}, {
      1.1289932943409875`, -4.584934346559963, -0.11653854877015464`}, {
      1.0859955295606583`, -4.723289564373308, -0.07769236584676978}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64l1Pief+1vcD9mh9sK0UPvH+zIb3i6l77pS/n
+rbZv7XnevX3V6S06AHvz6Wzlj7ebH/pyzm1w/Pf2bN+rfu7plcEKr7YngEM
PkBpkQPCC7YzcE0usJneOiNHbsMH+99cjUzBRcIHPCHq9+tyG960Sfho/02U
iXXZE6EDXhDz9x+ZcNI1WuCT/UeFZvafYUIH3kLcAxf/ABWHunO/Hpo5UHfu
R7cX6s79ONy55zKav6DuxAgHqDvtYeHGDw03qDvtcYUnADNgt8I=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        0.5696873477287563, -4.883461451229845, -0.06123551213008731}, {
        0.5696873477287563, -4.883461451229845, -0.06123551213008732}, {
        0.7131248984858376, -4.92230763415323, -0.040823674753391555`}, {
        0.7131248984858376, -4.92230763415323, -0.04082367475339155}, {
        0.5696873477287563, -4.883461451229845, -0.06123551213008731}}], 
       Polygon3DBox[{{
        0.7131248984858376, -4.92230763415323, -0.04082367475339155}, {
        0.7131248984858376, -4.92230763415323, -0.040823674753391555`}, {
        0.8565624492429187, -4.961153817076615, -0.02041183737669579}, {
        0.8565624492429188, -4.961153817076615, -0.020411837376695777`}, {
        0.7131248984858376, -4.92230763415323, -0.04082367475339155}}], 
       Polygon3DBox[{{
        0.8565624492429188, -4.961153817076615, -0.020411837376695777`}, {
        0.8565624492429187, -4.961153817076615, -0.02041183737669579}, {
        0.9999999999999999, -5., -2.224372259010705*^-17}, {
        1., -5., -7.135928036432382*^-18}, {
        0.8565624492429188, -4.961153817076615, -0.020411837376695777`}}], 
       Polygon3DBox[{{1., -5., -7.135928036432382*^-18}, {
        1., -5., -7.135928036432382*^-18}, {
        1.143437550757081, -5.038846182923385, 0.02041183737669576}, {
        1.143437550757081, -5.038846182923385, 0.020411837376695753`}, {
        1., -5., -7.135928036432382*^-18}}], 
       Polygon3DBox[{{1.143437550757081, -5.038846182923385, 
        0.020411837376695753`}, {1.143437550757081, -5.038846182923385, 
        0.02041183737669576}, {1.2868751015141624`, -5.07769236584677, 
        0.04082367475339153}, {1.2868751015141624`, -5.07769236584677, 
        0.04082367475339153}, {1.143437550757081, -5.038846182923385, 
        0.020411837376695753`}}], 
       Polygon3DBox[{{1.2868751015141624`, -5.07769236584677, 
        0.04082367475339153}, {1.2868751015141624`, -5.07769236584677, 
        0.04082367475339153}, {1.4303126522712435`, -5.116538548770155, 
        0.0612355121300873}, {1.4303126522712435`, -5.116538548770155, 
        0.06123551213008728}, {1.2868751015141624`, -5.07769236584677, 
        0.04082367475339153}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIHrm16ftkpav1+px3z
/F5ffGZvrDEts3CD8IEJZ96bX3+2ZL9ijP/yrxmv7SVFTm+xuAETn7KfAQw+
2ENokQPlWnPXcWQn7nkfGKHT6v3J/vlrE+/j6iIHeiHq7e8v3hDBNf2L/dnr
mdP6/EUO9EPMtz/3laO1/9E3+y2H5z0MLRc5cAXiHvvzaOJQd2KYA3Wn/Qc0
e6HutMfhTht0f0HdiREOUHfuT0ELN6g79+MKTwBWurrI
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.4406940533877688, -5.298527104669883, 
      0.05530303664006736}, {
      0.6986806420697439, -4.468395797789808, -0.17777406090024198`}, {
      1.5593059466122312`, -4.701472895330117, -0.05530303664006736}, {
      1.301319357930256, -5.531604202210192, 0.17777406090024198`}, {
      0.4406940533877688, -5.298527104669883, 0.05530303664006736}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.4406940533877688, -5.298527104669883, 
       0.05530303664006736}, {
       0.6986806420697439, -4.468395797789808, -0.17777406090024198`}, {
       1.5593059466122312`, -4.701472895330117, -0.05530303664006736}, {
       1.301319357930256, -5.531604202210192, 0.17777406090024198`}, {
       0.4406940533877688, -5.298527104669883, 0.05530303664006736}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.8944782759745522, -4.426419413851459, 
      0.0976301656726812}, {0.8944782759745523, -4.426419413851459, 
      0.09763016567268121}, {0.9296521839830348, -4.284279609234306, 
      0.0650867771151208}, {0.9296521839830347, -4.284279609234306, 
      0.0650867771151208}, {0.8944782759745522, -4.426419413851459, 
      0.0976301656726812}}], 
     Polygon3DBox[{{0.9296521839830347, -4.284279609234306, 
      0.0650867771151208}, {0.9296521839830348, -4.284279609234306, 
      0.0650867771151208}, {0.9648260919915175, -4.142139804617154, 
      0.03254338855756042}, {0.9648260919915174, -4.142139804617153, 
      0.0325433885575604}, {0.9296521839830347, -4.284279609234306, 
      0.0650867771151208}}], 
     Polygon3DBox[{{0.9648260919915174, -4.142139804617153, 
      0.0325433885575604}, {0.9648260919915175, -4.142139804617154, 
      0.03254338855756042}, {1., -4., 2.9693874081859424`*^-17}, {1., -4., 
      0.}, {0.9648260919915174, -4.142139804617153, 0.0325433885575604}}], 
     Polygon3DBox[{{1., -4., 0.}, {1., -4., 5.60692789790848*^-18}, {
      1.0351739080084825`, -3.857860195382847, -0.032543388557560386`}, {
      1.0351739080084825`, -3.857860195382847, -0.03254338855756039}, {
      1., -4., 0.}}], 
     Polygon3DBox[{{
      1.0351739080084825`, -3.857860195382847, -0.03254338855756039}, {
      1.0351739080084825`, -3.857860195382847, -0.032543388557560386`}, {
      1.0703478160169653`, -3.7157203907656937`, -0.06508677711512079}, {
      1.0703478160169653`, -3.7157203907656937`, -0.06508677711512079}, {
      1.0351739080084825`, -3.857860195382847, -0.03254338855756039}}], 
     Polygon3DBox[{{
      1.0703478160169653`, -3.7157203907656937`, -0.06508677711512079}, {
      1.0703478160169653`, -3.7157203907656937`, -0.06508677711512079}, {
      1.1055217240254478`, -3.573580586148541, -0.09763016567268118}, {
      1.1055217240254478`, -3.573580586148541, -0.09763016567268117}, {
      1.0703478160169653`, -3.7157203907656937`, -0.06508677711512079}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6VePL5hPlv7HNqir2WbxE8kHt+VYLXvx32adNu
v9+6/63956BFhlLKggc8u2Ret63cYG98+u33W/ff2VdqXpTonSgAFV9gzwAG
H6C0wIHKZy1GZkezbdKkOFuEJnyw510be+7pHb4DHhD1+8+aCHGoKny0l4ra
Pef0Tl6o+Ib9xv7SPeYbPtprsEtmb5zGcyAb4h4Mcag7McyBunM/ur1Qd+7H
4c496P6CutM+HS0coO60Rw83qDsxxGHhCQBI9azg
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        0.5631108008182854, -3.902369834327319, -0.04578404076842598}, {
        0.5631108008182854, -3.9023698343273185`, -0.045784040768425995`}, {
        0.7087405338788568, -3.9349132228848793`, -0.030522693845617326`}, {
        0.7087405338788568, -3.9349132228848793`, -0.030522693845617326`}, {
        0.5631108008182854, -3.902369834327319, -0.04578404076842598}}], 
       Polygon3DBox[{{
        0.7087405338788568, -3.9349132228848793`, -0.030522693845617326`}, {
        0.7087405338788568, -3.9349132228848793`, -0.030522693845617326`}, {
        0.8543702669394284, -3.9674566114424397`, -0.015261346922808675`}, {
        0.8543702669394284, -3.9674566114424397`, -0.015261346922808665`}, {
        0.7087405338788568, -3.9349132228848793`, -0.030522693845617326`}}], 
       Polygon3DBox[{{
        0.8543702669394284, -3.9674566114424397`, -0.015261346922808665`}, {
        0.8543702669394284, -3.9674566114424397`, -0.015261346922808675`}, {
        0.9999999999999999, -4., -1.7273789321560045`*^-17}, {
        1., -4., -5.978123494563741*^-18}, {
        0.8543702669394284, -3.9674566114424397`, -0.015261346922808665`}}], 
       Polygon3DBox[{{1., -4., -5.978123494563741*^-18}, {
        1., -4., -5.978123494563741*^-18}, {
        1.1456297330605716`, -4.032543388557561, 0.015261346922808653`}, {
        1.1456297330605716`, -4.032543388557561, 0.015261346922808647`}, {
        1., -4., -5.978123494563741*^-18}}], 
       Polygon3DBox[{{1.1456297330605716`, -4.032543388557561, 
        0.015261346922808647`}, {1.1456297330605716`, -4.032543388557561, 
        0.015261346922808653`}, {1.2912594661211432`, -4.065086777115121, 
        0.03052269384561731}, {1.2912594661211432`, -4.065086777115121, 
        0.030522693845617305`}, {1.1456297330605716`, -4.032543388557561, 
        0.015261346922808647`}}], 
       Polygon3DBox[{{1.2912594661211432`, -4.065086777115121, 
        0.030522693845617305`}, {1.2912594661211432`, -4.065086777115121, 
        0.03052269384561731}, {1.4368891991817145`, -4.0976301656726815`, 
        0.045784040768425974`}, {1.4368891991817145`, -4.0976301656726815`, 
        0.04578404076842595}, {1.2912594661211432`, -4.065086777115121, 
        0.030522693845617305`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4LfgP3H7RV81YuHy/Sv3p
BQzrntmvk15+YnMV/4Eqs0z/cMf5+yftTw1gCH9tf703+EnkXph4/34GMPhg
D6EFDuxi0j10gjtqj7nC2ev1IZ/sRS2v8QYrChwoh6i3z3OYtf7/ii/2mkVr
pJc5CRyogJhvvyQhvb3+7zd7u9VNmj+TBQ7chLgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15/4daOEGded+XOEJADx7nmY=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.45758907679283756`, -4.328789248178778, 
      0.05184612490425521}, {
      0.6686325248437331, -3.4759504204758596`, -0.14341420644110717`}, {
      1.5424109232071626`, -3.671210751821222, -0.05184612490425521}, {
      1.331367475156267, -4.52404957952414, 0.14341420644110717`}, {
      0.45758907679283756`, -4.328789248178778, 0.05184612490425521}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.45758907679283756`, -4.328789248178778, 
       0.05184612490425521}, {
       0.6686325248437331, -3.4759504204758596`, -0.14341420644110717`}, {
       1.5424109232071626`, -3.671210751821222, -0.05184612490425521}, {
       1.331367475156267, -4.52404957952414, 0.14341420644110717`}, {
       0.45758907679283756`, -4.328789248178778, 0.05184612490425521}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.9194119258859308, -3.4361462361834545`, 
      0.07603961450186135}, {0.9194119258859309, -3.4361462361834545`, 
      0.07603961450186136}, {0.9462746172572873, -3.2907641574556363`, 
      0.05069307633457424}, {0.9462746172572872, -3.2907641574556363`, 
      0.05069307633457424}, {0.9194119258859308, -3.4361462361834545`, 
      0.07603961450186135}}], 
     Polygon3DBox[{{0.9462746172572872, -3.2907641574556363`, 
      0.05069307633457424}, {0.9462746172572873, -3.2907641574556363`, 
      0.05069307633457424}, {0.9731373086286437, -3.145382078727818, 
      0.025346538167287137`}, {0.9731373086286436, -3.145382078727818, 
      0.02534653816728712}, {0.9462746172572872, -3.2907641574556363`, 
      0.05069307633457424}}], 
     Polygon3DBox[{{0.9731373086286436, -3.145382078727818, 
      0.02534653816728712}, {0.9731373086286437, -3.145382078727818, 
      0.025346538167287137`}, {1., -3., 2.2757311613747393`*^-17}, {1., -3., 
      0.}, {0.9731373086286436, -3.145382078727818, 0.02534653816728712}}], 
     Polygon3DBox[{{1., -3., 0.}, {1., -3., 3.9971047685057405`*^-18}, {
      1.0268626913713563`, -2.854617921272182, -0.02534653816728711}, {
      1.0268626913713563`, -2.854617921272182, -0.025346538167287113`}, {
      1., -3., 0.}}], 
     Polygon3DBox[{{
      1.0268626913713563`, -2.854617921272182, -0.025346538167287113`}, {
      1.0268626913713563`, -2.854617921272182, -0.02534653816728711}, {
      1.0537253827427129`, -2.7092358425443637`, -0.050693076334574226`}, {
      1.0537253827427129`, -2.7092358425443637`, -0.05069307633457423}, {
      1.0268626913713563`, -2.854617921272182, -0.025346538167287113`}}], 
     Polygon3DBox[{{
      1.0537253827427129`, -2.7092358425443637`, -0.05069307633457423}, {
      1.0537253827427129`, -2.7092358425443637`, -0.050693076334574226`}, {
      1.0805880741140692`, -2.5638537638165455`, -0.07603961450186135}, {
      1.0805880741140692`, -2.563853763816546, -0.07603961450186134}, {
      1.0537253827427129`, -2.7092358425443637`, -0.05069307633457423}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILYoUO+/lP3WfmLxUxurWu4D69NqOEPLN9tXfz2y
5aH7O/tt32do1ARzHZhq/Dux8MtK+71VSbc+KL+3v13tI7JPkxMqPtOeAQw+
QGmOA4EMf9Q4F6baLDx0bhJ73gd71ZbNrx2vsR2YDFG/37l1rir/nQ/2Xhzp
15vXsB6YAjF//xP3nB1iXh/tC3qkDh9tYjmwDuIeuHg+VBzqTgxzoO7cj24v
1J37cbhzD7q/oO7ECAeoO+1h4TYBGm5Qd9rjCk8Anu2qjg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        0.5576735557045728, -2.923960385498139, -0.03263883734713291}, {
        0.5576735557045728, -2.9239603854981384`, -0.03263883734713292}, {
        0.7051157038030484, -2.949306923665426, -0.02175922489808861}, {
        0.7051157038030484, -2.949306923665426, -0.021759224898088608`}, {
        0.5576735557045728, -2.923960385498139, -0.03263883734713291}}], 
       Polygon3DBox[{{
        0.7051157038030484, -2.949306923665426, -0.021759224898088608`}, {
        0.7051157038030484, -2.949306923665426, -0.02175922489808861}, {
        0.8525578519015242, -2.974653461832713, -0.010879612449044316`}, {
        0.8525578519015242, -2.974653461832713, -0.010879612449044307`}, {
        0.7051157038030484, -2.949306923665426, -0.021759224898088608`}}], 
       Polygon3DBox[{{
        0.8525578519015242, -2.974653461832713, -0.010879612449044307`}, {
        0.8525578519015242, -2.974653461832713, -0.010879612449044316`}, {
        0.9999999999999999, -3., -1.2708614352023475`*^-17}, {
        1., -3., -4.656083525405158*^-18}, {
        0.8525578519015242, -2.974653461832713, -0.010879612449044307`}}], 
       Polygon3DBox[{{1., -3., -4.656083525405158*^-18}, {
        1., -3., -4.656083525405158*^-18}, {
        1.1474421480984758`, -3.025346538167287, 0.010879612449044297`}, {
        1.1474421480984758`, -3.025346538167287, 0.010879612449044293`}, {
        1., -3., -4.656083525405158*^-18}}], 
       Polygon3DBox[{{1.1474421480984758`, -3.025346538167287, 
        0.010879612449044293`}, {1.1474421480984758`, -3.025346538167287, 
        0.010879612449044297`}, {1.2948842961969516`, -3.050693076334574, 
        0.0217592248980886}, {1.2948842961969516`, -3.050693076334574, 
        0.021759224898088597`}, {1.1474421480984758`, -3.025346538167287, 
        0.010879612449044293`}}], 
       Polygon3DBox[{{1.2948842961969516`, -3.050693076334574, 
        0.021759224898088597`}, {1.2948842961969516`, -3.050693076334574, 
        0.0217592248980886}, {1.4423264442954271`, -3.076039614501861, 
        0.0326388373471329}, {1.4423264442954271`, -3.076039614501861, 
        0.032638837347132896`}, {1.2948842961969516`, -3.050693076334574, 
        0.021759224898088597`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewHHNp+LOXctmC/TOz3
c34TntkbCVdY6c1gP7A61vsuj8e0/X3rqtPVPV7bz+S0kRU/AxNv288ABh/s
ITTHAb5z+3gTJgbt2anh5PMm+pN9+rfDj14YcxxYCVFvXxTYMuPG9i/25960
H72YznFgFcR8e62qY0+OCH+3N33svWLXbI4D9hD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7ty/Bi3coO7cjys8AZlZpDk=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.47708548159050357`, -3.360106621681593, 
      0.04340077715472844}, {
      0.638261629818642, -2.4878141493146844`, -0.10867845184899426`}, {
      1.5229145184094963`, -2.639893378318407, -0.04340077715472844}, {
      1.361738370181358, -3.5121858506853156`, 0.10867845184899426`}, {
      0.47708548159050357`, -3.360106621681593, 0.04340077715472844}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.47708548159050357`, -3.360106621681593, 
       0.04340077715472844}, {
       0.638261629818642, -2.4878141493146844`, -0.10867845184899426`}, {
       1.5229145184094963`, -2.639893378318407, -0.04340077715472844}, {
       1.361738370181358, -3.5121858506853156`, 0.10867845184899426`}, {
       0.47708548159050357`, -3.360106621681593, 0.04340077715472844}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.9455506413883192, -2.4436407387825065`, 
      0.052135997538059496`}, {0.9455506413883193, -2.4436407387825065`, 
      0.0521359975380595}, {0.9637004275922129, -2.295760492521671, 
      0.03475733169203967}, {0.9637004275922127, -2.295760492521671, 
      0.03475733169203967}, {0.9455506413883192, -2.4436407387825065`, 
      0.052135997538059496`}}], 
     Polygon3DBox[{{0.9637004275922127, -2.295760492521671, 
      0.03475733169203967}, {0.9637004275922129, -2.295760492521671, 
      0.03475733169203967}, {0.9818502137961065, -2.1478802462608355`, 
      0.017378665846019842`}, {0.9818502137961064, -2.1478802462608355`, 
      0.017378665846019836`}, {0.9637004275922127, -2.295760492521671, 
      0.03475733169203967}}], 
     Polygon3DBox[{{0.9818502137961064, -2.1478802462608355`, 
      0.017378665846019836`}, {0.9818502137961065, -2.1478802462608355`, 
      0.017378665846019842`}, {1., -2., 1.562637735773605*^-17}, {1., -2., 
      0.}, {0.9818502137961064, -2.1478802462608355`, 
      0.017378665846019836`}}], 
     Polygon3DBox[{{1., -2., 0.}, {1., -2., 2.7635807180573547`*^-18}, {
      1.0181497862038937`, -1.8521197537391645`, -0.017378665846019825`}, {
      1.0181497862038935`, -1.8521197537391645`, -0.01737866584601983}, {
      1., -2., 0.}}], 
     Polygon3DBox[{{
      1.0181497862038935`, -1.8521197537391645`, -0.01737866584601983}, {
      1.0181497862038937`, -1.8521197537391645`, -0.017378665846019825`}, {
      1.0362995724077873`, -1.7042395074783292`, -0.03475733169203966}, {
      1.0362995724077873`, -1.7042395074783292`, -0.034757331692039664`}, {
      1.0181497862038935`, -1.8521197537391645`, -0.01737866584601983}}], 
     Polygon3DBox[{{
      1.0362995724077873`, -1.7042395074783292`, -0.034757331692039664`}, {
      1.0362995724077873`, -1.7042395074783292`, -0.03475733169203966}, {
      1.0544493586116808`, -1.5563592612174937`, -0.05213599753805949}, {
      1.0544493586116808`, -1.556359261217494, -0.05213599753805948}, {
      1.0362995724077873`, -1.7042395074783292`, -0.034757331692039664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4w0M/+7PjOnukLY8vkHuYD1jP2npi4cZX9q1Ml
7ouuvbNfsyhs7fZYpgOXd11u3XZ6oX1p6i7lwOz39mGBq6/d1mOEik+0ZwCD
D1Ca4cDmHu77t1bE2rieVcoL9/pgHxK7Mshj0d/9FyHq93fPcr2zbsoH+5W7
gpZOcPm9/xLE/P0X0jO82O5/sP8n/uf7jWc/9ltC3AMX/wsVh7oTbs4KqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwY4SGG9Sd9rjCEwDQkcAk
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        0.5536004058587259, -1.9478640024619405`, -0.022566349089235094`}, {
        0.5536004058587259, -1.9478640024619405`, -0.0225663490892351}, {
        0.7024002705724839, -1.9652426683079602`, -0.015044232726156733`}, {
        0.7024002705724839, -1.9652426683079602`, -0.015044232726156733`}, {
        0.5536004058587259, -1.9478640024619405`, -0.022566349089235094`}}], 
       Polygon3DBox[{{
        0.7024002705724839, -1.9652426683079602`, -0.015044232726156733`}, {
        0.7024002705724839, -1.9652426683079602`, -0.015044232726156733`}, {
        0.8512001352862419, -1.9826213341539802`, -0.007522116363078373}, {
        0.8512001352862419, -1.9826213341539802`, -0.007522116363078367}, {
        0.7024002705724839, -1.9652426683079602`, -0.015044232726156733`}}], 
       Polygon3DBox[{{
        0.8512001352862419, -1.9826213341539802`, -0.007522116363078367}, {
        0.8512001352862419, -1.9826213341539802`, -0.007522116363078373}, {
        0.9999999999999999, -2., -8.759893645399773*^-18}, {
        1., -2., -3.1924091252669424`*^-18}, {
        0.8512001352862419, -1.9826213341539802`, -0.007522116363078367}}], 
       Polygon3DBox[{{1., -2., -3.1924091252669424`*^-18}, {
        1., -2., -3.1924091252669424`*^-18}, {
        1.148799864713758, -2.01737866584602, 0.007522116363078361}, {
        1.148799864713758, -2.01737866584602, 0.007522116363078359}, {
        1., -2., -3.1924091252669424`*^-18}}], 
       Polygon3DBox[{{1.148799864713758, -2.01737866584602, 
        0.007522116363078359}, {1.148799864713758, -2.01737866584602, 
        0.007522116363078361}, {1.2975997294275161`, -2.0347573316920395`, 
        0.015044232726156724`}, {1.2975997294275161`, -2.0347573316920395`, 
        0.015044232726156723`}, {1.148799864713758, -2.01737866584602, 
        0.007522116363078359}}], 
       Polygon3DBox[{{1.2975997294275161`, -2.0347573316920395`, 
        0.015044232726156723`}, {1.2975997294275161`, -2.0347573316920395`, 
        0.015044232726156724`}, {1.446399594141274, -2.0521359975380595`, 
        0.02256634908923509}, {1.446399594141274, -2.0521359975380595`, 
        0.02256634908923508}, {1.2975997294275161`, -2.0347573316920395`, 
        0.015044232726156723`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7vf+scwLtIevr+nnc3
FQWqntlrJl30XlT4f78ta/aepvN9+92+vxHgsH1tL7rxherFHTDxuv0MYPDB
HkIzHGDXj/z0Zo3nntiWzu/ViZ/sy5Zz505XZjhgBVFvv4tD+P33Q1/sX/uJ
39JzZzhgDTHfXqx3zrNile/2id+U3I9lMRx4DXEPhjjUnRjmQN1pj24v1J32
ONxpg+4vqDsxwgHqzv1X0MIN6s79uMITAFP0pts=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.4991510472470452, -2.391504741244447, 
      0.0295696484488244}, {
      0.6080497644704068, -1.5042232636794342`, -0.0747023466272946}, {
      1.5008489527529547`, -1.6084952587555532`, -0.0295696484488244}, {
      1.3919502355295932`, -2.4957767363205656`, 0.0747023466272946}, {
      0.4991510472470452, -2.391504741244447, 0.0295696484488244}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.4991510472470452, -2.391504741244447, 
       0.0295696484488244}, {
       0.6080497644704068, -1.5042232636794342`, -0.0747023466272946}, {
       1.5008489527529547`, -1.6084952587555532`, -0.0295696484488244}, {
       1.3919502355295932`, -2.4957767363205656`, 0.0747023466272946}, {
       0.4991510472470452, -2.391504741244447, 0.0295696484488244}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.9725506200210112, -1.4483782490010226`, 
      0.026523147655324503`}, {0.9725506200210114, -1.4483782490010226`, 
      0.026523147655324507`}, {0.9817004133473409, -1.2989188326673484`, 
      0.017682098436883006`}, {0.9817004133473408, -1.2989188326673484`, 
      0.017682098436883006`}, {0.9725506200210112, -1.4483782490010226`, 
      0.026523147655324503`}}], 
     Polygon3DBox[{{0.9817004133473408, -1.2989188326673484`, 
      0.017682098436883006`}, {0.9817004133473409, -1.2989188326673484`, 
      0.017682098436883006`}, {0.9908502066736705, -1.1494594163336742`, 
      0.00884104921844151}, {0.9908502066736704, -1.1494594163336742`, 
      0.008841049218441503}, {0.9817004133473408, -1.2989188326673484`, 
      0.017682098436883006`}}], 
     Polygon3DBox[{{0.9908502066736704, -1.1494594163336742`, 
      0.008841049218441503}, {0.9908502066736705, -1.1494594163336742`, 
      0.00884104921844151}, {1., -1.0000000000000002`, 
      8.53050502720272*^-18}, {1., -1., 0.}, {
      0.9908502066736704, -1.1494594163336742`, 0.008841049218441503}}], 
     Polygon3DBox[{{1., -1., 0.}, {1., -1., 1.9868140910973867`*^-18}, {
      1.0091497933263296`, -0.8505405836663258, -0.008841049218441498}, {
      1.0091497933263296`, -0.8505405836663258, -0.0088410492184415}, {
      1., -1., 0.}}], 
     Polygon3DBox[{{
      1.0091497933263296`, -0.8505405836663258, -0.0088410492184415}, {
      1.0091497933263296`, -0.8505405836663258, -0.008841049218441498}, {
      1.0182995866526592`, -0.7010811673326517, -0.017682098436883}, {
      1.0182995866526592`, -0.7010811673326516, -0.017682098436883002`}, {
      1.0091497933263296`, -0.8505405836663258, -0.0088410492184415}}], 
     Polygon3DBox[{{
      1.0182995866526592`, -0.7010811673326516, -0.017682098436883002`}, {
      1.0182995866526592`, -0.7010811673326517, -0.017682098436883}, {
      1.0274493799789888`, -0.5516217509989775, -0.026523147655324503`}, {
      1.0274493799789888`, -0.5516217509989776, -0.0265231476553245}, {
      1.0182995866526592`, -0.7010811673326516, -0.017682098436883002`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG6zDqtSkn9vX6m+e3Wfzvf9rP8F/B9pzLZnqbX8
I5b13n5Zvrps/Ikv+9eHcHc5Sk+yb9onU8e99b395e2T+/RTPkHFm+wZwOAD
jN5/1jzDOlfXz2b/go8OVaof7KMm3Hi0wPz1/rUQ9fvrHB83fvH6YL9FYeNR
x/xn+9dBzN9v++jKobyCD/YCGztXPFr2cD8LxD1wcT6oONSdGOZA3bkf3V6o
O/fjcOcedH9B3YkRDlB32rdDw60CGm5Qd9rjCk8AF6ym6w==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        0.5510753755114947, -0.9734768523446755, -0.016223568236006368`}, {
        0.5510753755114947, -0.9734768523446754, -0.01622356823600637}, {
        0.700716917007663, -0.9823179015631169, -0.01081571215733758}, {
        0.700716917007663, -0.9823179015631169, -0.01081571215733758}, {
        0.5510753755114947, -0.9734768523446755, -0.016223568236006368`}}], 
       Polygon3DBox[{{
        0.700716917007663, -0.9823179015631169, -0.01081571215733758}, {
        0.700716917007663, -0.9823179015631169, -0.01081571215733758}, {
        0.8503584585038315, -0.9911589507815585, -0.005407856078668794}, {
        0.8503584585038315, -0.9911589507815585, -0.005407856078668791}, {
        0.700716917007663, -0.9823179015631169, -0.01081571215733758}}], 
       Polygon3DBox[{{
        0.8503584585038315, -0.9911589507815585, -0.005407856078668791}, {
        0.8503584585038315, -0.9911589507815585, -0.005407856078668794}, {
        0.9999999999999999, -1., -5.626691948901757*^-18}, {
        1., -1., -1.624074393970289*^-18}, {
        0.8503584585038315, -0.9911589507815585, -0.005407856078668791}}], 
       Polygon3DBox[{{1., -1., -1.624074393970289*^-18}, {
        1., -1., -1.624074393970289*^-18}, {
        1.1496415414961685`, -1.0088410492184414`, 0.005407856078668787}, {
        1.1496415414961685`, -1.0088410492184414`, 0.005407856078668786}, {
        1., -1., -1.624074393970289*^-18}}], 
       Polygon3DBox[{{1.1496415414961685`, -1.0088410492184414`, 
        0.005407856078668786}, {1.1496415414961685`, -1.0088410492184414`, 
        0.005407856078668787}, {1.299283082992337, -1.017682098436883, 
        0.010815712157337575`}, {1.299283082992337, -1.017682098436883, 
        0.010815712157337573`}, {1.1496415414961685`, -1.0088410492184414`, 
        0.005407856078668786}}], 
       Polygon3DBox[{{1.299283082992337, -1.017682098436883, 
        0.010815712157337573`}, {1.299283082992337, -1.017682098436883, 
        0.010815712157337575`}, {1.4489246244885052`, -1.0265231476553245`, 
        0.016223568236006364`}, {1.4489246244885052`, -1.0265231476553245`, 
        0.01622356823600636}, {1.299283082992337, -1.017682098436883, 
        0.010815712157337573`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/3t7H9s345Z8L+Kys8
H7nmPLOPXrr+s2r++/2ccX/9e9Ta9mddUfmoZPbafu2l6z8nbYeJl+1nAIMP
9lB6/0bl4LclpU57Tk/NbX+X8sl+pZhIs5nKh/1sEPX207Rv8909+cU+WFeD
Ldfjw352iPn2CQc9pp3W+27/x9mmc3HOh/2tEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3O+AFm5Qd+7HFZ4AEl+yVQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.523625995532506, -1.4218551013456981`, 
      0.010299579419318135`}, {
      0.5785247554904833, -0.5250986033436529, -0.042746715891330875`}, {
      1.476374004467494, -0.5781448986543019, -0.010299579419318135`}, {
      1.4214752445095167`, -1.4749013966563471`, 0.042746715891330875`}, {
      0.523625995532506, -1.4218551013456981`, 0.010299579419318135`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.523625995532506, -1.4218551013456981`, 
       0.010299579419318135`}, {
       0.5785247554904833, -0.5250986033436529, -0.042746715891330875`}, {
       1.476374004467494, -0.5781448986543019, -0.010299579419318135`}, {
       1.4214752445095167`, -1.4749013966563471`, 0.042746715891330875`}, {
       0.523625995532506, -1.4218551013456981`, 0.010299579419318135`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1., -0.45, 0.}, {1., -0.45, 3.4428622644535503`*^-18}, {
      1., -0.3, 2.869051887044625*^-18}, {1., -0.30000000000000004`, 0.}, {
      1., -0.45, 0.}}], 
     Polygon3DBox[{{1., -0.30000000000000004`, 0.}, {1., -0.3, 
      2.869051887044625*^-18}, {1., -0.15000000000000008`, 
      2.2952415096357003`*^-18}, {1., -0.15000000000000002`, 0.}, {
      1., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{1., -0.15000000000000002`, 0.}, {
      1., -0.15000000000000008`, 2.2952415096357003`*^-18}, {
      1., -1.1102230246251565`*^-16, 1.7214311322267755`*^-18}, {1., 0., 
      0.}, {1., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{1., 0., 0.}, {1., 0., 1.7214311322267751`*^-18}, {1., 
      0.14999999999999997`, 1.1476207548178502`*^-18}, {1., 
      0.14999999999999997`, 0.}, {1., 0., 0.}}], 
     Polygon3DBox[{{1., 0.14999999999999997`, 0.}, {1., 0.14999999999999997`, 
      1.1476207548178502`*^-18}, {1., 0.29999999999999993`, 
      5.738103774089252*^-19}, {1., 0.3, 0.}, {1., 0.14999999999999997`, 
      0.}}], Polygon3DBox[{{1., 0.3, 0.}, {1., 0.29999999999999993`, 
      5.738103774089253*^-19}, {1., 0.44999999999999996`, 
      2.866758717457077*^-34}, {1., 0.4499999999999999, 0.}, {1., 0.3, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4YH/2DAjc2c+AAj7YmxiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDSikhp
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.5502195943040942, 0., -0.014056551925218786`}, {
        0.5502195943040942, 
        5.5109105961630896`*^-17, -0.014056551925218786`}, {
        0.7001463962027294, 4.592425496802574*^-17, -0.009371034616812523}, {
        0.7001463962027294, 9.184850993605149*^-18, -0.009371034616812525}, {
        0.5502195943040942, 0., -0.014056551925218786`}}], 
       Polygon3DBox[{{0.7001463962027294, 
        9.184850993605149*^-18, -0.009371034616812525}, {0.7001463962027294, 
        4.592425496802574*^-17, -0.009371034616812523}, {0.8500731981013646, 
        3.67394039744206*^-17, -0.004685517308406264}, {0.8500731981013647, 
        1.8369701987210297`*^-17, -0.0046855173084062625`}, {
        0.7001463962027294, 9.184850993605149*^-18, -0.009371034616812525}}], 
       Polygon3DBox[{{0.8500731981013647, 
        1.8369701987210297`*^-17, -0.0046855173084062625`}, {
        0.8500731981013646, 3.67394039744206*^-17, -0.004685517308406264}, {
        0.9999999999999999, 
        2.7554552980815454`*^-17, -3.4679794653815483`*^-18}, {1., 
        2.7554552980815448`*^-17, 0.}, {0.8500731981013647, 
        1.8369701987210297`*^-17, -0.0046855173084062625`}}], 
       Polygon3DBox[{{1., 2.7554552980815448`*^-17, 0.}, {1., 
        2.7554552980815448`*^-17, 0.}, {1.1499268018986353`, 
        1.83697019872103*^-17, 0.004685517308406261}, {1.1499268018986353`, 
        3.6739403974420595`*^-17, 0.004685517308406261}, {1., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{1.1499268018986353`, 3.6739403974420595`*^-17, 
        0.004685517308406261}, {1.1499268018986353`, 1.83697019872103*^-17, 
        0.004685517308406261}, {1.2998536037972706`, 9.184850993605152*^-18, 
        0.009371034616812522}, {1.2998536037972706`, 4.592425496802574*^-17, 
        0.009371034616812523}, {1.1499268018986353`, 3.6739403974420595`*^-17,
         0.004685517308406261}}], 
       Polygon3DBox[{{1.2998536037972706`, 4.592425496802574*^-17, 
        0.009371034616812523}, {1.2998536037972706`, 9.184850993605153*^-18, 
        0.009371034616812522}, {1.4497804056959058`, 4.5887548728832574`*^-33,
         0.014056551925218784`}, {1.4497804056959058`, 5.510910596163089*^-17,
         0.014056551925218782`}, {1.2998536037972706`, 4.592425496802574*^-17,
         0.009371034616812523}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC74mCKfNvuhPQMUrN3RWLbuZM/+Bd7OWTPTn8HF
Sy6s/iln2Lz/wlLFrWeMX6OJF++H8D7AxQ9sKP7a8cd+j4Ru/lLJtE9w8SKI
enuDqHtexme+wMWLIebbe7T7fvAx+g4XXw1xD4Y41J0Y5kDdaY9uL9Sd9jjc
aYPuL6g7McIB6s79hWjhBnXnflzhCQBjMnoq
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.5502195943040942, -0.45, -0.014056551925218786`}, {
      0.5502195943040942, 0.45, -0.014056551925218786`}, {1.4497804056959058`,
       0.45, 0.014056551925218786`}, {1.4497804056959058`, -0.45, 
      0.014056551925218786`}, {
      0.5502195943040942, -0.45, -0.014056551925218786`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.5502195943040942, -0.45, -0.014056551925218786`}, {
       0.5502195943040942, 0.45, -0.014056551925218786`}, {
       1.4497804056959058`, 0.45, 0.014056551925218786`}, {
       1.4497804056959058`, -0.45, 0.014056551925218786`}, {
       0.5502195943040942, -0.45, -0.014056551925218786`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.0274493799789888`, 
      0.5516217509989774, -0.026523147655324503`}, {1.0274493799789888`, 
      0.5516217509989774, -0.0265231476553245}, {1.0182995866526592`, 
      0.7010811673326516, -0.017682098436883}, {1.0182995866526592`, 
      0.7010811673326516, -0.017682098436883006`}, {1.0274493799789888`, 
      0.5516217509989774, -0.026523147655324503`}}], 
     Polygon3DBox[{{1.0182995866526592`, 
      0.7010811673326516, -0.017682098436883006`}, {1.0182995866526592`, 
      0.7010811673326516, -0.017682098436883}, {1.0091497933263296`, 
      0.8505405836663258, -0.008841049218441503}, {1.0091497933263296`, 
      0.8505405836663258, -0.008841049218441503}, {1.0182995866526592`, 
      0.7010811673326516, -0.017682098436883006`}}], 
     Polygon3DBox[{{1.0091497933263296`, 
      0.8505405836663258, -0.008841049218441503}, {1.0091497933263296`, 
      0.8505405836663258, -0.008841049218441503}, {1., 
      0.9999999999999999, -4.556876845007946*^-18}, {1., 1., 0.}, {
      1.0091497933263296`, 0.8505405836663258, -0.008841049218441503}}], 
     Polygon3DBox[{{1., 1., 0.}, {1., 1., 1.9868140910973867`*^-18}, {
      0.9908502066736705, 1.1494594163336742`, 0.008841049218441501}, {
      0.9908502066736704, 1.1494594163336742`, 0.0088410492184415}, {1., 1., 
      0.}}], Polygon3DBox[{{0.9908502066736704, 1.1494594163336742`, 
      0.0088410492184415}, {0.9908502066736705, 1.1494594163336742`, 
      0.008841049218441501}, {0.9817004133473409, 1.2989188326673484`, 
      0.017682098436883}, {0.9817004133473408, 1.2989188326673484`, 
      0.017682098436883002`}, {0.9908502066736704, 1.1494594163336742`, 
      0.0088410492184415}}], 
     Polygon3DBox[{{0.9817004133473408, 1.2989188326673484`, 
      0.017682098436883002`}, {0.9817004133473409, 1.2989188326673484`, 
      0.017682098436883}, {0.9725506200210113, 1.4483782490010224`, 
      0.026523147655324503`}, {0.9725506200210113, 1.4483782490010224`, 
      0.0265231476553245}, {0.9817004133473408, 1.2989188326673484`, 
      0.017682098436883002`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILZ9dOVQXsEHe76NnSseLXtoz/pfwP+Rxuz9dY6P
G794fbDforDxqGP+M/v1IdxdjtKT9u9f8NGhSvWDfdSEG48WmL+GijftZwCD
D/Yw+qx5hnWurt+epn0yddxb39tf3j65Tz/lk/1aiHp7llrLP2JZ7+2X5avL
xp/4Yr8OYr59u3VYlZL8e/sK9d2r+3S+27NA3GPfBhWvhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPCzcBaLhB3bkfV3gCAGbQok8=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.5510753755114947, 
        0.9734768523446755, -0.016223568236006368`}, {0.5510753755114947, 
        0.9734768523446755, -0.016223568236006364`}, {0.700716917007663, 
        0.982317901563117, -0.010815712157337573`}, {0.700716917007663, 
        0.982317901563117, -0.01081571215733758}, {0.5510753755114947, 
        0.9734768523446755, -0.016223568236006368`}}], 
       Polygon3DBox[{{0.700716917007663, 
        0.982317901563117, -0.01081571215733758}, {0.700716917007663, 
        0.982317901563117, -0.010815712157337573`}, {0.8503584585038315, 
        0.9911589507815586, -0.00540785607866879}, {0.8503584585038315, 
        0.9911589507815585, -0.005407856078668789}, {0.700716917007663, 
        0.982317901563117, -0.01081571215733758}}], 
       Polygon3DBox[{{0.8503584585038315, 
        0.9911589507815585, -0.005407856078668789}, {0.8503584585038315, 
        0.9911589507815586, -0.00540785607866879}, {0.9999999999999999, 
        1., -2.378543160961178*^-18}, {1., 1., 1.624074393970289*^-18}, {
        0.8503584585038315, 0.9911589507815585, -0.005407856078668789}}], 
       Polygon3DBox[{{1., 1., 1.624074393970289*^-18}, {1., 1., 
        1.624074393970289*^-18}, {1.1496415414961685`, 1.0088410492184414`, 
        0.0054078560786687884`}, {1.1496415414961685`, 1.0088410492184416`, 
        0.005407856078668789}, {1., 1., 1.624074393970289*^-18}}], 
       Polygon3DBox[{{1.1496415414961685`, 1.0088410492184416`, 
        0.005407856078668789}, {1.1496415414961685`, 1.0088410492184414`, 
        0.0054078560786687884`}, {1.299283082992337, 1.017682098436883, 
        0.010815712157337575`}, {1.299283082992337, 1.017682098436883, 
        0.01081571215733758}, {1.1496415414961685`, 1.0088410492184416`, 
        0.005407856078668789}}], 
       Polygon3DBox[{{1.299283082992337, 1.017682098436883, 
        0.01081571215733758}, {1.299283082992337, 1.017682098436883, 
        0.010815712157337575`}, {1.4489246244885052`, 1.0265231476553245`, 
        0.016223568236006364`}, {1.4489246244885052`, 1.0265231476553245`, 
        0.016223568236006368`}, {1.299283082992337, 1.017682098436883, 
        0.01081571215733758}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/t29j+Wb+cM2H/lRWe
j1xzntlHL13/WTX/vT1n3F//HrW2/VlXVD4qmb22X3vp+s9J22HiZfsZwOCD
PYzeqBz8tqTUac/pqbnt71I+2a8UE2k2U/lgzwZRbz9N+zbf3ZNf7IN1Ndhy
PT7Ys0PMt0846DHttN53+z/ONp2Lcz7Yt0LcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+pOjHCAunO/A1q4Qd25H1d4AgDiharV
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.5785247554904833, 
      0.5250986033436529, -0.042746715891330875`}, {0.523625995532506, 
      1.4218551013456981`, 0.010299579419318135`}, {1.4214752445095167`, 
      1.4749013966563471`, 0.042746715891330875`}, {1.476374004467494, 
      0.5781448986543019, -0.010299579419318135`}, {0.5785247554904833, 
      0.5250986033436529, -0.042746715891330875`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}, {0.523625995532506, 
       1.4218551013456981`, 0.010299579419318135`}, {1.4214752445095167`, 
       1.4749013966563471`, 0.042746715891330875`}, {1.476374004467494, 
       0.5781448986543019, -0.010299579419318135`}, {0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.0544493586116808`, 
      1.5563592612174937`, -0.052135997538059496`}, {1.054449358611681, 
      1.5563592612174937`, -0.05213599753805949}, {1.0362995724077873`, 
      1.7042395074783292`, -0.03475733169203966}, {1.0362995724077873`, 
      1.704239507478329, -0.03475733169203967}, {1.0544493586116808`, 
      1.5563592612174937`, -0.052135997538059496`}}], 
     Polygon3DBox[{{1.0362995724077873`, 
      1.704239507478329, -0.03475733169203967}, {1.0362995724077873`, 
      1.7042395074783292`, -0.03475733169203966}, {1.0181497862038937`, 
      1.8521197537391645`, -0.017378665846019836`}, {1.0181497862038935`, 
      1.8521197537391645`, -0.017378665846019836`}, {1.0362995724077873`, 
      1.704239507478329, -0.03475733169203967}}], 
     Polygon3DBox[{{1.0181497862038935`, 
      1.8521197537391645`, -0.017378665846019836`}, {1.0181497862038937`, 
      1.8521197537391645`, -0.017378665846019836`}, {1., 
      2., -1.0099215921621339`*^-17}, {1., 2., 0.}, {1.0181497862038935`, 
      1.8521197537391645`, -0.017378665846019836`}}], 
     Polygon3DBox[{{1., 2., 0.}, {1., 2., 2.7635807180573547`*^-18}, {
      0.9818502137961065, 2.1478802462608355`, 0.017378665846019832`}, {
      0.9818502137961064, 2.1478802462608355`, 0.01737866584601983}, {1., 2., 
      0.}}], Polygon3DBox[{{0.9818502137961064, 2.1478802462608355`, 
      0.01737866584601983}, {0.9818502137961065, 2.1478802462608355`, 
      0.017378665846019832`}, {0.9637004275922129, 2.295760492521671, 
      0.03475733169203966}, {0.9637004275922127, 2.295760492521671, 
      0.034757331692039664`}, {0.9818502137961064, 2.1478802462608355`, 
      0.01737866584601983}}], 
     Polygon3DBox[{{0.9637004275922127, 2.295760492521671, 
      0.034757331692039664`}, {0.9637004275922129, 2.295760492521671, 
      0.03475733169203966}, {0.9455506413883192, 2.443640738782506, 
      0.05213599753805949}, {0.9455506413883192, 2.443640738782506, 
      0.05213599753805948}, {0.9637004275922127, 2.295760492521671, 
      0.034757331692039664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL6QnuHFdv+D/V/xP99vPPthbz1j74mJG1ft757l
emfdlA/2K3YFLZ3g8tv+8q7LrdtOL9zvelYpL9zrg31I7Mogj0V/oeIT9zOA
wQd7CM3gsLmH+/6tFbF7SlN3KQdmv7cPC1x97bYeo8NFiHr7V6dK3Bdde2e/
ZlHY2u2xTA6XIObbJxjoZ392fGfP+IWxZXIPs4MlxD1wcSaoONSdGOZA3WmP
bi/UnfY43GmD7i+oO+HhsBIaDlB37oeF2z9ouEHduR9XeAIAJUq8tQ==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.5536004058587259, 
        1.9478640024619405`, -0.022566349089235094`}, {0.5536004058587259, 
        1.9478640024619405`, -0.022566349089235088`}, {0.7024002705724839, 
        1.9652426683079605`, -0.015044232726156723`}, {0.7024002705724839, 
        1.9652426683079602`, -0.01504423272615673}, {0.5536004058587259, 
        1.9478640024619405`, -0.022566349089235094`}}], 
       Polygon3DBox[{{0.7024002705724839, 
        1.9652426683079602`, -0.01504423272615673}, {0.7024002705724839, 
        1.9652426683079605`, -0.015044232726156723`}, {0.8512001352862419, 
        1.9826213341539802`, -0.007522116363078364}, {0.8512001352862419, 
        1.9826213341539802`, -0.007522116363078364}, {0.7024002705724839, 
        1.9652426683079602`, -0.01504423272615673}}], 
       Polygon3DBox[{{0.8512001352862419, 
        1.9826213341539802`, -0.007522116363078364}, {0.8512001352862419, 
        1.9826213341539802`, -0.007522116363078364}, {0.9999999999999999, 
        2., -2.375075394865886*^-18}, {1., 2., 3.1924091252669424`*^-18}, {
        0.8512001352862419, 1.9826213341539802`, -0.007522116363078364}}], 
       Polygon3DBox[{{1., 2., 3.1924091252669424`*^-18}, {1., 2., 
        3.1924091252669424`*^-18}, {1.148799864713758, 2.01737866584602, 
        0.007522116363078365}, {1.148799864713758, 2.01737866584602, 
        0.007522116363078367}, {1., 2., 3.1924091252669424`*^-18}}], 
       Polygon3DBox[{{1.148799864713758, 2.01737866584602, 
        0.007522116363078367}, {1.148799864713758, 2.01737866584602, 
        0.007522116363078365}, {1.2975997294275161`, 2.0347573316920395`, 
        0.015044232726156728`}, {1.2975997294275161`, 2.0347573316920395`, 
        0.015044232726156733`}, {1.148799864713758, 2.01737866584602, 
        0.007522116363078367}}], 
       Polygon3DBox[{{1.2975997294275161`, 2.0347573316920395`, 
        0.015044232726156733`}, {1.2975997294275161`, 2.0347573316920395`, 
        0.015044232726156728`}, {1.446399594141274, 2.0521359975380595`, 
        0.02256634908923509}, {1.446399594141274, 2.0521359975380595`, 
        0.022566349089235094`}, {1.2975997294275161`, 2.0347573316920395`, 
        0.015044232726156733`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7bv3UO4F0kPX1/z7ub
igJVz+w1ky56Lyr8b2/Lmr2n6XzffrfvbwQ4bF/bi258oXpxB0y8bj8DGHyw
h9AMDuz6kZ/erPHcE9vS+b068ZN92XLu3OnKDA5WEPX2uziE338/9MX+tZ/4
LT13BgdriPn2Yr1znhWrfLdP/KbkfiyLweE1xD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g7919BCzeoO/fjCk8AJCmfWw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.6080497644704068, 
      1.5042232636794342`, -0.0747023466272946}, {0.4991510472470452, 
      2.391504741244447, 0.0295696484488244}, {1.3919502355295932`, 
      2.4957767363205656`, 0.0747023466272946}, {1.5008489527529547`, 
      1.6084952587555532`, -0.0295696484488244}, {0.6080497644704068, 
      1.5042232636794342`, -0.0747023466272946}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}, {0.4991510472470452, 
       2.391504741244447, 0.0295696484488244}, {1.3919502355295932`, 
       2.4957767363205656`, 0.0747023466272946}, {1.5008489527529547`, 
       1.6084952587555532`, -0.0295696484488244}, {0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.0805880741140692`, 
      2.5638537638165455`, -0.07603961450186135}, {1.0805880741140692`, 
      2.5638537638165455`, -0.07603961450186134}, {1.0537253827427129`, 
      2.7092358425443637`, -0.050693076334574226`}, {1.0537253827427129`, 
      2.7092358425443637`, -0.05069307633457424}, {1.0805880741140692`, 
      2.5638537638165455`, -0.07603961450186135}}], 
     Polygon3DBox[{{1.0537253827427129`, 
      2.7092358425443637`, -0.05069307633457424}, {1.0537253827427129`, 
      2.7092358425443637`, -0.050693076334574226`}, {1.0268626913713566`, 
      2.854617921272182, -0.025346538167287123`}, {1.0268626913713563`, 
      2.854617921272182, -0.02534653816728712}, {1.0537253827427129`, 
      2.7092358425443637`, -0.05069307633457424}}], 
     Polygon3DBox[{{1.0268626913713563`, 
      2.854617921272182, -0.02534653816728712}, {1.0268626913713566`, 
      2.854617921272182, -0.025346538167287123`}, {1., 
      3., -1.476310207673591*^-17}, {1., 3., 0.}, {1.0268626913713563`, 
      2.854617921272182, -0.02534653816728712}}], 
     Polygon3DBox[{{1., 3., 0.}, {1., 3., 3.9971047685057405`*^-18}, {
      0.9731373086286437, 3.145382078727818, 0.025346538167287117`}, {
      0.9731373086286436, 3.145382078727818, 0.025346538167287113`}, {1., 3., 
      0.}}], Polygon3DBox[{{0.9731373086286436, 3.145382078727818, 
      0.025346538167287113`}, {0.9731373086286437, 3.145382078727818, 
      0.025346538167287117`}, {0.9462746172572872, 3.2907641574556363`, 
      0.050693076334574226`}, {0.9462746172572872, 3.2907641574556363`, 
      0.05069307633457423}, {0.9731373086286436, 3.145382078727818, 
      0.025346538167287113`}}], 
     Polygon3DBox[{{0.9462746172572872, 3.2907641574556363`, 
      0.05069307633457423}, {0.9462746172572872, 3.2907641574556363`, 
      0.050693076334574226`}, {0.9194119258859308, 3.4361462361834545`, 
      0.07603961450186135}, {0.9194119258859308, 3.436146236183454, 
      0.07603961450186134}, {0.9462746172572872, 3.2907641574556363`, 
      0.05069307633457423}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7inrNDzOujfX6P1OGjTSwO69NqOEPLN+93bp2r
yn/ng70XR/r15jWsDlONfycWflm5f+Ghc5PY8z7Yq7Zsfu14jQ0qPnM/Axh8
sIfQHA6BDH/UOBem7tlblXTrg/J7+9vVPiL7NDkdJkPU21d/PbLlofs7+23f
Z2jUBHM5TIGYb29RoN5/Kfut/YTipzZWtdwO6yDugYtPhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPC7cCaLhB3bkfV3gCAMjAo+I=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.5576735557045728, 
        2.923960385498139, -0.03263883734713291}, {0.5576735557045728, 
        2.923960385498139, -0.0326388373471329}, {0.7051157038030484, 
        2.949306923665426, -0.021759224898088597`}, {0.7051157038030484, 
        2.949306923665426, -0.021759224898088608`}, {0.5576735557045728, 
        2.923960385498139, -0.03263883734713291}}], 
       Polygon3DBox[{{0.7051157038030484, 
        2.949306923665426, -0.021759224898088608`}, {0.7051157038030484, 
        2.949306923665426, -0.021759224898088597`}, {0.8525578519015242, 
        2.974653461832713, -0.010879612449044302`}, {0.8525578519015242, 
        2.974653461832713, -0.0108796124490443}, {0.7051157038030484, 
        2.949306923665426, -0.021759224898088608`}}], 
       Polygon3DBox[{{0.8525578519015242, 
        2.974653461832713, -0.0108796124490443}, {0.8525578519015242, 
        2.974653461832713, -0.010879612449044302`}, {0.9999999999999999, 
        3., -3.3964473012131554`*^-18}, {1., 3., 4.656083525405158*^-18}, {
        0.8525578519015242, 2.974653461832713, -0.0108796124490443}}], 
       Polygon3DBox[{{1., 3., 4.656083525405158*^-18}, {1., 3., 
        4.656083525405158*^-18}, {1.1474421480984758`, 3.025346538167287, 
        0.010879612449044304`}, {1.1474421480984758`, 3.025346538167287, 
        0.010879612449044307`}, {1., 3., 4.656083525405158*^-18}}], 
       Polygon3DBox[{{1.1474421480984758`, 3.025346538167287, 
        0.010879612449044307`}, {1.1474421480984758`, 3.025346538167287, 
        0.010879612449044304`}, {1.2948842961969516`, 3.050693076334574, 
        0.0217592248980886}, {1.2948842961969516`, 3.050693076334574, 
        0.02175922489808861}, {1.1474421480984758`, 3.025346538167287, 
        0.010879612449044307`}}], 
       Polygon3DBox[{{1.2948842961969516`, 3.050693076334574, 
        0.02175922489808861}, {1.2948842961969516`, 3.050693076334574, 
        0.0217592248980886}, {1.4423264442954271`, 3.076039614501861, 
        0.0326388373471329}, {1.4423264442954271`, 3.0760396145018616`, 
        0.03263883734713291}, {1.2948842961969516`, 3.050693076334574, 
        0.02175922489808861}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewODm0/lnJuW7BfJvb7
Ob8Jz+yNhCus9GawO6yO9b7L4zFtf9+66nR1j9f2MzltZMXPwMTb9jOAwQd7
CM3hwHduH2/CxKA9OzWcfN5Ef7JP/3b40QtjDoeVEPX2RYEtM25s/2J/7k37
0YvpHA6rIObba1Ude3JE+Lu96WPvFbtmczjYQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6c/8atHCDunM/rvAEAGmOnLk=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.638261629818642, 
      2.4878141493146844`, -0.10867845184899426`}, {0.47708548159050357`, 
      3.360106621681593, 0.04340077715472844}, {1.361738370181358, 
      3.5121858506853156`, 0.10867845184899426`}, {1.5229145184094963`, 
      2.639893378318407, -0.04340077715472844}, {0.638261629818642, 
      2.4878141493146844`, -0.10867845184899426`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}, {0.47708548159050357`, 
       3.360106621681593, 0.04340077715472844}, {1.361738370181358, 
       3.5121858506853156`, 0.10867845184899426`}, {1.5229145184094963`, 
       2.639893378318407, -0.04340077715472844}, {0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.1055217240254478`, 
      3.573580586148541, -0.0976301656726812}, {1.105521724025448, 
      3.573580586148541, -0.09763016567268118}, {1.0703478160169653`, 
      3.7157203907656937`, -0.06508677711512077}, {1.0703478160169653`, 
      3.7157203907656937`, -0.0650867771151208}, {1.1055217240254478`, 
      3.573580586148541, -0.0976301656726812}}], 
     Polygon3DBox[{{1.0703478160169653`, 
      3.7157203907656937`, -0.0650867771151208}, {1.0703478160169653`, 
      3.7157203907656937`, -0.06508677711512077}, {1.0351739080084827`, 
      3.857860195382847, -0.03254338855756041}, {1.0351739080084825`, 
      3.857860195382847, -0.0325433885575604}, {1.0703478160169653`, 
      3.7157203907656937`, -0.0650867771151208}}], 
     Polygon3DBox[{{1.0351739080084825`, 
      3.857860195382847, -0.0325433885575604}, {1.0351739080084827`, 
      3.857860195382847, -0.03254338855756041}, {1., 
      4., -1.8480018286042463`*^-17}, {1., 4., 0.}, {1.0351739080084825`, 
      3.857860195382847, -0.0325433885575604}}], 
     Polygon3DBox[{{1., 4., 0.}, {1., 4., 5.60692789790848*^-18}, {
      0.9648260919915175, 4.142139804617153, 0.0325433885575604}, {
      0.9648260919915174, 4.142139804617153, 0.03254338855756039}, {1., 4., 
      0.}}], Polygon3DBox[{{0.9648260919915174, 4.142139804617153, 
      0.03254338855756039}, {0.9648260919915175, 4.142139804617153, 
      0.0325433885575604}, {0.9296521839830348, 4.284279609234306, 
      0.06508677711512079}, {0.9296521839830348, 4.284279609234306, 
      0.06508677711512079}, {0.9648260919915174, 4.142139804617153, 
      0.03254338855756039}}], 
     Polygon3DBox[{{0.9296521839830348, 4.284279609234306, 
      0.06508677711512079}, {0.9296521839830348, 4.284279609234306, 
      0.06508677711512079}, {0.8944782759745522, 4.426419413851459, 
      0.09763016567268118}, {0.8944782759745522, 4.426419413851459, 
      0.09763016567268117}, {0.9296521839830348, 4.284279609234306, 
      0.06508677711512079}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDb2l+4x3/DRXoNdMnvjNB6H3POrErz+7dh/1kSI
Q1Xho71U1O45p3fyOnh2ybxuW7lhf5oUZ4vQhA/2vGtjzz29wwcVX7CfAQw+
2ENoAYfKZy1GZkez9xiffvv91v139pWaFyV6Jwo4eEDU26dPu/1+6/639p+D
FhlKKQtCxTfYz0o8+XzC/Df2OTXFXsu3CDpkQ9yDIQ51p30amjlQd9qj2wt1
pz0Od9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwA37KMQ
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.5631108008182854, 
        3.902369834327319, -0.04578404076842598}, {0.5631108008182854, 
        3.902369834327319, -0.04578404076842597}, {0.7087405338788568, 
        3.9349132228848793`, -0.030522693845617305`}, {0.7087405338788568, 
        3.9349132228848793`, -0.03052269384561732}, {0.5631108008182854, 
        3.902369834327319, -0.04578404076842598}}], 
       Polygon3DBox[{{0.7087405338788568, 
        3.9349132228848793`, -0.03052269384561732}, {0.7087405338788568, 
        3.9349132228848793`, -0.030522693845617305`}, {0.8543702669394284, 
        3.9674566114424397`, -0.015261346922808658`}, {0.8543702669394284, 
        3.9674566114424397`, -0.015261346922808658`}, {0.7087405338788568, 
        3.9349132228848793`, -0.03052269384561732}}], 
       Polygon3DBox[{{0.8543702669394284, 
        3.9674566114424397`, -0.015261346922808658`}, {0.8543702669394284, 
        3.9674566114424397`, -0.015261346922808658`}, {0.9999999999999999, 
        4., -5.3175423324325605`*^-18}, {1., 4., 5.978123494563741*^-18}, {
        0.8543702669394284, 3.9674566114424397`, -0.015261346922808658`}}], 
       Polygon3DBox[{{1., 4., 5.978123494563741*^-18}, {1., 4., 
        5.978123494563741*^-18}, {1.1456297330605716`, 4.032543388557561, 
        0.01526134692280866}, {1.1456297330605716`, 4.032543388557561, 
        0.015261346922808665`}, {1., 4., 5.978123494563741*^-18}}], 
       Polygon3DBox[{{1.1456297330605716`, 4.032543388557561, 
        0.015261346922808665`}, {1.1456297330605716`, 4.032543388557561, 
        0.01526134692280866}, {1.2912594661211432`, 4.065086777115121, 
        0.030522693845617316`}, {1.2912594661211432`, 4.065086777115121, 
        0.030522693845617326`}, {1.1456297330605716`, 4.032543388557561, 
        0.015261346922808665`}}], 
       Polygon3DBox[{{1.2912594661211432`, 4.065086777115121, 
        0.030522693845617326`}, {1.2912594661211432`, 4.065086777115121, 
        0.030522693845617316`}, {1.4368891991817145`, 4.0976301656726815`, 
        0.045784040768425974`}, {1.4368891991817145`, 4.0976301656726815`, 
        0.04578404076842598}, {1.2912594661211432`, 4.065086777115121, 
        0.030522693845617326`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4Lfgdbr/oq2YsXL5fpf70
AoZ1z+zXSS8/sbmK36HKLNM/3HH+/kn7UwMYwl/bX+8NfhK5Fybev58BDD7Y
Q2gBh11MuodOcEftMVc4e70+5JO9qOU13mBFAYdyiHr7PIdZ6/+v+GKvWbRG
epmTgEMFxHz7JQnp7fV/v9nbrW7S/Jks4HAT4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+3eghRvUnftxhScADLCW5g==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.6686325248437331, 
      3.4759504204758596`, -0.14341420644110717`}, {0.45758907679283756`, 
      4.328789248178778, 0.05184612490425521}, {1.331367475156267, 
      4.52404957952414, 0.14341420644110717`}, {1.5424109232071626`, 
      3.671210751821222, -0.05184612490425521}, {0.6686325248437331, 
      3.4759504204758596`, -0.14341420644110717`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}, {0.45758907679283756`, 
       4.328789248178778, 0.05184612490425521}, {1.331367475156267, 
       4.52404957952414, 0.14341420644110717`}, {1.5424109232071626`, 
       3.671210751821222, -0.05184612490425521}, {0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.1289932943409875`, 
      4.584934346559962, -0.11653854877015467`}, {1.1289932943409877`, 
      4.584934346559963, -0.11653854877015465`}, {1.0859955295606585`, 
      4.723289564373308, -0.07769236584676976}, {1.0859955295606585`, 
      4.723289564373308, -0.07769236584676979}, {1.1289932943409875`, 
      4.584934346559962, -0.11653854877015467`}}], 
     Polygon3DBox[{{1.0859955295606585`, 
      4.723289564373308, -0.07769236584676979}, {1.0859955295606585`, 
      4.723289564373308, -0.07769236584676976}, {1.0429977647803292`, 
      4.861644782186654, -0.0388461829233849}, {1.0429977647803292`, 
      4.861644782186654, -0.038846182923384896`}, {1.0859955295606585`, 
      4.723289564373308, -0.07769236584676979}}], 
     Polygon3DBox[{{1.0429977647803292`, 
      4.861644782186654, -0.038846182923384896`}, {1.0429977647803292`, 
      4.861644782186654, -0.0388461829233849}, {1., 
      5., -2.1252763741135615`*^-17}, {1., 5., 0.}, {1.0429977647803292`, 
      4.861644782186654, -0.038846182923384896`}}], 
     Polygon3DBox[{{1., 5., 0.}, {1., 5., 7.499187392426035*^-18}, {
      0.9570022352196709, 5.138355217813346, 0.03884618292338489}, {
      0.9570022352196709, 5.138355217813346, 0.03884618292338488}, {1., 5., 
      0.}}], Polygon3DBox[{{0.9570022352196709, 5.138355217813346, 
      0.03884618292338488}, {0.9570022352196709, 5.138355217813346, 
      0.03884618292338489}, {0.9140044704393416, 5.276710435626692, 
      0.07769236584676976}, {0.9140044704393416, 5.276710435626692, 
      0.07769236584676978}, {0.9570022352196709, 5.138355217813346, 
      0.03884618292338488}}], 
     Polygon3DBox[{{0.9140044704393416, 5.276710435626692, 
      0.07769236584676978}, {0.9140044704393416, 5.276710435626692, 
      0.07769236584676976}, {0.8710067056590125, 5.415065653440037, 
      0.11653854877015465`}, {0.8710067056590125, 5.415065653440037, 
      0.11653854877015464`}, {0.9140044704393416, 5.276710435626692, 
      0.07769236584676978}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID4y4aRrtMAn+w8Kzew/w4Qc3r/ZkF5xde9+PW7D
mzYJH+2/iTKxLnsi5OD9uXTW0seb909vnZEjt+GD/W+uRqbgImGo+OL9DGDw
wR5CizgIL9jOwDW5YM/lL+fUDs9/Z8/6te7vml4RB0+IevulL+f6ttm/ted6
9fdXpLSogxfEfPuKezklnvdf2/Pfr/nBtlLU4S3EPXBxAag41J0Y5kDdaX8J
zV6oO+1xuNMG3V9Qd+7XRQsHqDv3w8LtIzTcoO7cjys8AU2IsAw=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{0.5696873477287563, 
        4.883461451229845, -0.06123551213008731}, {0.5696873477287563, 
        4.883461451229845, -0.061235512130087294`}, {0.7131248984858376, 
        4.92230763415323, -0.04082367475339153}, {0.7131248984858376, 
        4.92230763415323, -0.04082367475339155}, {0.5696873477287563, 
        4.883461451229845, -0.06123551213008731}}], 
       Polygon3DBox[{{0.7131248984858376, 
        4.92230763415323, -0.04082367475339155}, {0.7131248984858376, 
        4.92230763415323, -0.04082367475339153}, {0.8565624492429187, 
        4.961153817076615, -0.02041183737669577}, {0.8565624492429188, 
        4.961153817076615, -0.02041183737669577}, {0.7131248984858376, 
        4.92230763415323, -0.04082367475339155}}], 
       Polygon3DBox[{{0.8565624492429188, 
        4.961153817076615, -0.02041183737669577}, {0.8565624492429187, 
        4.961153817076615, -0.02041183737669577}, {0.9999999999999999, 
        5., -7.971866517242282*^-18}, {1., 5., 7.135928036432382*^-18}, {
        0.8565624492429188, 4.961153817076615, -0.02041183737669577}}], 
       Polygon3DBox[{{1., 5., 7.135928036432382*^-18}, {1., 5., 
        7.135928036432382*^-18}, {1.143437550757081, 5.038846182923385, 
        0.020411837376695767`}, {1.143437550757081, 5.038846182923385, 
        0.020411837376695774`}, {1., 5., 7.135928036432382*^-18}}], 
       Polygon3DBox[{{1.143437550757081, 5.038846182923385, 
        0.020411837376695774`}, {1.143437550757081, 5.038846182923385, 
        0.020411837376695767`}, {1.2868751015141624`, 5.07769236584677, 
        0.04082367475339153}, {1.2868751015141624`, 5.07769236584677, 
        0.040823674753391555`}, {1.143437550757081, 5.038846182923385, 
        0.020411837376695774`}}], 
       Polygon3DBox[{{1.2868751015141624`, 5.07769236584677, 
        0.040823674753391555`}, {1.2868751015141624`, 5.07769236584677, 
        0.04082367475339153}, {1.4303126522712435`, 5.116538548770155, 
        0.0612355121300873}, {1.4303126522712435`, 5.116538548770155, 
        0.06123551213008731}, {1.2868751015141624`, 5.07769236584677, 
        0.040823674753391555`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIO1zY9v+wUtX6/0455
fq8vPrM31piWWbhB2GHCmffm158t2a8Y47/8a8Zre0mR01ssbsDEp+xnAIMP
9hBaxKFca+46juzEPe8DI3RavT/ZP39t4n1cXcShF6Le/v7iDRFc07/Yn72e
Oa3PX8ShH2K+/bmvHK39j77Zbzk872FouYjDFYh77M+jiUPdiWEO1J32H9Ds
hbrTHoc7bdD9BXUnRjhA3bk/BS3coO7cjys8ASbvs0g=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{0.6986806420697439, 
      4.468395797789808, -0.17777406090024198`}, {0.4406940533877688, 
      5.298527104669883, 0.05530303664006736}, {1.301319357930256, 
      5.531604202210192, 0.17777406090024198`}, {1.5593059466122312`, 
      4.701472895330117, -0.05530303664006736}, {0.6986806420697439, 
      4.468395797789808, -0.17777406090024198`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}, {0.4406940533877688, 
       5.298527104669883, 0.05530303664006736}, {1.301319357930256, 
       5.531604202210192, 0.17777406090024198`}, {1.5593059466122312`, 
       4.701472895330117, -0.05530303664006736}, {0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.869252174881742, -5.415214614705815, 
      0.11402556713977308`}, {1.869252174881742, -5.415214614705815, 
      0.11402556713977309`}, {1.9128347832544945`, -5.27680974313721, 
      0.07601704475984872}, {1.9128347832544945`, -5.2768097431372105`, 
      0.07601704475984872}, {1.869252174881742, -5.415214614705815, 
      0.11402556713977308`}}], 
     Polygon3DBox[{{1.9128347832544945`, -5.2768097431372105`, 
      0.07601704475984872}, {1.9128347832544945`, -5.27680974313721, 
      0.07601704475984872}, {1.9564173916272474`, -5.138404871568605, 
      0.03800852237992439}, {1.9564173916272471`, -5.138404871568605, 
      0.03800852237992436}, {1.9128347832544945`, -5.2768097431372105`, 
      0.07601704475984872}}], 
     Polygon3DBox[{{1.9564173916272471`, -5.138404871568605, 
      0.03800852237992436}, {1.9564173916272474`, -5.138404871568605, 
      0.03800852237992439}, {2., -5., 3.746710059903171*^-17}, {2., -5., 
      0.}, {1.9564173916272471`, -5.138404871568605, 0.03800852237992436}}], 
     Polygon3DBox[{{2., -5., 0.}, {2., -5., 9.335142813583325*^-18}, {
      2.043582608372753, -4.861595128431395, -0.03800852237992434}, {
      2.043582608372753, -4.861595128431395, -0.038008522379924345`}, {
      2., -5., 0.}}], 
     Polygon3DBox[{{
      2.043582608372753, -4.861595128431395, -0.038008522379924345`}, {
      2.043582608372753, -4.861595128431395, -0.03800852237992434}, {
      2.0871652167455053`, -4.72319025686279, -0.07601704475984869}, {
      2.0871652167455053`, -4.72319025686279, -0.0760170447598487}, {
      2.043582608372753, -4.861595128431395, -0.038008522379924345`}}], 
     Polygon3DBox[{{
      2.0871652167455053`, -4.72319025686279, -0.0760170447598487}, {
      2.0871652167455053`, -4.72319025686279, -0.07601704475984869}, {
      2.130747825118258, -4.584785385294185, -0.11402556713977306`}, {
      2.130747825118258, -4.584785385294185, -0.11402556713977305`}, {
      2.0871652167455053`, -4.72319025686279, -0.0760170447598487}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7W8PF7yYu/9r7vpFn1Vooe+PHu6MTjBnvtLVd7
L/0x65+9yZd05hJp0QMB8/USb5Vutp9zdWlQje9/e6lfmxl39YpAxRfbM0CA
A4QSOZCr/yeg27zAxkh07TXHSAaHZ6w+/1yLhA/4QdTvT9aKWtu8icHhLPeM
P91PhA74Q8zfP9WeveUoN6PDZsEnvy6GCR34BnEPhjjUnftToOacgZoDded+
dHuh7tyPw5175qL5C+pOeDgYQ8MB6k579HCDuhNDHBaeAPT8qmA=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        1.5714121092718345`, -4.885974432860227, -0.07622722584244547}, {
        1.5714121092718345`, -4.885974432860227, -0.07622722584244548}, {
        1.7142747395145563`, -4.9239829552401515`, -0.050818150561630325`}, {
        1.7142747395145563`, -4.9239829552401515`, -0.050818150561630325`}, {
        1.5714121092718345`, -4.885974432860227, -0.07622722584244547}}], 
       Polygon3DBox[{{
        1.7142747395145563`, -4.9239829552401515`, -0.050818150561630325`}, {
        1.7142747395145563`, -4.9239829552401515`, -0.050818150561630325`}, {
        1.8571373697572782`, -4.961991477620075, -0.02540907528081518}, {
        1.8571373697572782`, -4.961991477620075, -0.025409075280815166`}, {
        1.7142747395145563`, -4.9239829552401515`, -0.050818150561630325`}}], 
       Polygon3DBox[{{
        1.8571373697572782`, -4.961991477620075, -0.025409075280815166`}, {
        1.8571373697572782`, -4.961991477620075, -0.02540907528081518}, {
        2., -5., -2.5788545898397507`*^-17}, {
        2., -5., -6.982052290934236*^-18}, {
        1.8571373697572782`, -4.961991477620075, -0.025409075280815166`}}], 
       Polygon3DBox[{{2., -5., -6.982052290934236*^-18}, {
        2., -5., -6.982052290934236*^-18}, {
        2.1428626302427216`, -5.038008522379925, 0.02540907528081515}, {
        2.1428626302427216`, -5.038008522379925, 0.02540907528081514}, {
        2., -5., -6.982052290934236*^-18}}], 
       Polygon3DBox[{{2.1428626302427216`, -5.038008522379925, 
        0.02540907528081514}, {2.1428626302427216`, -5.038008522379925, 
        0.02540907528081515}, {2.2857252604854437`, -5.0760170447598485`, 
        0.050818150561630304`}, {2.2857252604854437`, -5.0760170447598485`, 
        0.0508181505616303}, {2.1428626302427216`, -5.038008522379925, 
        0.02540907528081514}}], 
       Polygon3DBox[{{2.2857252604854437`, -5.0760170447598485`, 
        0.0508181505616303}, {2.2857252604854437`, -5.0760170447598485`, 
        0.050818150561630304`}, {2.4285878907281653`, -5.114025567139773, 
        0.07622722584244547}, {2.4285878907281653`, -5.114025567139773, 
        0.07622722584244544}, {2.2857252604854437`, -5.0760170447598485`, 
        0.0508181505616303}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIHHB/wLVrQvHn/Lb3M
yNW5v+2bXaunaWwSPsCsnal7jWXV/tzpW9Zc3fbX/uAiW2+RmzDxWfsZIMAB
Qokc0PmpU71pXeoezy1LNaeqMDrYxx7a8lpN5AADRL395AzvYC1PJofaXS2Z
131FDjBCzLe/I/OxZn8us8MecXe5wyUiBxwg7sEQh7oTwxyoO+290OyFutMe
hztt0P0FdSdGOEDdud8DLdyg7tyPKzwBIROWmg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.4406642841535762`, -5.301189047566042, 
      0.037798341297327606`}, {
      1.7021599343900928`, -4.470759818154412, -0.19025279298221853`}, {
      2.559335715846424, -4.698810952433958, -0.037798341297327606`}, {
      2.297840065609907, -5.529240181845588, 0.19025279298221853`}, {
      1.4406642841535762`, -5.301189047566042, 0.037798341297327606`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.4406642841535762`, -5.301189047566042, 
       0.037798341297327606`}, {
       1.7021599343900928`, -4.470759818154412, -0.19025279298221853`}, {
       2.559335715846424, -4.698810952433958, -0.037798341297327606`}, {
       2.297840065609907, -5.529240181845588, 0.19025279298221853`}, {
       1.4406642841535762`, -5.301189047566042, 0.037798341297327606`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.892903738327715, -4.426467649779901, 
      0.09568560198394237}, {1.8929037383277152`, -4.426467649779901, 
      0.09568560198394238}, {1.9286024922184768`, -4.2843117665199335`, 
      0.06379040132262825}, {1.9286024922184766`, -4.2843117665199335`, 
      0.06379040132262825}, {1.892903738327715, -4.426467649779901, 
      0.09568560198394237}}], 
     Polygon3DBox[{{1.9286024922184766`, -4.2843117665199335`, 
      0.06379040132262825}, {1.9286024922184768`, -4.2843117665199335`, 
      0.06379040132262825}, {1.9643012461092384`, -4.142155883259967, 
      0.03189520066131414}, {1.9643012461092384`, -4.142155883259967, 
      0.03189520066131413}, {1.9286024922184766`, -4.2843117665199335`, 
      0.06379040132262825}}], 
     Polygon3DBox[{{1.9643012461092384`, -4.142155883259967, 
      0.03189520066131413}, {1.9643012461092384`, -4.142155883259967, 
      0.03189520066131414}, {2., -4., 3.1068948481505124`*^-17}, {2., -4., 
      0.}, {1.9643012461092384`, -4.142155883259967, 0.03189520066131413}}], 
     Polygon3DBox[{{2., -4., 0.}, {2., -4., 7.461757715351485*^-18}, {
      2.035698753890762, -3.8578441167400332`, -0.031895200661314106`}, {
      2.035698753890762, -3.8578441167400332`, -0.03189520066131411}, {
      2., -4., 0.}}], 
     Polygon3DBox[{{
      2.035698753890762, -3.8578441167400332`, -0.03189520066131411}, {
      2.035698753890762, -3.8578441167400332`, -0.031895200661314106`}, {
      2.071397507781523, -3.7156882334800665`, -0.06379040132262823}, {
      2.071397507781523, -3.715688233480066, -0.06379040132262824}, {
      2.035698753890762, -3.8578441167400332`, -0.03189520066131411}}], 
     Polygon3DBox[{{
      2.071397507781523, -3.715688233480066, -0.06379040132262824}, {
      2.071397507781523, -3.7156882334800665`, -0.06379040132262823}, {
      2.107096261672285, -3.5735323502200993`, -0.09568560198394235}, {
      2.107096261672285, -3.5735323502200993`, -0.09568560198394234}, {
      2.071397507781523, -3.715688233480066, -0.06379040132262824}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5Sr5kX6vnP3jy36f3mLYIH3MUtmG/V7bA/+7/A
s+/2P/vzHmvmKykLHjDYVRU+MWSD/fP6HSrHc//bZ6hc8584UQAqvsCeAQIc
IJTAgZ8PFJ/PMc+24T2wOFfGk8HBcHtwwt07fAf0IOr3Sza437aYxOCQmLf8
wK6dvAf0IebvV3N47RF6m8FhkupvhRnTeA64QtyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwB+/+d/A==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        1.5645326466546545`, -3.9043143980160577`, -0.06092987562247867}, {
        1.5645326466546545`, -3.9043143980160577`, -0.06092987562247868}, {
        1.709688431103103, -3.9362095986773715`, -0.04061991708165245}, {
        1.709688431103103, -3.9362095986773715`, -0.04061991708165245}, {
        1.5645326466546545`, -3.9043143980160577`, -0.06092987562247867}}], 
       Polygon3DBox[{{
        1.709688431103103, -3.9362095986773715`, -0.04061991708165245}, {
        1.709688431103103, -3.9362095986773715`, -0.04061991708165245}, {
        1.8548442155515514`, -3.9681047993386858`, -0.020309958540826237`}, {
        1.8548442155515514`, -3.9681047993386858`, -0.020309958540826227`}, {
        1.709688431103103, -3.9362095986773715`, -0.04061991708165245}}], 
       Polygon3DBox[{{
        1.8548442155515514`, -3.9681047993386858`, -0.020309958540826227`}, {
        1.8548442155515514`, -3.9681047993386858`, -0.020309958540826237`}, {
        2., -4., -2.089144237717788*^-17}, {
        2., -4., -5.8590533097061324`*^-18}, {
        1.8548442155515514`, -3.9681047993386858`, -0.020309958540826227`}}], 
       Polygon3DBox[{{2., -4., -5.8590533097061324`*^-18}, {
        2., -4., -5.8590533097061324`*^-18}, {
        2.1451557844484483`, -4.031895200661314, 0.020309958540826213`}, {
        2.1451557844484483`, -4.031895200661314, 0.02030995854082621}, {
        2., -4., -5.8590533097061324`*^-18}}], 
       Polygon3DBox[{{2.1451557844484483`, -4.031895200661314, 
        0.02030995854082621}, {2.1451557844484483`, -4.031895200661314, 
        0.020309958540826213`}, {2.2903115688968967`, -4.0637904013226285`, 
        0.04061991708165243}, {2.2903115688968967`, -4.0637904013226285`, 
        0.04061991708165243}, {2.1451557844484483`, -4.031895200661314, 
        0.02030995854082621}}], 
       Polygon3DBox[{{2.2903115688968967`, -4.0637904013226285`, 
        0.04061991708165243}, {2.2903115688968967`, -4.0637904013226285`, 
        0.04061991708165243}, {2.4354673533453455`, -4.095685601983942, 
        0.06092987562247866}, {2.4354673533453455`, -4.095685601983942, 
        0.06092987562247864}, {2.2903115688968967`, -4.0637904013226285`, 
        0.04061991708165243}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Thv/A5h3eccZG6/fX/5/n
+Cjqt72elktpdC3/gbOqd+2UzizZv7/+vELh2r/24qKLdq3dBxOfsp8BAhwg
lMCBq1+STI6HJO5RcJiR767J6FDydZ3SSgWBA6ch6u0dGgzu9wUxObx8Fesa
5Chw4AzEfPvEAyf8rlUzO8Q+4Mn4nShwYCPEPRjiUHfaO6KZA3WnPbq9UHfa
43CnzQE0f0HdCQ8HfWg4QN253x4t3KDu3I8rPAGnipmB
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.4574363849823695`, -4.330782047795958, 
      0.0347557263614637}, {
      1.6716289083269396`, -3.477846748236157, -0.15661547760642103`}, {
      2.5425636150176305`, -3.6692179522040416`, -0.0347557263614637}, {
      2.3283710916730604`, -4.522153251763843, 0.15661547760642103`}, {
      1.4574363849823695`, -4.330782047795958, 0.0347557263614637}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.4574363849823695`, -4.330782047795958, 
       0.0347557263614637}, {
       1.6716289083269396`, -3.477846748236157, -0.15661547760642103`}, {
       2.5425636150176305`, -3.6692179522040416`, -0.0347557263614637}, {
       2.3283710916730604`, -4.522153251763843, 0.15661547760642103`}, {
       1.4574363849823695`, -4.330782047795958, 0.0347557263614637}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.9181179562782646`, -3.4361475544378655`, 
      0.07463673139829312}, {1.9181179562782646`, -3.4361475544378655`, 
      0.07463673139829313}, {1.9454119708521764`, -3.2907650362919103`, 
      0.04975782093219541}, {1.9454119708521764`, -3.2907650362919103`, 
      0.04975782093219542}, {1.9181179562782646`, -3.4361475544378655`, 
      0.07463673139829312}}], 
     Polygon3DBox[{{1.9454119708521764`, -3.2907650362919103`, 
      0.04975782093219542}, {1.9454119708521764`, -3.2907650362919103`, 
      0.04975782093219541}, {1.9727059854260882`, -3.145382518145955, 
      0.024878910466097724`}, {1.9727059854260882`, -3.145382518145955, 
      0.02487891046609771}, {1.9454119708521764`, -3.2907650362919103`, 
      0.04975782093219542}}], 
     Polygon3DBox[{{1.9727059854260882`, -3.145382518145955, 
      0.02487891046609771}, {1.9727059854260882`, -3.145382518145955, 
      0.024878910466097724`}, {2., -3., 2.4275082521479556`*^-17}, {2., -3., 
      0.}, {1.9727059854260882`, -3.145382518145955, 0.02487891046609771}}], 
     Polygon3DBox[{{2., -3., 0.}, {2., -3., 5.8609897034465846`*^-18}, {
      2.027294014573912, -2.854617481854045, -0.024878910466097696`}, {
      2.027294014573912, -2.854617481854045, -0.0248789104660977}, {2., -3., 
      0.}}], Polygon3DBox[{{
      2.027294014573912, -2.854617481854045, -0.0248789104660977}, {
      2.027294014573912, -2.854617481854045, -0.024878910466097696`}, {
      2.0545880291478236`, -2.7092349637080897`, -0.0497578209321954}, {
      2.0545880291478236`, -2.7092349637080897`, -0.049757820932195405`}, {
      2.027294014573912, -2.854617481854045, -0.0248789104660977}}], 
     Polygon3DBox[{{
      2.0545880291478236`, -2.7092349637080897`, -0.049757820932195405`}, {
      2.0545880291478236`, -2.7092349637080897`, -0.0497578209321954}, {
      2.0818820437217354`, -2.5638524455621345`, -0.0746367313982931}, {
      2.0818820437217354`, -2.5638524455621345`, -0.0746367313982931}, {
      2.0545880291478236`, -2.7092349637080897`, -0.049757820932195405`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILaKcyyZs+Gf/b/gK2+tarkPcM/Ln5Aivdm+5mWD
b4bCf/uQ3t55NcFcB1Jr7bNvV66031dyQM1kwn/7Vcfc/PdpckLFZ9ozQIAD
hOI4cNmWq+WhVarNwqPz3zw1Z3AIs9y5wfEa24EkiPr9Tt32N0/nMzisKSpK
bF7DeiAZYv7+xwH3j25czuDAtEZb6GgTywEuiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScADh6hHw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        1.5588209983435757`, -2.925363268601707, -0.04785861284679986}, {
        1.5588209983435757`, -2.925363268601707, -0.04785861284679987}, {
        1.705880665562384, -2.9502421790678044`, -0.03190574189786658}, {
        1.7058806655623837`, -2.9502421790678044`, -0.03190574189786658}, {
        1.5588209983435757`, -2.925363268601707, -0.04785861284679986}}], 
       Polygon3DBox[{{
        1.7058806655623837`, -2.9502421790678044`, -0.03190574189786658}, {
        1.705880665562384, -2.9502421790678044`, -0.03190574189786658}, {
        1.8529403327811917`, -2.975121089533902, -0.0159528709489333}, {
        1.852940332781192, -2.975121089533902, -0.015952870948933294`}, {
        1.7058806655623837`, -2.9502421790678044`, -0.03190574189786658}}], 
       Polygon3DBox[{{
        1.852940332781192, -2.975121089533902, -0.015952870948933294`}, {
        1.8529403327811917`, -2.975121089533902, -0.0159528709489333}, {
        2., -3., -1.6377678134540027`*^-17}, {
        2., -3., -4.570181710287021*^-18}, {
        1.852940332781192, -2.975121089533902, -0.015952870948933294`}}], 
       Polygon3DBox[{{2., -3., -4.570181710287021*^-18}, {
        2., -3., -4.570181710287021*^-18}, {
        2.1470596672188083`, -3.024878910466098, 0.01595287094893328}, {
        2.1470596672188083`, -3.024878910466098, 0.015952870948933277`}, {
        2., -3., -4.570181710287021*^-18}}], 
       Polygon3DBox[{{2.1470596672188083`, -3.024878910466098, 
        0.015952870948933277`}, {2.1470596672188083`, -3.024878910466098, 
        0.01595287094893328}, {2.294119334437616, -3.0497578209321956`, 
        0.03190574189786657}, {2.294119334437616, -3.049757820932195, 
        0.03190574189786657}, {2.1470596672188083`, -3.024878910466098, 
        0.015952870948933277`}}], 
       Polygon3DBox[{{2.294119334437616, -3.049757820932195, 
        0.03190574189786657}, {2.294119334437616, -3.0497578209321956`, 
        0.03190574189786657}, {2.4411790016564243`, -3.074636731398293, 
        0.047858612846799854`}, {2.4411790016564243`, -3.074636731398293, 
        0.04785861284679984}, {2.294119334437616, -3.049757820932195, 
        0.03190574189786657}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdPYD0yaxTHrTsGL/0sbw
Nk/v3/ZcTMGTJGaxH0jlYeb5HLpg/+UD2oeXLP1rz9qo6clzFiY+YT8DBDhA
KI4DfzKjMl9ZRu+ZLp81T1eX0eF33bVtn404DiRD1Nvr2l+xiY5icvj2d03u
81SOAykQ8+2PxNnd7mhndvhQ06xyewbHgSkQ92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6c/8ytHCAunM/erhB3YkhDgtPAOtJmX8=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.4769389546218403`, -3.3615108230395725`, 
      0.026778118551493257`}, {
      1.640703042065311, -2.489215714163841, -0.12249534424509298`}, {
      2.5230610453781597`, -2.6384891769604275`, -0.026778118551493257`}, {
      2.359296957934689, -3.510784285836159, 0.12249534424509298`}, {
      1.4769389546218403`, -3.3615108230395725`, 0.026778118551493257`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.4769389546218403`, -3.3615108230395725`, 
       0.026778118551493257`}, {
       1.640703042065311, -2.489215714163841, -0.12249534424509298`}, {
       2.5230610453781597`, -2.6384891769604275`, -0.026778118551493257`}, {
       2.359296957934689, -3.510784285836159, 0.12249534424509298`}, {
       1.4769389546218403`, -3.3615108230395725`, 0.026778118551493257`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.9446286321645672`, -2.4436316014098365`, 
      0.05123488903644718}, {1.9446286321645674`, -2.4436316014098365`, 
      0.051234889036447184`}, {1.9630857547763783`, -2.295754400939891, 
      0.034156592690964785`}, {1.963085754776378, -2.295754400939891, 
      0.034156592690964785`}, {1.9446286321645672`, -2.4436316014098365`, 
      0.05123488903644718}}], 
     Polygon3DBox[{{1.963085754776378, -2.295754400939891, 
      0.034156592690964785`}, {1.9630857547763783`, -2.295754400939891, 
      0.034156592690964785`}, {1.9815428773881891`, -2.147877200469946, 
      0.017078296345482406`}, {1.9815428773881891`, -2.1478772004699453`, 
      0.017078296345482392`}, {1.963085754776378, -2.295754400939891, 
      0.034156592690964785`}}], 
     Polygon3DBox[{{1.9815428773881891`, -2.1478772004699453`, 
      0.017078296345482392`}, {1.9815428773881891`, -2.147877200469946, 
      0.017078296345482406`}, {2., -2., 1.7270413504216556`*^-17}, {2., -2., 
      0.}, {1.9815428773881891`, -2.1478772004699453`, 
      0.017078296345482392`}}], 
     Polygon3DBox[{{2., -2., 0.}, {2., -2., 4.629934954799078*^-18}, {
      2.018457122611811, -1.8521227995300544`, -0.017078296345482386`}, {
      2.018457122611811, -1.8521227995300544`, -0.01707829634548239}, {
      2., -2., 0.}}], 
     Polygon3DBox[{{
      2.018457122611811, -1.8521227995300544`, -0.01707829634548239}, {
      2.018457122611811, -1.8521227995300544`, -0.017078296345482386`}, {
      2.0369142452236217`, -1.704245599060109, -0.03415659269096478}, {
      2.0369142452236217`, -1.7042455990601089`, -0.03415659269096478}, {
      2.018457122611811, -1.8521227995300544`, -0.01707829634548239}}], 
     Polygon3DBox[{{
      2.0369142452236217`, -1.7042455990601089`, -0.03415659269096478}, {
      2.0369142452236217`, -1.704245599060109, -0.03415659269096478}, {
      2.055371367835433, -1.5563683985901635`, -0.05123488903644717}, {
      2.055371367835433, -1.5563683985901635`, -0.05123488903644716}, {
      2.0369142452236217`, -1.7042455990601089`, -0.03415659269096478}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYzXPDSSPa/PZvFnJ19PcwH2I8tm1lqvcr+psKB
2Wcy/tuvr9pbvSWW6UDUTUnBnzUL7XMFHvimbflvH773nu0tPUao+ER7Bghw
gNIHHLIaZOarxtqc+s5/84wqg0Ngq1OL96K/+yMh6vdPfi+/aaY3g8MirlaO
6S6/oeIL98c+1+9OK2Rw+NJ/vOfRsx/7WSHuwRCHuhPDHKg796PbC3Xnfhzu
3IPuL6g7McIB6k579HCDuhNDHBaeAA2DpIA=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        1.5545275870096076`, -1.9487651109635529`, -0.03780628796827476}, {
        1.5545275870096076`, -1.9487651109635529`, -0.03780628796827477}, {
        1.7030183913397383`, -1.9658434073090352`, -0.025204191978849846`}, {
        1.7030183913397383`, -1.9658434073090352`, -0.025204191978849846`}, {
        1.5545275870096076`, -1.9487651109635529`, -0.03780628796827476}}], 
       Polygon3DBox[{{
        1.7030183913397383`, -1.9658434073090352`, -0.025204191978849846`}, {
        1.7030183913397383`, -1.9658434073090352`, -0.025204191978849846`}, {
        1.851509195669869, -1.9829217036545175`, -0.01260209598942493}, {
        1.8515091956698693`, -1.9829217036545177`, -0.012602095989424925`}, {
        1.7030183913397383`, -1.9658434073090352`, -0.025204191978849846`}}], 
       Polygon3DBox[{{
        1.8515091956698693`, -1.9829217036545177`, -0.012602095989424925`}, {
        1.851509195669869, -1.9829217036545175`, -0.01260209598942493}, {
        2., -2., -1.246465689382167*^-17}, {
        2., -2., -3.1372321431577427`*^-18}, {
        1.8515091956698693`, -1.9829217036545177`, -0.012602095989424925`}}], 
       Polygon3DBox[{{2., -2., -3.1372321431577427`*^-18}, {
        2., -2., -3.1372321431577427`*^-18}, {
        2.1484908043301307`, -2.0170782963454825`, 0.012602095989424916`}, {
        2.1484908043301307`, -2.0170782963454825`, 0.012602095989424914`}, {
        2., -2., -3.1372321431577427`*^-18}}], 
       Polygon3DBox[{{2.1484908043301307`, -2.0170782963454825`, 
        0.012602095989424914`}, {2.1484908043301307`, -2.0170782963454825`, 
        0.012602095989424916`}, {2.2969816086602615`, -2.0341565926909646`, 
        0.025204191978849835`}, {2.2969816086602615`, -2.0341565926909646`, 
        0.025204191978849832`}, {2.1484908043301307`, -2.0170782963454825`, 
        0.012602095989424914`}}], 
       Polygon3DBox[{{2.2969816086602615`, -2.0341565926909646`, 
        0.025204191978849832`}, {2.2969816086602615`, -2.0341565926909646`, 
        0.025204191978849835`}, {2.4454724129903926`, -2.051234889036447, 
        0.03780628796827476}, {2.445472412990392, -2.051234889036447, 
        0.037806287968274746`}, {2.2969816086602615`, -2.0341565926909646`, 
        0.025204191978849832`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7v/xNyoSUievH+3ctK
zCbY/7Y3NSw3lyj5v3/5MdGNCudn7o8LtpI+Mf+v/ewZu6V5dsHEO/czQIAD
lD7QpTpp8ofG0D2B15I+SRswOmw2Vvr0U4nhwBKIevtFa44+MU9gckhNd3ny
2ZXhwFKI+fafmzSuB09gdpCYnXbtbQbDgd8Q99h/QROHuhPDHKg77dHthbrT
Hoc7bdD9BXUnRjhA3bkfPdyg7sQQh4UnAEs1qdI=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.4991562191741747`, -2.3923967123733894`, 
      0.013428601068172417`}, {
      1.6098989548450404`, -1.5051335095537164`, -0.08904117700472194}, {
      2.500843780825825, -1.6076032876266106`, -0.013428601068172417`}, {
      2.39010104515496, -2.4948664904462836`, 0.08904117700472194}, {
      1.4991562191741747`, -2.3923967123733894`, 0.013428601068172417`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.4991562191741747`, -2.3923967123733894`, 
       0.013428601068172417`}, {
       1.6098989548450404`, -1.5051335095537164`, -0.08904117700472194}, {
       2.500843780825825, -1.6076032876266106`, -0.013428601068172417`}, {
       2.39010104515496, -2.4948664904462836`, 0.08904117700472194}, {
       1.4991562191741747`, -2.3923967123733894`, 0.013428601068172417`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.972070577249549, -1.4483743280284576`, 
      0.026084656598385412`}, {1.972070577249549, -1.4483743280284576`, 
      0.02608465659838542}, {1.9813803848330327`, -1.2989162186856384`, 
      0.01738977106559028}, {1.9813803848330327`, -1.2989162186856384`, 
      0.017389771065590278`}, {1.972070577249549, -1.4483743280284576`, 
      0.026084656598385412`}}], 
     Polygon3DBox[{{1.9813803848330327`, -1.2989162186856384`, 
      0.017389771065590278`}, {1.9813803848330327`, -1.2989162186856384`, 
      0.01738977106559028}, {1.9906901924165163`, -1.1494581093428193`, 
      0.008694885532795148}, {1.9906901924165163`, -1.1494581093428193`, 
      0.008694885532795139}, {1.9813803848330327`, -1.2989162186856384`, 
      0.017389771065590278`}}], 
     Polygon3DBox[{{1.9906901924165163`, -1.1494581093428193`, 
      0.008694885532795139}, {1.9906901924165163`, -1.1494581093428193`, 
      0.008694885532795148}, {2., -1.0000000000000002`, 
      1.028820450357654*^-17}, {2., -1., 0.}, {
      1.9906901924165163`, -1.1494581093428193`, 0.008694885532795139}}], 
     Polygon3DBox[{{2., -1., 0.}, {2., -1., 3.852696426916983*^-18}, {
      2.0093098075834837`, -0.8505418906571808, -0.008694885532795134}, {
      2.0093098075834837`, -0.8505418906571808, -0.008694885532795136}, {
      2., -1., 0.}}], 
     Polygon3DBox[{{
      2.0093098075834837`, -0.8505418906571808, -0.008694885532795136}, {
      2.0093098075834837`, -0.8505418906571808, -0.008694885532795134}, {
      2.0186196151669673`, -0.7010837813143616, -0.01738977106559027}, {
      2.0186196151669673`, -0.7010837813143616, -0.017389771065590275`}, {
      2.0093098075834837`, -0.8505418906571808, -0.008694885532795136}}], 
     Polygon3DBox[{{
      2.0186196151669673`, -0.7010837813143616, -0.017389771065590275`}, {
      2.0186196151669673`, -0.7010837813143616, -0.01738977106559027}, {
      2.027929422750451, -0.5516256719715423, -0.02608465659838541}, {
      2.027929422750451, -0.5516256719715424, -0.026084656598385405`}, {
      2.0186196151669673`, -0.7010837813143616, -0.017389771065590275`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Ds/rBzN7/9ot+GPd36Xzf//O+4Jr3W2fZe2yW
eb1783978d/l8TEnvuxf/or7xPxzE+2XRPZ9vXvzv33P3936eimfoOKN9gwQ
4AChPuzPuiP8Y8taXxu9yxasgsIMDi9ZOhYsNn+9fylE/f6YZYVcSmoMDpc4
BRzd85/tXwYxf39X5Sp+Y0sGhz18Mx6+WvZw/3eIe+Diu6HiUHdimAN15350
e6Hu3I/DnXtg/uqG+gvqToxwgLrTHj3coO7EEIeFJwCcs7sn
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        1.5518595299730515`, -0.9739153434016146, -0.03145965375159091}, {
        1.5518595299730515`, -0.9739153434016146, -0.03145965375159091}, {
        1.701239686648701, -0.9826102289344096, -0.02097310250106061}, {
        1.701239686648701, -0.9826102289344097, -0.02097310250106061}, {
        1.5518595299730515`, -0.9739153434016146, -0.03145965375159091}}], 
       Polygon3DBox[{{
        1.701239686648701, -0.9826102289344097, -0.02097310250106061}, {
        1.701239686648701, -0.9826102289344096, -0.02097310250106061}, {
        1.8506198433243504`, -0.9913051144672048, -0.01048655125053031}, {
        1.8506198433243504`, -0.9913051144672048, -0.010486551250530307`}, {
        1.701239686648701, -0.9826102289344097, -0.02097310250106061}}], 
       Polygon3DBox[{{
        1.8506198433243504`, -0.9913051144672048, -0.010486551250530307`}, {
        1.8506198433243504`, -0.9913051144672048, -0.01048655125053031}, {
        2., -1., -9.35883165867051*^-18}, {
        2., -1., -1.5972245605035291`*^-18}, {
        1.8506198433243504`, -0.9913051144672048, -0.010486551250530307`}}], 
       Polygon3DBox[{{2., -1., -1.5972245605035291`*^-18}, {
        2., -1., -1.5972245605035291`*^-18}, {
        2.1493801566756496`, -1.008694885532795, 0.010486551250530298`}, {
        2.1493801566756496`, -1.008694885532795, 0.010486551250530298`}, {
        2., -1., -1.5972245605035291`*^-18}}], 
       Polygon3DBox[{{2.1493801566756496`, -1.008694885532795, 
        0.010486551250530298`}, {2.1493801566756496`, -1.008694885532795, 
        0.010486551250530298`}, {2.298760313351299, -1.0173897710655904`, 
        0.0209731025010606}, {2.2987603133512993`, -1.0173897710655901`, 
        0.020973102501060603`}, {2.1493801566756496`, -1.008694885532795, 
        0.010486551250530298`}}], 
       Polygon3DBox[{{2.2987603133512993`, -1.0173897710655901`, 
        0.020973102501060603`}, {2.298760313351299, -1.0173897710655904`, 
        0.0209731025010606}, {2.4481404700269485`, -1.0260846565983854`, 
        0.031459653751590905`}, {2.4481404700269485`, -1.0260846565983854`, 
        0.031459653751590905`}, {2.2987603133512993`, -1.0173897710655901`, 
        0.020973102501060603`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7v3xrDfKFKesH+t8y8
0u4Wv+1XL9jP2F34fv+nC5GiPyun7v/W2NarPOevfeiF+w1Hd8DEW/czQIAD
hPqwX05P4fmSp4F7WPfbWL4zZHS4Kj7Bfq7yh/3vIertueoqi+4kMzms1leo
t3L/sP8jxHx7Ptttq09NZXZocN+w73rWh/1bIO7BEIe6E8McqDvt0e2FutMe
hzttvqP5C+pOjHCAunM/erhB3YkhDgtPAOhqriA=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}, {
      1.5797889527235025`, -0.5255410153731569, -0.05754431034997633}, {
      2.4760698927773994`, -0.5777103285699278, 0.0053749971532055}, {
      2.4202110472764975`, -1.474458984626843, 0.05754431034997633}, {
      1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}, {
       1.5797889527235025`, -0.5255410153731569, -0.05754431034997633}, {
       2.4760698927773994`, -0.5777103285699278, 0.0053749971532055}, {
       2.4202110472764975`, -1.474458984626843, 0.05754431034997633}, {
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2., -0.45, 0.}, {2., -0.45, 7.17357845216038*^-18}, {
      2., -0.3, 5.977982043466983*^-18}, {2., -0.30000000000000004`, 0.}, {
      2., -0.45, 0.}}], 
     Polygon3DBox[{{2., -0.30000000000000004`, 0.}, {2., -0.3, 
      5.977982043466983*^-18}, {2., -0.15000000000000008`, 
      4.782385634773587*^-18}, {2., -0.15000000000000002`, 0.}, {
      2., -0.30000000000000004`, 0.}}], 
     Polygon3DBox[{{2., -0.15000000000000002`, 0.}, {
      2., -0.15000000000000008`, 4.782385634773587*^-18}, {
      2., -1.1102230246251565`*^-16, 3.586789226080191*^-18}, {2., 0., 0.}, {
      2., -0.15000000000000002`, 0.}}], 
     Polygon3DBox[{{2., 0., 0.}, {2., 0., 3.58678922608019*^-18}, {2., 
      0.14999999999999997`, 2.3911928173867936`*^-18}, {2., 
      0.14999999999999997`, 0.}, {2., 0., 0.}}], 
     Polygon3DBox[{{2., 0.14999999999999997`, 0.}, {2., 0.14999999999999997`, 
      2.3911928173867936`*^-18}, {2., 0.29999999999999993`, 
      1.195596408693397*^-18}, {2., 0.3, 0.}, {2., 0.14999999999999997`, 
      0.}}], Polygon3DBox[{{2., 0.3, 0.}, {2., 0.29999999999999993`, 
      1.1955964086933972`*^-18}, {2., 0.44999999999999996`, 
      5.973203974907509*^-34}, {2., 0.4499999999999999, 0.}, {2., 0.3, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjhwOHsGBO7sZ0AFDibGIHAZh/hhDHEINWEPurgR
RL09urgxxHwM8dMQ92CIn8UhboLDHBMc9kLdaYPDnRj+MsYRDqdxhBt6eAIA
pSs6aA==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{1.5509541313373787`, 0., -0.02928835668028898}, {
        1.5509541313373787`, 
        5.5109105961630896`*^-17, -0.02928835668028898}, {1.7006360875582525`,
         4.592425496802574*^-17, -0.019525571120192653`}, {
        1.7006360875582525`, 
        9.184850993605149*^-18, -0.019525571120192656`}, {1.5509541313373787`,
         0., -0.02928835668028898}}], 
       Polygon3DBox[{{1.7006360875582525`, 
        9.184850993605149*^-18, -0.019525571120192656`}, {1.7006360875582525`,
         4.592425496802574*^-17, -0.019525571120192653`}, {
        1.8503180437791262`, 3.67394039744206*^-17, -0.009762785560096332}, {
        1.8503180437791262`, 
        1.8369701987210297`*^-17, -0.009762785560096328}, {
        1.7006360875582525`, 
        9.184850993605149*^-18, -0.019525571120192656`}}], 
       Polygon3DBox[{{1.8503180437791262`, 
        1.8369701987210297`*^-17, -0.009762785560096328}, {
        1.8503180437791262`, 3.67394039744206*^-17, -0.009762785560096332}, {
        2., 2.7554552980815454`*^-17, -7.225912875531298*^-18}, {2., 
        2.7554552980815448`*^-17, 0.}, {1.8503180437791262`, 
        1.8369701987210297`*^-17, -0.009762785560096328}}], 
       Polygon3DBox[{{2., 2.7554552980815448`*^-17, 0.}, {2., 
        2.7554552980815448`*^-17, 0.}, {2.1496819562208738`, 
        1.83697019872103*^-17, 0.009762785560096325}, {2.1496819562208738`, 
        3.6739403974420595`*^-17, 0.009762785560096325}, {2., 
        2.7554552980815448`*^-17, 0.}}], 
       Polygon3DBox[{{2.1496819562208738`, 3.6739403974420595`*^-17, 
        0.009762785560096325}, {2.1496819562208738`, 1.83697019872103*^-17, 
        0.009762785560096325}, {2.2993639124417475`, 9.184850993605152*^-18, 
        0.01952557112019265}, {2.2993639124417475`, 4.592425496802574*^-17, 
        0.019525571120192653`}, {2.1496819562208738`, 
        3.6739403974420595`*^-17, 0.009762785560096325}}], 
       Polygon3DBox[{{2.2993639124417475`, 4.592425496802574*^-17, 
        0.019525571120192653`}, {2.2993639124417475`, 9.184850993605153*^-18, 
        0.01952557112019265}, {2.4490458686626213`, 4.5887548728832574`*^-33, 
        0.029288356680288976`}, {2.4490458686626213`, 5.510910596163089*^-17, 
        0.029288356680288972`}, {2.2993639124417475`, 4.592425496802574*^-17, 
        0.019525571120192653`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7GVe2+9cIPewYoeLEtMeLI37n7W2KW658z/Q0X
/1g57WnTv8n7ndZdFn8+6y+aePN+KNcBJu4hsEIkd2XAnvsaYiU9Roxw8fcQ
9fb7AnVeSKQywcU/QMy3n1vlFLN0OjNc/BnEPRjiUHdimAN1pz26vVB3wtyN
7k4bdH9B3YkRDlB37kcPN6g7McRh4QkA2mF9Jg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.5509541313373787`, -0.45, -0.02928835668028898}, {
      1.5509541313373787`, 0.45, -0.02928835668028898}, {2.4490458686626213`, 
      0.45, 0.02928835668028898}, {2.4490458686626213`, -0.45, 
      0.02928835668028898}, {
      1.5509541313373787`, -0.45, -0.02928835668028898}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.5509541313373787`, -0.45, -0.02928835668028898}, {
       1.5509541313373787`, 0.45, -0.02928835668028898}, {2.4490458686626213`,
        0.45, 0.02928835668028898}, {2.4490458686626213`, -0.45, 
       0.02928835668028898}, {
       1.5509541313373787`, -0.45, -0.02928835668028898}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.027929422750451, 
      0.5516256719715423, -0.026084656598385412`}, {2.027929422750451, 
      0.5516256719715423, -0.026084656598385405`}, {2.0186196151669673`, 
      0.7010837813143616, -0.017389771065590268`}, {2.0186196151669673`, 
      0.7010837813143616, -0.017389771065590278`}, {2.027929422750451, 
      0.5516256719715423, -0.026084656598385412`}}], 
     Polygon3DBox[{{2.0186196151669673`, 
      0.7010837813143616, -0.017389771065590278`}, {2.0186196151669673`, 
      0.7010837813143616, -0.017389771065590268`}, {2.0093098075834837`, 
      0.8505418906571807, -0.008694885532795137}, {2.0093098075834837`, 
      0.8505418906571808, -0.008694885532795139}, {2.0186196151669673`, 
      0.7010837813143616, -0.017389771065590278`}}], 
     Polygon3DBox[{{2.0093098075834837`, 
      0.8505418906571808, -0.008694885532795139}, {2.0093098075834837`, 
      0.8505418906571807, -0.008694885532795137}, {2., 
      0.9999999999999999, -2.5828116497425712`*^-18}, {2., 1., 0.}, {
      2.0093098075834837`, 0.8505418906571808, -0.008694885532795139}}], 
     Polygon3DBox[{{2., 1., 0.}, {2., 1., 3.852696426916983*^-18}, {
      1.9906901924165163`, 1.1494581093428191`, 0.008694885532795137}, {
      1.9906901924165163`, 1.1494581093428191`, 0.008694885532795136}, {2., 
      1., 0.}}], 
     Polygon3DBox[{{1.9906901924165163`, 1.1494581093428191`, 
      0.008694885532795136}, {1.9906901924165163`, 1.1494581093428191`, 
      0.008694885532795137}, {1.9813803848330327`, 1.2989162186856384`, 
      0.01738977106559027}, {1.9813803848330327`, 1.2989162186856384`, 
      0.017389771065590275`}, {1.9906901924165163`, 1.1494581093428191`, 
      0.008694885532795136}}], 
     Polygon3DBox[{{1.9813803848330327`, 1.2989162186856384`, 
      0.017389771065590275`}, {1.9813803848330327`, 1.2989162186856384`, 
      0.01738977106559027}, {1.972070577249549, 1.4483743280284576`, 
      0.02608465659838541}, {1.972070577249549, 1.4483743280284576`, 
      0.026084656598385405`}, {1.9813803848330327`, 1.2989162186856384`, 
      0.017389771065590275`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO6qXMVvbMngsJtvxsNXyx7a/7wvuOb91ln7Y5YV
cimpMThc4hRwdM9/Zr/8FfeJ+ecm7te7bMEqKMzg8JKlY8Fi89dQ8cb9DBDg
AKE+2GfdEf6xZa3vniWRfV/v3vxv3/13t75eyif7pRD19h6bZV7v3vzfXvx3
eXzMiS/2yyDm27/hWf1gZu9/+0U/jPu7dL7bf4e4B0Mc6k4Mc6DutIfZ2wO1
F+pOexzutEH3F9SdGOEAded+WLjtgYYb1J37cYUnAJXTslI=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{1.5518595299730515`, 
        0.9739153434016146, -0.03145965375159091}, {1.5518595299730515`, 
        0.9739153434016147, -0.03145965375159091}, {1.701239686648701, 
        0.9826102289344097, -0.020973102501060603`}, {1.701239686648701, 
        0.9826102289344097, -0.02097310250106061}, {1.5518595299730515`, 
        0.9739153434016146, -0.03145965375159091}}], 
       Polygon3DBox[{{1.701239686648701, 
        0.9826102289344097, -0.02097310250106061}, {1.701239686648701, 
        0.9826102289344097, -0.020973102501060603`}, {1.8506198433243504`, 
        0.9913051144672049, -0.010486551250530307`}, {1.8506198433243504`, 
        0.9913051144672049, -0.010486551250530303`}, {1.701239686648701, 
        0.9826102289344097, -0.02097310250106061}}], 
       Polygon3DBox[{{1.8506198433243504`, 
        0.9913051144672049, -0.010486551250530303`}, {1.8506198433243504`, 
        0.9913051144672049, -0.010486551250530307`}, {1.9999999999999998`, 
        1., -6.164382537663451*^-18}, {2., 1., 1.5972245605035291`*^-18}, {
        1.8506198433243504`, 0.9913051144672049, -0.010486551250530303`}}], 
       Polygon3DBox[{{2., 1., 1.5972245605035291`*^-18}, {2., 1., 
        1.5972245605035291`*^-18}, {2.1493801566756496`, 1.008694885532795, 
        0.010486551250530302`}, {2.1493801566756496`, 1.008694885532795, 
        0.010486551250530302`}, {2., 1., 1.5972245605035291`*^-18}}], 
       Polygon3DBox[{{2.1493801566756496`, 1.008694885532795, 
        0.010486551250530302`}, {2.1493801566756496`, 1.008694885532795, 
        0.010486551250530302`}, {2.298760313351299, 1.0173897710655904`, 
        0.0209731025010606}, {2.2987603133512993`, 1.0173897710655904`, 
        0.02097310250106061}, {2.1493801566756496`, 1.008694885532795, 
        0.010486551250530302`}}], 
       Polygon3DBox[{{2.2987603133512993`, 1.0173897710655904`, 
        0.02097310250106061}, {2.298760313351299, 1.0173897710655904`, 
        0.0209731025010606}, {2.4481404700269485`, 1.0260846565983854`, 
        0.031459653751590905`}, {2.4481404700269485`, 1.0260846565983854`, 
        0.031459653751590905`}, {2.2987603133512993`, 1.0173897710655904`, 
        0.02097310250106061}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7bb41hvlAlvWD/W2Ze
aXeL3/arF+xn7C58b//pQqToz8qp+781tvUqz/lrH3rhfsPRHTDx1v0MEOAA
oT7Yy+kpPF/yNHAP634by3eGjA5XxSfYz1X+YP8eot6eq66y6E4yk8NqfYV6
K/cP9h8h5tvz2W5bfWoqs0OD+4Z917M+2G+BuAdDHOpODHOg7rRHtxfqTnsc
7rT5juYvqDsxwgHqzv3o4QZ1J4Y4LDwBuJ+moA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.5797889527235025`, 
      0.5255410153731569, -0.05754431034997633}, {1.5239301072226004`, 
      1.4222896714300721`, -0.0053749971532055}, {2.4202110472764975`, 
      1.474458984626843, 0.05754431034997633}, {2.4760698927773994`, 
      0.5777103285699278, 0.0053749971532055}, {1.5797889527235025`, 
      0.5255410153731569, -0.05754431034997633}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}, {1.5239301072226004`, 
       1.4222896714300721`, -0.0053749971532055}, {2.4202110472764975`, 
       1.474458984626843, 0.05754431034997633}, {2.4760698927773994`, 
       0.5777103285699278, 0.0053749971532055}, {1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.055371367835433, 
      1.5563683985901635`, -0.05123488903644718}, {2.055371367835433, 
      1.5563683985901635`, -0.05123488903644717}, {2.036914245223622, 
      1.7042455990601089`, -0.03415659269096477}, {2.0369142452236217`, 
      1.7042455990601089`, -0.034156592690964785`}, {2.055371367835433, 
      1.5563683985901635`, -0.05123488903644718}}], 
     Polygon3DBox[{{2.0369142452236217`, 
      1.7042455990601089`, -0.034156592690964785`}, {2.036914245223622, 
      1.7042455990601089`, -0.03415659269096477}, {2.018457122611811, 
      1.8521227995300544`, -0.017078296345482392`}, {2.018457122611811, 
      1.8521227995300544`, -0.017078296345482392`}, {2.0369142452236217`, 
      1.7042455990601089`, -0.034156592690964785`}}], 
     Polygon3DBox[{{2.018457122611811, 
      1.8521227995300544`, -0.017078296345482392`}, {2.018457122611811, 
      1.8521227995300544`, -0.017078296345482392`}, {2., 
      2., -8.010543594618399*^-18}, {2., 2., 0.}, {2.018457122611811, 
      1.8521227995300544`, -0.017078296345482392`}}], 
     Polygon3DBox[{{2., 2., 0.}, {2., 2., 4.629934954799078*^-18}, {
      1.9815428773881891`, 2.1478772004699453`, 0.017078296345482392`}, {
      1.9815428773881891`, 2.1478772004699453`, 0.01707829634548239}, {2., 2.,
       0.}}], Polygon3DBox[{{1.9815428773881891`, 2.1478772004699453`, 
      0.01707829634548239}, {1.9815428773881891`, 2.1478772004699453`, 
      0.017078296345482392`}, {1.9630857547763783`, 2.295754400939891, 
      0.03415659269096478}, {1.963085754776378, 2.295754400939891, 
      0.03415659269096478}, {1.9815428773881891`, 2.1478772004699453`, 
      0.01707829634548239}}], 
     Polygon3DBox[{{1.963085754776378, 2.295754400939891, 
      0.03415659269096478}, {1.9630857547763783`, 2.295754400939891, 
      0.03415659269096478}, {1.9446286321645672`, 2.4436316014098365`, 
      0.05123488903644717}, {1.9446286321645672`, 2.4436316014098365`, 
      0.05123488903644716}, {1.963085754776378, 2.295754400939891, 
      0.03415659269096478}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII59rt+dVsjg8KX/eM+jZz/s2Y8tm1lqvWr/5Pfy
m2Z6Mzgs4mrlmO7y2z7qpqTgz5qF+0995795RpXBIbDVqcV70V+o+MT9DBDg
AKMdshpk5qvG7skVeOCbtuW/ffjee7a39BgdIiHq7W8qHJh9JuO//fqqvdVb
Ypmg4gvt3QwXvDSS/W/PZjFnZ18PswMrxD0Y4lB3YpgDdac9ur1Qd9rjcKcN
ur+g7sQIB6g796OHG9SdGOKw8AQAUR6f7Q==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{1.5545275870096076`, 
        1.9487651109635529`, -0.03780628796827476}, {1.5545275870096076`, 
        1.9487651109635529`, -0.03780628796827475}, {1.7030183913397383`, 
        1.9658434073090352`, -0.025204191978849832`}, {1.7030183913397383`, 
        1.9658434073090352`, -0.025204191978849846`}, {1.5545275870096076`, 
        1.9487651109635529`, -0.03780628796827476}}], 
       Polygon3DBox[{{1.7030183913397383`, 
        1.9658434073090352`, -0.025204191978849846`}, {1.7030183913397383`, 
        1.9658434073090352`, -0.025204191978849832`}, {1.851509195669869, 
        1.9829217036545177`, -0.012602095989424923`}, {1.8515091956698693`, 
        1.9829217036545177`, -0.012602095989424921`}, {1.7030183913397383`, 
        1.9658434073090352`, -0.025204191978849846`}}], 
       Polygon3DBox[{{1.8515091956698693`, 
        1.9829217036545177`, -0.012602095989424921`}, {1.851509195669869, 
        1.9829217036545177`, -0.012602095989424923`}, {1.9999999999999998`, 
        2., -6.190192607506183*^-18}, {2., 2., 3.1372321431577427`*^-18}, {
        1.8515091956698693`, 1.9829217036545177`, -0.012602095989424921`}}], 
       Polygon3DBox[{{2., 2., 3.1372321431577427`*^-18}, {2., 2., 
        3.1372321431577427`*^-18}, {2.1484908043301307`, 2.0170782963454825`, 
        0.01260209598942492}, {2.1484908043301307`, 2.0170782963454825`, 
        0.012602095989424921`}, {2., 2., 3.1372321431577427`*^-18}}], 
       Polygon3DBox[{{2.1484908043301307`, 2.0170782963454825`, 
        0.012602095989424921`}, {2.1484908043301307`, 2.0170782963454825`, 
        0.01260209598942492}, {2.2969816086602615`, 2.0341565926909646`, 
        0.025204191978849835`}, {2.2969816086602615`, 2.034156592690965, 
        0.025204191978849846`}, {2.1484908043301307`, 2.0170782963454825`, 
        0.012602095989424921`}}], 
       Polygon3DBox[{{2.2969816086602615`, 2.034156592690965, 
        0.025204191978849846`}, {2.2969816086602615`, 2.0341565926909646`, 
        0.025204191978849835`}, {2.4454724129903926`, 2.051234889036447, 
        0.03780628796827476}, {2.445472412990392, 2.051234889036447, 
        0.03780628796827476}, {2.2969816086602615`, 2.034156592690965, 
        0.025204191978849846`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7b/wm50BIRvXj/7mUl
ZhPsf9ubGpabS5T8t19+THSjwvmZ++OCraRPzP9rP3vGbmmeXTDxzv0MEOAA
o7tUJ03+0Bi6J/Ba0idpA0aHzcZKn34qMTgsgai3X7Tm6BPzBCaH1HSXJ59d
GRyWQsy3/9ykcT14ArODxOy0a28zGBx+Q9xj/wVNHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAbaqJS
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.6098989548450404`, 
      1.5051335095537164`, -0.08904117700472194}, {1.4991562191741747`, 
      2.3923967123733894`, 0.013428601068172417`}, {2.39010104515496, 
      2.4948664904462836`, 0.08904117700472194}, {2.500843780825825, 
      1.6076032876266106`, -0.013428601068172417`}, {1.6098989548450404`, 
      1.5051335095537164`, -0.08904117700472194}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}, {1.4991562191741747`, 
       2.3923967123733894`, 0.013428601068172417`}, {2.39010104515496, 
       2.4948664904462836`, 0.08904117700472194}, {2.500843780825825, 
       1.6076032876266106`, -0.013428601068172417`}, {1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.0818820437217354`, 
      2.5638524455621345`, -0.07463673139829312}, {2.0818820437217354`, 
      2.5638524455621345`, -0.0746367313982931}, {2.0545880291478236`, 
      2.7092349637080897`, -0.0497578209321954}, {2.0545880291478236`, 
      2.7092349637080897`, -0.04975782093219542}, {2.0818820437217354`, 
      2.5638524455621345`, -0.07463673139829312}}], 
     Polygon3DBox[{{2.0545880291478236`, 
      2.7092349637080897`, -0.04975782093219542}, {2.0545880291478236`, 
      2.7092349637080897`, -0.0497578209321954}, {2.027294014573912, 
      2.854617481854045, -0.02487891046609771}, {2.027294014573912, 
      2.854617481854045, -0.02487891046609771}, {2.0545880291478236`, 
      2.7092349637080897`, -0.04975782093219542}}], 
     Polygon3DBox[{{2.027294014573912, 
      2.854617481854045, -0.02487891046609771}, {2.027294014573912, 
      2.854617481854045, -0.02487891046609771}, {2., 
      3., -1.2553103114586385`*^-17}, {2., 3., 0.}, {2.027294014573912, 
      2.854617481854045, -0.02487891046609771}}], 
     Polygon3DBox[{{2., 3., 0.}, {2., 3., 5.8609897034465846`*^-18}, {
      1.9727059854260882`, 3.145382518145955, 0.024878910466097703`}, {
      1.9727059854260882`, 3.145382518145955, 0.0248789104660977}, {2., 3., 
      0.}}], Polygon3DBox[{{1.9727059854260882`, 3.145382518145955, 
      0.0248789104660977}, {1.9727059854260882`, 3.145382518145955, 
      0.024878910466097703`}, {1.9454119708521764`, 3.2907650362919103`, 
      0.0497578209321954}, {1.9454119708521764`, 3.2907650362919103`, 
      0.049757820932195405`}, {1.9727059854260882`, 3.145382518145955, 
      0.0248789104660977}}], 
     Polygon3DBox[{{1.9454119708521764`, 3.2907650362919103`, 
      0.049757820932195405`}, {1.9454119708521764`, 3.2907650362919103`, 
      0.0497578209321954}, {1.9181179562782646`, 3.4361475544378655`, 
      0.0746367313982931}, {1.9181179562782646`, 3.4361475544378655`, 
      0.0746367313982931}, {1.9454119708521764`, 3.2907650362919103`, 
      0.049757820932195405`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4ccP/oxuUMDkxrtIWONrE4cM/Ln5AivXm/U7f9
zdP5DA5riooSm9ewOqTW2mffrly5f+HR+W+emjM4hFnu3OB4jQ0qPnM/AwQ4
QCgOh8u2XC0PrVL37Cs5oGYy4b/9qmNu/vs0OR2SIOrta142+GYo/LcP6e2d
VxPM5ZAMMd/eKs6xZM6Gf/b/gq+8tarlduCCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAsX5ka
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{1.5588209983435757`, 
        2.925363268601707, -0.04785861284679986}, {1.5588209983435757`, 
        2.925363268601707, -0.047858612846799854`}, {1.705880665562384, 
        2.950242179067805, -0.03190574189786657}, {1.7058806655623837`, 
        2.9502421790678044`, -0.03190574189786658}, {1.5588209983435757`, 
        2.925363268601707, -0.04785861284679986}}], 
       Polygon3DBox[{{1.7058806655623837`, 
        2.9502421790678044`, -0.03190574189786658}, {1.705880665562384, 
        2.950242179067805, -0.03190574189786657}, {1.8529403327811917`, 
        2.975121089533902, -0.015952870948933287`}, {1.852940332781192, 
        2.975121089533902, -0.015952870948933287`}, {1.7058806655623837`, 
        2.9502421790678044`, -0.03190574189786658}}], 
       Polygon3DBox[{{1.852940332781192, 
        2.975121089533902, -0.015952870948933287`}, {1.8529403327811917`, 
        2.975121089533902, -0.015952870948933287`}, {1.9999999999999998`, 
        3., -7.237314713965981*^-18}, {2., 3., 4.570181710287021*^-18}, {
        1.852940332781192, 2.975121089533902, -0.015952870948933287`}}], 
       Polygon3DBox[{{2., 3., 4.570181710287021*^-18}, {2., 3., 
        4.570181710287021*^-18}, {2.1470596672188083`, 3.024878910466098, 
        0.015952870948933287`}, {2.1470596672188083`, 3.024878910466098, 
        0.01595287094893329}, {2., 3., 4.570181710287021*^-18}}], 
       Polygon3DBox[{{2.1470596672188083`, 3.024878910466098, 
        0.01595287094893329}, {2.1470596672188083`, 3.024878910466098, 
        0.015952870948933287`}, {2.294119334437616, 3.0497578209321956`, 
        0.03190574189786657}, {2.294119334437616, 3.0497578209321956`, 
        0.03190574189786658}, {2.1470596672188083`, 3.024878910466098, 
        0.01595287094893329}}], 
       Polygon3DBox[{{2.294119334437616, 3.0497578209321956`, 
        0.03190574189786658}, {2.294119334437616, 3.0497578209321956`, 
        0.03190574189786657}, {2.4411790016564243`, 3.074636731398293, 
        0.047858612846799854`}, {2.4411790016564243`, 3.074636731398293, 
        0.047858612846799854`}, {2.294119334437616, 3.0497578209321956`, 
        0.03190574189786658}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdHaHaZNYJr1pWLF/aWN4
m6f3b3supuBJErPYHVJ5mHk+hy7Yf/mA9uElS//aszZqevKchYlP2M8AAQ4Q
isPhT2ZU5ivL6D3T5bPm6eoyOvyuu7btsxGHQzJEvb2u/RWb6Cgmh29/1+Q+
T+VwSIGYb38kzu52Rzuzw4eaZpXbMzgcpkDcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+rO/cvQwgHqzv3o4QZ1J4Y4LDwBu36R/w==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.640703042065311, 
      2.489215714163841, -0.12249534424509298`}, {1.4769389546218403`, 
      3.3615108230395725`, 0.026778118551493257`}, {2.359296957934689, 
      3.510784285836159, 0.12249534424509298`}, {2.5230610453781597`, 
      2.6384891769604275`, -0.026778118551493257`}, {1.640703042065311, 
      2.489215714163841, -0.12249534424509298`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}, {1.4769389546218403`, 
       3.3615108230395725`, 0.026778118551493257`}, {2.359296957934689, 
       3.510784285836159, 0.12249534424509298`}, {2.5230610453781597`, 
       2.6384891769604275`, -0.026778118551493257`}, {1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.107096261672285, 
      3.5735323502200993`, -0.09568560198394237}, {2.107096261672285, 
      3.5735323502200993`, -0.09568560198394235}, {2.0713975077815237`, 
      3.715688233480066, -0.06379040132262823}, {2.071397507781523, 
      3.715688233480066, -0.06379040132262825}, {2.107096261672285, 
      3.5735323502200993`, -0.09568560198394237}}], 
     Polygon3DBox[{{2.071397507781523, 
      3.715688233480066, -0.06379040132262825}, {2.0713975077815237`, 
      3.715688233480066, -0.06379040132262823}, {2.035698753890762, 
      3.8578441167400332`, -0.03189520066131413}, {2.035698753890762, 
      3.8578441167400332`, -0.03189520066131413}, {2.071397507781523, 
      3.715688233480066, -0.06379040132262825}}], 
     Polygon3DBox[{{2.035698753890762, 
      3.8578441167400332`, -0.03189520066131413}, {2.035698753890762, 
      3.8578441167400332`, -0.03189520066131413}, {2., 
      4., -1.614543305080215*^-17}, {2., 4., 0.}, {2.035698753890762, 
      3.8578441167400332`, -0.03189520066131413}}], 
     Polygon3DBox[{{2., 4., 0.}, {2., 4., 7.461757715351485*^-18}, {
      1.9643012461092384`, 4.142155883259967, 0.03189520066131412}, {
      1.9643012461092384`, 4.142155883259967, 0.03189520066131411}, {2., 4., 
      0.}}], Polygon3DBox[{{1.9643012461092384`, 4.142155883259967, 
      0.03189520066131411}, {1.9643012461092384`, 4.142155883259967, 
      0.03189520066131412}, {1.9286024922184768`, 4.2843117665199335`, 
      0.06379040132262823}, {1.9286024922184766`, 4.2843117665199335`, 
      0.06379040132262824}, {1.9643012461092384`, 4.142155883259967, 
      0.03189520066131411}}], 
     Polygon3DBox[{{1.9286024922184766`, 4.2843117665199335`, 
      0.06379040132262824}, {1.9286024922184768`, 4.2843117665199335`, 
      0.06379040132262823}, {1.892903738327715, 4.426467649779901, 
      0.09568560198394235}, {1.892903738327715, 4.426467649779901, 
      0.09568560198394234}, {1.9286024922184766`, 4.2843117665199335`, 
      0.06379040132262824}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFZzeO0RepvBYZLqb4UZ03gc3MUtmG/V7dgv2eB+
22ISg0Ni3vIDu3byOhjsqgqfGLJhP++BxbkyngwOhtuDE+7e4YOKL9jPAAEO
EErA4ecDxedzzLP3PK/foXI89799hso1/4kTBRz0IOrtz/4v8Oy7/c/+vMea
+UrKgg76EPPtt9Rr5oV6/rM3z216v3mLoIMrxD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g796OHG9SdGOKw8AQADzaV3w==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{1.5645326466546545`, 
        3.9043143980160577`, -0.06092987562247867}, {1.5645326466546545`, 
        3.9043143980160577`, -0.06092987562247865}, {1.709688431103103, 
        3.936209598677372, -0.04061991708165243}, {1.709688431103103, 
        3.936209598677372, -0.04061991708165245}, {1.5645326466546545`, 
        3.9043143980160577`, -0.06092987562247867}}], 
       Polygon3DBox[{{1.709688431103103, 
        3.936209598677372, -0.04061991708165245}, {1.709688431103103, 
        3.936209598677372, -0.04061991708165243}, {1.8548442155515514`, 
        3.9681047993386858`, -0.020309958540826224`}, {1.8548442155515514`, 
        3.9681047993386858`, -0.02030995854082622}, {1.709688431103103, 
        3.936209598677372, -0.04061991708165245}}], 
       Polygon3DBox[{{1.8548442155515514`, 
        3.9681047993386858`, -0.02030995854082622}, {1.8548442155515514`, 
        3.9681047993386858`, -0.020309958540826224`}, {1.9999999999999998`, 
        4., -9.173335757765612*^-18}, {2., 4., 5.8590533097061324`*^-18}, {
        1.8548442155515514`, 3.9681047993386858`, -0.02030995854082622}}], 
       Polygon3DBox[{{2., 4., 5.8590533097061324`*^-18}, {2., 4., 
        5.8590533097061324`*^-18}, {2.1451557844484483`, 4.031895200661314, 
        0.02030995854082622}, {2.1451557844484483`, 4.031895200661314, 
        0.020309958540826224`}, {2., 4., 5.8590533097061324`*^-18}}], 
       Polygon3DBox[{{2.1451557844484483`, 4.031895200661314, 
        0.020309958540826224`}, {2.1451557844484483`, 4.031895200661314, 
        0.02030995854082622}, {2.2903115688968967`, 4.0637904013226285`, 
        0.04061991708165243}, {2.2903115688968967`, 4.0637904013226285`, 
        0.04061991708165245}, {2.1451557844484483`, 4.031895200661314, 
        0.020309958540826224`}}], 
       Polygon3DBox[{{2.2903115688968967`, 4.0637904013226285`, 
        0.04061991708165245}, {2.2903115688968967`, 4.0637904013226285`, 
        0.04061991708165243}, {2.4354673533453455`, 4.095685601983942, 
        0.06092987562247866}, {2.4354673533453455`, 4.095685601983942, 
        0.06092987562247867}, {2.2903115688968967`, 4.0637904013226285`, 
        0.04061991708165245}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Tht9h8w7vOGOj9fvr/89z
fBT1215Py6U0upbf4azqXTulM0v2768/r1C49q+9uOiiXWv3wcSn7GeAAAcI
JeBw9UuSyfGQxD0KDjPy3TUZHUq+rlNaqSDgcBqi3t6hweB+XxCTw8tXsa5B
jgIOZyDm2yceOOF3rZrZIfYBT8bvRAGHjRD3YIhD3WnviGYO1J326PZC3WmP
w502B9D8BXUnPBz0oeEAded+e7Rwg7pzP67wBAB3v5IB
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.6716289083269396`, 
      3.477846748236157, -0.15661547760642103`}, {1.4574363849823695`, 
      4.330782047795958, 0.0347557263614637}, {2.3283710916730604`, 
      4.522153251763843, 0.15661547760642103`}, {2.5425636150176305`, 
      3.6692179522040416`, -0.0347557263614637}, {1.6716289083269396`, 
      3.477846748236157, -0.15661547760642103`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.6716289083269396`, 
       3.477846748236157, -0.15661547760642103`}, {1.4574363849823695`, 
       4.330782047795958, 0.0347557263614637}, {2.3283710916730604`, 
       4.522153251763843, 0.15661547760642103`}, {2.5425636150176305`, 
       3.6692179522040416`, -0.0347557263614637}, {1.6716289083269396`, 
       3.477846748236157, -0.15661547760642103`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.130747825118258, 
      4.584785385294185, -0.11402556713977308`}, {2.1307478251182586`, 
      4.584785385294185, -0.11402556713977306`}, {2.0871652167455057`, 
      4.72319025686279, -0.07601704475984869}, {2.0871652167455057`, 
      4.7231902568627895`, -0.07601704475984872}, {2.130747825118258, 
      4.584785385294185, -0.11402556713977308`}}], 
     Polygon3DBox[{{2.0871652167455057`, 
      4.7231902568627895`, -0.07601704475984872}, {2.0871652167455057`, 
      4.72319025686279, -0.07601704475984869}, {2.043582608372753, 
      4.861595128431395, -0.03800852237992436}, {2.043582608372753, 
      4.861595128431395, -0.03800852237992436}, {2.0871652167455057`, 
      4.7231902568627895`, -0.07601704475984872}}], 
     Polygon3DBox[{{2.043582608372753, 
      4.861595128431395, -0.03800852237992436}, {2.043582608372753, 
      4.861595128431395, -0.03800852237992436}, {2., 
      5., -1.8796814971865053`*^-17}, {2., 5., 0.}, {2.043582608372753, 
      4.861595128431395, -0.03800852237992436}}], 
     Polygon3DBox[{{2., 5., 0.}, {2., 5., 9.335142813583325*^-18}, {
      1.9564173916272474`, 5.138404871568605, 0.03800852237992435}, {
      1.9564173916272474`, 5.138404871568605, 0.038008522379924345`}, {2., 5.,
       0.}}], Polygon3DBox[{{1.9564173916272474`, 5.138404871568605, 
      0.038008522379924345`}, {1.9564173916272474`, 5.138404871568605, 
      0.03800852237992435}, {1.9128347832544945`, 5.27680974313721, 
      0.07601704475984869}, {1.9128347832544945`, 5.27680974313721, 
      0.0760170447598487}, {1.9564173916272474`, 5.138404871568605, 
      0.038008522379924345`}}], 
     Polygon3DBox[{{1.9128347832544945`, 5.27680974313721, 
      0.0760170447598487}, {1.9128347832544945`, 5.27680974313721, 
      0.07601704475984869}, {1.869252174881742, 5.415214614705815, 
      0.11402556713977306`}, {1.869252174881742, 5.415214614705815, 
      0.11402556713977305`}, {1.9128347832544945`, 5.27680974313721, 
      0.0760170447598487}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ5qz95ylJvRYbPgk18Xw4Qcfrw7OvG4wd79KVpR
a5s3MTic4Z7xp/uJkEPAfL3EW6Wb9xuJrr3mGMng8IzV559rkTBUfPF+Bghw
gFAiDrn6fwK6zQv2zL26NKjG97+91K/NjLt6RRz8IOrtLVd7L/0x65+98Zd0
5hJpUQd/iPn21xo+fi958dfe9500q95KUYdvEPdgiEPdCTfHBGoO1J32c9Ds
hbrTHoc7bdD9BXXn/mRoOJyFhgPUnfvRww3qTgxxWHgCAOlOoY4=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{1.5714121092718345`, 
        4.885974432860227, -0.07622722584244547}, {1.5714121092718345`, 
        4.885974432860227, -0.07622722584244546}, {1.7142747395145563`, 
        4.9239829552401515`, -0.0508181505616303}, {1.7142747395145563`, 
        4.9239829552401515`, -0.050818150561630325`}, {1.5714121092718345`, 
        4.885974432860227, -0.07622722584244547}}], 
       Polygon3DBox[{{1.7142747395145563`, 
        4.9239829552401515`, -0.050818150561630325`}, {1.7142747395145563`, 
        4.9239829552401515`, -0.0508181505616303}, {1.8571373697572782`, 
        4.961991477620075, -0.02540907528081516}, {1.8571373697572782`, 
        4.961991477620075, -0.02540907528081516}, {1.7142747395145563`, 
        4.9239829552401515`, -0.050818150561630325`}}], 
       Polygon3DBox[{{1.8571373697572782`, 
        4.961991477620075, -0.02540907528081516}, {1.8571373697572782`, 
        4.961991477620075, -0.02540907528081516}, {1.9999999999999998`, 
        5., -1.1824441316529032`*^-17}, {2., 5., 6.982052290934236*^-18}, {
        1.8571373697572782`, 4.961991477620075, -0.02540907528081516}}], 
       Polygon3DBox[{{2., 5., 6.982052290934236*^-18}, {2., 5., 
        6.982052290934236*^-18}, {2.1428626302427216`, 5.038008522379925, 
        0.025409075280815156`}, {2.1428626302427216`, 5.038008522379925, 
        0.025409075280815163`}, {2., 5., 6.982052290934236*^-18}}], 
       Polygon3DBox[{{2.1428626302427216`, 5.038008522379925, 
        0.025409075280815163`}, {2.1428626302427216`, 5.038008522379925, 
        0.025409075280815156`}, {2.2857252604854437`, 5.0760170447598485`, 
        0.050818150561630304`}, {2.2857252604854437`, 5.0760170447598485`, 
        0.050818150561630325`}, {2.1428626302427216`, 5.038008522379925, 
        0.025409075280815163`}}], 
       Polygon3DBox[{{2.2857252604854437`, 5.0760170447598485`, 
        0.050818150561630325`}, {2.2857252604854437`, 5.0760170447598485`, 
        0.050818150561630304`}, {2.4285878907281653`, 5.114025567139773, 
        0.07622722584244547}, {2.4285878907281653`, 5.114025567139773, 
        0.07622722584244547}, {2.2857252604854437`, 5.0760170447598485`, 
        0.050818150561630325`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIOjg/4Fi1o3rz/ll5m
5Orc3/bNrtXTNDYJOzBrZ+peY1m1P3f6ljVXt/21P7jI1lvkJkx81n4GCHCA
UCIOOj91qjetS93juWWp5lQVRgf72ENbXquJODBA1NtPzvAO1vJkcqjd1ZJ5
3VfEgRFivv0dmY81+3OZHfaIu8sdLhFxcIC4B0Mc6k4Mc6DutPdCsxfqTnsc
7rRB9xfUnRjhAHXnfg+0cIO6cz+u8AQA8TmPGg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{1.7021599343900928`, 
      4.470759818154412, -0.19025279298221853`}, {1.4406642841535762`, 
      5.301189047566042, 0.037798341297327606`}, {2.297840065609907, 
      5.529240181845588, 0.19025279298221853`}, {2.559335715846424, 
      4.698810952433958, -0.037798341297327606`}, {1.7021599343900928`, 
      4.470759818154412, -0.19025279298221853`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}, {1.4406642841535762`, 
       5.301189047566042, 0.037798341297327606`}, {2.297840065609907, 
       5.529240181845588, 0.19025279298221853`}, {2.559335715846424, 
       4.698810952433958, -0.037798341297327606`}, {1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.8677794592568007`, -5.415560304174549, 
      0.11102865485960163`}, {2.8677794592568007`, -5.415560304174549, 
      0.11102865485960166`}, {2.9118529728378673`, -5.2770402027830325`, 
      0.07401910323973443}, {2.9118529728378673`, -5.2770402027830325`, 
      0.07401910323973443}, {2.8677794592568007`, -5.415560304174549, 
      0.11102865485960163`}}], 
     Polygon3DBox[{{2.9118529728378673`, -5.2770402027830325`, 
      0.07401910323973443}, {2.9118529728378673`, -5.2770402027830325`, 
      0.07401910323973443}, {2.9559264864189334`, -5.138520101391516, 
      0.03700955161986724}, {2.9559264864189334`, -5.138520101391516, 
      0.037009551619867215`}, {2.9118529728378673`, -5.2770402027830325`, 
      0.07401910323973443}}], 
     Polygon3DBox[{{2.9559264864189334`, -5.138520101391516, 
      0.037009551619867215`}, {2.9559264864189334`, -5.138520101391516, 
      0.03700955161986724}, {3., -5., 3.866660718210214*^-17}, {3., -5., 
      0.}, {2.9559264864189334`, -5.138520101391516, 0.037009551619867215`}}],
      Polygon3DBox[{{3., -5., 0.}, {3., -5., 1.1274036289148914`*^-17}, {
      3.0440735135810666`, -4.861479898608484, -0.037009551619867194`}, {
      3.0440735135810666`, -4.861479898608484, -0.0370095516198672}, {3., -5.,
       0.}}], Polygon3DBox[{{
      3.0440735135810666`, -4.861479898608484, -0.0370095516198672}, {
      3.0440735135810666`, -4.861479898608484, -0.037009551619867194`}, {
      3.0881470271621327`, -4.7229597972169675`, -0.0740191032397344}, {
      3.0881470271621327`, -4.7229597972169675`, -0.07401910323973442}, {
      3.0440735135810666`, -4.861479898608484, -0.0370095516198672}}], 
     Polygon3DBox[{{
      3.0881470271621327`, -4.7229597972169675`, -0.07401910323973442}, {
      3.0881470271621327`, -4.7229597972169675`, -0.0740191032397344}, {
      3.1322205407431993`, -4.584439695825451, -0.11102865485960162`}, {
      3.1322205407431993`, -4.584439695825451, -0.1110286548596016}, {
      3.0881470271621327`, -4.7229597972169675`, -0.07401910323973442}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINY1yI02+8jmYHji/eKOlaIHrpZ27YzP2WN/8pTH
pEpvdoeyVq/cDdKiB54s3lj96tMm+5RUlZN7lrI77HZaanajVwQqvsieAQw4
HCC0yIHqtFrlO1PybebMum3mHMXh4Lo36qR6kfCBRxD1+81Nt+e2beFw6Kra
Osn/idCBxxDz918+P2nJST5Oh/PmAjHlYUIHLkPcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AZRarC4=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        2.573739882665349, -4.888971345140399, -0.09205949255735071}, {
        2.573739882665349, -4.888971345140399, -0.09205949255735073}, {
        2.7158265884435657`, -4.925980896760265, -0.06137299503823382}, {
        2.7158265884435657`, -4.925980896760265, -0.06137299503823382}, {
        2.573739882665349, -4.888971345140399, -0.09205949255735071}}], 
       Polygon3DBox[{{
        2.7158265884435657`, -4.925980896760265, -0.06137299503823382}, {
        2.7158265884435657`, -4.925980896760265, -0.06137299503823382}, {
        2.857913294221783, -4.962990448380133, -0.03068649751911693}, {
        2.857913294221783, -4.962990448380133, -0.030686497519116913`}, {
        2.7158265884435657`, -4.925980896760265, -0.06137299503823382}}], 
       Polygon3DBox[{{
        2.857913294221783, -4.962990448380133, -0.030686497519116913`}, {
        2.857913294221783, -4.962990448380133, -0.03068649751911693}, {
        3., -5., -2.9511115066589925`*^-17}, {
        3., -5., -6.7985443393723685`*^-18}, {
        2.857913294221783, -4.962990448380133, -0.030686497519116913`}}], 
       Polygon3DBox[{{3., -5., -6.7985443393723685`*^-18}, {
        3., -5., -6.7985443393723685`*^-18}, {
        3.142086705778217, -5.037009551619867, 0.030686497519116892`}, {
        3.142086705778217, -5.037009551619867, 0.030686497519116885`}, {
        3., -5., -6.7985443393723685`*^-18}}], 
       Polygon3DBox[{{3.142086705778217, -5.037009551619867, 
        0.030686497519116885`}, {3.142086705778217, -5.037009551619867, 
        0.030686497519116892`}, {3.284173411556434, -5.074019103239735, 
        0.06137299503823379}, {3.2841734115564343`, -5.074019103239735, 
        0.06137299503823379}, {3.142086705778217, -5.037009551619867, 
        0.030686497519116885`}}], 
       Polygon3DBox[{{3.2841734115564343`, -5.074019103239735, 
        0.06137299503823379}, {3.284173411556434, -5.074019103239735, 
        0.06137299503823379}, {3.426260117334651, -5.111028654859601, 
        0.0920594925573507}, {3.426260117334651, -5.111028654859601, 
        0.09205949255735067}, {3.2841734115564343`, -5.074019103239735, 
        0.06137299503823379}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PuEDUt8v/jWduH1/xvFw
L+ZdrA4FloJhJluED6h8Ef/rnrN+/5bH2ksZ77I57JjDoS11CyY+fz8DGHA4
QGiRA0XeL4Mm6mft8ZG5EvVPidPBI/n7laeqIgcUIOrtZ1is2PrHlcthwrF3
K097ixxQgphv/zikRuB3BrfDdc1ndRsLRQ5IQNyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AfzSfOg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.4415193419221497`, -5.3045316493149475`, 
      0.018969162302250916`}, {
      2.7059604234085484`, -4.47341104096585, -0.20308814741695236`}, {
      3.5584806580778503`, -4.6954683506850525`, -0.018969162302250916`}, {
      3.2940395765914516`, -5.52658895903415, 0.20308814741695236`}, {
      2.4415193419221497`, -5.3045316493149475`, 0.018969162302250916`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.4415193419221497`, -5.3045316493149475`, 
       0.018969162302250916`}, {
       2.7059604234085484`, -4.47341104096585, -0.20308814741695236`}, {
       3.5584806580778503`, -4.6954683506850525`, -0.018969162302250916`}, {
       3.2940395765914516`, -5.52658895903415, 0.20308814741695236`}, {
       2.4415193419221497`, -5.3045316493149475`, 0.018969162302250916`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.891557308146282, -4.426653187402996, 
      0.09331259433958147}, {2.891557308146282, -4.426653187402996, 
      0.09331259433958149}, {2.9277048720975216`, -4.284435458268664, 
      0.06220839622638766}, {2.927704872097521, -4.284435458268664, 
      0.06220839622638766}, {2.891557308146282, -4.426653187402996, 
      0.09331259433958147}}], 
     Polygon3DBox[{{2.927704872097521, -4.284435458268664, 
      0.06220839622638766}, {2.9277048720975216`, -4.284435458268664, 
      0.06220839622638766}, {2.963852436048761, -4.142217729134332, 
      0.031104198113193853`}, {2.963852436048761, -4.142217729134332, 
      0.03110419811319383}, {2.927704872097521, -4.284435458268664, 
      0.06220839622638766}}], 
     Polygon3DBox[{{2.963852436048761, -4.142217729134332, 
      0.03110419811319383}, {2.963852436048761, -4.142217729134332, 
      0.031104198113193853`}, {3., -4., 3.245739092285295*^-17}, {3., -4., 
      0.}, {2.963852436048761, -4.142217729134332, 0.03110419811319383}}], 
     Polygon3DBox[{{3., -4., 0.}, {3., -4., 9.435659651006192*^-18}, {
      3.036147563951239, -3.857782270865668, -0.031104198113193808`}, {
      3.036147563951239, -3.857782270865668, -0.031104198113193815`}, {
      3., -4., 0.}}], 
     Polygon3DBox[{{
      3.036147563951239, -3.857782270865668, -0.031104198113193815`}, {
      3.036147563951239, -3.857782270865668, -0.031104198113193808`}, {
      3.072295127902479, -3.715564541731336, -0.06220839622638763}, {
      3.072295127902479, -3.715564541731336, -0.062208396226387644`}, {
      3.036147563951239, -3.857782270865668, -0.031104198113193815`}}], 
     Polygon3DBox[{{
      3.072295127902479, -3.715564541731336, -0.062208396226387644`}, {
      3.072295127902479, -3.715564541731336, -0.06220839622638763}, {
      3.108442691853718, -3.573346812597004, -0.09331259433958146}, {
      3.108442691853718, -3.573346812597004, -0.09331259433958145}, {
      3.072295127902479, -3.715564541731336, -0.062208396226387644`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmEP3H/cwLRXYHtdZdk55sETwwLeBfT+jj7fbxf/U7
PmSzOxyJqOFxVhY8UJK9Iu34zfX2G/6Ju/zYyu6QpGPXtnCiAFR8vj0DGHA4
QGiBA12RPVcvdGXZBDC+2M3uxeFgs7z58547fAcKIOr3L2S6UM4/hcOhwo/9
eeVO3gNFEPP3f2TeYSx+j8Nhy9euW2bTeA5MgbgHQxzqTgxzoO7cj24v1J37
cbhzD7q/oO7ECAeoO+3Rww3qTgxxWHgCAI3cqOo=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        2.5665759995290798`, -3.9066874056604184`, -0.07704800810793501}, {
        2.5665759995290798`, -3.9066874056604184`, -0.07704800810793502}, {
        2.71105066635272, -3.9377916037736123`, -0.051365338738623346`}, {
        2.71105066635272, -3.9377916037736123`, -0.051365338738623346`}, {
        2.5665759995290798`, -3.9066874056604184`, -0.07704800810793501}}], 
       Polygon3DBox[{{
        2.71105066635272, -3.9377916037736123`, -0.051365338738623346`}, {
        2.71105066635272, -3.9377916037736123`, -0.051365338738623346`}, {
        2.85552533317636, -3.968895801886806, -0.02568266936931169}, {
        2.85552533317636, -3.968895801886806, -0.025682669369311677`}, {
        2.71105066635272, -3.9377916037736123`, -0.051365338738623346`}}], 
       Polygon3DBox[{{
        2.85552533317636, -3.968895801886806, -0.025682669369311677`}, {
        2.85552533317636, -3.968895801886806, -0.02568266936931169}, {
        3., -4., -2.4722742410668572`*^-17}, {
        3., -4., -5.713748498905194*^-18}, {
        2.85552533317636, -3.968895801886806, -0.025682669369311677`}}], 
       Polygon3DBox[{{3., -4., -5.713748498905194*^-18}, {
        3., -4., -5.713748498905194*^-18}, {
        3.14447466682364, -4.031104198113193, 0.02568266936931166}, {
        3.14447466682364, -4.031104198113193, 0.025682669369311656`}, {
        3., -4., -5.713748498905194*^-18}}], 
       Polygon3DBox[{{3.14447466682364, -4.031104198113193, 
        0.025682669369311656`}, {3.14447466682364, -4.031104198113193, 
        0.02568266936931166}, {3.28894933364728, -4.062208396226388, 
        0.051365338738623326`}, {3.28894933364728, -4.062208396226388, 
        0.05136533873862333}, {3.14447466682364, -4.031104198113193, 
        0.025682669369311656`}}], 
       Polygon3DBox[{{3.28894933364728, -4.062208396226388, 
        0.05136533873862333}, {3.28894933364728, -4.062208396226388, 
        0.051365338738623326`}, {3.4334240004709202`, -4.093312594339581, 
        0.077048008107935}, {3.4334240004709202`, -4.093312594339581, 
        0.07704800810793498}, {3.28894933364728, -4.062208396226388, 
        0.05136533873862333}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA/+BwuXcwtk7N+9vcn0X
Yr2B1SEoLvXRjAb+A287+Y/0+azaf1CpfJXsDTYHzfVGhT4HYOKz9jOAAYcD
hBY4MGvu9h9lr1L32N/tCH2kzumQvSLt+E15gQOvIOrt63YJrj7iz+VwPeBs
32Z7gQNvIObb750+i2F5ObeD00/jsN54gQMFEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMAmrqc8g==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.4581333076753618`, -4.333340593063415, 
      0.016264586231646463`}, {
      2.675018691382798, -3.480034218257422, -0.1703606024475165}, {
      3.5418666923246382`, -3.666659406936585, -0.016264586231646463`}, {
      3.324981308617202, -4.519965781742577, 0.1703606024475165}, {
      2.4581333076753618`, -4.333340593063415, 0.016264586231646463`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.4581333076753618`, -4.333340593063415, 
       0.016264586231646463`}, {
       2.675018691382798, -3.480034218257422, -0.1703606024475165}, {
       3.5418666923246382`, -3.666659406936585, -0.016264586231646463`}, {
       3.324981308617202, -4.519965781742577, 0.1703606024475165}, {
       2.4581333076753618`, -4.333340593063415, 0.016264586231646463`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.916995547693319, -3.4362314620775116`, 
      0.07288602328968406}, {2.916995547693319, -3.4362314620775116`, 
      0.07288602328968408}, {2.9446636984622128`, -3.2908209747183412`, 
      0.04859068219312272}, {2.9446636984622128`, -3.2908209747183412`, 
      0.048590682193122715`}, {2.916995547693319, -3.4362314620775116`, 
      0.07288602328968406}}], 
     Polygon3DBox[{{2.9446636984622128`, -3.2908209747183412`, 
      0.048590682193122715`}, {2.9446636984622128`, -3.2908209747183412`, 
      0.04859068219312272}, {2.9723318492311064`, -3.145410487359171, 
      0.02429534109656138}, {2.9723318492311064`, -3.145410487359171, 
      0.024295341096561358`}, {2.9446636984622128`, -3.2908209747183412`, 
      0.048590682193122715`}}], 
     Polygon3DBox[{{2.9723318492311064`, -3.145410487359171, 
      0.024295341096561358`}, {2.9723318492311064`, -3.145410487359171, 
      0.02429534109656138}, {3., -3., 2.5840212643065484`*^-17}, {3., -3., 
      0.}, {2.9723318492311064`, -3.145410487359171, 0.024295341096561358`}}],
      Polygon3DBox[{{3., -3., 0.}, {3., -3., 7.858047925382672*^-18}, {
      3.0276681507688936`, -2.8545895126408296`, -0.024295341096561344`}, {
      3.0276681507688936`, -2.8545895126408296`, -0.02429534109656135}, {
      3., -3., 0.}}], 
     Polygon3DBox[{{
      3.0276681507688936`, -2.8545895126408296`, -0.02429534109656135}, {
      3.0276681507688936`, -2.8545895126408296`, -0.024295341096561344`}, {
      3.0553363015377872`, -2.7091790252816588`, -0.0485906821931227}, {
      3.0553363015377872`, -2.7091790252816588`, -0.04859068219312271}, {
      3.0276681507688936`, -2.8545895126408296`, -0.02429534109656135}}], 
     Polygon3DBox[{{
      3.0553363015377872`, -2.7091790252816588`, -0.04859068219312271}, {
      3.0553363015377872`, -2.7091790252816588`, -0.0485906821931227}, {
      3.083004452306681, -2.5637685379224884`, -0.07288602328968406}, {
      3.083004452306681, -2.5637685379224884`, -0.07288602328968405}, {
      3.0553363015377872`, -2.7091790252816588`, -0.04859068219312271}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGaK/X+IMYzdYcb9Ha/TarkPqMfE9q1Yscl+zYuQ
66v72B1221d/mhnMdcD0wsW9Dx6ssA8rWfU69Di7w735tj/PaHJCxWfYM4AB
hwOUPtCo2/I5dXeKzaruUJFVFhwOygmH2IyvsR0whqjfHyK+WiOkkMPB9UAL
b9oa1gMmEPP3/1vEYPtvJYdDhoK7yMwmlgNqEPdgiEPdiWEO1J37YfYqQe2F
unM/DnfugfnrLtRfUHdihAPUnfbo4QZ1J4Y4LDwBAQenGQ==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        2.5606022601651173`, -2.927113976710316, -0.06416583075915237}, {
        2.5606022601651173`, -2.927113976710316, -0.06416583075915239}, {
        2.707068173443411, -2.951409317806877, -0.04277722050610158}, {
        2.707068173443411, -2.951409317806877, -0.04277722050610158}, {
        2.5606022601651173`, -2.927113976710316, -0.06416583075915237}}], 
       Polygon3DBox[{{
        2.707068173443411, -2.951409317806877, -0.04277722050610158}, {
        2.707068173443411, -2.951409317806877, -0.04277722050610158}, {
        2.8535340867217056`, -2.9757046589034384`, -0.021388610253050805`}, {
        2.8535340867217056`, -2.975704658903439, -0.021388610253050794`}, {
        2.707068173443411, -2.951409317806877, -0.04277722050610158}}], 
       Polygon3DBox[{{
        2.8535340867217056`, -2.975704658903439, -0.021388610253050794`}, {
        2.8535340867217056`, -2.9757046589034384`, -0.021388610253050805`}, {
        3., -3., -2.0293733467995007`*^-17}, {
        3., -3., -4.4629817562145516`*^-18}, {
        2.8535340867217056`, -2.975704658903439, -0.021388610253050794`}}], 
       Polygon3DBox[{{3., -3., -4.4629817562145516`*^-18}, {
        3., -3., -4.4629817562145516`*^-18}, {
        3.1464659132782944`, -3.024295341096561, 0.02138861025305078}, {
        3.1464659132782944`, -3.024295341096561, 0.021388610253050777`}, {
        3., -3., -4.4629817562145516`*^-18}}], 
       Polygon3DBox[{{3.1464659132782944`, -3.024295341096561, 
        0.021388610253050777`}, {3.1464659132782944`, -3.024295341096561, 
        0.02138861025305078}, {3.292931826556589, -3.048590682193123, 
        0.04277722050610157}, {3.292931826556589, -3.048590682193123, 
        0.04277722050610157}, {3.1464659132782944`, -3.024295341096561, 
        0.021388610253050777`}}], 
       Polygon3DBox[{{3.292931826556589, -3.048590682193123, 
        0.04277722050610157}, {3.292931826556589, -3.048590682193123, 
        0.04277722050610157}, {3.4393977398348827`, -3.072886023289684, 
        0.06416583075915236}, {3.4393977398348827`, -3.072886023289684, 
        0.06416583075915233}, {3.292931826556589, -3.048590682193123, 
        0.04277722050610157}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLPYD/jMWMujkbtj/6dbx
aOEVrA77d3DU1sxhPyByWifs6bOl+yvfPl7LeYXNISGmxc7uHEx86n4GMOBw
gNIHJvw7fzzTIWlPu5BM0DdtTocFi6sPHjTkOCAEUW/Pp2qx5E04l4Oj+/em
5mSOA8IQ8+2nmId8e9TM7fDwVZGL61SOA74Q92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6EyMcoO7cjx5uUHdiiMPCEwCAj5re
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.477597807858436, -3.3633454387878277`, 
      0.00872019253053169}, {
      2.643606712471798, -2.490882514632804, -0.13705185404883644`}, {
      3.522402192141564, -2.6366545612121723`, -0.00872019253053169}, {
      3.356393287528202, -3.509117485367196, 0.13705185404883644`}, {
      2.477597807858436, -3.3633454387878277`, 0.00872019253053169}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.477597807858436, -3.3633454387878277`, 
       0.00872019253053169}, {
       2.643606712471798, -2.490882514632804, -0.13705185404883644`}, {
       3.522402192141564, -2.6366545612121723`, -0.00872019253053169}, {
       3.356393287528202, -3.509117485367196, 0.13705185404883644`}, {
       2.477597807858436, -3.3633454387878277`, 0.00872019253053169}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.943820711372146, -2.443660950882228, 
      0.050088403763204704`}, {2.9438207113721466`, -2.443660950882228, 
      0.05008840376320472}, {2.9625471409147646`, -2.2957739672548185`, 
      0.033392269175469814`}, {2.962547140914764, -2.2957739672548185`, 
      0.03339226917546981}, {2.943820711372146, -2.443660950882228, 
      0.050088403763204704`}}], 
     Polygon3DBox[{{2.962547140914764, -2.2957739672548185`, 
      0.03339226917546981}, {2.9625471409147646`, -2.2957739672548185`, 
      0.033392269175469814`}, {2.981273570457382, -2.1478869836274095`, 
      0.016696134587734918`}, {2.981273570457382, -2.1478869836274095`, 
      0.016696134587734904`}, {2.962547140914764, -2.2957739672548185`, 
      0.03339226917546981}}], 
     Polygon3DBox[{{2.981273570457382, -2.1478869836274095`, 
      0.016696134587734904`}, {2.981273570457382, -2.1478869836274095`, 
      0.016696134587734918`}, {3., -2., 1.8998056265215357`*^-17}, {3., -2., 
      0.}, {2.981273570457382, -2.1478869836274095`, 0.016696134587734904`}}],
      Polygon3DBox[{{3., -2., 0.}, {3., -2., 6.640434237519533*^-18}, {
      3.018726429542618, -1.8521130163725907`, -0.016696134587734893`}, {
      3.018726429542618, -1.8521130163725907`, -0.016696134587734897`}, {
      3., -2., 0.}}], 
     Polygon3DBox[{{
      3.018726429542618, -1.8521130163725907`, -0.016696134587734897`}, {
      3.018726429542618, -1.8521130163725907`, -0.016696134587734893`}, {
      3.037452859085236, -1.7042260327451815`, -0.033392269175469794`}, {
      3.037452859085236, -1.7042260327451815`, -0.0333922691754698}, {
      3.018726429542618, -1.8521130163725907`, -0.016696134587734897`}}], 
     Polygon3DBox[{{
      3.037452859085236, -1.7042260327451815`, -0.0333922691754698}, {
      3.037452859085236, -1.7042260327451815`, -0.033392269175469794`}, {
      3.056179288627854, -1.5563390491177722`, -0.0500884037632047}, {
      3.0561792886278534`, -1.5563390491177722`, -0.05008840376320469}, {
      3.037452859085236, -1.7042260327451815`, -0.0333922691754698}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7L3Xr/Yw+7Q2jmFZl5PcwHvh5W+aC/dKX9vE0R
r7w3szs8/vBo775YpgNLmiQWnJJYaO8fqfN16U12h6KKj3H39Rih4hPtGcCA
wwFCMxxIbbnMtbwuxmbjsstcUWocDrL8sk6Oi/7uXwRRvz/Jd7noFh8OBys5
q5Yml9/7F0PM3y/0pUqBr5jDIVw3/NjhZz/2f4a4Z78wVDwMKg51J4Y5UHfu
R7cX6s79ONy5B91fUHdihAPUnfbvoOEWAg03qDvtcYUnANDrogs=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        2.55609574249356, -1.9499115962367952`, -0.054223260471042437`}, {
        2.55609574249356, -1.9499115962367952`, -0.05422326047104244}, {
        2.70406382832904, -1.9666077308245302`, -0.0361488403140283}, {
        2.70406382832904, -1.9666077308245302`, -0.0361488403140283}, {
        2.55609574249356, -1.9499115962367952`, -0.054223260471042437`}}], 
       Polygon3DBox[{{
        2.70406382832904, -1.9666077308245302`, -0.0361488403140283}, {
        2.70406382832904, -1.9666077308245302`, -0.0361488403140283}, {
        2.85203191416452, -1.983303865412265, -0.01807442015701416}, {
        2.85203191416452, -1.983303865412265, -0.018074420157014152`}, {
        2.70406382832904, -1.9666077308245302`, -0.0361488403140283}}], 
       Polygon3DBox[{{
        2.85203191416452, -1.983303865412265, -0.018074420157014152`}, {
        2.85203191416452, -1.983303865412265, -0.01807442015701416}, {
        3., -2., -1.6444788443861207`*^-17}, {
        3., -2., -3.067030167150444*^-18}, {
        2.85203191416452, -1.983303865412265, -0.018074420157014152`}}], 
       Polygon3DBox[{{3., -2., -3.067030167150444*^-18}, {
        3., -2., -3.067030167150444*^-18}, {
        3.1479680858354797`, -2.016696134587735, 0.01807442015701414}, {
        3.1479680858354797`, -2.016696134587735, 0.01807442015701414}, {
        3., -2., -3.067030167150444*^-18}}], 
       Polygon3DBox[{{3.1479680858354797`, -2.016696134587735, 
        0.01807442015701414}, {3.1479680858354797`, -2.016696134587735, 
        0.01807442015701414}, {3.29593617167096, -2.03339226917547, 
        0.036148840314028284`}, {3.29593617167096, -2.0333922691754696`, 
        0.036148840314028284`}, {3.1479680858354797`, -2.016696134587735, 
        0.01807442015701414}}], 
       Polygon3DBox[{{3.29593617167096, -2.0333922691754696`, 
        0.036148840314028284`}, {3.29593617167096, -2.03339226917547, 
        0.036148840314028284`}, {3.44390425750644, -2.050088403763205, 
        0.054223260471042437`}, {3.44390425750644, -2.050088403763205, 
        0.05422326047104242}, {3.29593617167096, -2.0333922691754696`, 
        0.036148840314028284`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/3M609v0Xt8Or98ofS
zd8sZHV4bf1/lWX5//1rT9w/K9m0aD//w83S3y6wOXydW391zm6Y+KT9DGDA
4QChGQ7I/yxZc/VG3J4Pcj5POPU5HVgNHaYaKjEcWA1Rb//QdsYJ4TguB+6k
Bq1kF4YDayDm21+KebJGtpfbQWDygf1T0hgOMELcgyEOdSeGOVB32n9Esxfq
Tnsc7rQRQPMX1J0Y4QB15370cIO6E0McFp4AiG+rbw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}, {
      2.612275031121414, -1.5062506453545674`, -0.10431166423424715`}, {
      3.5000835461342934`, -1.6064274528809768`, 0.004134856707837732}, {
      3.387724968878586, -2.493749354645433, 0.10431166423424715`}, {
      2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}, {
       2.612275031121414, -1.5062506453545674`, -0.10431166423424715`}, {
       3.5000835461342934`, -1.6064274528809768`, 0.004134856707837732}, {
       3.387724968878586, -2.493749354645433, 0.10431166423424715`}, {
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.9716473660469473`, -1.4483803026123172`, 
      0.025519255028526287`}, {2.9716473660469473`, -1.4483803026123172`, 
      0.025519255028526297`}, {2.9810982440312985`, -1.2989202017415447`, 
      0.0170128366856842}, {2.981098244031298, -1.2989202017415449`, 
      0.017012836685684193`}, {2.9716473660469473`, -1.4483803026123172`, 
      0.025519255028526287`}}], 
     Polygon3DBox[{{2.981098244031298, -1.2989202017415449`, 
      0.017012836685684193`}, {2.9810982440312985`, -1.2989202017415447`, 
      0.0170128366856842}, {2.9905491220156493`, -1.1494601008707725`, 
      0.008506418342842109}, {2.9905491220156493`, -1.1494601008707723`, 
      0.008506418342842097}, {2.981098244031298, -1.2989202017415449`, 
      0.017012836685684193`}}], 
     Polygon3DBox[{{2.9905491220156493`, -1.1494601008707723`, 
      0.008506418342842097}, {2.9905491220156493`, -1.1494601008707725`, 
      0.008506418342842109}, {3., -1.0000000000000002`, 
      1.2165697406264207`*^-17}, {3., -1., 0.}, {
      2.9905491220156493`, -1.1494601008707723`, 0.008506418342842097}}], 
     Polygon3DBox[{{3., -1., 0.}, {3., -1., 5.86968307205283*^-18}, {
      3.0094508779843507`, -0.8505398991292277, -0.00850641834284209}, {
      3.0094508779843507`, -0.8505398991292277, -0.008506418342842093}, {
      3., -1., 0.}}], 
     Polygon3DBox[{{
      3.0094508779843507`, -0.8505398991292277, -0.008506418342842093}, {
      3.0094508779843507`, -0.8505398991292277, -0.00850641834284209}, {
      3.018901755968702, -0.7010797982584553, -0.017012836685684183`}, {
      3.018901755968702, -0.7010797982584552, -0.01701283668568419}, {
      3.0094508779843507`, -0.8505398991292277, -0.008506418342842093}}], 
     Polygon3DBox[{{
      3.018901755968702, -0.7010797982584552, -0.01701283668568419}, {
      3.018901755968702, -0.7010797982584553, -0.017012836685684183`}, {
      3.0283526339530527`, -0.5516196973876828, -0.025519255028526283`}, {
      3.0283526339530527`, -0.5516196973876829, -0.02551925502852628}, {
      3.018901755968702, -0.7010797982584552, -0.01701283668568419}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA4Lecz7/ii7Q579v0sTdL7vf6knYL5DcZa9pYUT
p9dNdof59St7Ek582T+nZKvKheyJ9rIyC1mWvmF3OL8/xM0g5RNUvNGeAQw4
HCD0h/0Rh5onsXL62jx+HPc7SpjDIakhrHi++ev9syDq9x8/vvfbVjUOh8MM
a5/Z5T/bPxti/v5Vq2U+CVhxOKg2MkfdW/Zw/3OIe+DiKlBxqDvh5hyCmgN1
536YvYlQe6Hu3I/DnXvQ/QV1Jzwc5kHDAepOe/Rwg7oTQxwWngD84KQi
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        2.5532881005546524`, -0.9744807449714737, -0.04792959958854693}, {
        2.5532881005546524`, -0.9744807449714736, -0.04792959958854693}, {
        2.7021920670364348`, -0.9829871633143158, -0.03195306639236462}, {
        2.7021920670364348`, -0.9829871633143158, -0.03195306639236462}, {
        2.5532881005546524`, -0.9744807449714737, -0.04792959958854693}}], 
       Polygon3DBox[{{
        2.7021920670364348`, -0.9829871633143158, -0.03195306639236462}, {
        2.7021920670364348`, -0.9829871633143158, -0.03195306639236462}, {
        2.851096033518217, -0.9914935816571578, -0.01597653319618232}, {
        2.8510960335182176`, -0.9914935816571578, -0.01597653319618231}, {
        2.7021920670364348`, -0.9829871633143158, -0.03195306639236462}}], 
       Polygon3DBox[{{
        2.8510960335182176`, -0.9914935816571578, -0.01597653319618231}, {
        2.851096033518217, -0.9914935816571578, -0.01597653319618232}, {
        3., -1., -1.3387613704758649`*^-17}, {
        3., -1., -1.5626036993654858`*^-18}, {
        2.8510960335182176`, -0.9914935816571578, -0.01597653319618231}}], 
       Polygon3DBox[{{3., -1., -1.5626036993654858`*^-18}, {
        3., -1., -1.5626036993654858`*^-18}, {
        3.1489039664817824`, -1.008506418342842, 0.015976533196182308`}, {
        3.1489039664817824`, -1.008506418342842, 0.015976533196182304`}, {
        3., -1., -1.5626036993654858`*^-18}}], 
       Polygon3DBox[{{3.1489039664817824`, -1.008506418342842, 
        0.015976533196182304`}, {3.1489039664817824`, -1.008506418342842, 
        0.015976533196182308`}, {3.2978079329635652`, -1.017012836685684, 
        0.031953066392364615`}, {3.2978079329635652`, -1.017012836685684, 
        0.03195306639236462}, {3.1489039664817824`, -1.008506418342842, 
        0.015976533196182304`}}], 
       Polygon3DBox[{{3.2978079329635652`, -1.017012836685684, 
        0.03195306639236462}, {3.2978079329635652`, -1.017012836685684, 
        0.031953066392364615`}, {3.4467118994453476`, -1.0255192550285264`, 
        0.04792959958854693}, {3.4467118994453476`, -1.0255192550285261`, 
        0.04792959958854692}, {3.2978079329635652`, -1.017012836685684, 
        0.03195306639236462}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7/3+hU01tVZdK/b/L7l9
X2weq0N0yK26hSXv9x9kDP6nFrNgf8Out/nc59kc9LRy9wfsgolP2M8ABhwO
EPrD/jdMpn8dXKL3NLgKTfhiwOnwMstzwXWlD/sPQNTbM3arKLxM5HK4dHWS
w3rXDzDz7RsvmG24O4nbYY/DnQdtGR/2L4C4B0Mc6k6c5qDbC3WnPQ532qD7
C+pOnOGAHm5Qd2KIw8ITAN69pfo=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}, {
      2.5816407345077046`, -0.5261004423591564, -0.07344885461707322}, {
      3.4750645333984003`, -0.5771389524162092, 0.022410344560020643`}, {
      3.4183592654922954`, -1.4738995576408436`, 0.07344885461707322}, {
      2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}, {
       2.5816407345077046`, -0.5261004423591564, -0.07344885461707322}, {
       3.4750645333984003`, -0.5771389524162092, 0.022410344560020643`}, {
       3.4183592654922954`, -1.4738995576408436`, 0.07344885461707322}, {
       2.5249354666015997`, -1.4228610475837908`, \
-0.022410344560020643`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3., -0.4499999999999999, 0.}, {3., -0.4499999999999999, 
      1.1211270752225218`*^-17}, {3., -0.29999999999999993`, 
      9.342725626854347*^-18}, {3., -0.3, 0.}, {3., -0.4499999999999999, 
      0.}}], Polygon3DBox[{{3., -0.3, 0.}, {3., -0.29999999999999993`, 
      9.342725626854347*^-18}, {3., -0.15000000000000005`, 
      7.47418050148348*^-18}, {3., -0.15, 0.}, {3., -0.3, 0.}}], 
     Polygon3DBox[{{3., -0.15, 0.}, {3., -0.15000000000000005`, 
      7.47418050148348*^-18}, {3., -1.1102230246251563`*^-16, 
      5.6056353761126104`*^-18}, {3., 0., 0.}, {3., -0.15, 0.}}], 
     Polygon3DBox[{{3., 0., 0.}, {3., 0., 5.605635376112609*^-18}, {3., 
      0.14999999999999994`, 3.73709025074174*^-18}, {3., 0.14999999999999994`,
       0.}, {3., 0., 0.}}], 
     Polygon3DBox[{{3., 0.14999999999999994`, 0.}, {3., 0.14999999999999994`, 
      3.73709025074174*^-18}, {3., 0.2999999999999999, 
      1.86854512537087*^-18}, {3., 0.29999999999999993`, 0.}, {3., 
      0.14999999999999994`, 0.}}], 
     Polygon3DBox[{{3., 0.29999999999999993`, 0.}, {3., 0.2999999999999999, 
      1.8685451253708704`*^-18}, {3., 0.44999999999999984`, 
      9.335258193320276*^-34}, {3., 0.4499999999999998, 0.}, {3., 
      0.29999999999999993`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgcDh9BgTu7GdAARwOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIA9mxGvg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.5523340665952334`, 0., -0.04577348652701718}, {
        2.5523340665952334`, 
        5.5109105961630883`*^-17, -0.04577348652701718}, {2.7015560443968223`,
         4.592425496802573*^-17, -0.03051565768467812}, {2.7015560443968223`, 
        9.184850993605147*^-18, -0.030515657684678125`}, {2.5523340665952334`,
         0., -0.04577348652701718}}], 
       Polygon3DBox[{{2.7015560443968223`, 
        9.184850993605147*^-18, -0.030515657684678125`}, {2.7015560443968223`,
         4.592425496802573*^-17, -0.03051565768467812}, {2.850778022198411, 
        3.6739403974420595`*^-17, -0.01525782884233907}, {2.850778022198411, 
        1.8369701987210294`*^-17, -0.015257828842339062`}, {
        2.7015560443968223`, 
        9.184850993605147*^-18, -0.030515657684678125`}}], 
       Polygon3DBox[{{2.850778022198411, 
        1.8369701987210294`*^-17, -0.015257828842339062`}, {2.850778022198411,
         3.6739403974420595`*^-17, -0.01525782884233907}, {3., 
        2.7554552980815448`*^-17, -1.1293061924369748`*^-17}, {3., 
        2.7554552980815442`*^-17, 0.}, {2.850778022198411, 
        1.8369701987210294`*^-17, -0.015257828842339062`}}], 
       Polygon3DBox[{{3., 2.7554552980815442`*^-17, 0.}, {3., 
        2.7554552980815442`*^-17, 0.}, {3.149221977801589, 
        1.8369701987210297`*^-17, 0.015257828842339057`}, {3.149221977801589, 
        3.673940397442059*^-17, 0.015257828842339057`}, {3., 
        2.7554552980815442`*^-17, 0.}}], 
       Polygon3DBox[{{3.149221977801589, 3.673940397442059*^-17, 
        0.015257828842339057`}, {3.149221977801589, 1.8369701987210297`*^-17, 
        0.015257828842339057`}, {3.2984439556031777`, 9.18485099360515*^-18, 
        0.030515657684678114`}, {3.2984439556031777`, 4.592425496802573*^-17, 
        0.03051565768467812}, {3.149221977801589, 3.673940397442059*^-17, 
        0.015257828842339057`}}], 
       Polygon3DBox[{{3.2984439556031777`, 4.592425496802573*^-17, 
        0.03051565768467812}, {3.2984439556031777`, 9.184850993605152*^-18, 
        0.030515657684678114`}, {3.4476659334047666`, 4.588754872883257*^-33, 
        0.045773486527017175`}, {3.4476659334047666`, 5.510910596163088*^-17, 
        0.045773486527017175`}, {3.2984439556031777`, 4.592425496802573*^-17, 
        0.03051565768467812}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb61Cyvl83iwAAFCbMDwufnL9+/51t41sk5rHDx
RhUx+Xr7+fvjfmtvTTnHhibevx/C44CLHyie5GLPFbVnEcsVr9mGnHDxOoh6
exfOFVPNkrng4g0Q8+2f8dY8uDiFGy4eD3EPhjjUnRjmQN1pj24v1J32ONxp
g+4vqDsxwgHqzv3o4QZ1J4Y4LDwBQAFbOQ==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}, {
      2.5523340665952334`, 0.4499999999999999, -0.04577348652701718}, {
      3.4476659334047666`, 0.4499999999999999, 0.04577348652701718}, {
      3.4476659334047666`, -0.4499999999999999, 0.04577348652701718}, {
      2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}, {
       2.5523340665952334`, 0.4499999999999999, -0.04577348652701718}, {
       3.4476659334047666`, 0.4499999999999999, 0.04577348652701718}, {
       3.4476659334047666`, -0.4499999999999999, 0.04577348652701718}, {
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.0283526339530527`, 
      0.5516196973876828, -0.025519255028526287`}, {3.0283526339530527`, 
      0.5516196973876828, -0.025519255028526276`}, {3.018901755968702, 
      0.7010797982584552, -0.01701283668568418}, {3.018901755968702, 
      0.7010797982584551, -0.017012836685684193`}, {3.0283526339530527`, 
      0.5516196973876828, -0.025519255028526287`}}], 
     Polygon3DBox[{{3.018901755968702, 
      0.7010797982584551, -0.017012836685684193`}, {3.018901755968702, 
      0.7010797982584552, -0.01701283668568418}, {3.0094508779843507`, 
      0.8505398991292276, -0.008506418342842091}, {3.0094508779843507`, 
      0.8505398991292276, -0.008506418342842097}, {3.018901755968702, 
      0.7010797982584551, -0.017012836685684193`}}], 
     Polygon3DBox[{{3.0094508779843507`, 
      0.8505398991292276, -0.008506418342842097}, {3.0094508779843507`, 
      0.8505398991292276, -0.008506418342842091}, {3., 
      0.9999999999999999, -4.26331262158544*^-19}, {3., 1., 0.}, {
      3.0094508779843507`, 0.8505398991292276, -0.008506418342842097}}], 
     Polygon3DBox[{{3., 1., 0.}, {3., 1., 5.86968307205283*^-18}, {
      2.9905491220156493`, 1.1494601008707723`, 0.008506418342842097}, {
      2.9905491220156493`, 1.1494601008707723`, 0.008506418342842093}, {3., 
      1., 0.}}], 
     Polygon3DBox[{{2.9905491220156493`, 1.1494601008707723`, 
      0.008506418342842093}, {2.9905491220156493`, 1.1494601008707723`, 
      0.008506418342842097}, {2.981098244031298, 1.2989202017415447`, 
      0.01701283668568419}, {2.981098244031298, 1.2989202017415447`, 
      0.01701283668568419}, {2.9905491220156493`, 1.1494601008707723`, 
      0.008506418342842093}}], 
     Polygon3DBox[{{2.981098244031298, 1.2989202017415447`, 
      0.01701283668568419}, {2.981098244031298, 1.2989202017415447`, 
      0.01701283668568419}, {2.9716473660469473`, 1.4483803026123172`, 
      0.025519255028526283`}, {2.9716473660469473`, 1.4483803026123172`, 
      0.02551925502852628}, {2.981098244031298, 1.2989202017415447`, 
      0.01701283668568419}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF61WuaTgBWHg0ojc9S9ZQ/tX+oJmO9QnLX/+PG9
37aqcTgcYlj7zC7/mf2ckq0qF7In7n/8OO53lDCHQ2JDWPF889dQ8cb9DGDA
4QChP9hHHGqexMrpu0dWZiHL0jfsDuf3h7gZpHyynwVRb29p4cTpdZPdYV79
yp6EE1/sZ0PMtw8Lecz7/ii7Q579v0sTdL7bP4e4B0Mc6k64OfOh5kDdaY9u
L9Sd9jjcaQPzVxLUX1B3wsPhMDQcoO7cDws3VWi4Qd25H1d4AgAIL5u5
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.5532881005546524`, 
        0.9744807449714737, -0.04792959958854693}, {2.5532881005546524`, 
        0.9744807449714737, -0.04792959958854693}, {2.7021920670364348`, 
        0.9829871633143159, -0.03195306639236462}, {2.7021920670364348`, 
        0.9829871633143158, -0.03195306639236462}, {2.5532881005546524`, 
        0.9744807449714737, -0.04792959958854693}}], 
       Polygon3DBox[{{2.7021920670364348`, 
        0.9829871633143158, -0.03195306639236462}, {2.7021920670364348`, 
        0.9829871633143159, -0.03195306639236462}, {2.851096033518217, 
        0.991493581657158, -0.015976533196182315`}, {2.8510960335182176`, 
        0.991493581657158, -0.01597653319618231}, {2.7021920670364348`, 
        0.9829871633143158, -0.03195306639236462}}], 
       Polygon3DBox[{{2.8510960335182176`, 
        0.991493581657158, -0.01597653319618231}, {2.851096033518217, 
        0.991493581657158, -0.015976533196182315`}, {3., 
        1., -1.0262406306027677`*^-17}, {3., 1., 1.5626036993654858`*^-18}, {
        2.8510960335182176`, 0.991493581657158, -0.01597653319618231}}], 
       Polygon3DBox[{{3., 1., 1.5626036993654858`*^-18}, {3., 1., 
        1.5626036993654858`*^-18}, {3.1489039664817824`, 1.008506418342842, 
        0.015976533196182308`}, {3.1489039664817824`, 1.008506418342842, 
        0.01597653319618231}, {3., 1., 1.5626036993654858`*^-18}}], 
       Polygon3DBox[{{3.1489039664817824`, 1.008506418342842, 
        0.01597653319618231}, {3.1489039664817824`, 1.008506418342842, 
        0.015976533196182308`}, {3.2978079329635652`, 1.017012836685684, 
        0.031953066392364615`}, {3.2978079329635652`, 1.0170128366856843`, 
        0.03195306639236462}, {3.1489039664817824`, 1.008506418342842, 
        0.01597653319618231}}], 
       Polygon3DBox[{{3.2978079329635652`, 1.0170128366856843`, 
        0.03195306639236462}, {3.2978079329635652`, 1.017012836685684, 
        0.031953066392364615`}, {3.4467118994453476`, 1.0255192550285264`, 
        0.04792959958854693}, {3.4467118994453476`, 1.0255192550285264`, 
        0.04792959958854692}, {3.2978079329635652`, 1.0170128366856843`, 
        0.03195306639236462}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7739wqaaWquuFfv/l9y+
LzaP1SE65FbdwpL39gcZg/+pxSzY37DrbT73eTYHPa3c/QG7YOIT9jOAAYcD
hP5g/4bJ9K+DS/SeBlehCV8MOB1eZnkuuK70wf4ARL09Y7eKwstELodLVyc5
rHf9ADPfvvGC2Ya7k7gd9jjcedCW8cF+AcQ9GOJQd+I0B91eqDvtcbjTBt1f
UHfiDAf0cIO6E0McFp4ArvKeeg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.5816407345077046`, 
      0.5261004423591564, -0.07344885461707322}, {2.5249354666015997`, 
      1.4228610475837908`, -0.022410344560020643`}, {3.4183592654922954`, 
      1.4738995576408436`, 0.07344885461707322}, {3.4750645333984003`, 
      0.5771389524162092, 0.022410344560020643`}, {2.5816407345077046`, 
      0.5261004423591564, -0.07344885461707322}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}, {2.5249354666015997`, 
       1.4228610475837908`, -0.022410344560020643`}, {3.4183592654922954`, 
       1.4738995576408436`, 0.07344885461707322}, {3.4750645333984003`, 
       0.5771389524162092, 0.022410344560020643`}, {2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.056179288627854, 
      1.556339049117772, -0.050088403763204704`}, {3.056179288627854, 
      1.556339049117772, -0.05008840376320469}, {3.037452859085236, 
      1.7042260327451815`, -0.03339226917546979}, {3.037452859085236, 
      1.7042260327451815`, -0.03339226917546981}, {3.056179288627854, 
      1.556339049117772, -0.050088403763204704`}}], 
     Polygon3DBox[{{3.037452859085236, 
      1.7042260327451815`, -0.03339226917546981}, {3.037452859085236, 
      1.7042260327451815`, -0.03339226917546979}, {3.018726429542618, 
      1.8521130163725905`, -0.016696134587734897`}, {3.018726429542618, 
      1.8521130163725907`, -0.016696134587734904`}, {3.037452859085236, 
      1.7042260327451815`, -0.03339226917546981}}], 
     Polygon3DBox[{{3.018726429542618, 
      1.8521130163725907`, -0.016696134587734904`}, {3.018726429542618, 
      1.8521130163725905`, -0.016696134587734897`}, {3., 
      2., -5.717187790176287*^-18}, {3., 2., 0.}, {3.018726429542618, 
      1.8521130163725907`, -0.016696134587734904`}}], 
     Polygon3DBox[{{3., 2., 0.}, {3., 2., 6.640434237519533*^-18}, {
      2.981273570457382, 2.1478869836274095`, 0.0166961345877349}, {
      2.981273570457382, 2.1478869836274095`, 0.016696134587734897`}, {3., 2.,
       0.}}], Polygon3DBox[{{2.981273570457382, 2.1478869836274095`, 
      0.016696134587734897`}, {2.981273570457382, 2.1478869836274095`, 
      0.0166961345877349}, {2.962547140914764, 2.2957739672548185`, 
      0.033392269175469794`}, {2.962547140914764, 2.2957739672548185`, 
      0.0333922691754698}, {2.981273570457382, 2.1478869836274095`, 
      0.016696134587734897`}}], 
     Polygon3DBox[{{2.962547140914764, 2.2957739672548185`, 
      0.0333922691754698}, {2.962547140914764, 2.2957739672548185`, 
      0.033392269175469794`}, {2.943820711372146, 2.443660950882228, 
      0.0500884037632047}, {2.9438207113721466`, 2.4436609508822276`, 
      0.05008840376320469}, {2.962547140914764, 2.2957739672548185`, 
      0.0333922691754698}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb+UqXAV8zhEKYbfuzwsx/2Xw+rfNBfunJ/ku9y
0S0+HA5WclYtTS6/7Zc0SSw4JbFw/8Zll7mi1DgcZPllnRwX/YWKT9zPAAYc
DhCawSG15TLX8rqYPf6ROl+X3mR3KKr4GHdfj9FhEUS9/bxNEa+8N7M7PP7w
aO++WCaHxRDz7d9xt97/2MPuEJJ5RWZeD7PDZ4h77N9CxUOh4lB3YpgDdac9
ur1Qd9rjcKcNur+g7sQIB6g79wtBwy0cGm5Qd+7HFZ4A33iaug==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.55609574249356, 
        1.9499115962367952`, -0.054223260471042437`}, {2.55609574249356, 
        1.9499115962367954`, -0.05422326047104243}, {2.70406382832904, 
        1.9666077308245302`, -0.036148840314028284`}, {2.70406382832904, 
        1.9666077308245302`, -0.0361488403140283}, {2.55609574249356, 
        1.9499115962367952`, -0.054223260471042437`}}], 
       Polygon3DBox[{{2.70406382832904, 
        1.9666077308245302`, -0.0361488403140283}, {2.70406382832904, 
        1.9666077308245302`, -0.036148840314028284`}, {2.85203191416452, 
        1.9833038654122652`, -0.018074420157014152`}, {2.85203191416452, 
        1.9833038654122652`, -0.018074420157014146`}, {2.70406382832904, 
        1.9666077308245302`, -0.0361488403140283}}], 
       Polygon3DBox[{{2.85203191416452, 
        1.9833038654122652`, -0.018074420157014146`}, {2.85203191416452, 
        1.9833038654122652`, -0.018074420157014152`}, {3., 
        2., -1.0310728109560317`*^-17}, {3., 2., 3.067030167150444*^-18}, {
        2.85203191416452, 1.9833038654122652`, -0.018074420157014146`}}], 
       Polygon3DBox[{{3., 2., 3.067030167150444*^-18}, {3., 2., 
        3.067030167150444*^-18}, {3.1479680858354797`, 2.016696134587735, 
        0.018074420157014146`}, {3.1479680858354797`, 2.016696134587735, 
        0.018074420157014146`}, {3., 2., 3.067030167150444*^-18}}], 
       Polygon3DBox[{{3.1479680858354797`, 2.016696134587735, 
        0.018074420157014146`}, {3.1479680858354797`, 2.016696134587735, 
        0.018074420157014146`}, {3.29593617167096, 2.03339226917547, 
        0.036148840314028284`}, {3.29593617167096, 2.03339226917547, 
        0.0361488403140283}, {3.1479680858354797`, 2.016696134587735, 
        0.018074420157014146`}}], 
       Polygon3DBox[{{3.29593617167096, 2.03339226917547, 
        0.0361488403140283}, {3.29593617167096, 2.03339226917547, 
        0.036148840314028284`}, {3.44390425750644, 2.050088403763205, 
        0.054223260471042437`}, {3.44390425750644, 2.050088403763205, 
        0.054223260471042437`}, {3.29593617167096, 2.03339226917547, 
        0.0361488403140283}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/tmdae36J2ePV++UPp
5m8Wsjq8tv6/yrL8v/3aE/fPSjYt2s//cLP0twtsDl/n1l+dsxsmPmk/Axhw
OEBoBgf5nyVrrt6I2/NBzucJpz6nA6uhw1RDJQaH1RD19g9tZ5wQjuNy4E5q
0Ep2YXBYAzHf/lLMkzWyvdwOApMP7J+SxuDACHEPhjjUnRjmQN1p/xHNXqg7
7XG400YAzV9Qd2KEA9Sd+9HDDepODHFYeAIAWKSj7w==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.612275031121414, 
      1.5062506453545674`, -0.10431166423424715`}, {2.4999164538657066`, 
      2.3935725471190232`, -0.004134856707837732}, {3.387724968878586, 
      2.493749354645433, 0.10431166423424715`}, {3.5000835461342934`, 
      1.6064274528809768`, 0.004134856707837732}, {2.612275031121414, 
      1.5062506453545674`, -0.10431166423424715`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}, {2.4999164538657066`, 
       2.3935725471190232`, -0.004134856707837732}, {3.387724968878586, 
       2.493749354645433, 0.10431166423424715`}, {3.5000835461342934`, 
       1.6064274528809768`, 0.004134856707837732}, {2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.083004452306681, 
      2.5637685379224884`, -0.07288602328968406}, {3.0830044523066813`, 
      2.5637685379224884`, -0.07288602328968405}, {3.0553363015377872`, 
      2.7091790252816588`, -0.048590682193122695`}, {3.0553363015377872`, 
      2.7091790252816588`, -0.048590682193122715`}, {3.083004452306681, 
      2.5637685379224884`, -0.07288602328968406}}], 
     Polygon3DBox[{{3.0553363015377872`, 
      2.7091790252816588`, -0.048590682193122715`}, {3.0553363015377872`, 
      2.7091790252816588`, -0.048590682193122695`}, {3.0276681507688936`, 
      2.854589512640829, -0.024295341096561358`}, {3.0276681507688936`, 
      2.854589512640829, -0.024295341096561358`}, {3.0553363015377872`, 
      2.7091790252816588`, -0.048590682193122715`}}], 
     Polygon3DBox[{{3.0276681507688936`, 
      2.854589512640829, -0.024295341096561358`}, {3.0276681507688936`, 
      2.854589512640829, -0.024295341096561358`}, {3., 
      3., -1.0124116792300137`*^-17}, {3., 3., 0.}, {3.0276681507688936`, 
      2.854589512640829, -0.024295341096561358`}}], 
     Polygon3DBox[{{3., 3., 0.}, {3., 3., 7.858047925382672*^-18}, {
      2.9723318492311064`, 3.1454104873591704`, 0.024295341096561358`}, {
      2.9723318492311064`, 3.1454104873591704`, 0.02429534109656135}, {3., 3.,
       0.}}], Polygon3DBox[{{2.9723318492311064`, 3.1454104873591704`, 
      0.02429534109656135}, {2.9723318492311064`, 3.1454104873591704`, 
      0.024295341096561358`}, {2.9446636984622128`, 3.2908209747183412`, 
      0.0485906821931227}, {2.9446636984622128`, 3.2908209747183412`, 
      0.04859068219312271}, {2.9723318492311064`, 3.1454104873591704`, 
      0.02429534109656135}}], 
     Polygon3DBox[{{2.9446636984622128`, 3.2908209747183412`, 
      0.04859068219312271}, {2.9446636984622128`, 3.2908209747183412`, 
      0.0485906821931227}, {2.916995547693319, 3.4362314620775116`, 
      0.07288602328968406}, {2.916995547693319, 3.4362314620775116`, 
      0.07288602328968405}, {2.9446636984622128`, 3.2908209747183412`, 
      0.04859068219312271}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP63iMH230oOhwwFd5GZTSwO6jGxfStWbNofIr5a
I6SQw8H1QAtv2hpWB9MLF/c+eLBi/6ruUJFVFhwOSgmH2IyvsUHFZ+xnAAMO
BxjdqNvyOXV3yp6wklWvQ4+zO9ydb/vzjCangzFEvf2aFyHXV/exO+y2r/40
M5jLwQRivj1T7P9DjGHsDjPu73idVsvtoAZxD4Y41J0Y5kDdaQ+z9x7UXqg7
7XG40wbmL2Wov6DuxAgHqDv3o4cb1J0Y4rDwBAAedp8h
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.5606022601651173`, 
        2.927113976710316, -0.06416583075915237}, {2.5606022601651173`, 
        2.927113976710316, -0.06416583075915236}, {2.707068173443411, 
        2.951409317806877, -0.04277722050610157}, {2.707068173443411, 
        2.951409317806877, -0.04277722050610158}, {2.5606022601651173`, 
        2.927113976710316, -0.06416583075915237}}], 
       Polygon3DBox[{{2.707068173443411, 
        2.951409317806877, -0.04277722050610158}, {2.707068173443411, 
        2.951409317806877, -0.04277722050610157}, {2.8535340867217056`, 
        2.975704658903439, -0.02138861025305079}, {2.8535340867217056`, 
        2.975704658903439, -0.021388610253050788`}, {2.707068173443411, 
        2.951409317806877, -0.04277722050610158}}], 
       Polygon3DBox[{{2.8535340867217056`, 
        2.975704658903439, -0.021388610253050788`}, {2.8535340867217056`, 
        2.975704658903439, -0.02138861025305079}, {3., 
        3., -1.1367769955565901`*^-17}, {3., 3., 4.4629817562145516`*^-18}, {
        2.8535340867217056`, 2.975704658903439, -0.021388610253050788`}}], 
       Polygon3DBox[{{3., 3., 4.4629817562145516`*^-18}, {3., 3., 
        4.4629817562145516`*^-18}, {3.1464659132782944`, 3.024295341096561, 
        0.021388610253050788`}, {3.1464659132782944`, 3.024295341096561, 
        0.02138861025305079}, {3., 3., 4.4629817562145516`*^-18}}], 
       Polygon3DBox[{{3.1464659132782944`, 3.024295341096561, 
        0.02138861025305079}, {3.1464659132782944`, 3.024295341096561, 
        0.021388610253050788`}, {3.292931826556589, 3.048590682193123, 
        0.04277722050610157}, {3.292931826556589, 3.048590682193123, 
        0.04277722050610158}, {3.1464659132782944`, 3.024295341096561, 
        0.02138861025305079}}], 
       Polygon3DBox[{{3.292931826556589, 3.048590682193123, 
        0.04277722050610158}, {3.292931826556589, 3.048590682193123, 
        0.04277722050610157}, {3.4393977398348827`, 3.072886023289684, 
        0.06416583075915236}, {3.4393977398348827`, 3.072886023289684, 
        0.06416583075915236}, {3.292931826556589, 3.048590682193123, 
        0.04277722050610158}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLHYH/xkLGXRyN+z/dOt4
tPAKVof9Ozhqa+awO4ic1gl7+mzp/sq3j9dyXmFzSIhpsbM7BxOfup8BDDgc
YPSEf+ePZzok7WkXkgn6ps3psGBx9cGDhhwOQhD19nyqFkvehHM5OLp/b2pO
5nAQhphvP8U85NujZm6Hh6+KXFyncjj4QtyDIQ51J4Y5UHfao9sLdac9Dnfa
oPsL6k6McIC6cz96uEHdiSEOC08AUMSTXg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.643606712471798, 
      2.490882514632804, -0.13705185404883644`}, {2.477597807858436, 
      3.3633454387878277`, 0.00872019253053169}, {3.356393287528202, 
      3.509117485367196, 0.13705185404883644`}, {3.522402192141564, 
      2.6366545612121723`, -0.00872019253053169}, {2.643606712471798, 
      2.490882514632804, -0.13705185404883644`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}, {2.477597807858436, 
       3.3633454387878277`, 0.00872019253053169}, {3.356393287528202, 
       3.509117485367196, 0.13705185404883644`}, {3.522402192141564, 
       2.6366545612121723`, -0.00872019253053169}, {2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.108442691853718, 
      3.573346812597004, -0.09331259433958147}, {3.108442691853718, 
      3.573346812597004, -0.09331259433958146}, {3.072295127902479, 
      3.715564541731336, -0.06220839622638763}, {3.072295127902479, 
      3.715564541731336, -0.06220839622638766}, {3.108442691853718, 
      3.573346812597004, -0.09331259433958147}}], 
     Polygon3DBox[{{3.072295127902479, 
      3.715564541731336, -0.06220839622638766}, {3.072295127902479, 
      3.715564541731336, -0.06220839622638763}, {3.0361475639512396`, 
      3.857782270865668, -0.031104198113193825`}, {3.036147563951239, 
      3.857782270865668, -0.03110419811319383}, {3.072295127902479, 
      3.715564541731336, -0.06220839622638766}}], 
     Polygon3DBox[{{3.036147563951239, 
      3.857782270865668, -0.03110419811319383}, {3.0361475639512396`, 
      3.857782270865668, -0.031104198113193825`}, {3., 
      4., -1.358607162084056*^-17}, {3., 4., 0.}, {3.036147563951239, 
      3.857782270865668, -0.03110419811319383}}], 
     Polygon3DBox[{{3., 4., 0.}, {3., 4., 9.435659651006192*^-18}, {
      2.963852436048761, 4.142217729134332, 0.031104198113193822`}, {
      2.963852436048761, 4.142217729134332, 0.031104198113193815`}, {3., 4., 
      0.}}], Polygon3DBox[{{2.963852436048761, 4.142217729134332, 
      0.031104198113193815`}, {2.963852436048761, 4.142217729134332, 
      0.031104198113193822`}, {2.927704872097521, 4.284435458268664, 
      0.06220839622638763}, {2.927704872097521, 4.284435458268664, 
      0.062208396226387644`}, {2.963852436048761, 4.142217729134332, 
      0.031104198113193815`}}], 
     Polygon3DBox[{{2.927704872097521, 4.284435458268664, 
      0.062208396226387644`}, {2.927704872097521, 4.284435458268664, 
      0.06220839622638763}, {2.891557308146282, 4.426653187402996, 
      0.09331259433958146}, {2.891557308146282, 4.426653187402996, 
      0.09331259433958145}, {2.927704872097521, 4.284435458268664, 
      0.062208396226387644`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7IvMNY/B6Hw5avXbfMpvE4TAv41xP6ePv+hUwX
yvmncDhU+LE/r9zJ61CSvSLt+M31+wMYX+xm9+JwsFne/HnPHT6o+Pz9DGDA
4QChBRy6InuuXujK2rPhn7jLj63sDkk6dm0LJwo4FEDU28f/1e/4kM3ucCSi
hsdZWdChCGK+Pf8f9zMvFNkd1Fp3TXqyRdBhCsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEALMkod0=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.5665759995290798`, 
        3.9066874056604184`, -0.07704800810793501}, {2.5665759995290798`, 
        3.9066874056604184`, -0.077048008107935}, {2.71105066635272, 
        3.9377916037736123`, -0.05136533873862333}, {2.71105066635272, 
        3.9377916037736123`, -0.051365338738623346`}, {2.5665759995290798`, 
        3.9066874056604184`, -0.07704800810793501}}], 
       Polygon3DBox[{{2.71105066635272, 
        3.9377916037736123`, -0.051365338738623346`}, {2.71105066635272, 
        3.9377916037736123`, -0.05136533873862333}, {2.85552533317636, 
        3.968895801886806, -0.025682669369311677`}, {2.85552533317636, 
        3.968895801886806, -0.02568266936931167}, {2.71105066635272, 
        3.9377916037736123`, -0.051365338738623346`}}], 
       Polygon3DBox[{{2.85552533317636, 
        3.968895801886806, -0.02568266936931167}, {2.85552533317636, 
        3.968895801886806, -0.025682669369311677`}, {3., 
        4., -1.329524541285818*^-17}, {3., 4., 5.713748498905194*^-18}, {
        2.85552533317636, 3.968895801886806, -0.02568266936931167}}], 
       Polygon3DBox[{{3., 4., 5.713748498905194*^-18}, {3., 4., 
        5.713748498905194*^-18}, {3.14447466682364, 4.031104198113193, 
        0.025682669369311666`}, {3.14447466682364, 4.031104198113193, 
        0.02568266936931167}, {3., 4., 5.713748498905194*^-18}}], 
       Polygon3DBox[{{3.14447466682364, 4.031104198113193, 
        0.02568266936931167}, {3.14447466682364, 4.031104198113193, 
        0.025682669369311666`}, {3.28894933364728, 4.062208396226388, 
        0.051365338738623326`}, {3.28894933364728, 4.062208396226388, 
        0.051365338738623346`}, {3.14447466682364, 4.031104198113193, 
        0.02568266936931167}}], 
       Polygon3DBox[{{3.28894933364728, 4.062208396226388, 
        0.051365338738623346`}, {3.28894933364728, 4.062208396226388, 
        0.051365338738623326`}, {3.4334240004709202`, 4.093312594339581, 
        0.077048008107935}, {3.4334240004709202`, 4.093312594339581, 
        0.07704800810793501}, {3.28894933364728, 4.062208396226388, 
        0.051365338738623346`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA79D4XJu4eydm/c3ub4L
sd7A6hAUl/poRgO/w9tO/iN9Pqv2H1QqXyV7g81Bc71Roc8BmPis/QxgwOEA
oQUcZs3d/qPsVeoe+7sdoY/UOR2yV6Qdvykv4PAKot6+bpfg6iP+XA7XA872
bbYXcHgDMd9+7/RZDMvLuR2cfhqH9cYLOBRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwBq75Vy
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.675018691382798, 
      3.480034218257422, -0.1703606024475165}, {2.4581333076753618`, 
      4.333340593063415, 0.016264586231646463`}, {3.324981308617202, 
      4.519965781742577, 0.1703606024475165}, {3.5418666923246382`, 
      3.666659406936585, -0.016264586231646463`}, {2.675018691382798, 
      3.480034218257422, -0.1703606024475165}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.675018691382798, 
       3.480034218257422, -0.1703606024475165}, {2.4581333076753618`, 
       4.333340593063415, 0.016264586231646463`}, {3.324981308617202, 
       4.519965781742577, 0.1703606024475165}, {3.5418666923246382`, 
       3.666659406936585, -0.016264586231646463`}, {2.675018691382798, 
       3.480034218257422, -0.1703606024475165}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.1322205407431993`, 
      4.584439695825451, -0.11102865485960163`}, {3.1322205407431993`, 
      4.584439695825451, -0.1110286548596016}, {3.088147027162133, 
      4.7229597972169675`, -0.0740191032397344}, {3.0881470271621327`, 
      4.7229597972169675`, -0.07401910323973443}, {3.1322205407431993`, 
      4.584439695825451, -0.11102865485960163`}}], 
     Polygon3DBox[{{3.0881470271621327`, 
      4.7229597972169675`, -0.07401910323973443}, {3.088147027162133, 
      4.7229597972169675`, -0.0740191032397344}, {3.0440735135810666`, 
      4.861479898608484, -0.037009551619867215`}, {3.0440735135810666`, 
      4.861479898608484, -0.037009551619867215`}, {3.0881470271621327`, 
      4.7229597972169675`, -0.07401910323973443}}], 
     Polygon3DBox[{{3.0440735135810666`, 
      4.861479898608484, -0.037009551619867215`}, {3.0440735135810666`, 
      4.861479898608484, -0.037009551619867215`}, {3., 
      5., -1.6118534603804307`*^-17}, {3., 5., 0.}, {3.0440735135810666`, 
      4.861479898608484, -0.037009551619867215`}}], 
     Polygon3DBox[{{3., 5., 0.}, {3., 5., 1.1274036289148914`*^-17}, {
      2.9559264864189334`, 5.138520101391516, 0.03700955161986721}, {
      2.9559264864189334`, 5.138520101391516, 0.0370095516198672}, {3., 5., 
      0.}}], Polygon3DBox[{{2.9559264864189334`, 5.138520101391516, 
      0.0370095516198672}, {2.9559264864189334`, 5.138520101391516, 
      0.03700955161986721}, {2.9118529728378673`, 5.2770402027830325`, 
      0.0740191032397344}, {2.9118529728378673`, 5.2770402027830325`, 
      0.07401910323973442}, {2.9559264864189334`, 5.138520101391516, 
      0.0370095516198672}}], 
     Polygon3DBox[{{2.9118529728378673`, 5.2770402027830325`, 
      0.07401910323973442}, {2.9118529728378673`, 5.2770402027830325`, 
      0.0740191032397344}, {2.8677794592568007`, 5.415560304174549, 
      0.11102865485960162`}, {2.8677794592568007`, 5.415560304174549, 
      0.1110286548596016}, {2.9118529728378673`, 5.2770402027830325`, 
      0.07401910323973442}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL58ftKSk3ycDufNBWLKw4QcrpZ27YzP2bPf3HR7
btsWDoeuqq2T/J8IOTxZvLH61adN++fMum3mHMXh4Lo36qR6kTBUfNF+BjDg
cIDQIg7VabXKd6bk70lJVTm5Zym7w26npWY3ekUcHkHU25885TGp0pvdoazV
K3eDtKjDY4j59roGudFmH9kcDE+8X9yxUtThMsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAMgFpRQ=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{2.573739882665349, 
        4.888971345140399, -0.09205949255735071}, {2.573739882665349, 
        4.888971345140399, -0.0920594925573507}, {2.7158265884435657`, 
        4.925980896760265, -0.06137299503823379}, {2.7158265884435657`, 
        4.925980896760265, -0.06137299503823382}, {2.573739882665349, 
        4.888971345140399, -0.09205949255735071}}], 
       Polygon3DBox[{{2.7158265884435657`, 
        4.925980896760265, -0.06137299503823382}, {2.7158265884435657`, 
        4.925980896760265, -0.06137299503823379}, {2.857913294221783, 
        4.962990448380133, -0.03068649751911691}, {2.857913294221783, 
        4.962990448380133, -0.030686497519116906`}, {2.7158265884435657`, 
        4.925980896760265, -0.06137299503823382}}], 
       Polygon3DBox[{{2.857913294221783, 
        4.962990448380133, -0.030686497519116906`}, {2.857913294221783, 
        4.962990448380133, -0.03068649751911691}, {3., 
        5., -1.5914026387845183`*^-17}, {3., 5., 6.7985443393723685`*^-18}, {
        2.857913294221783, 4.962990448380133, -0.030686497519116906`}}], 
       Polygon3DBox[{{3., 5., 6.7985443393723685`*^-18}, {3., 5., 
        6.7985443393723685`*^-18}, {3.142086705778217, 5.037009551619867, 
        0.0306864975191169}, {3.142086705778217, 5.037009551619867, 
        0.030686497519116906`}, {3., 5., 6.7985443393723685`*^-18}}], 
       Polygon3DBox[{{3.142086705778217, 5.037009551619867, 
        0.030686497519116906`}, {3.142086705778217, 5.037009551619867, 
        0.0306864975191169}, {3.284173411556434, 5.074019103239735, 
        0.06137299503823379}, {3.2841734115564343`, 5.074019103239735, 
        0.06137299503823382}, {3.142086705778217, 5.037009551619867, 
        0.030686497519116906`}}], 
       Polygon3DBox[{{3.2841734115564343`, 5.074019103239735, 
        0.06137299503823382}, {3.284173411556434, 5.074019103239735, 
        0.06137299503823379}, {3.426260117334651, 5.111028654859601, 
        0.0920594925573507}, {3.426260117334651, 5.111028654859601, 
        0.0920594925573507}, {3.2841734115564343`, 5.074019103239735, 
        0.06137299503823382}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PmEHqe8X/5pO3L4/43i4
F/MuVocCS8Ewky3CDipfxP+656zfv+Wx9lLGu2wOO+ZwaEvdgonP388ABhwO
EFrEocj7ZdBE/aw9PjJXov4pcTp4JH+/8lRVxEEBot5+hsWKrX9cuRwmHHu3
8rS3iIMSxHz7xyE1Ar8zuB2uaz6r21go4iABcQ+GONSdGOZA3WmPbi/UnfY4
3GmD7i+oOzHCAerO/ejhBnUnhjgsPAFPaZe6
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{2.7059604234085484`, 
      4.47341104096585, -0.20308814741695236`}, {2.4415193419221497`, 
      5.3045316493149475`, 0.018969162302250916`}, {3.2940395765914516`, 
      5.52658895903415, 0.20308814741695236`}, {3.5584806580778503`, 
      4.6954683506850525`, -0.018969162302250916`}, {2.7059604234085484`, 
      4.47341104096585, -0.20308814741695236`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}, {2.4415193419221497`, 
       5.3045316493149475`, 0.018969162302250916`}, {3.2940395765914516`, 
       5.52658895903415, 0.20308814741695236`}, {3.5584806580778503`, 
       4.6954683506850525`, -0.018969162302250916`}, {2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.8666649194187164`, -5.416125973605159, 
      0.10752176699413386`}, {3.8666649194187164`, -5.416125973605159, 
      0.10752176699413389`}, {3.911109946279144, -5.277417315736773, 
      0.07168117799608927}, {3.911109946279144, -5.277417315736773, 
      0.07168117799608925}, {3.8666649194187164`, -5.416125973605159, 
      0.10752176699413386`}}], 
     Polygon3DBox[{{3.911109946279144, -5.277417315736773, 
      0.07168117799608925}, {3.911109946279144, -5.277417315736773, 
      0.07168117799608927}, {3.9555549731395723`, -5.138708657868387, 
      0.03584058899804466}, {3.9555549731395723`, -5.138708657868387, 
      0.035840588998044626`}, {3.911109946279144, -5.277417315736773, 
      0.07168117799608925}}], 
     Polygon3DBox[{{3.9555549731395723`, -5.138708657868387, 
      0.035840588998044626`}, {3.9555549731395723`, -5.138708657868387, 
      0.03584058899804466}, {4., -5., 3.9840269050438044`*^-17}, {4., -5., 
      0.}, {3.9555549731395723`, -5.138708657868387, 0.035840588998044626`}}],
      Polygon3DBox[{{4., -5., 0.}, {4., -5., 1.331290430260057*^-17}, {
      4.044445026860428, -4.861291342131613, -0.035840588998044605`}, {
      4.044445026860428, -4.861291342131613, -0.03584058899804461}, {4., -5., 
      0.}}], Polygon3DBox[{{
      4.044445026860428, -4.861291342131613, -0.03584058899804461}, {
      4.044445026860428, -4.861291342131613, -0.035840588998044605`}, {
      4.0888900537208555`, -4.7225826842632275`, -0.07168117799608922}, {
      4.0888900537208555`, -4.722582684263227, -0.07168117799608924}, {
      4.044445026860428, -4.861291342131613, -0.03584058899804461}}], 
     Polygon3DBox[{{
      4.0888900537208555`, -4.722582684263227, -0.07168117799608924}, {
      4.0888900537208555`, -4.7225826842632275`, -0.07168117799608922}, {
      4.133335080581284, -4.583874026394841, -0.10752176699413385`}, {
      4.133335080581284, -4.583874026394841, -0.10752176699413384`}, {
      4.0888900537208555`, -4.722582684263227, -0.07168117799608924}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM77nM3y7h2fw9uZcW9lVokeyBS6+aK7bbe956JP
TF88+R2+7H7pISwjemBOovXsTZGb7FUDKxl/LeF3+HW3ZAlnnwhUfJE9AxgI
OEBokQMRvjuY6qfm2eSFO/9v0hVwYFPqjv5WKHxgFkT9/tvr2v6xRgs48LiI
bX/zWOjAbIj5+z3ZTv3t6BBwEE5bKPQ4VOhAOsQ9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITAGUgoHk=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        3.5767723830849816`, -4.892478233005866, -0.1087081133259772}, {
        3.5767723830849816`, -4.892478233005866, -0.10870811332597721`}, {
        3.7178482553899874`, -4.928318822003911, -0.07247207555065147}, {
        3.7178482553899874`, -4.928318822003911, -0.07247207555065147}, {
        3.5767723830849816`, -4.892478233005866, -0.1087081133259772}}], 
       Polygon3DBox[{{
        3.7178482553899874`, -4.928318822003911, -0.07247207555065147}, {
        3.7178482553899874`, -4.928318822003911, -0.07247207555065147}, {
        3.8589241276949937`, -4.964159411001956, -0.036236037775325754`}, {
        3.8589241276949937`, -4.964159411001956, -0.03623603777532574}, {
        3.7178482553899874`, -4.928318822003911, -0.07247207555065147}}], 
       Polygon3DBox[{{
        3.8589241276949937`, -4.964159411001956, -0.03623603777532574}, {
        3.8589241276949937`, -4.964159411001956, -0.036236037775325754`}, {
        4., -5., -3.340386502897072*^-17}, {
        4., -5., -6.583809389401678*^-18}, {
        3.8589241276949937`, -4.964159411001956, -0.03623603777532574}}], 
       Polygon3DBox[{{4., -5., -6.583809389401678*^-18}, {
        4., -5., -6.583809389401678*^-18}, {
        4.141075872305006, -5.035840588998044, 0.03623603777532571}, {
        4.141075872305006, -5.035840588998044, 0.03623603777532571}, {
        4., -5., -6.583809389401678*^-18}}], 
       Polygon3DBox[{{4.141075872305006, -5.035840588998044, 
        0.03623603777532571}, {4.141075872305006, -5.035840588998044, 
        0.03623603777532571}, {4.282151744610013, -5.071681177996089, 
        0.07247207555065144}, {4.282151744610013, -5.071681177996089, 
        0.07247207555065144}, {4.141075872305006, -5.035840588998044, 
        0.03623603777532571}}], 
       Polygon3DBox[{{4.282151744610013, -5.071681177996089, 
        0.07247207555065144}, {4.282151744610013, -5.071681177996089, 
        0.07247207555065144}, {4.423227616915018, -5.107521766994134, 
        0.10870811332597718`}, {4.423227616915018, -5.107521766994134, 
        0.10870811332597716`}, {4.282151744610013, -5.071681177996089, 
        0.07247207555065144}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSh84GRDd733ld37+RQe
W6rv43WoEppsOnOb8IE2hthV7b2b9rNP+DhH+D6fg23nyVk+t2Hii/YzgIGA
A4QWOWAS9kH60eu8PX/M2w3LJgg4HC4zS92sInKgBaLe/mc+X/IbBUGHtrc5
p9I8RQ60Qsy3/7p86pSkjYIOXimL9aXyRA4ch7gHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4AdYmgyw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      3.443437302503698, -5.308604206611026, -0.0011863463318433354`}, {
      3.710107463666265, -4.476352259400707, -0.21622988032011106`}, {
      4.556562697496302, -4.691395793388974, 0.0011863463318433354`}, {
      4.289892536333735, -5.523647740599293, 0.21622988032011106`}, {
      3.443437302503698, -5.308604206611026, -0.0011863463318433354`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}, {
       3.710107463666265, -4.476352259400707, -0.21622988032011106`}, {
       4.556562697496302, -4.691395793388974, 0.0011863463318433354`}, {
       4.289892536333735, -5.523647740599293, 0.21622988032011106`}, {
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.89050744445111, -4.4269948118783935`, 
      0.090480997498417}, {3.89050744445111, -4.4269948118783935`, 
      0.09048099749841702}, {3.927004962967407, -4.284663207918929, 
      0.06032066499894468}, {3.9270049629674064`, -4.284663207918929, 
      0.06032066499894467}, {3.89050744445111, -4.4269948118783935`, 
      0.090480997498417}}], 
     Polygon3DBox[{{3.9270049629674064`, -4.284663207918929, 
      0.06032066499894467}, {3.927004962967407, -4.284663207918929, 
      0.06032066499894468}, {3.963502481483703, -4.142331603959464, 
      0.03016033249947236}, {3.963502481483703, -4.142331603959464, 
      0.030160332499472337`}, {3.9270049629674064`, -4.284663207918929, 
      0.06032066499894467}}], 
     Polygon3DBox[{{3.963502481483703, -4.142331603959464, 
      0.030160332499472337`}, {3.963502481483703, -4.142331603959464, 
      0.03016033249947236}, {4., -4., 3.385097232025841*^-17}, {4., -4., 
      0.}, {3.963502481483703, -4.142331603959464, 0.030160332499472337`}}], 
     Polygon3DBox[{{4., -4., 0.}, {4., -4., 1.1527841939415355`*^-17}, {
      4.036497518516296, -3.8576683960405354`, -0.030160332499472316`}, {
      4.036497518516296, -3.8576683960405354`, -0.030160332499472323`}, {
      4., -4., 0.}}], 
     Polygon3DBox[{{
      4.036497518516296, -3.8576683960405354`, -0.030160332499472323`}, {
      4.036497518516296, -3.8576683960405354`, -0.030160332499472316`}, {
      4.072995037032594, -3.715336792081071, -0.06032066499894464}, {
      4.072995037032594, -3.715336792081071, -0.06032066499894466}, {
      4.036497518516296, -3.8576683960405354`, -0.030160332499472323`}}], 
     Polygon3DBox[{{
      4.072995037032594, -3.715336792081071, -0.06032066499894466}, {
      4.072995037032594, -3.715336792081071, -0.06032066499894464}, {
      4.10949255554889, -3.5730051881216065`, -0.09048099749841698}, {
      4.10949255554889, -3.5730051881216065`, -0.09048099749841697}, {
      4.072995037032594, -3.715336792081071, -0.06032066499894466}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4g8S32kDy/g3vgIQW7rYIHbrpr2R7W3G5/KvXn
5MYsfofW7sYDdcqCByq4Hi+LfLTO/ummPycdtvI7HDrqkLB/ogBUfJ49AxgI
OEDpAzs6hLgX7Mm06V3GODteVcChuqTOvvEO34ESiPr90r7MZvu9BBy+v/hT
x7ST90AZxPz9Kz6zXJQrEHAoiq3e1zyV58B1iHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA3taehg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        3.5693581990138235`, -3.909519002501583, -0.09413197296919804}, {
        3.5693581990138235`, -3.909519002501583, -0.09413197296919805}, {
        3.712905466009216, -3.9396793350010553`, -0.06275464864613203}, {
        3.712905466009216, -3.9396793350010553`, -0.06275464864613203}, {
        3.5693581990138235`, -3.909519002501583, -0.09413197296919804}}], 
       Polygon3DBox[{{
        3.712905466009216, -3.9396793350010553`, -0.06275464864613203}, {
        3.712905466009216, -3.9396793350010553`, -0.06275464864613203}, {
        3.8564527330046077`, -3.9698396675005276`, -0.03137732432306604}, {
        3.8564527330046077`, -3.9698396675005276`, -0.03137732432306602}, {
        3.712905466009216, -3.9396793350010553`, -0.06275464864613203}}], 
       Polygon3DBox[{{
        3.8564527330046077`, -3.9698396675005276`, -0.03137732432306602}, {
        3.8564527330046077`, -3.9698396675005276`, -0.03137732432306604}, {
        4., -4., -2.876424847490403*^-17}, {
        4., -4., -5.5403631985048026`*^-18}, {
        3.8564527330046077`, -3.9698396675005276`, -0.03137732432306602}}], 
       Polygon3DBox[{{4., -4., -5.5403631985048026`*^-18}, {
        4., -4., -5.5403631985048026`*^-18}, {
        4.143547266995392, -4.030160332499472, 0.031377324323065996`}, {
        4.143547266995392, -4.030160332499472, 0.031377324323065996`}, {
        4., -4., -5.5403631985048026`*^-18}}], 
       Polygon3DBox[{{4.143547266995392, -4.030160332499472, 
        0.031377324323065996`}, {4.143547266995392, -4.030160332499472, 
        0.031377324323065996`}, {4.287094533990784, -4.060320664998945, 
        0.062754648646132}, {4.287094533990785, -4.060320664998945, 
        0.062754648646132}, {4.143547266995392, -4.030160332499472, 
        0.031377324323065996`}}], 
       Polygon3DBox[{{4.287094533990785, -4.060320664998945, 
        0.062754648646132}, {4.287094533990784, -4.060320664998945, 
        0.062754648646132}, {4.4306418009861765`, -4.090480997498417, 
        0.09413197296919802}, {4.4306418009861765`, -4.090480997498417, 
        0.09413197296919801}, {4.287094533990785, -4.060320664998945, 
        0.062754648646132}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvEfkFPMLOSQ3LF/tuHb
4+xbeB2uFafMLGvhP5CVPdt7g8CG/WdnfHvMfIvP4bXlJh/rQzDxBfsZwEDA
AUofYN28VqP6WNaemZtZ+P5NEnDgerws8pGcwIEMiHp743ROmT+qgg6ix3w3
H7EVOJAJMd/+jBSf1q8dgg7yK7/wLI8ROCALcQ+GONSdGOZA3WmPbi/UnfY4
3GlzDs1fUHdihAPUnfvRww3qTgxxWHgCAMRgk2U=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      3.4598656434649335`, -4.336513814379977, -0.00365097547078104}, {
      3.678850754562714, -3.4825241906231894`, -0.18461297046761505`}, {
      4.5401343565350665`, -3.6634861856200236`, 0.00365097547078104}, {
      4.321149245437287, -4.51747580937681, 0.18461297046761505`}, {
      3.4598656434649335`, -4.336513814379977, -0.00365097547078104}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}, {
       3.678850754562714, -3.4825241906231894`, -0.18461297046761505`}, {
       4.5401343565350665`, -3.6634861856200236`, 0.00365097547078104}, {
       4.321149245437287, -4.51747580937681, 0.18461297046761505`}, {
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.916100877358713, -3.436410638638441, 
      0.07075797978468554}, {3.916100877358713, -3.436410638638441, 
      0.07075797978468555}, {3.9440672515724753`, -3.290940425758961, 
      0.0471719865231237}, {3.9440672515724753`, -3.290940425758961, 
      0.047171986523123696`}, {3.916100877358713, -3.436410638638441, 
      0.07075797978468554}}], 
     Polygon3DBox[{{3.9440672515724753`, -3.290940425758961, 
      0.047171986523123696`}, {3.9440672515724753`, -3.290940425758961, 
      0.0471719865231237}, {3.9720336257862376`, -3.1454702128794807`, 
      0.023585993261561872`}, {3.9720336257862376`, -3.1454702128794807`, 
      0.023585993261561848`}, {3.9440672515724753`, -3.290940425758961, 
      0.047171986523123696`}}], 
     Polygon3DBox[{{3.9720336257862376`, -3.1454702128794807`, 
      0.023585993261561848`}, {3.9720336257862376`, -3.1454702128794807`, 
      0.023585993261561872`}, {4., -3., 2.7446916554762127`*^-17}, {4., -3., 
      0.}, {3.9720336257862376`, -3.1454702128794807`, 
      0.023585993261561848`}}], 
     Polygon3DBox[{{4., -3., 0.}, {4., -3., 9.989774703002288*^-18}, {
      4.027966374213762, -2.8545297871205197`, -0.023585993261561834`}, {
      4.027966374213762, -2.8545297871205197`, -0.02358599326156184}, {
      4., -3., 0.}}], 
     Polygon3DBox[{{
      4.027966374213762, -2.8545297871205197`, -0.02358599326156184}, {
      4.027966374213762, -2.8545297871205197`, -0.023585993261561834`}, {
      4.055932748427525, -2.709059574241039, -0.04717198652312368}, {
      4.055932748427525, -2.709059574241039, -0.04717198652312369}, {
      4.027966374213762, -2.8545297871205197`, -0.02358599326156184}}], 
     Polygon3DBox[{{
      4.055932748427525, -2.709059574241039, -0.04717198652312369}, {
      4.055932748427525, -2.709059574241039, -0.04717198652312368}, {
      4.083899122641287, -2.563589361361559, -0.07075797978468552}, {
      4.083899122641287, -2.563589361361559, -0.07075797978468552}, {
      4.055932748427525, -2.709059574241039, -0.04717198652312369}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ61N2GTTgi/w7sFKXeO1HIfyDOWfmkou8l+z+Wp
isW9/A7zD7yddCOY64Dd+3Nmb9VW2N97eWrCzmP8DgEPyjzfaHJCxWfYM4CB
gAOE5jiwWSY8okAhxUawe5b5YhkBh43ynduEr7EdsIGo368kZprvZingkGgv
lKu+hvWALcT8/cYLzy97GSrgIBQ/W9m6ieVALsQ9GOJQd2KYA3Xnfpi9G6D2
Qt25H4c798D85Q/1F9SdGOEAdac9erhB3YkhDgtPADECmQ4=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        3.5631485346619574`, -2.9292420202153147`, -0.08157270087961327}, {
        3.5631485346619574`, -2.929242020215314, -0.08157270087961328}, {
        3.708765689774638, -2.9528280134768763`, -0.05438180058640885}, {
        3.708765689774638, -2.9528280134768763`, -0.05438180058640885}, {
        3.5631485346619574`, -2.9292420202153147`, -0.08157270087961327}}], 
       Polygon3DBox[{{
        3.708765689774638, -2.9528280134768763`, -0.05438180058640885}, {
        3.708765689774638, -2.9528280134768763`, -0.05438180058640885}, {
        3.854382844887319, -2.976414006738438, -0.027190900293204444`}, {
        3.854382844887319, -2.976414006738438, -0.02719090029320443}, {
        3.708765689774638, -2.9528280134768763`, -0.05438180058640885}}], 
       Polygon3DBox[{{
        3.854382844887319, -2.976414006738438, -0.02719090029320443}, {
        3.854382844887319, -2.976414006738438, -0.027190900293204444`}, {
        4., -3., -2.4457985716740727`*^-17}, {
        4., -3., -4.332676672872413*^-18}, {
        3.854382844887319, -2.976414006738438, -0.02719090029320443}}], 
       Polygon3DBox[{{4., -3., -4.332676672872413*^-18}, {
        4., -3., -4.332676672872413*^-18}, {
        4.145617155112681, -3.0235859932615616`, 0.027190900293204413`}, {
        4.145617155112681, -3.0235859932615616`, 0.02719090029320441}, {
        4., -3., -4.332676672872413*^-18}}], 
       Polygon3DBox[{{4.145617155112681, -3.0235859932615616`, 
        0.02719090029320441}, {4.145617155112681, -3.0235859932615616`, 
        0.027190900293204413`}, {4.291234310225362, -3.0471719865231237`, 
        0.05438180058640883}, {4.291234310225362, -3.0471719865231237`, 
        0.05438180058640884}, {4.145617155112681, -3.0235859932615616`, 
        0.02719090029320441}}], 
       Polygon3DBox[{{4.291234310225362, -3.0471719865231237`, 
        0.05438180058640884}, {4.291234310225362, -3.0471719865231237`, 
        0.05438180058640883}, {4.436851465338043, -3.0707579797846853`, 
        0.08157270087961326}, {4.436851465338043, -3.0707579797846853`, 
        0.08157270087961324}, {4.291234310225362, -3.0471719865231237`, 
        0.05438180058640884}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPvuBEqu2S58ebtmvdH9C
RO9qXgfnIyreKfPZD3z05ch7d331/on5HmuOXeVzUEqapLrpPEx89n4GMBBw
gNAcBzymbYz+aJy+x/zE7ZUyUwUc7s3NveVrwHHgHUS9ff6E7cGWWoIOe61v
b5mdwHHgA8R8+2URk/+G7hd0mH3To//lBI4DxRD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAMplplI=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}, {
      3.6470476573032444`, -2.492831381576873, -0.1523306806642988}, {
      4.52075058797933, -2.634347341146244, 0.010814721094927732`}, {
      4.352952342696756, -3.507168618423127, 0.1523306806642988}, {
      3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}, {
       3.6470476573032444`, -2.492831381576873, -0.1523306806642988}, {
       4.52075058797933, -2.634347341146244, 0.010814721094927732`}, {
       4.352952342696756, -3.507168618423127, 0.1523306806642988}, {
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}}]}}}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.943166839324925, -2.4437352115023008`, 
      0.048672928006126485`}, {3.9431668393249253`, -2.4437352115023008`, 
      0.048672928006126506`}, {3.9621112262166167`, -2.295823474334867, 
      0.032448618670751}, {3.9621112262166167`, -2.2958234743348673`, 
      0.032448618670750995`}, {3.943166839324925, -2.4437352115023008`, 
      0.048672928006126485`}}], 
     Polygon3DBox[{{3.9621112262166167`, -2.2958234743348673`, 
      0.032448618670750995`}, {3.9621112262166167`, -2.295823474334867, 
      0.032448618670751}, {3.9810556131083086`, -2.1479117371674334`, 
      0.016224309335375515`}, {3.981055613108308, -2.1479117371674334`, 
      0.016224309335375497`}, {3.9621112262166167`, -2.2958234743348673`, 
      0.032448618670750995`}}], 
     Polygon3DBox[{{3.981055613108308, -2.1479117371674334`, 
      0.016224309335375497`}, {3.9810556131083086`, -2.1479117371674334`, 
      0.016224309335375515`}, {4., -2., 2.0807016348335987`*^-17}, {4., -2., 
      0.}, {3.981055613108308, -2.1479117371674334`, 0.016224309335375497`}}],
      Polygon3DBox[{{4., -2., 0.}, {4., -2., 8.798615159819488*^-18}, {
      4.018944386891691, -1.8520882628325666`, -0.016224309335375484`}, {
      4.018944386891691, -1.8520882628325666`, -0.01622430933537549}, {
      4., -2., 0.}}], 
     Polygon3DBox[{{
      4.018944386891691, -1.8520882628325666`, -0.01622430933537549}, {
      4.018944386891691, -1.8520882628325666`, -0.016224309335375484`}, {
      4.037888773783384, -1.704176525665133, -0.03244861867075098}, {
      4.037888773783384, -1.704176525665133, -0.03244861867075099}, {
      4.018944386891691, -1.8520882628325666`, -0.01622430933537549}}], 
     Polygon3DBox[{{
      4.037888773783384, -1.704176525665133, -0.03244861867075099}, {
      4.037888773783384, -1.704176525665133, -0.03244861867075098}, {
      4.056833160675075, -1.5562647884976992`, -0.04867292800612648}, {
      4.056833160675075, -1.5562647884976994`, -0.04867292800612647}, {
      4.037888773783384, -1.704176525665133, -0.03244861867075099}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP402Ydvdje/Q+Lj19xHe5gPHHf/Wbzi9Qr779vv
xqVv4ndwdJq76UYs0wGD1t/fpeYusP99O2+98U1+B4WFfpFv9Bih4hPsGcBA
wAFCMxxY0vHDvWlDtA3TJA+NNGEBhwN7k3zVF/3drwdRv59VZWLAGTUBh/rq
o7P8XH7v14eYv599280KIysBB3tLjRelz37sPwpxD1zcDioOdSeGOVB37ofZ
ux9qL9Sd+3G4cw+6v6DuhIeDAzQcoO60Rw83qDsxxGHhCQBDpaoH
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        3.5584469708890527`, -1.9513270719938736`, -0.07184614507583269}, {
        3.5584469708890527`, -1.9513270719938736`, -0.07184614507583269}, {
        3.7056313139260353`, -1.967551381329249, -0.047897430050555134`}, {
        3.7056313139260353`, -1.967551381329249, -0.047897430050555134`}, {
        3.5584469708890527`, -1.9513270719938736`, -0.07184614507583269}}], 
       Polygon3DBox[{{
        3.7056313139260353`, -1.967551381329249, -0.047897430050555134`}, {
        3.7056313139260353`, -1.967551381329249, -0.047897430050555134`}, {
        3.8528156569630174`, -1.9837756906646244`, -0.023948715025277578`}, {
        3.8528156569630174`, -1.9837756906646244`, -0.02394871502527757}, {
        3.7056313139260353`, -1.967551381329249, -0.047897430050555134`}}], 
       Polygon3DBox[{{
        3.8528156569630174`, -1.9837756906646244`, -0.02394871502527757}, {
        3.8528156569630174`, -1.9837756906646244`, -0.023948715025277578`}, {
        4., -2., -2.0705967161891344`*^-17}, {
        4., -2., -2.980357274391618*^-18}, {
        3.8528156569630174`, -1.9837756906646244`, -0.02394871502527757}}], 
       Polygon3DBox[{{4., -2., -2.980357274391618*^-18}, {
        4., -2., -2.980357274391618*^-18}, {
        4.147184343036982, -2.0162243093353753`, 0.023948715025277553`}, {
        4.147184343036982, -2.0162243093353753`, 0.023948715025277553`}, {
        4., -2., -2.980357274391618*^-18}}], 
       Polygon3DBox[{{4.147184343036982, -2.0162243093353753`, 
        0.023948715025277553`}, {4.147184343036982, -2.0162243093353753`, 
        0.023948715025277553`}, {4.294368686073964, -2.032448618670751, 
        0.04789743005055511}, {4.294368686073964, -2.032448618670751, 
        0.04789743005055512}, {4.147184343036982, -2.0162243093353753`, 
        0.023948715025277553`}}], 
       Polygon3DBox[{{4.294368686073964, -2.032448618670751, 
        0.04789743005055512}, {4.294368686073964, -2.032448618670751, 
        0.04789743005055511}, {4.441553029110947, -2.0486729280061264`, 
        0.07184614507583269}, {4.441553029110947, -2.0486729280061264`, 
        0.07184614507583267}, {4.294368686073964, -2.032448618670751, 
        0.04789743005055512}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/3Zx8q9G5K2bTf+cgh
dqWlvA7XlB00xKv/758Q4cTP3LZiv2LSQ+aJl/gcXgsqTOneCxOfsZ8BDAQc
IDTDgfIvieZr81P2vPfjr9s+TcCB6/t7UytFhgO9EPX29+bK/cnTFXQQfXc/
u8SJ4UA/xHz7c290q9SOCDrIPz2/cF0yw4EsiHswxKHutL+PZg7Unfbo9kLd
aY/DnTZKaP6CuhMeDteh4QB15/5UtHCDunM/rvAEAGxLlYo=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}, {
      3.615280131564128, -1.5075918604915728`, -0.12051907308195917`}, {
      4.4983861897860224`, -1.6049377165038257`, 0.023173217069706202`}, {
      4.384719868435872, -2.492408139508427, 0.12051907308195917`}, {
      3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}, {
       3.615280131564128, -1.5075918604915728`, -0.12051907308195917`}, {
       4.4983861897860224`, -1.6049377165038257`, 0.023173217069706202`}, {
       4.384719868435872, -2.492408139508427, 0.12051907308195917`}, {
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}}]}}}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.9713017628409095`, -1.448397910860311, 
      0.024813801000032897`}, {3.9713017628409095`, -1.448397910860311, 
      0.024813801000032915`}, {3.98086784189394, -1.2989319405735407`, 
      0.016542534000021945`}, {3.9808678418939394`, -1.2989319405735409`, 
      0.016542534000021935`}, {3.9713017628409095`, -1.448397910860311, 
      0.024813801000032897`}}], 
     Polygon3DBox[{{3.9808678418939394`, -1.2989319405735409`, 
      0.016542534000021935`}, {3.98086784189394, -1.2989319405735407`, 
      0.016542534000021945`}, {3.9904339209469697`, -1.1494659702867704`, 
      0.00827126700001098}, {3.9904339209469697`, -1.1494659702867704`, 
      0.008271267000010967}, {3.9808678418939394`, -1.2989319405735409`, 
      0.016542534000021935`}}], 
     Polygon3DBox[{{3.9904339209469697`, -1.1494659702867704`, 
      0.008271267000010967}, {3.9904339209469697`, -1.1494659702867704`, 
      0.00827126700001098}, {4., -1.0000000000000002`, 
      1.4164696761907403`*^-17}, {4., -1., 0.}, {
      3.9904339209469697`, -1.1494659702867704`, 0.008271267000010967}}], 
     Polygon3DBox[{{4., -1., 0.}, {4., -1., 8.042729384417789*^-18}, {
      4.00956607905303, -0.8505340297132297, -0.008271267000010959}, {
      4.00956607905303, -0.8505340297132297, -0.008271267000010964}, {4., -1.,
       0.}}], 
     Polygon3DBox[{{
      4.00956607905303, -0.8505340297132297, -0.008271267000010964}, {
      4.00956607905303, -0.8505340297132297, -0.008271267000010959}, {
      4.019132158106061, -0.7010680594264593, -0.016542534000021925`}, {
      4.019132158106061, -0.7010680594264593, -0.01654253400002193}, {
      4.00956607905303, -0.8505340297132297, -0.008271267000010964}}], 
     Polygon3DBox[{{
      4.019132158106061, -0.7010680594264593, -0.01654253400002193}, {
      4.019132158106061, -0.7010680594264593, -0.016542534000021925`}, {
      4.028698237159091, -0.551602089139689, -0.024813801000032894`}, {
      4.028698237159091, -0.5516020891396891, -0.02481380100003289}, {
      4.019132158106061, -0.7010680594264593, -0.01654253400002193}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHacfv625VF+B75rqz0X63zfX5yj/P9kxkz7Bn5T
24s3+B24nhy/nXPiy/7Fc8VXtX2YYH+gfda8jDf8DqyfHueapXyCijfYM4CB
gAOE/rA/eWONdLe1j43Cnk0bTnMKOHyXtlCZbP56/0KI+v0OFamJ04UFHN6Z
F3io5T/bvwhi/v4EEwmhZFkBh2fBK3J2Lnu4vxDiHrj4E6g41J1wc95CzYG6
cz/M3m9Qe6Hu3I/DnXtg/mKB+gvqTng4cELDAepOe1i48ULDDepOe1zhCQAe
eKll
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        3.555510159655889, -0.9751861989999671, -0.06567386931495228}, {
        3.555510159655889, -0.9751861989999671, -0.06567386931495228}, {
        3.7036734397705926`, -0.9834574659999781, -0.04378257954330152}, {
        3.7036734397705926`, -0.9834574659999781, -0.043782579543301524`}, {
        3.555510159655889, -0.9751861989999671, -0.06567386931495228}}], 
       Polygon3DBox[{{
        3.7036734397705926`, -0.9834574659999781, -0.043782579543301524`}, {
        3.7036734397705926`, -0.9834574659999781, -0.04378257954330152}, {
        3.8518367198852963`, -0.991728732999989, -0.021891289771650776`}, {
        3.8518367198852963`, -0.991728732999989, -0.021891289771650762`}, {
        3.7036734397705926`, -0.9834574659999781, -0.043782579543301524`}}], 
       Polygon3DBox[{{
        3.8518367198852963`, -0.991728732999989, -0.021891289771650762`}, {
        3.8518367198852963`, -0.991728732999989, -0.021891289771650776`}, {
        4., -1., -1.7722216393953723`*^-17}, {
        4., -1., -1.519407098468484*^-18}, {
        3.8518367198852963`, -0.991728732999989, -0.021891289771650762`}}], 
       Polygon3DBox[{{4., -1., -1.519407098468484*^-18}, {
        4., -1., -1.519407098468484*^-18}, {
        4.148163280114703, -1.008271267000011, 0.021891289771650755`}, {
        4.148163280114703, -1.008271267000011, 0.02189128977165075}, {
        4., -1., -1.519407098468484*^-18}}], 
       Polygon3DBox[{{4.148163280114703, -1.008271267000011, 
        0.02189128977165075}, {4.148163280114703, -1.008271267000011, 
        0.021891289771650755`}, {4.296326560229407, -1.0165425340000218`, 
        0.04378257954330151}, {4.296326560229407, -1.0165425340000218`, 
        0.04378257954330152}, {4.148163280114703, -1.008271267000011, 
        0.02189128977165075}}], 
       Polygon3DBox[{{4.296326560229407, -1.0165425340000218`, 
        0.04378257954330152}, {4.296326560229407, -1.0165425340000218`, 
        0.04378257954330151}, {4.4444898403441115`, -1.024813801000033, 
        0.06567386931495227}, {4.444489840344111, -1.024813801000033, 
        0.06567386931495227}, {4.296326560229407, -1.0165425340000218`, 
        0.04378257954330152}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7vv3PlxQaGCxv2m7GH
d8kv5HUQdl5/qrri/f7qY93TVmct2z+7Wfto/wU+h86F4U9t98DEp+1nAAMB
Bwj9YX+aqvwKy3VJe4zssmR3TBdwsNYP4X2o+GF/JUS9fWrNFasCfUGH8rgV
UoecP+yvgphvP32XXYTGcUGHTb1/1Benfth/G+Ie+xlo4lB3YpgDdae9MZq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAKHjriA=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}, {
      3.5842083968149794`, -0.5267882881396561, -0.09048767031498518}, {
      4.473188077503202, -0.5764158901397218, 0.04086006831491938}, {
      4.415791603185021, -1.473211711860344, 0.09048767031498518}, {
      3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}, {
       3.5842083968149794`, -0.5267882881396561, -0.09048767031498518}, {
       4.473188077503202, -0.5764158901397218, 0.04086006831491938}, {
       4.415791603185021, -1.473211711860344, 0.09048767031498518}, {
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}}]}}}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4., -0.4499999999999999, 0.}, {4., -0.4499999999999999, 
      1.556686749278627*^-17}, {4., -0.29999999999999993`, 
      1.2972389577321892`*^-17}, {4., -0.3, 0.}, {4., -0.4499999999999999, 
      0.}}], Polygon3DBox[{{4., -0.3, 0.}, {4., -0.29999999999999993`, 
      1.2972389577321892`*^-17}, {4., -0.15000000000000005`, 
      1.0377911661857515`*^-17}, {4., -0.15, 0.}, {4., -0.3, 0.}}], 
     Polygon3DBox[{{4., -0.15, 0.}, {4., -0.15000000000000005`, 
      1.0377911661857515`*^-17}, {4., -1.1102230246251563`*^-16, 
      7.783433746393137*^-18}, {4., 0., 0.}, {4., -0.15, 0.}}], 
     Polygon3DBox[{{4., 0., 0.}, {4., 0., 7.783433746393135*^-18}, {4., 
      0.14999999999999994`, 5.1889558309287576`*^-18}, {4., 
      0.14999999999999994`, 0.}, {4., 0., 0.}}], 
     Polygon3DBox[{{4., 0.14999999999999994`, 0.}, {4., 0.14999999999999994`, 
      5.1889558309287576`*^-18}, {4., 0.2999999999999999, 
      2.594477915464379*^-18}, {4., 0.29999999999999993`, 0.}, {4., 
      0.14999999999999994`, 0.}}], 
     Polygon3DBox[{{4., 0.29999999999999993`, 0.}, {4., 0.2999999999999999, 
      2.5944779154643795`*^-18}, {4., 0.44999999999999984`, 
      1.296202103383515*^-33}, {4., 0.4499999999999998, 0.}, {4., 
      0.29999999999999993`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcDh9BgTu7GdAAQIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIATatHNg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{3.554510871386728, 0., -0.06355655975104223}, {
        3.554510871386728, 5.5109105961630883`*^-17, -0.06355655975104223}, {
        3.7030072475911524`, 
        4.592425496802573*^-17, -0.042371039834028144`}, {3.703007247591152, 
        9.184850993605147*^-18, -0.04237103983402815}, {3.554510871386728, 
        0., -0.06355655975104223}}], 
       Polygon3DBox[{{3.703007247591152, 
        9.184850993605147*^-18, -0.04237103983402815}, {3.7030072475911524`, 
        4.592425496802573*^-17, -0.042371039834028144`}, {3.851503623795576, 
        3.6739403974420595`*^-17, -0.021185519917014083`}, {3.851503623795576,
         1.8369701987210294`*^-17, -0.021185519917014076`}, {
        3.703007247591152, 9.184850993605147*^-18, -0.04237103983402815}}], 
       Polygon3DBox[{{3.851503623795576, 
        1.8369701987210294`*^-17, -0.021185519917014076`}, {3.851503623795576,
         3.6739403974420595`*^-17, -0.021185519917014083`}, {4., 
        2.7554552980815448`*^-17, -1.5680434667015906`*^-17}, {4., 
        2.7554552980815442`*^-17, 0.}, {3.851503623795576, 
        1.8369701987210294`*^-17, -0.021185519917014076`}}], 
       Polygon3DBox[{{4., 2.7554552980815442`*^-17, 0.}, {4., 
        2.7554552980815442`*^-17, 0.}, {4.148496376204424, 
        1.8369701987210297`*^-17, 0.02118551991701407}, {4.148496376204424, 
        3.673940397442059*^-17, 0.02118551991701407}, {4., 
        2.7554552980815442`*^-17, 0.}}], 
       Polygon3DBox[{{4.148496376204424, 3.673940397442059*^-17, 
        0.02118551991701407}, {4.148496376204424, 1.8369701987210297`*^-17, 
        0.02118551991701407}, {4.296992752408848, 9.18485099360515*^-18, 
        0.04237103983402814}, {4.296992752408848, 4.592425496802573*^-17, 
        0.042371039834028144`}, {4.148496376204424, 3.673940397442059*^-17, 
        0.02118551991701407}}], 
       Polygon3DBox[{{4.296992752408848, 4.592425496802573*^-17, 
        0.042371039834028144`}, {4.296992752408848, 9.184850993605152*^-18, 
        0.04237103983402814}, {4.445489128613271, 4.588754872883257*^-33, 
        0.06355655975104221}, {4.445489128613271, 5.510910596163088*^-17, 
        0.0635565597510422}, {4.296992752408848, 4.592425496802573*^-17, 
        0.042371039834028144`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbn909dnM/jwAAF7NsmK9q5btivz9XlfGg+L1x8
y6cjOis2Lt0vwXpU8eF5PjTxqfshPAG4uMMpP1UekaQ9JbWy+fwzEOKbIOrt
X/yyuidnIAgX3wwx3z6mIsJX7wRCnBXiHgxxqDsxzIG60x7dXqg77XG40wbd
X1B37jdACweoO/d7oIUb1J37cYUnALFVY88=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      3.554510871386728, -0.4499999999999999, -0.06355655975104223}, {
      3.554510871386728, 0.4499999999999999, -0.06355655975104223}, {
      4.445489128613271, 0.4499999999999999, 0.06355655975104223}, {
      4.445489128613271, -0.4499999999999999, 0.06355655975104223}, {
      3.554510871386728, -0.4499999999999999, -0.06355655975104223}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}, {
       3.554510871386728, 0.4499999999999999, -0.06355655975104223}, {
       4.445489128613271, 0.4499999999999999, 0.06355655975104223}, {
       4.445489128613271, -0.4499999999999999, 0.06355655975104223}, {
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.028698237159091, 
      0.5516020891396889, -0.024813801000032897`}, {4.028698237159091, 
      0.5516020891396889, -0.02481380100003288}, {4.019132158106061, 
      0.7010680594264593, -0.016542534000021918`}, {4.019132158106061, 
      0.7010680594264592, -0.016542534000021935`}, {4.028698237159091, 
      0.5516020891396889, -0.024813801000032897`}}], 
     Polygon3DBox[{{4.019132158106061, 
      0.7010680594264592, -0.016542534000021935`}, {4.019132158106061, 
      0.7010680594264593, -0.016542534000021918`}, {4.00956607905303, 
      0.8505340297132296, -0.008271267000010959}, {4.00956607905303, 
      0.8505340297132296, -0.008271267000010967}, {4.019132158106061, 
      0.7010680594264592, -0.016542534000021935`}}], 
     Polygon3DBox[{{4.00956607905303, 
      0.8505340297132296, -0.008271267000010967}, {4.00956607905303, 
      0.8505340297132296, -0.008271267000010959}, {4., 0.9999999999999999, 
      1.9207620069281777`*^-18}, {4., 1., 0.}, {4.00956607905303, 
      0.8505340297132296, -0.008271267000010967}}], 
     Polygon3DBox[{{4., 1., 0.}, {4., 1., 8.042729384417789*^-18}, {
      3.9904339209469697`, 1.1494659702867702`, 0.00827126700001097}, {
      3.9904339209469697`, 1.1494659702867702`, 0.008271267000010964}, {4., 
      1., 0.}}], 
     Polygon3DBox[{{3.9904339209469697`, 1.1494659702867702`, 
      0.008271267000010964}, {3.9904339209469697`, 1.1494659702867702`, 
      0.00827126700001097}, {3.9808678418939394`, 1.2989319405735407`, 
      0.01654253400002193}, {3.9808678418939394`, 1.2989319405735407`, 
      0.01654253400002193}, {3.9904339209469697`, 1.1494659702867702`, 
      0.008271267000010964}}], 
     Polygon3DBox[{{3.9808678418939394`, 1.2989319405735407`, 
      0.01654253400002193}, {3.9808678418939394`, 1.2989319405735407`, 
      0.01654253400002193}, {3.9713017628409095`, 1.448397910860311, 
      0.024813801000032894`}, {3.9713017628409095`, 1.4483979108603109`, 
      0.02481380100003289}, {3.9808678418939394`, 1.2989319405735407`, 
      0.01654253400002193}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4wkRBKlhVweBK8Imfnsof2xTnK/09mzNzvUJGa
OF1YwOGteYGHWv4z+8VzxVe1fZiwX2HPpg2nOQUcvklbqEw2fw0Vb9jPAAYC
DhD6g33yxhrpbmufPQfaZ83LeMPvwPLpca5Zyif7hRD19g38prYXb/A7cD45
fjvnxBf7RRDz7R2nn79teZTfgffaas/FOt/tCyHugYvzQcWh7oSbwwU1B+pO
e5i9rFB7oe60x+FOG5i/vkP9BXUnPBzeQcMB6s79sHB7Bg03qDv34wpPABv9
oRE=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{3.555510159655889, 
        0.9751861989999671, -0.06567386931495228}, {3.555510159655889, 
        0.9751861989999672, -0.06567386931495228}, {3.7036734397705926`, 
        0.9834574659999781, -0.04378257954330152}, {3.7036734397705926`, 
        0.9834574659999781, -0.043782579543301524`}, {3.555510159655889, 
        0.9751861989999671, -0.06567386931495228}}], 
       Polygon3DBox[{{3.7036734397705926`, 
        0.9834574659999781, -0.043782579543301524`}, {3.7036734397705926`, 
        0.9834574659999781, -0.04378257954330152}, {3.8518367198852963`, 
        0.9917287329999891, -0.02189128977165077}, {3.8518367198852963`, 
        0.9917287329999891, -0.021891289771650762`}, {3.7036734397705926`, 
        0.9834574659999781, -0.043782579543301524`}}], 
       Polygon3DBox[{{3.8518367198852963`, 
        0.9917287329999891, -0.021891289771650762`}, {3.8518367198852963`, 
        0.9917287329999891, -0.02189128977165077}, {4., 
        1., -1.4683402197016756`*^-17}, {4., 1., 1.519407098468484*^-18}, {
        3.8518367198852963`, 0.9917287329999891, -0.021891289771650762`}}], 
       Polygon3DBox[{{4., 1., 1.519407098468484*^-18}, {4., 1., 
        1.519407098468484*^-18}, {4.148163280114703, 1.008271267000011, 
        0.021891289771650755`}, {4.148163280114703, 1.008271267000011, 
        0.02189128977165076}, {4., 1., 1.519407098468484*^-18}}], 
       Polygon3DBox[{{4.148163280114703, 1.008271267000011, 
        0.02189128977165076}, {4.148163280114703, 1.008271267000011, 
        0.021891289771650755`}, {4.296326560229407, 1.016542534000022, 
        0.04378257954330151}, {4.296326560229407, 1.016542534000022, 
        0.04378257954330152}, {4.148163280114703, 1.008271267000011, 
        0.02189128977165076}}], 
       Polygon3DBox[{{4.296326560229407, 1.016542534000022, 
        0.04378257954330152}, {4.296326560229407, 1.016542534000022, 
        0.04378257954330151}, {4.4444898403441115`, 1.024813801000033, 
        0.06567386931495227}, {4.444489840344111, 1.024813801000033, 
        0.06567386931495227}, {4.296326560229407, 1.016542534000022, 
        0.04378257954330152}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7b37nyYgPDhQ37zdjD
u+QX8joIO68/VV3x3r76WPe01VnL9s9u1j7af4HPoXNh+FPbPTDxafsZwEDA
AUJ/sE9TlV9huS5pj5FdluyO6QIO1vohvA8VP9hXQtTbp9ZcsSrQF3Qoj1sh
dcj5g30VxHz76bvsIjSOCzps6v2jvjj1g/1tiHvsZ6CJQ92JYQ7UnfbGaPZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAchimoA==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.5842083968149794`, 
      0.5267882881396561, -0.09048767031498518}, {3.5268119224967984`, 
      1.4235841098602782`, -0.04086006831491938}, {4.415791603185021, 
      1.473211711860344, 0.09048767031498518}, {4.473188077503202, 
      0.5764158901397218, 0.04086006831491938}, {3.5842083968149794`, 
      0.5267882881396561, -0.09048767031498518}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.5842083968149794`, 
       0.5267882881396561, -0.09048767031498518}, {3.5268119224967984`, 
       1.4235841098602782`, -0.04086006831491938}, {4.415791603185021, 
       1.473211711860344, 0.09048767031498518}, {4.473188077503202, 
       0.5764158901397218, 0.04086006831491938}, {3.5842083968149794`, 
       0.5267882881396561, -0.09048767031498518}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.056833160675075, 
      1.5562647884976992`, -0.048672928006126485`}, {4.056833160675075, 
      1.5562647884976992`, -0.048672928006126465`}, {4.037888773783384, 
      1.704176525665133, -0.032448618670750974`}, {4.037888773783384, 
      1.704176525665133, -0.032448618670750995`}, {4.056833160675075, 
      1.5562647884976992`, -0.048672928006126485`}}], 
     Polygon3DBox[{{4.037888773783384, 
      1.704176525665133, -0.032448618670750995`}, {4.037888773783384, 
      1.704176525665133, -0.032448618670750974`}, {4.018944386891691, 
      1.8520882628325663`, -0.016224309335375494`}, {4.018944386891691, 
      1.8520882628325663`, -0.016224309335375497`}, {4.037888773783384, 
      1.704176525665133, -0.032448618670750995`}}], 
     Polygon3DBox[{{4.018944386891691, 
      1.8520882628325663`, -0.016224309335375497`}, {4.018944386891691, 
      1.8520882628325663`, -0.016224309335375494`}, {4., 
      2., -3.2097860286970067`*^-18}, {4., 2., 0.}, {4.018944386891691, 
      1.8520882628325663`, -0.016224309335375497`}}], 
     Polygon3DBox[{{4., 2., 0.}, {4., 2., 8.798615159819488*^-18}, {
      3.9810556131083086`, 2.1479117371674334`, 0.016224309335375497`}, {
      3.981055613108308, 2.1479117371674334`, 0.01622430933537549}, {4., 2., 
      0.}}], Polygon3DBox[{{3.981055613108308, 2.1479117371674334`, 
      0.01622430933537549}, {3.9810556131083086`, 2.1479117371674334`, 
      0.016224309335375497`}, {3.9621112262166167`, 2.295823474334867, 
      0.03244861867075098}, {3.9621112262166167`, 2.295823474334867, 
      0.03244861867075099}, {3.981055613108308, 2.1479117371674334`, 
      0.01622430933537549}}], 
     Polygon3DBox[{{3.9621112262166167`, 2.295823474334867, 
      0.03244861867075099}, {3.9621112262166167`, 2.295823474334867, 
      0.03244861867075098}, {3.943166839324925, 2.4437352115023008`, 
      0.04867292800612648}, {3.943166839324925, 2.4437352115023008`, 
      0.04867292800612647}, {3.9621112262166167`, 2.295823474334867, 
      0.03244861867075099}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGbfdrPCyErAwc5S40Xpsx/2x91/Fq94vWI/q8rE
gDNqAg711Udn+bn8tjdo/f1dau6C/UyTPDTShAUc9u9N8lVf9BcqPmE/AxgI
OEBoBoclHT/cmzZE7/l9O2+98U1+B4WFfpFv9Bgd9CDq7b9vvxuXvonfwcFp
7qYbsUwO+hDz7T9N9uGb3c3vkPj4NffRHmaHoxD3YIhD3Qk3xxFqDtSd9uj2
Qt1pj8OdNjB/HYD6C+pOjHCAunM/LNzsoeEGded+XOEJAFg6osg=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{3.5584469708890527`, 
        1.9513270719938736`, -0.07184614507583269}, {3.5584469708890527`, 
        1.9513270719938736`, -0.07184614507583269}, {3.7056313139260353`, 
        1.9675513813292491`, -0.04789743005055512}, {3.7056313139260353`, 
        1.9675513813292491`, -0.047897430050555134`}, {3.5584469708890527`, 
        1.9513270719938736`, -0.07184614507583269}}], 
       Polygon3DBox[{{3.7056313139260353`, 
        1.9675513813292491`, -0.047897430050555134`}, {3.7056313139260353`, 
        1.9675513813292491`, -0.04789743005055512}, {3.8528156569630174`, 
        1.9837756906646244`, -0.02394871502527757}, {3.8528156569630174`, 
        1.9837756906646244`, -0.023948715025277564`}, {3.7056313139260353`, 
        1.9675513813292491`, -0.047897430050555134`}}], 
       Polygon3DBox[{{3.8528156569630174`, 
        1.9837756906646244`, -0.023948715025277564`}, {3.8528156569630174`, 
        1.9837756906646244`, -0.02394871502527757}, {4., 
        2., -1.4745252613108107`*^-17}, {4., 2., 2.980357274391618*^-18}, {
        3.8528156569630174`, 1.9837756906646244`, -0.023948715025277564`}}], 
       Polygon3DBox[{{4., 2., 2.980357274391618*^-18}, {4., 2., 
        2.980357274391618*^-18}, {4.147184343036982, 2.0162243093353753`, 
        0.02394871502527756}, {4.147184343036982, 2.0162243093353753`, 
        0.02394871502527756}, {4., 2., 2.980357274391618*^-18}}], 
       Polygon3DBox[{{4.147184343036982, 2.0162243093353753`, 
        0.02394871502527756}, {4.147184343036982, 2.0162243093353753`, 
        0.02394871502527756}, {4.294368686073964, 2.032448618670751, 
        0.04789743005055511}, {4.294368686073964, 2.032448618670751, 
        0.047897430050555134`}, {4.147184343036982, 2.0162243093353753`, 
        0.02394871502527756}}], 
       Polygon3DBox[{{4.294368686073964, 2.032448618670751, 
        0.047897430050555134`}, {4.294368686073964, 2.032448618670751, 
        0.04789743005055511}, {4.441553029110947, 2.0486729280061264`, 
        0.07184614507583269}, {4.441553029110947, 2.0486729280061264`, 
        0.07184614507583267}, {4.294368686073964, 2.032448618670751, 
        0.047897430050555134`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/tsw8VejelbNrvfOQQ
u9JSXodryg4a4tX/7SdEOPEzt63Yr5j0kHniJT6H14IKU7r3wsRn7GcAAwEH
CM3gUP4l0Xxtfsqe9378ddunCThwfX9vaqXI4NALUW9/b67cnzxdQQfRd/ez
S5wYHPoh5tufe6NbpXZE0EH+6fmF65IZHLIg7sEQh7rT/j6aOVB32qPbC3Wn
PQ532iih+QvqTng4XIeGA9Sd+1PRwg3qzv24whMAPICOCg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.615280131564128, 
      1.5075918604915728`, -0.12051907308195917`}, {3.501613810213978, 
      2.3950622834961743`, -0.023173217069706202`}, {4.384719868435872, 
      2.492408139508427, 0.12051907308195917`}, {4.4983861897860224`, 
      1.6049377165038257`, 0.023173217069706202`}, {3.615280131564128, 
      1.5075918604915728`, -0.12051907308195917`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.615280131564128, 
       1.5075918604915728`, -0.12051907308195917`}, {3.501613810213978, 
       2.3950622834961743`, -0.023173217069706202`}, {4.384719868435872, 
       2.492408139508427, 0.12051907308195917`}, {4.4983861897860224`, 
       1.6049377165038257`, 0.023173217069706202`}, {3.615280131564128, 
       1.5075918604915728`, -0.12051907308195917`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.083899122641287, 
      2.563589361361559, -0.07075797978468554}, {4.083899122641287, 
      2.563589361361559, -0.07075797978468552}, {4.055932748427525, 
      2.709059574241039, -0.047171986523123675`}, {4.055932748427525, 
      2.709059574241039, -0.047171986523123696`}, {4.083899122641287, 
      2.563589361361559, -0.07075797978468554}}], 
     Polygon3DBox[{{4.055932748427525, 
      2.709059574241039, -0.047171986523123696`}, {4.055932748427525, 
      2.709059574241039, -0.047171986523123675`}, {4.027966374213762, 
      2.8545297871205193`, -0.023585993261561845`}, {4.027966374213762, 
      2.8545297871205193`, -0.023585993261561848`}, {4.055932748427525, 
      2.709059574241039, -0.047171986523123696`}}], 
     Polygon3DBox[{{4.027966374213762, 
      2.8545297871205193`, -0.023585993261561848`}, {4.027966374213762, 
      2.8545297871205193`, -0.023585993261561845`}, {4., 
      3., -7.467367148757545*^-18}, {4., 3., 0.}, {4.027966374213762, 
      2.8545297871205193`, -0.023585993261561848`}}], 
     Polygon3DBox[{{4., 3., 0.}, {4., 3., 9.989774703002288*^-18}, {
      3.9720336257862376`, 3.1454702128794803`, 0.023585993261561848`}, {
      3.9720336257862376`, 3.1454702128794803`, 0.02358599326156184}, {4., 3.,
       0.}}], 
     Polygon3DBox[{{3.9720336257862376`, 3.1454702128794803`, 
      0.02358599326156184}, {3.9720336257862376`, 3.1454702128794803`, 
      0.023585993261561848`}, {3.9440672515724753`, 3.290940425758961, 
      0.04717198652312368}, {3.9440672515724753`, 3.290940425758961, 
      0.04717198652312369}, {3.9720336257862376`, 3.1454702128794803`, 
      0.02358599326156184}}], 
     Polygon3DBox[{{3.9440672515724753`, 3.290940425758961, 
      0.04717198652312369}, {3.9440672515724753`, 3.290940425758961, 
      0.04717198652312368}, {3.916100877358713, 3.436410638638441, 
      0.07075797978468552}, {3.916100877358713, 3.436410638638441, 
      0.07075797978468552}, {3.9440672515724753`, 3.290940425758961, 
      0.04717198652312369}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZeeH7Zy1ABB6H42crWTSwOecbSLw1lN+1XEjPN
d7MUcEi0F8pVX8PqYPf+nNlbtRX7BbtnmS+WEXDYIN+5TfgaG1R8xn4GMBBw
gNAcDptlwiMKFFL23Ht5asLOY/wO/g/KPN9ocjrYQNTb77k8VbG4l99h/oG3
k24EcznYQsy3n7U3YZNOCL/DuwUpd47UcjvkQtyDIQ51J4Y5UHfaw+wNgNoL
dac9DnfawPy1EeovqDsxwgHqzv3o4QZ1J4Y4LDwBQUWQgw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{3.5631485346619574`, 
        2.9292420202153147`, -0.08157270087961327}, {3.5631485346619574`, 
        2.9292420202153147`, -0.08157270087961326}, {3.708765689774638, 
        2.9528280134768763`, -0.05438180058640884}, {3.708765689774638, 
        2.9528280134768763`, -0.05438180058640885}, {3.5631485346619574`, 
        2.9292420202153147`, -0.08157270087961327}}], 
       Polygon3DBox[{{3.708765689774638, 
        2.9528280134768763`, -0.05438180058640885}, {3.708765689774638, 
        2.9528280134768763`, -0.05438180058640884}, {3.854382844887319, 
        2.9764140067384384`, -0.02719090029320443}, {3.854382844887319, 
        2.9764140067384384`, -0.027190900293204423`}, {3.708765689774638, 
        2.9528280134768763`, -0.05438180058640885}}], 
       Polygon3DBox[{{3.854382844887319, 
        2.9764140067384384`, -0.027190900293204423`}, {3.854382844887319, 
        2.9764140067384384`, -0.02719090029320443}, {4., 
        3., -1.57926323709959*^-17}, {4., 3., 4.332676672872413*^-18}, {
        3.854382844887319, 2.9764140067384384`, -0.027190900293204423`}}], 
       Polygon3DBox[{{4., 3., 4.332676672872413*^-18}, {4., 3., 
        4.332676672872413*^-18}, {4.145617155112681, 3.023585993261562, 
        0.02719090029320442}, {4.145617155112681, 3.023585993261562, 
        0.027190900293204423`}, {4., 3., 4.332676672872413*^-18}}], 
       Polygon3DBox[{{4.145617155112681, 3.023585993261562, 
        0.027190900293204423`}, {4.145617155112681, 3.023585993261562, 
        0.02719090029320442}, {4.291234310225362, 3.0471719865231237`, 
        0.05438180058640883}, {4.291234310225362, 3.0471719865231237`, 
        0.05438180058640885}, {4.145617155112681, 3.023585993261562, 
        0.027190900293204423`}}], 
       Polygon3DBox[{{4.291234310225362, 3.0471719865231237`, 
        0.05438180058640885}, {4.291234310225362, 3.0471719865231237`, 
        0.05438180058640883}, {4.436851465338043, 3.0707579797846853`, 
        0.08157270087961326}, {4.436851465338043, 3.070757979784686, 
        0.08157270087961327}, {4.291234310225362, 3.0471719865231237`, 
        0.05438180058640885}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPrtDiVXbpU8Pt+xXuj8h
onc1r4PzERXvlPnsDh99OfLeXV+9f2K+x5pjV/kclJImqW46DxOfvZ8BDAQc
IDSHg8e0jdEfjdP3mJ+4vVJmqoDDvbm5t3wNOBzeQdTb50/YHmypJeiw1/r2
ltkJHA4fIObbL4uY/Dd0v6DD7Jse/S8ncDgUQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Ampqe0g==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.6470476573032444`, 
      2.492831381576873, -0.1523306806642988}, {3.4792494120206703`, 
      3.365652658853756, -0.010814721094927732`}, {4.352952342696756, 
      3.507168618423127, 0.1523306806642988}, {4.52075058797933, 
      2.634347341146244, 0.010814721094927732`}, {3.6470476573032444`, 
      2.492831381576873, -0.1523306806642988}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}, {3.4792494120206703`, 
       3.365652658853756, -0.010814721094927732`}, {4.352952342696756, 
       3.507168618423127, 0.1523306806642988}, {4.52075058797933, 
       2.634347341146244, 0.010814721094927732`}, {3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.10949255554889, 
      3.5730051881216065`, -0.090480997498417}, {4.10949255554889, 
      3.5730051881216065`, -0.09048099749841697}, {4.072995037032594, 
      3.715336792081071, -0.06032066499894464}, {4.072995037032594, 
      3.715336792081071, -0.06032066499894467}, {4.10949255554889, 
      3.5730051881216065`, -0.090480997498417}}], 
     Polygon3DBox[{{4.072995037032594, 
      3.715336792081071, -0.06032066499894467}, {4.072995037032594, 
      3.715336792081071, -0.06032066499894464}, {4.036497518516297, 
      3.8576683960405354`, -0.030160332499472333`}, {4.036497518516296, 
      3.8576683960405354`, -0.030160332499472337`}, {4.072995037032594, 
      3.715336792081071, -0.06032066499894467}}], 
     Polygon3DBox[{{4.036497518516296, 
      3.8576683960405354`, -0.030160332499472337`}, {4.036497518516297, 
      3.8576683960405354`, -0.030160332499472333`}, {4., 
      4., -1.0795288441427694`*^-17}, {4., 4., 0.}, {4.036497518516296, 
      3.8576683960405354`, -0.030160332499472337`}}], 
     Polygon3DBox[{{4., 4., 0.}, {4., 4., 1.1527841939415355`*^-17}, {
      3.963502481483703, 4.142331603959464, 0.03016033249947233}, {
      3.963502481483703, 4.142331603959464, 0.030160332499472323`}, {4., 4., 
      0.}}], Polygon3DBox[{{3.963502481483703, 4.142331603959464, 
      0.030160332499472323`}, {3.963502481483703, 4.142331603959464, 
      0.03016033249947233}, {3.9270049629674064`, 4.284663207918929, 
      0.06032066499894465}, {3.9270049629674064`, 4.284663207918929, 
      0.06032066499894466}, {3.963502481483703, 4.142331603959464, 
      0.030160332499472323`}}], 
     Polygon3DBox[{{3.9270049629674064`, 4.284663207918929, 
      0.06032066499894466}, {3.9270049629674064`, 4.284663207918929, 
      0.06032066499894465}, {3.89050744445111, 4.4269948118783935`, 
      0.09048099749841698}, {3.89050744445111, 4.4269948118783935`, 
      0.09048099749841697}, {3.9270049629674064`, 4.284663207918929, 
      0.06032066499894466}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7xmeWiXIGAQ1Fs9b7mqTwON921bA9rbt8v7cts
tt9LwOH7iz91TDt5HSq4Hi+LfLRuf+8yxtnxqgIO1SV19o13+KDi8/YzgIGA
A4ze0SHEvWBP5p6nm/6cdNjK73DoqEPC/okCDiUQ9fanUn9Obszid2jtbjxQ
pyzoUAYx336DxLfYQ/L8Du6BhxTstgo6XIe4B0Mc6k4Mc6DutEe3F+pOexzu
tEH3F9SdGOEAded+9HCDuhNDHBaeAA22mDc=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{3.5693581990138235`, 
        3.909519002501583, -0.09413197296919804}, {3.5693581990138235`, 
        3.909519002501583, -0.09413197296919802}, {3.712905466009216, 
        3.9396793350010553`, -0.062754648646132}, {3.712905466009216, 
        3.9396793350010553`, -0.06275464864613203}, {3.5693581990138235`, 
        3.909519002501583, -0.09413197296919804}}], 
       Polygon3DBox[{{3.712905466009216, 
        3.9396793350010553`, -0.06275464864613203}, {3.712905466009216, 
        3.9396793350010553`, -0.062754648646132}, {3.8564527330046077`, 
        3.9698396675005276`, -0.03137732432306602}, {3.8564527330046077`, 
        3.9698396675005276`, -0.03137732432306601}, {3.712905466009216, 
        3.9396793350010553`, -0.06275464864613203}}], 
       Polygon3DBox[{{3.8564527330046077`, 
        3.9698396675005276`, -0.03137732432306601}, {3.8564527330046077`, 
        3.9698396675005276`, -0.03137732432306602}, {4., 
        4., -1.7683522077894423`*^-17}, {4., 4., 5.5403631985048026`*^-18}, {
        3.8564527330046077`, 3.9698396675005276`, -0.03137732432306601}}], 
       Polygon3DBox[{{4., 4., 5.5403631985048026`*^-18}, {4., 4., 
        5.5403631985048026`*^-18}, {4.143547266995392, 4.030160332499472, 
        0.03137732432306601}, {4.143547266995392, 4.030160332499472, 
        0.03137732432306601}, {4., 4., 5.5403631985048026`*^-18}}], 
       Polygon3DBox[{{4.143547266995392, 4.030160332499472, 
        0.03137732432306601}, {4.143547266995392, 4.030160332499472, 
        0.03137732432306601}, {4.287094533990784, 4.060320664998945, 
        0.062754648646132}, {4.287094533990785, 4.060320664998945, 
        0.06275464864613203}, {4.143547266995392, 4.030160332499472, 
        0.03137732432306601}}], 
       Polygon3DBox[{{4.287094533990785, 4.060320664998945, 
        0.06275464864613203}, {4.287094533990784, 4.060320664998945, 
        0.062754648646132}, {4.4306418009861765`, 4.090480997498417, 
        0.09413197296919802}, {4.4306418009861765`, 4.090480997498417, 
        0.09413197296919804}, {4.287094533990785, 4.060320664998945, 
        0.06275464864613203}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvE7yClmFnJI7tg/2/Dt
cfYtvA7XilNmlrXwO2Rlz/beILBh/9kZ3x4z3+JzeG25ycf6EEx8wX4GMBBw
gNGsm9dqVB/L2jNzMwvfv0kCDlyPl0U+khNwyICotzdO55T5oyroIHrMd/MR
WwGHTIj59mek+LR+7RB0kF/5hWd5jICDLMQ9GOJQd2KYA3WnPbq9UHfa43Cn
zTk0f0HdiREOUHfuRw83qDsxxGHhCQCUlYvl
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.678850754562714, 
      3.4825241906231894`, -0.18461297046761505`}, {3.4598656434649335`, 
      4.336513814379977, -0.00365097547078104}, {4.321149245437287, 
      4.51747580937681, 0.18461297046761505`}, {4.5401343565350665`, 
      3.6634861856200236`, 0.00365097547078104}, {3.678850754562714, 
      3.4825241906231894`, -0.18461297046761505`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}, {3.4598656434649335`, 
       4.336513814379977, -0.00365097547078104}, {4.321149245437287, 
       4.51747580937681, 0.18461297046761505`}, {4.5401343565350665`, 
       3.6634861856200236`, 0.00365097547078104}, {3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.133335080581284, 
      4.583874026394841, -0.10752176699413386`}, {4.133335080581284, 
      4.583874026394841, -0.10752176699413384`}, {4.0888900537208555`, 
      4.722582684263227, -0.07168117799608921}, {4.0888900537208555`, 
      4.722582684263227, -0.07168117799608925}, {4.133335080581284, 
      4.583874026394841, -0.10752176699413386`}}], 
     Polygon3DBox[{{4.0888900537208555`, 
      4.722582684263227, -0.07168117799608925}, {4.0888900537208555`, 
      4.722582684263227, -0.07168117799608921}, {4.044445026860428, 
      4.861291342131613, -0.03584058899804462}, {4.044445026860428, 
      4.861291342131613, -0.035840588998044626`}, {4.0888900537208555`, 
      4.722582684263227, -0.07168117799608925}}], 
     Polygon3DBox[{{4.044445026860428, 
      4.861291342131613, -0.035840588998044626`}, {4.044445026860428, 
      4.861291342131613, -0.03584058899804462}, {4., 
      5., -1.3214460445236899`*^-17}, {4., 5., 0.}, {4.044445026860428, 
      4.861291342131613, -0.035840588998044626`}}], 
     Polygon3DBox[{{4., 5., 0.}, {4., 5., 1.331290430260057*^-17}, {
      3.9555549731395723`, 5.138708657868387, 0.03584058899804462}, {
      3.9555549731395723`, 5.138708657868387, 0.03584058899804461}, {4., 5., 
      0.}}], Polygon3DBox[{{3.9555549731395723`, 5.138708657868387, 
      0.03584058899804461}, {3.9555549731395723`, 5.138708657868387, 
      0.03584058899804462}, {3.911109946279144, 5.2774173157367725`, 
      0.07168117799608922}, {3.911109946279144, 5.277417315736773, 
      0.07168117799608924}, {3.9555549731395723`, 5.138708657868387, 
      0.03584058899804461}}], 
     Polygon3DBox[{{3.911109946279144, 5.277417315736773, 
      0.07168117799608924}, {3.911109946279144, 5.2774173157367725`, 
      0.07168117799608922}, {3.8666649194187164`, 5.416125973605159, 
      0.10752176699413385`}, {3.8666649194187164`, 5.416125973605159, 
      0.10752176699413384`}, {3.911109946279144, 5.277417315736773, 
      0.07168117799608924}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZkO/W3o0PAQThtodDjUCGHTKGbL7rbdu+/va7t
H2u0gAOPi9j2N4+FHOYkWs/eFLlpf1648/8mXQEHNqXu6G+FwlDxRfsZwEDA
AUKLOET47mCqn5q3RzWwkvHXEn6HX3dLlnD2iTjMgqi391z0iemLJ7/Dl90v
PYRlRB1mQ8y3z/uczfLuHZ/D25lxb2VWiTqkQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Aa8CXvw==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{3.5767723830849816`, 
        4.892478233005866, -0.1087081133259772}, {3.5767723830849816`, 
        4.892478233005866, -0.10870811332597718`}, {3.7178482553899874`, 
        4.928318822003911, -0.07247207555065144}, {3.7178482553899874`, 
        4.928318822003911, -0.07247207555065147}, {3.5767723830849816`, 
        4.892478233005866, -0.1087081133259772}}], 
       Polygon3DBox[{{3.7178482553899874`, 
        4.928318822003911, -0.07247207555065147}, {3.7178482553899874`, 
        4.928318822003911, -0.07247207555065144}, {3.8589241276949937`, 
        4.964159411001956, -0.03623603777532574}, {3.8589241276949937`, 
        4.964159411001956, -0.036236037775325726`}, {3.7178482553899874`, 
        4.928318822003911, -0.07247207555065147}}], 
       Polygon3DBox[{{3.8589241276949937`, 
        4.964159411001956, -0.036236037775325726`}, {3.8589241276949937`, 
        4.964159411001956, -0.03623603777532574}, {4., 
        5., -2.023624625016736*^-17}, {4., 5., 6.583809389401678*^-18}, {
        3.8589241276949937`, 4.964159411001956, -0.036236037775325726`}}], 
       Polygon3DBox[{{4., 5., 6.583809389401678*^-18}, {4., 5., 
        6.583809389401678*^-18}, {4.141075872305006, 5.035840588998044, 
        0.036236037775325726`}, {4.141075872305006, 5.035840588998044, 
        0.036236037775325726`}, {4., 5., 6.583809389401678*^-18}}], 
       Polygon3DBox[{{4.141075872305006, 5.035840588998044, 
        0.036236037775325726`}, {4.141075872305006, 5.035840588998044, 
        0.036236037775325726`}, {4.282151744610013, 5.071681177996089, 
        0.07247207555065144}, {4.282151744610013, 5.071681177996089, 
        0.07247207555065147}, {4.141075872305006, 5.035840588998044, 
        0.036236037775325726`}}], 
       Polygon3DBox[{{4.282151744610013, 5.071681177996089, 
        0.07247207555065147}, {4.282151744610013, 5.071681177996089, 
        0.07247207555065144}, {4.423227616915018, 5.107521766994134, 
        0.10870811332597718`}, {4.423227616915018, 5.107521766994134, 
        0.10870811332597718`}, {4.282151744610013, 5.071681177996089, 
        0.07247207555065147}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSjscLKhu977yu79fAqP
LdX38TpUCU02nblN2KGNIXZVe++m/ewTPs4Rvs/nYNt5cpbPbZj4ov0MYCDg
AKFFHEzCPkg/ep235495u2HZBAGHw2VmqZtVRBxaIOrtf+bzJb9REHRoe5tz
Ks1TxKEVYr791+VTpyRtFHTwSlmsL5Un4nAc4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+9HDDepODHFYeAIARb6ZSw==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{3.710107463666265, 
      4.476352259400707, -0.21622988032011106`}, {3.443437302503698, 
      5.308604206611026, -0.0011863463318433354`}, {4.289892536333735, 
      5.523647740599293, 0.21622988032011106`}, {4.556562697496302, 
      4.691395793388974, 0.0011863463318433354`}, {3.710107463666265, 
      4.476352259400707, -0.21622988032011106`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}, {3.443437302503698, 
       5.308604206611026, -0.0011863463318433354`}, {4.289892536333735, 
       5.523647740599293, 0.21622988032011106`}, {4.556562697496302, 
       4.691395793388974, 0.0011863463318433354`}, {3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.865989359316708, -5.416928888763165, 
      0.10349613470253909`}, {4.865989359316708, -5.416928888763165, 
      0.10349613470253911`}, {4.9106595728778055`, -5.277952592508776, 
      0.06899742313502609}, {4.9106595728778055`, -5.277952592508776, 
      0.06899742313502608}, {4.865989359316708, -5.416928888763165, 
      0.10349613470253909`}}], 
     Polygon3DBox[{{4.9106595728778055`, -5.277952592508776, 
      0.06899742313502608}, {4.9106595728778055`, -5.277952592508776, 
      0.06899742313502609}, {4.955329786438902, -5.138976296254389, 
      0.034498711567513066`}, {4.955329786438902, -5.138976296254389, 
      0.03449871156751304}, {4.9106595728778055`, -5.277952592508776, 
      0.06899742313502608}}], 
     Polygon3DBox[{{4.955329786438902, -5.138976296254389, 
      0.03449871156751304}, {4.955329786438902, -5.138976296254389, 
      0.034498711567513066`}, {5., -5., 4.097802015687242*^-17}, {5., -5., 
      0.}, {4.955329786438902, -5.138976296254389, 0.03449871156751304}}], 
     Polygon3DBox[{{5., -5., 0.}, {5., -5., 1.5443844222102288`*^-17}, {
      5.044670213561098, -4.861023703745611, -0.03449871156751302}, {
      5.044670213561098, -4.861023703745611, -0.034498711567513024`}, {
      5., -5., 0.}}], 
     Polygon3DBox[{{
      5.044670213561098, -4.861023703745611, -0.034498711567513024`}, {
      5.044670213561098, -4.861023703745611, -0.03449871156751302}, {
      5.0893404271221945`, -4.722047407491224, -0.06899742313502605}, {
      5.0893404271221945`, -4.722047407491224, -0.06899742313502606}, {
      5.044670213561098, -4.861023703745611, -0.034498711567513024`}}], 
     Polygon3DBox[{{
      5.0893404271221945`, -4.722047407491224, -0.06899742313502606}, {
      5.0893404271221945`, -4.722047407491224, -0.06899742313502605}, {
      5.134010640683292, -4.583071111236835, -0.10349613470253907`}, {
      5.134010640683292, -4.583071111236835, -0.10349613470253907`}, {
      5.0893404271221945`, -4.722047407491224, -0.06899742313502606}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY8o/zqaJmwg99v8Yz3q0QPSAecZ9xZt8t+o1Hu
x+Ylwg6dy3fNmi8jemBf1/3VF1ZutI+Yue2H4yVhh6PBsWf9+0Sg4gvtGcBA
xAFKH5hgI38yuiDXZkWaJ/s+XREH6zWLjDYUCh/YA1G/3//sJL6aaBGH8gjX
1ITHQgf2Qszf/934jqhVp4jDJpYX0wVChQ5IQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBQDylww==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        4.5806133268275735`, -4.896503865297461, -0.1261085582623079}, {
        4.5806133268275735`, -4.896503865297461, -0.1261085582623079}, {
        4.720408884551715, -4.931002576864974, -0.08407237217487194}, {
        4.720408884551715, -4.931002576864974, -0.08407237217487194}, {
        4.5806133268275735`, -4.896503865297461, -0.1261085582623079}}], 
       Polygon3DBox[{{
        4.720408884551715, -4.931002576864974, -0.08407237217487194}, {
        4.720408884551715, -4.931002576864974, -0.08407237217487194}, {
        4.860204442275857, -4.9655012884324865`, -0.042036186087436}, {
        4.860204442275858, -4.9655012884324865`, -0.04203618608743598}, {
        4.720408884551715, -4.931002576864974, -0.08407237217487194}}], 
       Polygon3DBox[{{
        4.860204442275858, -4.9655012884324865`, -0.04203618608743598}, {
        4.860204442275857, -4.9655012884324865`, -0.042036186087436}, {
        5., -5., -3.745033827884545*^-17}, {
        5., -5., -6.33731050437939*^-18}, {
        4.860204442275858, -4.9655012884324865`, -0.04203618608743598}}], 
       Polygon3DBox[{{5., -5., -6.33731050437939*^-18}, {
        5., -5., -6.33731050437939*^-18}, {
        5.139795557724142, -5.034498711567513, 0.04203618608743595}, {
        5.139795557724142, -5.034498711567513, 0.04203618608743595}, {
        5., -5., -6.33731050437939*^-18}}], 
       Polygon3DBox[{{5.139795557724142, -5.034498711567513, 
        0.04203618608743595}, {5.139795557724142, -5.034498711567513, 
        0.04203618608743595}, {5.279591115448285, -5.068997423135026, 
        0.08407237217487191}, {5.279591115448285, -5.068997423135026, 
        0.08407237217487191}, {5.139795557724142, -5.034498711567513, 
        0.04203618608743595}}], 
       Polygon3DBox[{{5.279591115448285, -5.068997423135026, 
        0.08407237217487191}, {5.279591115448285, -5.068997423135026, 
        0.08407237217487191}, {5.4193866731724265`, -5.103496134702539, 
        0.12610855826230788`}, {5.4193866731724265`, -5.103496134702539, 
        0.12610855826230788`}, {5.279591115448285, -5.068997423135026, 
        0.08407237217487191}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIHDu/Z6xSscmD//2m3
7256KORwtTFgb8RO4QPrf/+JONK6dX/D6bd5NwuEHV47rIhbcwcmvnQ/AxiI
OEDpA3suXvpS8b5wT4OJ0ES1fhEH0f3hC4OVRQ6shai3Z8xUUfKVE3XQrlvv
tNxN5MA6iPn2jXPNNhevFXVwsGV/8itT5MAhiHswxKHuxDAH6k57dHuh7rTH
4U4bdH9B3YkRDlB37kcPN6g7McRh4QkAfNSs8Q==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      4.446602686144281, -5.313432754060626, -0.02261242355976882}, {
      4.714623967510865, -4.4795749765342965`, -0.22960469296484698`}, {
      5.553397313855719, -4.686567245939374, 0.02261242355976882}, {
      5.285376032489135, -5.5204250234657035`, 0.22960469296484698`}, {
      4.446602686144281, -5.313432754060626, -0.02261242355976882}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       4.446602686144281, -5.313432754060626, -0.02261242355976882}, {
       4.714623967510865, -4.4795749765342965`, -0.22960469296484698`}, {
       5.553397313855719, -4.686567245939374, 0.02261242355976882}, {
       5.285376032489135, -5.5204250234657035`, 0.22960469296484698`}, {
       4.446602686144281, -5.313432754060626, -0.02261242355976882}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.889828083677382, -4.427507394723118, 
      0.08717554881303934}, {4.889828083677382, -4.427507394723118, 
      0.08717554881303936}, {4.926552055784922, -4.285004929815412, 
      0.05811703254202624}, {4.926552055784922, -4.285004929815412, 
      0.05811703254202623}, {4.889828083677382, -4.427507394723118, 
      0.08717554881303934}}], 
     Polygon3DBox[{{4.926552055784922, -4.285004929815412, 
      0.05811703254202623}, {4.926552055784922, -4.285004929815412, 
      0.05811703254202624}, {4.96327602789246, -4.142502464907706, 
      0.029058516271013145`}, {4.96327602789246, -4.142502464907706, 
      0.029058516271013114`}, {4.926552055784922, -4.285004929815412, 
      0.05811703254202623}}], 
     Polygon3DBox[{{4.96327602789246, -4.142502464907706, 
      0.029058516271013114`}, {4.96327602789246, -4.142502464907706, 
      0.029058516271013145`}, {5., -4., 3.523958838348834*^-17}, {5., -4., 
      0.}, {4.96327602789246, -4.142502464907706, 0.029058516271013114`}}], 
     Polygon3DBox[{{5., -4., 0.}, {5., -4., 1.3731965833139333`*^-17}, {
      5.03672397210754, -3.857497535092294, -0.029058516271013093`}, {
      5.03672397210754, -3.857497535092294, -0.029058516271013104`}, {5., -4.,
       0.}}], Polygon3DBox[{{
      5.03672397210754, -3.857497535092294, -0.029058516271013104`}, {
      5.03672397210754, -3.857497535092294, -0.029058516271013093`}, {
      5.073447944215078, -3.7149950701845884`, -0.0581170325420262}, {
      5.073447944215078, -3.7149950701845884`, -0.05811703254202622}, {
      5.03672397210754, -3.857497535092294, -0.029058516271013104`}}], 
     Polygon3DBox[{{
      5.073447944215078, -3.7149950701845884`, -0.05811703254202622}, {
      5.073447944215078, -3.7149950701845884`, -0.0581170325420262}, {
      5.110171916322618, -3.5724926052768824`, -0.08717554881303932}, {
      5.110171916322618, -3.5724926052768824`, -0.08717554881303932}, {
      5.073447944215078, -3.7149950701845884`, -0.05811703254202622}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF59+aa4fr+wg3bnnPojWwUPPN+gyawcuM1etvcZ
/6ktwg6ybMKhN5QFD3RNM2dpObjWvs/tM3vqLWEHvuZOrTcTBaDic+0ZwEDE
AUILHJBd0cz87nSGTdFOnh+zVEUcHv98s0r9Dt+Bdoj6/Y+LJD+Yeos4HP98
M9R/B++BToj5+0N11F5cKBBxWPX2GEP5FJ4DzyDuwRCHuhNuzjGoOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AX7empM=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        4.573002008838895, -3.9128244511869608`, -0.11213001040544965`}, {
        4.573002008838895, -3.9128244511869608`, -0.11213001040544966`}, {
        4.715334672559263, -3.941882967457974, -0.07475334027029978}, {
        4.715334672559263, -3.941882967457974, -0.07475334027029978}, {
        4.573002008838895, -3.9128244511869608`, -0.11213001040544965`}}], 
       Polygon3DBox[{{
        4.715334672559263, -3.941882967457974, -0.07475334027029978}, {
        4.715334672559263, -3.941882967457974, -0.07475334027029978}, {
        4.857667336279632, -3.970941483728987, -0.03737667013514991}, {
        4.857667336279632, -3.970941483728987, -0.0373766701351499}, {
        4.715334672559263, -3.941882967457974, -0.07475334027029978}}], 
       Polygon3DBox[{{
        4.857667336279632, -3.970941483728987, -0.0373766701351499}, {
        4.857667336279632, -3.970941483728987, -0.03737667013514991}, {
        5., -4., -3.3002256019465367`*^-17}, {
        5., -4., -5.3379628408901235`*^-18}, {
        4.857667336279632, -3.970941483728987, -0.0373766701351499}}], 
       Polygon3DBox[{{5., -4., -5.3379628408901235`*^-18}, {
        5., -4., -5.3379628408901235`*^-18}, {
        5.142332663720368, -4.0290585162710135`, 0.03737667013514987}, {
        5.142332663720368, -4.029058516271013, 0.03737667013514987}, {
        5., -4., -5.3379628408901235`*^-18}}], 
       Polygon3DBox[{{5.142332663720368, -4.029058516271013, 
        0.03737667013514987}, {5.142332663720368, -4.0290585162710135`, 
        0.03737667013514987}, {5.284665327440736, -4.058117032542026, 
        0.07475334027029976}, {5.284665327440737, -4.058117032542026, 
        0.07475334027029976}, {5.142332663720368, -4.029058516271013, 
        0.03737667013514987}}], 
       Polygon3DBox[{{5.284665327440737, -4.058117032542026, 
        0.07475334027029976}, {5.284665327440736, -4.058117032542026, 
        0.07475334027029976}, {5.426997991161105, -4.08717554881304, 
        0.11213001040544963`}, {5.426997991161105, -4.08717554881304, 
        0.1121300104054496}, {5.284665327440737, -4.058117032542026, 
        0.07475334027029976}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwH+vKnp/du2bP/b4Tj
xoY7Qg7LFN+//9nBfyDBa9d7DuXN++vXLIhwyBN2uDzh+/eaIzDxxfsZwEDE
AUILHJin9vAJ39P8PY3B8cv3TxRxmG7O0nJQVuBAHES9PfPyfX71yqIOuvkc
HM3WAgfiIebbt/yS/Wa3VdThyDKeHpdIgQM9EPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMA8Aae1A==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      4.462830092516277, -4.340331845910078, -0.024954461592410312`}, {
      4.683173925161513, -3.485317056463843, -0.19930555921848897`}, {
      5.537169907483723, -3.6596681540899216`, 0.024954461592410312`}, {
      5.316826074838487, -4.514682943536157, 0.19930555921848897`}, {
      4.462830092516277, -4.340331845910078, -0.024954461592410312`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}, {
       4.683173925161513, -3.485317056463843, -0.19930555921848897`}, {
       5.537169907483723, -3.6596681540899216`, 0.024954461592410312`}, {
       5.316826074838487, -4.514682943536157, 0.19930555921848897`}, {
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.915495681804043, -3.4366955918959663`, 
      0.06823474353193006}, {4.915495681804043, -3.4366955918959663`, 
      0.06823474353193008}, {4.943663787869363, -3.2911303945973107`, 
      0.04548982902128672}, {4.943663787869362, -3.2911303945973107`, 
      0.045489829021286704`}, {4.915495681804043, -3.4366955918959663`, 
      0.06823474353193006}}], 
     Polygon3DBox[{{4.943663787869362, -3.2911303945973107`, 
      0.045489829021286704`}, {4.943663787869363, -3.2911303945973107`, 
      0.04548982902128672}, {4.971831893934681, -3.1455651972986556`, 
      0.02274491451064338}, {4.971831893934681, -3.1455651972986556`, 
      0.022744914510643352`}, {4.943663787869362, -3.2911303945973107`, 
      0.045489829021286704`}}], 
     Polygon3DBox[{{4.971831893934681, -3.1455651972986556`, 
      0.022744914510643352`}, {4.971831893934681, -3.1455651972986556`, 
      0.02274491451064338}, {5., -3., 2.9086265251280304`*^-17}, {5., -3., 
      0.}, {4.971831893934681, -3.1455651972986556`, 0.022744914510643352`}}],
      Polygon3DBox[{{5., -3., 0.}, {5., -3., 1.2251646729382258`*^-17}, {
      5.028168106065319, -2.854434802701345, -0.022744914510643338`}, {
      5.028168106065319, -2.854434802701345, -0.022744914510643345`}, {
      5., -3., 0.}}], 
     Polygon3DBox[{{
      5.028168106065319, -2.854434802701345, -0.022744914510643345`}, {
      5.028168106065319, -2.854434802701345, -0.022744914510643338`}, {
      5.056336212130638, -2.7088696054026893`, -0.04548982902128668}, {
      5.056336212130638, -2.7088696054026893`, -0.0454898290212867}, {
      5.028168106065319, -2.854434802701345, -0.022744914510643345`}}], 
     Polygon3DBox[{{
      5.056336212130638, -2.7088696054026893`, -0.0454898290212867}, {
      5.056336212130638, -2.7088696054026893`, -0.04548982902128668}, {
      5.084504318195957, -2.5633044081040337`, -0.06823474353193004}, {
      5.084504318195957, -2.563304408104034, -0.06823474353193003}, {
      5.056336212130638, -2.7088696054026893`, -0.0454898290212867}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ9aby5fKWwgxSjjlNUHfeBmatfs18t32jP4Xb2
jP8xYQfBMFkdmxCuA2eePIkv9Fpuz7I47Zn6Y2EHztV8YnJanFDx6fYMYCDi
AKE5DoRkvjy/OSPZ5k/MTMkbMiIOP0I+vnx4le3AKYj6/T92GhlvsBRxeL/y
0eXDq1kPnIaYv/+z2BmfjjARh+f/Lu9d2shyYDrEPXDxZ1BxqDsxzIG6cz/M
3u9Qe6Hu3I/DnXtg/uKA+gvqToxwgLrTHhZuktBwg7rTHld4AgB2yaTn
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        4.5665999994623245`, -2.93176525646807, -0.10004228760416743`}, {
        4.5665999994623245`, -2.93176525646807, -0.10004228760416745`}, {
        4.711066666308216, -2.9545101709787134`, -0.06669485840277829}, {
        4.711066666308216, -2.9545101709787134`, -0.06669485840277829}, {
        4.5665999994623245`, -2.93176525646807, -0.10004228760416743`}}], 
       Polygon3DBox[{{
        4.711066666308216, -2.9545101709787134`, -0.06669485840277829}, {
        4.711066666308216, -2.9545101709787134`, -0.06669485840277829}, {
        4.855533333154108, -2.9772550854893565`, -0.03334742920138917}, {
        4.855533333154108, -2.9772550854893565`, -0.033347429201389146`}, {
        4.711066666308216, -2.9545101709787134`, -0.06669485840277829}}], 
       Polygon3DBox[{{
        4.855533333154108, -2.9772550854893565`, -0.033347429201389146`}, {
        4.855533333154108, -2.9772550854893565`, -0.03334742920138917}, {
        5., -3., -2.886022882047728*^-17}, {
        5., -3., -4.178173012850935*^-18}, {
        4.855533333154108, -2.9772550854893565`, -0.033347429201389146`}}], 
       Polygon3DBox[{{5., -3., -4.178173012850935*^-18}, {
        5., -3., -4.178173012850935*^-18}, {
        5.144466666845892, -3.0227449145106435`, 0.03334742920138913}, {
        5.144466666845892, -3.0227449145106435`, 0.033347429201389125`}, {
        5., -3., -4.178173012850935*^-18}}], 
       Polygon3DBox[{{5.144466666845892, -3.0227449145106435`, 
        0.033347429201389125`}, {5.144466666845892, -3.0227449145106435`, 
        0.03334742920138913}, {5.288933333691784, -3.0454898290212866`, 
        0.06669485840277826}, {5.288933333691784, -3.0454898290212866`, 
        0.06669485840277826}, {5.144466666845892, -3.0227449145106435`, 
        0.033347429201389125`}}], 
       Polygon3DBox[{{5.288933333691784, -3.0454898290212866`, 
        0.06669485840277826}, {5.288933333691784, -3.0454898290212866`, 
        0.06669485840277826}, {5.4334000005376755`, -3.06823474353193, 
        0.10004228760416742`}, {5.433400000537675, -3.06823474353193, 
        0.10004228760416739`}, {5.288933333691784, -3.0454898290212866`, 
        0.06669485840277826}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewHjotXCcbP2bnfxN3k
juINIYfcnAara4vYD7TuWsb9Smjj/lnKUu8EcoQdzMwcZLMvwsQX7mcAAxEH
CM1xwKjnQMbtkpw9aXeeCr6fLOJw6uT+R1P0OA40Q9Tbn9lxWvmeuqjD5Mn1
RzVjOQ60QMy3N5y60fTsblGH2Fj7Ffu6OQ4chbjH3ghNHOpODHOg7rRHtxfq
Tnsc7rRB9xfUnRjhAHXn/vNo4QZ1535c4QkABlSbCg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      4.482095681266368, -3.368460848364036, -0.031807544072237376`}, {
      4.651104317658282, -2.495069664572104, -0.1682770311360975}, {
      5.517904318733632, -2.631539151635964, 0.031807544072237376`}, {
      5.348895682341718, -3.504930335427896, 0.1682770311360975}, {
      4.482095681266368, -3.368460848364036, -0.031807544072237376`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}, {
       4.651104317658282, -2.495069664572104, -0.1682770311360975}, {
       5.517904318733632, -2.631539151635964, 0.031807544072237376`}, {
       5.348895682341718, -3.504930335427896, 0.1682770311360975}, {
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.942711522202292, -2.4438598759561367`, 
      0.04697276687427018}, {4.942711522202292, -2.4438598759561367`, 
      0.046972766874270204`}, {4.961807681468195, -2.2959065839707575`, 
      0.03131517791618014}, {4.961807681468195, -2.2959065839707575`, 
      0.031315177916180124`}, {4.942711522202292, -2.4438598759561367`, 
      0.04697276687427018}}], 
     Polygon3DBox[{{4.961807681468195, -2.2959065839707575`, 
      0.031315177916180124`}, {4.961807681468195, -2.2959065839707575`, 
      0.03131517791618014}, {4.980903840734098, -2.1479532919853788`, 
      0.015657588958090083`}, {4.980903840734097, -2.1479532919853788`, 
      0.015657588958090062`}, {4.961807681468195, -2.2959065839707575`, 
      0.031315177916180124`}}], 
     Polygon3DBox[{{4.980903840734097, -2.1479532919853788`, 
      0.015657588958090062`}, {4.980903840734098, -2.1479532919853788`, 
      0.015657588958090083`}, {5., -2., 2.2690621327318924`*^-17}, {5., -2., 
      0.}, {4.980903840734097, -2.1479532919853788`, 0.015657588958090062`}}],
      Polygon3DBox[{{5., -2., 0.}, {5., -2., 1.1101677479726786`*^-17}, {
      5.019096159265903, -1.8520467080146212`, -0.01565758895809005}, {
      5.019096159265903, -1.8520467080146212`, -0.015657588958090055`}, {
      5., -2., 0.}}], 
     Polygon3DBox[{{
      5.019096159265903, -1.8520467080146212`, -0.015657588958090055`}, {
      5.019096159265903, -1.8520467080146212`, -0.01565758895809005}, {
      5.038192318531805, -1.7040934160292425`, -0.031315177916180104`}, {
      5.038192318531805, -1.7040934160292425`, -0.03131517791618012}, {
      5.019096159265903, -1.8520467080146212`, -0.015657588958090055`}}], 
     Polygon3DBox[{{
      5.038192318531805, -1.7040934160292425`, -0.03131517791618012}, {
      5.038192318531805, -1.7040934160292425`, -0.031315177916180104`}, {
      5.057288477797708, -1.5561401240438635`, -0.046972766874270176`}, {
      5.057288477797708, -1.5561401240438637`, -0.04697276687427017}, {
      5.038192318531805, -1.7040934160292425`, -0.03131517791618012}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5dH6oddlTY4dFzyQy2XuYDPSp8zRd4Vthbnnos
8+SGsMO0WWmuLHFMBzbncjJ1cyywl3layFf0RtjB23ezEpM+I1R8gj0DGIg4
QGiGA1e28a97viPK5olU38deYRGHrNSZu34v/Lt/I0T9/uOmMo+l1UUcrpwy
Kv3u/Hv/Joj5+1cHrLqy0krEwc7gjP7npz/2d0HcAxe3hYpD3Qk35zLUHKg7
96PbC3Xnfhzu3IPuL6g7McIB6k57WLg9hIYb1J32uMITAFbOk70=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        4.56173551333006, -1.95302723312573, -0.09065207607169844}, {
        4.56173551333006, -1.9530272331257297`, -0.09065207607169844}, {
        4.707823675553373, -1.9686848220838198`, -0.06043471738113229}, {
        4.707823675553373, -1.9686848220838198`, -0.0604347173811323}, {
        4.56173551333006, -1.95302723312573, -0.09065207607169844}}], 
       Polygon3DBox[{{
        4.707823675553373, -1.9686848220838198`, -0.0604347173811323}, {
        4.707823675553373, -1.9686848220838198`, -0.06043471738113229}, {
        4.853911837776686, -1.98434241104191, -0.030217358690566163`}, {
        4.853911837776686, -1.98434241104191, -0.030217358690566153`}, {
        4.707823675553373, -1.9686848220838198`, -0.0604347173811323}}], 
       Polygon3DBox[{{
        4.853911837776686, -1.98434241104191, -0.030217358690566153`}, {
        4.853911837776686, -1.98434241104191, -0.030217358690566163`}, {
        5., -2., -2.5241590671065895`*^-17}, {
        5., -2., -2.87625242998349*^-18}, {
        4.853911837776686, -1.98434241104191, -0.030217358690566153`}}], 
       Polygon3DBox[{{5., -2., -2.87625242998349*^-18}, {
        5., -2., -2.87625242998349*^-18}, {
        5.146088162223314, -2.01565758895809, 0.030217358690566135`}, {
        5.146088162223314, -2.01565758895809, 0.030217358690566135`}, {
        5., -2., -2.87625242998349*^-18}}], 
       Polygon3DBox[{{5.146088162223314, -2.01565758895809, 
        0.030217358690566135`}, {5.146088162223314, -2.01565758895809, 
        0.030217358690566135`}, {5.292176324446627, -2.03131517791618, 
        0.06043471738113228}, {5.292176324446627, -2.03131517791618, 
        0.06043471738113228}, {5.146088162223314, -2.01565758895809, 
        0.030217358690566135`}}], 
       Polygon3DBox[{{5.292176324446627, -2.03131517791618, 
        0.06043471738113228}, {5.292176324446627, -2.03131517791618, 
        0.06043471738113228}, {5.43826448666994, -2.04697276687427, 
        0.09065207607169842}, {5.43826448666994, -2.04697276687427, 
        0.09065207607169841}, {5.292176324446627, -2.03131517791618, 
        0.06043471738113228}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//739/lKvtpsn1/UMTx
XeevCDlM2vJ++e76//unXkqe6/Nx3X7NNcl307OEHTxvfb98dz9MfN5+BjAQ
cYDQDAeq9S/rip7M3HM9eI7SjKkiDreFWMQEFRgOTIKot1+33MLVQFvUYbsq
h46SA8OByRDz7Vt+X0k/cUDUYZIFj5NxAsOBtxD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAFR4qAI=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      4.504447035532352, -2.396887109081866, -0.043679309197428254`}, {
      4.619023991127767, -1.5091673571695932`, -0.1376248429459686}, {
      5.495552964467648, -1.6031128909181338`, 0.043679309197428254`}, {
      5.380976008872233, -2.490832642830407, 0.1376248429459686}, {
      4.504447035532352, -2.396887109081866, -0.043679309197428254`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}, {
       4.619023991127767, -1.5091673571695932`, -0.1376248429459686}, {
       5.495552964467648, -1.6031128909181338`, 0.043679309197428254`}, {
       5.380976008872233, -2.490832642830407, 0.1376248429459686}, {
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.97105710406142, -1.448428666283699, 
      0.023959132490797116`}, {4.97105710406142, -1.448428666283699, 
      0.023959132490797137`}, {4.980704736040947, -1.2989524441891325`, 
      0.01597275499386476}, {4.980704736040947, -1.2989524441891327`, 
      0.015972754993864746`}, {4.97105710406142, -1.448428666283699, 
      0.023959132490797116`}}], 
     Polygon3DBox[{{4.980704736040947, -1.2989524441891327`, 
      0.015972754993864746`}, {4.980704736040947, -1.2989524441891325`, 
      0.01597275499386476}, {4.990352368020473, -1.1494762220945665`, 
      0.00798637749693239}, {4.990352368020473, -1.1494762220945662`, 
      0.007986377496932373}, {4.980704736040947, -1.2989524441891327`, 
      0.015972754993864746`}}], 
     Polygon3DBox[{{4.990352368020473, -1.1494762220945662`, 
      0.007986377496932373}, {4.990352368020473, -1.1494762220945665`, 
      0.00798637749693239}, {5., -1.0000000000000002`, 
      1.628138498235918*^-17}, {5., -1., 0.}, {
      4.990352368020473, -1.1494762220945662`, 0.007986377496932373}}], 
     Polygon3DBox[{{5., -1., 0.}, {5., -1., 1.0370278195397484`*^-17}, {
      5.009647631979527, -0.8505237779054338, -0.007986377496932363}, {
      5.009647631979527, -0.8505237779054338, -0.00798637749693237}, {5., -1.,
       0.}}], Polygon3DBox[{{
      5.009647631979527, -0.8505237779054338, -0.00798637749693237}, {
      5.009647631979527, -0.8505237779054338, -0.007986377496932363}, {
      5.019295263959053, -0.7010475558108675, -0.015972754993864736`}, {
      5.019295263959053, -0.7010475558108674, -0.015972754993864743`}, {
      5.009647631979527, -0.8505237779054338, -0.00798637749693237}}], 
     Polygon3DBox[{{
      5.019295263959053, -0.7010475558108674, -0.015972754993864743`}, {
      5.019295263959053, -0.7010475558108675, -0.015972754993864736`}, {
      5.02894289593858, -0.5515713337163011, -0.023959132490797112`}, {
      5.02894289593858, -0.5515713337163012, -0.023959132490797112`}, {
      5.019295263959053, -0.7010475558108674, -0.015972754993864743`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb9oXg65pGwg3ZBS+dhne/7+62+aO7rmGHPF3Dw
ju0bYQfZBWujm0582Z9Q41uoGT3Bnn1Fwju5b8IOfBeu6TqmfIKKN9gzgIGI
A4T+sH++SmP6LCdvm5/h8wUfcoo4PIkPWlJr/np/HET9/k/r7ZQPCYs4HN+/
xON33rP98RDz979mv2eyWFbEYbX89zcVyx7u74O4By6+CioOdSfcnGNQc6Du
3A+z9zHUXqg79+Nw5x50f0HdCQ8HGWg4QN1pDws3LWi4Qd1pjys8AY+uo70=

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{
        4.558689111507046, -0.9760408675092029, -0.08467974768412961}, {
        4.558689111507046, -0.9760408675092028, -0.08467974768412961}, {
        4.705792741004697, -0.9840272450061353, -0.05645316512275307}, {
        4.705792741004697, -0.9840272450061353, -0.056453165122753085`}, {
        4.558689111507046, -0.9760408675092029, -0.08467974768412961}}], 
       Polygon3DBox[{{
        4.705792741004697, -0.9840272450061353, -0.056453165122753085`}, {
        4.705792741004697, -0.9840272450061353, -0.05645316512275307}, {
        4.852896370502348, -0.9920136225030676, -0.028226582561376556`}, {
        4.852896370502348, -0.9920136225030676, -0.028226582561376543`}, {
        4.705792741004697, -0.9840272450061353, -0.056453165122753085`}}], 
       Polygon3DBox[{{
        4.852896370502348, -0.9920136225030676, -0.028226582561376543`}, {
        4.852896370502348, -0.9920136225030676, -0.028226582561376556`}, {
        5., -1., -2.2358941656508875`*^-17}, {
        5., -1., -1.467073745760102*^-18}, {
        4.852896370502348, -0.9920136225030676, -0.028226582561376543`}}], 
       Polygon3DBox[{{5., -1., -1.467073745760102*^-18}, {
        5., -1., -1.467073745760102*^-18}, {
        5.147103629497652, -1.0079863774969324`, 0.028226582561376532`}, {
        5.147103629497652, -1.0079863774969324`, 0.02822658256137653}, {
        5., -1., -1.467073745760102*^-18}}], 
       Polygon3DBox[{{5.147103629497652, -1.0079863774969324`, 
        0.02822658256137653}, {5.147103629497652, -1.0079863774969324`, 
        0.028226582561376532`}, {5.294207258995303, -1.0159727549938646`, 
        0.056453165122753064`}, {5.294207258995303, -1.0159727549938646`, 
        0.05645316512275307}, {5.147103629497652, -1.0079863774969324`, 
        0.02822658256137653}}], 
       Polygon3DBox[{{5.294207258995303, -1.0159727549938646`, 
        0.05645316512275307}, {5.294207258995303, -1.0159727549938646`, 
        0.056453165122753064`}, {5.441310888492954, -1.023959132490797, 
        0.0846797476841296}, {5.441310888492954, -1.023959132490797, 
        0.0846797476841296}, {5.294207258995303, -1.0159727549938646`, 
        0.05645316512275307}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f751x7nzVp7db9tlWC
obsvCTnITindolb7fn9N8avHuc/X7Jfb27EqNlPYge+UVdTkfTDxOfsZwEDE
AUJ/2D9x64wXBmIZex45lYcumibi8HPWo6BtCh/2V0LU2x9ufbfKRVfU4aPp
0aU5jh/2V0HMt196IpXh+WFRh1cXlv9QSvqwfzbEPRjiUHfCzfkENQfqTnt0
e6HutMfhThuYv/ih/oK6EyMcoO7cjx5uUHdiiMPCEwC6Tri6
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}, {
      4.587632007445626, -0.527612201225504, -0.10863888017492673`}, {
      5.470253784431534, -0.5755304662070981, 0.060720615193332494`}, {
      5.412367992554374, -1.472387798774496, 0.10863888017492673`}, {
      4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}, {
       4.587632007445626, -0.527612201225504, -0.10863888017492673`}, {
       5.470253784431534, -0.5755304662070981, 0.060720615193332494`}, {
       5.412367992554374, -1.472387798774496, 0.10863888017492673`}, {
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}}]}}}, \

   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5., -0.4499999999999999, 0.}, {5., -0.4499999999999999, 
      2.0238161967470138`*^-17}, {5., -0.29999999999999993`, 
      1.686513497289178*^-17}, {5., -0.3, 0.}, {5., -0.4499999999999999, 
      0.}}], Polygon3DBox[{{5., -0.3, 0.}, {5., -0.29999999999999993`, 
      1.686513497289178*^-17}, {5., -0.15000000000000005`, 
      1.3492107978313426`*^-17}, {5., -0.15, 0.}, {5., -0.3, 0.}}], 
     Polygon3DBox[{{5., -0.15, 0.}, {5., -0.15000000000000005`, 
      1.3492107978313426`*^-17}, {5., -1.1102230246251563`*^-16, 
      1.011908098373507*^-17}, {5., 0., 0.}, {5., -0.15, 0.}}], 
     Polygon3DBox[{{5., 0., 0.}, {5., 0., 1.0119080983735069`*^-17}, {5., 
      0.14999999999999994`, 6.746053989156713*^-18}, {5., 
      0.14999999999999994`, 0.}, {5., 0., 0.}}], 
     Polygon3DBox[{{5., 0.14999999999999994`, 0.}, {5., 0.14999999999999994`, 
      6.746053989156713*^-18}, {5., 0.2999999999999999, 
      3.3730269945783574`*^-18}, {5., 0.29999999999999993`, 0.}, {5., 
      0.14999999999999994`, 0.}}], 
     Polygon3DBox[{{5., 0.29999999999999993`, 0.}, {5., 0.2999999999999999, 
      3.3730269945783577`*^-18}, {5., 0.44999999999999984`, 
      1.685165504428388*^-33}, {5., 0.4499999999999998, 0.}, {5., 
      0.29999999999999993`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcTh9BgTu7GdAASIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIAeUNHcg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{4.557651133210165, 0., -0.08262856678987253}, {
        4.557651133210165, 5.5109105961630883`*^-17, -0.08262856678987253}, {
        4.705100755473443, 4.592425496802573*^-17, -0.05508571119324835}, {
        4.705100755473443, 9.184850993605147*^-18, -0.055085711193248364`}, {
        4.557651133210165, 0., -0.08262856678987253}}], 
       Polygon3DBox[{{4.705100755473443, 
        9.184850993605147*^-18, -0.055085711193248364`}, {4.705100755473443, 
        4.592425496802573*^-17, -0.05508571119324835}, {4.852550377736722, 
        3.6739403974420595`*^-17, -0.027542855596624193`}, {4.852550377736722,
         1.8369701987210294`*^-17, -0.027542855596624182`}, {
        4.705100755473443, 9.184850993605147*^-18, -0.055085711193248364`}}], 
       Polygon3DBox[{{4.852550377736722, 
        1.8369701987210294`*^-17, -0.027542855596624182`}, {4.852550377736722,
         3.6739403974420595`*^-17, -0.027542855596624193`}, {5., 
        2.7554552980815448`*^-17, -2.0385808298198676`*^-17}, {5., 
        2.7554552980815442`*^-17, 0.}, {4.852550377736722, 
        1.8369701987210294`*^-17, -0.027542855596624182`}}], 
       Polygon3DBox[{{5., 2.7554552980815442`*^-17, 0.}, {5., 
        2.7554552980815442`*^-17, 0.}, {5.147449622263278, 
        1.8369701987210297`*^-17, 0.02754285559662417}, {5.147449622263278, 
        3.673940397442059*^-17, 0.02754285559662417}, {5., 
        2.7554552980815442`*^-17, 0.}}], 
       Polygon3DBox[{{5.147449622263278, 3.673940397442059*^-17, 
        0.02754285559662417}, {5.147449622263278, 1.8369701987210297`*^-17, 
        0.02754285559662417}, {5.294899244526557, 9.18485099360515*^-18, 
        0.05508571119324834}, {5.294899244526557, 4.592425496802573*^-17, 
        0.05508571119324835}, {5.147449622263278, 3.673940397442059*^-17, 
        0.02754285559662417}}], 
       Polygon3DBox[{{5.294899244526557, 4.592425496802573*^-17, 
        0.05508571119324835}, {5.294899244526557, 9.184850993605152*^-18, 
        0.05508571119324834}, {5.442348866789835, 4.588754872883257*^-33, 
        0.08262856678987253}, {5.442348866789835, 5.510910596163088*^-17, 
        0.08262856678987252}, {5.294899244526557, 4.592425496802573*^-17, 
        0.05508571119324835}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmINa4w/eMw1rIgQEKHN8JB6iqb91/dNKWd6yXEOLM
k6UOGJqs2Z/sGfWdKVMYTXzOfghPBC6uoyqmcKUhfc/cbUs5/k5DiDNA1Ntb
53oL/tIVhYszQsy3v6H8UfL7EYS4A8Q9GOJQd2KYA3WnPbq9UHfa43CnDbq/
oO7ECAeoO/ejhxvUnRjisPAEAJHdWYk=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{
      4.557651133210165, -0.4499999999999999, -0.08262856678987253}, {
      4.557651133210165, 0.4499999999999999, -0.08262856678987253}, {
      5.442348866789835, 0.4499999999999999, 0.08262856678987253}, {
      5.442348866789835, -0.4499999999999999, 0.08262856678987253}, {
      4.557651133210165, -0.4499999999999999, -0.08262856678987253}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}, {
       4.557651133210165, 0.4499999999999999, -0.08262856678987253}, {
       5.442348866789835, 0.4499999999999999, 0.08262856678987253}, {
       5.442348866789835, -0.4499999999999999, 0.08262856678987253}, {
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5.02894289593858, 
      0.5515713337163011, -0.023959132490797116`}, {5.02894289593858, 
      0.5515713337163011, -0.023959132490797095`}, {5.019295263959053, 
      0.7010475558108674, -0.015972754993864725`}, {5.019295263959053, 
      0.7010475558108673, -0.015972754993864746`}, {5.02894289593858, 
      0.5515713337163011, -0.023959132490797116`}}], 
     Polygon3DBox[{{5.019295263959053, 
      0.7010475558108673, -0.015972754993864746`}, {5.019295263959053, 
      0.7010475558108674, -0.015972754993864725`}, {5.009647631979527, 
      0.8505237779054337, -0.007986377496932363}, {5.009647631979527, 
      0.8505237779054337, -0.007986377496932373}, {5.019295263959053, 
      0.7010475558108673, -0.015972754993864746`}}], 
     Polygon3DBox[{{5.009647631979527, 
      0.8505237779054337, -0.007986377496932373}, {5.009647631979527, 
      0.8505237779054337, -0.007986377496932363}, {5., 0.9999999999999999, 
      4.459171408435789*^-18}, {5., 1., 0.}, {5.009647631979527, 
      0.8505237779054337, -0.007986377496932373}}], 
     Polygon3DBox[{{5., 1., 0.}, {5., 1., 1.0370278195397484`*^-17}, {
      4.990352368020473, 1.1494762220945662`, 0.007986377496932377}, {
      4.990352368020473, 1.1494762220945662`, 0.00798637749693237}, {5., 1., 
      0.}}], Polygon3DBox[{{4.990352368020473, 1.1494762220945662`, 
      0.00798637749693237}, {4.990352368020473, 1.1494762220945662`, 
      0.007986377496932377}, {4.980704736040947, 1.2989524441891325`, 
      0.015972754993864743`}, {4.980704736040947, 1.2989524441891325`, 
      0.015972754993864743`}, {4.990352368020473, 1.1494762220945662`, 
      0.00798637749693237}}], 
     Polygon3DBox[{{4.980704736040947, 1.2989524441891325`, 
      0.015972754993864743`}, {4.980704736040947, 1.2989524441891325`, 
      0.015972754993864743`}, {4.97105710406142, 1.448428666283699, 
      0.023959132490797112`}, {4.97105710406142, 1.4484286662836987`, 
      0.023959132490797112`}, {4.980704736040947, 1.2989524441891325`, 
      0.015972754993864743`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Nfs9ksayIwyr5728qlj2077f6ormvY8b+T+vt
lA8Jizgc27/E43feM/uEGt9CzegJ+3+Gzxd8yCni8Dg+aEmt+WuoeMN+BjAQ
cYDQH+znqzSmz3Ly3sO+IuGd3DdhB74L13QdUz7Zx0HU2/MFHLxj+0bYQWbB
2uimE1/s4yHm24v+UDwd80jYQaugpfOwznf7Poh74OLaUHGoO+HmyELNgbrT
Ht1eqDvtcbjTBuavJ1B/Qd0JD4fj0HCAunM/LNxWQ8MN6s79uMITALm+nWg=

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{4.558689111507046, 
        0.9760408675092029, -0.08467974768412961}, {4.558689111507046, 
        0.9760408675092029, -0.08467974768412961}, {4.705792741004697, 
        0.9840272450061353, -0.05645316512275307}, {4.705792741004697, 
        0.9840272450061353, -0.056453165122753085`}, {4.558689111507046, 
        0.9760408675092029, -0.08467974768412961}}], 
       Polygon3DBox[{{4.705792741004697, 
        0.9840272450061353, -0.056453165122753085`}, {4.705792741004697, 
        0.9840272450061353, -0.05645316512275307}, {4.852896370502348, 
        0.9920136225030677, -0.02822658256137655}, {4.852896370502348, 
        0.9920136225030677, -0.028226582561376543`}, {4.705792741004697, 
        0.9840272450061353, -0.056453165122753085`}}], 
       Polygon3DBox[{{4.852896370502348, 
        0.9920136225030677, -0.028226582561376543`}, {4.852896370502348, 
        0.9920136225030677, -0.02822658256137655}, {5., 
        1., -1.942479416498867*^-17}, {5., 1., 1.467073745760102*^-18}, {
        4.852896370502348, 0.9920136225030677, -0.028226582561376543`}}], 
       Polygon3DBox[{{5., 1., 1.467073745760102*^-18}, {5., 1., 
        1.467073745760102*^-18}, {5.147103629497652, 1.0079863774969324`, 
        0.028226582561376532`}, {5.147103629497652, 1.0079863774969324`, 
        0.028226582561376536`}, {5., 1., 1.467073745760102*^-18}}], 
       Polygon3DBox[{{5.147103629497652, 1.0079863774969324`, 
        0.028226582561376536`}, {5.147103629497652, 1.0079863774969324`, 
        0.028226582561376532`}, {5.294207258995303, 1.0159727549938649`, 
        0.056453165122753064`}, {5.294207258995303, 1.0159727549938649`, 
        0.05645316512275307}, {5.147103629497652, 1.0079863774969324`, 
        0.028226582561376536`}}], 
       Polygon3DBox[{{5.294207258995303, 1.0159727549938649`, 
        0.05645316512275307}, {5.294207258995303, 1.0159727549938649`, 
        0.056453165122753064`}, {5.441310888492954, 1.023959132490797, 
        0.0846797476841296}, {5.441310888492954, 1.023959132490797, 
        0.0846797476841296}, {5.294207258995303, 1.0159727549938649`, 
        0.05645316512275307}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f2c669z5q0dut+2yrB
0N2XhBxkp5RuUat9b19T/Opx7vM1++X2dqyKzRR24DtlFTV5H0x8zn4GMBBx
gNAf7CdunfHCQCxjzyOn8tBF00Qcfs56FLRN4YN9JUS9/eHWd6tcdEUdPpoe
XZrj+MG+CmK+/dITqQzPD4s6vLqw/IdS0gf72RD3YIhD3Qk35xPUHKg77dHt
hbrTHoc7bWD+4of6C+pOjHCAunM/erhB3YkhDgtPAIqDsTo=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.587632007445626, 
      0.527612201225504, -0.10863888017492673`}, {4.529746215568466, 
      1.4244695337929019`, -0.060720615193332494`}, {5.412367992554374, 
      1.472387798774496, 0.10863888017492673`}, {5.470253784431534, 
      0.5755304662070981, 0.060720615193332494`}, {4.587632007445626, 
      0.527612201225504, -0.10863888017492673`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{4.587632007445626, 
       0.527612201225504, -0.10863888017492673`}, {4.529746215568466, 
       1.4244695337929019`, -0.060720615193332494`}, {5.412367992554374, 
       1.472387798774496, 0.10863888017492673`}, {5.470253784431534, 
       0.5755304662070981, 0.060720615193332494`}, {4.587632007445626, 
       0.527612201225504, -0.10863888017492673`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5.057288477797708, 
      1.5561401240438635`, -0.04697276687427018}, {5.057288477797708, 
      1.5561401240438635`, -0.04697276687427016}, {5.038192318531805, 
      1.7040934160292425`, -0.0313151779161801}, {5.038192318531805, 
      1.7040934160292422`, -0.031315177916180124`}, {5.057288477797708, 
      1.5561401240438635`, -0.04697276687427018}}], 
     Polygon3DBox[{{5.038192318531805, 
      1.7040934160292422`, -0.031315177916180124`}, {5.038192318531805, 
      1.7040934160292425`, -0.0313151779161801}, {5.019096159265903, 
      1.852046708014621, -0.015657588958090055`}, {5.019096159265903, 
      1.8520467080146212`, -0.015657588958090062`}, {5.038192318531805, 
      1.7040934160292422`, -0.031315177916180124`}}], 
     Polygon3DBox[{{5.019096159265903, 
      1.8520467080146212`, -0.015657588958090062`}, {5.019096159265903, 
      1.852046708014621, -0.015657588958090055`}, {5., 
      2., -4.872663678653445*^-19}, {5., 2., 0.}, {5.019096159265903, 
      1.8520467080146212`, -0.015657588958090062`}}], 
     Polygon3DBox[{{5., 2., 0.}, {5., 2., 1.1101677479726786`*^-17}, {
      4.980903840734097, 2.1479532919853788`, 0.015657588958090062`}, {
      4.980903840734097, 2.1479532919853788`, 0.015657588958090055`}, {5., 2.,
       0.}}], Polygon3DBox[{{4.980903840734097, 2.1479532919853788`, 
      0.015657588958090055`}, {4.980903840734097, 2.1479532919853788`, 
      0.015657588958090062`}, {4.961807681468195, 2.2959065839707575`, 
      0.03131517791618012}, {4.961807681468195, 2.2959065839707575`, 
      0.03131517791618012}, {4.980903840734097, 2.1479532919853788`, 
      0.015657588958090055`}}], 
     Polygon3DBox[{{4.961807681468195, 2.2959065839707575`, 
      0.03131517791618012}, {4.961807681468195, 2.2959065839707575`, 
      0.03131517791618012}, {4.942711522202292, 2.4438598759561363`, 
      0.046972766874270176`}, {4.942711522202292, 2.4438598759561363`, 
      0.04697276687427017}, {4.961807681468195, 2.2959065839707575`, 
      0.03131517791618012}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF4dsOrKSisRB1uDM/qfn/6w71Hha77As2L/cVOZ
x9LqIg6XTxmVfnf+bb85l5Opm2PB/idSfR97hUUcslJn7vq98C9UfMJ+BjAQ
cYDQDA5XtvGve74jao/M00K+ojfCDt6+m5WY9BkdNkLU21ueeizz5Iaww7RZ
aa4scUwOmyDm24euD9UOOyrs8PC5ZAZbL7NDF8Q9cPFHUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw+EKNByg7twPCzc7aLhB3bkfV3gCAJTDjtI=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{4.56173551333006, 
        1.95302723312573, -0.09065207607169844}, {4.56173551333006, 
        1.95302723312573, -0.09065207607169844}, {4.707823675553373, 
        1.96868482208382, -0.06043471738113228}, {4.707823675553373, 
        1.9686848220838198`, -0.0604347173811323}, {4.56173551333006, 
        1.95302723312573, -0.09065207607169844}}], 
       Polygon3DBox[{{4.707823675553373, 
        1.9686848220838198`, -0.0604347173811323}, {4.707823675553373, 
        1.96868482208382, -0.06043471738113228}, {4.853911837776686, 
        1.98434241104191, -0.030217358690566156`}, {4.853911837776686, 
        1.98434241104191, -0.030217358690566146`}, {4.707823675553373, 
        1.9686848220838198`, -0.0604347173811323}}], 
       Polygon3DBox[{{4.853911837776686, 
        1.98434241104191, -0.030217358690566146`}, {4.853911837776686, 
        1.98434241104191, -0.030217358690566156`}, {5., 
        2., -1.948908581109891*^-17}, {5., 2., 2.87625242998349*^-18}, {
        4.853911837776686, 1.98434241104191, -0.030217358690566146`}}], 
       Polygon3DBox[{{5., 2., 2.87625242998349*^-18}, {5., 2., 
        2.87625242998349*^-18}, {5.146088162223314, 2.01565758895809, 
        0.030217358690566142`}, {5.146088162223314, 2.01565758895809, 
        0.030217358690566142`}, {5., 2., 2.87625242998349*^-18}}], 
       Polygon3DBox[{{5.146088162223314, 2.01565758895809, 
        0.030217358690566142`}, {5.146088162223314, 2.01565758895809, 
        0.030217358690566142`}, {5.292176324446627, 2.03131517791618, 
        0.06043471738113228}, {5.292176324446627, 2.03131517791618, 
        0.06043471738113229}, {5.146088162223314, 2.01565758895809, 
        0.030217358690566142`}}], 
       Polygon3DBox[{{5.292176324446627, 2.03131517791618, 
        0.06043471738113229}, {5.292176324446627, 2.03131517791618, 
        0.06043471738113228}, {5.43826448666994, 2.04697276687427, 
        0.09065207607169842}, {5.43826448666994, 2.04697276687427, 
        0.09065207607169841}, {5.292176324446627, 2.03131517791618, 
        0.06043471738113229}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//27+9ylf002b4/KOL4
rvNXhBwmbXm/fHf9f/upl5Ln+nxct19zTfLd9CxhB89b3y/f3Q8Tn7efAQxE
HCA0g0O1/mVd0ZOZe64Hz1GaMVXE4bYQi5igAoPDJIh6+3XLLVwNtEUdtqty
6Cg5MDhMhphv3/L7SvqJA6IOkyx4nIwTGBzeQtyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AJK2ggg==
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.619023991127767, 
      1.5091673571695932`, -0.1376248429459686}, {4.504447035532352, 
      2.396887109081866, -0.043679309197428254`}, {5.380976008872233, 
      2.490832642830407, 0.1376248429459686}, {5.495552964467648, 
      1.6031128909181338`, 0.043679309197428254`}, {4.619023991127767, 
      1.5091673571695932`, -0.1376248429459686}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}, {4.504447035532352, 
       2.396887109081866, -0.043679309197428254`}, {5.380976008872233, 
       2.490832642830407, 0.1376248429459686}, {5.495552964467648, 
       1.6031128909181338`, 0.043679309197428254`}, {4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5.084504318195957, 
      2.5633044081040337`, -0.06823474353193006}, {5.084504318195957, 
      2.5633044081040337`, -0.06823474353193003}, {5.056336212130638, 
      2.7088696054026893`, -0.045489829021286676`}, {5.056336212130638, 
      2.7088696054026893`, -0.045489829021286704`}, {5.084504318195957, 
      2.5633044081040337`, -0.06823474353193006}}], 
     Polygon3DBox[{{5.056336212130638, 
      2.7088696054026893`, -0.045489829021286704`}, {5.056336212130638, 
      2.7088696054026893`, -0.045489829021286676`}, {5.028168106065319, 
      2.8544348027013444`, -0.022744914510643345`}, {5.028168106065319, 
      2.8544348027013444`, -0.022744914510643352`}, {5.056336212130638, 
      2.7088696054026893`, -0.045489829021286704`}}], 
     Polygon3DBox[{{5.028168106065319, 
      2.8544348027013444`, -0.022744914510643352`}, {5.028168106065319, 
      2.8544348027013444`, -0.022744914510643345`}, {5., 
      3., -4.5829717925157884`*^-18}, {5., 3., 0.}, {5.028168106065319, 
      2.8544348027013444`, -0.022744914510643352`}}], 
     Polygon3DBox[{{5., 3., 0.}, {5., 3., 1.2251646729382258`*^-17}, {
      4.971831893934681, 3.145565197298655, 0.022744914510643352`}, {
      4.971831893934681, 3.145565197298655, 0.022744914510643345`}, {5., 3., 
      0.}}], Polygon3DBox[{{4.971831893934681, 3.145565197298655, 
      0.022744914510643345`}, {4.971831893934681, 3.145565197298655, 
      0.022744914510643352`}, {4.943663787869362, 3.2911303945973107`, 
      0.0454898290212867}, {4.943663787869362, 3.2911303945973107`, 
      0.0454898290212867}, {4.971831893934681, 3.145565197298655, 
      0.022744914510643345`}}], 
     Polygon3DBox[{{4.943663787869362, 3.2911303945973107`, 
      0.0454898290212867}, {4.943663787869362, 3.2911303945973107`, 
      0.0454898290212867}, {4.915495681804043, 3.4366955918959663`, 
      0.06823474353193004}, {4.915495681804043, 3.436695591895966, 
      0.06823474353193003}, {4.943663787869362, 3.2911303945973107`, 
      0.0454898290212867}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4sdsanI0zE4dm/y3uXNrI4zFz9mv1q+cb9P3Ya
GW+wFHF4v/LR5cOrWR3OPHkSX+i1fP+fmJmSN2REHL6HfHz58CobVHz6fgYw
EHGA0BwOIZkvz2/OSN7DsjjtmfpjYQeO1XxiclqcDqcg6u053M6e8T8m7CAY
JqtjE8LlcBpivj3vS+PN5SuFHSQZdZyi6rgdpkPcAxeXgopD3YlhDtSd9jB7
OaH2Qt1pj8OdNjB//YD6C+pOjHCAunM/LNyeQ8MN6s79uMITAMm8oR0=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{4.5665999994623245`, 
        2.93176525646807, -0.10004228760416743`}, {4.5665999994623245`, 
        2.93176525646807, -0.10004228760416742`}, {4.711066666308216, 
        2.9545101709787134`, -0.06669485840277826}, {4.711066666308216, 
        2.9545101709787134`, -0.06669485840277829}, {4.5665999994623245`, 
        2.93176525646807, -0.10004228760416743`}}], 
       Polygon3DBox[{{4.711066666308216, 
        2.9545101709787134`, -0.06669485840277829}, {4.711066666308216, 
        2.9545101709787134`, -0.06669485840277826}, {4.855533333154108, 
        2.9772550854893565`, -0.03334742920138915}, {4.855533333154108, 
        2.9772550854893565`, -0.033347429201389146`}, {4.711066666308216, 
        2.9545101709787134`, -0.06669485840277829}}], 
       Polygon3DBox[{{4.855533333154108, 
        2.9772550854893565`, -0.033347429201389146`}, {4.855533333154108, 
        2.9772550854893565`, -0.03334742920138915}, {5., 
        3., -2.0503882794775412`*^-17}, {5., 3., 4.178173012850935*^-18}, {
        4.855533333154108, 2.9772550854893565`, -0.033347429201389146`}}], 
       Polygon3DBox[{{5., 3., 4.178173012850935*^-18}, {5., 3., 
        4.178173012850935*^-18}, {5.144466666845892, 3.0227449145106435`, 
        0.03334742920138913}, {5.144466666845892, 3.0227449145106435`, 
        0.03334742920138914}, {5., 3., 4.178173012850935*^-18}}], 
       Polygon3DBox[{{5.144466666845892, 3.0227449145106435`, 
        0.03334742920138914}, {5.144466666845892, 3.0227449145106435`, 
        0.03334742920138913}, {5.288933333691784, 3.0454898290212866`, 
        0.06669485840277826}, {5.288933333691784, 3.0454898290212866`, 
        0.06669485840277829}, {5.144466666845892, 3.0227449145106435`, 
        0.03334742920138914}}], 
       Polygon3DBox[{{5.288933333691784, 3.0454898290212866`, 
        0.06669485840277829}, {5.288933333691784, 3.0454898290212866`, 
        0.06669485840277826}, {5.4334000005376755`, 3.06823474353193, 
        0.10004228760416742`}, {5.433400000537675, 3.06823474353193, 
        0.10004228760416742`}, {5.288933333691784, 3.0454898290212866`, 
        0.06669485840277829}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewOx8WrBOPn7Nxv4m5y
R/GGkENuToPVtUXsDq27lnG/Etq4f5ay1DuBHGEHMzMH2eyLMPGF+xnAQMQB
QnM4GPUcyLhdkrMn7c5TwfeTRRxOndz/aIoeh0MzRL39mR2nle+pizpMnlx/
VDOWw6EFYr694dSNpmd3izrExtqv2NfN4XAU4h57IzRxqDsxzIG60x7dXqg7
7XG40wbdX1B3YoQD1J37z6OFG9Sd+3GFJwDWepOK
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.651104317658282, 
      2.495069664572104, -0.1682770311360975}, {4.482095681266368, 
      3.368460848364036, -0.031807544072237376`}, {5.348895682341718, 
      3.504930335427896, 0.1682770311360975}, {5.517904318733632, 
      2.631539151635964, 0.031807544072237376`}, {4.651104317658282, 
      2.495069664572104, -0.1682770311360975}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{4.651104317658282, 
       2.495069664572104, -0.1682770311360975}, {4.482095681266368, 
       3.368460848364036, -0.031807544072237376`}, {5.348895682341718, 
       3.504930335427896, 0.1682770311360975}, {5.517904318733632, 
       2.631539151635964, 0.031807544072237376`}, {4.651104317658282, 
       2.495069664572104, -0.1682770311360975}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5.110171916322618, 
      3.5724926052768824`, -0.08717554881303934}, {5.110171916322618, 
      3.5724926052768824`, -0.08717554881303931}, {5.073447944215078, 
      3.7149950701845884`, -0.0581170325420262}, {5.073447944215078, 
      3.714995070184588, -0.05811703254202623}, {5.110171916322618, 
      3.5724926052768824`, -0.08717554881303934}}], 
     Polygon3DBox[{{5.073447944215078, 
      3.714995070184588, -0.05811703254202623}, {5.073447944215078, 
      3.7149950701845884`, -0.0581170325420262}, {5.03672397210754, 
      3.857497535092294, -0.02905851627101311}, {5.03672397210754, 
      3.857497535092294, -0.029058516271013114`}, {5.073447944215078, 
      3.714995070184588, -0.05811703254202623}}], 
     Polygon3DBox[{{5.03672397210754, 
      3.857497535092294, -0.029058516271013114`}, {5.03672397210754, 
      3.857497535092294, -0.02905851627101311}, {5., 
      4., -7.775656717209665*^-18}, {5., 4., 0.}, {5.03672397210754, 
      3.857497535092294, -0.029058516271013114`}}], 
     Polygon3DBox[{{5., 4., 0.}, {5., 4., 1.3731965833139333`*^-17}, {
      4.96327602789246, 4.142502464907706, 0.029058516271013114`}, {
      4.96327602789246, 4.142502464907706, 0.029058516271013104`}, {5., 4., 
      0.}}], Polygon3DBox[{{4.96327602789246, 4.142502464907706, 
      0.029058516271013104`}, {4.96327602789246, 4.142502464907706, 
      0.029058516271013114`}, {4.926552055784922, 4.285004929815412, 
      0.058117032542026215`}, {4.926552055784922, 4.285004929815412, 
      0.05811703254202622}, {4.96327602789246, 4.142502464907706, 
      0.029058516271013104`}}], 
     Polygon3DBox[{{4.926552055784922, 4.285004929815412, 
      0.05811703254202622}, {4.926552055784922, 4.285004929815412, 
      0.058117032542026215`}, {4.889828083677382, 4.427507394723118, 
      0.08717554881303932}, {4.889828083677382, 4.427507394723118, 
      0.08717554881303932}, {4.926552055784922, 4.285004929815412, 
      0.05811703254202622}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7VUXtxoUDEYdXbYwzlU3gcnm/QZFYO3Lb/cZHk
B1NvEYdjn2+G+u/gdeiaZs7ScnDt/qKdPD9mqYo4PP75ZpX6HT6o+Nz9DGAg
4gChBRxkVzQzvzudsafP7TN76i1hB77mTq03EwUc2iHq7WV7n/Gf2iLsIMsm
HHpDWdChE2K+/erLN8X1+4UdtDvn1B/ZKujwDOIeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHfCw+E4NByg7tyPHm5Qd2KIw8ITAJxik1I=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{4.573002008838895, 
        3.9128244511869608`, -0.11213001040544965`}, {4.573002008838895, 
        3.9128244511869608`, -0.11213001040544963`}, {4.715334672559263, 
        3.941882967457974, -0.07475334027029976}, {4.715334672559263, 
        3.941882967457974, -0.07475334027029978}, {4.573002008838895, 
        3.9128244511869608`, -0.11213001040544965`}}], 
       Polygon3DBox[{{4.715334672559263, 
        3.941882967457974, -0.07475334027029978}, {4.715334672559263, 
        3.941882967457974, -0.07475334027029976}, {4.857667336279632, 
        3.970941483728987, -0.0373766701351499}, {4.857667336279632, 
        3.970941483728987, -0.037376670135149885`}, {4.715334672559263, 
        3.941882967457974, -0.07475334027029978}}], 
       Polygon3DBox[{{4.857667336279632, 
        3.970941483728987, -0.037376670135149885`}, {4.857667336279632, 
        3.970941483728987, -0.0373766701351499}, {5., 
        4., -2.2326330337685117`*^-17}, {5., 4., 5.3379628408901235`*^-18}, {
        4.857667336279632, 3.970941483728987, -0.037376670135149885`}}], 
       Polygon3DBox[{{5., 4., 5.3379628408901235`*^-18}, {5., 4., 
        5.3379628408901235`*^-18}, {5.142332663720368, 4.0290585162710135`, 
        0.037376670135149885`}, {5.142332663720368, 4.0290585162710135`, 
        0.037376670135149885`}, {5., 4., 5.3379628408901235`*^-18}}], 
       Polygon3DBox[{{5.142332663720368, 4.0290585162710135`, 
        0.037376670135149885`}, {5.142332663720368, 4.0290585162710135`, 
        0.037376670135149885`}, {5.284665327440736, 4.058117032542026, 
        0.07475334027029976}, {5.284665327440737, 4.058117032542026, 
        0.07475334027029978}, {5.142332663720368, 4.0290585162710135`, 
        0.037376670135149885`}}], 
       Polygon3DBox[{{5.284665327440737, 4.058117032542026, 
        0.07475334027029978}, {5.284665327440736, 4.058117032542026, 
        0.07475334027029976}, {5.426997991161105, 4.08717554881304, 
        0.11213001040544963`}, {5.426997991161105, 4.08717554881304, 
        0.11213001040544963`}, {5.284665327440737, 4.058117032542026, 
        0.07475334027029978}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwOffnT03u37Nn/N8Jx
Y8MdIYdliu/f/+zgd0jw2vWeQ3nz/vo1CyIc8oQdLk/4/r3mCEx88X4GMBBx
gNACDvPUHj7he5q/pzE4fvn+iSIO081ZWg7KCjjEQdTbMy/f51evLOqgm8/B
0Wwt4BAPMd++5ZfsN7utog5HlvH0uEQKOPRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwDAO5dU
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.683173925161513, 
      3.485317056463843, -0.19930555921848897`}, {4.462830092516277, 
      4.340331845910078, -0.024954461592410312`}, {5.316826074838487, 
      4.514682943536157, 0.19930555921848897`}, {5.537169907483723, 
      3.6596681540899216`, 0.024954461592410312`}, {4.683173925161513, 
      3.485317056463843, -0.19930555921848897`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}, {4.462830092516277, 
       4.340331845910078, -0.024954461592410312`}, {5.316826074838487, 
       4.514682943536157, 0.19930555921848897`}, {5.537169907483723, 
       3.6596681540899216`, 0.024954461592410312`}, {4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{5.134010640683292, 
      4.583071111236835, -0.10349613470253909`}, {5.134010640683292, 
      4.583071111236835, -0.10349613470253906`}, {5.0893404271221945`, 
      4.722047407491224, -0.06899742313502603}, {5.0893404271221945`, 
      4.722047407491224, -0.06899742313502608}, {5.134010640683292, 
      4.583071111236835, -0.10349613470253909`}}], 
     Polygon3DBox[{{5.0893404271221945`, 
      4.722047407491224, -0.06899742313502608}, {5.0893404271221945`, 
      4.722047407491224, -0.06899742313502603}, {5.044670213561098, 
      4.861023703745611, -0.034498711567513024`}, {5.044670213561098, 
      4.861023703745611, -0.03449871156751304}, {5.0893404271221945`, 
      4.722047407491224, -0.06899742313502608}}], 
     Polygon3DBox[{{5.044670213561098, 
      4.861023703745611, -0.03449871156751304}, {5.044670213561098, 
      4.861023703745611, -0.034498711567513024`}, {5., 
      5., -1.0090331712667836`*^-17}, {5., 5., 0.}, {5.044670213561098, 
      4.861023703745611, -0.03449871156751304}}], 
     Polygon3DBox[{{5., 5., 0.}, {5., 5., 1.5443844222102288`*^-17}, {
      4.955329786438902, 5.138976296254389, 0.03449871156751303}, {
      4.955329786438902, 5.138976296254389, 0.034498711567513024`}, {5., 5., 
      0.}}], Polygon3DBox[{{4.955329786438902, 5.138976296254389, 
      0.034498711567513024`}, {4.955329786438902, 5.138976296254389, 
      0.03449871156751303}, {4.9106595728778055`, 5.277952592508776, 
      0.06899742313502605}, {4.9106595728778055`, 5.277952592508776, 
      0.06899742313502606}, {4.955329786438902, 5.138976296254389, 
      0.034498711567513024`}}], 
     Polygon3DBox[{{4.9106595728778055`, 5.277952592508776, 
      0.06899742313502606}, {4.9106595728778055`, 5.277952592508776, 
      0.06899742313502605}, {4.865989359316708, 5.416928888763165, 
      0.10349613470253907`}, {4.865989359316708, 5.416928888763165, 
      0.10349613470253907`}, {4.9106595728778055`, 5.277952592508776, 
      0.06899742313502606}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5ufEfUqlPEYRPLi+kCoUIO0gHnGXfW7drvf3YS
X020iEN5hGtqwmMhh31d91dfWLlx/4o0T/Z9uiIO1msWGW0oFIaKL9zPAAYi
DjB6go38yeiC3D0RM7f9cLwk7HA0OPasf5+Iwx6IevuNRrkfm5cIO3Qu3zVr
voyow16I+facZ5RfHS0TdvD7LZ7xfpWogxTEPRjiUHdimAN1pz26vVB32uNw
pw26v6DuxAgHqDv3o4cb1J0Y4rDwBABZ7Z27
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{4.5806133268275735`, 
        4.896503865297461, -0.1261085582623079}, {4.5806133268275735`, 
        4.896503865297461, -0.1261085582623079}, {4.720408884551715, 
        4.931002576864974, -0.08407237217487191}, {4.720408884551715, 
        4.931002576864974, -0.08407237217487194}, {4.5806133268275735`, 
        4.896503865297461, -0.1261085582623079}}], 
       Polygon3DBox[{{4.720408884551715, 
        4.931002576864974, -0.08407237217487194}, {4.720408884551715, 
        4.931002576864974, -0.08407237217487191}, {4.860204442275857, 
        4.965501288432487, -0.042036186087435985`}, {4.860204442275858, 
        4.965501288432487, -0.042036186087435964`}, {4.720408884551715, 
        4.931002576864974, -0.08407237217487194}}], 
       Polygon3DBox[{{4.860204442275858, 
        4.965501288432487, -0.042036186087435964`}, {4.860204442275857, 
        4.965501288432487, -0.042036186087435985`}, {5., 
        5., -2.4775717270086665`*^-17}, {5., 5., 6.33731050437939*^-18}, {
        4.860204442275858, 4.965501288432487, -0.042036186087435964`}}], 
       Polygon3DBox[{{5., 5., 6.33731050437939*^-18}, {5., 5., 
        6.33731050437939*^-18}, {5.139795557724142, 5.034498711567513, 
        0.042036186087435964`}, {5.139795557724142, 5.0344987115675135`, 
        0.042036186087435964`}, {5., 5., 6.33731050437939*^-18}}], 
       Polygon3DBox[{{5.139795557724142, 5.0344987115675135`, 
        0.042036186087435964`}, {5.139795557724142, 5.034498711567513, 
        0.042036186087435964`}, {5.279591115448285, 5.068997423135026, 
        0.08407237217487191}, {5.279591115448285, 5.068997423135026, 
        0.08407237217487194}, {5.139795557724142, 5.0344987115675135`, 
        0.042036186087435964`}}], 
       Polygon3DBox[{{5.279591115448285, 5.068997423135026, 
        0.08407237217487194}, {5.279591115448285, 5.068997423135026, 
        0.08407237217487191}, {5.4193866731724265`, 5.103496134702539, 
        0.12610855826230788`}, {5.4193866731724265`, 5.103496134702539, 
        0.12610855826230788`}, {5.279591115448285, 5.068997423135026, 
        0.08407237217487194}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIOh/fsdQpWObD//7Tb
dzc9FHK42hiwN2KnsMP6338ijrRu3d9w+m3ezQJhh9cOK+LW3IGJL93PAAYi
DjB6z8VLXyreF+5pMBGaqNYv4iC6P3xhsLKIw1qIenvGTBUlXzlRB+269U7L
3UQc1kHMt2+ca7a5eK2og4Mt+5NfmSIOhyDuwRCHuhPDHKg77dHthbrTHoc7
bdD9BXUnRjhA3bkfPdyg7sQQh4UnAE0JpXE=
         "]]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{4.714623967510865, 
      4.4795749765342965`, -0.22960469296484698`}, {4.446602686144281, 
      5.313432754060626, -0.02261242355976882}, {5.285376032489135, 
      5.5204250234657035`, 0.22960469296484698`}, {5.553397313855719, 
      4.686567245939374, 0.02261242355976882}, {4.714623967510865, 
      4.4795749765342965`, -0.22960469296484698`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}, {4.446602686144281, 
       5.313432754060626, -0.02261242355976882}, {5.285376032489135, 
       5.5204250234657035`, 0.22960469296484698`}, {5.553397313855719, 
       4.686567245939374, 0.02261242355976882}, {4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404678770816*^9, 3.566101178287225*^9, 
  3.614727731944861*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[263]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tRotate[PointOfRays[{10,10},BirthPoint->{-50,0,-50},NumberOfRays->11],90,{0,\
1,0}],
\tMirror[{.9,.9}],
\tMoveDirected[Screen[{2,2}],{10,0,10},{0,0,0}]}, ReportedSurfaces->All, \
CreateClones->clonedplaces,
\tPlotRange->{{-8,12.5},{-6.5,6.5},{-1,13.5}}, PlotType->Full3D, \
RunningCommentary->TurboTrace, CloneSortLength-> 3];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[264]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.61472773237709*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732378867*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732380219*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277323815403`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8"}], ",", "12.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "13.5`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8"}], ",", "12.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "13.5`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`ReportedSurfaces -> All, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     PlotRange -> {{-8, 12.5}, {-6.5, 6.5}, {-1, 13.5}}, 
     Optica`Optica`PlotType -> Optica`Optica`Full3D, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`ReportedSurfaces -> All, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     PlotRange -> {{-8, 12.5}, {-6.5, 6.5}, {-1, 13.5}}, 
     Optica`Optica`PlotType -> Optica`Optica`Full3D, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277323953543`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732426564*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732428369*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.15396999999999999575450715383340138942`5.2080360230533325", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.15396999999999999575450715383340138942`5.2080360230533325, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732543911*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732545512*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732547106*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732548636*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732550521*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732552388*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277325539494`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732555485*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732556994*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732678747*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277326804113`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.61472773268202*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732683516*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"PointOfRays", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"10", ",", "10"}], "}"}], ",", 
               RowBox[{"BirthPoint", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "50"}], ",", "0", ",", 
                  RowBox[{"-", "50"}]}], "}"}]}], ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "11"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", 
                 RowBox[{"-", "1.`"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "50.`"}], ",", "0", ",", "50.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.7071067811865475`", ",", "0", ",", 
              RowBox[{"-", "0.7071067811865475`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.7071067811865475`", ",", "0", ",", "0.7071067811865475`"}], 
             "}"}]}], "}"}]}], "}"}]}], "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`PointOfRays[{
           Optica`Optica`Ray[]}, {10, 10}, 
          Optica`Optica`BirthPoint -> {-50, 0, -50}, 
          Optica`Optica`NumberOfRays -> 11, 
          Optica`Optica`SourceTransformation -> {{0, 0, 
            0}, {{0, 0, -1.}, {0, 1., 0}, {1., 0, 0}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, 0, 0}, {{0, 
            0, -1}, {0, 1, 0}, {1, 0, 0}}}]], 
       Optica`Optica`SourceTransformation :> {{-50., 0, 50.}, {{
          0.7071067811865475, 0, -0.7071067811865475}, {0, 1., 0}, {
          0.7071067811865475, 0, 0.7071067811865475}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-50, 0, 
         50}, {{2^Rational[-1, 2], 0, -2^Rational[-1, 2]}, {0, 1, 0}, {
          2^Rational[-1, 2], 0, 2^Rational[-1, 2]}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 11, 
       Optica`Optica`BirthPoint :> {-50, 0, -50}, 
       Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 70359, 
       Optica`Optica`SourceFraction :> {1, 1}, 
       Optica`Optica`SourceOffset :> {0, 0}, 
       Optica`Optica`GridSpacing :> {#& , #& }, Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues :> {}], False, False, False, 
      False, {{-50., 0, 50.}, {{0.7071067811865475, 0, -0.7071067811865475}, {
        0, 1., 0}, {0.7071067811865475, 0, 0.7071067811865475}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732685615*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732768272*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.61472773277004*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.61472773277164*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732826788*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732862383*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277328651743`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277328680677`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732872047*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "1"}],
  SequenceForm["maximum used clone sort position = ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277329134207`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"121", ",", "0", ",", "0"}], "}"}]}],
  SequenceForm["Histogram of used sort positions: ", {121, 0, 0}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732916448*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({121, 0, 0}\\)\\), \
\\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] All\\)\\)\\)\\)]\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727732963305*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "0.12256899999999999739674905185893294401`5.108980556126502", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "242", 
   "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   0.12256899999999999739674905185893294401`5.108980556126502, 
   " seconds with ", 242, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732967067*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732968746*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732970504*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732973412*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732975424*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732977004*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727732978766*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277329802523`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277330502777`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.6147277331667957`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727733202228*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJysnHdUFcn2tpEgKCDZnMWcszOiXQbMOWACxZyzYs5hdMxixlHBLCYU89Eq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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7WmeXYUCZyoE3Ae9ejVaIHmGNN7/is32+/K3qO
NoO/yIF1W++oTZcRPcBkd25Sh/xW+7u650Qb1EUOXI/Km+zdJwIVX2rPAAYi
B2D0GmNGVfdZhTbKlwxf1d8QPqC5dGLOlkLhAwwQ9fvdliRf+b9B+ECQl/LN
jMdCBxgh5u/PKpu6r75T+ED1+y2usqFCBxgg7oGLV0HFoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHhZurdBwg7rTHld4AgAlc5t6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQofqEwUOMezotPe/lB1
lpW66AGO41vuNq4WPrDsNZfJZqlGe4WHtqZzJ4scaEm+9e7AVZh4oT0DGIgc
gNEi9/aEXW20sXkod+hUUo7wgZo5qoL2WiIHlkLU7z9o2zL16A2hAz8svJXq
QmDijfsXxbglaLgKHSi5WmC8t07kQDnEPRjiUHdimAN15/4HaPZC3bkfhzv3
yKP5C+pOjHCAutMePdyg7sQQh4UnAE8rnsw=
       
       "], {{-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}, {-5.316739533975529, -4.4593508581224395`, \
-0.11124105808568469`}, {-4.451813203970924, -4.706888096742872, \
-0.1362961805347467}, {-4.683260466024471, -5.5406491418775605`, 
       0.11124105808568469`}, {-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJYofOTokSByoLmM6a3pNsED9zviGJ8577JP9X6j
beAgcmDtz7DPyiqCB16x2ofNbNpov1n1m6iEgsiBazWrfwpOEoCKL7RnAAOR
AxBa4IBB/L7+/3q5Nr63OF89vy98IJhtJc+d23wHXkLU75+9RfjK+f3CB5bx
BEnu2M4LFd+4/0Wf7L7t84UP/BL6rTplMs+BuxD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAHZ9ong=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMt/QFVO4wT7ldn2kzdt
LOnQEj1wkd3P9HUx/wEpkYLWqN5J9l43I6xcpooceMG8fNbXnTDxJnsGMBA5
AKEFDlwpS7037bWfzTa15Ud3Zwkf4KlbY8SqLHBAAqJ+f66vX3f5VaEDEn8i
UrncBA5IQszfr1zyNcDYQeiAchXrDP5MgQPKEPdgiEPdiWEO1J370e2FunM/
DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AugqWTQ==
       
       "], {{-5.531329884018523, -4.325341537419348, 
       0.12977456753339}, {-5.343278604100026, -3.469461366072062, \
-0.07542252897520049}, {-4.468670115981477, -3.6746584625806524`, \
-0.12977456753339}, {-4.656721395899974, -4.5305386339279385`, 
       0.07542252897520049}, {-5.531329884018523, -4.325341537419348, 
       0.12977456753339}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC66dVtI1lPkgJFrdmR0PfcB5imlsf2uW+wXTpzE
s89A5ICi3qcJz0O4DmyQ+nQxk321/UUPT7Z4CZEDguKVJ4q1OKHis+0ZwEDk
AITmOPD8gGeLbluajf72bT8XPBc+8P5Fm3nPVbYDayHq98fn5X52PC984P5F
3nyJ1awH1kPM39+nqvL20TbhA+d2TVm2pIHlABPEPRjiUHdimAN15350e6Hu
3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwCxsaBB
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewHnCaFdf9TWWLPs+Qr
r5mu6IGp5jsiHk1mPxAlIcf/7/Yse7ZLv9hmTxM5cFo6RufjSZh4lz0DGIgc
gNAcB+Znvkv8lxhm80uX9WdKpvAB0yeLL/OZcRwIh6jf/yWa69PJS0IHsk+4
L5fN4TgQATF//7tO/td6NkIHFqx5XaWziOOAI8Q9+9+iiUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1p70QWrhB3WmPKzwBhR2gJQ==
       
       "], {{-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}, {-5.369827301509674, -2.4836276446310626`, \
-0.03984165745559268}, {-4.487372759012824, -2.6420004479704664`, \
-0.11853114588381125`}, {-4.630172698490326, -3.5163723553689374`, 
       0.03984165745559268}, {-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7GO2mFvqHIgYR2ocoVvcwHLI1rpGfMWm3fH5dY
cEpB5MBrlu0BBXFMBy6dCRISSF9k777ewCJVQORAaVO0hoU+I1R8kj0DGIgc
gNAMB2JC7xcfXR1nszPg/PFZ74UPiP32WN+/8O/+CxD1+wsXzus3vS98QPvb
xDh559/7L0LM36/1KTf8wjnhAw4fb/Guf/JjvznEPRjiUHfCzdGCmgN1536Y
vaJQe6Hu3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwDMJZ9O
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/3W667dG3f5RX2qtq8
Vfr6ogdmZubWH8/5v1+9pOeJZu8C+8lT2fZOny5y4OyWbfuTt8HEJ9gzgIHI
AQjNcOCV2KuaD1OjbXKzfjplZAgfmLVUReGcCsMBVYj6/bevfGq9cEHogLG3
p8McT4YDahDz93vYvzlhYSl04OyH3ISsPIYD5hD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAOcOq2o=
       
       "], {{-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}, {-5.39608595530146, -1.5019171722096671`, \
-0.005423345214476072}, {-4.507847314362481, -1.6097448420306848`, \
-0.10240432460654149`}, {-4.60391404469854, -2.498082827790333, 
       0.005423345214476072}, {-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64dHPtLgmRAxJ92aUqut/3t9xNkpL7Nts+oOdZ
cY2AyIFdcZ9+HDrxZX+k3XRBkSWT7DXcPlvacYgciNWvrElM+QQVb7JnAAOR
AxD6w/7JQn+Olwn629zYyXPs4HfhA24LedltzV/vD4eo37+hWLKn+b3wgR4n
ab6qvGf7IyDm7+/QVQtyfS584NJjDdHtSx/ub4a4By5+ESoOdSfcnG6oOVB3
7ke3F+rO/TjcuQfdX1B3YoQD1J32sHATh4Yb1J32uMITAN4Goo8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/3b3lx6XDCntX2TDxT
fFMNRA/wuhXH3896v7/yw8PrU2sX2TOynVpmNEPkAPvinevzt8LEJ9kzgIHI
AQj9Yf+JCRVC/hfjbP7/NI08my58oFZPWcND9cP+coj6/f8+Z2+adV7owM8Y
t4AJXh/2V0DM3//37ULuDHOhA2XdmRU38j/s3wRxz/4/aOJQd2KYA3XnfnR7
oe7cj8Ode9D9BXUnRjhA3WnPjBZuUHfa4wpPAIesugg=
       
       "], {{-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}, {-5.421742536374846, -0.5241728505774544, 
       0.026865533393664168`}, {-4.529958215082733, -0.5787849537735706, \
-0.0814776365897804}, {-4.578257463625154, -1.4758271494225457`, \
-0.026865533393664168`}, {-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOXD2DAjc2c+AAkQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDq/UMU
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH76tLrP5KToAQYoUNaZ7P13xxp755lBW84aIMTz
ZJOM/qkutl/ko3krbYYImvhkewgPIZ7Qtvjfn5fxNnGbr6nOTBeGi+dA1O/f
m7bW2+i8EFw8F2L+fmmplsLTZghxRYh7MMSh7sQwB+rO/ej2Qt25H4c796D7
C+pOjHCAutMePdyg7sQQh4UnAIbCbzw=
       "], {{-5.446489549934516, -0.45, 
       0.05609885737938949}, {-5.446489549934516, 0.45, 
       0.05609885737938949}, {-4.553510450065484, 
       0.45, -0.05609885737938949}, {-4.553510450065484, -0.45, \
-0.05609885737938949}, {-5.446489549934516, -0.45, 
       0.05609885737938949}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO7QVQtyfS584OJjDdHtSx/at9xNkpL7Nnv/hmLJ
nub3wge6naT5qvKe2UfaTRcUWTJp/42dPMcOfhc+4LaQl93W/DVUvGk/AxiI
HIDQH+wnC/05Xibov0fD7bOlHYfIgVj9yprElE/24RD19gE9z4prBEQO7Ir7
9OPQiS/2ERDz7Ssu3Vy7S0LkgHhfdqmK7nf7Zoh74OISUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw6EHGg5Qd+6HhdslaLhB3bkfV3gCAPXvm6U=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/tt7y4dDhhz2p7Jp4p
vqkGogd43Yrj72e9t6/88PD61NpF9oxsp5YZzRA5wL545/r8rTDxSfYMYCBy
AEJ/sD8xoULI/2Kczf+fppFn04UP1Oopa3iofrAvh6jf/+9z9qZZ54UO/Ixx
C5jg9cG+AmL+/r9vF3JnmAsdKOvOrLiR/8F+E8Q9+/+giUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz0zWrhB3WmPKzwBV+GyiA==
       "], {{-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}, {-5.470041784917267, 
       1.4212150462264295`, 0.0814776365897804}, {-4.578257463625154, 
       1.4758271494225457`, -0.026865533393664168`}, {-4.529958215082733, 
       0.5787849537735706, -0.0814776365897804}, {-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb6lBt+4ZzwAYePt3jXP/lhb2lcIz1j1ur9hQvn
9ZveFz6g9W1inLzzb/tLZ4KEBNIX7d8ZcP74rPfCB0R/e6zvX/gXKj5pPwMY
iByA0AwOMaH3i4+ujtvjvt7AIlVA5EBpU7SGhT6jwwWIevv+uMSCUwoiB16z
bA8oiGNyuAgx3/4a76QV+oYiBxLahSpX9DI7mEPcgyEOdSeGOVB32qPbC3Wn
PQ532sD8JQb1F9Sd8HDQhoYD1J370cMN6k4McVh4AgAZpptG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/tLdddurbv8gp7VW3e
Kn190QMzM3Prj+f8t1cv6Xmi2bvAfvJUtr3Tp4scOLtl2/7kbTDxCfYMYCBy
AEIzOLwSe1XzYWq0TW7WT6eMDOEDs5aqKJxTYXBQhajff/vKp9YLF4QOGHt7
OszxZHBQg5i/38P+zQkLS6EDZz/kJmTlMTiYQ9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBt0Oj6g==
       "], {{-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}, {-5.492152685637519, 
       2.390255157969315, 0.10240432460654149`}, {-4.60391404469854, 
       2.498082827790333, 0.005423345214476072}, {-4.507847314362481, 
       1.6097448420306848`, -0.10240432460654149`}, {-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO5TVXn7aJvwgXO7pixb0sDiwDylNLbfdcv++Lzc
z47nhQ/cv8ibL7Ga1WGD1KeLmeyr9+tv3/ZzwXPhA+9ftJn3XGWDis/ezwAG
IgcgNIfD8wOeLbptaXsueniyxUuIHBAUrzxRrMXpsBai3n7hxEk8+wxEDijq
fZrwPITLYT3EfPuiW7eFZD1FDhi5ZkdG13M7MEHcgyEOdSeGOVB32qPbC3Wn
PQ532qD7C+pOjHCAunM/erhB3YkhDgtPAPxcm8c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewOTpPCuv+pLLHnWfKV
10xX9MBU8x0RjyazO0RJyPH/uz3Lnu3SL7bZ00QOnJaO0fl4EibeZc8ABiIH
IDSHw/zMd4n/EsNsfumy/kzJFD5g+mTxZT4zDodwiPr9X6K5Pp28JHQg+4T7
ctkcDocIiPn733Xyv9azETqwYM3rKp1FHA6OEPfsf4smDnUnhjlQd+5Htxfq
zv043LkH3V9Qd2KEA9Sd9kJo4QZ1pz2u8AQAVVKYpQ==
       "], {{-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}, {-5.512627240987176, 
       3.3579995520295336`, 0.11853114588381125`}, {-4.630172698490326, 
       3.5163723553689374`, 0.03984165745559268}, {-4.487372759012824, 
       2.6420004479704664`, -0.11853114588381125`}, {-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7RJ7tv+3zhA7+EfqtOmczjcL8jjvGZ8679s7cI
Xzm/X/jAMp4gyR3beR1esdqHzWzauN/3Fuer5/eFDwSzreS5c5sPKr5wPwMY
iByA0AIOBvH7+v/r5e7ZrPpNVEJB5MC1mtU/BScJOLyEqLdP9X6jbeAgcmDt
z7DPyiqCUPGN9hKFjxw9EkQONJcxvTXdJuhwF+IeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHdihAPUnfvRww3qTgxxWHgCAL+ynUU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMvvoCqncYL9ymz7yZs2
lnRoiR64yO5n+rqY30FKpKA1qneSvdfNCCuXqSIHXjAvn/V1J0y8yZ4BDEQO
QGgBhytlqfemvfaz2aa2/OjuLOEDPHVrjFiVBRwkIOr35/r6dZdfFTog8Sci
lctNwEESYv5+5ZKvAcYOQgeUq1hn8GcKOChD3IMhDnUnhjlQd+5Htxfqzv04
3LkH3V9Qd2KEA9Sd9ujhBnUnhjgsPAGKP47N
       "], {{-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}, {-5.531329884018523, 
       4.325341537419348, 0.12977456753339}, {-4.656721395899974, 
       4.5305386339279385`, 0.07542252897520049}, {-4.468670115981477, 
       3.6746584625806524`, -0.12977456753339}, {-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM4qm7qvvlP4QNX7La6yoUIOzLGmd3zW79/vtiT5
yv8NwgeCvJRvZjwWcmCyOzepQ37rfuVLhq/qbwgf0Fw6MWdLoTBUfOl+BjAQ
OQClHdYYM6q6zyrcc1f3nGiDusiB61F5k737RBwYIOrtd0XP0WbwFzmwbusd
tekyog6MEPPtp3VmOTaUiRxoFfDe9WiVqAMDxD1w8TaoONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/bBwq4aGG9Sd+3GFJwBRVpSe
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQo7VCYKnONZ0Wlvf6g6
y0pd9ADH8S13G1cLOyx7zWWyWarRXuGhrencySIHWpJvvTtwFSZeaM8ABiIH
oLSDyL09YVcbbWweyh06lZQjfKBmjqqgvZaIw1KI+v0HbVumHr0hdOCHhbdS
XQhMvHH/ohi3BA1XoQMlVwuM99aJOJRD3IMhDnUnhjlQd+5/gGYv1J37cbhz
jzyav6DuxAgHqDvt0cMN6k4McVh4AgAfYJdM
       "], {{-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}, {-5.548186796029076, 
       5.293111903257128, 0.1362961805347467}, {-4.683260466024471, 
       5.5406491418775605`, 0.11124105808568469`}, {-4.451813203970924, 
       4.706888096742872, -0.1362961805347467}, {-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4Yy/7lcYXAgfvKbh9jVokeqGlk3Jnav99e8SXL
j+kBAgemHtL7ZisjemDl6tUXnLm22k8oYfrjrSFwwCtR/LdcnwhUfKk9AxgI
HIDQIgd4+Ptv9HYU2twX+82esZ7/wLZ5L1geFgofWA5Rv3+f7jf+C3H8B7Jt
L3Ieeix0YAXE/P1zXT6KW/DxH1C8s5NvcajQgSqIezDEoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBrdqOh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUPNP+6yfRwRby99eKr
ywrVBQ8EBu79cG218IF1gRPXOEiH2s+9mHV5x2SBAytXxFW8vgoTd7VnAAOB
AxBa5IDAEeWnW6cJ2hyL0Yrsu8F3IDx8YbuIlsiB1RD1+7t3hmyS2ch7YP06
J37NEJEDayHm7w8Uq+de3clzgI3tyTTbOpEDjRD37A9AE4e6E8McqDv3H0Wz
F+rO/TjcuQfdX1B32luhhQPUnfbo4QZ1J4Y4LDwBfGOi6w==
       
       "], {{-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}, {-4.314722153887294, -4.460348007608924, \
-0.12134946625710644`}, {-3.449163700929936, -4.706911647569121, \
-0.12521417370309038`}, {-3.685277846112706, -5.539651992391076, 
       0.12134946625710644`}, {-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA42vzA7MEngwJxPD45f2Cp4QNzPZMN0k1325lWm
e7sdBQ7sXejQ+kBZ8MDue0oKqRUb7WX2zrp3VEHgwP2ABU4fJgpAxRfaM4CB
wAEY/VDW6sFf2Vybk62nnEr28R9wjttfJX+H78BOiPr9E7mntr6o4T/Qtqfu
q90O3gO7IObvj5oYfyLGmv/ASSm7grgpPAfEIO6Bi5+AikPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AfqOk/Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj/+AgvJhye12E+1PdSTf
fqMleIDr5b9rNiX8Bxpvriv3/Ndmn3pkY27ZVIEDrSX12XK7YOJl9gxgIHAA
RjtsFbS01XS2MSufoyJ8le/AXleHUx+UBA7UQ9Tvz3ln4am2ivdAdXfDlIeu
AgcaIObvX5R6NdeynueAxcUDcZcyBA7IQ9yDIQ51J4Y5UHfuR7cX6s79ONy5
B91fUHdihAPUnfbo4QZ1J4Y4LDwB/I2ewA==
       
       "], {{-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}, {-4.341864306775701, -3.470080753685618, \
-0.08552419621584771}, {-3.466106818667752, -3.674810750402369, \
-0.11920580050090333`}, {-3.658135693224299, -4.529919246314382, 
       0.08552419621584771}, {-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF72W9d9h5fAAaMP98Vv1XEfOHx2jiOb4xZ7yb/F
+hcMBQ6Uf7VPnRjCdSBa6OKaWMbV9r3/doq/kBA4sPvX/E0eWpxQ8dn2DGAg
cABCcxxY8CQiVbkxzeY5U88F/XP8B1xZE3y3X2U7EAFRv/8cq8TC+Dn8B7q4
DszKW816IBJi/v6tHEsK+7P4D5zjV3ih2shy4BDEPRjiUHfCzemEmgN15350
e6Hu3I/DnXvQ/QV1JzwcyqDhAHWnPXq4Qd2JIQ4LTwBENJ2Z
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9Hst+oKrogO/yH3PtrS2b
mQ/qCh7Yvtun89dk9gPLF141lvo92X7unIOND6YJHLgdu8zl70mYeLM9AxgI
HIDQHAcSNt65OnVZgM3RYzV/7C7xHVBdFLmbyYzjwFKI+v1dvT9/1C7hPeDp
srmMNYfjwDKI+fsDQsq+7injOZD3jMeIYxHHgQqIe/b7o4lD3YlhDtSd+9Ht
hbpzPw537kH3F9SdGOEAdac9erhB3YkhDgtPAFgJs7M=
       
       "], {{-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}, {-4.369053812165066, -2.4839433884236968`, \
-0.04984834375199349}, {-3.4850090079231695`, -2.642177776810767, \
-0.10838604463507687`}, {-3.630946187834934, -3.5160566115763032`, 
       0.04984834375199349}, {-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP6Vx8fkYyRwwGf/45mZvcwHpiyon/lj9mr75V/i
GDsUBQ7cvTI9zS2O6UDygf8Cv9MX2QdXrWc4IiBwIP+Vt7GyPiNUfJI9AxgI
HIDQDAf8X4fI+K6Ns4nkXviv/B7/AWXtjJk7F/7dnwhRv3+zmNPf93v4D7iF
XTAqdv69Pwli/n4epce/02fzH8hstDij8/TH/kkQ92CIQ92JYQ7UnfvR7YW6
cz8Od+6B+SsP6i+oOzHCAepOe1i4eUPDDepOe1zhCQC0oq21
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/3x+men8N7YrH97gJz
xhv6ggf+MlaoH8j5v//yxEw1oYRZ9rE7ZjO8mS5w4B/DHuGEbTDxLnsGMBA4
AKEZDtzyW3tq569QG9f+E//UL/AdaPyv+O28CsOBixD1+7vlJv71X8B7gOm/
85v5ngwHLkHM339hbeSf8gKeA03/Uh/l5zEciIW4B0Mc6s79XWjmQN25H91e
qDv343DnHnR/Qd2JEQ5Qd9qjhxvUnRjisPAEAIcMpkw=
       
       "], {{-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}, {-4.3959655727217335`, -1.5020265855785278`, \
-0.01528868040643376}, {-3.505798282008966, -1.6098752655742845`, \
-0.09255999958932283}, {-3.6040344272782665`, -2.4979734144214722`, 
       0.01528868040643376}, {-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5JPMjtIylwIOyLsgez7vf9F7l/qPv/mW3vO007
9q6AwIEniw7dWnPiy/6H7AFHTVZMslc/PXVdHofAgaLAxNywlE9Q8SZ7BjAQ
OAChP+wvS2r9HC7hb7M588oipff8B2RjbVWDzV/vvw9Rvz/18gpX13v8Byx3
VXkty3u2/wHE/P0StrUv0s/yHwgT35H/c+nD/ech7oGLh0LFoe6Em2MBNQfq
zv0we2Wg9kLduR+HO/eg+wvqToxwgLrTHhZuodBwg7rTHld4AgAMeqjF
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7vn77NLlz3yDL7iJWd
hQqGggcO1l+N3Jf1fv8pj39yz6Pm2a+5csRiwgyBAw/2v9KJ3woT77NnAAOB
AxD6w/6g55dnHvCOtFkRVtZ3/xzfAYEFXZkBqh/2H4eo3x+w9o3M/rm8BxQc
RC8v8Pqw/wTE/P0/mJNXz8vhOaD/YL7Nx/wP+6dC3IMhDnUnhjlQd+5Htxfq
zv043LkH5q+HUH9B3YkRDlB32sPCbRE03KDutMcVngBF/rXf
       
       "], {{-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}, {-4.422258832323806, -0.5241808713787737, 
       0.01713579186011437}, {-3.5283328583537994`, -0.5788402128371133, \
-0.07179513331845389}, {-3.5777411676761943`, -1.4758191286212263`, \
-0.01713579186011437}, {-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOHD2DAjc2c+AAgQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQC/ZULY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHax4j8bdkrwAAMUHG/5UrTy+HJ7vZp4435DhPjW
6NnvHm6Zby++b/3M4zME0MT77SE8hPgBRZ05gjlRNpeaF5wpOMcHF98IUb9/
KbvjzIdzeOHimyHm7y/vfpgalM0DFz8KcQ+GONSdGOZA3bkf3V6oO/fjcOce
dH9B3YkRDlB32qOHG9SdGOKw8AQAllp+eA==
       "], {{-4.4475967445892515`, -0.45,
        0.04644517448674317}, {-4.4475967445892515`, 0.45, 
       0.04644517448674317}, {-3.552403255410748, 
       0.45, -0.04644517448674317}, {-3.552403255410748, -0.45, \
-0.04644517448674317}, {-4.4475967445892515`, -0.45, 
       0.04644517448674317}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJawrX2Rfpb/QKj4jvyfSx/aX+T+oe7/Z/b+1Msr
XF3v8R+w2FXltSzvmf1D9oCjJism7d+ceWWR0nv+AzKxtqrB5q+h4k37GcBA
4ACE/mBfltT6OVzCf4/66anr8jgEDhQFJuaGpXyyvw9Rb+87TTv2roDAgSeL
Dt1ac+KL/QOI+fYliQe5fSQFDoR+UfZg1v1ufx7iHrh4GFQc6k4Mc6DutEe3
F+pOexzutIH5SxbqL6g74eFgCQ0HqDv3w8ItDBpuUHfuxxWeAEtUo+I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7bT99mF657ZJl9xMrO
QgVDwQMH669G7st6b3/K45/c86h59muuHLGYMEPgwIP9r3Tit8LE++wZwEDg
AIT+YB/0/PLMA96RNivCyvrun+M7ILCgKzNA9YP9cYj6/QFr38jsn8t7QMFB
9PICrw/2JyDm7//BnLx6Xg7PAf0H820+5n+wnwpxD4Y41J0Y5kDduR/dXqg7
9+Nw5x6Yvx5C/QV1J0Y4QN1pDwu3RdBwg7rTHld4AgAWM65f
       
       "], {{-4.422258832323806, 0.5241808713787737, 
       0.01713579186011437}, {-4.471667141646201, 1.4211597871628867`, 
       0.07179513331845389}, {-3.5777411676761943`, 
       1.4758191286212263`, -0.01713579186011437}, {-3.5283328583537994`, 
       0.5788402128371133, -0.07179513331845389}, {-4.422258832323806, 
       0.5241808713787737, 0.01713579186011437}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZRevw7fTb/gcxGizM6T3/YT1lQP/PH7NX7N4s5
/X2/h/+AW9gFo2Ln3/bJB/4L/E5ftD+Se+G/8nv8B5S1M2buXPgXKj5pPwMY
CByA0AwO/q9DZHzXxu0JrlrPcERA4EDeK29jZX1Gh0SIevvlX+IYOxQFDty9
Mj3NLY7JIQlivv2vPD4mHyOBA977H8/M7GV2mARxD1zcByoOdSeGOVB32sPs
zYfaC3WnPQ532qD7C+pOjHCAunM/erhB3YkhDgtPAO1TqEI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/t43TPz+E9sdh+d4E5
4w19wQN/GSvUD+T8t788MVNNKGGWfeyO2Qxvpgsc+MewRzhhG0y8y54BDAQO
QGgGh1t+a0/t/BVq49p/4p/6Bb4Djf8Vv51XYXC4CFG/v1tu4l//BbwHmP47
v5nvyeBwCWL+/gtrI/+UF/AcaPqX+ig/j8EhFuIeDHGoO/d3oZkDded+dHuh
7tyPw5170P0FdSdGOEDdaY8eblB3YojDwhMAV0GezA==
       
       "], {{-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}, {-4.494201717991034, 
       2.3901247344257155`, 0.09255999958932283}, {-3.6040344272782665`, 
       2.4979734144214722`, 0.01528868040643376}, {-3.505798282008966, 
       1.6098752655742845`, -0.09255999958932283}, {-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7KsaSwP4v/wDl+hReqjSwOh8/OcWRz3LL/HKvE
wvg5/Ac6uQ7MylvN6hAtdHFNLOPq/c+Zei7on+M/4Mqa4Lv9KhtUfPZ+BjAQ
OAChORwWPIlIVW5M29P7b6f4CwmBA7t/zd/kocXpEAFRby/5t1j/gqHAgbKv
9qkTQ7gcIiHm2y/7reu+w0vggNGH++K36rgdDkHcgyEOdSfcnHKoOVB32qPb
C3WnPQ532qD7C+pOeDh0QcMB6s796OEGdSeGOCw8AVQNlWA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9HsvuUFV0wHf5j7n21pbN
zAd1BQ9s3+3T+Wsyu8PyhVeNpX5Ptp8752Djg2kCB27HLnP5exIm3mzPAAYC
ByA0h0PCxjtXpy4LsDl6rOaP3SW+A6qLInczmXE4LIWo39/V+/NH7RLeA54u
m8tYczgclkHM3x8QUvZ1TxnPgbxnPEYcizgcKiDu2e+PJg51J4Y5UHfuR7cX
6s79ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBKD6sMw==
       "], {{-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}, {-4.5149909920768305`, 
       3.357822223189233, 0.10838604463507687`}, {-3.630946187834934, 
       3.5160566115763032`, 0.04984834375199349}, {-3.4850090079231695`, 
       2.642177776810767, -0.10838604463507687`}, {-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmII6aGH8ixpr/wAkpu4K4KTwO4n4mG6ab7No/kXtq
64sa/gNte+q+2u3gddh9T0khtWLj/pOtp5xK9vEfcI7bXyV/hw8qvnA/AxgI
HIDSDg9lrR78lc3dI7N31r2jCgIH7gcscPowUcBhJ0S9vXmV6d5uR4EDexc6
tD5QFnTYBTHfPtj8wuzAJIEDcz49OH5hq6CDGMQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/fDwu0kNNyg7tyPKzwBhSqbwA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj99BQfmw5Ha7ifanOpJv
v9ESPMD18t81mxJ+h8ab68o9/7XZpx7ZmFs2VeBAa0l9ttwumHiZPQMYCByA
0g4OWwUtbTWdbczK56gIX+U7sNfV4dQHJQGHeoj6/TnvLDzVVvEeqO5umPLQ
VcChAWL+/kWpV3Mt63kOWFw8EHcpQ8BBHuIeDHGoOzHMgbpzP7q9UHfux+HO
Pej+groTIxyg7rRHDzeoOzHEYeEJAMzCl0A=
       "], {{-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}, {-4.533893181332248, 
       4.3251892495976305`, 0.11920580050090333`}, {-3.658135693224299, 
       4.529919246314382, 0.08552419621584771}, {-3.466106818667752, 
       3.674810750402369, -0.11920580050090333`}, {-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7r8lHcgo//gOKdnXyLQ4UcahoZd6b279+/T/cb
/4U4/gPZthc5Dz0Wcli5evUFZ66t+++L/WbPWM9/YNu8FywPC4Wh4kv3M4CB
wAEILeLAw99/o7ejcM+EEqY/3hoCB7wSxX/L9Yk4LIeot1d8yfJjeoDAgamH
9L7Zyog6rICYb78xlv3L4wqBA/eV3T7GrBJ1qIK4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAHIEmuU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUdmn/dZHq4It7eevHV
ZYXqggcCA/d+uLZa2GFd4MQ1DtKh9nMvZl3eMVngwMoVcRWvr8LEXe0ZwEDg
AIQWcRA4ovx06zRBm2MxWpF9N/gOhIcvbBfREnFYDVG/v3tnyCaZjbwH1q9z
4tcMEXFYCzF/f6BYPffqTp4DbGxPptnWiTg0QtyzPwBNHOpODHOg7tx/FM1e
qDv343DnHnR/Qd1pb4UWDlB32qOHG9SdGOKw8AQATJibaw==
       
       "], {{-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}, {-4.550836299070064, 
       5.293088352430879, 0.12521417370309038`}, {-3.685277846112706, 
       5.539651992391076, 0.12134946625710644`}, {-3.449163700929936, 
       4.706911647569121, -0.12521417370309038`}, {-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ7/si8+xvHgZkCvL+frhQ9IMHfz+SUsN+ec9ab
8zFLOA4IcsctfycteiAtPn7NtVdb7Fl9v6XrBXEc6GBdH/y9VwQqvsSeAQw4
DkBokQP155f0x+YV2vzexDnj4lr2AxW/AtZwFAkfSIGo3/89VdhgcTT7gfdf
FkYIPhE6kAoxf/8nCdkTJZzsB9Lff2KRChM6IAZxD4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBAADoqNh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQPhHwIYj76t2k/y4nu
Wk5/rgNNTX5LQ9YIHzg2NY8lJqhyP9OTo/ta1DkPODouD9K6BhPP3M8ABhwH
ILTIAZVLbJHfJU33/JO2cqy+wXZg/76ItVc1RQ4chqi3/2Ne0vRtA+uButqN
UauDRQ4chZhv/yt43eHCTpYDNjZcHI21IgeCIO7BEIe6E8McqDvt0e2FutMe
hztt0P0FdSdGOEDduR893KDuxBCHhScAWr2f1g==
       
       "], {{-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}, {-3.312505755072035, -4.46152110262191, \
-0.13183561781754752`}, {-2.4467287942367104`, -4.706646159126566, \
-0.11328943868710814`}, {-2.687494244927965, -5.53847889737809, 
       0.13183561781754752`}, {-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP545ofSjhMcB3okrWeUbBU8cFXsA8NPiV32CzsC
xC+0chyITVMXWKwseKA/5Wvo79SN9gEuK7hfOHEc0N8s3HFxogBUfKE9Axhw
HIDQAgemL3fu9/2fY7Nhd/gX8b3sBxbPvPE+5g7fgV6I+v3x5etf6FexH3Az
3nh/5w7eA30Q8/fzG7PfdTdnP/DyTOd5sak8By5D3AMXfwEVh7oTwxyoO/ej
2wt1534c7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDdFqzl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwHGE6s+RXFXGHfkWRQ
Hx/GdeBOSIDqhRL+A6tvyS63YSqwdzGcsV9fm/NAntYKoYxdMPEEewYw4DgA
oQUOyIi3i6Wu07LZcy7d4cIVtgMnX63+dlpJ4MBKiPr9FXPPNyxYyXpg0tXw
t9NdBQ6sgpi/3zTH/GBBHcuB6APMT5IzBA78Ow52D4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBADqD5zw
       
       "], {{-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}, {-3.3402540371688305`, -3.4708538614882167`, \
-0.09608097776553255}, {-2.4637310374127157`, -3.6747409669130344`, \
-0.10780612765928528`}, {-2.6597459628311695`, -4.529146138511783, 
       0.09608097776553255}, {-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62WS9yzQyOA4/smmyS6rgPTJ+z5KKT8Rb7n+Ul
1idSOQ680VxT6xjCdeDUBYNDzO9X2f+13iX7xIjjwDeRa/sUtDih4rPsGcCA
4wCM/rtWo/xGYZoN8xHXR9Jn2Q9wvdZ0vH+V7cAJiPr97B3dR8xnsR8QuRbc
tG8164GTEPP3c/lcXBaczn5A7mDt4bmNLAemQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBXi+qQw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gP1L68vX3Lj0n2XCHO
fyNjuA7stfn+wXkK+4G/D8/Pn+3dac+6auE/HT3OA3Hzqn8onoKJV9ozgAHH
ARgdZKPLGi7iavM7NI7x8kW2A4sSW9jvmXIc+AVRv//b6j1MyxazHnA+zMG/
J5vjwB+I+fs/MkqzVJayHHiq0is2ayHHgRqIe/Z/QBOHuhPDHKg796PbC3Xn
fhzu3IPuL6g7McIB6k57frRwg7rTHld4AgAvILGg
       
       "], {{-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}, {-3.3680927955513313`, -2.484382010548441, \
-0.0603803181271666}, {-2.482812247597164, -2.642196372468562, \
-0.0974340437929547}, {-2.6319072044486687`, -3.515617989451559, 
       0.0603803181271666}, {-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4M9/C6lsZxoPFS3AK9XuYDbm+uByhMXG0faGVw
p8+F40BYzxRR+TimAwYeT00PJCyy15CVyHNX4jig7Xaqi1+fESo+yZ4BDDgO
QGiGA34VlyMdFsbZ3Hj0fOKOu+wHVhVnv3qw8O9+PYj6/euPnlcu3M1+IOT5
tSsHnX/v14eYv799xfatmjPZD/yLctq/6OmP/S4Q98DF/0LFoe6EmxMMNQfq
zv3o9kLduR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBnoag1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/v/zlJ2d7n2Bz760E9
IccTuA7suxrw72fO//3LeHLr7+pNts/WdFuVbMB54H6Wxv+abTDxZnsGMOA4
AKEZDoiIctcf++FvM/XaztA559kOTDiV3XBQheHAEoj6/Zpri1dbzGc9oDj1
OkOzJ8OBpRDz9+9r1mW8msdyYGO8c6NLHsOB7xD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9Sd8HDYDw0HqDvt0cMN6k4McVh4AgAmcqfC
       
       "], {{-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}, {-3.3956693749101743`, -1.5022218105675396`, \
-0.025741404070748052`}, {-2.503903797978213, -1.6099050111530673`, \
-0.08194179651477952}, {-2.6043306250898257`, -2.49777818943246, 
       0.025741404070748052`}, {-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO573ue4z5jjwIEg3y+Pdb7vn3K7wCH222x7Ltf4
a3VKHAcaeox/TD/xZf/O51+17JZMsm9dpJ9tL8hxwOGY5B/vlE9Q8SZ7BjDg
OAChP+w3bnL5tEfQ36Y69sKUA+/YDzQUn2HPMH+9fztE/f5vuxZoNt5lP8Dw
fAb/hbxn+3dAzN9fJFG4z/EMUH1UqrjFsof7J0PcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8ARi2tic=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff7T/t4CB4sXGg/b3W6
TUMy14FDASv47mW9379799aDYU7T7c9fNZY7YMh5IFEjhD1/K0y83Z4BDDgO
QOgP+wtkDn37lBhsY6h15qH9ObYD51+H1niofti/A6J+f1LIjMP1c1gPzL++
+scErw/7d0LM3z+5LmXp/iyWA3mHGUtv5n/YfwriHgxxqDsxzIG6cz+6vVB3
7sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBdsrFT
       
       "], {{-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}, {-3.4226114232035196`, -0.5242334257478558, 
       0.006764007855904815}, {-2.5268581199223967`, -0.5788474109204276, \
-0.06137799302847672}, {-2.5773885767964804`, -1.4757665742521442`, \
-0.006764007855904815}, {-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgOHD2DAjc2c+AAjgOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQBoNUJg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF6is01r4TTuAwxQ4NEaqnu2epF93olzhdkpXHDx
xJjjEwWXzrA3T3m+w9SIE028wx7C44CLByipLenrDLE5OVvC/dRZNrh4HET9
/snmhn1TZrPCxRMg5u+Puex5NS6TBS7uDnEPhjjUnfsnoZkDded+dHuh7tyP
w5170P0Fdad9Llo4QN1pjx5uUHdiiMPCEwDGkGug
       
       "], {{-3.44854958885624, -0.45, 
       0.03610078028101299}, {-3.44854958885624, 0.45, 
       0.03610078028101299}, {-2.55145041114376, 
       0.45, -0.03610078028101299}, {-2.55145041114376, -0.45, \
-0.03610078028101299}, {-3.44854958885624, -0.45, 
       0.03610078028101299}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6SKNzneIb9QENUqrjFsof2U24XOMR+m73/264F
mo132Q8wPJ/BfyHvmf3O51+17JZM2l8de2HKgXdA9cVn2DPMX0PFm/YzgAHH
AQj9wd64yeXTHkH/Pa2L9LPtBTkOOByT/OOd8sl+O0S9PZdr/LU6JY4DDT3G
P6af+GK/A2K+fd/zPsd9xhwHDgT5fnms891+MsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEACBnrXM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff2p308BA8WLrSftzrd
piGZ68ChgBV897Le2+/evfVgmNN0+/NXjeUOGHIeSNQIYc/fChNvt2cAA44D
EPqDfYHMoW+fEoNtDLXOPLQ/x3bg/OvQGg/VD/Y7IOr3J4XMOFw/h/XA/Our
f0zw+mC/E2L+/sl1KUv3Z7EcyDvMWHoz/4P9KYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnAC3nqdM=
       "], {{-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}, {-3.4731418800776033`, 
       1.4211525890795724`, 0.06137799302847672}, {-2.5773885767964804`, 
       1.4757665742521442`, -0.006764007855904815}, {-2.5268581199223967`, 
       0.5788474109204276, -0.06137799302847672}, {-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG5fsX2r5kz2A3+jnPYvevrD3u3N9QCFiav3rz96
XrlwN/uB4OfXrhx0/m1v4PHU9EDCov03Hj2fuOMu+4FVxdmvHiz8CxWftJ8B
DDgOQGgGB7+Ky5EOC+P2aMhK5LkrcRzQdjvVxa/P6KAHUW8faGVwp8+F40BY
zxRR+TgmB32I+faV4R5e19I4DjReilug18vs4AJxD4Y41J0Y5kDdaY9uL9Sd
9jjcaYPuL6g74eEQAg0HqDv3w8LtHzTcoO7cjys8Aa+lo7o=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/b/5ykbO9zbI799aCe
kOMJXAf2XQ349zPnv/0yntz6u3qT7bM13VYlG3AeuJ+l8b9mG0y82Z4BDDgO
QGgGBxFR7vpjP/xtpl7bGTrnPNuBCaeyGw6qMDgsgajfr7m2eLXFfNYDilOv
MzR7MjgshZi/f1+zLuPVPJYDG+OdG13yGBy+Q9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHfCw2E/NByg7rRHDzeoOzHEYeEJAPaYoEI=
       
       "], {{-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}, {-3.496096202021787, 
       2.3900949888469327`, 0.08194179651477952}, {-2.6043306250898257`, 
       2.49777818943246, 0.025741404070748052`}, {-2.503903797978213, 
       1.6099050111530673`, -0.08194179651477952}, {-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIObyubgsOJ39gNzB2sNzG1kcps9ZctHJeMt+9o7u
I+az2A+IXAtu2rea1eHUBYNDzO9X7Wc+4vpI+iz7Aa7Xmo73r7JBxWftZwAD
jgNQ2uHvWo3yG4Vpe/5a75J9YsRx4JvItX0KWpwOJyDq7X+Wl1ifSOU48EZz
Ta1jCJfDSYj59t8260WumcFx4JFdk01SHbfDNIh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+5HDzeoOzHEYeEJAHHOos0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gdal/e3r7lxyR7rhDn
v5ExXAf22nz/4DyF3eHvw/PzZ3t32rOuWvhPR4/zQNy86h+Kp2DilfYMYMBx
AEo7BNnosoaLuNr8Do1jvHyR7cCixBb2e6YcDr8g6vd/W72Hadli1gPOhzn4
92RzOPyBmL//I6M0S2Upy4GnKr1isxZyONRA3LP/A5o41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfa86OFG9Sd9rjCEwD/Rqog
       "], {{-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}, {-3.517187752402836, 
       3.357803627531438, 0.0974340437929547}, {-2.6319072044486687`, 
       3.515617989451559, 0.0603803181271666}, {-2.482812247597164, 
       2.642196372468562, -0.0974340437929547}, {-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEG3MftfdnP3AizOd58Wm8jhcFfvA8FNi1/748vUv
9KvYD7gZb7y/cwevQ3/K19DfqRv3b9gd/kV8L/uBxTNvvI+5wwcVX7ifAQw4
DkBoAYfpy537ff/n7AlwWcH9wonjgP5m4Y6LEwUceiHq7Rd2BIhfaOU4EJum
LrBYWdChD2K+/cczP5R2nOA40CNpPaNkq6DDZYh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+6HhdtLaLhB3bkfV3gCANZ+pEI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwODCfW/IpirrDvSDKo
jw/jOnAnJED1Qgm/w+pbssttmArsXQxn7NfX5jyQp7VCKGMXTDzBngEMOA5A
aAEHGfF2sdR1WjZ7zqU7XLjCduDkq9XfTisJOKyEqN9fMfd8w4KVrAcmXQ1/
O91VwGEVxPz9pjnmBwvqWA5EH2B+kpwh4PDvONg9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITALpElXA=
       "], {{-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}, {-3.5362689625872843`, 
       4.325259033086965, 0.10780612765928528`}, {-2.6597459628311695`, 
       4.529146138511783, 0.09608097776553255}, {-2.4637310374127157`, 
       3.6747409669130344`, -0.10780612765928528`}, {-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4kIXuihJP9QPr7TyxSYUIOEvz9TE4J+/d/TxU2
WBzNfuD9l4URgk+EHNLi49dce7Vl/+9NnDMurmU/UPErYA1HkTBUfMl+BjDg
OAChRRzqzy/pj80r3MPq+y1dL4jjQAfr+uDvvSIOKRD19pyz3pyPWcJxQJA7
bvk7aVGHVIj59nzPH5l3f+M4MFOA9/fTlaIOYhD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAA9Zmrc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQdQj4EMR/927Sf5UR3
Lac/14GmJr+lIWuEHY5NzWOJCarcz/Tk6L4Wdc4Djo7Lg7SuwcQz9zOAAccB
CC3ioHKJLfK7pOmef9JWjtU32A7s3xex9qqmiMNhiHr7P+YlTd82sB6oq90Y
tTpYxOEoxHz7X8HrDhd2shywseHiaKwVcQiCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAq8phW
       "], {{-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}, {-3.5532712057632896`, 
       5.293353840873434, 0.11328943868710814`}, {-2.687494244927965, 
       5.53847889737809, 0.13183561781754752`}, {-2.4467287942367104`, 
       4.706646159126566, -0.11328943868710814`}, {-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ4gd9PG9jfDgcXcFt1NK0UPHAo8djFEfr891/4J
GnXLGQ4cYr8Qs0Za9IDOQ72Hvfu32LfGe4jsD2Y48JA5Q+9arwhUfIk9AwQc
gFAiB/zT/kzw9iq0+eaQf70x4v9++T/TL2oWCR/Qgqjf/7rx3jrmjf/22/3Q
Xxz8ROiANsT8/Q8P+ba1cv7bH/vleEltmNCB/RD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdad9P1q4Qd1pjys8AehjrlY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUPLJc/4uq2bOr+M8WM
yTf9mA5Uu1SfYFwrfMBUawP75rs9+5/tbNiYo854wG6R7ZOGazDxmv0MEHAA
QokcuHZWyFCUz2OPSc+/OWob/+4/FHtIul5T5IARRL19hsRfS9+k3/tbd7eY
/wsSOWACMd9+zpLf14qFf+53l3QPrq0RObAM4h772WjiUHfap6OZA3WnPbq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAEkooqA=
       
       "], {{-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}, {-2.310075459334159, -4.462891124238714, \
-0.14271392748137285`}, {-1.4445737499249551`, -4.7060347804248615`, \
-0.10042972870477429`}, {-1.689924540665841, -5.537108875761286, 
       0.14271392748137285`}, {-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Vybv9yBmGA/YB/xaqbBU8ULHLzvfgu532Nhs3
qzR3MByoNw05mKsseOC3Wr3xNc+N9vNuRE5ydGE4cEBq1YNtEwWg4gvtGSDg
AIQSOOAzrY4h9UKOzRE/n9s15f/3N55abTfpDt+BnxD1+zvmztj2892//UxT
w2tVdvIe+AUxf7/PmycTy9L+7W+OZ96zbSrPgTKIe+DiTVBxqDsxzIG6cz+6
vVB37sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBS1bE6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgPnFq99Vf5rfL93Wse
PpgcxnTgBFuK38ZS/gM7+939vp7N3+92reCDpzbjgRRmo+U3dsHE4/czQMAB
CCVw4Mj3CWLfG7T2lAbLyees/Lvf71/amslKAge2QdTbv1pmY3cj6Pf+OX/O
Rqi7ChzYATHfPv5XVKzLnx/7X/0yYd2dLnDgJMQ9GOJQd2KYA3WnPbq9UHfa
43CnjSuav6DuxAgHqDv3o4cb1J0Y4rDwBABBeLcr
       
       "], {{-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}, {-2.3384267856882803`, -3.4718030810301665`, \
-0.10712294581215505`}, {-1.4616040559471155`, -3.674401807986821, \
-0.09547578114449966}, {-1.66157321431172, -4.528196918969834, 
       0.10712294581215505`}, {-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6nOn/909kMB7Y41q/9Xst9QFammi1Daov9/sMi
pe/SGQ6c015V/CuY60CN6hKOB2dX2d9P7LL6bsxw4LnoVcu/mpxQ8Vn2DBBw
AEJxHLCRv7fRKizNxtHmdZfgjP/7JV9pHWO6xnagCqJ+f3PFNVFlg//7ja6E
9rCuYT1QDTF//5EtBxeYnPi332dfQxBHE8sBaYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnANnAoq4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewHlk04O1/wVo39nCqR
vKcxTAey8u/Wn5jCfqAg4d5+bptiez9bru1FeowHtm5/Z59yCiaebM8AAQcg
FMcB9t+P5ePZDWxSWl9PlFr8d7+3h+CB2aYcB/Ig6vef4LqubOr2e/+0CUoN
5tkcB/Ih5u/XmXBoq//LH/sf3jB2uLyA48ASiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA8ayh1w==
       
       "], {{-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}, {-2.366917531924889, -2.4849645070759623`, \
-0.07148402475128206}, {-1.4808390979345027`, -2.642020364891229, \
-0.0855718330639844}, {-1.633082468075111, -3.5150354929240377`, 
       0.07148402475128206}, {-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62IuiPSCbDgYRVilE/e5gP+G1kCMktX22/pKDn
L68bw4HXx7In/o5lOmBaxmAxz3+RfZDFsX9sygwHSh9vPfFXjxEqPsmeAQIO
wOhwqbDYTS1xNjH9xUyfdv7fL2o5JY9l0d/9xhD1+3fIPWd5Uvx/v1aRxl0O
l9/7TSDm7xddF8V+Tff/fofVe7x5n/3Y7wtxD4Y41J0Y5kDduR/dXqg79+Nw
5x50f0HdiREOUHfao4cb1J0Y4rDwBAC52J69
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7v12H7V1ZoMtHeLyTX
Z1oi0wG/P/Z8zbn/9z/fFOQ5/UObvfoqM7XTBowH1P/Jtx/cBhMvs2eAgAMw
OuvVkfTLss42m1dP2pw57+/+NwwFNvNVGA48gajfnxqumn7Z5vf+m4wPKuw8
GQ48hZi/X4J5h5Tt7R/7jzIFbL2by3BAG+IeDHGoOzHMgbpz/yY0e6Hu3I/D
nXvQ/QV1p70vWjhA3WmPHm5Qd2KIw8ITADZMq2Y=
       
       "], {{-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}, {-2.395165371281734, -1.502519492476819, \
-0.03684391366627121}, {-1.5022155123688876`, -1.609810554839941, \
-0.07044714869685079}, {-1.604834628718266, -2.497480507523181, 
       0.03684391366627121}, {-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPYT3e371IThwKoTn1OP63zf/9XlQ1b/w9n2ncnq
nc7KDAeOtS5613Liy/6fugvmxE+bZH904+QjCwUZDjx2Cix3SvkEFW+yZ4CA
AxDqw/55PglR83/52ZTPuVG2587//VZVsYLV5q/3f4eo3//WYuPbip3/95d8
2aX0Le/Z/h8Q8/enXO1MMZ32f/+6PAmTwmUP93+GuAcuvgYqDnUn3JxiqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwWwkNN6g77XGFJwB/9sFU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7zfn6Vy8W1k8XT7RYLH
uapSmA5M+CfF7Jv9fv+T1oPPy1367S92JLPaGjEe8KjvbVy2FSZeb88AAQcg
1If9k96ffp3M52UT/87ia+vsv/tjHCz366h+2P8Aon7/3juFr7jNf+/f0VBU
F+n1Yf8jiPn7ZU6vuj/x0o/9IgdX27blf9ifAXEPhjjUnRjmQN25Pw7NXqg7
9+Nw5x50f0Hdab8QLRyg7rRHDzeoOzHEYeEJAGNTuuo=
       
       "], {{-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}, {-2.422763365772555, -0.5243400200337339, \
-0.004326663743797126}, {-1.525580660274528, -0.5787952829846525, \
-0.05012859920712154}, {-1.5772366342274449`, -1.4756599799662662`, 
       0.004326663743797126}, {-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjg4cPYMCNzZz4AKDpgYg8BlHOKHMcQh1IQ96OJG
EPX26OLGEPMxxE9D3IMhfhaHuAkOc0xw2At1pw0Od2L4yxhHOJzGEW7o4QkA
EQVB6A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5PP/hcdwbzAQYoaDh+9Xzb5Jn2X12uvS9OZYKL
M7b2dbHwTrSvUnr9facRI5p4oz2UCxdnMJ4xkT3bx4Znt6ZAz6y/+2HC/1vA
6veLlwUrSJj+hoszQMzfr2RYa7Dk/A+4eB3EPRjiUHfuF0MzB+rO/dxo9kLd
CeOju3MPur+g7sQIB6g77dHDDepODHFYeAIAnIBtHA==
       
       "], {{-2.4493063074013928`, -0.45, 
       0.024976831851240444`}, {-2.4493063074013928`, 0.45, 
       0.024976831851240444`}, {-1.5506936925986072`, 
       0.45, -0.024976831851240444`}, {-1.5506936925986072`, -0.45, \
-0.024976831851240444`}, {-2.4493063074013928`, -0.45, 
       0.024976831851240444`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE652pliOu3//jV5EiaFyx7af3X5kNX/cPb+txYb
31bs/L+/+MsupW95z+x/6i6YEz9t0v7yOTfK9tz5v9+qKlaw2vw1VLxpPwME
HIBQH+zn+SREzf/lt+foxslHFgoyHHjsFFjulPLJ/jtEvX1nsnqnszLDgWOt
i961nPhi/wNivr2f6G7fpyYMB1ae+Jx6XOe7/WeIe+Diq6DiUHdimAN1pz26
vVB32uNwpw26v6DuhIdDCTQcoO7cDwu3ddBwg7pzP67wBACrErpp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7y3z1K5+DayeLr9IsHj
XFUpTAcm/JNi9s1+b/+k9eDzcpd++4sdyay2RowHPOp7G5dthYnX2zNAwAEI
9cF+0vvTr5P5vGzi31l8bZ39d3+Mg+V+HdUP9g8g6vfvvVP4itv89/4dDUV1
kV4f7B9BzN8vc3rV/YmXfuwXObjati3/g30GxD0Y4lB3YpgDdef+ODR7oe7c
j8Ode9D9BXWn/UK0cIC60x493KDuxBCHhScAM4izag==
       "], {{-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}, {-2.474419339725472, 
       1.4212047170153475`, 0.05012859920712154}, {-1.5772366342274449`, 
       1.4756599799662662`, 0.004326663743797126}, {-1.525580660274528, 
       0.5787952829846525, -0.05012859920712154}, {-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBZdF8V+Tff/fofVe7x5n/2w99vIEJJbvnr/Drnn
LE+K/+/XKtK4y+Hy2960jMFinv+i/TH9xUyfdv7fL2o5JY9l0V+o+KT9DBBw
AEo7hEuFxW5qidsTZHHsH5syw4HSx1tP/NVjdDCGqLdfUtDzl9eN4cDrY9kT
f8cyOZhAzLf/tiLoj0gmw4GEVYpRP3uYHXwh7sEQh7oTwxyoO+3R7YW60x6H
O23Q/QV1J0Y4QN25Hz3coO7EEIeFJwDbRJhI
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7b67D9Kys0mWjvF5Lr
My2R6YDfH3u+5tz/9s83BXlO/9Bmr77KTO20AeMB9X/y7Qe3wcTL7Bkg4ACU
dsh6dST9sqyzzebVkzZnzvu7/w1Dgc18FQaHJxD1+1PDVdMv2/zef5PxQYWd
J4PDU4j5+yWYd0jZ3v6x/yhTwNa7uQwO2hD3YIhD3YlhDtSd+zeh2Qt1534c
7tyD7i+oO+190cIB6k579HCDuhNDHBaeAAaBo+Y=
       "], {{-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}, {-2.4977844876311126`, 
       2.390189445160059, 0.07044714869685079}, {-1.604834628718266, 
       2.497480507523181, 0.03684391366627121}, {-1.5022155123688876`, 
       1.609810554839941, -0.07044714869685079}, {-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6y5eACkxP/9vvsawjiaGJxkJWpZsuQ2rK/ueKa
qLLB//1GV0J7WNewOtSoLuF4cHbVfkeb112CM/7vl3yldYzpGhtUfNZ+Bgg4
AKE4HGzk7220Ckvbcz+xy+q7McOB56JXLf9qcjpUQdTb7z8sUvouneHAOe1V
xb+CuRyqIebbz1Odv/7pbIYDWxzr136v5XaQhrgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4ACOubuQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewOyyacnS94q8Z+TpVI
3tMYpgNZ+XfrT0xhdyhIuLef26bY3s+Wa3uRHuOBrdvf2aecgokn2zNAwAEI
xeHA/vuxfDy7gU1K6+uJUov/7vf2EDww25TDIQ+ifv8JruvKpm6/90+boNRg
ns3hkA8xf7/OhENb/V/+2P/whrHD5QUcDksg7sEQh7oTwxyoO/ej2wt1534c
7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDB4ZpX
       "], {{-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}, {-2.5191609020654973`, 
       3.357979635108771, 0.0855718330639844}, {-1.633082468075111, 
       3.5150354929240377`, 0.07148402475128206}, {-1.4808390979345027`, 
       2.642020364891229, -0.0855718330639844}, {-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZ582RiWdq//U3xzHu2TeVxqNhl53vw3c79HXNn
bPv57t9+pqnhtSo7eR1+q9UbX/PcuP+In8/tmvL/+xtPrbabdIcPKr5wPwME
HIBQAg4+0+oYUi/k7Jl3I3KSowvDgQNSqx5smyjg8BOi3t5m42aV5g6GA/Wm
IQdzlQUdfkHMt7/Vybv9yBmGA/YB/xaqbBV0KIO4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+WLg1Q8MN6s79uMITAIPwqug=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgdTq3e+qv8Vvn+7jUP
H0wOYzpwgi3Fb2Mpv8POfne/r2fz97tdK/jgqc14IIXZaPmNXTDx+P0MEHAA
Qgk4HPk+Qex7g9ae0mA5+ZyVf/f7/UtbM1lJwGEbRL39q2U2djeCfu+f8+ds
hLqrgMMOiPn28b+iYl3+/Nj/6pcJ6+50AYeTEPdgiEPdiWEO1J326PZC3WmP
w502rmj+groTIxyg7tyPHm5Qd2KIw8ITABGtr6s=
       "], {{-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}, {-2.5383959440528843`, 
       4.325598192013179, 0.09547578114449966}, {-1.66157321431172, 
       4.528196918969834, 0.10712294581215505`}, {-1.4616040559471155`, 
       3.674401807986821, -0.09547578114449966}, {-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH54yLetlfPf/tgvx0tqw4QcDgUeuxgiv3//68Z7
65g3/ttv90N/cfATIQedh3oPe/dv2f/NIf96Y8T//fJ/pl/ULBKGii/ZzwAB
ByCUiIN/2p8J3l6Fe1rjPUT2BzMceMicoXetV8RBC6Lenmv/BI265QwHDrFf
iFkjLeqgDTHfvl/upo3tb4YDi7ktuptWijrsh7jHfgKaONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/ejhBnUnhjgsPAEuVakc
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUdlssfcXVbNnX/mWLG
5Jt+TAeqXapPMK4VdjDV2sC++W7P/mc7GzbmqDMesFtk+6ThGky8Zj8DBByA
UCIO184KGYryeewx6fk3R23j3/2HYg9J12uKOBhB1NtnSPy19E36vb91d4v5
vyARBxOI+fZzlvy+Viz8c7+7pHtwbY2IwzKIe+xno4lD3WmfjmYO1J326PZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAGV2bIA==
       "], {{-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}, {-2.555426250075045, 
       5.2939652195751385`, 0.10042972870477429`}, {-1.689924540665841, 
       5.537108875761286, 0.14271392748137285`}, {-1.4445737499249551`, 
       4.7060347804248615`, -0.10042972870477429`}, {-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILY7HuAx6//H/bt/6fJbrBQ9sHvTFambJ/fZ1+t3
twqGftx/KfDklipp0QN1Z3r3TGjbYr9/+tFDHas+7H+5IiVqb68IVHyJPQMY
fNgPoUUOZGiVfTorVWjTeKGk6t2qd/vFw2cvdSoSPlADUb+feeHLL3dC3+7X
W2fm3fpE6EAtxPz9LYVx+acZ3ux3Zb304XiY0IGdEPdgiEPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08A8orAVQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBE+IJHY67/dZeF+yS0v
VjTP+bL/3AnevU/XCh9Q1Enf78k2fT9vVMkVR79P+9OftN37dA0m3r6fAQw+
QGmRA0eXNMi/0A/e89xbPLwm+fX+mdKViryaIgfkIOrtz03XW/fj2LP9Ruaf
nKSCRA7IQ8y33/bYlbVU69H+00HZKerVIgfEIe6x34omDnUnhjlQd9qj2wt1
pz0Od9rwoPkL6k6McIC6c78qWrhB3bkfV3gCAENxo/8=
       
       "], {{-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}, {-1.3074142524896448`, -4.464479631202829, \
-0.15399484397074759`}, {-0.44277975827814153`, -4.705014545315876, \
-0.08654007014229913}, {-0.6925857475103553, -5.535520368797171, 
       0.15399484397074759`}, {-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEM29o6Js4cf9botU9jzZInggNvzI34zNO+23xqj+
9hP7uF8/R0LDWVnwwKsnTf9clTbaR62bVKve/WG/uBnPlIUTBaDiC+0ZwODD
fggtcKClVn9FSV+OjffiWywbX77bf3Hy8+t77vAdeAFRv3+621bOpMtv9y9S
P7++cifvgZcQ8/c/etnPJ7z3zf6S3dvazabxHIiBuAcuXgwVh7pz/zQ0c6Du
3I9uL9Sd+3G4cw+6v6DuxAgHqDvt0cMN6k4McVh4AgBFtrmQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPEf8LydbSqxc9J+k+hP
t0+u+bL/5gvuC2/L+A8kqTz9eOpbx/5Zuj/fpoR92p/zhfVF2W6YeMV+BjD4
AKUFDgTOeym38qzLnjNLeFXMgl/vP8X6t9tFSeBAAkS9/QxPaY+cZc/2T+H+
Jd7pInAgEWK+fdo7jZxFPx/ujxX8vvhsmsABD4h77FPRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3YkRDlB37j+LFm5Qd+7HFZ4Atma6Pw==
       
       "], {{-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}, {-1.3363574191970282`, -3.4729523642627917`, \
-0.11867803594150737`}, {-0.45980333298826614`, -3.6737400266827285`, \
-0.08210962647842927}, {-0.6636425808029717, -4.527047635737208, 
       0.11867803594150737`}, {-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC7WVEtXsfu4/94FZeH5tdwHuG6I/4r5stl+kfQR
F4krH/ZPeSCetD+Y60By6alFarNX2V/kTVLiyfqw3+sD98b7mpxQ8Vn2DGDw
YT+E5jigvn1F+1ftNJu4J9a7n2u/37+N/4ufwjW2AwkQ9fv3nigvOx/+bn+O
/Iu5DmtYDyRBzN8vvXaz4fbmt/uV9O+8SWhiOcABcQ+GONSd+/egmQN15350
e6Hu3I/DnXvQ/QV1J0Y4QN1pX4QWblB32uMKTwDIp64Z
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBPYD9/9sLtfvKt3/6Hnf
VeVdX/ZrXStJnTyV/YB2oKuX/Y6c/R+Lj78SjP20XzR716aTp2DiMfsZwOAD
lOY48EOiP+P+O/U98hKFWndcX+9/PcXV18yU44AGRL29ncGjkB3dz/Zf0+ye
lZPFcUATYr59nEdw/ZSLD/cf2Hfh+aL5HAfuQdxjH4MmDnWnvS2aOVB32suh
2Qt1pz0Od9p8QPMX1J37H6KFA9Sd+y+ihRvUnftxhScAOA2p7A==
       
       "], {{-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}, {-1.3654950603405707`, -2.485713996326056, \
-0.08320617339913328}, {-0.4791620690881889, -2.641608869101888, \
-0.07268869937669903}, {-0.6345049396594293, -3.514286003673944, 
       0.08320617339913328}, {-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5/Nyh+1rUP+9dttv16uof5QABHpPAD79X2oS8f
ThHs/7C/REnT724s04GHUdZJU40W2a/6UnCqw/3DfquJIsvf6TFCxSfZM4DB
h/0QmuHA6TdJfn4hcTarxeSy3xW8399z99pGpUV/99+HqN8frmtz7c7Dd/sl
d69NdnX5vf8BxPz9TC5RjqeD3u1fOqNFNOPZj/3+EPdgiEPdCTdHAmoO1J37
0e2FunM/DnfuQfcX1J0Y4QB1pz0s3NZCww3qTntc4QkAh1iyzg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/vv85f67WOt9je7tGS
ZJEjX/Zrqr4Lyc77v19e9A/v5PRMe/nCS4ZcSZ/2TxEqX2W6HSYeac8ABh/2
Q2iGAzMFg8yWaqvaHJKNnvPa+vX+bWVHtFJVGA7IQNTvb7HeZnG9/Nn+nLcd
oac8GA7IQczf7xYpePXQ5of7FVN8G/RzGQ5chbhnvyuaONSd+5vRzIG6cz+6
vVB37sfhzj0wf02F+gvqToxwgLrTPhYt3KDutMcVngDY0aCt
       
       "], {{-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}, {-1.3944131960809822`, -1.502938348477095, \
-0.0486615386368611}, {-0.5008001745126557, -1.609564863601969, \
-0.057964976488012875`}, {-0.6055868039190176, -2.497061651522905, 
       0.0486615386368611}, {-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDbT+zZBOOfDfmnmJXvW6Xzf/9lQk+nYrtn2VSf9
uHk9Puzfu+ZQbcmJL/t/nC5gbKmZZL83ZXkrm8qH/XFhD+2sUj5BxZvsGcDg
w34Y/TFYcG3beT+bNrONXz5tf7/fJdi2qdv89f5vEPX7eXOTXj7Nf7+/fVkV
i3j+s/3fIebvn7xY+N4N9ff7z/zc3rZo2cP9HyHugYufgopD3Qk3pw1qDtSd
+2H2OkPthbpzPw537kH3F9Sd8HDYAw0HqDvtYeEmBQ03qDvtcYUnADNouvs=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr3f/3C70btYuzb7RxrV
z8xOfdm/oPLLfemc9/t1vs6wrV1Ra184xbZYOvXT/gs2v97zboOJ59ozgMGH
/TB6ieIqDuHtFjZy11skT5q+3j/jIRPHT5UP+zUh6vfbrOM0npT9bL/BYVaB
T54f9mtDzN8f1drnE73w4f4TSzgkXud92H8f4p79kWjiUHfut0YzB+rO/ej2
Qt25H4c796D7C+pOjHCAutM+GC3coO60xxWeAOT6uVI=
       
       "], {{-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}, {-1.4226672975718835`, -0.524511498680574, \
-0.0162185287953971}, {-0.524561007755691, -0.5786708421747833, \
-0.03794081469881218}, {-0.5773327024281165, -1.4754885013194259`, 
       0.0162185287953971}, {-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4sP/sGRC4s58BBXzYb2IMApdxiB/GEIfQE/ag
ixtB1NujixtDzMcQPw1xD4b4WRziJjjMMcFhL9SdNjjcieEvYxzhcBpHuKGH
JwA+ZE/p
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5SjP2SZ/R9PwMUrA1XZdk2ucveXMzuh+eZL3Dx
Equ8tee2N9rLcMv/UUn7hCZeaA/hfYCLH9i2/fTadlubUy8Psm8zfg0XL4Ko
3z/pcjN/TvozuHgxxPz9MXtdxZVmP4SLr4a4B0Mc6k4Mc6Du3H8SzV6oO/fj
cOceaTR/Qd2JEQ5Qd9qjhxvUnRjisPAEAG+9eME=
       
       "], {{-1.4498128457508597`, -0.45, 
       0.012977048875352748`}, {-1.4498128457508597`, 0.45, 
       0.012977048875352748`}, {-0.5501871542491403, 
       0.45, -0.012977048875352748`}, {-0.5501871542491403, -0.45, \
-0.012977048875352748`}, {-1.4498128457508597`, -0.45, 
       0.012977048875352748`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ68WPjeDfX3+0/93N62aNlD+8+GmkzHds3ez5ub
9PJp/vv9bcuqWMTzn9n/OF3A2FIzaX+b2cYvn7a/3+8cbNvUbf4aKt60nwEM
PsBo+4/Bgmvbzvvt2ZuyvJVN5cP+uLCHdlYpn+y/QdTbV5304+b1+LB/z5pD
tSUnvth/h5hvb6b3bYJwzof9UsxL9qzT+W7/EeIeuLg0VBzqTrg5e6HmQN1p
j24v1J32ONxpA/OXC9RfUHfCw6EdGg5Qd+6HhdsZaLhB3bkfV3gCAH/3tpE=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr23f7jd6F2sXZv9I43q
Z2anvuxfUPnlvnTOe3udrzNsa1fU2hdOsS2WTv20/4LNr/e822DiufYMYPBh
P5S2X6K4ikN4u4WN3PUWyZOmr/fPeMjE8VPlg70mRP1+m3WcxpOyn+03OMwq
8Mnzg702xPz9Ua19PtELH+4/sYRD4nXeB/v7EPfsj0QTh7pzvzWaOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J32wWjhBnWnPa7wBAC1L7HS
       
       "], {{-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}, {-1.475438992244309, 
       1.4213291578252167`, 0.03794081469881218}, {-0.5773327024281165, 
       1.4754885013194259`, 0.0162185287953971}, {-0.524561007755691, 
       0.5786708421747833, -0.03794081469881218}, {-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZyiXI8HfRu/9IZLaIZz37YB3BECj/wXr0/XNfm
2p2H7/ZL7F6b7Ory2/5hlHXSVKNF+1eLyWW/K3i/v+futY1Ki/5CxSftZwCD
D1CaweH0myQ/v5C4Pau+FJzqcP+w32qiyPJ3eowO9yHq7UNfPpwi2P9hf4mS
pt/dWCaHBxDz7f/fDYqfde3D/rWbbb+e7mF28Ie4By6+DioOdSeGOVB32qPb
C3WnPQ532qD7C+pOeDhIQsMB6s796OEGdSeGOCw8AXyEqfs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/bX+ev9VrHW2xv92hJ
ssiRL/s1Vd+FZOf9t5cX/cM7OT3TXr7wkiFX0qf9U4TKV5luh4lH2jOAwYf9
EJrBYaZgkNlSbVWbQ7LRc15bv96/reyIVqoKg4MMRP3+FuttFtfLn+3PedsR
esqDwUEOYv5+t0jBq4c2P9yvmOLboJ/L4HAV4p79rmjiUHfub0YzB+rO/ej2
Qt25H4c798D8NRXqL6g7McIB6k77WLRwg7rTHld4AgCpBpkt
       
       "], {{-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}, {-1.4991998254873442`, 
       2.3904351363980307`, 0.057964976488012875`}, {-0.6055868039190176, 
       2.497061651522905, 0.0486615386368611}, {-0.5008001745126557, 
       1.609564863601969, -0.057964976488012875`}, {-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZeu9lwe/Pb/Ur6d94kNLE4cN0Q/xXzZfP+PSfK
y86Hv9ufI/9irsMaVofk0lOL1Gav2h/3xHr3c+33+7fxf/FTuMYGFZ+1nwEM
PkBpDgf17Svav2qn7bnIm6TEk/Vhv9cH7o33NTkdEiDq7RdJH3GRuPJh/5QH
4kn7g7kckiDm2xdpqqWr2H3cf++CsvD8Wm4HDoh77IvRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3bl/L1o4QN25Hz3coO7EEIeFJwAEq6hk
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBHaH+382l+t3le5/9Lzv
qvKuL/u1rpWkTp7K7qAd6OplvyNn/8fi468EYz/tF83etenkKZh4zH4GMPgA
pTkcfkj0Z9x/p75HXqJQ647r6/2vp7j6mplyOGhA1NvbGTwK2dH9bP81ze5Z
OVkcDpoQ8+3jPILrp1x8uP/AvgvPF83ncLgHcY99DJo41J32tmjmQN1pL4dm
L9Sd9jjcafMBzV9Qd+5/iBYOUHfuv4gWblB37scVngAIQqJs
       
       "], {{-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}, {-1.520837930911811, 
       3.358391130898112, 0.07268869937669903}, {-0.6345049396594293, 
       3.514286003673944, 0.08320617339913328}, {-0.4791620690881889, 
       2.641608869101888, -0.07268869937669903}, {-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH70sp9PeO+b/cW7t7WbTeNxiA0/8jdj887909y2
ciZdfrt/kfr59ZU7eR1ePWn656q0cb/34lssG1++239x8vPre+7wQcUX7mcA
gw9QWsChpVZ/RUlfzp6odZNq1bs/7Bc345mycKKAwwuIevutMaq//cQ+7tfP
kdBwVhZ0eAkx356fe0dF2cKP+90Wqex5skXQIQbiHgxxqDsxzIG60x7dXqg7
7XG40wbdX1B37p+OFg5Qd+6HhVsJNNyg7tyPKzwBfomzNA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPE7eN7ONpXYOWm/SfSn
2yfXfNl/8wX3hbdl/A5JKk8/nvrWsX+W7s+3KWGf9ud8YX1RthsmXrGfAQw+
QGkBh8B5L+VWnnXZc2YJr4pZ8Ov9p1j/drsoCTgkQNTbz/CU9shZ9mz/FO5f
4p0uAg6JEPPt095p5Cz6+XB/rOD3xWfTBBw8IO6xT0UTh7oTwxyoO+3R7YW6
0x6HO23Q/QV1J0Y4QN25/yxauEHduR9XeAIAhpuyvw==
       
       "], {{-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}, {-1.5401966670117337`, 
       4.3262599733172715`, 0.08210962647842927}, {-0.6636425808029717, 
       4.527047635737208, 0.11867803594150737`}, {-0.45980333298826614`, 
       3.6737400266827285`, -0.08210962647842927}, {-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG4pjMs/zfBmvyvrpQ/Hw4Qcdm+6InXz5L79zAtf
frkT+na/3joz79YnQg51Z3r3TGjbsr/xQknVu1Xv9ouHz17qVCQMFV+ynwEM
PkBpEYcMrbJPZ6UK9+yffvRQx6oP+1+uSIna2yviUANRb1+v390qGPpx/6XA
k1uqpEUdaiHm29sdD/CY9f/j/t2/dPktVoo67IS4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAAzVuPs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBF2kEjs9d/usnC/5JYX
K5rnfNl/7gTv3qdrhR0UddL3e7JN388bVXLF0e/T/vQnbfc+XYOJt+9nAIMP
UFrE4eiSBvkX+sF7nnuLh9ckv94/U7pSkVdTxEEOot7+3HS9dT+OPdtvZP7J
SSpIxEEeYr79tseurKVaj/afDspOUa8WcRCHuMd+K5o41J0Y5kDdaY9uL9Sd
9jjcacOD5i+oOzHCAerO/apo4QZ1535c4QkAE6acfw==
       
       "], {{-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}, {-1.5572202417218586`, 
       5.294985454684124, 0.08654007014229913}, {-0.6925857475103553, 
       5.535520368797171, 0.15399484397074759`}, {-0.44277975827814153`, 
       4.705014545315876, -0.08654007014229913}, {-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczqwf7Hr1CU8K0UPSB8OkH4Us8/+UabP
/ktrt+7P1eM7HCsteiDjuqnQG9stUPGl+83E2x+u6xWBii+xf8Yk6nVLoGgP
AxiIHLjWcX2ny70Cm/sQ9fanXlTIBRYJH0iDqN//EGK+/eSLH20WPRE6kA4x
f38GxD32sbuyoj+HCR2QhLhnfyaaONSd+x+hmQN1J1QcYS/Unfuh7rRBc+ee
+2j+grrT/iFaOEDdaZ+BFm5Qd9rjCk8A7DCuRg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAkfuLb8+7J5Uiv2f2eO
Ny3IvLR/kcZ2f471wgee5P+S3C+4ACp+aH/glNvqLddh4hP2v4+ex7x7fd8e
BjAQOaCWurDB7kTUnq8Q9fbrs1VuVGuIHHgMUW//DWK+fdx1jw3fA2DiC+zf
Q9xjz+Oc21FcKXLgCsQ99h/RxKHutP+OZg7UnVBxhL1Qd9pD3WmD5k6br2j+
grpz/ze0cIC6c/97tHCDunM/rvAEANbYspU=
       
       "], {{-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}, {-0.3045027929542561, -4.466307923050252, \
-0.16568287806566326`}, {
       0.5585535390243542, -4.703517494256951, -0.07152669314103544}, {
       0.3045027929542561, -5.533692076949748, 
       0.16568287806566326`}, {-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeKu/bp84QE7twgeUJyRUGySstM+5n6v
sP62jftPxPWbqikLHhAXeO1T8XYDVHzh/pT1x6UmTxSAii+wfyc3XeFnS+4e
BjAQOHBe6q5WsVmOTRREvb3FwoJTN+/wHRCFqN8fDTHfPt/p4ZTNO3kPiEHM
388BcY/98seB8b3TeA7IQ9yznwtNHOrO/TFo5kDdCRVH2At1536oO23Q3Lkn
Cs1fUHfaR6OFA9Sd9lB37teBhhvUnfa4whMASwOmrw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwHfFwrDG5qL9gv6GET
8GTtpf31y2fYTqngP5AWs8DhTP9UqPih/QeCz8h57YGJt+4/qsR/+6Ji/x4G
MBA4ELKo9cGV74F7+CHq7RWuzfxwS1HgQDJEvb0AxHx7hzXGD7c6CxxIhZhv
LwZxj31C09mLE1IFDnhD3GMPdad9IlQc6k57QTRzoO6EiiPshbrTHupOGzR3
2vCj+Qvqzv0CaOEAded+MbRwg7pzP67wBADkramf
       
       "], {{-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}, {-0.33401604091785, -3.4743265786345203`, \
-0.13076979192258442`}, {
       0.5415745076593318, -3.672697089056829, -0.0676007184997242}, {
       0.33401604091785, -4.52567342136548, 
       0.13076979192258442`}, {-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2bJf1K7oXmwt9wGzh3//X9q32X5D0ART
YbbV+3fWLXw5OZjrgKfO3/+Hg1dBxWfvj9l/4ctJTU6o+Cz75y4/GAVa0/Yw
gAHHgYn+K1ZVfEi1WQtRb7/EQZ/b7BrbATeI+v3rIebbezTGieWsYT3gDjF/
PxPEPfavD/YqLmpiOWACcc9+ZjRxqDv3Q91p7w41B+pOqDjCXqg790PdaYPm
zj1r0fwFdac91J37d0DDAepOeya0cIO60x5XeAIAsqysoQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewHTrmfX5v+fNL+U+qq
X5yeXdrvz83wYcM09gM74kVsu0w6oeKH9i9nZaiIOA0Tr9z/643tmyP1/XsY
wIDjQN6vCXdlGV33nICot4/89b99uQnHgW0Q9fYnIebbb/zyn98/k+PAdoj5
9msg7rHnev9/+re5HAdOQNxjvw5NHOpO+1No5kDdCRVH2At1pz3UnTZo7rQ5
geYvqDv3n0QLB6g7969BCzeoO/fjCk8AxEqwGg==
       
       "], {{-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}, {-0.36378498764196615`, -2.4866553064733674`, \
-0.09559136150501202}, {
       0.5221271591828324, -2.6409162994733557`, -0.05866963149497644}, {
       0.36378498764196615`, -3.5133446935266326`, 
       0.09559136150501202}, {-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHb1/vNBX1hX9jAfuOGy/6gC92r72kme
L33sFu03Nf/BfCyW6YB1c71eNvsiqPik/bOk/zA+1mOEik+yV/lyvuVqetwe
Bgg4wGNQ7xvLE2dTDVFvf+YE+x/LRX/3W0LU76+BmG8/fSL/j2KX3/utIObv
3wFxj31SlPiXtc9+7L8Gcc/+XWjiUHfuh7rTfhrUHKg7oeKT7E9D7YW6cz/U
nTZo7txTjeYvqDvta9DCAepO+x1o4QZ1pz2u8AQA1z2orw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv5/f/fag4plno3791in
x0cJXN7/jLln2ZH8//v5J4U3zeUph4of3v+Z0S340XaYePr+xzvCvrw+2r+H
AQIO8PjPe6NrarxnF0S9Pdv/mGt8KgwHeCHq7XdDzLfn/bdzjawHwwE+iPn2
0yHusRf+K9ask8NwoAviHvuZaOJQd9rvQTMH6k6oOMJeqDvtoe60QXOnzS40
f0HduX83WjhA3bl/Olq4Qd25H1d4AgDUiKoI
       
       "], {{-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}, {-0.393362316641488, -1.5034989636824452`, \
-0.061260172886108376`}, {
       0.5002570104284851, -1.6091375137523605`, -0.04437837718380681}, {
       0.393362316641488, -2.4965010363175546`, 
       0.061260172886108376`}, {-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzx7f89cF//ZOt/3zyxLUayrm20f6BfQ
EZ80aX/cPt2u9BNf9u/56SQWEjIJKt60X/++2FHjlE9Q8SZ7Q93bvV8W++1h
AIMP+x97San29PjZ+EPU2y92vFQ6w/z1/l0Q9fsDIObbuzYveW2Q/2z/boj5
+8sh7rF/caQs8eSyh/unQ9yzvxJNHOrO/VB32rtAzYG6EyreZL8Iai/Unfuh
7rRBc+cefzR/Qd1pH4AWDlB32pejhRvUnfa4whMApP+t+Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXm/f94SFW+P6Yn7V3i/
E0zWurzf6IVvfGzu+/11tw1SEkrCoeKH90t+WbZ+3TaYuPv+gxq9J/w/9u9h
AIMP+ycnXl6xtFt4zzKIevvPrTorVqh82F8DUW+/HGK+/XPuyIBAzw/7ayHm
21dC3GN/a2Lrj5+5H/bPhbjHvhpNHOpO+xVo5kDdCRVH2At1pz3UnTZo7rRZ
huYvqDv3L0cLB6g791eihRvUnftxhScA8QS5Lg==
       
       "], {{-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}, {-0.4222630617365743, -0.5247599788390629, \
-0.028997051226052385`}, {
       0.47612322836711235`, -0.5784594165300123, -0.024702386464896992`}, {
       0.4222630617365743, -1.475240021160937, 
       0.028997051226052385`}, {-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgQ4ewYE7uxnQAMmxiBwGYf4YQxxCJiwB13ECKLe
Hl3cGGI+hvhpiHswxM/iEDfBYY4JDnuh7rTB4U4MfxnjCIfTOMINPTwB7z42
qA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID57BgTu7GdAAybGIHAZh/hhDHEImLAHXcQIot4e
XdwYYj6G+GmIezDEz+IQN8FhjgkOe6HutMHhTgx/GeMIh9M4wg1XeAIAlqw2
qA==
       "], {{-0.45, -0.45, 0.}, {-0.45, 0.45, 0.}, {0.45, 0.45, 0.}, {
       0.45, -0.45, 0.}, {-0.45, -0.45, 0.}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzzb/sWRssSTyx7azyxLUayrm70/0C+g
Iz5pkr1L85LXBvnP7Pf8dBILCZkEFW+yX+R4qXSG+WuoeNN+Q93bvV8W+9kw
gMEH+8deUqo9PX57/CHq9+vfFztqnPLJfhdEvX0AxPz9cft0u9JPfLHfDTHf
vhzinv09c138Z+t8t58OcY99JZo41J32gWjmQN0JFUfYC3WnPdSde9DcaQN1
p/1iqL+g7twPdae9KzQcoO7cX44WblB37scVngB+HafS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXlvP2+JirfH9MT9K7zf
CSZrXd5v9MI3Pjb3vX3dbYOUhJJwqPjh/ZJflq1ftw0m7r7/oEbvCf+P/XsY
wOCD/eTEyyuWdgvvWQZRb/+5VWfFCpUP9jUQ9fbLIebbP+eODAj0/GBfCzHf
vhLiHvtbE1t//Mz9YD8X4h77ajRxqDvtV6CZA3UnVBxhL9Sd9lB32qC502YZ
mr+g7ty/HC0coO7cX4kWblB37scVngDBObGu
       "], {{-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}, {-0.47612322836711235`, 
       1.4215405834699877`, 0.024702386464896992`}, {0.4222630617365743, 
       1.475240021160937, 0.028997051226052385`}, {0.47612322836711235`, 
       0.5784594165300123, -0.024702386464896992`}, {-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHa1fVKU+Je1z37Y33DZf1SBe/X+2kme
L33sFtlPm8j/o9jlt711c71eNvsiqPgk+9Mn2P9YLvoLFZ+0X+XL+Zar6XE2
DBDgwGNQ7xvLE7enGqJ+/yzpP4yP9RgdLCHq7Wsg5u83Nf/BfCyWycEKYr79
Doh79p8P+sK6sofZ4RrEPfa70MSh7rSvRTMH6k6oOMJeqDvtoe7cg+ZOG6g7
7c9A/QV1536oO+2nQ8MB6s79O9DCDerO/bjCEwClbqIu
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv7fvnvtQcUyz8b9e6zT
46MELu9/xtyz7Ej+f3v+SeFNc3nKoeKH939mdAt+tB0mnr7/8Y6wL6+P9u9h
gAAHHv95b3RNjffsgqi3Z/sfc41PhcGBF6LefjfEfHvefzvXyHowOPBBzLef
DnGPvfBfsWadHAaHLoh77GeiiUPdab8HzRyoO6HiCHuh7rSHutMGzZ02u9D8
BXXn/t1o4QB15/7paOEGded+XOEJAKS9oog=
       "], {{-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}, {-0.5002570104284851, 
       2.3908624862476398`, 0.04437837718380681}, {0.393362316641488, 
       2.4965010363175546`, 0.061260172886108376`}, {0.5002570104284851, 
       1.6091375137523605`, -0.04437837718380681}, {-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2WL/+mCv4qImFgezh3//X9q3ef+GoAmm
wmyr7d0b48Ry1rA6eOr8/X84eBVUfLb9Egd9brNrbFDxWfufu/xgFGhNs2EA
Aw6Hif4rVlV8SN2zFqJ+f8z+C19OanI6uEHU26+HmL9/R93Cl5ODuRzcIebb
M0Hcs1/UruhebC23gwnEPfbMaOJQd9pD3bl/J9QcqDuh4gh7oe60h7pzD5o7
bdai+Qvqzv1Qd9p7QMMB6s79TGjhBnXnflzhCQCJrKYb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewOp9zPr01/Pmn/KXXV
L07PLu3352b4sGEau8OOeBHbLpNOqPih/ctZGSoiTsPEK/f/emP75kh9/x4G
MOBwyPs14a4so+ueExD19pG//rcvN+Fw2AZRb38SYr79xi//+f0zORy2Q8y3
XwNxjz3X+//Tv83lcDgBcY/9OjRxqDvtT6GZA3UnVBxhL9Sd9lB32qC50+YE
mr+g7tx/Ei0coO7cvwYt3KDu3I8rPAGUf6ia
       "], {{-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}, {-0.5221271591828324, 
       3.3590837005266443`, 0.05866963149497644}, {0.36378498764196615`, 
       3.5133446935266326`, 0.09559136150501202}, {0.5221271591828324, 
       2.6409162994733557`, -0.05866963149497644}, {-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeIu++WPA+N7p/E4KM5IKDZJ2bk/5n6v
sP62jfb5Tg+nbN7J6yAu8Nqn4u0GqPhCe4uFBadu3uGDii/Y/05uusLPllwb
BjAQcDgvdVer2CxnTxRE/f6U9celJk8UcBCFqLePhpi//0Rcv6masqCDGMR8
ew6Ie/br8IUH7Nwi6CAPcY891J37daHiUHfax6CZA3UnVBxhL9Sd9lB37kFz
p00Umr+g7twfjRYOUHfu50ALN6g79+MKTwAjjqA4
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwOPq4VBje1F+wX9LAJ
eLL20v765TNsp1TwO6TFLHA40z8VKn5o/4HgM3Jee2DirfuPKvHfvqjYv4cB
DAQcQha1PrjyPXAPP0S9vcK1mR9uKQo4JEPU2wtAzLd3WGP8cKuzgEMqxHx7
MYh77BOazl6ckCrg4A1xjz3UnfaJUHGoO+0F0cyBuhMqjrAX6k57qDtt0Nxp
w4/mL6g79wughQPUnfvF0MIN6s79uMITALTioh8=
       "], {{-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}, {-0.5415745076593318, 
       4.327302910943171, 0.0676007184997242}, {0.33401604091785, 
       4.52567342136548, 0.13076979192258442`}, {0.5415745076593318, 
       3.672697089056829, -0.0676007184997242}, {-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczpgH7srK/pzmJCD9OEA6Ucx+/Y/yvTZ
f2ntVvvJFz/aLHoi5JBx3VToje0WqPhS+1MvKuQCi4Sh4kv2P2MS9bolUGTD
AAYiDtc6ru90uVew5z5E/X4z8faH63pFHNIg6u0fQszfn6vHdzhWWtQhHWK+
fQbEPfsXu05dwrNS1EES4h77TDRxqDvtH6GZA3UnVBxhL9Sd9lB37kFzp819
NH9B3bn/IVo4QN25PwMt3KDu3I8rPAG39qcS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAk7XFv+fdk8qRX7vzPH
mxZkXtq/SGO7P8d6YYcn+b8k9wsugIof2h845bZ6y3WY+IT976PnMe9e37eH
AQxEHNRSFzbYnYja8xWi3n59tsqNag0Rh8cQ9fbfIObbx1332PA9ACa+wP49
xD32PM65HcWVIg5XIO6x/4gmDnWn/Xc0c6DuhIoj7IW60x7qThs0d9p8RfMX
1J37v6GFA9Sd+9+jhRvUnftxhScApw2rFQ==
       "], {{-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}, {-0.5585535390243542, 
       5.296482505743049, 0.07152669314103544}, {0.3045027929542561, 
       5.533692076949748, 0.16568287806566326`}, {0.5585535390243542, 
       4.703517494256951, -0.07152669314103544}, {-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64l1Pief+1vcD9mh9sK0UPvH+zIb3i6l77pS/n
+rbZv7XnevX3V6S06AHvz6Wzlj7ebH/pyzm1w/Pf2bN+rfu7plcEKr7YngEM
PkBpkQPCC7YzcE0usJneOiNHbsMH+99cjUzBRcIHPCHq9+tyG960Sfho/02U
iXXZE6EDXhDz9x+ZcNI1WuCT/UeFZvafYUIH3kLcAxf/ABWHunO/Hpo5UHfu
R7cX6s79ONy55zKav6DuxAgHqDvtYeHGDw03qDvtcYUnADNgt8I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIHrm16ftkpav1+px3z
/F5ffGZvrDEts3CD8IEJZ96bX3+2ZL9ijP/yrxmv7SVFTm+xuAETn7KfAQw+
2ENokQPlWnPXcWQn7nkfGKHT6v3J/vlrE+/j6iIHeiHq7e8v3hDBNf2L/dnr
mdP6/EUO9EPMtz/3laO1/9E3+y2H5z0MLRc5cAXiHvvzaOJQd2KYA3Wn/Qc0
e6HutMfhTht0f0HdiREOUHfuT0ELN6g79+MKTwBWurrI
       "], {{
       0.4406940533877688, -5.298527104669883, 0.05530303664006736}, {
       0.6986806420697439, -4.468395797789808, -0.17777406090024198`}, {
       1.5593059466122312`, -4.701472895330117, -0.05530303664006736}, {
       1.301319357930256, -5.531604202210192, 0.17777406090024198`}, {
       0.4406940533877688, -5.298527104669883, 
       0.05530303664006736}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6VePL5hPlv7HNqir2WbxE8kHt+VYLXvx32adNu
v9+6/63956BFhlLKggc8u2Ret63cYG98+u33W/ff2VdqXpTonSgAFV9gzwAG
H6C0wIHKZy1GZkezbdKkOFuEJnyw510be+7pHb4DHhD1+8+aCHGoKny0l4ra
Pef0Tl6o+Ib9xv7SPeYbPtprsEtmb5zGcyAb4h4Mcag7McyBunM/ur1Qd+7H
4c496P6CutM+HS0coO60Rw83qDsxxGHhCQBI9azg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4LfgP3H7RV81YuHy/Sv3p
BQzrntmvk15+YnMV/4Eqs0z/cMf5+yftTw1gCH9tf703+EnkXph4/34GMPhg
D6EFDuxi0j10gjtqj7nC2ev1IZ/sRS2v8QYrChwoh6i3z3OYtf7/ii/2mkVr
pJc5CRyogJhvvyQhvb3+7zd7u9VNmj+TBQ7chLgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15/4daOEGded+XOEJADx7nmY=
       "], {{
       0.45758907679283756`, -4.328789248178778, 0.05184612490425521}, {
       0.6686325248437331, -3.4759504204758596`, -0.14341420644110717`}, {
       1.5424109232071626`, -3.671210751821222, -0.05184612490425521}, {
       1.331367475156267, -4.52404957952414, 0.14341420644110717`}, {
       0.45758907679283756`, -4.328789248178778, 
       0.05184612490425521}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILYoUO+/lP3WfmLxUxurWu4D69NqOEPLN9tXfz2y
5aH7O/tt32do1ARzHZhq/Dux8MtK+71VSbc+KL+3v13tI7JPkxMqPtOeAQw+
QGmOA4EMf9Q4F6baLDx0bhJ73gd71ZbNrx2vsR2YDFG/37l1rir/nQ/2Xhzp
15vXsB6YAjF//xP3nB1iXh/tC3qkDh9tYjmwDuIeuHg+VBzqTgxzoO7cj24v
1J37cbhzD7q/oO7ECAeoO+1h4TYBGm5Qd9rjCk8Anu2qjg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewHHNp+LOXctmC/TOz3
c34TntkbCVdY6c1gP7A61vsuj8e0/X3rqtPVPV7bz+S0kRU/AxNv288ABh/s
ITTHAb5z+3gTJgbt2anh5PMm+pN9+rfDj14YcxxYCVFvXxTYMuPG9i/25960
H72YznFgFcR8e62qY0+OCH+3N33svWLXbI4D9hD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7ty/Bi3coO7cjys8AZlZpDk=
       "], {{
       0.47708548159050357`, -3.360106621681593, 0.04340077715472844}, {
       0.638261629818642, -2.4878141493146844`, -0.10867845184899426`}, {
       1.5229145184094963`, -2.639893378318407, -0.04340077715472844}, {
       1.361738370181358, -3.5121858506853156`, 0.10867845184899426`}, {
       0.47708548159050357`, -3.360106621681593, 
       0.04340077715472844}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4w0M/+7PjOnukLY8vkHuYD1jP2npi4cZX9q1Ml
7ouuvbNfsyhs7fZYpgOXd11u3XZ6oX1p6i7lwOz39mGBq6/d1mOEik+0ZwCD
D1Ca4cDmHu77t1bE2rieVcoL9/pgHxK7Mshj0d/9FyHq93fPcr2zbsoH+5W7
gpZOcPm9/xLE/P0X0jO82O5/sP8n/uf7jWc/9ltC3AMX/wsVh7oTbs4KqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwY4SGG9Sd9rjCEwDQkcAk
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7vf+scwLtIevr+nnc3
FQWqntlrJl30XlT4f78ta/aepvN9+92+vxHgsH1tL7rxherFHTDxuv0MYPDB
HkIzHGDXj/z0Zo3nntiWzu/ViZ/sy5Zz505XZjhgBVFvv4tD+P33Q1/sX/uJ
39JzZzhgDTHfXqx3zrNile/2id+U3I9lMRx4DXEPhjjUnRjmQN1pj24v1J32
ONxpg+4vqDsxwgHqzv1X0MIN6s79uMITAFP0pts=
       "], {{
       0.4991510472470452, -2.391504741244447, 0.0295696484488244}, {
       0.6080497644704068, -1.5042232636794342`, -0.0747023466272946}, {
       1.5008489527529547`, -1.6084952587555532`, -0.0295696484488244}, {
       1.3919502355295932`, -2.4957767363205656`, 0.0747023466272946}, {
       0.4991510472470452, -2.391504741244447, 
       0.0295696484488244}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG6zDqtSkn9vX6m+e3Wfzvf9rP8F/B9pzLZnqbX8
I5b13n5Zvrps/Ikv+9eHcHc5Sk+yb9onU8e99b395e2T+/RTPkHFm+wZwOAD
jN5/1jzDOlfXz2b/go8OVaof7KMm3Hi0wPz1/rUQ9fvrHB83fvH6YL9FYeNR
x/xn+9dBzN9v++jKobyCD/YCGztXPFr2cD8LxD1wcT6oONSdGOZA3bkf3V6o
O/fjcOcedH9B3YkRDlB32rdDw60CGm5Qd9rjCk8AF6ym6w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/3t7H9s345Z8L+Kys8
H7nmPLOPXrr+s2r++/2ccX/9e9Ta9mddUfmoZPbafu2l6z8nbYeJl+1nAIMP
9lB6/0bl4LclpU57Tk/NbX+X8sl+pZhIs5nKh/1sEPX207Rv8909+cU+WFeD
Ldfjw352iPn2CQc9pp3W+27/x9mmc3HOh/2tEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3O+AFm5Qd+7HFZ4AEl+yVQ==
       "], {{
       0.523625995532506, -1.4218551013456981`, 0.010299579419318135`}, {
       0.5785247554904833, -0.5250986033436529, -0.042746715891330875`}, {
       1.476374004467494, -0.5781448986543019, -0.010299579419318135`}, {
       1.4214752445095167`, -1.4749013966563471`, 0.042746715891330875`}, {
       0.523625995532506, -1.4218551013456981`, 
       0.010299579419318135`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4YH/2DAjc2c+AAj7YmxiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDSikhp
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC74mCKfNvuhPQMUrN3RWLbuZM/+Bd7OWTPTn8HF
Sy6s/iln2Lz/wlLFrWeMX6OJF++H8D7AxQ9sKP7a8cd+j4Ru/lLJtE9w8SKI
enuDqHtexme+wMWLIebbe7T7fvAx+g4XXw1xD4Y41J0Y5kDdaY9uL9Sd9jjc
aYPuL6g7McIB6s79hWjhBnXnflzhCQBjMnoq
       "], {{
       0.5502195943040942, -0.45, -0.014056551925218786`}, {
       0.5502195943040942, 0.45, -0.014056551925218786`}, {
       1.4497804056959058`, 0.45, 0.014056551925218786`}, {
       1.4497804056959058`, -0.45, 0.014056551925218786`}, {
       0.5502195943040942, -0.45, -0.014056551925218786`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILZ9dOVQXsEHe76NnSseLXtoz/pfwP+Rxuz9dY6P
G794fbDforDxqGP+M/v1IdxdjtKT9u9f8NGhSvWDfdSEG48WmL+GijftZwCD
D/Yw+qx5hnWurt+epn0yddxb39tf3j65Tz/lk/1aiHp7llrLP2JZ7+2X5avL
xp/4Yr8OYr59u3VYlZL8e/sK9d2r+3S+27NA3GPfBhWvhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPCzcBaLhB3bkfV3gCAGbQok8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/t29j+Wb+cM2H/lRWe
j1xzntlHL13/WTX/vT1n3F//HrW2/VlXVD4qmb22X3vp+s9J22HiZfsZwOCD
PYzeqBz8tqTUac/pqbnt71I+2a8UE2k2U/lgzwZRbz9N+zbf3ZNf7IN1Ndhy
PT7Ys0PMt0846DHttN53+z/ONp2Lcz7Yt0LcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+pOjHCAunO/A1q4Qd25H1d4AgDiharV
       "], {{0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}, {0.523625995532506, 
       1.4218551013456981`, 0.010299579419318135`}, {1.4214752445095167`, 
       1.4749013966563471`, 0.042746715891330875`}, {1.476374004467494, 
       0.5781448986543019, -0.010299579419318135`}, {0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL6QnuHFdv+D/V/xP99vPPthbz1j74mJG1ft757l
emfdlA/2K3YFLZ3g8tv+8q7LrdtOL9zvelYpL9zrg31I7Mogj0V/oeIT9zOA
wQd7CM3gsLmH+/6tFbF7SlN3KQdmv7cPC1x97bYeo8NFiHr7V6dK3Bdde2e/
ZlHY2u2xTA6XIObbJxjoZ392fGfP+IWxZXIPs4MlxD1wcSaoONSdGOZA3WmP
bi/UnfY43GmD7i+oO+HhsBIaDlB37oeF2z9ouEHduR9XeAIAJUq8tQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7bv3UO4F0kPX1/z7ub
igJVz+w1ky56Lyr8b2/Lmr2n6XzffrfvbwQ4bF/bi258oXpxB0y8bj8DGHyw
h9AMDuz6kZ/erPHcE9vS+b068ZN92XLu3OnKDA5WEPX2uziE338/9MX+tZ/4
LT13BgdriPn2Yr1znhWrfLdP/KbkfiyLweE1xD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g7919BCzeoO/fjCk8AJCmfWw==
       "], {{0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}, {0.4991510472470452, 
       2.391504741244447, 0.0295696484488244}, {1.3919502355295932`, 
       2.4957767363205656`, 0.0747023466272946}, {1.5008489527529547`, 
       1.6084952587555532`, -0.0295696484488244}, {0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7inrNDzOujfX6P1OGjTSwO69NqOEPLN+93bp2r
yn/ng70XR/r15jWsDlONfycWflm5f+Ghc5PY8z7Yq7Zsfu14jQ0qPnM/Axh8
sIfQHA6BDH/UOBem7tlblXTrg/J7+9vVPiL7NDkdJkPU21d/PbLlofs7+23f
Z2jUBHM5TIGYb29RoN5/Kfut/YTipzZWtdwO6yDugYtPhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPC7cCaLhB3bkfV3gCAMjAo+I=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewODm0/lnJuW7BfJvb7
Ob8Jz+yNhCus9GawO6yO9b7L4zFtf9+66nR1j9f2MzltZMXPwMTb9jOAwQd7
CM3hwHduH2/CxKA9OzWcfN5Ef7JP/3b40QtjDoeVEPX2RYEtM25s/2J/7k37
0YvpHA6rIObba1Ude3JE+Lu96WPvFbtmczjYQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6c/8atHCDunM/rvAEAGmOnLk=
       "], {{0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}, {0.47708548159050357`, 
       3.360106621681593, 0.04340077715472844}, {1.361738370181358, 
       3.5121858506853156`, 0.10867845184899426`}, {1.5229145184094963`, 
       2.639893378318407, -0.04340077715472844}, {0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDb2l+4x3/DRXoNdMnvjNB6H3POrErz+7dh/1kSI
Q1Xho71U1O45p3fyOnh2ybxuW7lhf5oUZ4vQhA/2vGtjzz29wwcVX7CfAQw+
2ENoAYfKZy1GZkez9xiffvv91v139pWaFyV6Jwo4eEDU26dPu/1+6/639p+D
FhlKKQtCxTfYz0o8+XzC/Df2OTXFXsu3CDpkQ9yDIQ51p30amjlQd9qj2wt1
pz0Od9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwA37KMQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4Lfgdbr/oq2YsXL5fpf70
AoZ1z+zXSS8/sbmK36HKLNM/3HH+/kn7UwMYwl/bX+8NfhK5Fybev58BDD7Y
Q2gBh11MuodOcEftMVc4e70+5JO9qOU13mBFAYdyiHr7PIdZ6/+v+GKvWbRG
epmTgEMFxHz7JQnp7fV/v9nbrW7S/Jks4HAT4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+3eghRvUnftxhScADLCW5g==
       "], {{0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}, {0.45758907679283756`, 
       4.328789248178778, 0.05184612490425521}, {1.331367475156267, 
       4.52404957952414, 0.14341420644110717`}, {1.5424109232071626`, 
       3.671210751821222, -0.05184612490425521}, {0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmID4y4aRrtMAn+w8Kzew/w4Qc3r/ZkF5xde9+PW7D
mzYJH+2/iTKxLnsi5OD9uXTW0seb909vnZEjt+GD/W+uRqbgImGo+OL9DGDw
wR5CizgIL9jOwDW5YM/lL+fUDs9/Z8/6te7vml4RB0+IevulL+f6ttm/ted6
9fdXpLSogxfEfPuKezklnvdf2/Pfr/nBtlLU4S3EPXBxAag41J0Y5kDdaX8J
zV6oO+1xuNMG3V9Qd+7XRQsHqDv3w8LtIzTcoO7cjys8AU2IsAw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIO1zY9v+wUtX6/0455
fq8vPrM31piWWbhB2GHCmffm158t2a8Y47/8a8Zre0mR01ssbsDEp+xnAIMP
9hBaxKFca+46juzEPe8DI3RavT/ZP39t4n1cXcShF6Le/v7iDRFc07/Yn72e
Oa3PX8ShH2K+/bmvHK39j77Zbzk872FouYjDFYh77M+jiUPdiWEO1J32H9Ds
hbrTHoc7bdD9BXUnRjhA3bk/BS3coO7cjys8ASbvs0g=
       "], {{0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}, {0.4406940533877688, 
       5.298527104669883, 0.05530303664006736}, {1.301319357930256, 
       5.531604202210192, 0.17777406090024198`}, {1.5593059466122312`, 
       4.701472895330117, -0.05530303664006736}, {0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7W8PF7yYu/9r7vpFn1Vooe+PHu6MTjBnvtLVd7
L/0x65+9yZd05hJp0QMB8/USb5Vutp9zdWlQje9/e6lfmxl39YpAxRfbM0CA
A4QSOZCr/yeg27zAxkh07TXHSAaHZ6w+/1yLhA/4QdTvT9aKWtu8icHhLPeM
P91PhA74Q8zfP9WeveUoN6PDZsEnvy6GCR34BnEPhjjUnftToOacgZoDded+
dHuh7tyPw5175qL5C+pOeDgYQ8MB6k579HCDuhNDHBaeAPT8qmA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIHHB/wLVrQvHn/Lb3M
yNW5v+2bXaunaWwSPsCsnal7jWXV/tzpW9Zc3fbX/uAiW2+RmzDxWfsZIMAB
Qokc0PmpU71pXeoezy1LNaeqMDrYxx7a8lpN5AADRL395AzvYC1PJofaXS2Z
131FDjBCzLe/I/OxZn8us8MecXe5wyUiBxwg7sEQh7oTwxyoO+290OyFutMe
hztt0P0FdSdGOEDdud8DLdyg7tyPKzwBIROWmg==
       "], {{
       1.4406642841535762`, -5.301189047566042, 0.037798341297327606`}, {
       1.7021599343900928`, -4.470759818154412, -0.19025279298221853`}, {
       2.559335715846424, -4.698810952433958, -0.037798341297327606`}, {
       2.297840065609907, -5.529240181845588, 0.19025279298221853`}, {
       1.4406642841535762`, -5.301189047566042, 
       0.037798341297327606`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5Sr5kX6vnP3jy36f3mLYIH3MUtmG/V7bA/+7/A
s+/2P/vzHmvmKykLHjDYVRU+MWSD/fP6HSrHc//bZ6hc8584UQAqvsCeAQIc
IJTAgZ8PFJ/PMc+24T2wOFfGk8HBcHtwwt07fAf0IOr3Sza437aYxOCQmLf8
wK6dvAf0IebvV3N47RF6m8FhkupvhRnTeA64QtyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwB+/+d/A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Thv/A5h3eccZG6/fX/5/n
+Cjqt72elktpdC3/gbOqd+2UzizZv7/+vELh2r/24qKLdq3dBxOfsp8BAhwg
lMCBq1+STI6HJO5RcJiR767J6FDydZ3SSgWBA6ch6u0dGgzu9wUxObx8Fesa
5Chw4AzEfPvEAyf8rlUzO8Q+4Mn4nShwYCPEPRjiUHfaO6KZA3WnPbq9UHfa
43CnzQE0f0HdCQ8HfWg4QN253x4t3KDu3I8rPAGnipmB
       "], {{
       1.4574363849823695`, -4.330782047795958, 0.0347557263614637}, {
       1.6716289083269396`, -3.477846748236157, -0.15661547760642103`}, {
       2.5425636150176305`, -3.6692179522040416`, -0.0347557263614637}, {
       2.3283710916730604`, -4.522153251763843, 0.15661547760642103`}, {
       1.4574363849823695`, -4.330782047795958, 
       0.0347557263614637}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILaKcyyZs+Gf/b/gK2+tarkPcM/Ln5Aivdm+5mWD
b4bCf/uQ3t55NcFcB1Jr7bNvV66031dyQM1kwn/7Vcfc/PdpckLFZ9ozQIAD
hOI4cNmWq+WhVarNwqPz3zw1Z3AIs9y5wfEa24EkiPr9Tt32N0/nMzisKSpK
bF7DeiAZYv7+xwH3j25czuDAtEZb6GgTywEuiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScADh6hHw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdPYD0yaxTHrTsGL/0sbw
Nk/v3/ZcTMGTJGaxH0jlYeb5HLpg/+UD2oeXLP1rz9qo6clzFiY+YT8DBDhA
KI4DfzKjMl9ZRu+ZLp81T1eX0eF33bVtn404DiRD1Nvr2l+xiY5icvj2d03u
81SOAykQ8+2PxNnd7mhndvhQ06xyewbHgSkQ92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6c/8ytHCAunM/erhB3YkhDgtPAOtJmX8=
       "], {{
       1.4769389546218403`, -3.3615108230395725`, 0.026778118551493257`}, {
       1.640703042065311, -2.489215714163841, -0.12249534424509298`}, {
       2.5230610453781597`, -2.6384891769604275`, -0.026778118551493257`}, {
       2.359296957934689, -3.510784285836159, 0.12249534424509298`}, {
       1.4769389546218403`, -3.3615108230395725`, 
       0.026778118551493257`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYzXPDSSPa/PZvFnJ19PcwH2I8tm1lqvcr+psKB
2Wcy/tuvr9pbvSWW6UDUTUnBnzUL7XMFHvimbflvH773nu0tPUao+ER7Bghw
gNIHHLIaZOarxtqc+s5/84wqg0Ngq1OL96K/+yMh6vdPfi+/aaY3g8MirlaO
6S6/oeIL98c+1+9OK2Rw+NJ/vOfRsx/7WSHuwRCHuhPDHKg796PbC3Xnfhzu
3IPuL6g7McIB6k579HCDuhNDHBaeAA2DpIA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7v/xNyoSUievH+3ctK
zCbY/7Y3NSw3lyj5v3/5MdGNCudn7o8LtpI+Mf+v/ewZu6V5dsHEO/czQIAD
lD7QpTpp8ofG0D2B15I+SRswOmw2Vvr0U4nhwBKIevtFa44+MU9gckhNd3ny
2ZXhwFKI+fafmzSuB09gdpCYnXbtbQbDgd8Q99h/QROHuhPDHKg77dHthbrT
Hoc7bdD9BXUnRjhA3bkfPdyg7sQQh4UnAEs1qdI=
       "], {{
       1.4991562191741747`, -2.3923967123733894`, 0.013428601068172417`}, {
       1.6098989548450404`, -1.5051335095537164`, -0.08904117700472194}, {
       2.500843780825825, -1.6076032876266106`, -0.013428601068172417`}, {
       2.39010104515496, -2.4948664904462836`, 0.08904117700472194}, {
       1.4991562191741747`, -2.3923967123733894`, 
       0.013428601068172417`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Ds/rBzN7/9ot+GPd36Xzf//O+4Jr3W2fZe2yW
eb1783978d/l8TEnvuxf/or7xPxzE+2XRPZ9vXvzv33P3936eimfoOKN9gwQ
4AChPuzPuiP8Y8taXxu9yxasgsIMDi9ZOhYsNn+9fylE/f6YZYVcSmoMDpc4
BRzd85/tXwYxf39X5Sp+Y0sGhz18Mx6+WvZw/3eIe+Diu6HiUHdimAN15350
e6Hu3I/DnXtg/uqG+gvqToxwgLrTHj3coO7EEIeFJwCcs7sn
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7v3xrDfKFKesH+t8y8
0u4Wv+1XL9jP2F34fv+nC5GiPyun7v/W2NarPOevfeiF+w1Hd8DEW/czQIAD
hPqwX05P4fmSp4F7WPfbWL4zZHS4Kj7Bfq7yh/3vIertueoqi+4kMzms1leo
t3L/sP8jxHx7Ptttq09NZXZocN+w73rWh/1bIO7BEIe6E8McqDvt0e2FutMe
hzttvqP5C+pOjHCAunM/erhB3YkhDgtPAOhqriA=
       "], {{
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}, {
       1.5797889527235025`, -0.5255410153731569, -0.05754431034997633}, {
       2.4760698927773994`, -0.5777103285699278, 0.0053749971532055}, {
       2.4202110472764975`, -1.474458984626843, 0.05754431034997633}, {
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjhwOHsGBO7sZ0AFDibGIHAZh/hhDHEINWEPurgR
RL09urgxxHwM8dMQ92CIn8UhboLDHBMc9kLdaYPDnRj+MsYRDqdxhBt6eAIA
pSs6aA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7GVe2+9cIPewYoeLEtMeLI37n7W2KW658z/Q0X
/1g57WnTv8n7ndZdFn8+6y+aePN+KNcBJu4hsEIkd2XAnvsaYiU9Roxw8fcQ
9fb7AnVeSKQywcU/QMy3n1vlFLN0OjNc/BnEPRjiUHdimAN1pz26vVB3wtyN
7k4bdH9B3YkRDlB37kcPN6g7McRh4QkA2mF9Jg==
       "], {{
       1.5509541313373787`, -0.45, -0.02928835668028898}, {
       1.5509541313373787`, 0.45, -0.02928835668028898}, {2.4490458686626213`,
        0.45, 0.02928835668028898}, {2.4490458686626213`, -0.45, 
       0.02928835668028898}, {
       1.5509541313373787`, -0.45, -0.02928835668028898}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO6qXMVvbMngsJtvxsNXyx7a/7wvuOb91ln7Y5YV
cimpMThc4hRwdM9/Zr/8FfeJ+ecm7te7bMEqKMzg8JKlY8Fi89dQ8cb9DBDg
AKE+2GfdEf6xZa3vniWRfV/v3vxv3/13t75eyif7pRD19h6bZV7v3vzfXvx3
eXzMiS/2yyDm27/hWf1gZu9/+0U/jPu7dL7bf4e4B0Mc6k4Mc6DutIfZ2wO1
F+pOexzutEH3F9SdGOEAded+WLjtgYYb1J37cYUnAJXTslI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7bb41hvlAlvWD/W2Ze
aXeL3/arF+xn7C58b//pQqToz8qp+781tvUqz/lrH3rhfsPRHTDx1v0MEOAA
oT7Yy+kpPF/yNHAP634by3eGjA5XxSfYz1X+YP8eot6eq66y6E4yk8NqfYV6
K/cP9h8h5tvz2W5bfWoqs0OD+4Z917M+2G+BuAdDHOpODHOg7rRHtxfqTnsc
7rT5juYvqDsxwgHqzv3o4QZ1J4Y4LDwBuJ+moA==
       "], {{1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}, {1.5239301072226004`, 
       1.4222896714300721`, -0.0053749971532055}, {2.4202110472764975`, 
       1.474458984626843, 0.05754431034997633}, {2.4760698927773994`, 
       0.5777103285699278, 0.0053749971532055}, {1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmII59rt+dVsjg8KX/eM+jZz/s2Y8tm1lqvWr/5Pfy
m2Z6Mzgs4mrlmO7y2z7qpqTgz5qF+0995795RpXBIbDVqcV70V+o+MT9DBDg
AKMdshpk5qvG7skVeOCbtuW/ffjee7a39BgdIiHq7W8qHJh9JuO//fqqvdVb
Ypmg4gvt3QwXvDSS/W/PZjFnZ18PswMrxD0Y4lB3YpgDdac9ur1Qd9rjcKcN
ur+g7sQIB6g796OHG9SdGOKw8AQAUR6f7Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7b/wm50BIRvXj/7mUl
ZhPsf9ubGpabS5T8t19+THSjwvmZ++OCraRPzP9rP3vGbmmeXTDxzv0MEOAA
o7tUJ03+0Bi6J/Ba0idpA0aHzcZKn34qMTgsgai3X7Tm6BPzBCaH1HSXJ59d
GRyWQsy3/9ykcT14ArODxOy0a28zGBx+Q9xj/wVNHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAbaqJS
       "], {{1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}, {1.4991562191741747`, 
       2.3923967123733894`, 0.013428601068172417`}, {2.39010104515496, 
       2.4948664904462836`, 0.08904117700472194}, {2.500843780825825, 
       1.6076032876266106`, -0.013428601068172417`}, {1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4ccP/oxuUMDkxrtIWONrE4cM/Ln5AivXm/U7f9
zdP5DA5riooSm9ewOqTW2mffrly5f+HR+W+emjM4hFnu3OB4jQ0qPnM/AwQ4
QCgOh8u2XC0PrVL37Cs5oGYy4b/9qmNu/vs0OR2SIOrta142+GYo/LcP6e2d
VxPM5ZAMMd/eKs6xZM6Gf/b/gq+8tarlduCCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAsX5ka
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdHaHaZNYJr1pWLF/aWN4
m6f3b3supuBJErPYHVJ5mHk+hy7Yf/mA9uElS//aszZqevKchYlP2M8AAQ4Q
isPhT2ZU5ivL6D3T5bPm6eoyOvyuu7btsxGHQzJEvb2u/RWb6Cgmh29/1+Q+
T+VwSIGYb38kzu52Rzuzw4eaZpXbMzgcpkDcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+rO/cvQwgHqzv3o4QZ1J4Y4LDwBu36R/w==
       "], {{1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}, {1.4769389546218403`, 
       3.3615108230395725`, 0.026778118551493257`}, {2.359296957934689, 
       3.510784285836159, 0.12249534424509298`}, {2.5230610453781597`, 
       2.6384891769604275`, -0.026778118551493257`}, {1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFZzeO0RepvBYZLqb4UZ03gc3MUtmG/V7dgv2eB+
22ISg0Ni3vIDu3byOhjsqgqfGLJhP++BxbkyngwOhtuDE+7e4YOKL9jPAAEO
EErA4ecDxedzzLP3PK/foXI89799hso1/4kTBRz0IOrtz/4v8Oy7/c/+vMea
+UrKgg76EPPtt9Rr5oV6/rM3z216v3mLoIMrxD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g796OHG9SdGOKw8AQADzaV3w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Tht9h8w7vOGOj9fvr/89z
fBT1215Py6U0upbf4azqXTulM0v2768/r1C49q+9uOiiXWv3wcSn7GeAAAcI
JeBw9UuSyfGQxD0KDjPy3TUZHUq+rlNaqSDgcBqi3t6hweB+XxCTw8tXsa5B
jgIOZyDm2yceOOF3rZrZIfYBT8bvRAGHjRD3YIhD3WnviGYO1J326PZC3WmP
w502B9D8BXUnPBz0oeEAded+e7Rwg7pzP67wBAB3v5IB
       "], {{1.6716289083269396`,
        3.477846748236157, -0.15661547760642103`}, {1.4574363849823695`, 
       4.330782047795958, 0.0347557263614637}, {2.3283710916730604`, 
       4.522153251763843, 0.15661547760642103`}, {2.5425636150176305`, 
       3.6692179522040416`, -0.0347557263614637}, {1.6716289083269396`, 
       3.477846748236157, -0.15661547760642103`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ5qz95ylJvRYbPgk18Xw4Qcfrw7OvG4wd79KVpR
a5s3MTic4Z7xp/uJkEPAfL3EW6Wb9xuJrr3mGMng8IzV559rkTBUfPF+Bghw
gFAiDrn6fwK6zQv2zL26NKjG97+91K/NjLt6RRz8IOrtLVd7L/0x65+98Zd0
5hJpUQd/iPn21xo+fi958dfe9500q95KUYdvEPdgiEPdCTfHBGoO1J32c9Ds
hbrTHoc7bdD9BXXn/mRoOJyFhgPUnfvRww3qTgxxWHgCAOlOoY4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIOjg/4Fi1o3rz/ll5m
5Orc3/bNrtXTNDYJOzBrZ+peY1m1P3f6ljVXt/21P7jI1lvkJkx81n4GCHCA
UCIOOj91qjetS93juWWp5lQVRgf72ENbXquJODBA1NtPzvAO1vJkcqjd1ZJ5
3VfEgRFivv0dmY81+3OZHfaIu8sdLhFxcIC4B0Mc6k4Mc6DutPdCsxfqTnsc
7rRB9xfUnRjhAHXnfg+0cIO6cz+u8AQA8TmPGg==
       "], {{1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}, {1.4406642841535762`, 
       5.301189047566042, 0.037798341297327606`}, {2.297840065609907, 
       5.529240181845588, 0.19025279298221853`}, {2.559335715846424, 
       4.698810952433958, -0.037798341297327606`}, {1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmINY1yI02+8jmYHji/eKOlaIHrpZ27YzP2WN/8pTH
pEpvdoeyVq/cDdKiB54s3lj96tMm+5RUlZN7lrI77HZaanajVwQqvsieAQw4
HCC0yIHqtFrlO1PybebMum3mHMXh4Lo36qR6kfCBRxD1+81Nt+e2beFw6Kra
Osn/idCBxxDz918+P2nJST5Oh/PmAjHlYUIHLkPcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AZRarC4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PuEDUt8v/jWduH1/xvFw
L+ZdrA4FloJhJluED6h8Ef/rnrN+/5bH2ksZ77I57JjDoS11CyY+fz8DGHA4
QGiRA0XeL4Mm6mft8ZG5EvVPidPBI/n7laeqIgcUIOrtZ1is2PrHlcthwrF3
K097ixxQgphv/zikRuB3BrfDdc1ndRsLRQ5IQNyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AfzSfOg==
       "], {{
       2.4415193419221497`, -5.3045316493149475`, 0.018969162302250916`}, {
       2.7059604234085484`, -4.47341104096585, -0.20308814741695236`}, {
       3.5584806580778503`, -4.6954683506850525`, -0.018969162302250916`}, {
       3.2940395765914516`, -5.52658895903415, 0.20308814741695236`}, {
       2.4415193419221497`, -5.3045316493149475`, 
       0.018969162302250916`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEP3H/cwLRXYHtdZdk55sETwwLeBfT+jj7fbxf/U7
PmSzOxyJqOFxVhY8UJK9Iu34zfX2G/6Ju/zYyu6QpGPXtnCiAFR8vj0DGHA4
QGiBA12RPVcvdGXZBDC+2M3uxeFgs7z58547fAcKIOr3L2S6UM4/hcOhwo/9
eeVO3gNFEPP3f2TeYSx+j8Nhy9euW2bTeA5MgbgHQxzqTgxzoO7cj24v1J37
cbhzD7q/oO7ECAeoO+3Rww3qTgxxWHgCAI3cqOo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA/+BwuXcwtk7N+9vcn0X
Yr2B1SEoLvXRjAb+A287+Y/0+azaf1CpfJXsDTYHzfVGhT4HYOKz9jOAAYcD
hBY4MGvu9h9lr1L32N/tCH2kzumQvSLt+E15gQOvIOrt63YJrj7iz+VwPeBs
32Z7gQNvIObb750+i2F5ObeD00/jsN54gQMFEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMAmrqc8g==
       "], {{
       2.4581333076753618`, -4.333340593063415, 0.016264586231646463`}, {
       2.675018691382798, -3.480034218257422, -0.1703606024475165}, {
       3.5418666923246382`, -3.666659406936585, -0.016264586231646463`}, {
       3.324981308617202, -4.519965781742577, 0.1703606024475165}, {
       2.4581333076753618`, -4.333340593063415, 
       0.016264586231646463`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGaK/X+IMYzdYcb9Ha/TarkPqMfE9q1Yscl+zYuQ
66v72B1221d/mhnMdcD0wsW9Dx6ssA8rWfU69Di7w735tj/PaHJCxWfYM4AB
hwOUPtCo2/I5dXeKzaruUJFVFhwOygmH2IyvsR0whqjfHyK+WiOkkMPB9UAL
b9oa1gMmEPP3/1vEYPtvJYdDhoK7yMwmlgNqEPdgiEPdiWEO1J37YfYqQe2F
unM/DnfugfnrLtRfUHdihAPUnfbo4QZ1J4Y4LDwBAQenGQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLPYD/jMWMujkbtj/6dbx
aOEVrA77d3DU1sxhPyByWifs6bOl+yvfPl7LeYXNISGmxc7uHEx86n4GMOBw
gNIHJvw7fzzTIWlPu5BM0DdtTocFi6sPHjTkOCAEUW/Pp2qx5E04l4Oj+/em
5mSOA8IQ8+2nmId8e9TM7fDwVZGL61SOA74Q92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6EyMcoO7cjx5uUHdiiMPCEwCAj5re
       "], {{
       2.477597807858436, -3.3633454387878277`, 0.00872019253053169}, {
       2.643606712471798, -2.490882514632804, -0.13705185404883644`}, {
       3.522402192141564, -2.6366545612121723`, -0.00872019253053169}, {
       3.356393287528202, -3.509117485367196, 0.13705185404883644`}, {
       2.477597807858436, -3.3633454387878277`, 
       0.00872019253053169}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7L3Xr/Yw+7Q2jmFZl5PcwHvh5W+aC/dKX9vE0R
r7w3szs8/vBo775YpgNLmiQWnJJYaO8fqfN16U12h6KKj3H39Rih4hPtGcCA
wwFCMxxIbbnMtbwuxmbjsstcUWocDrL8sk6Oi/7uXwRRvz/Jd7noFh8OBys5
q5Yml9/7F0PM3y/0pUqBr5jDIVw3/NjhZz/2f4a4Z78wVDwMKg51J4Y5UHfu
R7cX6s79ONy5B91fUHdihAPUnfbvoOEWAg03qDvtcYUnANDrogs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/3M609v0Xt8Or98ofS
zd8sZHV4bf1/lWX5//1rT9w/K9m0aD//w83S3y6wOXydW391zm6Y+KT9DGDA
4QChGQ7I/yxZc/VG3J4Pcj5POPU5HVgNHaYaKjEcWA1Rb//QdsYJ4TguB+6k
Bq1kF4YDayDm21+KebJGtpfbQWDygf1T0hgOMELcgyEOdSeGOVB32n9Esxfq
Tnsc7rQRQPMX1J0Y4QB15370cIO6E0McFp4AiG+rbw==
       "], {{
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}, {
       2.612275031121414, -1.5062506453545674`, -0.10431166423424715`}, {
       3.5000835461342934`, -1.6064274528809768`, 0.004134856707837732}, {
       3.387724968878586, -2.493749354645433, 0.10431166423424715`}, {
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA4Lecz7/ii7Q579v0sTdL7vf6knYL5DcZa9pYUT
p9dNdof59St7Ek582T+nZKvKheyJ9rIyC1mWvmF3OL8/xM0g5RNUvNGeAQw4
HCD0h/0Rh5onsXL62jx+HPc7SpjDIakhrHi++ev9syDq9x8/vvfbVjUOh8MM
a5/Z5T/bPxti/v5Vq2U+CVhxOKg2MkfdW/Zw/3OIe+DiKlBxqDvh5hyCmgN1
536YvYlQe6Hu3I/DnXvQ/QV1Jzwc5kHDAepOe/Rwg7oTQxwWngD84KQi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7/3+hU01tVZdK/b/L7l9
X2weq0N0yK26hSXv9x9kDP6nFrNgf8Out/nc59kc9LRy9wfsgolP2M8ABhwO
EPrD/jdMpn8dXKL3NLgKTfhiwOnwMstzwXWlD/sPQNTbM3arKLxM5HK4dHWS
w3rXDzDz7RsvmG24O4nbYY/DnQdtGR/2L4C4B0Mc6k6c5qDbC3WnPQ532qD7
C+pOnOGAHm5Qd2KIw8ITAN69pfo=
       "], {{
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}, {
       2.5816407345077046`, -0.5261004423591564, -0.07344885461707322}, {
       3.4750645333984003`, -0.5771389524162092, 0.022410344560020643`}, {
       3.4183592654922954`, -1.4738995576408436`, 0.07344885461707322}, {
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgcDh9BgTu7GdAARwOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIA9mxGvg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb61Cyvl83iwAAFCbMDwufnL9+/51t41sk5rHDx
RhUx+Xr7+fvjfmtvTTnHhibevx/C44CLHyie5GLPFbVnEcsVr9mGnHDxOoh6
exfOFVPNkrng4g0Q8+2f8dY8uDiFGy4eD3EPhjjUnRjmQN1pj24v1J32ONxp
g+4vqDsxwgHqzv3o4QZ1J4Y4LDwBQAFbOQ==
       "], {{
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}, {
       2.5523340665952334`, 0.4499999999999999, -0.04577348652701718}, {
       3.4476659334047666`, 0.4499999999999999, 0.04577348652701718}, {
       3.4476659334047666`, -0.4499999999999999, 0.04577348652701718}, {
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF61WuaTgBWHg0ojc9S9ZQ/tX+oJmO9QnLX/+PG9
37aqcTgcYlj7zC7/mf2ckq0qF7In7n/8OO53lDCHQ2JDWPF889dQ8cb9DGDA
4QChP9hHHGqexMrpu0dWZiHL0jfsDuf3h7gZpHyynwVRb29p4cTpdZPdYV79
yp6EE1/sZ0PMtw8Lecz7/ii7Q579v0sTdL7bP4e4B0Mc6k64OfOh5kDdaY9u
L9Sd9jjcaQPzVxLUX1B3wsPhMDQcoO7cDws3VWi4Qd25H1d4AgAIL5u5
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7739wqaaWquuFfv/l9y+
LzaP1SE65FbdwpL39gcZg/+pxSzY37DrbT73eTYHPa3c/QG7YOIT9jOAAYcD
hP5g/4bJ9K+DS/SeBlehCV8MOB1eZnkuuK70wf4ARL09Y7eKwstELodLVyc5
rHf9ADPfvvGC2Ya7k7gd9jjcedCW8cF+AcQ9GOJQd+I0B91eqDvtcbjTBt1f
UHfiDAf0cIO6E0McFp4ArvKeeg==
       "], {{2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}, {2.5249354666015997`, 
       1.4228610475837908`, -0.022410344560020643`}, {3.4183592654922954`, 
       1.4738995576408436`, 0.07344885461707322}, {3.4750645333984003`, 
       0.5771389524162092, 0.022410344560020643`}, {2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb+UqXAV8zhEKYbfuzwsx/2Xw+rfNBfunJ/ku9y
0S0+HA5WclYtTS6/7Zc0SSw4JbFw/8Zll7mi1DgcZPllnRwX/YWKT9zPAAYc
DhCawSG15TLX8rqYPf6ROl+X3mR3KKr4GHdfj9FhEUS9/bxNEa+8N7M7PP7w
aO++WCaHxRDz7d9xt97/2MPuEJJ5RWZeD7PDZ4h77N9CxUOh4lB3YpgDdac9
ur1Qd9rjcKcNur+g7sQIB6g79wtBwy0cGm5Qd+7HFZ4A33iaug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/tmdae36J2ePV++UPp
5m8Wsjq8tv6/yrL8v/3aE/fPSjYt2s//cLP0twtsDl/n1l+dsxsmPmk/Axhw
OEBoBgf5nyVrrt6I2/NBzucJpz6nA6uhw1RDJQaH1RD19g9tZ5wQjuNy4E5q
0Ep2YXBYAzHf/lLMkzWyvdwOApMP7J+SxuDACHEPhjjUnRjmQN1p/xHNXqg7
7XG400YAzV9Qd2KEA9Sd+9HDDepODHFYeAIAWKSj7w==
       "], {{2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}, {2.4999164538657066`, 
       2.3935725471190232`, -0.004134856707837732}, {3.387724968878586, 
       2.493749354645433, 0.10431166423424715`}, {3.5000835461342934`, 
       1.6064274528809768`, 0.004134856707837732}, {2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP63iMH230oOhwwFd5GZTSwO6jGxfStWbNofIr5a
I6SQw8H1QAtv2hpWB9MLF/c+eLBi/6ruUJFVFhwOSgmH2IyvsUHFZ+xnAAMO
BxjdqNvyOXV3yp6wklWvQ4+zO9ydb/vzjCangzFEvf2aFyHXV/exO+y2r/40
M5jLwQRivj1T7P9DjGHsDjPu73idVsvtoAZxD4Y41J0Y5kDdaQ+z9x7UXqg7
7XG40wbmL2Wov6DuxAgHqDv3o4cb1J0Y4rDwBAAedp8h
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLHYH/xkLGXRyN+z/dOt4
tPAKVof9Ozhqa+awO4ic1gl7+mzp/sq3j9dyXmFzSIhpsbM7BxOfup8BDDgc
YPSEf+ePZzok7WkXkgn6ps3psGBx9cGDhhwOQhD19nyqFkvehHM5OLp/b2pO
5nAQhphvP8U85NujZm6Hh6+KXFyncjj4QtyDIQ51J4Y5UHfao9sLdac9Dnfa
oPsL6k6McIC6cz96uEHdiSEOC08AUMSTXg==
       "], {{2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}, {2.477597807858436, 
       3.3633454387878277`, 0.00872019253053169}, {3.356393287528202, 
       3.509117485367196, 0.13705185404883644`}, {3.522402192141564, 
       2.6366545612121723`, -0.00872019253053169}, {2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7IvMNY/B6Hw5avXbfMpvE4TAv41xP6ePv+hUwX
yvmncDhU+LE/r9zJ61CSvSLt+M31+wMYX+xm9+JwsFne/HnPHT6o+Pz9DGDA
4QChBRy6InuuXujK2rPhn7jLj63sDkk6dm0LJwo4FEDU28f/1e/4kM3ucCSi
hsdZWdChCGK+Pf8f9zMvFNkd1Fp3TXqyRdBhCsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEALMkod0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA79D4XJu4eydm/c3ub4L
sd7A6hAUl/poRgO/w9tO/iN9Pqv2H1QqXyV7g81Bc71Roc8BmPis/QxgwOEA
oQUcZs3d/qPsVeoe+7sdoY/UOR2yV6Qdvykv4PAKot6+bpfg6iP+XA7XA872
bbYXcHgDMd9+7/RZDMvLuR2cfhqH9cYLOBRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwBq75Vy
       "], {{2.675018691382798, 
       3.480034218257422, -0.1703606024475165}, {2.4581333076753618`, 
       4.333340593063415, 0.016264586231646463`}, {3.324981308617202, 
       4.519965781742577, 0.1703606024475165}, {3.5418666923246382`, 
       3.666659406936585, -0.016264586231646463`}, {2.675018691382798, 
       3.480034218257422, -0.1703606024475165}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL58ftKSk3ycDufNBWLKw4QcrpZ27YzP2bPf3HR7
btsWDoeuqq2T/J8IOTxZvLH61adN++fMum3mHMXh4Lo36qR6kTBUfNF+BjDg
cIDQIg7VabXKd6bk70lJVTm5Zym7w26npWY3ekUcHkHU25885TGp0pvdoazV
K3eDtKjDY4j59roGudFmH9kcDE+8X9yxUtThMsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAMgFpRQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PmEHqe8X/5pO3L4/43i4
F/MuVocCS8Ewky3CDipfxP+656zfv+Wx9lLGu2wOO+ZwaEvdgonP388ABhwO
EFrEocj7ZdBE/aw9PjJXov4pcTp4JH+/8lRVxEEBot5+hsWKrX9cuRwmHHu3
8rS3iIMSxHz7xyE1Ar8zuB2uaz6r21go4iABcQ+GONSdGOZA3WmPbi/UnfY4
3GmD7i+oOzHCAerO/ejhBnUnhjgsPAFPaZe6
       "], {{2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}, {2.4415193419221497`, 
       5.3045316493149475`, 0.018969162302250916`}, {3.2940395765914516`, 
       5.52658895903415, 0.20308814741695236`}, {3.5584806580778503`, 
       4.6954683506850525`, -0.018969162302250916`}, {2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM77nM3y7h2fw9uZcW9lVokeyBS6+aK7bbe956JP
TF88+R2+7H7pISwjemBOovXsTZGb7FUDKxl/LeF3+HW3ZAlnnwhUfJE9AxgI
OEBokQMRvjuY6qfm2eSFO/9v0hVwYFPqjv5WKHxgFkT9/tvr2v6xRgs48LiI
bX/zWOjAbIj5+z3ZTv3t6BBwEE5bKPQ4VOhAOsQ9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITAGUgoHk=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSh84GRDd733ld37+RQe
W6rv43WoEppsOnOb8IE2hthV7b2b9rNP+DhH+D6fg23nyVk+t2Hii/YzgIGA
A4QWOWAS9kH60eu8PX/M2w3LJgg4HC4zS92sInKgBaLe/mc+X/IbBUGHtrc5
p9I8RQ60Qsy3/7p86pSkjYIOXimL9aXyRA4ch7gHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4AdYmgyw==
       "], {{
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}, {
       3.710107463666265, -4.476352259400707, -0.21622988032011106`}, {
       4.556562697496302, -4.691395793388974, 0.0011863463318433354`}, {
       4.289892536333735, -5.523647740599293, 0.21622988032011106`}, {
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4g8S32kDy/g3vgIQW7rYIHbrpr2R7W3G5/KvXn
5MYsfofW7sYDdcqCByq4Hi+LfLTO/ummPycdtvI7HDrqkLB/ogBUfJ49AxgI
OEDpAzs6hLgX7Mm06V3GODteVcChuqTOvvEO34ESiPr90r7MZvu9BBy+v/hT
x7ST90AZxPz9Kz6zXJQrEHAoiq3e1zyV58B1iHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA3taehg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvEfkFPMLOSQ3LF/tuHb
4+xbeB2uFafMLGvhP5CVPdt7g8CG/WdnfHvMfIvP4bXlJh/rQzDxBfsZwEDA
AUofYN28VqP6WNaemZtZ+P5NEnDgerws8pGcwIEMiHp743ROmT+qgg6ix3w3
H7EVOJAJMd/+jBSf1q8dgg7yK7/wLI8ROCALcQ+GONSdGOZA3WmPbi/UnfY4
3GlzDs1fUHdihAPUnfvRww3qTgxxWHgCAMRgk2U=
       "], {{
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}, {
       3.678850754562714, -3.4825241906231894`, -0.18461297046761505`}, {
       4.5401343565350665`, -3.6634861856200236`, 0.00365097547078104}, {
       4.321149245437287, -4.51747580937681, 0.18461297046761505`}, {
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ61N2GTTgi/w7sFKXeO1HIfyDOWfmkou8l+z+Wp
isW9/A7zD7yddCOY64Dd+3Nmb9VW2N97eWrCzmP8DgEPyjzfaHJCxWfYM4CB
gAOE5jiwWSY8okAhxUawe5b5YhkBh43ynduEr7EdsIGo368kZprvZingkGgv
lKu+hvWALcT8/cYLzy97GSrgIBQ/W9m6ieVALsQ9GOJQd2KYA3Xnfpi9G6D2
Qt25H4c798D85Q/1F9SdGOEAdac9erhB3YkhDgtPADECmQ4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPvuBEqu2S58ebtmvdH9C
RO9qXgfnIyreKfPZD3z05ch7d331/on5HmuOXeVzUEqapLrpPEx89n4GMBBw
gNAcBzymbYz+aJy+x/zE7ZUyUwUc7s3NveVrwHHgHUS9ff6E7cGWWoIOe61v
b5mdwHHgA8R8+2URk/+G7hd0mH3To//lBI4DxRD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAMplplI=
       "], {{
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}, {
       3.6470476573032444`, -2.492831381576873, -0.1523306806642988}, {
       4.52075058797933, -2.634347341146244, 0.010814721094927732`}, {
       4.352952342696756, -3.507168618423127, 0.1523306806642988}, {
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP402Ydvdje/Q+Lj19xHe5gPHHf/Wbzi9Qr779vv
xqVv4ndwdJq76UYs0wGD1t/fpeYusP99O2+98U1+B4WFfpFv9Bih4hPsGcBA
wAFCMxxY0vHDvWlDtA3TJA+NNGEBhwN7k3zVF/3drwdRv59VZWLAGTUBh/rq
o7P8XH7v14eYv599280KIysBB3tLjRelz37sPwpxD1zcDioOdSeGOVB37ofZ
ux9qL9Sd+3G4cw+6v6DuhIeDAzQcoO60Rw83qDsxxGHhCQBDpaoH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/3Zx8q9G5K2bTf+cgh
dqWlvA7XlB00xKv/758Q4cTP3LZiv2LSQ+aJl/gcXgsqTOneCxOfsZ8BDAQc
IDTDgfIvieZr81P2vPfjr9s+TcCB6/t7UytFhgO9EPX29+bK/cnTFXQQfXc/
u8SJ4UA/xHz7c290q9SOCDrIPz2/cF0yw4EsiHswxKHutL+PZg7Unfbo9kLd
aY/DnTZKaP6CuhMeDteh4QB15/5UtHCDunM/rvAEAGxLlYo=
       "], {{
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}, {
       3.615280131564128, -1.5075918604915728`, -0.12051907308195917`}, {
       4.4983861897860224`, -1.6049377165038257`, 0.023173217069706202`}, {
       4.384719868435872, -2.492408139508427, 0.12051907308195917`}, {
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHacfv625VF+B75rqz0X63zfX5yj/P9kxkz7Bn5T
24s3+B24nhy/nXPiy/7Fc8VXtX2YYH+gfda8jDf8DqyfHueapXyCijfYM4CB
gAOE/rA/eWONdLe1j43Cnk0bTnMKOHyXtlCZbP56/0KI+v0OFamJ04UFHN6Z
F3io5T/bvwhi/v4EEwmhZFkBh2fBK3J2Lnu4vxDiHrj4E6g41J1wc95CzYG6
cz/M3m9Qe6Hu3I/DnXtg/mKB+gvqTng4cELDAepOe1i48ULDDepOe1zhCQAe
eKll
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7vv3PlxQaGCxv2m7GH
d8kv5HUQdl5/qrri/f7qY93TVmct2z+7Wfto/wU+h86F4U9t98DEp+1nAAMB
Bwj9YX+aqvwKy3VJe4zssmR3TBdwsNYP4X2o+GF/JUS9fWrNFasCfUGH8rgV
UoecP+yvgphvP32XXYTGcUGHTb1/1Benfth/G+Ie+xlo4lB3YpgDdae9MZq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAKHjriA=
       "], {{
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}, {
       3.5842083968149794`, -0.5267882881396561, -0.09048767031498518}, {
       4.473188077503202, -0.5764158901397218, 0.04086006831491938}, {
       4.415791603185021, -1.473211711860344, 0.09048767031498518}, {
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcDh9BgTu7GdAAQIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIATatHNg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbn909dnM/jwAAF7NsmK9q5btivz9XlfGg+L1x8
y6cjOis2Lt0vwXpU8eF5PjTxqfshPAG4uMMpP1UekaQ9JbWy+fwzEOKbIOrt
X/yyuidnIAgX3wwx3z6mIsJX7wRCnBXiHgxxqDsxzIG60x7dXqg77XG40wbd
X1B37jdACweoO/d7oIUb1J37cYUnALFVY88=
       "], {{
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}, {
       3.554510871386728, 0.4499999999999999, -0.06355655975104223}, {
       4.445489128613271, 0.4499999999999999, 0.06355655975104223}, {
       4.445489128613271, -0.4499999999999999, 0.06355655975104223}, {
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4wkRBKlhVweBK8Imfnsof2xTnK/09mzNzvUJGa
OF1YwOGteYGHWv4z+8VzxVe1fZiwX2HPpg2nOQUcvklbqEw2fw0Vb9jPAAYC
DhD6g33yxhrpbmufPQfaZ83LeMPvwPLpca5Zyif7hRD19g38prYXb/A7cD45
fjvnxBf7RRDz7R2nn79teZTfgffaas/FOt/tCyHugYvzQcWh7oSbwwU1B+pO
e5i9rFB7oe60x+FOG5i/vkP9BXUnPBzeQcMB6s79sHB7Bg03qDv34wpPABv9
oRE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7b37nyYgPDhQ37zdjD
u+QX8joIO68/VV3x3r76WPe01VnL9s9u1j7af4HPoXNh+FPbPTDxafsZwEDA
AUJ/sE9TlV9huS5pj5FdluyO6QIO1vohvA8VP9hXQtTbp9ZcsSrQF3Qoj1sh
dcj5g30VxHz76bvsIjSOCzps6v2jvjj1g/1tiHvsZ6CJQ92JYQ7UnfbGaPZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAchimoA==
       "], {{3.5842083968149794`,
        0.5267882881396561, -0.09048767031498518}, {3.5268119224967984`, 
       1.4235841098602782`, -0.04086006831491938}, {4.415791603185021, 
       1.473211711860344, 0.09048767031498518}, {4.473188077503202, 
       0.5764158901397218, 0.04086006831491938}, {3.5842083968149794`, 
       0.5267882881396561, -0.09048767031498518}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGbfdrPCyErAwc5S40Xpsx/2x91/Fq94vWI/q8rE
gDNqAg711Udn+bn8tjdo/f1dau6C/UyTPDTShAUc9u9N8lVf9BcqPmE/AxgI
OEBoBoclHT/cmzZE7/l9O2+98U1+B4WFfpFv9Bgd9CDq7b9vvxuXvonfwcFp
7qYbsUwO+hDz7T9N9uGb3c3vkPj4NffRHmaHoxD3YIhD3Qk3xxFqDtSd9uj2
Qt1pj8OdNjB/HYD6C+pOjHCAunM/LNzsoeEGded+XOEJAFg6osg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/tsw8VejelbNrvfOQQ
u9JSXodryg4a4tX/7SdEOPEzt63Yr5j0kHniJT6H14IKU7r3wsRn7GcAAwEH
CM3gUP4l0Xxtfsqe9378ddunCThwfX9vaqXI4NALUW9/b67cnzxdQQfRd/ez
S5wYHPoh5tufe6NbpXZE0EH+6fmF65IZHLIg7sEQh7rT/j6aOVB32qPbC3Wn
PQ532iih+QvqTng4XIeGA9Sd+1PRwg3qzv24whMAPICOCg==
       "], {{
       3.615280131564128, 1.5075918604915728`, -0.12051907308195917`}, {
       3.501613810213978, 2.3950622834961743`, -0.023173217069706202`}, {
       4.384719868435872, 2.492408139508427, 0.12051907308195917`}, {
       4.4983861897860224`, 1.6049377165038257`, 0.023173217069706202`}, {
       3.615280131564128, 
       1.5075918604915728`, -0.12051907308195917`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZeeH7Zy1ABB6H42crWTSwOecbSLw1lN+1XEjPN
d7MUcEi0F8pVX8PqYPf+nNlbtRX7BbtnmS+WEXDYIN+5TfgaG1R8xn4GMBBw
gNAcDptlwiMKFFL23Ht5asLOY/wO/g/KPN9ocjrYQNTb77k8VbG4l99h/oG3
k24EcznYQsy3n7U3YZNOCL/DuwUpd47UcjvkQtyDIQ51J4Y5UHfaw+wNgNoL
dac9DnfawPy1EeovqDsxwgHqzv3o4QZ1J4Y4LDwBQUWQgw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPrtDiVXbpU8Pt+xXuj8h
onc1r4PzERXvlPnsDh99OfLeXV+9f2K+x5pjV/kclJImqW46DxOfvZ8BDAQc
IDSHg8e0jdEfjdP3mJ+4vVJmqoDDvbm5t3wNOBzeQdTb50/YHmypJeiw1/r2
ltkJHA4fIObbL4uY/Dd0v6DD7Jse/S8ncDgUQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Ampqe0g==
       "], {{3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}, {3.4792494120206703`, 
       3.365652658853756, -0.010814721094927732`}, {4.352952342696756, 
       3.507168618423127, 0.1523306806642988}, {4.52075058797933, 
       2.634347341146244, 0.010814721094927732`}, {3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7xmeWiXIGAQ1Fs9b7mqTwON921bA9rbt8v7cts
tt9LwOH7iz91TDt5HSq4Hi+LfLRuf+8yxtnxqgIO1SV19o13+KDi8/YzgIGA
A4ze0SHEvWBP5p6nm/6cdNjK73DoqEPC/okCDiUQ9fanUn9Obszid2jtbjxQ
pyzoUAYx336DxLfYQ/L8Du6BhxTstgo6XIe4B0Mc6k4Mc6DutEe3F+pOexzu
tEH3F9SdGOEAded+9HCDuhNDHBaeAA22mDc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvE7yClmFnJI7tg/2/Dt
cfYtvA7XilNmlrXwO2Rlz/beILBh/9kZ3x4z3+JzeG25ycf6EEx8wX4GMBBw
gNGsm9dqVB/L2jNzMwvfv0kCDlyPl0U+khNwyICotzdO55T5oyroIHrMd/MR
WwGHTIj59mek+LR+7RB0kF/5hWd5jICDLMQ9GOJQd2KYA3WnPbq9UHfa43Cn
zTk0f0HdiREOUHfuRw83qDsxxGHhCQCUlYvl
       "], {{3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}, {3.4598656434649335`, 
       4.336513814379977, -0.00365097547078104}, {4.321149245437287, 
       4.51747580937681, 0.18461297046761505`}, {4.5401343565350665`, 
       3.6634861856200236`, 0.00365097547078104}, {3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZkO/W3o0PAQThtodDjUCGHTKGbL7rbdu+/va7t
H2u0gAOPi9j2N4+FHOYkWs/eFLlpf1648/8mXQEHNqXu6G+FwlDxRfsZwEDA
AUKLOET47mCqn5q3RzWwkvHXEn6HX3dLlnD2iTjMgqi391z0iemLJ7/Dl90v
PYRlRB1mQ8y3z/uczfLuHZ/D25lxb2VWiTqkQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Aa8CXvw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSjscLKhu977yu79fAqP
LdX38TpUCU02nblN2KGNIXZVe++m/ewTPs4Rvs/nYNt5cpbPbZj4ov0MYCDg
AKFFHEzCPkg/ep235495u2HZBAGHw2VmqZtVRBxaIOrtf+bzJb9REHRoe5tz
Ks1TxKEVYr791+VTpyRtFHTwSlmsL5Un4nAc4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+9HDDepODHFYeAIARb6ZSw==
       "], {{3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}, {3.443437302503698, 
       5.308604206611026, -0.0011863463318433354`}, {4.289892536333735, 
       5.523647740599293, 0.21622988032011106`}, {4.556562697496302, 
       4.691395793388974, 0.0011863463318433354`}, {3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY8o/zqaJmwg99v8Yz3q0QPSAecZ9xZt8t+o1Hu
x+Ylwg6dy3fNmi8jemBf1/3VF1ZutI+Yue2H4yVhh6PBsWf9+0Sg4gvtGcBA
xAFKH5hgI38yuiDXZkWaJ/s+XREH6zWLjDYUCh/YA1G/3//sJL6aaBGH8gjX
1ITHQgf2Qszf/934jqhVp4jDJpYX0wVChQ5IQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBQDylww==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIHDu/Z6xSscmD//2m3
7256KORwtTFgb8RO4QPrf/+JONK6dX/D6bd5NwuEHV47rIhbcwcmvnQ/AxiI
OEDpA3suXvpS8b5wT4OJ0ES1fhEH0f3hC4OVRQ6shai3Z8xUUfKVE3XQrlvv
tNxN5MA6iPn2jXPNNhevFXVwsGV/8itT5MAhiHswxKHuxDAH6k57dHuh7rTH
4U4bdH9B3YkRDlB37kcPN6g7McRh4QkAfNSs8Q==
       "], {{
       4.446602686144281, -5.313432754060626, -0.02261242355976882}, {
       4.714623967510865, -4.4795749765342965`, -0.22960469296484698`}, {
       5.553397313855719, -4.686567245939374, 0.02261242355976882}, {
       5.285376032489135, -5.5204250234657035`, 0.22960469296484698`}, {
       4.446602686144281, -5.313432754060626, -0.02261242355976882}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF59+aa4fr+wg3bnnPojWwUPPN+gyawcuM1etvcZ
/6ktwg6ybMKhN5QFD3RNM2dpObjWvs/tM3vqLWEHvuZOrTcTBaDic+0ZwEDE
AUILHJBd0cz87nSGTdFOnh+zVEUcHv98s0r9Dt+Bdoj6/Y+LJD+Yeos4HP98
M9R/B++BToj5+0N11F5cKBBxWPX2GEP5FJ4DzyDuwRCHuhNuzjGoOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AX7empM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwH+vKnp/du2bP/b4Tj
xoY7Qg7LFN+//9nBfyDBa9d7DuXN++vXLIhwyBN2uDzh+/eaIzDxxfsZwEDE
AUILHJin9vAJ39P8PY3B8cv3TxRxmG7O0nJQVuBAHES9PfPyfX71yqIOuvkc
HM3WAgfiIebbt/yS/Wa3VdThyDKeHpdIgQM9EPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMA8Aae1A==
       "], {{
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}, {
       4.683173925161513, -3.485317056463843, -0.19930555921848897`}, {
       5.537169907483723, -3.6596681540899216`, 0.024954461592410312`}, {
       5.316826074838487, -4.514682943536157, 0.19930555921848897`}, {
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ9aby5fKWwgxSjjlNUHfeBmatfs18t32jP4Xb2
jP8xYQfBMFkdmxCuA2eePIkv9Fpuz7I47Zn6Y2EHztV8YnJanFDx6fYMYCDi
AKE5DoRkvjy/OSPZ5k/MTMkbMiIOP0I+vnx4le3AKYj6/T92GhlvsBRxeL/y
0eXDq1kPnIaYv/+z2BmfjjARh+f/Lu9d2shyYDrEPXDxZ1BxqDsxzIG6cz/M
3u9Qe6Hu3I/DnXtg/uKA+gvqToxwgLrTHhZuktBwg7rTHld4AgB2yaTn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewHjotXCcbP2bnfxN3k
juINIYfcnAara4vYD7TuWsb9Smjj/lnKUu8EcoQdzMwcZLMvwsQX7mcAAxEH
CM1xwKjnQMbtkpw9aXeeCr6fLOJw6uT+R1P0OA40Q9Tbn9lxWvmeuqjD5Mn1
RzVjOQ60QMy3N5y60fTsblGH2Fj7Ffu6OQ4chbjH3ghNHOpODHOg7rRHtxfq
Tnsc7rRB9xfUnRjhAHXn/vNo4QZ1535c4QkABlSbCg==
       "], {{
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}, {
       4.651104317658282, -2.495069664572104, -0.1682770311360975}, {
       5.517904318733632, -2.631539151635964, 0.031807544072237376`}, {
       5.348895682341718, -3.504930335427896, 0.1682770311360975}, {
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5dH6oddlTY4dFzyQy2XuYDPSp8zRd4Vthbnnos
8+SGsMO0WWmuLHFMBzbncjJ1cyywl3layFf0RtjB23ezEpM+I1R8gj0DGIg4
QGiGA1e28a97viPK5olU38deYRGHrNSZu34v/Lt/I0T9/uOmMo+l1UUcrpwy
Kv3u/Hv/Joj5+1cHrLqy0krEwc7gjP7npz/2d0HcAxe3hYpD3Qk35zLUHKg7
96PbC3Xnfhzu3IPuL6g7McIB6k57WLg9hIYb1J32uMITAFbOk70=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//739/lKvtpsn1/UMTx
XeevCDlM2vJ++e76//unXkqe6/Nx3X7NNcl307OEHTxvfb98dz9MfN5+BjAQ
cYDQDAeq9S/rip7M3HM9eI7SjKkiDreFWMQEFRgOTIKot1+33MLVQFvUYbsq
h46SA8OByRDz7Vt+X0k/cUDUYZIFj5NxAsOBtxD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAFR4qAI=
       "], {{
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}, {
       4.619023991127767, -1.5091673571695932`, -0.1376248429459686}, {
       5.495552964467648, -1.6031128909181338`, 0.043679309197428254`}, {
       5.380976008872233, -2.490832642830407, 0.1376248429459686}, {
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb9oXg65pGwg3ZBS+dhne/7+62+aO7rmGHPF3Dw
ju0bYQfZBWujm0582Z9Q41uoGT3Bnn1Fwju5b8IOfBeu6TqmfIKKN9gzgIGI
A4T+sH++SmP6LCdvm5/h8wUfcoo4PIkPWlJr/np/HET9/k/r7ZQPCYs4HN+/
xON33rP98RDz979mv2eyWFbEYbX89zcVyx7u74O4By6+CioOdSfcnGNQc6Du
3A+z9zHUXqg79+Nw5x50f0HdCQ8HGWg4QN1pDws3LWi4Qd1pjys8AY+uo70=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f751x7nzVp7db9tlWC
obsvCTnITindolb7fn9N8avHuc/X7Jfb27EqNlPYge+UVdTkfTDxOfsZwEDE
AUJ/2D9x64wXBmIZex45lYcumibi8HPWo6BtCh/2V0LU2x9ufbfKRVfU4aPp
0aU5jh/2V0HMt196IpXh+WFRh1cXlv9QSvqwfzbEPRjiUHfCzfkENQfqTnt0
e6HutMfhThuYv/ih/oK6EyMcoO7cjx5uUHdiiMPCEwC6Tri6
       "], {{
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}, {
       4.587632007445626, -0.527612201225504, -0.10863888017492673`}, {
       5.470253784431534, -0.5755304662070981, 0.060720615193332494`}, {
       5.412367992554374, -1.472387798774496, 0.10863888017492673`}, {
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcTh9BgTu7GdAASIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIAeUNHcg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINa4w/eMw1rIgQEKHN8JB6iqb91/dNKWd6yXEOLM
k6UOGJqs2Z/sGfWdKVMYTXzOfghPBC6uoyqmcKUhfc/cbUs5/k5DiDNA1Ntb
53oL/tIVhYszQsy3v6H8UfL7EYS4A8Q9GOJQd2KYA3WnPbq9UHfa43CnDbq/
oO7ECAeoO/ejhxvUnRjisPAEAJHdWYk=
       "], {{
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}, {
       4.557651133210165, 0.4499999999999999, -0.08262856678987253}, {
       5.442348866789835, 0.4499999999999999, 0.08262856678987253}, {
       5.442348866789835, -0.4499999999999999, 0.08262856678987253}, {
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Nfs9ksayIwyr5728qlj2077f6ormvY8b+T+vt
lA8Jizgc27/E43feM/uEGt9CzegJ+3+Gzxd8yCni8Dg+aEmt+WuoeMN+BjAQ
cYDQH+znqzSmz3Ly3sO+IuGd3DdhB74L13QdUz7Zx0HU2/MFHLxj+0bYQWbB
2uimE1/s4yHm24v+UDwd80jYQaugpfOwznf7Poh74OLaUHGoO+HmyELNgbrT
Ht1eqDvtcbjTBuavJ1B/Qd0JD4fj0HCAunM/LNxWQ8MN6s79uMITALm+nWg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f2c669z5q0dut+2yrB
0N2XhBxkp5RuUat9b19T/Opx7vM1++X2dqyKzRR24DtlFTV5H0x8zn4GMBBx
gNAf7CdunfHCQCxjzyOn8tBF00Qcfs56FLRN4YN9JUS9/eHWd6tcdEUdPpoe
XZrj+MG+CmK+/dITqQzPD4s6vLqw/IdS0gf72RD3YIhD3Qk35xPUHKg77dHt
hbrTHoc7bWD+4of6C+pOjHCAunM/erhB3YkhDgtPAIqDsTo=
       "], {{
       4.587632007445626, 0.527612201225504, -0.10863888017492673`}, {
       4.529746215568466, 1.4244695337929019`, -0.060720615193332494`}, {
       5.412367992554374, 1.472387798774496, 0.10863888017492673`}, {
       5.470253784431534, 0.5755304662070981, 0.060720615193332494`}, {
       4.587632007445626, 
       0.527612201225504, -0.10863888017492673`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF4dsOrKSisRB1uDM/qfn/6w71Hha77As2L/cVOZ
x9LqIg6XTxmVfnf+bb85l5Opm2PB/idSfR97hUUcslJn7vq98C9UfMJ+BjAQ
cYDQDA5XtvGve74jao/M00K+ojfCDt6+m5WY9BkdNkLU21ueeizz5Iaww7RZ
aa4scUwOmyDm24euD9UOOyrs8PC5ZAZbL7NDF8Q9cPFHUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw+EKNByg7twPCzc7aLhB3bkfV3gCAJTDjtI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//27+9ylf002b4/KOL4
rvNXhBwmbXm/fHf9f/upl5Ln+nxct19zTfLd9CxhB89b3y/f3Q8Tn7efAQxE
HCA0g0O1/mVd0ZOZe64Hz1GaMVXE4bYQi5igAoPDJIh6+3XLLVwNtEUdtqty
6Cg5MDhMhphv3/L7SvqJA6IOkyx4nIwTGBzeQtyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AJK2ggg==
       "], {{4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}, {4.504447035532352, 
       2.396887109081866, -0.043679309197428254`}, {5.380976008872233, 
       2.490832642830407, 0.1376248429459686}, {5.495552964467648, 
       1.6031128909181338`, 0.043679309197428254`}, {4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4sdsanI0zE4dm/y3uXNrI4zFz9mv1q+cb9P3Ya
GW+wFHF4v/LR5cOrWR3OPHkSX+i1fP+fmJmSN2REHL6HfHz58CobVHz6fgYw
EHGA0BwOIZkvz2/OSN7DsjjtmfpjYQeO1XxiclqcDqcg6u053M6e8T8m7CAY
JqtjE8LlcBpivj3vS+PN5SuFHSQZdZyi6rgdpkPcAxeXgopD3YlhDtSd9jB7
OaH2Qt1pj8OdNjB//YD6C+pOjHCAunM/LNyeQ8MN6s79uMITAMm8oR0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewOx8WrBOPn7Nxv4m5y
R/GGkENuToPVtUXsDq27lnG/Etq4f5ay1DuBHGEHMzMH2eyLMPGF+xnAQMQB
QnM4GPUcyLhdkrMn7c5TwfeTRRxOndz/aIoeh0MzRL39mR2nle+pizpMnlx/
VDOWw6EFYr694dSNpmd3izrExtqv2NfN4XAU4h57IzRxqDsxzIG60x7dXqg7
7XG40wbdX1B3YoQD1J37z6OFG9Sd+3GFJwDWepOK
       "], {{4.651104317658282, 
       2.495069664572104, -0.1682770311360975}, {4.482095681266368, 
       3.368460848364036, -0.031807544072237376`}, {5.348895682341718, 
       3.504930335427896, 0.1682770311360975}, {5.517904318733632, 
       2.631539151635964, 0.031807544072237376`}, {4.651104317658282, 
       2.495069664572104, -0.1682770311360975}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7VUXtxoUDEYdXbYwzlU3gcnm/QZFYO3Lb/cZHk
B1NvEYdjn2+G+u/gdeiaZs7ScnDt/qKdPD9mqYo4PP75ZpX6HT6o+Nz9DGAg
4gChBRxkVzQzvzudsafP7TN76i1hB77mTq03EwUc2iHq7WV7n/Gf2iLsIMsm
HHpDWdChE2K+/erLN8X1+4UdtDvn1B/ZKujwDOIeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHfCw+E4NByg7tyPHm5Qd2KIw8ITAJxik1I=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwOffnT03u37Nn/N8Jx
Y8MdIYdliu/f/+zgd0jw2vWeQ3nz/vo1CyIc8oQdLk/4/r3mCEx88X4GMBBx
gNACDvPUHj7he5q/pzE4fvn+iSIO081ZWg7KCjjEQdTbMy/f51evLOqgm8/B
0Wwt4BAPMd++5ZfsN7utog5HlvH0uEQKOPRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwDAO5dU
       "], {{4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}, {4.462830092516277, 
       4.340331845910078, -0.024954461592410312`}, {5.316826074838487, 
       4.514682943536157, 0.19930555921848897`}, {5.537169907483723, 
       3.6596681540899216`, 0.024954461592410312`}, {4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5ufEfUqlPEYRPLi+kCoUIO0gHnGXfW7drvf3YS
X020iEN5hGtqwmMhh31d91dfWLlx/4o0T/Z9uiIO1msWGW0oFIaKL9zPAAYi
DjB6go38yeiC3D0RM7f9cLwk7HA0OPasf5+Iwx6IevuNRrkfm5cIO3Qu3zVr
voyow16I+facZ5RfHS0TdvD7LZ7xfpWogxTEPRjiUHdimAN1pz26vVB32uNw
pw26v6DuxAgHqDv3o4cb1J0Y4rDwBABZ7Z27
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIOh/fsdQpWObD//7Tb
dzc9FHK42hiwN2KnsMP6338ijrRu3d9w+m3ezQJhh9cOK+LW3IGJL93PAAYi
DjB6z8VLXyreF+5pMBGaqNYv4iC6P3xhsLKIw1qIenvGTBUlXzlRB+269U7L
3UQc1kHMt2+ca7a5eK2og4Mt+5NfmSIOhyDuwRCHuhPDHKg77dHthbrTHoc7
bdD9BXUnRjhA3bkfPdyg7sQQh4UnAE0JpXE=
       "], {{4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}, {4.446602686144281, 
       5.313432754060626, -0.02261242355976882}, {5.285376032489135, 
       5.5204250234657035`, 0.22960469296484698`}, {5.553397313855719, 
       4.686567245939374, 0.02261242355976882}, {4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQcYDQH/aj8lUcwkJB4CkO8asY4gwoACEeAlFv
j138KYY41D1Ei4fhMCcMh70E3InhrxAc4QB1D0FxABe8L7E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN77Of0ZZ5aqAwMUOPPMkPw2Vcnh8vf376I/qsDF
dTkEBJfwKTu8+l3+fW0FQlyMpYMjqF0ZykeIw/io8gwMMP0w82DiMPtg9sPE
Ye7DJY7LHFz24nInLn/hCgdc4YZLHAA8XFso
       "], {{10.707106781186548`, -1., 
       9.292893218813452}, {10.707106781186548`, 1., 9.292893218813452}, {
       9.292893218813452, 1., 10.707106781186548`}, {9.292893218813452, -1., 
       10.707106781186548`}, {10.707106781186548`, -1., 9.292893218813452}}}],
     
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyVmU2OE0EMhZsEpFlmMRdAcIyg6SVsOQISay4YxBwhy1lmOcuIJTDhb9q2
6pW/LsfSqIn65eW167XLZV5/+vLx83aapu9//zZ///79+8X0Lz7cT0v8/h/v
5+dPt/ftVfGn/fJZ8DvA+2fB3/j9qcEfDzl+Ur36fcGfv+X8hI8o8t/l/EfI
zzQbspgfwJ8gPzvkh/VF/m3Db+saeWrzc9q3/IbfAf64v6T48MNlNf/Oq/ed
P8eHH3R9c/0a4U/gdz8U9c+5nuMB8gP40wHy73h9f2F9HT8JvtVv6xR+2DT4
5xrT47k+5HisD6An/LAR/CbFc314keIjhP8A/FQfxD/OP8vv++9CfhxfzL/j
Wz0n0BN+UP72eS3vWkcd/67lN3z4oeU/S30zPPnhcZ/jab/QemW4qh+07oze
R+cHPzzC84YfJD/wvOEH0f91SvHhh+L6Ov4iz/vUPK/lkfaLs+Tf8FwfWv2G
Dz/o/pLz434h+Tc87xe5Hg3qB5zf/aD1H/TPhi/mx/GSf+APP8j67mF9Hf8k
+Wn3LwuqD2epPxa6D8fz5vzkh0d9Hy0cvxV+eb+WqPaTfRT5wQ+PWq8s5PMw
P4A/y35qEX4orq9/1nrS8ttzUv+g/YbhyQ9azw3P54scT/3Dg/QPhq/6Qet+
x38AfjxfgP45x+t+5PlxvORf3kfPP+D99wRP/aT226ab/SD70XINP7Tvl/Zj
hg8/tH4+Sb/teQQ996CnXB/mSUL4QX/4QfTvQb//juQH9LMfIP/yHMP1dXy7
v+h+ZDpov+jOI6bH8evnZcPfXIkPP7T6j7I/Gj78oOfB/HkjhP8A/O6H9fmM
88/X4Wm/6M4Ly5X6B+33fH0dr35r9Rgvzh/0PG5Xx7f6u/O76XL8ev3x5wS8
1h/Dhx/W91N9r0bnWee/y/H6/jq//A7OT5Yrzh8AT/uF+s3X1/GtP7U/MRzN
J8+SH8OHH/T9yvlpHqXvu+t2/NToeQB+rg+XnF8i+hPgh3mU1hPnnwEP/DSf
PB8g/4jP+fW5+7n0sw/fCO/bucXpHHKE133hrePb7/dz6acSf6z7RvgvOb/H
D+G/yfmlDgz5/X5Nv677KD87uE/8t0U8zaUDv03x2ieQfppLB/+U8uvcaaRf
5wwj/RE1/XquHPIDH+kPP9Tyo3VgpJ/90Orv59Lr/P1cWt+XVn8/l67xa99I
+enn0orfpPiINh/6Pvdz6SL/TPhcf7U+9HPpWv61TyD+fi79S/S/bL9vehyv
/E8pv/aNpL+fS8t9ze+C03PlCK8ReNFn/DJnGPLP1+H1XDnKD9eHPP/hh/X1
pbk01ZN+Lq3vV/t9mktT/aS5NOWzn0u/EvzPFB9Re97wQ5Hf79f06zlilJ/w
Qy3/1f3CQvss9OcSug+P8OwH/bzElXjuH4BfYqSf+wfgx/s5nv2Q4/V8PNKv
5wjC93PpgT9hLo3+7+bS68/bz6XX999+Lq31M9cfUeSXudOQ3+/X+Kt+6OfS
LR/lv3q+6OfSej7apvhyfViu3E/meqrnC5pLj/REDPor48f+AfiJD/RzP5nj
y/Vhuer/Y+L5wvD3Nf5+Ll3jr/qhn0sP+uflyvWhXY9+Ll3Dc30Afr9f01/1
Qz+XLq4v/L5+7ufSNTyfN9t61c+l19+Xfi5dw3P/APweNf3cPwD/fB2+2k/S
XHqkv+qHfi5dw5fnk8tVz/0jfj5f5HjeLzYpXmPIj/sF8AMf8WvdGubf79fy
P/bDH5Invis=
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJzFlmFKAzEUhGOr0J/90QuI3mNzBo9Q8LdHdI9U/KluVUomsDMZXiKFBnTJ
x/Rl3svbTR6Pby+vm5TSx9/fNmEc5vWT+d7wneHJ8NO70ac2P01Gn40fw/eG
H4gjT/YFznXAnOtQdYZzHTiu6Kc25zpUP4ZzHWq+xJEP1wGc/YJzHerccK4D
/170U5tzHaofw7kONV/i8C19ijiGSx4zPYlzHUTH+qnNuQ7Vj+Fch5ovcfjj
OoBzHcC5DjVPw7kOUhfWT23Odah+DOc61HyJY7jvlnuPXV+7fXZ5uyH9gJHb
WPqhDOmHMqQfynrSD4VLPxQu/QDfhks/mDyrnvsB82z8GC79gHyJI670Q+HS
D4VLPyCu4dIP7IP1XKdMT/ZjuPRDmct5AT63uZwXWNdwOS8Kl/OC/bGezwvo
c5vLeVHmcl6UudwfwOc2l/sD1jVc7g+Fy/2BfIie7w/Q5zaX+0Nur1PzJY65
3CcRx3C5TyKu4XKfJB+i5/sk9LnN5T5Z5nKfzLz+z2U81fnd5f9zdhxP/v1i
9BvSn4vuk/S7QO/iOz+jeTHfBvHPpE9Xju/0Lr7zMxrf6XlfovjOD3PExfrg
i4mzMXEiP6P+vyn+vdEvQfxEfO075uu4/XF6812CfF2f8H5F753z+UD8K+hP
p3fxnZ9e/2tdvL+YcxwXP+K3it+7brS/bt3e93f0+xbpe+sQ9Q+fR1GfOJ+9
9XRxRvvEnZvRuqP5Or1bd/T7PMp74/93fx139xm3L6P8VvFH6zDa573cnY/X
0mM+6v8X4PQxwg==
      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>{{-8, 12.5}, {-6.5, 6.5}, {-1, 13.5}}]], "Print",
 CellChangeTimes->{3.563404678969515*^9, 3.566101178770914*^9, 
  3.614727733421648*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[264]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tRotate[PointOfRays[{10,10},BirthPoint->{-50,0,-50},NumberOfRays->33],90,{0,\
1,0}],
\tMirror[{.9,.9}],
\tMoveDirected[Screen[{2,2}],{10,0,10},{0,0,0}]}, ReportedSurfaces->All, \
CreateClones->clonedplaces,
\tPlotRange->{{-8,12.5},{-6.5,6.5},{-1,13.5}}, PlotType->Full3D, \
RunningCommentary->TurboTrace, CloneSortLength-> 3];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[265]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727733698797*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277337008543`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727733703966*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727733705779*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8"}], ",", "12.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "13.5`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8"}], ",", "12.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.5`"}], ",", "6.5`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "13.5`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotType", "\[Rule]", "Full3D"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`ReportedSurfaces -> All, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     PlotRange -> {{-8, 12.5}, {-6.5, 6.5}, {-1, 13.5}}, 
     Optica`Optica`PlotType -> Optica`Optica`Full3D, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`ReportedSurfaces -> All, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     PlotRange -> {{-8, 12.5}, {-6.5, 6.5}, {-1, 13.5}}, 
     Optica`Optica`PlotType -> Optica`Optica`Full3D, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277337273197`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727733750351*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727733751816*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.27008599999999999274891138156817760319`5.452101986247799", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.27008599999999999274891138156817760319`5.452101986247799, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734018773*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734020678*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.61472773402225*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734023859*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734025598*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734027133*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734028947*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734030479*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734032448*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734169458*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277341711607`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734173212*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277341748877`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"PointOfRays", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"10", ",", "10"}], "}"}], ",", 
               RowBox[{"BirthPoint", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "50"}], ",", "0", ",", 
                  RowBox[{"-", "50"}]}], "}"}]}], ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "33"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", 
                 RowBox[{"-", "1.`"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "50.`"}], ",", "0", ",", "50.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.7071067811865475`", ",", "0", ",", 
              RowBox[{"-", "0.7071067811865475`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.7071067811865475`", ",", "0", ",", "0.7071067811865475`"}], 
             "}"}]}], "}"}]}], "}"}]}], "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`PointOfRays[{
           Optica`Optica`Ray[]}, {10, 10}, 
          Optica`Optica`BirthPoint -> {-50, 0, -50}, 
          Optica`Optica`NumberOfRays -> 33, 
          Optica`Optica`SourceTransformation -> {{0, 0, 
            0}, {{0, 0, -1.}, {0, 1., 0}, {1., 0, 0}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, 0, 0}, {{0, 
            0, -1}, {0, 1, 0}, {1, 0, 0}}}]], 
       Optica`Optica`SourceTransformation :> {{-50., 0, 50.}, {{
          0.7071067811865475, 0, -0.7071067811865475}, {0, 1., 0}, {
          0.7071067811865475, 0, 0.7071067811865475}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-50, 0, 
         50}, {{2^Rational[-1, 2], 0, -2^Rational[-1, 2]}, {0, 1, 0}, {
          2^Rational[-1, 2], 0, 2^Rational[-1, 2]}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 33, 
       Optica`Optica`BirthPoint :> {-50, 0, -50}, 
       Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 71646, 
       Optica`Optica`SourceFraction :> {1, 1}, 
       Optica`Optica`SourceOffset :> {0, 0}, 
       Optica`Optica`GridSpacing :> {#& , #& }, Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues :> {}], False, False, False, 
      False, {{-50., 0, 50.}, {{0.7071067811865475, 0, -0.7071067811865475}, {
        0, 1., 0}, {0.7071067811865475, 0, 0.7071067811865475}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277341777554`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734269031*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734270637*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277342721024`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.61472773436931*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277343708887`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277343726*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734374631*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734376936*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "2"}],
  SequenceForm["maximum used clone sort position = ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734920776*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"871", ",", "8", ",", "0"}], "}"}]}],
  SequenceForm["Histogram of used sort positions: ", {871, 8, 0}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727734922454*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({871, 8, 0}\\)\\), \
\\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] All\\)\\)\\)\\)]\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727734971664*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "0.70992699999999997473310031637083739042`5.871813606890082", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "1758",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   0.70992699999999997473310031637083739042`5.871813606890082, 
   " seconds with ", 1758, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277350181704`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735071802*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735074379*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277350774*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735080476*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735082106*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277350835648`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277350849524`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735086903*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735206291*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.6147277354910173`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJysnHdUFcn2tpEgKCDZnMWcszOiXQbMOWACxZyzYs5hdMxixlHBLCYU89Eq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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7WmeXYUCZyoE3Ae9ejVaIHmGNN7/is32+/K3qO
NoO/yIF1W++oTZcRPcBkd25Sh/xW+7u650Qb1EUOXI/Km+zdJwIVX2rPAAYi
B2D0GmNGVfdZhTbKlwxf1d8QPqC5dGLOlkLhAwwQ9fvdliRf+b9B+ECQl/LN
jMdCBxgh5u/PKpu6r75T+ED1+y2usqFCBxgg7oGLV0HFoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHhZurdBwg7rTHld4AgAlc5t6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQofqEwUOMezotPe/lB1
lpW66AGO41vuNq4WPrDsNZfJZqlGe4WHtqZzJ4scaEm+9e7AVZh4oT0DGIgc
gNEi9/aEXW20sXkod+hUUo7wgZo5qoL2WiIHlkLU7z9o2zL16A2hAz8svJXq
QmDijfsXxbglaLgKHSi5WmC8t07kQDnEPRjiUHdimAN15/4HaPZC3bkfhzv3
yKP5C+pOjHCAutMePdyg7sQQh4UnAE8rnsw=
       
       "], {{-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}, {-5.316739533975529, -4.4593508581224395`, \
-0.11124105808568469`}, {-4.451813203970924, -4.706888096742872, \
-0.1362961805347467}, {-4.683260466024471, -5.5406491418775605`, 
       0.11124105808568469`}, {-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJYofOTokSByoLmM6a3pNsED9zviGJ8577JP9X6j
beAgcmDtz7DPyiqCB16x2ofNbNpov1n1m6iEgsiBazWrfwpOEoCKL7RnAAOR
AxBa4IBB/L7+/3q5Nr63OF89vy98IJhtJc+d23wHXkLU75+9RfjK+f3CB5bx
BEnu2M4LFd+4/0Wf7L7t84UP/BL6rTplMs+BuxD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAHZ9ong=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMt/QFVO4wT7ldn2kzdt
LOnQEj1wkd3P9HUx/wEpkYLWqN5J9l43I6xcpooceMG8fNbXnTDxJnsGMBA5
AKEFDlwpS7037bWfzTa15Ud3Zwkf4KlbY8SqLHBAAqJ+f66vX3f5VaEDEn8i
UrncBA5IQszfr1zyNcDYQeiAchXrDP5MgQPKEPdgiEPdiWEO1J370e2FunM/
DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AugqWTQ==
       
       "], {{-5.531329884018523, -4.325341537419348, 
       0.12977456753339}, {-5.343278604100026, -3.469461366072062, \
-0.07542252897520049}, {-4.468670115981477, -3.6746584625806524`, \
-0.12977456753339}, {-4.656721395899974, -4.5305386339279385`, 
       0.07542252897520049}, {-5.531329884018523, -4.325341537419348, 
       0.12977456753339}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC66dVtI1lPkgJFrdmR0PfcB5imlsf2uW+wXTpzE
s89A5ICi3qcJz0O4DmyQ+nQxk321/UUPT7Z4CZEDguKVJ4q1OKHis+0ZwEDk
AITmOPD8gGeLbluajf72bT8XPBc+8P5Fm3nPVbYDayHq98fn5X52PC984P5F
3nyJ1awH1kPM39+nqvL20TbhA+d2TVm2pIHlABPEPRjiUHdimAN15350e6Hu
3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwCxsaBB
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewHnCaFdf9TWWLPs+Qr
r5mu6IGp5jsiHk1mPxAlIcf/7/Yse7ZLv9hmTxM5cFo6RufjSZh4lz0DGIgc
gNAcB+Znvkv8lxhm80uX9WdKpvAB0yeLL/OZcRwIh6jf/yWa69PJS0IHsk+4
L5fN4TgQATF//7tO/td6NkIHFqx5XaWziOOAI8Q9+9+iiUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1p70QWrhB3WmPKzwBhR2gJQ==
       
       "], {{-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}, {-5.369827301509674, -2.4836276446310626`, \
-0.03984165745559268}, {-4.487372759012824, -2.6420004479704664`, \
-0.11853114588381125`}, {-4.630172698490326, -3.5163723553689374`, 
       0.03984165745559268}, {-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7GO2mFvqHIgYR2ocoVvcwHLI1rpGfMWm3fH5dY
cEpB5MBrlu0BBXFMBy6dCRISSF9k777ewCJVQORAaVO0hoU+I1R8kj0DGIgc
gNAMB2JC7xcfXR1nszPg/PFZ74UPiP32WN+/8O/+CxD1+wsXzus3vS98QPvb
xDh559/7L0LM36/1KTf8wjnhAw4fb/Guf/JjvznEPRjiUHfCzdGCmgN1536Y
vaJQe6Hu3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwDMJZ9O
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/3W667dG3f5RX2qtq8
Vfr6ogdmZubWH8/5v1+9pOeJZu8C+8lT2fZOny5y4OyWbfuTt8HEJ9gzgIHI
AQjNcOCV2KuaD1OjbXKzfjplZAgfmLVUReGcCsMBVYj6/bevfGq9cEHogLG3
p8McT4YDahDz93vYvzlhYSl04OyH3ISsPIYD5hD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAOcOq2o=
       
       "], {{-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}, {-5.39608595530146, -1.5019171722096671`, \
-0.005423345214476072}, {-4.507847314362481, -1.6097448420306848`, \
-0.10240432460654149`}, {-4.60391404469854, -2.498082827790333, 
       0.005423345214476072}, {-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64dHPtLgmRAxJ92aUqut/3t9xNkpL7Nts+oOdZ
cY2AyIFdcZ9+HDrxZX+k3XRBkSWT7DXcPlvacYgciNWvrElM+QQVb7JnAAOR
AxD6w/7JQn+Olwn629zYyXPs4HfhA24LedltzV/vD4eo37+hWLKn+b3wgR4n
ab6qvGf7IyDm7+/QVQtyfS584NJjDdHtSx/ub4a4By5+ESoOdSfcnG6oOVB3
7ke3F+rO/TjcuQfdX1B3YoQD1J32sHATh4Yb1J32uMITAN4Goo8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/3b3lx6XDCntX2TDxT
fFMNRA/wuhXH3896v7/yw8PrU2sX2TOynVpmNEPkAPvinevzt8LEJ9kzgIHI
AQj9Yf+JCRVC/hfjbP7/NI08my58oFZPWcND9cP+coj6/f8+Z2+adV7owM8Y
t4AJXh/2V0DM3//37ULuDHOhA2XdmRU38j/s3wRxz/4/aOJQd2KYA3XnfnR7
oe7cj8Ode9D9BXUnRjhA3WnPjBZuUHfa4wpPAIesugg=
       
       "], {{-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}, {-5.421742536374846, -0.5241728505774544, 
       0.026865533393664168`}, {-4.529958215082733, -0.5787849537735706, \
-0.0814776365897804}, {-4.578257463625154, -1.4758271494225457`, \
-0.026865533393664168`}, {-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOXD2DAjc2c+AAkQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDq/UMU
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH76tLrP5KToAQYoUNaZ7P13xxp755lBW84aIMTz
ZJOM/qkutl/ko3krbYYImvhkewgPIZ7Qtvjfn5fxNnGbr6nOTBeGi+dA1O/f
m7bW2+i8EFw8F2L+fmmplsLTZghxRYh7MMSh7sQwB+rO/ej2Qt25H4c796D7
C+pOjHCAutMePdyg7sQQh4UnAIbCbzw=
       "], {{-5.446489549934516, -0.45, 
       0.05609885737938949}, {-5.446489549934516, 0.45, 
       0.05609885737938949}, {-4.553510450065484, 
       0.45, -0.05609885737938949}, {-4.553510450065484, -0.45, \
-0.05609885737938949}, {-5.446489549934516, -0.45, 
       0.05609885737938949}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO7QVQtyfS584OJjDdHtSx/at9xNkpL7Nnv/hmLJ
nub3wge6naT5qvKe2UfaTRcUWTJp/42dPMcOfhc+4LaQl93W/DVUvGk/AxiI
HIDQH+wnC/05Xibov0fD7bOlHYfIgVj9yprElE/24RD19gE9z4prBEQO7Ir7
9OPQiS/2ERDz7Ssu3Vy7S0LkgHhfdqmK7nf7Zoh74OISUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw6EHGg5Qd+6HhdslaLhB3bkfV3gCAPXvm6U=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/tt7y4dDhhz2p7Jp4p
vqkGogd43Yrj72e9t6/88PD61NpF9oxsp5YZzRA5wL545/r8rTDxSfYMYCBy
AEJ/sD8xoULI/2Kczf+fppFn04UP1Oopa3iofrAvh6jf/+9z9qZZ54UO/Ixx
C5jg9cG+AmL+/r9vF3JnmAsdKOvOrLiR/8F+E8Q9+/+giUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz0zWrhB3WmPKzwBV+GyiA==
       "], {{-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}, {-5.470041784917267, 
       1.4212150462264295`, 0.0814776365897804}, {-4.578257463625154, 
       1.4758271494225457`, -0.026865533393664168`}, {-4.529958215082733, 
       0.5787849537735706, -0.0814776365897804}, {-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb6lBt+4ZzwAYePt3jXP/lhb2lcIz1j1ur9hQvn
9ZveFz6g9W1inLzzb/tLZ4KEBNIX7d8ZcP74rPfCB0R/e6zvX/gXKj5pPwMY
iByA0AwOMaH3i4+ujtvjvt7AIlVA5EBpU7SGhT6jwwWIevv+uMSCUwoiB16z
bA8oiGNyuAgx3/4a76QV+oYiBxLahSpX9DI7mEPcgyEOdSeGOVB32qPbC3Wn
PQ532sD8JQb1F9Sd8HDQhoYD1J370cMN6k4McVh4AgAZpptG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/tLdddurbv8gp7VW3e
Kn190QMzM3Prj+f8t1cv6Xmi2bvAfvJUtr3Tp4scOLtl2/7kbTDxCfYMYCBy
AEIzOLwSe1XzYWq0TW7WT6eMDOEDs5aqKJxTYXBQhajff/vKp9YLF4QOGHt7
OszxZHBQg5i/38P+zQkLS6EDZz/kJmTlMTiYQ9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBt0Oj6g==
       "], {{-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}, {-5.492152685637519, 
       2.390255157969315, 0.10240432460654149`}, {-4.60391404469854, 
       2.498082827790333, 0.005423345214476072}, {-4.507847314362481, 
       1.6097448420306848`, -0.10240432460654149`}, {-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO5TVXn7aJvwgXO7pixb0sDiwDylNLbfdcv++Lzc
z47nhQ/cv8ibL7Ga1WGD1KeLmeyr9+tv3/ZzwXPhA+9ftJn3XGWDis/ezwAG
IgcgNIfD8wOeLbptaXsueniyxUuIHBAUrzxRrMXpsBai3n7hxEk8+wxEDijq
fZrwPITLYT3EfPuiW7eFZD1FDhi5ZkdG13M7MEHcgyEOdSeGOVB32qPbC3Wn
PQ532qD7C+pOjHCAunM/erhB3YkhDgtPAPxcm8c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewOTpPCuv+pLLHnWfKV
10xX9MBU8x0RjyazO0RJyPH/uz3Lnu3SL7bZ00QOnJaO0fl4EibeZc8ABiIH
IDSHw/zMd4n/EsNsfumy/kzJFD5g+mTxZT4zDodwiPr9X6K5Pp28JHQg+4T7
ctkcDocIiPn733Xyv9azETqwYM3rKp1FHA6OEPfsf4smDnUnhjlQd+5Htxfq
zv043LkH3V9Qd2KEA9Sd9kJo4QZ1pz2u8AQAVVKYpQ==
       "], {{-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}, {-5.512627240987176, 
       3.3579995520295336`, 0.11853114588381125`}, {-4.630172698490326, 
       3.5163723553689374`, 0.03984165745559268}, {-4.487372759012824, 
       2.6420004479704664`, -0.11853114588381125`}, {-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7RJ7tv+3zhA7+EfqtOmczjcL8jjvGZ8679s7cI
Xzm/X/jAMp4gyR3beR1esdqHzWzauN/3Fuer5/eFDwSzreS5c5sPKr5wPwMY
iByA0AIOBvH7+v/r5e7ZrPpNVEJB5MC1mtU/BScJOLyEqLdP9X6jbeAgcmDt
z7DPyiqCUPGN9hKFjxw9EkQONJcxvTXdJuhwF+IeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHdihAPUnfvRww3qTgxxWHgCAL+ynUU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMvvoCqncYL9ymz7yZs2
lnRoiR64yO5n+rqY30FKpKA1qneSvdfNCCuXqSIHXjAvn/V1J0y8yZ4BDEQO
QGgBhytlqfemvfaz2aa2/OjuLOEDPHVrjFiVBRwkIOr35/r6dZdfFTog8Sci
lctNwEESYv5+5ZKvAcYOQgeUq1hn8GcKOChD3IMhDnUnhjlQd+5Htxfqzv04
3LkH3V9Qd2KEA9Sd9ujhBnUnhjgsPAGKP47N
       "], {{-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}, {-5.531329884018523, 
       4.325341537419348, 0.12977456753339}, {-4.656721395899974, 
       4.5305386339279385`, 0.07542252897520049}, {-4.468670115981477, 
       3.6746584625806524`, -0.12977456753339}, {-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM4qm7qvvlP4QNX7La6yoUIOzLGmd3zW79/vtiT5
yv8NwgeCvJRvZjwWcmCyOzepQ37rfuVLhq/qbwgf0Fw6MWdLoTBUfOl+BjAQ
OQClHdYYM6q6zyrcc1f3nGiDusiB61F5k737RBwYIOrtd0XP0WbwFzmwbusd
tekyog6MEPPtp3VmOTaUiRxoFfDe9WiVqAMDxD1w8TaoONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/bBwq4aGG9Sd+3GFJwBRVpSe
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQo7VCYKnONZ0Wlvf6g6
y0pd9ADH8S13G1cLOyx7zWWyWarRXuGhrencySIHWpJvvTtwFSZeaM8ABiIH
oLSDyL09YVcbbWweyh06lZQjfKBmjqqgvZaIw1KI+v0HbVumHr0hdOCHhbdS
XQhMvHH/ohi3BA1XoQMlVwuM99aJOJRD3IMhDnUnhjlQd+5/gGYv1J37cbhz
jzyav6DuxAgHqDvt0cMN6k4McVh4AgAfYJdM
       "], {{-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}, {-5.548186796029076, 
       5.293111903257128, 0.1362961805347467}, {-4.683260466024471, 
       5.5406491418775605`, 0.11124105808568469`}, {-4.451813203970924, 
       4.706888096742872, -0.1362961805347467}, {-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4Yy/7lcYXAgfvKbh9jVokeqGlk3Jnav99e8SXL
j+kBAgemHtL7ZisjemDl6tUXnLm22k8oYfrjrSFwwCtR/LdcnwhUfKk9AxgI
HIDQIgd4+Ptv9HYU2twX+82esZ7/wLZ5L1geFgofWA5Rv3+f7jf+C3H8B7Jt
L3Ieeix0YAXE/P1zXT6KW/DxH1C8s5NvcajQgSqIezDEoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBrdqOh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUPNP+6yfRwRby99eKr
ywrVBQ8EBu79cG218IF1gRPXOEiH2s+9mHV5x2SBAytXxFW8vgoTd7VnAAOB
AxBa5IDAEeWnW6cJ2hyL0Yrsu8F3IDx8YbuIlsiB1RD1+7t3hmyS2ch7YP06
J37NEJEDayHm7w8Uq+de3clzgI3tyTTbOpEDjRD37A9AE4e6E8McqDv3H0Wz
F+rO/TjcuQfdX1B32luhhQPUnfbo4QZ1J4Y4LDwBfGOi6w==
       
       "], {{-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}, {-4.314722153887294, -4.460348007608924, \
-0.12134946625710644`}, {-3.449163700929936, -4.706911647569121, \
-0.12521417370309038`}, {-3.685277846112706, -5.539651992391076, 
       0.12134946625710644`}, {-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA42vzA7MEngwJxPD45f2Cp4QNzPZMN0k1325lWm
e7sdBQ7sXejQ+kBZ8MDue0oKqRUb7WX2zrp3VEHgwP2ABU4fJgpAxRfaM4CB
wAEY/VDW6sFf2Vybk62nnEr28R9wjttfJX+H78BOiPr9E7mntr6o4T/Qtqfu
q90O3gO7IObvj5oYfyLGmv/ASSm7grgpPAfEIO6Bi5+AikPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AfqOk/Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj/+AgvJhye12E+1PdSTf
fqMleIDr5b9rNiX8Bxpvriv3/Ndmn3pkY27ZVIEDrSX12XK7YOJl9gxgIHAA
RjtsFbS01XS2MSufoyJ8le/AXleHUx+UBA7UQ9Tvz3ln4am2ivdAdXfDlIeu
AgcaIObvX5R6NdeynueAxcUDcZcyBA7IQ9yDIQ51J4Y5UHfuR7cX6s79ONy5
B91fUHdihAPUnfbo4QZ1J4Y4LDwB/I2ewA==
       
       "], {{-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}, {-4.341864306775701, -3.470080753685618, \
-0.08552419621584771}, {-3.466106818667752, -3.674810750402369, \
-0.11920580050090333`}, {-3.658135693224299, -4.529919246314382, 
       0.08552419621584771}, {-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF72W9d9h5fAAaMP98Vv1XEfOHx2jiOb4xZ7yb/F
+hcMBQ6Uf7VPnRjCdSBa6OKaWMbV9r3/doq/kBA4sPvX/E0eWpxQ8dn2DGAg
cABCcxxY8CQiVbkxzeY5U88F/XP8B1xZE3y3X2U7EAFRv/8cq8TC+Dn8B7q4
DszKW816IBJi/v6tHEsK+7P4D5zjV3ih2shy4BDEPRjiUHfCzemEmgN15350
e6Hu3I/DnXvQ/QV1JzwcyqDhAHWnPXq4Qd2JIQ4LTwBENJ2Z
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9Hst+oKrogO/yH3PtrS2b
mQ/qCh7Yvtun89dk9gPLF141lvo92X7unIOND6YJHLgdu8zl70mYeLM9AxgI
HIDQHAcSNt65OnVZgM3RYzV/7C7xHVBdFLmbyYzjwFKI+v1dvT9/1C7hPeDp
srmMNYfjwDKI+fsDQsq+7injOZD3jMeIYxHHgQqIe/b7o4lD3YlhDtSd+9Ht
hbpzPw537kH3F9SdGOEAdac9erhB3YkhDgtPAFgJs7M=
       
       "], {{-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}, {-4.369053812165066, -2.4839433884236968`, \
-0.04984834375199349}, {-3.4850090079231695`, -2.642177776810767, \
-0.10838604463507687`}, {-3.630946187834934, -3.5160566115763032`, 
       0.04984834375199349}, {-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP6Vx8fkYyRwwGf/45mZvcwHpiyon/lj9mr75V/i
GDsUBQ7cvTI9zS2O6UDygf8Cv9MX2QdXrWc4IiBwIP+Vt7GyPiNUfJI9AxgI
HIDQDAf8X4fI+K6Ns4nkXviv/B7/AWXtjJk7F/7dnwhRv3+zmNPf93v4D7iF
XTAqdv69Pwli/n4epce/02fzH8hstDij8/TH/kkQ92CIQ92JYQ7UnfvR7YW6
cz8Od+6B+SsP6i+oOzHCAepOe1i4eUPDDepOe1zhCQC0oq21
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/3x+men8N7YrH97gJz
xhv6ggf+MlaoH8j5v//yxEw1oYRZ9rE7ZjO8mS5w4B/DHuGEbTDxLnsGMBA4
AKEZDtzyW3tq569QG9f+E//UL/AdaPyv+O28CsOBixD1+7vlJv71X8B7gOm/
85v5ngwHLkHM339hbeSf8gKeA03/Uh/l5zEciIW4B0Mc6s79XWjmQN25H91e
qDv343DnHnR/Qd2JEQ5Qd9qjhxvUnRjisPAEAIcMpkw=
       
       "], {{-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}, {-4.3959655727217335`, -1.5020265855785278`, \
-0.01528868040643376}, {-3.505798282008966, -1.6098752655742845`, \
-0.09255999958932283}, {-3.6040344272782665`, -2.4979734144214722`, 
       0.01528868040643376}, {-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5JPMjtIylwIOyLsgez7vf9F7l/qPv/mW3vO007
9q6AwIEniw7dWnPiy/6H7AFHTVZMslc/PXVdHofAgaLAxNywlE9Q8SZ7BjAQ
OAChP+wvS2r9HC7hb7M588oipff8B2RjbVWDzV/vvw9Rvz/18gpX13v8Byx3
VXkty3u2/wHE/P0StrUv0s/yHwgT35H/c+nD/ech7oGLh0LFoe6Em2MBNQfq
zv0we2Wg9kLduR+HO/eg+wvqToxwgLrTHhZuodBwg7rTHld4AgAMeqjF
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7vn77NLlz3yDL7iJWd
hQqGggcO1l+N3Jf1fv8pj39yz6Pm2a+5csRiwgyBAw/2v9KJ3woT77NnAAOB
AxD6w/6g55dnHvCOtFkRVtZ3/xzfAYEFXZkBqh/2H4eo3x+w9o3M/rm8BxQc
RC8v8Pqw/wTE/P0/mJNXz8vhOaD/YL7Nx/wP+6dC3IMhDnUnhjlQd+5Htxfq
zv043LkH5q+HUH9B3YkRDlB32sPCbRE03KDutMcVngBF/rXf
       
       "], {{-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}, {-4.422258832323806, -0.5241808713787737, 
       0.01713579186011437}, {-3.5283328583537994`, -0.5788402128371133, \
-0.07179513331845389}, {-3.5777411676761943`, -1.4758191286212263`, \
-0.01713579186011437}, {-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOHD2DAjc2c+AAgQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQC/ZULY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHax4j8bdkrwAAMUHG/5UrTy+HJ7vZp4435DhPjW
6NnvHm6Zby++b/3M4zME0MT77SE8hPgBRZ05gjlRNpeaF5wpOMcHF98IUb9/
KbvjzIdzeOHimyHm7y/vfpgalM0DFz8KcQ+GONSdGOZA3bkf3V6oO/fjcOce
dH9B3YkRDlB32qOHG9SdGOKw8AQAllp+eA==
       "], {{-4.4475967445892515`, -0.45,
        0.04644517448674317}, {-4.4475967445892515`, 0.45, 
       0.04644517448674317}, {-3.552403255410748, 
       0.45, -0.04644517448674317}, {-3.552403255410748, -0.45, \
-0.04644517448674317}, {-4.4475967445892515`, -0.45, 
       0.04644517448674317}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJawrX2Rfpb/QKj4jvyfSx/aX+T+oe7/Z/b+1Msr
XF3v8R+w2FXltSzvmf1D9oCjJism7d+ceWWR0nv+AzKxtqrB5q+h4k37GcBA
4ACE/mBfltT6OVzCf4/66anr8jgEDhQFJuaGpXyyvw9Rb+87TTv2roDAgSeL
Dt1ac+KL/QOI+fYliQe5fSQFDoR+UfZg1v1ufx7iHrh4GFQc6k4Mc6DutEe3
F+pOexzutIH5SxbqL6g74eFgCQ0HqDv3w8ItDBpuUHfuxxWeAEtUo+I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7bT99mF657ZJl9xMrO
QgVDwQMH669G7st6b3/K45/c86h59muuHLGYMEPgwIP9r3Tit8LE++wZwEDg
AIT+YB/0/PLMA96RNivCyvrun+M7ILCgKzNA9YP9cYj6/QFr38jsn8t7QMFB
9PICrw/2JyDm7//BnLx6Xg7PAf0H820+5n+wnwpxD4Y41J0Y5kDduR/dXqg7
9+Nw5x6Yvx5C/QV1J0Y4QN1pDwu3RdBwg7rTHld4AgAWM65f
       
       "], {{-4.422258832323806, 0.5241808713787737, 
       0.01713579186011437}, {-4.471667141646201, 1.4211597871628867`, 
       0.07179513331845389}, {-3.5777411676761943`, 
       1.4758191286212263`, -0.01713579186011437}, {-3.5283328583537994`, 
       0.5788402128371133, -0.07179513331845389}, {-4.422258832323806, 
       0.5241808713787737, 0.01713579186011437}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZRevw7fTb/gcxGizM6T3/YT1lQP/PH7NX7N4s5
/X2/h/+AW9gFo2Ln3/bJB/4L/E5ftD+Se+G/8nv8B5S1M2buXPgXKj5pPwMY
CByA0AwO/q9DZHzXxu0JrlrPcERA4EDeK29jZX1Gh0SIevvlX+IYOxQFDty9
Mj3NLY7JIQlivv2vPD4mHyOBA977H8/M7GV2mARxD1zcByoOdSeGOVB32sPs
zYfaC3WnPQ532qD7C+pOjHCAunM/erhB3YkhDgtPAO1TqEI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/t43TPz+E9sdh+d4E5
4w19wQN/GSvUD+T8t788MVNNKGGWfeyO2Qxvpgsc+MewRzhhG0y8y54BDAQO
QGgGh1t+a0/t/BVq49p/4p/6Bb4Djf8Vv51XYXC4CFG/v1tu4l//BbwHmP47
v5nvyeBwCWL+/gtrI/+UF/AcaPqX+ig/j8EhFuIeDHGoO/d3oZkDded+dHuh
7tyPw5170P0FdSdGOEDdaY8eblB3YojDwhMAV0GezA==
       
       "], {{-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}, {-4.494201717991034, 
       2.3901247344257155`, 0.09255999958932283}, {-3.6040344272782665`, 
       2.4979734144214722`, 0.01528868040643376}, {-3.505798282008966, 
       1.6098752655742845`, -0.09255999958932283}, {-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7KsaSwP4v/wDl+hReqjSwOh8/OcWRz3LL/HKvE
wvg5/Ac6uQ7MylvN6hAtdHFNLOPq/c+Zei7on+M/4Mqa4Lv9KhtUfPZ+BjAQ
OAChORwWPIlIVW5M29P7b6f4CwmBA7t/zd/kocXpEAFRby/5t1j/gqHAgbKv
9qkTQ7gcIiHm2y/7reu+w0vggNGH++K36rgdDkHcgyEOdSfcnHKoOVB32qPb
C3WnPQ532qD7C+pOeDh0QcMB6s796OEGdSeGOCw8AVQNlWA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9HsvuUFV0wHf5j7n21pbN
zAd1BQ9s3+3T+Wsyu8PyhVeNpX5Ptp8752Djg2kCB27HLnP5exIm3mzPAAYC
ByA0h0PCxjtXpy4LsDl6rOaP3SW+A6qLInczmXE4LIWo39/V+/NH7RLeA54u
m8tYczgclkHM3x8QUvZ1TxnPgbxnPEYcizgcKiDu2e+PJg51J4Y5UHfuR7cX
6s79ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBKD6sMw==
       "], {{-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}, {-4.5149909920768305`, 
       3.357822223189233, 0.10838604463507687`}, {-3.630946187834934, 
       3.5160566115763032`, 0.04984834375199349}, {-3.4850090079231695`, 
       2.642177776810767, -0.10838604463507687`}, {-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmII6aGH8ixpr/wAkpu4K4KTwO4n4mG6ab7No/kXtq
64sa/gNte+q+2u3gddh9T0khtWLj/pOtp5xK9vEfcI7bXyV/hw8qvnA/AxgI
HIDSDg9lrR78lc3dI7N31r2jCgIH7gcscPowUcBhJ0S9vXmV6d5uR4EDexc6
tD5QFnTYBTHfPtj8wuzAJIEDcz49OH5hq6CDGMQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/fDwu0kNNyg7tyPKzwBhSqbwA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj99BQfmw5Ha7ifanOpJv
v9ESPMD18t81mxJ+h8ab68o9/7XZpx7ZmFs2VeBAa0l9ttwumHiZPQMYCByA
0g4OWwUtbTWdbczK56gIX+U7sNfV4dQHJQGHeoj6/TnvLDzVVvEeqO5umPLQ
VcChAWL+/kWpV3Mt63kOWFw8EHcpQ8BBHuIeDHGoOzHMgbpzP7q9UHfux+HO
Pej+groTIxyg7rRHDzeoOzHEYeEJAMzCl0A=
       "], {{-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}, {-4.533893181332248, 
       4.3251892495976305`, 0.11920580050090333`}, {-3.658135693224299, 
       4.529919246314382, 0.08552419621584771}, {-3.466106818667752, 
       3.674810750402369, -0.11920580050090333`}, {-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7r8lHcgo//gOKdnXyLQ4UcahoZd6b279+/T/cb
/4U4/gPZthc5Dz0Wcli5evUFZ66t+++L/WbPWM9/YNu8FywPC4Wh4kv3M4CB
wAEILeLAw99/o7ejcM+EEqY/3hoCB7wSxX/L9Yk4LIeot1d8yfJjeoDAgamH
9L7Zyog6rICYb78xlv3L4wqBA/eV3T7GrBJ1qIK4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAHIEmuU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUdmn/dZHq4It7eevHV
ZYXqggcCA/d+uLZa2GFd4MQ1DtKh9nMvZl3eMVngwMoVcRWvr8LEXe0ZwEDg
AIQWcRA4ovx06zRBm2MxWpF9N/gOhIcvbBfREnFYDVG/v3tnyCaZjbwH1q9z
4tcMEXFYCzF/f6BYPffqTp4DbGxPptnWiTg0QtyzPwBNHOpODHOg7tx/FM1e
qDv343DnHnR/Qd1pb4UWDlB32qOHG9SdGOKw8AQATJibaw==
       
       "], {{-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}, {-4.550836299070064, 
       5.293088352430879, 0.12521417370309038`}, {-3.685277846112706, 
       5.539651992391076, 0.12134946625710644`}, {-3.449163700929936, 
       4.706911647569121, -0.12521417370309038`}, {-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ7/si8+xvHgZkCvL+frhQ9IMHfz+SUsN+ec9ab
8zFLOA4IcsctfycteiAtPn7NtVdb7Fl9v6XrBXEc6GBdH/y9VwQqvsSeAQw4
DkBokQP155f0x+YV2vzexDnj4lr2AxW/AtZwFAkfSIGo3/89VdhgcTT7gfdf
FkYIPhE6kAoxf/8nCdkTJZzsB9Lff2KRChM6IAZxD4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBAADoqNh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQPhHwIYj76t2k/y4nu
Wk5/rgNNTX5LQ9YIHzg2NY8lJqhyP9OTo/ta1DkPODouD9K6BhPP3M8ABhwH
ILTIAZVLbJHfJU33/JO2cqy+wXZg/76ItVc1RQ4chqi3/2Ne0vRtA+uButqN
UauDRQ4chZhv/yt43eHCTpYDNjZcHI21IgeCIO7BEIe6E8McqDvt0e2FutMe
hztt0P0FdSdGOEDduR893KDuxBCHhScAWr2f1g==
       
       "], {{-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}, {-3.312505755072035, -4.46152110262191, \
-0.13183561781754752`}, {-2.4467287942367104`, -4.706646159126566, \
-0.11328943868710814`}, {-2.687494244927965, -5.53847889737809, 
       0.13183561781754752`}, {-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP545ofSjhMcB3okrWeUbBU8cFXsA8NPiV32CzsC
xC+0chyITVMXWKwseKA/5Wvo79SN9gEuK7hfOHEc0N8s3HFxogBUfKE9Axhw
HIDQAgemL3fu9/2fY7Nhd/gX8b3sBxbPvPE+5g7fgV6I+v3x5etf6FexH3Az
3nh/5w7eA30Q8/fzG7PfdTdnP/DyTOd5sak8By5D3AMXfwEVh7oTwxyoO/ej
2wt1534c7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDdFqzl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwHGE6s+RXFXGHfkWRQ
Hx/GdeBOSIDqhRL+A6tvyS63YSqwdzGcsV9fm/NAntYKoYxdMPEEewYw4DgA
oQUOyIi3i6Wu07LZcy7d4cIVtgMnX63+dlpJ4MBKiPr9FXPPNyxYyXpg0tXw
t9NdBQ6sgpi/3zTH/GBBHcuB6APMT5IzBA78Ow52D4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBADqD5zw
       
       "], {{-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}, {-3.3402540371688305`, -3.4708538614882167`, \
-0.09608097776553255}, {-2.4637310374127157`, -3.6747409669130344`, \
-0.10780612765928528`}, {-2.6597459628311695`, -4.529146138511783, 
       0.09608097776553255}, {-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62WS9yzQyOA4/smmyS6rgPTJ+z5KKT8Rb7n+Ul
1idSOQ680VxT6xjCdeDUBYNDzO9X2f+13iX7xIjjwDeRa/sUtDih4rPsGcCA
4wCM/rtWo/xGYZoN8xHXR9Jn2Q9wvdZ0vH+V7cAJiPr97B3dR8xnsR8QuRbc
tG8164GTEPP3c/lcXBaczn5A7mDt4bmNLAemQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBXi+qQw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gP1L68vX3Lj0n2XCHO
fyNjuA7stfn+wXkK+4G/D8/Pn+3dac+6auE/HT3OA3Hzqn8onoKJV9ozgAHH
ARgdZKPLGi7iavM7NI7x8kW2A4sSW9jvmXIc+AVRv//b6j1MyxazHnA+zMG/
J5vjwB+I+fs/MkqzVJayHHiq0is2ayHHgRqIe/Z/QBOHuhPDHKg796PbC3Xn
fhzu3IPuL6g7McIB6k57frRwg7rTHld4AgAvILGg
       
       "], {{-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}, {-3.3680927955513313`, -2.484382010548441, \
-0.0603803181271666}, {-2.482812247597164, -2.642196372468562, \
-0.0974340437929547}, {-2.6319072044486687`, -3.515617989451559, 
       0.0603803181271666}, {-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4M9/C6lsZxoPFS3AK9XuYDbm+uByhMXG0faGVw
p8+F40BYzxRR+TimAwYeT00PJCyy15CVyHNX4jig7Xaqi1+fESo+yZ4BDDgO
QGiGA34VlyMdFsbZ3Hj0fOKOu+wHVhVnv3qw8O9+PYj6/euPnlcu3M1+IOT5
tSsHnX/v14eYv799xfatmjPZD/yLctq/6OmP/S4Q98DF/0LFoe6EmxMMNQfq
zv3o9kLduR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBnoag1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/v/zlJ2d7n2Bz760E9
IccTuA7suxrw72fO//3LeHLr7+pNts/WdFuVbMB54H6Wxv+abTDxZnsGMOA4
AKEZDoiIctcf++FvM/XaztA559kOTDiV3XBQheHAEoj6/Zpri1dbzGc9oDj1
OkOzJ8OBpRDz9+9r1mW8msdyYGO8c6NLHsOB7xD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9Sd8HDYDw0HqDvt0cMN6k4McVh4AgAmcqfC
       
       "], {{-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}, {-3.3956693749101743`, -1.5022218105675396`, \
-0.025741404070748052`}, {-2.503903797978213, -1.6099050111530673`, \
-0.08194179651477952}, {-2.6043306250898257`, -2.49777818943246, 
       0.025741404070748052`}, {-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO573ue4z5jjwIEg3y+Pdb7vn3K7wCH222x7Ltf4
a3VKHAcaeox/TD/xZf/O51+17JZMsm9dpJ9tL8hxwOGY5B/vlE9Q8SZ7BjDg
OAChP+w3bnL5tEfQ36Y69sKUA+/YDzQUn2HPMH+9fztE/f5vuxZoNt5lP8Dw
fAb/hbxn+3dAzN9fJFG4z/EMUH1UqrjFsof7J0PcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8ARi2tic=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff7T/t4CB4sXGg/b3W6
TUMy14FDASv47mW9379799aDYU7T7c9fNZY7YMh5IFEjhD1/K0y83Z4BDDgO
QOgP+wtkDn37lBhsY6h15qH9ObYD51+H1niofti/A6J+f1LIjMP1c1gPzL++
+scErw/7d0LM3z+5LmXp/iyWA3mHGUtv5n/YfwriHgxxqDsxzIG6cz+6vVB3
7sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBdsrFT
       
       "], {{-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}, {-3.4226114232035196`, -0.5242334257478558, 
       0.006764007855904815}, {-2.5268581199223967`, -0.5788474109204276, \
-0.06137799302847672}, {-2.5773885767964804`, -1.4757665742521442`, \
-0.006764007855904815}, {-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgOHD2DAjc2c+AAjgOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQBoNUJg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF6is01r4TTuAwxQ4NEaqnu2epF93olzhdkpXHDx
xJjjEwWXzrA3T3m+w9SIE028wx7C44CLByipLenrDLE5OVvC/dRZNrh4HET9
/snmhn1TZrPCxRMg5u+Puex5NS6TBS7uDnEPhjjUnfsnoZkDded+dHuh7tyP
w5170P0Fdad9Llo4QN1pjx5uUHdiiMPCEwDGkGug
       
       "], {{-3.44854958885624, -0.45, 
       0.03610078028101299}, {-3.44854958885624, 0.45, 
       0.03610078028101299}, {-2.55145041114376, 
       0.45, -0.03610078028101299}, {-2.55145041114376, -0.45, \
-0.03610078028101299}, {-3.44854958885624, -0.45, 
       0.03610078028101299}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6SKNzneIb9QENUqrjFsof2U24XOMR+m73/264F
mo132Q8wPJ/BfyHvmf3O51+17JZM2l8de2HKgXdA9cVn2DPMX0PFm/YzgAHH
AQj9wd64yeXTHkH/Pa2L9LPtBTkOOByT/OOd8sl+O0S9PZdr/LU6JY4DDT3G
P6af+GK/A2K+fd/zPsd9xhwHDgT5fnms891+MsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEACBnrXM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff2p308BA8WLrSftzrd
piGZ68ChgBV897Le2+/evfVgmNN0+/NXjeUOGHIeSNQIYc/fChNvt2cAA44D
EPqDfYHMoW+fEoNtDLXOPLQ/x3bg/OvQGg/VD/Y7IOr3J4XMOFw/h/XA/Our
f0zw+mC/E2L+/sl1KUv3Z7EcyDvMWHoz/4P9KYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnAC3nqdM=
       "], {{-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}, {-3.4731418800776033`, 
       1.4211525890795724`, 0.06137799302847672}, {-2.5773885767964804`, 
       1.4757665742521442`, -0.006764007855904815}, {-2.5268581199223967`, 
       0.5788474109204276, -0.06137799302847672}, {-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG5fsX2r5kz2A3+jnPYvevrD3u3N9QCFiav3rz96
XrlwN/uB4OfXrhx0/m1v4PHU9EDCov03Hj2fuOMu+4FVxdmvHiz8CxWftJ8B
DDgOQGgGB7+Ky5EOC+P2aMhK5LkrcRzQdjvVxa/P6KAHUW8faGVwp8+F40BY
zxRR+TgmB32I+faV4R5e19I4DjReilug18vs4AJxD4Y41J0Y5kDdaY9uL9Sd
9jjcaYPuL6g74eEQAg0HqDv3w8LtHzTcoO7cjys8Aa+lo7o=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/b/5ykbO9zbI799aCe
kOMJXAf2XQ349zPnv/0yntz6u3qT7bM13VYlG3AeuJ+l8b9mG0y82Z4BDDgO
QGgGBxFR7vpjP/xtpl7bGTrnPNuBCaeyGw6qMDgsgajfr7m2eLXFfNYDilOv
MzR7MjgshZi/f1+zLuPVPJYDG+OdG13yGBy+Q9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHfCw2E/NByg7rRHDzeoOzHEYeEJAPaYoEI=
       
       "], {{-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}, {-3.496096202021787, 
       2.3900949888469327`, 0.08194179651477952}, {-2.6043306250898257`, 
       2.49777818943246, 0.025741404070748052`}, {-2.503903797978213, 
       1.6099050111530673`, -0.08194179651477952}, {-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIObyubgsOJ39gNzB2sNzG1kcps9ZctHJeMt+9o7u
I+az2A+IXAtu2rea1eHUBYNDzO9X7Wc+4vpI+iz7Aa7Xmo73r7JBxWftZwAD
jgNQ2uHvWo3yG4Vpe/5a75J9YsRx4JvItX0KWpwOJyDq7X+Wl1ifSOU48EZz
Ta1jCJfDSYj59t8260WumcFx4JFdk01SHbfDNIh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+5HDzeoOzHEYeEJAHHOos0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gdal/e3r7lxyR7rhDn
v5ExXAf22nz/4DyF3eHvw/PzZ3t32rOuWvhPR4/zQNy86h+Kp2DilfYMYMBx
AEo7BNnosoaLuNr8Do1jvHyR7cCixBb2e6YcDr8g6vd/W72Hadli1gPOhzn4
92RzOPyBmL//I6M0S2Upy4GnKr1isxZyONRA3LP/A5o41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfa86OFG9Sd9rjCEwD/Rqog
       "], {{-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}, {-3.517187752402836, 
       3.357803627531438, 0.0974340437929547}, {-2.6319072044486687`, 
       3.515617989451559, 0.0603803181271666}, {-2.482812247597164, 
       2.642196372468562, -0.0974340437929547}, {-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEG3MftfdnP3AizOd58Wm8jhcFfvA8FNi1/748vUv
9KvYD7gZb7y/cwevQ3/K19DfqRv3b9gd/kV8L/uBxTNvvI+5wwcVX7ifAQw4
DkBoAYfpy537ff/n7AlwWcH9wonjgP5m4Y6LEwUceiHq7Rd2BIhfaOU4EJum
LrBYWdChD2K+/cczP5R2nOA40CNpPaNkq6DDZYh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+6HhdtLaLhB3bkfV3gCANZ+pEI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwODCfW/IpirrDvSDKo
jw/jOnAnJED1Qgm/w+pbssttmArsXQxn7NfX5jyQp7VCKGMXTDzBngEMOA5A
aAEHGfF2sdR1WjZ7zqU7XLjCduDkq9XfTisJOKyEqN9fMfd8w4KVrAcmXQ1/
O91VwGEVxPz9pjnmBwvqWA5EH2B+kpwh4PDvONg9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITALpElXA=
       "], {{-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}, {-3.5362689625872843`, 
       4.325259033086965, 0.10780612765928528`}, {-2.6597459628311695`, 
       4.529146138511783, 0.09608097776553255}, {-2.4637310374127157`, 
       3.6747409669130344`, -0.10780612765928528`}, {-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4kIXuihJP9QPr7TyxSYUIOEvz9TE4J+/d/TxU2
WBzNfuD9l4URgk+EHNLi49dce7Vl/+9NnDMurmU/UPErYA1HkTBUfMl+BjDg
OAChRRzqzy/pj80r3MPq+y1dL4jjQAfr+uDvvSIOKRD19pyz3pyPWcJxQJA7
bvk7aVGHVIj59nzPH5l3f+M4MFOA9/fTlaIOYhD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAA9Zmrc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQdQj4EMR/927Sf5UR3
Lac/14GmJr+lIWuEHY5NzWOJCarcz/Tk6L4Wdc4Djo7Lg7SuwcQz9zOAAccB
CC3ioHKJLfK7pOmef9JWjtU32A7s3xex9qqmiMNhiHr7P+YlTd82sB6oq90Y
tTpYxOEoxHz7X8HrDhd2shywseHiaKwVcQiCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAq8phW
       "], {{-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}, {-3.5532712057632896`, 
       5.293353840873434, 0.11328943868710814`}, {-2.687494244927965, 
       5.53847889737809, 0.13183561781754752`}, {-2.4467287942367104`, 
       4.706646159126566, -0.11328943868710814`}, {-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ4gd9PG9jfDgcXcFt1NK0UPHAo8djFEfr891/4J
GnXLGQ4cYr8Qs0Za9IDOQ72Hvfu32LfGe4jsD2Y48JA5Q+9arwhUfIk9AwQc
gFAiB/zT/kzw9iq0+eaQf70x4v9++T/TL2oWCR/Qgqjf/7rx3jrmjf/22/3Q
Xxz8ROiANsT8/Q8P+ba1cv7bH/vleEltmNCB/RD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdad9P1q4Qd1pjys8AehjrlY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUPLJc/4uq2bOr+M8WM
yTf9mA5Uu1SfYFwrfMBUawP75rs9+5/tbNiYo854wG6R7ZOGazDxmv0MEHAA
QokcuHZWyFCUz2OPSc+/OWob/+4/FHtIul5T5IARRL19hsRfS9+k3/tbd7eY
/wsSOWACMd9+zpLf14qFf+53l3QPrq0RObAM4h772WjiUHfap6OZA3WnPbq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAEkooqA=
       
       "], {{-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}, {-2.310075459334159, -4.462891124238714, \
-0.14271392748137285`}, {-1.4445737499249551`, -4.7060347804248615`, \
-0.10042972870477429`}, {-1.689924540665841, -5.537108875761286, 
       0.14271392748137285`}, {-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Vybv9yBmGA/YB/xaqbBU8ULHLzvfgu532Nhs3
qzR3MByoNw05mKsseOC3Wr3xNc+N9vNuRE5ydGE4cEBq1YNtEwWg4gvtGSDg
AIQSOOAzrY4h9UKOzRE/n9s15f/3N55abTfpDt+BnxD1+zvmztj2892//UxT
w2tVdvIe+AUxf7/PmycTy9L+7W+OZ96zbSrPgTKIe+DiTVBxqDsxzIG6cz+6
vVB37sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBS1bE6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgPnFq99Vf5rfL93Wse
PpgcxnTgBFuK38ZS/gM7+939vp7N3+92reCDpzbjgRRmo+U3dsHE4/czQMAB
CCVw4Mj3CWLfG7T2lAbLyees/Lvf71/amslKAge2QdTbv1pmY3cj6Pf+OX/O
Rqi7ChzYATHfPv5XVKzLnx/7X/0yYd2dLnDgJMQ9GOJQd2KYA3WnPbq9UHfa
43CnjSuav6DuxAgHqDv3o4cb1J0Y4rDwBABBeLcr
       
       "], {{-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}, {-2.3384267856882803`, -3.4718030810301665`, \
-0.10712294581215505`}, {-1.4616040559471155`, -3.674401807986821, \
-0.09547578114449966}, {-1.66157321431172, -4.528196918969834, 
       0.10712294581215505`}, {-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6nOn/909kMB7Y41q/9Xst9QFammi1Daov9/sMi
pe/SGQ6c015V/CuY60CN6hKOB2dX2d9P7LL6bsxw4LnoVcu/mpxQ8Vn2DBBw
AEJxHLCRv7fRKizNxtHmdZfgjP/7JV9pHWO6xnagCqJ+f3PFNVFlg//7ja6E
9rCuYT1QDTF//5EtBxeYnPi332dfQxBHE8sBaYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnANnAoq4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewHlk04O1/wVo39nCqR
vKcxTAey8u/Wn5jCfqAg4d5+bptiez9bru1FeowHtm5/Z59yCiaebM8AAQcg
FMcB9t+P5ePZDWxSWl9PlFr8d7+3h+CB2aYcB/Ig6vef4LqubOr2e/+0CUoN
5tkcB/Ih5u/XmXBoq//LH/sf3jB2uLyA48ASiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA8ayh1w==
       
       "], {{-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}, {-2.366917531924889, -2.4849645070759623`, \
-0.07148402475128206}, {-1.4808390979345027`, -2.642020364891229, \
-0.0855718330639844}, {-1.633082468075111, -3.5150354929240377`, 
       0.07148402475128206}, {-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62IuiPSCbDgYRVilE/e5gP+G1kCMktX22/pKDn
L68bw4HXx7In/o5lOmBaxmAxz3+RfZDFsX9sygwHSh9vPfFXjxEqPsmeAQIO
wOhwqbDYTS1xNjH9xUyfdv7fL2o5JY9l0d/9xhD1+3fIPWd5Uvx/v1aRxl0O
l9/7TSDm7xddF8V+Tff/fofVe7x5n/3Y7wtxD4Y41J0Y5kDduR/dXqg79+Nw
5x50f0HdiREOUHfao4cb1J0Y4rDwBAC52J69
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7v12H7V1ZoMtHeLyTX
Z1oi0wG/P/Z8zbn/9z/fFOQ5/UObvfoqM7XTBowH1P/Jtx/cBhMvs2eAgAMw
OuvVkfTLss42m1dP2pw57+/+NwwFNvNVGA48gajfnxqumn7Z5vf+m4wPKuw8
GQ48hZi/X4J5h5Tt7R/7jzIFbL2by3BAG+IeDHGoOzHMgbpz/yY0e6Hu3I/D
nXvQ/QV1p70vWjhA3WmPHm5Qd2KIw8ITADZMq2Y=
       
       "], {{-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}, {-2.395165371281734, -1.502519492476819, \
-0.03684391366627121}, {-1.5022155123688876`, -1.609810554839941, \
-0.07044714869685079}, {-1.604834628718266, -2.497480507523181, 
       0.03684391366627121}, {-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPYT3e371IThwKoTn1OP63zf/9XlQ1b/w9n2ncnq
nc7KDAeOtS5613Liy/6fugvmxE+bZH904+QjCwUZDjx2Cix3SvkEFW+yZ4CA
AxDqw/55PglR83/52ZTPuVG2587//VZVsYLV5q/3f4eo3//WYuPbip3/95d8
2aX0Le/Z/h8Q8/enXO1MMZ32f/+6PAmTwmUP93+GuAcuvgYqDnUn3JxiqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwWwkNN6g77XGFJwB/9sFU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7zfn6Vy8W1k8XT7RYLH
uapSmA5M+CfF7Jv9fv+T1oPPy1367S92JLPaGjEe8KjvbVy2FSZeb88AAQcg
1If9k96ffp3M52UT/87ia+vsv/tjHCz366h+2P8Aon7/3juFr7jNf+/f0VBU
F+n1Yf8jiPn7ZU6vuj/x0o/9IgdX27blf9ifAXEPhjjUnRjmQN25Pw7NXqg7
9+Nw5x50f0Hdab8QLRyg7rRHDzeoOzHEYeEJAGNTuuo=
       
       "], {{-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}, {-2.422763365772555, -0.5243400200337339, \
-0.004326663743797126}, {-1.525580660274528, -0.5787952829846525, \
-0.05012859920712154}, {-1.5772366342274449`, -1.4756599799662662`, 
       0.004326663743797126}, {-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjg4cPYMCNzZz4AKDpgYg8BlHOKHMcQh1IQ96OJG
EPX26OLGEPMxxE9D3IMhfhaHuAkOc0xw2At1pw0Od2L4yxhHOJzGEW7o4QkA
EQVB6A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5PP/hcdwbzAQYoaDh+9Xzb5Jn2X12uvS9OZYKL
M7b2dbHwTrSvUnr9facRI5p4oz2UCxdnMJ4xkT3bx4Znt6ZAz6y/+2HC/1vA
6veLlwUrSJj+hoszQMzfr2RYa7Dk/A+4eB3EPRjiUHfuF0MzB+rO/dxo9kLd
CeOju3MPur+g7sQIB6g77dHDDepODHFYeAIAnIBtHA==
       
       "], {{-2.4493063074013928`, -0.45, 
       0.024976831851240444`}, {-2.4493063074013928`, 0.45, 
       0.024976831851240444`}, {-1.5506936925986072`, 
       0.45, -0.024976831851240444`}, {-1.5506936925986072`, -0.45, \
-0.024976831851240444`}, {-2.4493063074013928`, -0.45, 
       0.024976831851240444`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE652pliOu3//jV5EiaFyx7af3X5kNX/cPb+txYb
31bs/L+/+MsupW95z+x/6i6YEz9t0v7yOTfK9tz5v9+qKlaw2vw1VLxpPwME
HIBQH+zn+SREzf/lt+foxslHFgoyHHjsFFjulPLJ/jtEvX1nsnqnszLDgWOt
i961nPhi/wNivr2f6G7fpyYMB1ae+Jx6XOe7/WeIe+Diq6DiUHdimAN1pz26
vVB32uNwpw26v6DuhIdDCTQcoO7cDwu3ddBwg7pzP67wBACrErpp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7y3z1K5+DayeLr9IsHj
XFUpTAcm/JNi9s1+b/+k9eDzcpd++4sdyay2RowHPOp7G5dthYnX2zNAwAEI
9cF+0vvTr5P5vGzi31l8bZ39d3+Mg+V+HdUP9g8g6vfvvVP4itv89/4dDUV1
kV4f7B9BzN8vc3rV/YmXfuwXObjati3/g30GxD0Y4lB3YpgDdef+ODR7oe7c
j8Ode9D9BXWn/UK0cIC60x493KDuxBCHhScAM4izag==
       "], {{-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}, {-2.474419339725472, 
       1.4212047170153475`, 0.05012859920712154}, {-1.5772366342274449`, 
       1.4756599799662662`, 0.004326663743797126}, {-1.525580660274528, 
       0.5787952829846525, -0.05012859920712154}, {-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBZdF8V+Tff/fofVe7x5n/2w99vIEJJbvnr/Drnn
LE+K/+/XKtK4y+Hy2960jMFinv+i/TH9xUyfdv7fL2o5JY9l0V+o+KT9DBBw
AEo7hEuFxW5qidsTZHHsH5syw4HSx1tP/NVjdDCGqLdfUtDzl9eN4cDrY9kT
f8cyOZhAzLf/tiLoj0gmw4GEVYpRP3uYHXwh7sEQh7oTwxyoO+3R7YW60x6H
O23Q/QV1J0Y4QN25Hz3coO7EEIeFJwDbRJhI
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7b67D9Kys0mWjvF5Lr
My2R6YDfH3u+5tz/9s83BXlO/9Bmr77KTO20AeMB9X/y7Qe3wcTL7Bkg4ACU
dsh6dST9sqyzzebVkzZnzvu7/w1Dgc18FQaHJxD1+1PDVdMv2/zef5PxQYWd
J4PDU4j5+yWYd0jZ3v6x/yhTwNa7uQwO2hD3YIhD3YlhDtSd+zeh2Qt1534c
7tyD7i+oO+190cIB6k579HCDuhNDHBaeAAaBo+Y=
       "], {{-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}, {-2.4977844876311126`, 
       2.390189445160059, 0.07044714869685079}, {-1.604834628718266, 
       2.497480507523181, 0.03684391366627121}, {-1.5022155123688876`, 
       1.609810554839941, -0.07044714869685079}, {-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6y5eACkxP/9vvsawjiaGJxkJWpZsuQ2rK/ueKa
qLLB//1GV0J7WNewOtSoLuF4cHbVfkeb112CM/7vl3yldYzpGhtUfNZ+Bgg4
AKE4HGzk7220Ckvbcz+xy+q7McOB56JXLf9qcjpUQdTb7z8sUvouneHAOe1V
xb+CuRyqIebbz1Odv/7pbIYDWxzr136v5XaQhrgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4ACOubuQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewOyyacnS94q8Z+TpVI
3tMYpgNZ+XfrT0xhdyhIuLef26bY3s+Wa3uRHuOBrdvf2aecgokn2zNAwAEI
xeHA/vuxfDy7gU1K6+uJUov/7vf2EDww25TDIQ+ifv8JruvKpm6/90+boNRg
ns3hkA8xf7/OhENb/V/+2P/whrHD5QUcDksg7sEQh7oTwxyoO/ej2wt1534c
7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDB4ZpX
       "], {{-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}, {-2.5191609020654973`, 
       3.357979635108771, 0.0855718330639844}, {-1.633082468075111, 
       3.5150354929240377`, 0.07148402475128206}, {-1.4808390979345027`, 
       2.642020364891229, -0.0855718330639844}, {-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZ582RiWdq//U3xzHu2TeVxqNhl53vw3c79HXNn
bPv57t9+pqnhtSo7eR1+q9UbX/PcuP+In8/tmvL/+xtPrbabdIcPKr5wPwME
HIBQAg4+0+oYUi/k7Jl3I3KSowvDgQNSqx5smyjg8BOi3t5m42aV5g6GA/Wm
IQdzlQUdfkHMt7/Vybv9yBmGA/YB/xaqbBV0KIO4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+WLg1Q8MN6s79uMITAIPwqug=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgdTq3e+qv8Vvn+7jUP
H0wOYzpwgi3Fb2Mpv8POfne/r2fz97tdK/jgqc14IIXZaPmNXTDx+P0MEHAA
Qgk4HPk+Qex7g9ae0mA5+ZyVf/f7/UtbM1lJwGEbRL39q2U2djeCfu+f8+ds
hLqrgMMOiPn28b+iYl3+/Nj/6pcJ6+50AYeTEPdgiEPdiWEO1J326PZC3WmP
w502rmj+groTIxyg7tyPHm5Qd2KIw8ITABGtr6s=
       "], {{-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}, {-2.5383959440528843`, 
       4.325598192013179, 0.09547578114449966}, {-1.66157321431172, 
       4.528196918969834, 0.10712294581215505`}, {-1.4616040559471155`, 
       3.674401807986821, -0.09547578114449966}, {-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH54yLetlfPf/tgvx0tqw4QcDgUeuxgiv3//68Z7
65g3/ttv90N/cfATIQedh3oPe/dv2f/NIf96Y8T//fJ/pl/ULBKGii/ZzwAB
ByCUiIN/2p8J3l6Fe1rjPUT2BzMceMicoXetV8RBC6Lenmv/BI265QwHDrFf
iFkjLeqgDTHfvl/upo3tb4YDi7ktuptWijrsh7jHfgKaONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/ejhBnUnhjgsPAEuVakc
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUdlssfcXVbNnX/mWLG
5Jt+TAeqXapPMK4VdjDV2sC++W7P/mc7GzbmqDMesFtk+6ThGky8Zj8DBByA
UCIO184KGYryeewx6fk3R23j3/2HYg9J12uKOBhB1NtnSPy19E36vb91d4v5
vyARBxOI+fZzlvy+Viz8c7+7pHtwbY2IwzKIe+xno4lD3WmfjmYO1J326PZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAGV2bIA==
       "], {{-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}, {-2.555426250075045, 
       5.2939652195751385`, 0.10042972870477429`}, {-1.689924540665841, 
       5.537108875761286, 0.14271392748137285`}, {-1.4445737499249551`, 
       4.7060347804248615`, -0.10042972870477429`}, {-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILY7HuAx6//H/bt/6fJbrBQ9sHvTFambJ/fZ1+t3
twqGftx/KfDklipp0QN1Z3r3TGjbYr9/+tFDHas+7H+5IiVqb68IVHyJPQMY
fNgPoUUOZGiVfTorVWjTeKGk6t2qd/vFw2cvdSoSPlADUb+feeHLL3dC3+7X
W2fm3fpE6EAtxPz9LYVx+acZ3ux3Zb304XiY0IGdEPdgiEPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08A8orAVQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBE+IJHY67/dZeF+yS0v
VjTP+bL/3AnevU/XCh9Q1Enf78k2fT9vVMkVR79P+9OftN37dA0m3r6fAQw+
QGmRA0eXNMi/0A/e89xbPLwm+fX+mdKViryaIgfkIOrtz03XW/fj2LP9Ruaf
nKSCRA7IQ8y33/bYlbVU69H+00HZKerVIgfEIe6x34omDnUnhjlQd9qj2wt1
pz0Od9rwoPkL6k6McIC6c78qWrhB3bkfV3gCAENxo/8=
       
       "], {{-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}, {-1.3074142524896448`, -4.464479631202829, \
-0.15399484397074759`}, {-0.44277975827814153`, -4.705014545315876, \
-0.08654007014229913}, {-0.6925857475103553, -5.535520368797171, 
       0.15399484397074759`}, {-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEM29o6Js4cf9botU9jzZInggNvzI34zNO+23xqj+
9hP7uF8/R0LDWVnwwKsnTf9clTbaR62bVKve/WG/uBnPlIUTBaDiC+0ZwODD
fggtcKClVn9FSV+OjffiWywbX77bf3Hy8+t77vAdeAFRv3+621bOpMtv9y9S
P7++cifvgZcQ8/c/etnPJ7z3zf6S3dvazabxHIiBuAcuXgwVh7pz/zQ0c6Du
3I9uL9Sd+3G4cw+6v6DuxAgHqDvt0cMN6k4McVh4AgBFtrmQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPEf8LydbSqxc9J+k+hP
t0+u+bL/5gvuC2/L+A8kqTz9eOpbx/5Zuj/fpoR92p/zhfVF2W6YeMV+BjD4
AKUFDgTOeym38qzLnjNLeFXMgl/vP8X6t9tFSeBAAkS9/QxPaY+cZc/2T+H+
Jd7pInAgEWK+fdo7jZxFPx/ujxX8vvhsmsABD4h77FPRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3YkRDlB37j+LFm5Qd+7HFZ4Atma6Pw==
       
       "], {{-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}, {-1.3363574191970282`, -3.4729523642627917`, \
-0.11867803594150737`}, {-0.45980333298826614`, -3.6737400266827285`, \
-0.08210962647842927}, {-0.6636425808029717, -4.527047635737208, 
       0.11867803594150737`}, {-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC7WVEtXsfu4/94FZeH5tdwHuG6I/4r5stl+kfQR
F4krH/ZPeSCetD+Y60By6alFarNX2V/kTVLiyfqw3+sD98b7mpxQ8Vn2DGDw
YT+E5jigvn1F+1ftNJu4J9a7n2u/37+N/4ufwjW2AwkQ9fv3nigvOx/+bn+O
/Iu5DmtYDyRBzN8vvXaz4fbmt/uV9O+8SWhiOcABcQ+GONSd+/egmQN15350
e6Hu3I/DnXvQ/QV1J0Y4QN1pX4QWblB32uMKTwDIp64Z
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBPYD9/9sLtfvKt3/6Hnf
VeVdX/ZrXStJnTyV/YB2oKuX/Y6c/R+Lj78SjP20XzR716aTp2DiMfsZwOAD
lOY48EOiP+P+O/U98hKFWndcX+9/PcXV18yU44AGRL29ncGjkB3dz/Zf0+ye
lZPFcUATYr59nEdw/ZSLD/cf2Hfh+aL5HAfuQdxjH4MmDnWnvS2aOVB32suh
2Qt1pz0Od9p8QPMX1J37H6KFA9Sd+y+ihRvUnftxhScAOA2p7A==
       
       "], {{-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}, {-1.3654950603405707`, -2.485713996326056, \
-0.08320617339913328}, {-0.4791620690881889, -2.641608869101888, \
-0.07268869937669903}, {-0.6345049396594293, -3.514286003673944, 
       0.08320617339913328}, {-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5/Nyh+1rUP+9dttv16uof5QABHpPAD79X2oS8f
ThHs/7C/REnT724s04GHUdZJU40W2a/6UnCqw/3DfquJIsvf6TFCxSfZM4DB
h/0QmuHA6TdJfn4hcTarxeSy3xW8399z99pGpUV/99+HqN8frmtz7c7Dd/sl
d69NdnX5vf8BxPz9TC5RjqeD3u1fOqNFNOPZj/3+EPdgiEPdCTdHAmoO1J37
0e2FunM/DnfuQfcX1J0Y4QB1pz0s3NZCww3qTntc4QkAh1iyzg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/vv85f67WOt9je7tGS
ZJEjX/Zrqr4Lyc77v19e9A/v5PRMe/nCS4ZcSZ/2TxEqX2W6HSYeac8ABh/2
Q2iGAzMFg8yWaqvaHJKNnvPa+vX+bWVHtFJVGA7IQNTvb7HeZnG9/Nn+nLcd
oac8GA7IQczf7xYpePXQ5of7FVN8G/RzGQ5chbhnvyuaONSd+5vRzIG6cz+6
vVB37sfhzj0wf02F+gvqToxwgLrTPhYt3KDutMcVngDY0aCt
       
       "], {{-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}, {-1.3944131960809822`, -1.502938348477095, \
-0.0486615386368611}, {-0.5008001745126557, -1.609564863601969, \
-0.057964976488012875`}, {-0.6055868039190176, -2.497061651522905, 
       0.0486615386368611}, {-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDbT+zZBOOfDfmnmJXvW6Xzf/9lQk+nYrtn2VSf9
uHk9Puzfu+ZQbcmJL/t/nC5gbKmZZL83ZXkrm8qH/XFhD+2sUj5BxZvsGcDg
w34Y/TFYcG3beT+bNrONXz5tf7/fJdi2qdv89f5vEPX7eXOTXj7Nf7+/fVkV
i3j+s/3fIebvn7xY+N4N9ff7z/zc3rZo2cP9HyHugYufgopD3Qk3pw1qDtSd
+2H2OkPthbpzPw537kH3F9Sd8HDYAw0HqDvtYeEmBQ03qDvtcYUnADNouvs=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr3f/3C70btYuzb7RxrV
z8xOfdm/oPLLfemc9/t1vs6wrV1Ra184xbZYOvXT/gs2v97zboOJ59ozgMGH
/TB6ieIqDuHtFjZy11skT5q+3j/jIRPHT5UP+zUh6vfbrOM0npT9bL/BYVaB
T54f9mtDzN8f1drnE73w4f4TSzgkXud92H8f4p79kWjiUHfut0YzB+rO/ej2
Qt25H4c796D7C+pOjHCAutM+GC3coO60xxWeAOT6uVI=
       
       "], {{-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}, {-1.4226672975718835`, -0.524511498680574, \
-0.0162185287953971}, {-0.524561007755691, -0.5786708421747833, \
-0.03794081469881218}, {-0.5773327024281165, -1.4754885013194259`, 
       0.0162185287953971}, {-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4sP/sGRC4s58BBXzYb2IMApdxiB/GEIfQE/ag
ixtB1NujixtDzMcQPw1xD4b4WRziJjjMMcFhL9SdNjjcieEvYxzhcBpHuKGH
JwA+ZE/p
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5SjP2SZ/R9PwMUrA1XZdk2ucveXMzuh+eZL3Dx
Equ8tee2N9rLcMv/UUn7hCZeaA/hfYCLH9i2/fTadlubUy8Psm8zfg0XL4Ko
3z/pcjN/TvozuHgxxPz9MXtdxZVmP4SLr4a4B0Mc6k4Mc6Du3H8SzV6oO/fj
cOceaTR/Qd2JEQ5Qd9qjhxvUnRjisPAEAG+9eME=
       
       "], {{-1.4498128457508597`, -0.45, 
       0.012977048875352748`}, {-1.4498128457508597`, 0.45, 
       0.012977048875352748`}, {-0.5501871542491403, 
       0.45, -0.012977048875352748`}, {-0.5501871542491403, -0.45, \
-0.012977048875352748`}, {-1.4498128457508597`, -0.45, 
       0.012977048875352748`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ68WPjeDfX3+0/93N62aNlD+8+GmkzHds3ez5ub
9PJp/vv9bcuqWMTzn9n/OF3A2FIzaX+b2cYvn7a/3+8cbNvUbf4aKt60nwEM
PsBo+4/Bgmvbzvvt2ZuyvJVN5cP+uLCHdlYpn+y/QdTbV5304+b1+LB/z5pD
tSUnvth/h5hvb6b3bYJwzof9UsxL9qzT+W7/EeIeuLg0VBzqTrg5e6HmQN1p
j24v1J32ONxpA/OXC9RfUHfCw6EdGg5Qd+6HhdsZaLhB3bkfV3gCAH/3tpE=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr23f7jd6F2sXZv9I43q
Z2anvuxfUPnlvnTOe3udrzNsa1fU2hdOsS2WTv20/4LNr/e822DiufYMYPBh
P5S2X6K4ikN4u4WN3PUWyZOmr/fPeMjE8VPlg70mRP1+m3WcxpOyn+03OMwq
8Mnzg702xPz9Ua19PtELH+4/sYRD4nXeB/v7EPfsj0QTh7pzvzWaOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J32wWjhBnWnPa7wBAC1L7HS
       
       "], {{-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}, {-1.475438992244309, 
       1.4213291578252167`, 0.03794081469881218}, {-0.5773327024281165, 
       1.4754885013194259`, 0.0162185287953971}, {-0.524561007755691, 
       0.5786708421747833, -0.03794081469881218}, {-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZyiXI8HfRu/9IZLaIZz37YB3BECj/wXr0/XNfm
2p2H7/ZL7F6b7Ory2/5hlHXSVKNF+1eLyWW/K3i/v+futY1Ki/5CxSftZwCD
D1CaweH0myQ/v5C4Pau+FJzqcP+w32qiyPJ3eowO9yHq7UNfPpwi2P9hf4mS
pt/dWCaHBxDz7f/fDYqfde3D/rWbbb+e7mF28Ie4By6+DioOdSeGOVB32qPb
C3WnPQ532qD7C+pOeDhIQsMB6s796OEGdSeGOCw8AXyEqfs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/bX+ev9VrHW2xv92hJ
ssiRL/s1Vd+FZOf9t5cX/cM7OT3TXr7wkiFX0qf9U4TKV5luh4lH2jOAwYf9
EJrBYaZgkNlSbVWbQ7LRc15bv96/reyIVqoKg4MMRP3+FuttFtfLn+3PedsR
esqDwUEOYv5+t0jBq4c2P9yvmOLboJ/L4HAV4p79rmjiUHfub0YzB+rO/ej2
Qt25H4c798D8NRXqL6g7McIB6k77WLRwg7rTHld4AgCpBpkt
       
       "], {{-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}, {-1.4991998254873442`, 
       2.3904351363980307`, 0.057964976488012875`}, {-0.6055868039190176, 
       2.497061651522905, 0.0486615386368611}, {-0.5008001745126557, 
       1.609564863601969, -0.057964976488012875`}, {-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZeu9lwe/Pb/Ur6d94kNLE4cN0Q/xXzZfP+PSfK
y86Hv9ufI/9irsMaVofk0lOL1Gav2h/3xHr3c+33+7fxf/FTuMYGFZ+1nwEM
PkBpDgf17Svav2qn7bnIm6TEk/Vhv9cH7o33NTkdEiDq7RdJH3GRuPJh/5QH
4kn7g7kckiDm2xdpqqWr2H3cf++CsvD8Wm4HDoh77IvRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3bl/L1o4QN25Hz3coO7EEIeFJwAEq6hk
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBHaH+382l+t3le5/9Lzv
qvKuL/u1rpWkTp7K7qAd6OplvyNn/8fi468EYz/tF83etenkKZh4zH4GMPgA
pTkcfkj0Z9x/p75HXqJQ647r6/2vp7j6mplyOGhA1NvbGTwK2dH9bP81ze5Z
OVkcDpoQ8+3jPILrp1x8uP/AvgvPF83ncLgHcY99DJo41J32tmjmQN1pL4dm
L9Sd9jjcafMBzV9Qd+5/iBYOUHfuv4gWblB37scVngAIQqJs
       
       "], {{-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}, {-1.520837930911811, 
       3.358391130898112, 0.07268869937669903}, {-0.6345049396594293, 
       3.514286003673944, 0.08320617339913328}, {-0.4791620690881889, 
       2.641608869101888, -0.07268869937669903}, {-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH70sp9PeO+b/cW7t7WbTeNxiA0/8jdj887909y2
ciZdfrt/kfr59ZU7eR1ePWn656q0cb/34lssG1++239x8vPre+7wQcUX7mcA
gw9QWsChpVZ/RUlfzp6odZNq1bs/7Bc345mycKKAwwuIevutMaq//cQ+7tfP
kdBwVhZ0eAkx356fe0dF2cKP+90Wqex5skXQIQbiHgxxqDsxzIG60x7dXqg7
7XG40wbdX1B37p+OFg5Qd+6HhVsJNNyg7tyPKzwBfomzNA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPE7eN7ONpXYOWm/SfSn
2yfXfNl/8wX3hbdl/A5JKk8/nvrWsX+W7s+3KWGf9ud8YX1RthsmXrGfAQw+
QGkBh8B5L+VWnnXZc2YJr4pZ8Ov9p1j/drsoCTgkQNTbz/CU9shZ9mz/FO5f
4p0uAg6JEPPt095p5Cz6+XB/rOD3xWfTBBw8IO6xT0UTh7oTwxyoO+3R7YW6
0x6HO23Q/QV1J0Y4QN25/yxauEHduR9XeAIAhpuyvw==
       
       "], {{-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}, {-1.5401966670117337`, 
       4.3262599733172715`, 0.08210962647842927}, {-0.6636425808029717, 
       4.527047635737208, 0.11867803594150737`}, {-0.45980333298826614`, 
       3.6737400266827285`, -0.08210962647842927}, {-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG4pjMs/zfBmvyvrpQ/Hw4Qcdm+6InXz5L79zAtf
frkT+na/3joz79YnQg51Z3r3TGjbsr/xQknVu1Xv9ouHz17qVCQMFV+ynwEM
PkBpEYcMrbJPZ6UK9+yffvRQx6oP+1+uSIna2yviUANRb1+v390qGPpx/6XA
k1uqpEUdaiHm29sdD/CY9f/j/t2/dPktVoo67IS4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAAzVuPs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBF2kEjs9d/usnC/5JYX
K5rnfNl/7gTv3qdrhR0UddL3e7JN388bVXLF0e/T/vQnbfc+XYOJt+9nAIMP
UFrE4eiSBvkX+sF7nnuLh9ckv94/U7pSkVdTxEEOot7+3HS9dT+OPdtvZP7J
SSpIxEEeYr79tseurKVaj/afDspOUa8WcRCHuMd+K5o41J0Y5kDdaY9uL9Sd
9jjcacOD5i+oOzHCAerO/apo4QZ1535c4QkAE6acfw==
       
       "], {{-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}, {-1.5572202417218586`, 
       5.294985454684124, 0.08654007014229913}, {-0.6925857475103553, 
       5.535520368797171, 0.15399484397074759`}, {-0.44277975827814153`, 
       4.705014545315876, -0.08654007014229913}, {-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczqwf7Hr1CU8K0UPSB8OkH4Us8/+UabP
/ktrt+7P1eM7HCsteiDjuqnQG9stUPGl+83E2x+u6xWBii+xf8Yk6nVLoGgP
AxiIHLjWcX2ny70Cm/sQ9fanXlTIBRYJH0iDqN//EGK+/eSLH20WPRE6kA4x
f38GxD32sbuyoj+HCR2QhLhnfyaaONSd+x+hmQN1J1QcYS/Unfuh7rRBc+ee
+2j+grrT/iFaOEDdaZ+BFm5Qd9rjCk8A7DCuRg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAkfuLb8+7J5Uiv2f2eO
Ny3IvLR/kcZ2f471wgee5P+S3C+4ACp+aH/glNvqLddh4hP2v4+ex7x7fd8e
BjAQOaCWurDB7kTUnq8Q9fbrs1VuVGuIHHgMUW//DWK+fdx1jw3fA2DiC+zf
Q9xjz+Oc21FcKXLgCsQ99h/RxKHutP+OZg7UnVBxhL1Qd9pD3WmD5k6br2j+
grpz/ze0cIC6c/97tHCDunM/rvAEANbYspU=
       
       "], {{-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}, {-0.3045027929542561, -4.466307923050252, \
-0.16568287806566326`}, {
       0.5585535390243542, -4.703517494256951, -0.07152669314103544}, {
       0.3045027929542561, -5.533692076949748, 
       0.16568287806566326`}, {-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeKu/bp84QE7twgeUJyRUGySstM+5n6v
sP62jftPxPWbqikLHhAXeO1T8XYDVHzh/pT1x6UmTxSAii+wfyc3XeFnS+4e
BjAQOHBe6q5WsVmOTRREvb3FwoJTN+/wHRCFqN8fDTHfPt/p4ZTNO3kPiEHM
388BcY/98seB8b3TeA7IQ9yznwtNHOrO/TFo5kDdCRVH2At1536oO23Q3Lkn
Cs1fUHfaR6OFA9Sd9lB37teBhhvUnfa4whMASwOmrw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwHfFwrDG5qL9gv6GET
8GTtpf31y2fYTqngP5AWs8DhTP9UqPih/QeCz8h57YGJt+4/qsR/+6Ji/x4G
MBA4ELKo9cGV74F7+CHq7RWuzfxwS1HgQDJEvb0AxHx7hzXGD7c6CxxIhZhv
LwZxj31C09mLE1IFDnhD3GMPdad9IlQc6k57QTRzoO6EiiPshbrTHupOGzR3
2vCj+Qvqzv0CaOEAded+MbRwg7pzP67wBADkramf
       
       "], {{-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}, {-0.33401604091785, -3.4743265786345203`, \
-0.13076979192258442`}, {
       0.5415745076593318, -3.672697089056829, -0.0676007184997242}, {
       0.33401604091785, -4.52567342136548, 
       0.13076979192258442`}, {-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2bJf1K7oXmwt9wGzh3//X9q32X5D0ART
YbbV+3fWLXw5OZjrgKfO3/+Hg1dBxWfvj9l/4ctJTU6o+Cz75y4/GAVa0/Yw
gAHHgYn+K1ZVfEi1WQtRb7/EQZ/b7BrbATeI+v3rIebbezTGieWsYT3gDjF/
PxPEPfavD/YqLmpiOWACcc9+ZjRxqDv3Q91p7w41B+pOqDjCXqg790PdaYPm
zj1r0fwFdac91J37d0DDAepOeya0cIO60x5XeAIAsqysoQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewHTrmfX5v+fNL+U+qq
X5yeXdrvz83wYcM09gM74kVsu0w6oeKH9i9nZaiIOA0Tr9z/643tmyP1/XsY
wIDjQN6vCXdlGV33nICot4/89b99uQnHgW0Q9fYnIebbb/zyn98/k+PAdoj5
9msg7rHnev9/+re5HAdOQNxjvw5NHOpO+1No5kDdCRVH2At1pz3UnTZo7rQ5
geYvqDv3n0QLB6g7969BCzeoO/fjCk8AxEqwGg==
       
       "], {{-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}, {-0.36378498764196615`, -2.4866553064733674`, \
-0.09559136150501202}, {
       0.5221271591828324, -2.6409162994733557`, -0.05866963149497644}, {
       0.36378498764196615`, -3.5133446935266326`, 
       0.09559136150501202}, {-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHb1/vNBX1hX9jAfuOGy/6gC92r72kme
L33sFu03Nf/BfCyW6YB1c71eNvsiqPik/bOk/zA+1mOEik+yV/lyvuVqetwe
Bgg4wGNQ7xvLE2dTDVFvf+YE+x/LRX/3W0LU76+BmG8/fSL/j2KX3/utIObv
3wFxj31SlPiXtc9+7L8Gcc/+XWjiUHfuh7rTfhrUHKg7oeKT7E9D7YW6cz/U
nTZo7txTjeYvqDvta9DCAepO+x1o4QZ1pz2u8AQA1z2orw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv5/f/fag4plno3791in
x0cJXN7/jLln2ZH8//v5J4U3zeUph4of3v+Z0S340XaYePr+xzvCvrw+2r+H
AQIO8PjPe6NrarxnF0S9Pdv/mGt8KgwHeCHq7XdDzLfn/bdzjawHwwE+iPn2
0yHusRf+K9ask8NwoAviHvuZaOJQd9rvQTMH6k6oOMJeqDvtoe60QXOnzS40
f0HduX83WjhA3bl/Olq4Qd25H1d4AgDUiKoI
       
       "], {{-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}, {-0.393362316641488, -1.5034989636824452`, \
-0.061260172886108376`}, {
       0.5002570104284851, -1.6091375137523605`, -0.04437837718380681}, {
       0.393362316641488, -2.4965010363175546`, 
       0.061260172886108376`}, {-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzx7f89cF//ZOt/3zyxLUayrm20f6BfQ
EZ80aX/cPt2u9BNf9u/56SQWEjIJKt60X/++2FHjlE9Q8SZ7Q93bvV8W++1h
AIMP+x97San29PjZ+EPU2y92vFQ6w/z1/l0Q9fsDIObbuzYveW2Q/2z/boj5
+8sh7rF/caQs8eSyh/unQ9yzvxJNHOrO/VB32rtAzYG6EyreZL8Iai/Unfuh
7rRBc+cefzR/Qd1pH4AWDlB32pejhRvUnfa4whMApP+t+Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXm/f94SFW+P6Yn7V3i/
E0zWurzf6IVvfGzu+/11tw1SEkrCoeKH90t+WbZ+3TaYuPv+gxq9J/w/9u9h
AIMP+ycnXl6xtFt4zzKIevvPrTorVqh82F8DUW+/HGK+/XPuyIBAzw/7ayHm
21dC3GN/a2Lrj5+5H/bPhbjHvhpNHOpO+xVo5kDdCRVH2At1pz3UnTZo7rRZ
huYvqDv3L0cLB6g791eihRvUnftxhScA8QS5Lg==
       
       "], {{-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}, {-0.4222630617365743, -0.5247599788390629, \
-0.028997051226052385`}, {
       0.47612322836711235`, -0.5784594165300123, -0.024702386464896992`}, {
       0.4222630617365743, -1.475240021160937, 
       0.028997051226052385`}, {-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgQ4ewYE7uxnQAMmxiBwGYf4YQxxCJiwB13ECKLe
Hl3cGGI+hvhpiHswxM/iEDfBYY4JDnuh7rTB4U4MfxnjCIfTOMINPTwB7z42
qA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID57BgTu7GdAAybGIHAZh/hhDHEImLAHXcQIot4e
XdwYYj6G+GmIezDEz+IQN8FhjgkOe6HutMHhTgx/GeMIh9M4wg1XeAIAlqw2
qA==
       "], {{-0.45, -0.45, 0.}, {-0.45, 0.45, 0.}, {0.45, 0.45, 0.}, {
       0.45, -0.45, 0.}, {-0.45, -0.45, 0.}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzzb/sWRssSTyx7azyxLUayrm70/0C+g
Iz5pkr1L85LXBvnP7Pf8dBILCZkEFW+yX+R4qXSG+WuoeNN+Q93bvV8W+9kw
gMEH+8deUqo9PX57/CHq9+vfFztqnPLJfhdEvX0AxPz9cft0u9JPfLHfDTHf
vhzinv09c138Z+t8t58OcY99JZo41J32gWjmQN0JFUfYC3WnPdSde9DcaQN1
p/1iqL+g7twPdae9KzQcoO7cX44WblB37scVngB+HafS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXlvP2+JirfH9MT9K7zf
CSZrXd5v9MI3Pjb3vX3dbYOUhJJwqPjh/ZJflq1ftw0m7r7/oEbvCf+P/XsY
wOCD/eTEyyuWdgvvWQZRb/+5VWfFCpUP9jUQ9fbLIebbP+eODAj0/GBfCzHf
vhLiHvtbE1t//Mz9YD8X4h77ajRxqDvtV6CZA3UnVBxhL9Sd9lB32qC502YZ
mr+g7ty/HC0coO7cX4kWblB37scVngDBObGu
       "], {{-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}, {-0.47612322836711235`, 
       1.4215405834699877`, 0.024702386464896992`}, {0.4222630617365743, 
       1.475240021160937, 0.028997051226052385`}, {0.47612322836711235`, 
       0.5784594165300123, -0.024702386464896992`}, {-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHa1fVKU+Je1z37Y33DZf1SBe/X+2kme
L33sFtlPm8j/o9jlt711c71eNvsiqPgk+9Mn2P9YLvoLFZ+0X+XL+Zar6XE2
DBDgwGNQ7xvLE7enGqJ+/yzpP4yP9RgdLCHq7Wsg5u83Nf/BfCyWycEKYr79
Doh79p8P+sK6sofZ4RrEPfa70MSh7rSvRTMH6k6oOMJeqDvtoe7cg+ZOG6g7
7c9A/QV1536oO+2nQ8MB6s79O9DCDerO/bjCEwClbqIu
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv7fvnvtQcUyz8b9e6zT
46MELu9/xtyz7Ej+f3v+SeFNc3nKoeKH939mdAt+tB0mnr7/8Y6wL6+P9u9h
gAAHHv95b3RNjffsgqi3Z/sfc41PhcGBF6LefjfEfHvefzvXyHowOPBBzLef
DnGPvfBfsWadHAaHLoh77GeiiUPdab8HzRyoO6HiCHuh7rSHutMGzZ02u9D8
BXXn/t1o4QB15/7paOEGded+XOEJAKS9oog=
       "], {{-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}, {-0.5002570104284851, 
       2.3908624862476398`, 0.04437837718380681}, {0.393362316641488, 
       2.4965010363175546`, 0.061260172886108376`}, {0.5002570104284851, 
       1.6091375137523605`, -0.04437837718380681}, {-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2WL/+mCv4qImFgezh3//X9q3ef+GoAmm
wmyr7d0b48Ry1rA6eOr8/X84eBVUfLb9Egd9brNrbFDxWfufu/xgFGhNs2EA
Aw6Hif4rVlV8SN2zFqJ+f8z+C19OanI6uEHU26+HmL9/R93Cl5ODuRzcIebb
M0Hcs1/UruhebC23gwnEPfbMaOJQd9pD3bl/J9QcqDuh4gh7oe60h7pzD5o7
bdai+Qvqzv1Qd9p7QMMB6s79TGjhBnXnflzhCQCJrKYb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewOp9zPr01/Pmn/KXXV
L07PLu3352b4sGEau8OOeBHbLpNOqPih/ctZGSoiTsPEK/f/emP75kh9/x4G
MOBwyPs14a4so+ueExD19pG//rcvN+Fw2AZRb38SYr79xi//+f0zORy2Q8y3
XwNxjz3X+//Tv83lcDgBcY/9OjRxqDvtT6GZA3UnVBxhL9Sd9lB32qC50+YE
mr+g7tx/Ei0coO7cvwYt3KDu3I8rPAGUf6ia
       "], {{-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}, {-0.5221271591828324, 
       3.3590837005266443`, 0.05866963149497644}, {0.36378498764196615`, 
       3.5133446935266326`, 0.09559136150501202}, {0.5221271591828324, 
       2.6409162994733557`, -0.05866963149497644}, {-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeIu++WPA+N7p/E4KM5IKDZJ2bk/5n6v
sP62jfb5Tg+nbN7J6yAu8Nqn4u0GqPhCe4uFBadu3uGDii/Y/05uusLPllwb
BjAQcDgvdVer2CxnTxRE/f6U9celJk8UcBCFqLePhpi//0Rcv6masqCDGMR8
ew6Ie/br8IUH7Nwi6CAPcY891J37daHiUHfax6CZA3UnVBxhL9Sd9lB37kFz
p00Umr+g7twfjRYOUHfu50ALN6g79+MKTwAjjqA4
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwOPq4VBje1F+wX9LAJ
eLL20v765TNsp1TwO6TFLHA40z8VKn5o/4HgM3Jee2DirfuPKvHfvqjYv4cB
DAQcQha1PrjyPXAPP0S9vcK1mR9uKQo4JEPU2wtAzLd3WGP8cKuzgEMqxHx7
MYh77BOazl6ckCrg4A1xjz3UnfaJUHGoO+0F0cyBuhMqjrAX6k57qDtt0Nxp
w4/mL6g79wughQPUnfvF0MIN6s79uMITALTioh8=
       "], {{-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}, {-0.5415745076593318, 
       4.327302910943171, 0.0676007184997242}, {0.33401604091785, 
       4.52567342136548, 0.13076979192258442`}, {0.5415745076593318, 
       3.672697089056829, -0.0676007184997242}, {-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczpgH7srK/pzmJCD9OEA6Ucx+/Y/yvTZ
f2ntVvvJFz/aLHoi5JBx3VToje0WqPhS+1MvKuQCi4Sh4kv2P2MS9bolUGTD
AAYiDtc6ru90uVew5z5E/X4z8faH63pFHNIg6u0fQszfn6vHdzhWWtQhHWK+
fQbEPfsXu05dwrNS1EES4h77TDRxqDvtH6GZA3UnVBxhL9Sd9lB37kFzp819
NH9B3bn/IVo4QN25PwMt3KDu3I8rPAG39qcS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAk7XFv+fdk8qRX7vzPH
mxZkXtq/SGO7P8d6YYcn+b8k9wsugIof2h845bZ6y3WY+IT976PnMe9e37eH
AQxEHNRSFzbYnYja8xWi3n59tsqNag0Rh8cQ9fbfIObbx1332PA9ACa+wP49
xD32PM65HcWVIg5XIO6x/4gmDnWn/Xc0c6DuhIoj7IW60x7qThs0d9p8RfMX
1J37v6GFA9Sd+9+jhRvUnftxhScApw2rFQ==
       "], {{-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}, {-0.5585535390243542, 
       5.296482505743049, 0.07152669314103544}, {0.3045027929542561, 
       5.533692076949748, 0.16568287806566326`}, {0.5585535390243542, 
       4.703517494256951, -0.07152669314103544}, {-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64l1Pief+1vcD9mh9sK0UPvH+zIb3i6l77pS/n
+rbZv7XnevX3V6S06AHvz6Wzlj7ebH/pyzm1w/Pf2bN+rfu7plcEKr7YngEM
PkBpkQPCC7YzcE0usJneOiNHbsMH+99cjUzBRcIHPCHq9+tyG960Sfho/02U
iXXZE6EDXhDz9x+ZcNI1WuCT/UeFZvafYUIH3kLcAxf/ABWHunO/Hpo5UHfu
R7cX6s79ONy55zKav6DuxAgHqDvtYeHGDw03qDvtcYUnADNgt8I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIHrm16ftkpav1+px3z
/F5ffGZvrDEts3CD8IEJZ96bX3+2ZL9ijP/yrxmv7SVFTm+xuAETn7KfAQw+
2ENokQPlWnPXcWQn7nkfGKHT6v3J/vlrE+/j6iIHeiHq7e8v3hDBNf2L/dnr
mdP6/EUO9EPMtz/3laO1/9E3+y2H5z0MLRc5cAXiHvvzaOJQd2KYA3Wn/Qc0
e6HutMfhTht0f0HdiREOUHfuT0ELN6g79+MKTwBWurrI
       "], {{
       0.4406940533877688, -5.298527104669883, 0.05530303664006736}, {
       0.6986806420697439, -4.468395797789808, -0.17777406090024198`}, {
       1.5593059466122312`, -4.701472895330117, -0.05530303664006736}, {
       1.301319357930256, -5.531604202210192, 0.17777406090024198`}, {
       0.4406940533877688, -5.298527104669883, 
       0.05530303664006736}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6VePL5hPlv7HNqir2WbxE8kHt+VYLXvx32adNu
v9+6/63956BFhlLKggc8u2Ret63cYG98+u33W/ff2VdqXpTonSgAFV9gzwAG
H6C0wIHKZy1GZkezbdKkOFuEJnyw510be+7pHb4DHhD1+8+aCHGoKny0l4ra
Pef0Tl6o+Ib9xv7SPeYbPtprsEtmb5zGcyAb4h4Mcag7McyBunM/ur1Qd+7H
4c496P6CutM+HS0coO60Rw83qDsxxGHhCQBI9azg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4LfgP3H7RV81YuHy/Sv3p
BQzrntmvk15+YnMV/4Eqs0z/cMf5+yftTw1gCH9tf703+EnkXph4/34GMPhg
D6EFDuxi0j10gjtqj7nC2ev1IZ/sRS2v8QYrChwoh6i3z3OYtf7/ii/2mkVr
pJc5CRyogJhvvyQhvb3+7zd7u9VNmj+TBQ7chLgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15/4daOEGded+XOEJADx7nmY=
       "], {{
       0.45758907679283756`, -4.328789248178778, 0.05184612490425521}, {
       0.6686325248437331, -3.4759504204758596`, -0.14341420644110717`}, {
       1.5424109232071626`, -3.671210751821222, -0.05184612490425521}, {
       1.331367475156267, -4.52404957952414, 0.14341420644110717`}, {
       0.45758907679283756`, -4.328789248178778, 
       0.05184612490425521}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILYoUO+/lP3WfmLxUxurWu4D69NqOEPLN9tXfz2y
5aH7O/tt32do1ARzHZhq/Dux8MtK+71VSbc+KL+3v13tI7JPkxMqPtOeAQw+
QGmOA4EMf9Q4F6baLDx0bhJ73gd71ZbNrx2vsR2YDFG/37l1rir/nQ/2Xhzp
15vXsB6YAjF//xP3nB1iXh/tC3qkDh9tYjmwDuIeuHg+VBzqTgxzoO7cj24v
1J37cbhzD7q/oO7ECAeoO+1h4TYBGm5Qd9rjCk8Anu2qjg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewHHNp+LOXctmC/TOz3
c34TntkbCVdY6c1gP7A61vsuj8e0/X3rqtPVPV7bz+S0kRU/AxNv288ABh/s
ITTHAb5z+3gTJgbt2anh5PMm+pN9+rfDj14YcxxYCVFvXxTYMuPG9i/25960
H72YznFgFcR8e62qY0+OCH+3N33svWLXbI4D9hD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7ty/Bi3coO7cjys8AZlZpDk=
       "], {{
       0.47708548159050357`, -3.360106621681593, 0.04340077715472844}, {
       0.638261629818642, -2.4878141493146844`, -0.10867845184899426`}, {
       1.5229145184094963`, -2.639893378318407, -0.04340077715472844}, {
       1.361738370181358, -3.5121858506853156`, 0.10867845184899426`}, {
       0.47708548159050357`, -3.360106621681593, 
       0.04340077715472844}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4w0M/+7PjOnukLY8vkHuYD1jP2npi4cZX9q1Ml
7ouuvbNfsyhs7fZYpgOXd11u3XZ6oX1p6i7lwOz39mGBq6/d1mOEik+0ZwCD
D1Ca4cDmHu77t1bE2rieVcoL9/pgHxK7Mshj0d/9FyHq93fPcr2zbsoH+5W7
gpZOcPm9/xLE/P0X0jO82O5/sP8n/uf7jWc/9ltC3AMX/wsVh7oTbs4KqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwY4SGG9Sd9rjCEwDQkcAk
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7vf+scwLtIevr+nnc3
FQWqntlrJl30XlT4f78ta/aepvN9+92+vxHgsH1tL7rxherFHTDxuv0MYPDB
HkIzHGDXj/z0Zo3nntiWzu/ViZ/sy5Zz505XZjhgBVFvv4tD+P33Q1/sX/uJ
39JzZzhgDTHfXqx3zrNile/2id+U3I9lMRx4DXEPhjjUnRjmQN1pj24v1J32
ONxpg+4vqDsxwgHqzv1X0MIN6s79uMITAFP0pts=
       "], {{
       0.4991510472470452, -2.391504741244447, 0.0295696484488244}, {
       0.6080497644704068, -1.5042232636794342`, -0.0747023466272946}, {
       1.5008489527529547`, -1.6084952587555532`, -0.0295696484488244}, {
       1.3919502355295932`, -2.4957767363205656`, 0.0747023466272946}, {
       0.4991510472470452, -2.391504741244447, 
       0.0295696484488244}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG6zDqtSkn9vX6m+e3Wfzvf9rP8F/B9pzLZnqbX8
I5b13n5Zvrps/Ikv+9eHcHc5Sk+yb9onU8e99b395e2T+/RTPkHFm+wZwOAD
jN5/1jzDOlfXz2b/go8OVaof7KMm3Hi0wPz1/rUQ9fvrHB83fvH6YL9FYeNR
x/xn+9dBzN9v++jKobyCD/YCGztXPFr2cD8LxD1wcT6oONSdGOZA3bkf3V6o
O/fjcOcedH9B3YkRDlB32rdDw60CGm5Qd9rjCk8AF6ym6w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/3t7H9s345Z8L+Kys8
H7nmPLOPXrr+s2r++/2ccX/9e9Ta9mddUfmoZPbafu2l6z8nbYeJl+1nAIMP
9lB6/0bl4LclpU57Tk/NbX+X8sl+pZhIs5nKh/1sEPX207Rv8909+cU+WFeD
Ldfjw352iPn2CQc9pp3W+27/x9mmc3HOh/2tEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3O+AFm5Qd+7HFZ4AEl+yVQ==
       "], {{
       0.523625995532506, -1.4218551013456981`, 0.010299579419318135`}, {
       0.5785247554904833, -0.5250986033436529, -0.042746715891330875`}, {
       1.476374004467494, -0.5781448986543019, -0.010299579419318135`}, {
       1.4214752445095167`, -1.4749013966563471`, 0.042746715891330875`}, {
       0.523625995532506, -1.4218551013456981`, 
       0.010299579419318135`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4YH/2DAjc2c+AAj7YmxiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDSikhp
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC74mCKfNvuhPQMUrN3RWLbuZM/+Bd7OWTPTn8HF
Sy6s/iln2Lz/wlLFrWeMX6OJF++H8D7AxQ9sKP7a8cd+j4Ru/lLJtE9w8SKI
enuDqHtexme+wMWLIebbe7T7fvAx+g4XXw1xD4Y41J0Y5kDdaY9uL9Sd9jjc
aYPuL6g7McIB6s79hWjhBnXnflzhCQBjMnoq
       "], {{
       0.5502195943040942, -0.45, -0.014056551925218786`}, {
       0.5502195943040942, 0.45, -0.014056551925218786`}, {
       1.4497804056959058`, 0.45, 0.014056551925218786`}, {
       1.4497804056959058`, -0.45, 0.014056551925218786`}, {
       0.5502195943040942, -0.45, -0.014056551925218786`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILZ9dOVQXsEHe76NnSseLXtoz/pfwP+Rxuz9dY6P
G794fbDforDxqGP+M/v1IdxdjtKT9u9f8NGhSvWDfdSEG48WmL+GijftZwCD
D/Yw+qx5hnWurt+epn0yddxb39tf3j65Tz/lk/1aiHp7llrLP2JZ7+2X5avL
xp/4Yr8OYr59u3VYlZL8e/sK9d2r+3S+27NA3GPfBhWvhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPCzcBaLhB3bkfV3gCAGbQok8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/t29j+Wb+cM2H/lRWe
j1xzntlHL13/WTX/vT1n3F//HrW2/VlXVD4qmb22X3vp+s9J22HiZfsZwOCD
PYzeqBz8tqTUac/pqbnt71I+2a8UE2k2U/lgzwZRbz9N+zbf3ZNf7IN1Ndhy
PT7Ys0PMt0846DHttN53+z/ONp2Lcz7Yt0LcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+pOjHCAunO/A1q4Qd25H1d4AgDiharV
       "], {{0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}, {0.523625995532506, 
       1.4218551013456981`, 0.010299579419318135`}, {1.4214752445095167`, 
       1.4749013966563471`, 0.042746715891330875`}, {1.476374004467494, 
       0.5781448986543019, -0.010299579419318135`}, {0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL6QnuHFdv+D/V/xP99vPPthbz1j74mJG1ft757l
emfdlA/2K3YFLZ3g8tv+8q7LrdtOL9zvelYpL9zrg31I7Mogj0V/oeIT9zOA
wQd7CM3gsLmH+/6tFbF7SlN3KQdmv7cPC1x97bYeo8NFiHr7V6dK3Bdde2e/
ZlHY2u2xTA6XIObbJxjoZ392fGfP+IWxZXIPs4MlxD1wcSaoONSdGOZA3WmP
bi/UnfY43GmD7i+oO+HhsBIaDlB37oeF2z9ouEHduR9XeAIAJUq8tQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7bv3UO4F0kPX1/z7ub
igJVz+w1ky56Lyr8b2/Lmr2n6XzffrfvbwQ4bF/bi258oXpxB0y8bj8DGHyw
h9AMDuz6kZ/erPHcE9vS+b068ZN92XLu3OnKDA5WEPX2uziE338/9MX+tZ/4
LT13BgdriPn2Yr1znhWrfLdP/KbkfiyLweE1xD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g7919BCzeoO/fjCk8AJCmfWw==
       "], {{0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}, {0.4991510472470452, 
       2.391504741244447, 0.0295696484488244}, {1.3919502355295932`, 
       2.4957767363205656`, 0.0747023466272946}, {1.5008489527529547`, 
       1.6084952587555532`, -0.0295696484488244}, {0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7inrNDzOujfX6P1OGjTSwO69NqOEPLN+93bp2r
yn/ng70XR/r15jWsDlONfycWflm5f+Ghc5PY8z7Yq7Zsfu14jQ0qPnM/Axh8
sIfQHA6BDH/UOBem7tlblXTrg/J7+9vVPiL7NDkdJkPU21d/PbLlofs7+23f
Z2jUBHM5TIGYb29RoN5/Kfut/YTipzZWtdwO6yDugYtPhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPC7cCaLhB3bkfV3gCAMjAo+I=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewODm0/lnJuW7BfJvb7
Ob8Jz+yNhCus9GawO6yO9b7L4zFtf9+66nR1j9f2MzltZMXPwMTb9jOAwQd7
CM3hwHduH2/CxKA9OzWcfN5Ef7JP/3b40QtjDoeVEPX2RYEtM25s/2J/7k37
0YvpHA6rIObba1Ude3JE+Lu96WPvFbtmczjYQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6c/8atHCDunM/rvAEAGmOnLk=
       "], {{0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}, {0.47708548159050357`, 
       3.360106621681593, 0.04340077715472844}, {1.361738370181358, 
       3.5121858506853156`, 0.10867845184899426`}, {1.5229145184094963`, 
       2.639893378318407, -0.04340077715472844}, {0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDb2l+4x3/DRXoNdMnvjNB6H3POrErz+7dh/1kSI
Q1Xho71U1O45p3fyOnh2ybxuW7lhf5oUZ4vQhA/2vGtjzz29wwcVX7CfAQw+
2ENoAYfKZy1GZkez9xiffvv91v139pWaFyV6Jwo4eEDU26dPu/1+6/639p+D
FhlKKQtCxTfYz0o8+XzC/Df2OTXFXsu3CDpkQ9yDIQ51p30amjlQd9qj2wt1
pz0Od9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwA37KMQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4Lfgdbr/oq2YsXL5fpf70
AoZ1z+zXSS8/sbmK36HKLNM/3HH+/kn7UwMYwl/bX+8NfhK5Fybev58BDD7Y
Q2gBh11MuodOcEftMVc4e70+5JO9qOU13mBFAYdyiHr7PIdZ6/+v+GKvWbRG
epmTgEMFxHz7JQnp7fV/v9nbrW7S/Jks4HAT4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+3eghRvUnftxhScADLCW5g==
       "], {{0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}, {0.45758907679283756`, 
       4.328789248178778, 0.05184612490425521}, {1.331367475156267, 
       4.52404957952414, 0.14341420644110717`}, {1.5424109232071626`, 
       3.671210751821222, -0.05184612490425521}, {0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmID4y4aRrtMAn+w8Kzew/w4Qc3r/ZkF5xde9+PW7D
mzYJH+2/iTKxLnsi5OD9uXTW0seb909vnZEjt+GD/W+uRqbgImGo+OL9DGDw
wR5CizgIL9jOwDW5YM/lL+fUDs9/Z8/6te7vml4RB0+IevulL+f6ttm/ted6
9fdXpLSogxfEfPuKezklnvdf2/Pfr/nBtlLU4S3EPXBxAag41J0Y5kDdaX8J
zV6oO+1xuNMG3V9Qd+7XRQsHqDv3w8LtIzTcoO7cjys8AU2IsAw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIO1zY9v+wUtX6/0455
fq8vPrM31piWWbhB2GHCmffm158t2a8Y47/8a8Zre0mR01ssbsDEp+xnAIMP
9hBaxKFca+46juzEPe8DI3RavT/ZP39t4n1cXcShF6Le/v7iDRFc07/Yn72e
Oa3PX8ShH2K+/bmvHK39j77Zbzk872FouYjDFYh77M+jiUPdiWEO1J32H9Ds
hbrTHoc7bdD9BXUnRjhA3bk/BS3coO7cjys8ASbvs0g=
       "], {{0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}, {0.4406940533877688, 
       5.298527104669883, 0.05530303664006736}, {1.301319357930256, 
       5.531604202210192, 0.17777406090024198`}, {1.5593059466122312`, 
       4.701472895330117, -0.05530303664006736}, {0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7W8PF7yYu/9r7vpFn1Vooe+PHu6MTjBnvtLVd7
L/0x65+9yZd05hJp0QMB8/USb5Vutp9zdWlQje9/e6lfmxl39YpAxRfbM0CA
A4QSOZCr/yeg27zAxkh07TXHSAaHZ6w+/1yLhA/4QdTvT9aKWtu8icHhLPeM
P91PhA74Q8zfP9WeveUoN6PDZsEnvy6GCR34BnEPhjjUnftToOacgZoDded+
dHuh7tyPw5175qL5C+pOeDgYQ8MB6k579HCDuhNDHBaeAPT8qmA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIHHB/wLVrQvHn/Lb3M
yNW5v+2bXaunaWwSPsCsnal7jWXV/tzpW9Zc3fbX/uAiW2+RmzDxWfsZIMAB
Qokc0PmpU71pXeoezy1LNaeqMDrYxx7a8lpN5AADRL395AzvYC1PJofaXS2Z
131FDjBCzLe/I/OxZn8us8MecXe5wyUiBxwg7sEQh7oTwxyoO+290OyFutMe
hztt0P0FdSdGOEDdud8DLdyg7tyPKzwBIROWmg==
       "], {{
       1.4406642841535762`, -5.301189047566042, 0.037798341297327606`}, {
       1.7021599343900928`, -4.470759818154412, -0.19025279298221853`}, {
       2.559335715846424, -4.698810952433958, -0.037798341297327606`}, {
       2.297840065609907, -5.529240181845588, 0.19025279298221853`}, {
       1.4406642841535762`, -5.301189047566042, 
       0.037798341297327606`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5Sr5kX6vnP3jy36f3mLYIH3MUtmG/V7bA/+7/A
s+/2P/vzHmvmKykLHjDYVRU+MWSD/fP6HSrHc//bZ6hc8584UQAqvsCeAQIc
IJTAgZ8PFJ/PMc+24T2wOFfGk8HBcHtwwt07fAf0IOr3Sza437aYxOCQmLf8
wK6dvAf0IebvV3N47RF6m8FhkupvhRnTeA64QtyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwB+/+d/A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Thv/A5h3eccZG6/fX/5/n
+Cjqt72elktpdC3/gbOqd+2UzizZv7/+vELh2r/24qKLdq3dBxOfsp8BAhwg
lMCBq1+STI6HJO5RcJiR767J6FDydZ3SSgWBA6ch6u0dGgzu9wUxObx8Fesa
5Chw4AzEfPvEAyf8rlUzO8Q+4Mn4nShwYCPEPRjiUHfaO6KZA3WnPbq9UHfa
43CnzQE0f0HdCQ8HfWg4QN253x4t3KDu3I8rPAGnipmB
       "], {{
       1.4574363849823695`, -4.330782047795958, 0.0347557263614637}, {
       1.6716289083269396`, -3.477846748236157, -0.15661547760642103`}, {
       2.5425636150176305`, -3.6692179522040416`, -0.0347557263614637}, {
       2.3283710916730604`, -4.522153251763843, 0.15661547760642103`}, {
       1.4574363849823695`, -4.330782047795958, 
       0.0347557263614637}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILaKcyyZs+Gf/b/gK2+tarkPcM/Ln5Aivdm+5mWD
b4bCf/uQ3t55NcFcB1Jr7bNvV66031dyQM1kwn/7Vcfc/PdpckLFZ9ozQIAD
hOI4cNmWq+WhVarNwqPz3zw1Z3AIs9y5wfEa24EkiPr9Tt32N0/nMzisKSpK
bF7DeiAZYv7+xwH3j25czuDAtEZb6GgTywEuiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScADh6hHw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdPYD0yaxTHrTsGL/0sbw
Nk/v3/ZcTMGTJGaxH0jlYeb5HLpg/+UD2oeXLP1rz9qo6clzFiY+YT8DBDhA
KI4DfzKjMl9ZRu+ZLp81T1eX0eF33bVtn404DiRD1Nvr2l+xiY5icvj2d03u
81SOAykQ8+2PxNnd7mhndvhQ06xyewbHgSkQ92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6c/8ytHCAunM/erhB3YkhDgtPAOtJmX8=
       "], {{
       1.4769389546218403`, -3.3615108230395725`, 0.026778118551493257`}, {
       1.640703042065311, -2.489215714163841, -0.12249534424509298`}, {
       2.5230610453781597`, -2.6384891769604275`, -0.026778118551493257`}, {
       2.359296957934689, -3.510784285836159, 0.12249534424509298`}, {
       1.4769389546218403`, -3.3615108230395725`, 
       0.026778118551493257`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYzXPDSSPa/PZvFnJ19PcwH2I8tm1lqvcr+psKB
2Wcy/tuvr9pbvSWW6UDUTUnBnzUL7XMFHvimbflvH773nu0tPUao+ER7Bghw
gNIHHLIaZOarxtqc+s5/84wqg0Ngq1OL96K/+yMh6vdPfi+/aaY3g8MirlaO
6S6/oeIL98c+1+9OK2Rw+NJ/vOfRsx/7WSHuwRCHuhPDHKg796PbC3Xnfhzu
3IPuL6g7McIB6k579HCDuhNDHBaeAA2DpIA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7v/xNyoSUievH+3ctK
zCbY/7Y3NSw3lyj5v3/5MdGNCudn7o8LtpI+Mf+v/ewZu6V5dsHEO/czQIAD
lD7QpTpp8ofG0D2B15I+SRswOmw2Vvr0U4nhwBKIevtFa44+MU9gckhNd3ny
2ZXhwFKI+fafmzSuB09gdpCYnXbtbQbDgd8Q99h/QROHuhPDHKg77dHthbrT
Hoc7bdD9BXUnRjhA3bkfPdyg7sQQh4UnAEs1qdI=
       "], {{
       1.4991562191741747`, -2.3923967123733894`, 0.013428601068172417`}, {
       1.6098989548450404`, -1.5051335095537164`, -0.08904117700472194}, {
       2.500843780825825, -1.6076032876266106`, -0.013428601068172417`}, {
       2.39010104515496, -2.4948664904462836`, 0.08904117700472194}, {
       1.4991562191741747`, -2.3923967123733894`, 
       0.013428601068172417`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Ds/rBzN7/9ot+GPd36Xzf//O+4Jr3W2fZe2yW
eb1783978d/l8TEnvuxf/or7xPxzE+2XRPZ9vXvzv33P3936eimfoOKN9gwQ
4AChPuzPuiP8Y8taXxu9yxasgsIMDi9ZOhYsNn+9fylE/f6YZYVcSmoMDpc4
BRzd85/tXwYxf39X5Sp+Y0sGhz18Mx6+WvZw/3eIe+Diu6HiUHdimAN15350
e6Hu3I/DnXtg/uqG+gvqToxwgLrTHj3coO7EEIeFJwCcs7sn
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7v3xrDfKFKesH+t8y8
0u4Wv+1XL9jP2F34fv+nC5GiPyun7v/W2NarPOevfeiF+w1Hd8DEW/czQIAD
hPqwX05P4fmSp4F7WPfbWL4zZHS4Kj7Bfq7yh/3vIertueoqi+4kMzms1leo
t3L/sP8jxHx7Ptttq09NZXZocN+w73rWh/1bIO7BEIe6E8McqDvt0e2FutMe
hzttvqP5C+pOjHCAunM/erhB3YkhDgtPAOhqriA=
       "], {{
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}, {
       1.5797889527235025`, -0.5255410153731569, -0.05754431034997633}, {
       2.4760698927773994`, -0.5777103285699278, 0.0053749971532055}, {
       2.4202110472764975`, -1.474458984626843, 0.05754431034997633}, {
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjhwOHsGBO7sZ0AFDibGIHAZh/hhDHEINWEPurgR
RL09urgxxHwM8dMQ92CIn8UhboLDHBMc9kLdaYPDnRj+MsYRDqdxhBt6eAIA
pSs6aA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7GVe2+9cIPewYoeLEtMeLI37n7W2KW658z/Q0X
/1g57WnTv8n7ndZdFn8+6y+aePN+KNcBJu4hsEIkd2XAnvsaYiU9Roxw8fcQ
9fb7AnVeSKQywcU/QMy3n1vlFLN0OjNc/BnEPRjiUHdimAN1pz26vVB3wtyN
7k4bdH9B3YkRDlB37kcPN6g7McRh4QkA2mF9Jg==
       "], {{
       1.5509541313373787`, -0.45, -0.02928835668028898}, {
       1.5509541313373787`, 0.45, -0.02928835668028898}, {2.4490458686626213`,
        0.45, 0.02928835668028898}, {2.4490458686626213`, -0.45, 
       0.02928835668028898}, {
       1.5509541313373787`, -0.45, -0.02928835668028898}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO6qXMVvbMngsJtvxsNXyx7a/7wvuOb91ln7Y5YV
cimpMThc4hRwdM9/Zr/8FfeJ+ecm7te7bMEqKMzg8JKlY8Fi89dQ8cb9DBDg
AKE+2GfdEf6xZa3vniWRfV/v3vxv3/13t75eyif7pRD19h6bZV7v3vzfXvx3
eXzMiS/2yyDm27/hWf1gZu9/+0U/jPu7dL7bf4e4B0Mc6k4Mc6DutIfZ2wO1
F+pOexzutEH3F9SdGOEAded+WLjtgYYb1J37cYUnAJXTslI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7bb41hvlAlvWD/W2Ze
aXeL3/arF+xn7C58b//pQqToz8qp+781tvUqz/lrH3rhfsPRHTDx1v0MEOAA
oT7Yy+kpPF/yNHAP634by3eGjA5XxSfYz1X+YP8eot6eq66y6E4yk8NqfYV6
K/cP9h8h5tvz2W5bfWoqs0OD+4Z917M+2G+BuAdDHOpODHOg7rRHtxfqTnsc
7rT5juYvqDsxwgHqzv3o4QZ1J4Y4LDwBuJ+moA==
       "], {{1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}, {1.5239301072226004`, 
       1.4222896714300721`, -0.0053749971532055}, {2.4202110472764975`, 
       1.474458984626843, 0.05754431034997633}, {2.4760698927773994`, 
       0.5777103285699278, 0.0053749971532055}, {1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmII59rt+dVsjg8KX/eM+jZz/s2Y8tm1lqvWr/5Pfy
m2Z6Mzgs4mrlmO7y2z7qpqTgz5qF+0995795RpXBIbDVqcV70V+o+MT9DBDg
AKMdshpk5qvG7skVeOCbtuW/ffjee7a39BgdIiHq7W8qHJh9JuO//fqqvdVb
Ypmg4gvt3QwXvDSS/W/PZjFnZ18PswMrxD0Y4lB3YpgDdac9ur1Qd9rjcKcN
ur+g7sQIB6g796OHG9SdGOKw8AQAUR6f7Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7b/wm50BIRvXj/7mUl
ZhPsf9ubGpabS5T8t19+THSjwvmZ++OCraRPzP9rP3vGbmmeXTDxzv0MEOAA
o7tUJ03+0Bi6J/Ba0idpA0aHzcZKn34qMTgsgai3X7Tm6BPzBCaH1HSXJ59d
GRyWQsy3/9ykcT14ArODxOy0a28zGBx+Q9xj/wVNHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAbaqJS
       "], {{1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}, {1.4991562191741747`, 
       2.3923967123733894`, 0.013428601068172417`}, {2.39010104515496, 
       2.4948664904462836`, 0.08904117700472194}, {2.500843780825825, 
       1.6076032876266106`, -0.013428601068172417`}, {1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4ccP/oxuUMDkxrtIWONrE4cM/Ln5AivXm/U7f9
zdP5DA5riooSm9ewOqTW2mffrly5f+HR+W+emjM4hFnu3OB4jQ0qPnM/AwQ4
QCgOh8u2XC0PrVL37Cs5oGYy4b/9qmNu/vs0OR2SIOrta142+GYo/LcP6e2d
VxPM5ZAMMd/eKs6xZM6Gf/b/gq+8tarlduCCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAsX5ka
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdHaHaZNYJr1pWLF/aWN4
m6f3b3supuBJErPYHVJ5mHk+hy7Yf/mA9uElS//aszZqevKchYlP2M8AAQ4Q
isPhT2ZU5ivL6D3T5bPm6eoyOvyuu7btsxGHQzJEvb2u/RWb6Cgmh29/1+Q+
T+VwSIGYb38kzu52Rzuzw4eaZpXbMzgcpkDcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+rO/cvQwgHqzv3o4QZ1J4Y4LDwBu36R/w==
       "], {{1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}, {1.4769389546218403`, 
       3.3615108230395725`, 0.026778118551493257`}, {2.359296957934689, 
       3.510784285836159, 0.12249534424509298`}, {2.5230610453781597`, 
       2.6384891769604275`, -0.026778118551493257`}, {1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFZzeO0RepvBYZLqb4UZ03gc3MUtmG/V7dgv2eB+
22ISg0Ni3vIDu3byOhjsqgqfGLJhP++BxbkyngwOhtuDE+7e4YOKL9jPAAEO
EErA4ecDxedzzLP3PK/foXI89799hso1/4kTBRz0IOrtz/4v8Oy7/c/+vMea
+UrKgg76EPPtt9Rr5oV6/rM3z216v3mLoIMrxD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g796OHG9SdGOKw8AQADzaV3w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Tht9h8w7vOGOj9fvr/89z
fBT1215Py6U0upbf4azqXTulM0v2768/r1C49q+9uOiiXWv3wcSn7GeAAAcI
JeBw9UuSyfGQxD0KDjPy3TUZHUq+rlNaqSDgcBqi3t6hweB+XxCTw8tXsa5B
jgIOZyDm2yceOOF3rZrZIfYBT8bvRAGHjRD3YIhD3WnviGYO1J326PZC3WmP
w502B9D8BXUnPBz0oeEAded+e7Rwg7pzP67wBAB3v5IB
       "], {{1.6716289083269396`,
        3.477846748236157, -0.15661547760642103`}, {1.4574363849823695`, 
       4.330782047795958, 0.0347557263614637}, {2.3283710916730604`, 
       4.522153251763843, 0.15661547760642103`}, {2.5425636150176305`, 
       3.6692179522040416`, -0.0347557263614637}, {1.6716289083269396`, 
       3.477846748236157, -0.15661547760642103`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ5qz95ylJvRYbPgk18Xw4Qcfrw7OvG4wd79KVpR
a5s3MTic4Z7xp/uJkEPAfL3EW6Wb9xuJrr3mGMng8IzV559rkTBUfPF+Bghw
gFAiDrn6fwK6zQv2zL26NKjG97+91K/NjLt6RRz8IOrtLVd7L/0x65+98Zd0
5hJpUQd/iPn21xo+fi958dfe9500q95KUYdvEPdgiEPdCTfHBGoO1J32c9Ds
hbrTHoc7bdD9BXXn/mRoOJyFhgPUnfvRww3qTgxxWHgCAOlOoY4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIOjg/4Fi1o3rz/ll5m
5Orc3/bNrtXTNDYJOzBrZ+peY1m1P3f6ljVXt/21P7jI1lvkJkx81n4GCHCA
UCIOOj91qjetS93juWWp5lQVRgf72ENbXquJODBA1NtPzvAO1vJkcqjd1ZJ5
3VfEgRFivv0dmY81+3OZHfaIu8sdLhFxcIC4B0Mc6k4Mc6DutPdCsxfqTnsc
7rRB9xfUnRjhAHXnfg+0cIO6cz+u8AQA8TmPGg==
       "], {{1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}, {1.4406642841535762`, 
       5.301189047566042, 0.037798341297327606`}, {2.297840065609907, 
       5.529240181845588, 0.19025279298221853`}, {2.559335715846424, 
       4.698810952433958, -0.037798341297327606`}, {1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmINY1yI02+8jmYHji/eKOlaIHrpZ27YzP2WN/8pTH
pEpvdoeyVq/cDdKiB54s3lj96tMm+5RUlZN7lrI77HZaanajVwQqvsieAQw4
HCC0yIHqtFrlO1PybebMum3mHMXh4Lo36qR6kfCBRxD1+81Nt+e2beFw6Kra
Osn/idCBxxDz918+P2nJST5Oh/PmAjHlYUIHLkPcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AZRarC4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PuEDUt8v/jWduH1/xvFw
L+ZdrA4FloJhJluED6h8Ef/rnrN+/5bH2ksZ77I57JjDoS11CyY+fz8DGHA4
QGiRA0XeL4Mm6mft8ZG5EvVPidPBI/n7laeqIgcUIOrtZ1is2PrHlcthwrF3
K097ixxQgphv/zikRuB3BrfDdc1ndRsLRQ5IQNyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AfzSfOg==
       "], {{
       2.4415193419221497`, -5.3045316493149475`, 0.018969162302250916`}, {
       2.7059604234085484`, -4.47341104096585, -0.20308814741695236`}, {
       3.5584806580778503`, -4.6954683506850525`, -0.018969162302250916`}, {
       3.2940395765914516`, -5.52658895903415, 0.20308814741695236`}, {
       2.4415193419221497`, -5.3045316493149475`, 
       0.018969162302250916`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEP3H/cwLRXYHtdZdk55sETwwLeBfT+jj7fbxf/U7
PmSzOxyJqOFxVhY8UJK9Iu34zfX2G/6Ju/zYyu6QpGPXtnCiAFR8vj0DGHA4
QGiBA12RPVcvdGXZBDC+2M3uxeFgs7z58547fAcKIOr3L2S6UM4/hcOhwo/9
eeVO3gNFEPP3f2TeYSx+j8Nhy9euW2bTeA5MgbgHQxzqTgxzoO7cj24v1J37
cbhzD7q/oO7ECAeoO+3Rww3qTgxxWHgCAI3cqOo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA/+BwuXcwtk7N+9vcn0X
Yr2B1SEoLvXRjAb+A287+Y/0+azaf1CpfJXsDTYHzfVGhT4HYOKz9jOAAYcD
hBY4MGvu9h9lr1L32N/tCH2kzumQvSLt+E15gQOvIOrt63YJrj7iz+VwPeBs
32Z7gQNvIObb750+i2F5ObeD00/jsN54gQMFEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMAmrqc8g==
       "], {{
       2.4581333076753618`, -4.333340593063415, 0.016264586231646463`}, {
       2.675018691382798, -3.480034218257422, -0.1703606024475165}, {
       3.5418666923246382`, -3.666659406936585, -0.016264586231646463`}, {
       3.324981308617202, -4.519965781742577, 0.1703606024475165}, {
       2.4581333076753618`, -4.333340593063415, 
       0.016264586231646463`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGaK/X+IMYzdYcb9Ha/TarkPqMfE9q1Yscl+zYuQ
66v72B1221d/mhnMdcD0wsW9Dx6ssA8rWfU69Di7w735tj/PaHJCxWfYM4AB
hwOUPtCo2/I5dXeKzaruUJFVFhwOygmH2IyvsR0whqjfHyK+WiOkkMPB9UAL
b9oa1gMmEPP3/1vEYPtvJYdDhoK7yMwmlgNqEPdgiEPdiWEO1J37YfYqQe2F
unM/DnfugfnrLtRfUHdihAPUnfbo4QZ1J4Y4LDwBAQenGQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLPYD/jMWMujkbtj/6dbx
aOEVrA77d3DU1sxhPyByWifs6bOl+yvfPl7LeYXNISGmxc7uHEx86n4GMOBw
gNIHJvw7fzzTIWlPu5BM0DdtTocFi6sPHjTkOCAEUW/Pp2qx5E04l4Oj+/em
5mSOA8IQ8+2nmId8e9TM7fDwVZGL61SOA74Q92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6EyMcoO7cjx5uUHdiiMPCEwCAj5re
       "], {{
       2.477597807858436, -3.3633454387878277`, 0.00872019253053169}, {
       2.643606712471798, -2.490882514632804, -0.13705185404883644`}, {
       3.522402192141564, -2.6366545612121723`, -0.00872019253053169}, {
       3.356393287528202, -3.509117485367196, 0.13705185404883644`}, {
       2.477597807858436, -3.3633454387878277`, 
       0.00872019253053169}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7L3Xr/Yw+7Q2jmFZl5PcwHvh5W+aC/dKX9vE0R
r7w3szs8/vBo775YpgNLmiQWnJJYaO8fqfN16U12h6KKj3H39Rih4hPtGcCA
wwFCMxxIbbnMtbwuxmbjsstcUWocDrL8sk6Oi/7uXwRRvz/Jd7noFh8OBys5
q5Yml9/7F0PM3y/0pUqBr5jDIVw3/NjhZz/2f4a4Z78wVDwMKg51J4Y5UHfu
R7cX6s79ONy5B91fUHdihAPUnfbvoOEWAg03qDvtcYUnANDrogs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/3M609v0Xt8Or98ofS
zd8sZHV4bf1/lWX5//1rT9w/K9m0aD//w83S3y6wOXydW391zm6Y+KT9DGDA
4QChGQ7I/yxZc/VG3J4Pcj5POPU5HVgNHaYaKjEcWA1Rb//QdsYJ4TguB+6k
Bq1kF4YDayDm21+KebJGtpfbQWDygf1T0hgOMELcgyEOdSeGOVB32n9Esxfq
Tnsc7rQRQPMX1J0Y4QB15370cIO6E0McFp4AiG+rbw==
       "], {{
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}, {
       2.612275031121414, -1.5062506453545674`, -0.10431166423424715`}, {
       3.5000835461342934`, -1.6064274528809768`, 0.004134856707837732}, {
       3.387724968878586, -2.493749354645433, 0.10431166423424715`}, {
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA4Lecz7/ii7Q579v0sTdL7vf6knYL5DcZa9pYUT
p9dNdof59St7Ek582T+nZKvKheyJ9rIyC1mWvmF3OL8/xM0g5RNUvNGeAQw4
HCD0h/0Rh5onsXL62jx+HPc7SpjDIakhrHi++ev9syDq9x8/vvfbVjUOh8MM
a5/Z5T/bPxti/v5Vq2U+CVhxOKg2MkfdW/Zw/3OIe+DiKlBxqDvh5hyCmgN1
536YvYlQe6Hu3I/DnXvQ/QV1Jzwc5kHDAepOe/Rwg7oTQxwWngD84KQi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7/3+hU01tVZdK/b/L7l9
X2weq0N0yK26hSXv9x9kDP6nFrNgf8Out/nc59kc9LRy9wfsgolP2M8ABhwO
EPrD/jdMpn8dXKL3NLgKTfhiwOnwMstzwXWlD/sPQNTbM3arKLxM5HK4dHWS
w3rXDzDz7RsvmG24O4nbYY/DnQdtGR/2L4C4B0Mc6k6c5qDbC3WnPQ532qD7
C+pOnOGAHm5Qd2KIw8ITAN69pfo=
       "], {{
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}, {
       2.5816407345077046`, -0.5261004423591564, -0.07344885461707322}, {
       3.4750645333984003`, -0.5771389524162092, 0.022410344560020643`}, {
       3.4183592654922954`, -1.4738995576408436`, 0.07344885461707322}, {
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgcDh9BgTu7GdAARwOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIA9mxGvg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb61Cyvl83iwAAFCbMDwufnL9+/51t41sk5rHDx
RhUx+Xr7+fvjfmtvTTnHhibevx/C44CLHyie5GLPFbVnEcsVr9mGnHDxOoh6
exfOFVPNkrng4g0Q8+2f8dY8uDiFGy4eD3EPhjjUnRjmQN1pj24v1J32ONxp
g+4vqDsxwgHqzv3o4QZ1J4Y4LDwBQAFbOQ==
       "], {{
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}, {
       2.5523340665952334`, 0.4499999999999999, -0.04577348652701718}, {
       3.4476659334047666`, 0.4499999999999999, 0.04577348652701718}, {
       3.4476659334047666`, -0.4499999999999999, 0.04577348652701718}, {
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF61WuaTgBWHg0ojc9S9ZQ/tX+oJmO9QnLX/+PG9
37aqcTgcYlj7zC7/mf2ckq0qF7In7n/8OO53lDCHQ2JDWPF889dQ8cb9DGDA
4QChP9hHHGqexMrpu0dWZiHL0jfsDuf3h7gZpHyynwVRb29p4cTpdZPdYV79
yp6EE1/sZ0PMtw8Lecz7/ii7Q579v0sTdL7bP4e4B0Mc6k64OfOh5kDdaY9u
L9Sd9jjcaQPzVxLUX1B3wsPhMDQcoO7cDws3VWi4Qd25H1d4AgAIL5u5
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7739wqaaWquuFfv/l9y+
LzaP1SE65FbdwpL39gcZg/+pxSzY37DrbT73eTYHPa3c/QG7YOIT9jOAAYcD
hP5g/4bJ9K+DS/SeBlehCV8MOB1eZnkuuK70wf4ARL09Y7eKwstELodLVyc5
rHf9ADPfvvGC2Ya7k7gd9jjcedCW8cF+AcQ9GOJQd+I0B91eqDvtcbjTBt1f
UHfiDAf0cIO6E0McFp4ArvKeeg==
       "], {{2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}, {2.5249354666015997`, 
       1.4228610475837908`, -0.022410344560020643`}, {3.4183592654922954`, 
       1.4738995576408436`, 0.07344885461707322}, {3.4750645333984003`, 
       0.5771389524162092, 0.022410344560020643`}, {2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb+UqXAV8zhEKYbfuzwsx/2Xw+rfNBfunJ/ku9y
0S0+HA5WclYtTS6/7Zc0SSw4JbFw/8Zll7mi1DgcZPllnRwX/YWKT9zPAAYc
DhCawSG15TLX8rqYPf6ROl+X3mR3KKr4GHdfj9FhEUS9/bxNEa+8N7M7PP7w
aO++WCaHxRDz7d9xt97/2MPuEJJ5RWZeD7PDZ4h77N9CxUOh4lB3YpgDdac9
ur1Qd9rjcKcNur+g7sQIB6g79wtBwy0cGm5Qd+7HFZ4A33iaug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/tmdae36J2ePV++UPp
5m8Wsjq8tv6/yrL8v/3aE/fPSjYt2s//cLP0twtsDl/n1l+dsxsmPmk/Axhw
OEBoBgf5nyVrrt6I2/NBzucJpz6nA6uhw1RDJQaH1RD19g9tZ5wQjuNy4E5q
0Ep2YXBYAzHf/lLMkzWyvdwOApMP7J+SxuDACHEPhjjUnRjmQN1p/xHNXqg7
7XG400YAzV9Qd2KEA9Sd+9HDDepODHFYeAIAWKSj7w==
       "], {{2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}, {2.4999164538657066`, 
       2.3935725471190232`, -0.004134856707837732}, {3.387724968878586, 
       2.493749354645433, 0.10431166423424715`}, {3.5000835461342934`, 
       1.6064274528809768`, 0.004134856707837732}, {2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP63iMH230oOhwwFd5GZTSwO6jGxfStWbNofIr5a
I6SQw8H1QAtv2hpWB9MLF/c+eLBi/6ruUJFVFhwOSgmH2IyvsUHFZ+xnAAMO
BxjdqNvyOXV3yp6wklWvQ4+zO9ydb/vzjCangzFEvf2aFyHXV/exO+y2r/40
M5jLwQRivj1T7P9DjGHsDjPu73idVsvtoAZxD4Y41J0Y5kDdaQ+z9x7UXqg7
7XG40wbmL2Wov6DuxAgHqDv3o4cb1J0Y4rDwBAAedp8h
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLHYH/xkLGXRyN+z/dOt4
tPAKVof9Ozhqa+awO4ic1gl7+mzp/sq3j9dyXmFzSIhpsbM7BxOfup8BDDgc
YPSEf+ePZzok7WkXkgn6ps3psGBx9cGDhhwOQhD19nyqFkvehHM5OLp/b2pO
5nAQhphvP8U85NujZm6Hh6+KXFyncjj4QtyDIQ51J4Y5UHfao9sLdac9Dnfa
oPsL6k6McIC6cz96uEHdiSEOC08AUMSTXg==
       "], {{2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}, {2.477597807858436, 
       3.3633454387878277`, 0.00872019253053169}, {3.356393287528202, 
       3.509117485367196, 0.13705185404883644`}, {3.522402192141564, 
       2.6366545612121723`, -0.00872019253053169}, {2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7IvMNY/B6Hw5avXbfMpvE4TAv41xP6ePv+hUwX
yvmncDhU+LE/r9zJ61CSvSLt+M31+wMYX+xm9+JwsFne/HnPHT6o+Pz9DGDA
4QChBRy6InuuXujK2rPhn7jLj63sDkk6dm0LJwo4FEDU28f/1e/4kM3ucCSi
hsdZWdChCGK+Pf8f9zMvFNkd1Fp3TXqyRdBhCsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEALMkod0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA79D4XJu4eydm/c3ub4L
sd7A6hAUl/poRgO/w9tO/iN9Pqv2H1QqXyV7g81Bc71Roc8BmPis/QxgwOEA
oQUcZs3d/qPsVeoe+7sdoY/UOR2yV6Qdvykv4PAKot6+bpfg6iP+XA7XA872
bbYXcHgDMd9+7/RZDMvLuR2cfhqH9cYLOBRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwBq75Vy
       "], {{2.675018691382798, 
       3.480034218257422, -0.1703606024475165}, {2.4581333076753618`, 
       4.333340593063415, 0.016264586231646463`}, {3.324981308617202, 
       4.519965781742577, 0.1703606024475165}, {3.5418666923246382`, 
       3.666659406936585, -0.016264586231646463`}, {2.675018691382798, 
       3.480034218257422, -0.1703606024475165}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL58ftKSk3ycDufNBWLKw4QcrpZ27YzP2bPf3HR7
btsWDoeuqq2T/J8IOTxZvLH61adN++fMum3mHMXh4Lo36qR6kTBUfNF+BjDg
cIDQIg7VabXKd6bk70lJVTm5Zym7w26npWY3ekUcHkHU25885TGp0pvdoazV
K3eDtKjDY4j59roGudFmH9kcDE+8X9yxUtThMsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAMgFpRQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PmEHqe8X/5pO3L4/43i4
F/MuVocCS8Ewky3CDipfxP+656zfv+Wx9lLGu2wOO+ZwaEvdgonP388ABhwO
EFrEocj7ZdBE/aw9PjJXov4pcTp4JH+/8lRVxEEBot5+hsWKrX9cuRwmHHu3
8rS3iIMSxHz7xyE1Ar8zuB2uaz6r21go4iABcQ+GONSdGOZA3WmPbi/UnfY4
3GmD7i+oOzHCAerO/ejhBnUnhjgsPAFPaZe6
       "], {{2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}, {2.4415193419221497`, 
       5.3045316493149475`, 0.018969162302250916`}, {3.2940395765914516`, 
       5.52658895903415, 0.20308814741695236`}, {3.5584806580778503`, 
       4.6954683506850525`, -0.018969162302250916`}, {2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM77nM3y7h2fw9uZcW9lVokeyBS6+aK7bbe956JP
TF88+R2+7H7pISwjemBOovXsTZGb7FUDKxl/LeF3+HW3ZAlnnwhUfJE9AxgI
OEBokQMRvjuY6qfm2eSFO/9v0hVwYFPqjv5WKHxgFkT9/tvr2v6xRgs48LiI
bX/zWOjAbIj5+z3ZTv3t6BBwEE5bKPQ4VOhAOsQ9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITAGUgoHk=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSh84GRDd733ld37+RQe
W6rv43WoEppsOnOb8IE2hthV7b2b9rNP+DhH+D6fg23nyVk+t2Hii/YzgIGA
A4QWOWAS9kH60eu8PX/M2w3LJgg4HC4zS92sInKgBaLe/mc+X/IbBUGHtrc5
p9I8RQ60Qsy3/7p86pSkjYIOXimL9aXyRA4ch7gHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4AdYmgyw==
       "], {{
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}, {
       3.710107463666265, -4.476352259400707, -0.21622988032011106`}, {
       4.556562697496302, -4.691395793388974, 0.0011863463318433354`}, {
       4.289892536333735, -5.523647740599293, 0.21622988032011106`}, {
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4g8S32kDy/g3vgIQW7rYIHbrpr2R7W3G5/KvXn
5MYsfofW7sYDdcqCByq4Hi+LfLTO/ummPycdtvI7HDrqkLB/ogBUfJ49AxgI
OEDpAzs6hLgX7Mm06V3GODteVcChuqTOvvEO34ESiPr90r7MZvu9BBy+v/hT
x7ST90AZxPz9Kz6zXJQrEHAoiq3e1zyV58B1iHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA3taehg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvEfkFPMLOSQ3LF/tuHb
4+xbeB2uFafMLGvhP5CVPdt7g8CG/WdnfHvMfIvP4bXlJh/rQzDxBfsZwEDA
AUofYN28VqP6WNaemZtZ+P5NEnDgerws8pGcwIEMiHp743ROmT+qgg6ix3w3
H7EVOJAJMd/+jBSf1q8dgg7yK7/wLI8ROCALcQ+GONSdGOZA3WmPbi/UnfY4
3GlzDs1fUHdihAPUnfvRww3qTgxxWHgCAMRgk2U=
       "], {{
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}, {
       3.678850754562714, -3.4825241906231894`, -0.18461297046761505`}, {
       4.5401343565350665`, -3.6634861856200236`, 0.00365097547078104}, {
       4.321149245437287, -4.51747580937681, 0.18461297046761505`}, {
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ61N2GTTgi/w7sFKXeO1HIfyDOWfmkou8l+z+Wp
isW9/A7zD7yddCOY64Dd+3Nmb9VW2N97eWrCzmP8DgEPyjzfaHJCxWfYM4CB
gAOE5jiwWSY8okAhxUawe5b5YhkBh43ynduEr7EdsIGo368kZprvZingkGgv
lKu+hvWALcT8/cYLzy97GSrgIBQ/W9m6ieVALsQ9GOJQd2KYA3Xnfpi9G6D2
Qt25H4c798D85Q/1F9SdGOEAdac9erhB3YkhDgtPADECmQ4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPvuBEqu2S58ebtmvdH9C
RO9qXgfnIyreKfPZD3z05ch7d331/on5HmuOXeVzUEqapLrpPEx89n4GMBBw
gNAcBzymbYz+aJy+x/zE7ZUyUwUc7s3NveVrwHHgHUS9ff6E7cGWWoIOe61v
b5mdwHHgA8R8+2URk/+G7hd0mH3To//lBI4DxRD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAMplplI=
       "], {{
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}, {
       3.6470476573032444`, -2.492831381576873, -0.1523306806642988}, {
       4.52075058797933, -2.634347341146244, 0.010814721094927732`}, {
       4.352952342696756, -3.507168618423127, 0.1523306806642988}, {
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP402Ydvdje/Q+Lj19xHe5gPHHf/Wbzi9Qr779vv
xqVv4ndwdJq76UYs0wGD1t/fpeYusP99O2+98U1+B4WFfpFv9Bih4hPsGcBA
wAFCMxxY0vHDvWlDtA3TJA+NNGEBhwN7k3zVF/3drwdRv59VZWLAGTUBh/rq
o7P8XH7v14eYv599280KIysBB3tLjRelz37sPwpxD1zcDioOdSeGOVB37ofZ
ux9qL9Sd+3G4cw+6v6DuhIeDAzQcoO60Rw83qDsxxGHhCQBDpaoH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/3Zx8q9G5K2bTf+cgh
dqWlvA7XlB00xKv/758Q4cTP3LZiv2LSQ+aJl/gcXgsqTOneCxOfsZ8BDAQc
IDTDgfIvieZr81P2vPfjr9s+TcCB6/t7UytFhgO9EPX29+bK/cnTFXQQfXc/
u8SJ4UA/xHz7c290q9SOCDrIPz2/cF0yw4EsiHswxKHutL+PZg7Unfbo9kLd
aY/DnTZKaP6CuhMeDteh4QB15/5UtHCDunM/rvAEAGxLlYo=
       "], {{
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}, {
       3.615280131564128, -1.5075918604915728`, -0.12051907308195917`}, {
       4.4983861897860224`, -1.6049377165038257`, 0.023173217069706202`}, {
       4.384719868435872, -2.492408139508427, 0.12051907308195917`}, {
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHacfv625VF+B75rqz0X63zfX5yj/P9kxkz7Bn5T
24s3+B24nhy/nXPiy/7Fc8VXtX2YYH+gfda8jDf8DqyfHueapXyCijfYM4CB
gAOE/rA/eWONdLe1j43Cnk0bTnMKOHyXtlCZbP56/0KI+v0OFamJ04UFHN6Z
F3io5T/bvwhi/v4EEwmhZFkBh2fBK3J2Lnu4vxDiHrj4E6g41J1wc95CzYG6
cz/M3m9Qe6Hu3I/DnXtg/mKB+gvqTng4cELDAepOe1i48ULDDepOe1zhCQAe
eKll
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7vv3PlxQaGCxv2m7GH
d8kv5HUQdl5/qrri/f7qY93TVmct2z+7Wfto/wU+h86F4U9t98DEp+1nAAMB
Bwj9YX+aqvwKy3VJe4zssmR3TBdwsNYP4X2o+GF/JUS9fWrNFasCfUGH8rgV
UoecP+yvgphvP32XXYTGcUGHTb1/1Benfth/G+Ie+xlo4lB3YpgDdae9MZq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAKHjriA=
       "], {{
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}, {
       3.5842083968149794`, -0.5267882881396561, -0.09048767031498518}, {
       4.473188077503202, -0.5764158901397218, 0.04086006831491938}, {
       4.415791603185021, -1.473211711860344, 0.09048767031498518}, {
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcDh9BgTu7GdAAQIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIATatHNg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbn909dnM/jwAAF7NsmK9q5btivz9XlfGg+L1x8
y6cjOis2Lt0vwXpU8eF5PjTxqfshPAG4uMMpP1UekaQ9JbWy+fwzEOKbIOrt
X/yyuidnIAgX3wwx3z6mIsJX7wRCnBXiHgxxqDsxzIG60x7dXqg77XG40wbd
X1B37jdACweoO/d7oIUb1J37cYUnALFVY88=
       "], {{
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}, {
       3.554510871386728, 0.4499999999999999, -0.06355655975104223}, {
       4.445489128613271, 0.4499999999999999, 0.06355655975104223}, {
       4.445489128613271, -0.4499999999999999, 0.06355655975104223}, {
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4wkRBKlhVweBK8Imfnsof2xTnK/09mzNzvUJGa
OF1YwOGteYGHWv4z+8VzxVe1fZiwX2HPpg2nOQUcvklbqEw2fw0Vb9jPAAYC
DhD6g33yxhrpbmufPQfaZ83LeMPvwPLpca5Zyif7hRD19g38prYXb/A7cD45
fjvnxBf7RRDz7R2nn79teZTfgffaas/FOt/tCyHugYvzQcWh7oSbwwU1B+pO
e5i9rFB7oe60x+FOG5i/vkP9BXUnPBzeQcMB6s79sHB7Bg03qDv34wpPABv9
oRE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7b37nyYgPDhQ37zdjD
u+QX8joIO68/VV3x3r76WPe01VnL9s9u1j7af4HPoXNh+FPbPTDxafsZwEDA
AUJ/sE9TlV9huS5pj5FdluyO6QIO1vohvA8VP9hXQtTbp9ZcsSrQF3Qoj1sh
dcj5g30VxHz76bvsIjSOCzps6v2jvjj1g/1tiHvsZ6CJQ92JYQ7UnfbGaPZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAchimoA==
       "], {{3.5842083968149794`,
        0.5267882881396561, -0.09048767031498518}, {3.5268119224967984`, 
       1.4235841098602782`, -0.04086006831491938}, {4.415791603185021, 
       1.473211711860344, 0.09048767031498518}, {4.473188077503202, 
       0.5764158901397218, 0.04086006831491938}, {3.5842083968149794`, 
       0.5267882881396561, -0.09048767031498518}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGbfdrPCyErAwc5S40Xpsx/2x91/Fq94vWI/q8rE
gDNqAg711Udn+bn8tjdo/f1dau6C/UyTPDTShAUc9u9N8lVf9BcqPmE/AxgI
OEBoBoclHT/cmzZE7/l9O2+98U1+B4WFfpFv9Bgd9CDq7b9vvxuXvonfwcFp
7qYbsUwO+hDz7T9N9uGb3c3vkPj4NffRHmaHoxD3YIhD3Qk3xxFqDtSd9uj2
Qt1pj8OdNjB/HYD6C+pOjHCAunM/LNzsoeEGded+XOEJAFg6osg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/tsw8VejelbNrvfOQQ
u9JSXodryg4a4tX/7SdEOPEzt63Yr5j0kHniJT6H14IKU7r3wsRn7GcAAwEH
CM3gUP4l0Xxtfsqe9378ddunCThwfX9vaqXI4NALUW9/b67cnzxdQQfRd/ez
S5wYHPoh5tufe6NbpXZE0EH+6fmF65IZHLIg7sEQh7rT/j6aOVB32qPbC3Wn
PQ532iih+QvqTng4XIeGA9Sd+1PRwg3qzv24whMAPICOCg==
       "], {{
       3.615280131564128, 1.5075918604915728`, -0.12051907308195917`}, {
       3.501613810213978, 2.3950622834961743`, -0.023173217069706202`}, {
       4.384719868435872, 2.492408139508427, 0.12051907308195917`}, {
       4.4983861897860224`, 1.6049377165038257`, 0.023173217069706202`}, {
       3.615280131564128, 
       1.5075918604915728`, -0.12051907308195917`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZeeH7Zy1ABB6H42crWTSwOecbSLw1lN+1XEjPN
d7MUcEi0F8pVX8PqYPf+nNlbtRX7BbtnmS+WEXDYIN+5TfgaG1R8xn4GMBBw
gNAcDptlwiMKFFL23Ht5asLOY/wO/g/KPN9ocjrYQNTb77k8VbG4l99h/oG3
k24EcznYQsy3n7U3YZNOCL/DuwUpd47UcjvkQtyDIQ51J4Y5UHfaw+wNgNoL
dac9DnfawPy1EeovqDsxwgHqzv3o4QZ1J4Y4LDwBQUWQgw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPrtDiVXbpU8Pt+xXuj8h
onc1r4PzERXvlPnsDh99OfLeXV+9f2K+x5pjV/kclJImqW46DxOfvZ8BDAQc
IDSHg8e0jdEfjdP3mJ+4vVJmqoDDvbm5t3wNOBzeQdTb50/YHmypJeiw1/r2
ltkJHA4fIObbL4uY/Dd0v6DD7Jse/S8ncDgUQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Ampqe0g==
       "], {{3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}, {3.4792494120206703`, 
       3.365652658853756, -0.010814721094927732`}, {4.352952342696756, 
       3.507168618423127, 0.1523306806642988}, {4.52075058797933, 
       2.634347341146244, 0.010814721094927732`}, {3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7xmeWiXIGAQ1Fs9b7mqTwON921bA9rbt8v7cts
tt9LwOH7iz91TDt5HSq4Hi+LfLRuf+8yxtnxqgIO1SV19o13+KDi8/YzgIGA
A4ze0SHEvWBP5p6nm/6cdNjK73DoqEPC/okCDiUQ9fanUn9Obszid2jtbjxQ
pyzoUAYx336DxLfYQ/L8Du6BhxTstgo6XIe4B0Mc6k4Mc6DutEe3F+pOexzu
tEH3F9SdGOEAded+9HCDuhNDHBaeAA22mDc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvE7yClmFnJI7tg/2/Dt
cfYtvA7XilNmlrXwO2Rlz/beILBh/9kZ3x4z3+JzeG25ycf6EEx8wX4GMBBw
gNGsm9dqVB/L2jNzMwvfv0kCDlyPl0U+khNwyICotzdO55T5oyroIHrMd/MR
WwGHTIj59mek+LR+7RB0kF/5hWd5jICDLMQ9GOJQd2KYA3WnPbq9UHfa43Cn
zTk0f0HdiREOUHfuRw83qDsxxGHhCQCUlYvl
       "], {{3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}, {3.4598656434649335`, 
       4.336513814379977, -0.00365097547078104}, {4.321149245437287, 
       4.51747580937681, 0.18461297046761505`}, {4.5401343565350665`, 
       3.6634861856200236`, 0.00365097547078104}, {3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZkO/W3o0PAQThtodDjUCGHTKGbL7rbdu+/va7t
H2u0gAOPi9j2N4+FHOYkWs/eFLlpf1648/8mXQEHNqXu6G+FwlDxRfsZwEDA
AUKLOET47mCqn5q3RzWwkvHXEn6HX3dLlnD2iTjMgqi391z0iemLJ7/Dl90v
PYRlRB1mQ8y3z/uczfLuHZ/D25lxb2VWiTqkQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Aa8CXvw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSjscLKhu977yu79fAqP
LdX38TpUCU02nblN2KGNIXZVe++m/ewTPs4Rvs/nYNt5cpbPbZj4ov0MYCDg
AKFFHEzCPkg/ep235495u2HZBAGHw2VmqZtVRBxaIOrtf+bzJb9REHRoe5tz
Ks1TxKEVYr791+VTpyRtFHTwSlmsL5Un4nAc4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+9HDDepODHFYeAIARb6ZSw==
       "], {{3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}, {3.443437302503698, 
       5.308604206611026, -0.0011863463318433354`}, {4.289892536333735, 
       5.523647740599293, 0.21622988032011106`}, {4.556562697496302, 
       4.691395793388974, 0.0011863463318433354`}, {3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY8o/zqaJmwg99v8Yz3q0QPSAecZ9xZt8t+o1Hu
x+Ylwg6dy3fNmi8jemBf1/3VF1ZutI+Yue2H4yVhh6PBsWf9+0Sg4gvtGcBA
xAFKH5hgI38yuiDXZkWaJ/s+XREH6zWLjDYUCh/YA1G/3//sJL6aaBGH8gjX
1ITHQgf2Qszf/934jqhVp4jDJpYX0wVChQ5IQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBQDylww==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIHDu/Z6xSscmD//2m3
7256KORwtTFgb8RO4QPrf/+JONK6dX/D6bd5NwuEHV47rIhbcwcmvnQ/AxiI
OEDpA3suXvpS8b5wT4OJ0ES1fhEH0f3hC4OVRQ6shai3Z8xUUfKVE3XQrlvv
tNxN5MA6iPn2jXPNNhevFXVwsGV/8itT5MAhiHswxKHuxDAH6k57dHuh7rTH
4U4bdH9B3YkRDlB37kcPN6g7McRh4QkAfNSs8Q==
       "], {{
       4.446602686144281, -5.313432754060626, -0.02261242355976882}, {
       4.714623967510865, -4.4795749765342965`, -0.22960469296484698`}, {
       5.553397313855719, -4.686567245939374, 0.02261242355976882}, {
       5.285376032489135, -5.5204250234657035`, 0.22960469296484698`}, {
       4.446602686144281, -5.313432754060626, -0.02261242355976882}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF59+aa4fr+wg3bnnPojWwUPPN+gyawcuM1etvcZ
/6ktwg6ybMKhN5QFD3RNM2dpObjWvs/tM3vqLWEHvuZOrTcTBaDic+0ZwEDE
AUILHJBd0cz87nSGTdFOnh+zVEUcHv98s0r9Dt+Bdoj6/Y+LJD+Yeos4HP98
M9R/B++BToj5+0N11F5cKBBxWPX2GEP5FJ4DzyDuwRCHuhNuzjGoOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AX7empM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwH+vKnp/du2bP/b4Tj
xoY7Qg7LFN+//9nBfyDBa9d7DuXN++vXLIhwyBN2uDzh+/eaIzDxxfsZwEDE
AUILHJin9vAJ39P8PY3B8cv3TxRxmG7O0nJQVuBAHES9PfPyfX71yqIOuvkc
HM3WAgfiIebbt/yS/Wa3VdThyDKeHpdIgQM9EPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMA8Aae1A==
       "], {{
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}, {
       4.683173925161513, -3.485317056463843, -0.19930555921848897`}, {
       5.537169907483723, -3.6596681540899216`, 0.024954461592410312`}, {
       5.316826074838487, -4.514682943536157, 0.19930555921848897`}, {
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ9aby5fKWwgxSjjlNUHfeBmatfs18t32jP4Xb2
jP8xYQfBMFkdmxCuA2eePIkv9Fpuz7I47Zn6Y2EHztV8YnJanFDx6fYMYCDi
AKE5DoRkvjy/OSPZ5k/MTMkbMiIOP0I+vnx4le3AKYj6/T92GhlvsBRxeL/y
0eXDq1kPnIaYv/+z2BmfjjARh+f/Lu9d2shyYDrEPXDxZ1BxqDsxzIG6cz/M
3u9Qe6Hu3I/DnXtg/uKA+gvqToxwgLrTHhZuktBwg7rTHld4AgB2yaTn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewHjotXCcbP2bnfxN3k
juINIYfcnAara4vYD7TuWsb9Smjj/lnKUu8EcoQdzMwcZLMvwsQX7mcAAxEH
CM1xwKjnQMbtkpw9aXeeCr6fLOJw6uT+R1P0OA40Q9Tbn9lxWvmeuqjD5Mn1
RzVjOQ60QMy3N5y60fTsblGH2Fj7Ffu6OQ4chbjH3ghNHOpODHOg7rRHtxfq
Tnsc7rRB9xfUnRjhAHXn/vNo4QZ1535c4QkABlSbCg==
       "], {{
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}, {
       4.651104317658282, -2.495069664572104, -0.1682770311360975}, {
       5.517904318733632, -2.631539151635964, 0.031807544072237376`}, {
       5.348895682341718, -3.504930335427896, 0.1682770311360975}, {
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5dH6oddlTY4dFzyQy2XuYDPSp8zRd4Vthbnnos
8+SGsMO0WWmuLHFMBzbncjJ1cyywl3layFf0RtjB23ezEpM+I1R8gj0DGIg4
QGiGA1e28a97viPK5olU38deYRGHrNSZu34v/Lt/I0T9/uOmMo+l1UUcrpwy
Kv3u/Hv/Joj5+1cHrLqy0krEwc7gjP7npz/2d0HcAxe3hYpD3Qk35zLUHKg7
96PbC3Xnfhzu3IPuL6g7McIB6k57WLg9hIYb1J32uMITAFbOk70=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//739/lKvtpsn1/UMTx
XeevCDlM2vJ++e76//unXkqe6/Nx3X7NNcl307OEHTxvfb98dz9MfN5+BjAQ
cYDQDAeq9S/rip7M3HM9eI7SjKkiDreFWMQEFRgOTIKot1+33MLVQFvUYbsq
h46SA8OByRDz7Vt+X0k/cUDUYZIFj5NxAsOBtxD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAFR4qAI=
       "], {{
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}, {
       4.619023991127767, -1.5091673571695932`, -0.1376248429459686}, {
       5.495552964467648, -1.6031128909181338`, 0.043679309197428254`}, {
       5.380976008872233, -2.490832642830407, 0.1376248429459686}, {
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb9oXg65pGwg3ZBS+dhne/7+62+aO7rmGHPF3Dw
ju0bYQfZBWujm0582Z9Q41uoGT3Bnn1Fwju5b8IOfBeu6TqmfIKKN9gzgIGI
A4T+sH++SmP6LCdvm5/h8wUfcoo4PIkPWlJr/np/HET9/k/r7ZQPCYs4HN+/
xON33rP98RDz979mv2eyWFbEYbX89zcVyx7u74O4By6+CioOdSfcnGNQc6Du
3A+z9zHUXqg79+Nw5x50f0HdCQ8HGWg4QN1pDws3LWi4Qd1pjys8AY+uo70=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f751x7nzVp7db9tlWC
obsvCTnITindolb7fn9N8avHuc/X7Jfb27EqNlPYge+UVdTkfTDxOfsZwEDE
AUJ/2D9x64wXBmIZex45lYcumibi8HPWo6BtCh/2V0LU2x9ufbfKRVfU4aPp
0aU5jh/2V0HMt196IpXh+WFRh1cXlv9QSvqwfzbEPRjiUHfCzfkENQfqTnt0
e6HutMfhThuYv/ih/oK6EyMcoO7cjx5uUHdiiMPCEwC6Tri6
       "], {{
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}, {
       4.587632007445626, -0.527612201225504, -0.10863888017492673`}, {
       5.470253784431534, -0.5755304662070981, 0.060720615193332494`}, {
       5.412367992554374, -1.472387798774496, 0.10863888017492673`}, {
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcTh9BgTu7GdAASIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIAeUNHcg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINa4w/eMw1rIgQEKHN8JB6iqb91/dNKWd6yXEOLM
k6UOGJqs2Z/sGfWdKVMYTXzOfghPBC6uoyqmcKUhfc/cbUs5/k5DiDNA1Ntb
53oL/tIVhYszQsy3v6H8UfL7EYS4A8Q9GOJQd2KYA3WnPbq9UHfa43CnDbq/
oO7ECAeoO/ejhxvUnRjisPAEAJHdWYk=
       "], {{
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}, {
       4.557651133210165, 0.4499999999999999, -0.08262856678987253}, {
       5.442348866789835, 0.4499999999999999, 0.08262856678987253}, {
       5.442348866789835, -0.4499999999999999, 0.08262856678987253}, {
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Nfs9ksayIwyr5728qlj2077f6ormvY8b+T+vt
lA8Jizgc27/E43feM/uEGt9CzegJ+3+Gzxd8yCni8Dg+aEmt+WuoeMN+BjAQ
cYDQH+znqzSmz3Ly3sO+IuGd3DdhB74L13QdUz7Zx0HU2/MFHLxj+0bYQWbB
2uimE1/s4yHm24v+UDwd80jYQaugpfOwznf7Poh74OLaUHGoO+HmyELNgbrT
Ht1eqDvtcbjTBuavJ1B/Qd0JD4fj0HCAunM/LNxWQ8MN6s79uMITALm+nWg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f2c669z5q0dut+2yrB
0N2XhBxkp5RuUat9b19T/Opx7vM1++X2dqyKzRR24DtlFTV5H0x8zn4GMBBx
gNAf7CdunfHCQCxjzyOn8tBF00Qcfs56FLRN4YN9JUS9/eHWd6tcdEUdPpoe
XZrj+MG+CmK+/dITqQzPD4s6vLqw/IdS0gf72RD3YIhD3Qk35xPUHKg77dHt
hbrTHoc7bWD+4of6C+pOjHCAunM/erhB3YkhDgtPAIqDsTo=
       "], {{
       4.587632007445626, 0.527612201225504, -0.10863888017492673`}, {
       4.529746215568466, 1.4244695337929019`, -0.060720615193332494`}, {
       5.412367992554374, 1.472387798774496, 0.10863888017492673`}, {
       5.470253784431534, 0.5755304662070981, 0.060720615193332494`}, {
       4.587632007445626, 
       0.527612201225504, -0.10863888017492673`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF4dsOrKSisRB1uDM/qfn/6w71Hha77As2L/cVOZ
x9LqIg6XTxmVfnf+bb85l5Opm2PB/idSfR97hUUcslJn7vq98C9UfMJ+BjAQ
cYDQDA5XtvGve74jao/M00K+ojfCDt6+m5WY9BkdNkLU21ueeizz5Iaww7RZ
aa4scUwOmyDm24euD9UOOyrs8PC5ZAZbL7NDF8Q9cPFHUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw+EKNByg7twPCzc7aLhB3bkfV3gCAJTDjtI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//27+9ylf002b4/KOL4
rvNXhBwmbXm/fHf9f/upl5Ln+nxct19zTfLd9CxhB89b3y/f3Q8Tn7efAQxE
HCA0g0O1/mVd0ZOZe64Hz1GaMVXE4bYQi5igAoPDJIh6+3XLLVwNtEUdtqty
6Cg5MDhMhphv3/L7SvqJA6IOkyx4nIwTGBzeQtyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AJK2ggg==
       "], {{4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}, {4.504447035532352, 
       2.396887109081866, -0.043679309197428254`}, {5.380976008872233, 
       2.490832642830407, 0.1376248429459686}, {5.495552964467648, 
       1.6031128909181338`, 0.043679309197428254`}, {4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4sdsanI0zE4dm/y3uXNrI4zFz9mv1q+cb9P3Ya
GW+wFHF4v/LR5cOrWR3OPHkSX+i1fP+fmJmSN2REHL6HfHz58CobVHz6fgYw
EHGA0BwOIZkvz2/OSN7DsjjtmfpjYQeO1XxiclqcDqcg6u053M6e8T8m7CAY
JqtjE8LlcBpivj3vS+PN5SuFHSQZdZyi6rgdpkPcAxeXgopD3YlhDtSd9jB7
OaH2Qt1pj8OdNjB//YD6C+pOjHCAunM/LNyeQ8MN6s79uMITAMm8oR0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewOx8WrBOPn7Nxv4m5y
R/GGkENuToPVtUXsDq27lnG/Etq4f5ay1DuBHGEHMzMH2eyLMPGF+xnAQMQB
QnM4GPUcyLhdkrMn7c5TwfeTRRxOndz/aIoeh0MzRL39mR2nle+pizpMnlx/
VDOWw6EFYr694dSNpmd3izrExtqv2NfN4XAU4h57IzRxqDsxzIG60x7dXqg7
7XG40wbdX1B3YoQD1J37z6OFG9Sd+3GFJwDWepOK
       "], {{4.651104317658282, 
       2.495069664572104, -0.1682770311360975}, {4.482095681266368, 
       3.368460848364036, -0.031807544072237376`}, {5.348895682341718, 
       3.504930335427896, 0.1682770311360975}, {5.517904318733632, 
       2.631539151635964, 0.031807544072237376`}, {4.651104317658282, 
       2.495069664572104, -0.1682770311360975}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7VUXtxoUDEYdXbYwzlU3gcnm/QZFYO3Lb/cZHk
B1NvEYdjn2+G+u/gdeiaZs7ScnDt/qKdPD9mqYo4PP75ZpX6HT6o+Nz9DGAg
4gChBRxkVzQzvzudsafP7TN76i1hB77mTq03EwUc2iHq7WV7n/Gf2iLsIMsm
HHpDWdChE2K+/erLN8X1+4UdtDvn1B/ZKujwDOIeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHfCw+E4NByg7tyPHm5Qd2KIw8ITAJxik1I=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwOffnT03u37Nn/N8Jx
Y8MdIYdliu/f/+zgd0jw2vWeQ3nz/vo1CyIc8oQdLk/4/r3mCEx88X4GMBBx
gNACDvPUHj7he5q/pzE4fvn+iSIO081ZWg7KCjjEQdTbMy/f51evLOqgm8/B
0Wwt4BAPMd++5ZfsN7utog5HlvH0uEQKOPRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwDAO5dU
       "], {{4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}, {4.462830092516277, 
       4.340331845910078, -0.024954461592410312`}, {5.316826074838487, 
       4.514682943536157, 0.19930555921848897`}, {5.537169907483723, 
       3.6596681540899216`, 0.024954461592410312`}, {4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5ufEfUqlPEYRPLi+kCoUIO0gHnGXfW7drvf3YS
X020iEN5hGtqwmMhh31d91dfWLlx/4o0T/Z9uiIO1msWGW0oFIaKL9zPAAYi
DjB6go38yeiC3D0RM7f9cLwk7HA0OPasf5+Iwx6IevuNRrkfm5cIO3Qu3zVr
voyow16I+facZ5RfHS0TdvD7LZ7xfpWogxTEPRjiUHdimAN1pz26vVB32uNw
pw26v6DuxAgHqDv3o4cb1J0Y4rDwBABZ7Z27
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIOh/fsdQpWObD//7Tb
dzc9FHK42hiwN2KnsMP6338ijrRu3d9w+m3ezQJhh9cOK+LW3IGJL93PAAYi
DjB6z8VLXyreF+5pMBGaqNYv4iC6P3xhsLKIw1qIenvGTBUlXzlRB+269U7L
3UQc1kHMt2+ca7a5eK2og4Mt+5NfmSIOhyDuwRCHuhPDHKg77dHthbrTHoc7
bdD9BXUnRjhA3bkfPdyg7sQQh4UnAE0JpXE=
       "], {{4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}, {4.446602686144281, 
       5.313432754060626, -0.02261242355976882}, {5.285376032489135, 
       5.5204250234657035`, 0.22960469296484698`}, {5.553397313855719, 
       4.686567245939374, 0.02261242355976882}, {4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQcYDQH/aj8lUcwkJB4CkO8asY4gwoACEeAlFv
j138KYY41D1Ei4fhMCcMh70E3InhrxAc4QB1D0FxABe8L7E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN77Of0ZZ5aqAwMUOPPMkPw2Vcnh8vf376I/qsDF
dTkEBJfwKTu8+l3+fW0FQlyMpYMjqF0ZykeIw/io8gwMMP0w82DiMPtg9sPE
Ye7DJY7LHFz24nInLn/hCgdc4YZLHAA8XFso
       "], {{10.707106781186548`, -1., 
       9.292893218813452}, {10.707106781186548`, 1., 9.292893218813452}, {
       9.292893218813452, 1., 10.707106781186548`}, {9.292893218813452, -1., 
       10.707106781186548`}, {10.707106781186548`, -1., 9.292893218813452}}}],
     
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyMnXkgVN/7x41lGmTMDEqLUrRvKi1E56TSShulHZWUkkqRLFnSRqJISSlp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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJx0nHlcjlsX97ubNGguMkTct8wKRSX2lkRUQiWFBklEA1GSJiQNGjSnRKU0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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>{{-8, 12.5}, {-6.5, 6.5}, {-1, 13.5}}]], "Print",
 CellChangeTimes->{3.563404680148786*^9, 3.566101180997587*^9, 
  3.614727735820649*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[265]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tRotate[PointOfRays[{11,11},BirthPoint->{-50,0,-50},NumberOfRays->66, 
\t\tMonteCarlo->Stratified],90,{0,1,0}],
\tMirror[{.9,.9}],
\tMoveDirected[Screen[{2,2}],{10,0,10},{0,0,0}]}, CreateClones->clonedplaces, \
RunningCommentary->TurboTrace, CloneSortLength-> 3];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[266]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277363214397`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277363232393`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736324522*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736325945*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`ReportedSurfaces -> All, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`CreateClones -> CompressedData["

1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`ReportedSurfaces -> 
     All, Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortMethod -> 1, 
     Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736345278*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736368281*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736370182*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.61532200000000003559108563422341831028`5.809702356252906", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.61532200000000003559108563422341831028`5.809702356252906, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736947302*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736949318*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736951045*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736952467*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736953937*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277369553556`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277369568253`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727736958794*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277369612103`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737091827*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737094597*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737097187*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277370994473`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"PointOfRays", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"11", ",", "11"}], "}"}], ",", 
               RowBox[{"BirthPoint", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "50"}], ",", "0", ",", 
                  RowBox[{"-", "50"}]}], "}"}]}], ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "66"}], ",", 
               RowBox[{"MonteCarlo", "\[Rule]", "Stratified"}]}], "]"}], ",", 
             
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", 
                 RowBox[{"-", "1.`"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "50.`"}], ",", "0", ",", "50.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.7071067811865475`", ",", "0", ",", 
              RowBox[{"-", "0.7071067811865475`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.7071067811865475`", ",", "0", ",", "0.7071067811865475`"}], 
             "}"}]}], "}"}]}], "}"}]}], "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`PointOfRays[{
           Optica`Optica`Ray[]}, {11, 11}, 
          Optica`Optica`BirthPoint -> {-50, 0, -50}, 
          Optica`Optica`NumberOfRays -> 66, Optica`Optica`MonteCarlo -> 
          Optica`Optica`Stratified, 
          Optica`Optica`SourceTransformation -> {{0, 0, 
            0}, {{0, 0, -1.}, {0, 1., 0}, {1., 0, 0}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, 0, 0}, {{0, 
            0, -1}, {0, 1, 0}, {1, 0, 0}}}]], 
       Optica`Optica`SourceTransformation :> {{-50., 0, 50.}, {{
          0.7071067811865475, 0, -0.7071067811865475}, {0, 1., 0}, {
          0.7071067811865475, 0, 0.7071067811865475}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-50, 0, 
         50}, {{2^Rational[-1, 2], 0, -2^Rational[-1, 2]}, {0, 1, 0}, {
          2^Rational[-1, 2], 0, 2^Rational[-1, 2]}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 66, 
       Optica`Optica`BirthPoint :> {-50, 0, -50}, 
       Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       Optica`Optica`Stratified, Optica`Optica`SourceID :> 72933, 
       Optica`Optica`SourceFraction :> {1, 1}, 
       Optica`Optica`SourceOffset :> {0, 0}, 
       Optica`Optica`GridSpacing :> {#& , #& }, Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues :> {}], False, False, False, 
      False, {{-50., 0, 50.}, {{0.7071067811865475, 0, -0.7071067811865475}, {
        0, 1., 0}, {0.7071067811865475, 0, 0.7071067811865475}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737102405*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737196589*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737199237*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737201325*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.61472773726713*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277373056307`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727737307412*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277373090076`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277373105497`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "3"}],
  SequenceForm["maximum used clone sort position = ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277454865828`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3492", ",", "24", ",", "2"}], "}"}]}],
  SequenceForm["Histogram of used sort positions: ", {3492, 24, 2}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745488364*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({3492, 24, 2}\\)\\), \
\\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] All\\)\\)\\)\\)]\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6147277455881577`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You may wish to set CloneSortLength -> \"\>", 
   "\[InvisibleSpace]", "4"}],
  SequenceForm["You may wish to set CloneSortLength -> ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745595024*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "8.42597100000000054365045798476785421371`6.946219873344409", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "6936",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   8.42597100000000054365045798476785421371`6.946219873344409, 
   " seconds with ", 6936, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745771254*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277457737417`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745776566*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745779374*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745781176*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.61472774578257*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727745784054*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.61472774578544*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.6147277457868967`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.61472774589676*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727747236404*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[266]:="],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJysnHdUFcn2tpEgKCDZnMWcszOiXQbMOWACxZyzYs5hdMxixlHBLCYU89Eq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    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7WmeXYUCZyoE3Ae9ejVaIHmGNN7/is32+/K3qO
NoO/yIF1W++oTZcRPcBkd25Sh/xW+7u650Qb1EUOXI/Km+zdJwIVX2rPAAYi
B2D0GmNGVfdZhTbKlwxf1d8QPqC5dGLOlkLhAwwQ9fvdliRf+b9B+ECQl/LN
jMdCBxgh5u/PKpu6r75T+ED1+y2usqFCBxgg7oGLV0HFoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHhZurdBwg7rTHld4AgAlc5t6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQofqEwUOMezotPe/lB1
lpW66AGO41vuNq4WPrDsNZfJZqlGe4WHtqZzJ4scaEm+9e7AVZh4oT0DGIgc
gNEi9/aEXW20sXkod+hUUo7wgZo5qoL2WiIHlkLU7z9o2zL16A2hAz8svJXq
QmDijfsXxbglaLgKHSi5WmC8t07kQDnEPRjiUHdimAN15/4HaPZC3bkfhzv3
yKP5C+pOjHCAutMePdyg7sQQh4UnAE8rnsw=
       
       "], {{-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}, {-5.316739533975529, -4.4593508581224395`, \
-0.11124105808568469`}, {-4.451813203970924, -4.706888096742872, \
-0.1362961805347467}, {-4.683260466024471, -5.5406491418775605`, 
       0.11124105808568469`}, {-5.548186796029076, -5.293111903257128, 
       0.1362961805347467}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJYofOTokSByoLmM6a3pNsED9zviGJ8577JP9X6j
beAgcmDtz7DPyiqCB16x2ofNbNpov1n1m6iEgsiBazWrfwpOEoCKL7RnAAOR
AxBa4IBB/L7+/3q5Nr63OF89vy98IJhtJc+d23wHXkLU75+9RfjK+f3CB5bx
BEnu2M4LFd+4/0Wf7L7t84UP/BL6rTplMs+BuxD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAHZ9ong=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMt/QFVO4wT7ldn2kzdt
LOnQEj1wkd3P9HUx/wEpkYLWqN5J9l43I6xcpooceMG8fNbXnTDxJnsGMBA5
AKEFDlwpS7037bWfzTa15Ud3Zwkf4KlbY8SqLHBAAqJ+f66vX3f5VaEDEn8i
UrncBA5IQszfr1zyNcDYQeiAchXrDP5MgQPKEPdgiEPdiWEO1J370e2FunM/
DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AugqWTQ==
       
       "], {{-5.531329884018523, -4.325341537419348, 
       0.12977456753339}, {-5.343278604100026, -3.469461366072062, \
-0.07542252897520049}, {-4.468670115981477, -3.6746584625806524`, \
-0.12977456753339}, {-4.656721395899974, -4.5305386339279385`, 
       0.07542252897520049}, {-5.531329884018523, -4.325341537419348, 
       0.12977456753339}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC66dVtI1lPkgJFrdmR0PfcB5imlsf2uW+wXTpzE
s89A5ICi3qcJz0O4DmyQ+nQxk321/UUPT7Z4CZEDguKVJ4q1OKHis+0ZwEDk
AITmOPD8gGeLbluajf72bT8XPBc+8P5Fm3nPVbYDayHq98fn5X52PC984P5F
3nyJ1awH1kPM39+nqvL20TbhA+d2TVm2pIHlABPEPRjiUHdimAN15350e6Hu
3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwCxsaBB
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewHnCaFdf9TWWLPs+Qr
r5mu6IGp5jsiHk1mPxAlIcf/7/Yse7ZLv9hmTxM5cFo6RufjSZh4lz0DGIgc
gNAcB+Znvkv8lxhm80uX9WdKpvAB0yeLL/OZcRwIh6jf/yWa69PJS0IHsk+4
L5fN4TgQATF//7tO/td6NkIHFqx5XaWziOOAI8Q9+9+iiUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1p70QWrhB3WmPKzwBhR2gJQ==
       
       "], {{-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}, {-5.369827301509674, -2.4836276446310626`, \
-0.03984165745559268}, {-4.487372759012824, -2.6420004479704664`, \
-0.11853114588381125`}, {-4.630172698490326, -3.5163723553689374`, 
       0.03984165745559268}, {-5.512627240987176, -3.3579995520295336`, 
       0.11853114588381125`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7GO2mFvqHIgYR2ocoVvcwHLI1rpGfMWm3fH5dY
cEpB5MBrlu0BBXFMBy6dCRISSF9k777ewCJVQORAaVO0hoU+I1R8kj0DGIgc
gNAMB2JC7xcfXR1nszPg/PFZ74UPiP32WN+/8O/+CxD1+wsXzus3vS98QPvb
xDh559/7L0LM36/1KTf8wjnhAw4fb/Guf/JjvznEPRjiUHfCzdGCmgN1536Y
vaJQe6Hu3I/DnXvQ/QV1J0Y4QN1pjx5uUHdiiMPCEwDMJZ9O
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/3W667dG3f5RX2qtq8
Vfr6ogdmZubWH8/5v1+9pOeJZu8C+8lT2fZOny5y4OyWbfuTt8HEJ9gzgIHI
AQjNcOCV2KuaD1OjbXKzfjplZAgfmLVUReGcCsMBVYj6/bevfGq9cEHogLG3
p8McT4YDahDz93vYvzlhYSl04OyH3ISsPIYD5hD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdac9erhB3YkhDgtPAOcOq2o=
       
       "], {{-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}, {-5.39608595530146, -1.5019171722096671`, \
-0.005423345214476072}, {-4.507847314362481, -1.6097448420306848`, \
-0.10240432460654149`}, {-4.60391404469854, -2.498082827790333, 
       0.005423345214476072}, {-5.492152685637519, -2.390255157969315, 
       0.10240432460654149`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64dHPtLgmRAxJ92aUqut/3t9xNkpL7Nts+oOdZ
cY2AyIFdcZ9+HDrxZX+k3XRBkSWT7DXcPlvacYgciNWvrElM+QQVb7JnAAOR
AxD6w/7JQn+Olwn629zYyXPs4HfhA24LedltzV/vD4eo37+hWLKn+b3wgR4n
ab6qvGf7IyDm7+/QVQtyfS584NJjDdHtSx/ub4a4By5+ESoOdSfcnG6oOVB3
7ke3F+rO/TjcuQfdX1B3YoQD1J32sHATh4Yb1J32uMITAN4Goo8=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/3b3lx6XDCntX2TDxT
fFMNRA/wuhXH3896v7/yw8PrU2sX2TOynVpmNEPkAPvinevzt8LEJ9kzgIHI
AQj9Yf+JCRVC/hfjbP7/NI08my58oFZPWcND9cP+coj6/f8+Z2+adV7owM8Y
t4AJXh/2V0DM3//37ULuDHOhA2XdmRU38j/s3wRxz/4/aOJQd2KYA3XnfnR7
oe7cj8Ode9D9BXUnRjhA3WnPjBZuUHfa4wpPAIesugg=
       
       "], {{-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}, {-5.421742536374846, -0.5241728505774544, 
       0.026865533393664168`}, {-4.529958215082733, -0.5787849537735706, \
-0.0814776365897804}, {-4.578257463625154, -1.4758271494225457`, \
-0.026865533393664168`}, {-5.470041784917267, -1.4212150462264295`, 
       0.0814776365897804}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOXD2DAjc2c+AAkQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDq/UMU
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH76tLrP5KToAQYoUNaZ7P13xxp755lBW84aIMTz
ZJOM/qkutl/ko3krbYYImvhkewgPIZ7Qtvjfn5fxNnGbr6nOTBeGi+dA1O/f
m7bW2+i8EFw8F2L+fmmplsLTZghxRYh7MMSh7sQwB+rO/ej2Qt25H4c796D7
C+pOjHCAutMePdyg7sQQh4UnAIbCbzw=
       "], {{-5.446489549934516, -0.45, 
       0.05609885737938949}, {-5.446489549934516, 0.45, 
       0.05609885737938949}, {-4.553510450065484, 
       0.45, -0.05609885737938949}, {-4.553510450065484, -0.45, \
-0.05609885737938949}, {-5.446489549934516, -0.45, 
       0.05609885737938949}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO7QVQtyfS584OJjDdHtSx/at9xNkpL7Nnv/hmLJ
nub3wge6naT5qvKe2UfaTRcUWTJp/42dPMcOfhc+4LaQl93W/DVUvGk/AxiI
HIDQH+wnC/05Xibov0fD7bOlHYfIgVj9yprElE/24RD19gE9z4prBEQO7Ir7
9OPQiS/2ERDz7Ssu3Vy7S0LkgHhfdqmK7nf7Zoh74OISUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw6EHGg5Qd+6HhdslaLhB3bkfV3gCAPXvm6U=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGYRivsy/YToAZGXOvz+Cu/tt7y4dDhhz2p7Jp4p
vqkGogd43Yrj72e9t6/88PD61NpF9oxsp5YZzRA5wL545/r8rTDxSfYMYCBy
AEJ/sD8xoULI/2Kczf+fppFn04UP1Oopa3iofrAvh6jf/+9z9qZZ54UO/Ixx
C5jg9cG+AmL+/r9vF3JnmAsdKOvOrLiR/8F+E8Q9+/+giUPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz0zWrhB3WmPKzwBV+GyiA==
       "], {{-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}, {-5.470041784917267, 
       1.4212150462264295`, 0.0814776365897804}, {-4.578257463625154, 
       1.4758271494225457`, -0.026865533393664168`}, {-4.529958215082733, 
       0.5787849537735706, -0.0814776365897804}, {-5.421742536374846, 
       0.5241728505774544, 0.026865533393664168`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb6lBt+4ZzwAYePt3jXP/lhb2lcIz1j1ur9hQvn
9ZveFz6g9W1inLzzb/tLZ4KEBNIX7d8ZcP74rPfCB0R/e6zvX/gXKj5pPwMY
iByA0AwOMaH3i4+ujtvjvt7AIlVA5EBpU7SGhT6jwwWIevv+uMSCUwoiB16z
bA8oiGNyuAgx3/4a76QV+oYiBxLahSpX9DI7mEPcgyEOdSeGOVB32qPbC3Wn
PQ532sD8JQb1F9Sd8HDQhoYD1J370cMN6k4McVh4AgAZpptG
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5xQNj8+DHRA2lyKvbayv/tLdddurbv8gp7VW3e
Kn190QMzM3Prj+f8t1cv6Xmi2bvAfvJUtr3Tp4scOLtl2/7kbTDxCfYMYCBy
AEIzOLwSe1XzYWq0TW7WT6eMDOEDs5aqKJxTYXBQhajff/vKp9YLF4QOGHt7
OszxZHBQg5i/38P+zQkLS6EDZz/kJmTlMTiYQ9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBt0Oj6g==
       "], {{-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}, {-5.492152685637519, 
       2.390255157969315, 0.10240432460654149`}, {-4.60391404469854, 
       2.498082827790333, 0.005423345214476072}, {-4.507847314362481, 
       1.6097448420306848`, -0.10240432460654149`}, {-5.39608595530146, 
       1.5019171722096671`, -0.005423345214476072}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO5TVXn7aJvwgXO7pixb0sDiwDylNLbfdcv++Lzc
z47nhQ/cv8ibL7Ga1WGD1KeLmeyr9+tv3/ZzwXPhA+9ftJn3XGWDis/ezwAG
IgcgNIfD8wOeLbptaXsueniyxUuIHBAUrzxRrMXpsBai3n7hxEk8+wxEDijq
fZrwPITLYT3EfPuiW7eFZD1FDhi5ZkdG13M7MEHcgyEOdSeGOVB32qPbC3Wn
PQ532qD7C+pOjHCAunM/erhB3YkhDgtPAPxcm8c=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBYu+yBy8bDogYRgkdbLsewOTpPCuv+pLLHnWfKV
10xX9MBU8x0RjyazO0RJyPH/uz3Lnu3SL7bZ00QOnJaO0fl4EibeZc8ABiIH
IDSHw/zMd4n/EsNsfumy/kzJFD5g+mTxZT4zDodwiPr9X6K5Pp28JHQg+4T7
ctkcDocIiPn733Xyv9azETqwYM3rKp1FHA6OEPfsf4smDnUnhjlQd+5Htxfq
zv043LkH3V9Qd2KEA9Sd9kJo4QZ1pz2u8AQAVVKYpQ==
       "], {{-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}, {-5.512627240987176, 
       3.3579995520295336`, 0.11853114588381125`}, {-4.630172698490326, 
       3.5163723553689374`, 0.03984165745559268}, {-4.487372759012824, 
       2.6420004479704664`, -0.11853114588381125`}, {-5.369827301509674, 
       2.4836276446310626`, -0.03984165745559268}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7RJ7tv+3zhA7+EfqtOmczjcL8jjvGZ8679s7cI
Xzm/X/jAMp4gyR3beR1esdqHzWzauN/3Fuer5/eFDwSzreS5c5sPKr5wPwMY
iByA0AIOBvH7+v/r5e7ZrPpNVEJB5MC1mtU/BScJOLyEqLdP9X6jbeAgcmDt
z7DPyiqCUPGN9hKFjxw9EkQONJcxvTXdJuhwF+IeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHdihAPUnfvRww3qTgxxWHgCAL+ynUU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7bzbX+zH7RAzu5v55/oMvvoCqncYL9ymz7yZs2
lnRoiR64yO5n+rqY30FKpKA1qneSvdfNCCuXqSIHXjAvn/V1J0y8yZ4BDEQO
QGgBhytlqfemvfaz2aa2/OjuLOEDPHVrjFiVBRwkIOr35/r6dZdfFTog8Sci
lctNwEESYv5+5ZKvAcYOQgeUq1hn8GcKOChD3IMhDnUnhjlQd+5Htxfqzv04
3LkH3V9Qd2KEA9Sd9ujhBnUnhjgsPAGKP47N
       "], {{-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}, {-5.531329884018523, 
       4.325341537419348, 0.12977456753339}, {-4.656721395899974, 
       4.5305386339279385`, 0.07542252897520049}, {-4.468670115981477, 
       3.6746584625806524`, -0.12977456753339}, {-5.343278604100026, 
       3.469461366072062, -0.07542252897520049}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM4qm7qvvlP4QNX7La6yoUIOzLGmd3zW79/vtiT5
yv8NwgeCvJRvZjwWcmCyOzepQ37rfuVLhq/qbwgf0Fw6MWdLoTBUfOl+BjAQ
OQClHdYYM6q6zyrcc1f3nGiDusiB61F5k737RBwYIOrtd0XP0WbwFzmwbusd
tekyog6MEPPtp3VmOTaUiRxoFfDe9WiVqAMDxD1w8TaoONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/bBwq4aGG9Sd+3GFJwBRVpSe
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII5bvHP+9V2iB3q0+s84NQo7VCYKnONZ0Wlvf6g6
y0pd9ADH8S13G1cLOyx7zWWyWarRXuGhrencySIHWpJvvTtwFSZeaM8ABiIH
oLSDyL09YVcbbWweyh06lZQjfKBmjqqgvZaIw1KI+v0HbVumHr0hdOCHhbdS
XQhMvHH/ohi3BA1XoQMlVwuM99aJOJRD3IMhDnUnhjlQd+5/gGYv1J37cbhz
jzyav6DuxAgHqDvt0cMN6k4McVh4AgAfYJdM
       "], {{-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}, {-5.548186796029076, 
       5.293111903257128, 0.1362961805347467}, {-4.683260466024471, 
       5.5406491418775605`, 0.11124105808568469`}, {-4.451813203970924, 
       4.706888096742872, -0.1362961805347467}, {-5.316739533975529, 
       4.4593508581224395`, -0.11124105808568469`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4Yy/7lcYXAgfvKbh9jVokeqGlk3Jnav99e8SXL
j+kBAgemHtL7ZisjemDl6tUXnLm22k8oYfrjrSFwwCtR/LdcnwhUfKk9AxgI
HIDQIgd4+Ptv9HYU2twX+82esZ7/wLZ5L1geFgofWA5Rv3+f7jf+C3H8B7Jt
L3Ieeix0YAXE/P1zXT6KW/DxH1C8s5NvcajQgSqIezDEoe7EMAfqzv3o9kLd
uR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBrdqOh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUPNP+6yfRwRby99eKr
ywrVBQ8EBu79cG218IF1gRPXOEiH2s+9mHV5x2SBAytXxFW8vgoTd7VnAAOB
AxBa5IDAEeWnW6cJ2hyL0Yrsu8F3IDx8YbuIlsiB1RD1+7t3hmyS2ch7YP06
J37NEJEDayHm7w8Uq+de3clzgI3tyTTbOpEDjRD37A9AE4e6E8McqDv3H0Wz
F+rO/TjcuQfdX1B32luhhQPUnfbo4QZ1J4Y4LDwBfGOi6w==
       
       "], {{-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}, {-4.314722153887294, -4.460348007608924, \
-0.12134946625710644`}, {-3.449163700929936, -4.706911647569121, \
-0.12521417370309038`}, {-3.685277846112706, -5.539651992391076, 
       0.12134946625710644`}, {-4.550836299070064, -5.293088352430879, 
       0.12521417370309038`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA42vzA7MEngwJxPD45f2Cp4QNzPZMN0k1325lWm
e7sdBQ7sXejQ+kBZ8MDue0oKqRUb7WX2zrp3VEHgwP2ABU4fJgpAxRfaM4CB
wAEY/VDW6sFf2Vybk62nnEr28R9wjttfJX+H78BOiPr9E7mntr6o4T/Qtqfu
q90O3gO7IObvj5oYfyLGmv/ASSm7grgpPAfEIO6Bi5+AikPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08AfqOk/Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj/+AgvJhye12E+1PdSTf
fqMleIDr5b9rNiX8Bxpvriv3/Ndmn3pkY27ZVIEDrSX12XK7YOJl9gxgIHAA
RjtsFbS01XS2MSufoyJ8le/AXleHUx+UBA7UQ9Tvz3ln4am2ivdAdXfDlIeu
AgcaIObvX5R6NdeynueAxcUDcZcyBA7IQ9yDIQ51J4Y5UHfuR7cX6s79ONy5
B91fUHdihAPUnfbo4QZ1J4Y4LDwB/I2ewA==
       
       "], {{-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}, {-4.341864306775701, -3.470080753685618, \
-0.08552419621584771}, {-3.466106818667752, -3.674810750402369, \
-0.11920580050090333`}, {-3.658135693224299, -4.529919246314382, 
       0.08552419621584771}, {-4.533893181332248, -4.3251892495976305`, 
       0.11920580050090333`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF72W9d9h5fAAaMP98Vv1XEfOHx2jiOb4xZ7yb/F
+hcMBQ6Uf7VPnRjCdSBa6OKaWMbV9r3/doq/kBA4sPvX/E0eWpxQ8dn2DGAg
cABCcxxY8CQiVbkxzeY5U88F/XP8B1xZE3y3X2U7EAFRv/8cq8TC+Dn8B7q4
DszKW816IBJi/v6tHEsK+7P4D5zjV3ih2shy4BDEPRjiUHfCzemEmgN15350
e6Hu3I/DnXvQ/QV1JzwcyqDhAHWnPXq4Qd2JIQ4LTwBENJ2Z
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9Hst+oKrogO/yH3PtrS2b
mQ/qCh7Yvtun89dk9gPLF141lvo92X7unIOND6YJHLgdu8zl70mYeLM9AxgI
HIDQHAcSNt65OnVZgM3RYzV/7C7xHVBdFLmbyYzjwFKI+v1dvT9/1C7hPeDp
srmMNYfjwDKI+fsDQsq+7injOZD3jMeIYxHHgQqIe/b7o4lD3YlhDtSd+9Ht
hbpzPw537kH3F9SdGOEAdac9erhB3YkhDgtPAFgJs7M=
       
       "], {{-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}, {-4.369053812165066, -2.4839433884236968`, \
-0.04984834375199349}, {-3.4850090079231695`, -2.642177776810767, \
-0.10838604463507687`}, {-3.630946187834934, -3.5160566115763032`, 
       0.04984834375199349}, {-4.5149909920768305`, -3.357822223189233, 
       0.10838604463507687`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP6Vx8fkYyRwwGf/45mZvcwHpiyon/lj9mr75V/i
GDsUBQ7cvTI9zS2O6UDygf8Cv9MX2QdXrWc4IiBwIP+Vt7GyPiNUfJI9AxgI
HIDQDAf8X4fI+K6Ns4nkXviv/B7/AWXtjJk7F/7dnwhRv3+zmNPf93v4D7iF
XTAqdv69Pwli/n4epce/02fzH8hstDij8/TH/kkQ92CIQ92JYQ7UnfvR7YW6
cz8Od+6B+SsP6i+oOzHCAepOe1i4eUPDDepOe1zhCQC0oq21
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/3x+men8N7YrH97gJz
xhv6ggf+MlaoH8j5v//yxEw1oYRZ9rE7ZjO8mS5w4B/DHuGEbTDxLnsGMBA4
AKEZDtzyW3tq569QG9f+E//UL/AdaPyv+O28CsOBixD1+7vlJv71X8B7gOm/
85v5ngwHLkHM339hbeSf8gKeA03/Uh/l5zEciIW4B0Mc6s79XWjmQN25H91e
qDv343DnHnR/Qd2JEQ5Qd9qjhxvUnRjisPAEAIcMpkw=
       
       "], {{-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}, {-4.3959655727217335`, -1.5020265855785278`, \
-0.01528868040643376}, {-3.505798282008966, -1.6098752655742845`, \
-0.09255999958932283}, {-3.6040344272782665`, -2.4979734144214722`, 
       0.01528868040643376}, {-4.494201717991034, -2.3901247344257155`, 
       0.09255999958932283}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC5JPMjtIylwIOyLsgez7vf9F7l/qPv/mW3vO007
9q6AwIEniw7dWnPiy/6H7AFHTVZMslc/PXVdHofAgaLAxNywlE9Q8SZ7BjAQ
OAChP+wvS2r9HC7hb7M588oipff8B2RjbVWDzV/vvw9Rvz/18gpX13v8Byx3
VXkty3u2/wHE/P0StrUv0s/yHwgT35H/c+nD/ech7oGLh0LFoe6Em2MBNQfq
zv0we2Wg9kLduR+HO/eg+wvqToxwgLrTHhZuodBwg7rTHld4AgAMeqjF
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7vn77NLlz3yDL7iJWd
hQqGggcO1l+N3Jf1fv8pj39yz6Pm2a+5csRiwgyBAw/2v9KJ3woT77NnAAOB
AxD6w/6g55dnHvCOtFkRVtZ3/xzfAYEFXZkBqh/2H4eo3x+w9o3M/rm8BxQc
RC8v8Pqw/wTE/P0/mJNXz8vhOaD/YL7Nx/wP+6dC3IMhDnUnhjlQd+5Htxfq
zv043LkH5q+HUH9B3YkRDlB32sPCbRE03KDutMcVngBF/rXf
       
       "], {{-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}, {-4.422258832323806, -0.5241808713787737, 
       0.01713579186011437}, {-3.5283328583537994`, -0.5788402128371133, \
-0.07179513331845389}, {-3.5777411676761943`, -1.4758191286212263`, \
-0.01713579186011437}, {-4.471667141646201, -1.4211597871628867`, 
       0.07179513331845389}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQOHD2DAjc2c+AAgQOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQC/ZULY
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHax4j8bdkrwAAMUHG/5UrTy+HJ7vZp4435DhPjW
6NnvHm6Zby++b/3M4zME0MT77SE8hPgBRZ05gjlRNpeaF5wpOMcHF98IUb9/
KbvjzIdzeOHimyHm7y/vfpgalM0DFz8KcQ+GONSdGOZA3bkf3V6oO/fjcOce
dH9B3YkRDlB32qOHG9SdGOKw8AQAllp+eA==
       "], {{-4.4475967445892515`, -0.45,
        0.04644517448674317}, {-4.4475967445892515`, 0.45, 
       0.04644517448674317}, {-3.552403255410748, 
       0.45, -0.04644517448674317}, {-3.552403255410748, -0.45, \
-0.04644517448674317}, {-4.4475967445892515`, -0.45, 
       0.04644517448674317}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJawrX2Rfpb/QKj4jvyfSx/aX+T+oe7/Z/b+1Msr
XF3v8R+w2FXltSzvmf1D9oCjJism7d+ceWWR0nv+AzKxtqrB5q+h4k37GcBA
4ACE/mBfltT6OVzCf4/66anr8jgEDhQFJuaGpXyyvw9Rb+87TTv2roDAgSeL
Dt1ac+KL/QOI+fYliQe5fSQFDoR+UfZg1v1ufx7iHrh4GFQc6k4Mc6DutEe3
F+pOexzutIH5SxbqL6g74eFgCQ0HqDv3w8ItDBpuUHfuxxWeAEtUo+I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGap81u14aTggYX2B9pkFd7bT99mF657ZJl9xMrO
QgVDwQMH669G7st6b3/K45/c86h59muuHLGYMEPgwIP9r3Tit8LE++wZwEDg
AIT+YB/0/PLMA96RNivCyvrun+M7ILCgKzNA9YP9cYj6/QFr38jsn8t7QMFB
9PICrw/2JyDm7//BnLx6Xg7PAf0H820+5n+wnwpxD4Y41J0Y5kDduR/dXqg7
9+Nw5x6Yvx5C/QV1J0Y4QN1pDwu3RdBwg7rTHld4AgAWM65f
       
       "], {{-4.422258832323806, 0.5241808713787737, 
       0.01713579186011437}, {-4.471667141646201, 1.4211597871628867`, 
       0.07179513331845389}, {-3.5777411676761943`, 
       1.4758191286212263`, -0.01713579186011437}, {-3.5283328583537994`, 
       0.5788402128371133, -0.07179513331845389}, {-4.422258832323806, 
       0.5241808713787737, 0.01713579186011437}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZRevw7fTb/gcxGizM6T3/YT1lQP/PH7NX7N4s5
/X2/h/+AW9gFo2Ln3/bJB/4L/E5ftD+Se+G/8nv8B5S1M2buXPgXKj5pPwMY
CByA0AwO/q9DZHzXxu0JrlrPcERA4EDeK29jZX1Gh0SIevvlX+IYOxQFDty9
Mj3NLY7JIQlivv2vPD4mHyOBA977H8/M7GV2mARxD1zcByoOdSeGOVB32sPs
zYfaC3WnPQ532qD7C+pOjHCAunM/erhB3YkhDgtPAO1TqEI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbQvMx45Ljggd9MJtYKyv/t43TPz+E9sdh+d4E5
4w19wQN/GSvUD+T8t788MVNNKGGWfeyO2Qxvpgsc+MewRzhhG0y8y54BDAQO
QGgGh1t+a0/t/BVq49p/4p/6Bb4Djf8Vv51XYXC4CFG/v1tu4l//BbwHmP47
v5nvyeBwCWL+/gtrI/+UF/AcaPqX+ig/j8EhFuIeDHGoO/d3oZkDded+dHuh
7tyPw5170P0FdSdGOEDdaY8eblB3YojDwhMAV0GezA==
       
       "], {{-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}, {-4.494201717991034, 
       2.3901247344257155`, 0.09255999958932283}, {-3.6040344272782665`, 
       2.4979734144214722`, 0.01528868040643376}, {-3.505798282008966, 
       1.6098752655742845`, -0.09255999958932283}, {-4.3959655727217335`, 
       1.5020265855785278`, -0.01528868040643376}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7KsaSwP4v/wDl+hReqjSwOh8/OcWRz3LL/HKvE
wvg5/Ac6uQ7MylvN6hAtdHFNLOPq/c+Zei7on+M/4Mqa4Lv9KhtUfPZ+BjAQ
OAChORwWPIlIVW5M29P7b6f4CwmBA7t/zd/kocXpEAFRby/5t1j/gqHAgbKv
9qkTQ7gcIiHm2y/7reu+w0vggNGH++K36rgdDkHcgyEOdSfcnHKoOVB32qPb
C3WnPQ532qD7C+pOeDh0QcMB6s796OEGdSeGOCw8AVQNlWA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5x1aV14RHBA5MkP5/9HsvuUFV0wHf5j7n21pbN
zAd1BQ9s3+3T+Wsyu8PyhVeNpX5Ptp8752Djg2kCB27HLnP5exIm3mzPAAYC
ByA0h0PCxjtXpy4LsDl6rOaP3SW+A6qLInczmXE4LIWo39/V+/NH7RLeA54u
m8tYczgclkHM3x8QUvZ1TxnPgbxnPEYcizgcKiDu2e+PJg51J4Y5UHfuR7cX
6s79ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBKD6sMw==
       "], {{-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}, {-4.5149909920768305`, 
       3.357822223189233, 0.10838604463507687`}, {-3.630946187834934, 
       3.5160566115763032`, 0.04984834375199349}, {-3.4850090079231695`, 
       2.642177776810767, -0.10838604463507687`}, {-4.369053812165066, 
       2.4839433884236968`, -0.04984834375199349}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmII6aGH8ixpr/wAkpu4K4KTwO4n4mG6ab7No/kXtq
64sa/gNte+q+2u3gddh9T0khtWLj/pOtp5xK9vEfcI7bXyV/hw8qvnA/AxgI
HIDSDg9lrR78lc3dI7N31r2jCgIH7gcscPowUcBhJ0S9vXmV6d5uR4EDexc6
tD5QFnTYBTHfPtj8wuzAJIEDcz49OH5hq6CDGMQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/fDwu0kNNyg7tyPKzwBhSqbwA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINb3FfVMPiB4oD+2zilaj99BQfmw5Ha7ifanOpJv
v9ESPMD18t81mxJ+h8ab68o9/7XZpx7ZmFs2VeBAa0l9ttwumHiZPQMYCByA
0g4OWwUtbTWdbczK56gIX+U7sNfV4dQHJQGHeoj6/TnvLDzVVvEeqO5umPLQ
VcChAWL+/kWpV3Mt63kOWFw8EHcpQ8BBHuIeDHGoOzHMgbpzP7q9UHfux+HO
Pej+groTIxyg7rRHDzeoOzHEYeEJAMzCl0A=
       "], {{-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}, {-4.533893181332248, 
       4.3251892495976305`, 0.11920580050090333`}, {-3.658135693224299, 
       4.529919246314382, 0.08552419621584771}, {-3.466106818667752, 
       3.674810750402369, -0.11920580050090333`}, {-4.341864306775701, 
       3.470080753685618, -0.08552419621584771}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ7r8lHcgo//gOKdnXyLQ4UcahoZd6b279+/T/cb
/4U4/gPZthc5Dz0Wcli5evUFZ66t+++L/WbPWM9/YNu8FywPC4Wh4kv3M4CB
wAEILeLAw99/o7ejcM+EEqY/3hoCB7wSxX/L9Yk4LIeot1d8yfJjeoDAgamH
9L7Zyog6rICYb78xlv3L4wqBA/eV3T7GrBJ1qIK4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAHIEmuU=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL5R4lCltVvwwK+f0pmHGoUdmn/dZHq4It7eevHV
ZYXqggcCA/d+uLZa2GFd4MQ1DtKh9nMvZl3eMVngwMoVcRWvr8LEXe0ZwEDg
AIQWcRA4ovx06zRBm2MxWpF9N/gOhIcvbBfREnFYDVG/v3tnyCaZjbwH1q9z
4tcMEXFYCzF/f6BYPffqTp4DbGxPptnWiTg0QtyzPwBNHOpODHOg7tx/FM1e
qDv343DnHnR/Qd1pb4UWDlB32qOHG9SdGOKw8AQATJibaw==
       
       "], {{-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}, {-4.550836299070064, 
       5.293088352430879, 0.12521417370309038`}, {-3.685277846112706, 
       5.539651992391076, 0.12134946625710644`}, {-3.449163700929936, 
       4.706911647569121, -0.12521417370309038`}, {-4.314722153887294, 
       4.460348007608924, -0.12134946625710644`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ7/si8+xvHgZkCvL+frhQ9IMHfz+SUsN+ec9ab
8zFLOA4IcsctfycteiAtPn7NtVdb7Fl9v6XrBXEc6GBdH/y9VwQqvsSeAQw4
DkBokQP155f0x+YV2vzexDnj4lr2AxW/AtZwFAkfSIGo3/89VdhgcTT7gfdf
FkYIPhE6kAoxf/8nCdkTJZzsB9Lff2KRChM6IAZxD4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBAADoqNh
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQPhHwIYj76t2k/y4nu
Wk5/rgNNTX5LQ9YIHzg2NY8lJqhyP9OTo/ta1DkPODouD9K6BhPP3M8ABhwH
ILTIAZVLbJHfJU33/JO2cqy+wXZg/76ItVc1RQ4chqi3/2Ne0vRtA+uButqN
UauDRQ4chZhv/yt43eHCTpYDNjZcHI21IgeCIO7BEIe6E8McqDvt0e2FutMe
hztt0P0FdSdGOEDduR893KDuxBCHhScAWr2f1g==
       
       "], {{-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}, {-3.312505755072035, -4.46152110262191, \
-0.13183561781754752`}, {-2.4467287942367104`, -4.706646159126566, \
-0.11328943868710814`}, {-2.687494244927965, -5.53847889737809, 
       0.13183561781754752`}, {-3.5532712057632896`, -5.293353840873434, 
       0.11328943868710814`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP545ofSjhMcB3okrWeUbBU8cFXsA8NPiV32CzsC
xC+0chyITVMXWKwseKA/5Wvo79SN9gEuK7hfOHEc0N8s3HFxogBUfKE9Axhw
HIDQAgemL3fu9/2fY7Nhd/gX8b3sBxbPvPE+5g7fgV6I+v3x5etf6FexH3Az
3nh/5w7eA30Q8/fzG7PfdTdnP/DyTOd5sak8By5D3AMXfwEVh7oTwxyoO/ej
2wt1534c7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDdFqzl
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwHGE6s+RXFXGHfkWRQ
Hx/GdeBOSIDqhRL+A6tvyS63YSqwdzGcsV9fm/NAntYKoYxdMPEEewYw4DgA
oQUOyIi3i6Wu07LZcy7d4cIVtgMnX63+dlpJ4MBKiPr9FXPPNyxYyXpg0tXw
t9NdBQ6sgpi/3zTH/GBBHcuB6APMT5IzBA78Ow52D4Y41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfao4cb1J0Y4rDwBADqD5zw
       
       "], {{-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}, {-3.3402540371688305`, -3.4708538614882167`, \
-0.09608097776553255}, {-2.4637310374127157`, -3.6747409669130344`, \
-0.10780612765928528`}, {-2.6597459628311695`, -4.529146138511783, 
       0.09608097776553255}, {-3.5362689625872843`, -4.325259033086965, 
       0.10780612765928528`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62WS9yzQyOA4/smmyS6rgPTJ+z5KKT8Rb7n+Ul
1idSOQ680VxT6xjCdeDUBYNDzO9X2f+13iX7xIjjwDeRa/sUtDih4rPsGcCA
4wCM/rtWo/xGYZoN8xHXR9Jn2Q9wvdZ0vH+V7cAJiPr97B3dR8xnsR8QuRbc
tG8164GTEPP3c/lcXBaczn5A7mDt4bmNLAemQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBXi+qQw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gP1L68vX3Lj0n2XCHO
fyNjuA7stfn+wXkK+4G/D8/Pn+3dac+6auE/HT3OA3Hzqn8onoKJV9ozgAHH
ARgdZKPLGi7iavM7NI7x8kW2A4sSW9jvmXIc+AVRv//b6j1MyxazHnA+zMG/
J5vjwB+I+fs/MkqzVJayHHiq0is2ayHHgRqIe/Z/QBOHuhPDHKg796PbC3Xn
fhzu3IPuL6g7McIB6k57frRwg7rTHld4AgAvILGg
       
       "], {{-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}, {-3.3680927955513313`, -2.484382010548441, \
-0.0603803181271666}, {-2.482812247597164, -2.642196372468562, \
-0.0974340437929547}, {-2.6319072044486687`, -3.515617989451559, 
       0.0603803181271666}, {-3.517187752402836, -3.357803627531438, 
       0.0974340437929547}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4M9/C6lsZxoPFS3AK9XuYDbm+uByhMXG0faGVw
p8+F40BYzxRR+TimAwYeT00PJCyy15CVyHNX4jig7Xaqi1+fESo+yZ4BDDgO
QGiGA34VlyMdFsbZ3Hj0fOKOu+wHVhVnv3qw8O9+PYj6/euPnlcu3M1+IOT5
tSsHnX/v14eYv799xfatmjPZD/yLctq/6OmP/S4Q98DF/0LFoe6EmxMMNQfq
zv3o9kLduR+HO/eg+wvqToxwgLrTHj3coO7EEIeFJwBnoag1
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/v/zlJ2d7n2Bz760E9
IccTuA7suxrw72fO//3LeHLr7+pNts/WdFuVbMB54H6Wxv+abTDxZnsGMOA4
AKEZDoiIctcf++FvM/XaztA559kOTDiV3XBQheHAEoj6/Zpri1dbzGc9oDj1
OkOzJ8OBpRDz9+9r1mW8msdyYGO8c6NLHsOB7xD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9Sd8HDYDw0HqDvt0cMN6k4McVh4AgAmcqfC
       
       "], {{-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}, {-3.3956693749101743`, -1.5022218105675396`, \
-0.025741404070748052`}, {-2.503903797978213, -1.6099050111530673`, \
-0.08194179651477952}, {-2.6043306250898257`, -2.49777818943246, 
       0.025741404070748052`}, {-3.496096202021787, -2.3900949888469327`, 
       0.08194179651477952}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO573ue4z5jjwIEg3y+Pdb7vn3K7wCH222x7Ltf4
a3VKHAcaeox/TD/xZf/O51+17JZMsm9dpJ9tL8hxwOGY5B/vlE9Q8SZ7BjDg
OAChP+w3bnL5tEfQ36Y69sKUA+/YDzQUn2HPMH+9fztE/f5vuxZoNt5lP8Dw
fAb/hbxn+3dAzN9fJFG4z/EMUH1UqrjFsof7J0PcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8ARi2tic=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff7T/t4CB4sXGg/b3W6
TUMy14FDASv47mW9379799aDYU7T7c9fNZY7YMh5IFEjhD1/K0y83Z4BDDgO
QOgP+wtkDn37lBhsY6h15qH9ObYD51+H1niofti/A6J+f1LIjMP1c1gPzL++
+scErw/7d0LM3z+5LmXp/iyWA3mHGUtv5n/YfwriHgxxqDsxzIG6cz+6vVB3
7sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBdsrFT
       
       "], {{-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}, {-3.4226114232035196`, -0.5242334257478558, 
       0.006764007855904815}, {-2.5268581199223967`, -0.5788474109204276, \
-0.06137799302847672}, {-2.5773885767964804`, -1.4757665742521442`, \
-0.006764007855904815}, {-3.4731418800776033`, -1.4211525890795724`, 
       0.06137799302847672}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgOHD2DAjc2c+AAjgOmBiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQBoNUJg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF6is01r4TTuAwxQ4NEaqnu2epF93olzhdkpXHDx
xJjjEwWXzrA3T3m+w9SIE028wx7C44CLByipLenrDLE5OVvC/dRZNrh4HET9
/snmhn1TZrPCxRMg5u+Puex5NS6TBS7uDnEPhjjUnfsnoZkDded+dHuh7tyP
w5170P0Fdad9Llo4QN1pjx5uUHdiiMPCEwDGkGug
       
       "], {{-3.44854958885624, -0.45, 
       0.03610078028101299}, {-3.44854958885624, 0.45, 
       0.03610078028101299}, {-2.55145041114376, 
       0.45, -0.03610078028101299}, {-2.55145041114376, -0.45, \
-0.03610078028101299}, {-3.44854958885624, -0.45, 
       0.03610078028101299}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6SKNzneIb9QENUqrjFsof2U24XOMR+m73/264F
mo132Q8wPJ/BfyHvmf3O51+17JZM2l8de2HKgXdA9cVn2DPMX0PFm/YzgAHH
AQj9wd64yeXTHkH/Pa2L9LPtBTkOOByT/OOd8sl+O0S9PZdr/LU6JY4DDT3G
P6af+GK/A2K+fd/zPsd9xhwHDgT5fnms891+MsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEACBnrXM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5tnB3lMJX7gHLlH1Ffhff2p308BA8WLrSftzrd
piGZ68ChgBV897Le2+/evfVgmNN0+/NXjeUOGHIeSNQIYc/fChNvt2cAA44D
EPqDfYHMoW+fEoNtDLXOPLQ/x3bg/OvQGg/VD/Y7IOr3J4XMOFw/h/XA/Our
f0zw+mC/E2L+/sl1KUv3Z7EcyDvMWHoz/4P9KYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnAC3nqdM=
       "], {{-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}, {-3.4731418800776033`, 
       1.4211525890795724`, 0.06137799302847672}, {-2.5773885767964804`, 
       1.4757665742521442`, -0.006764007855904815}, {-2.5268581199223967`, 
       0.5788474109204276, -0.06137799302847672}, {-3.4226114232035196`, 
       0.5242334257478558, 0.006764007855904815}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG5fsX2r5kz2A3+jnPYvevrD3u3N9QCFiav3rz96
XrlwN/uB4OfXrhx0/m1v4PHU9EDCov03Hj2fuOMu+4FVxdmvHiz8CxWftJ8B
DDgOQGgGB7+Ky5EOC+P2aMhK5LkrcRzQdjvVxa/P6KAHUW8faGVwp8+F40BY
zxRR+TgmB32I+faV4R5e19I4DjReilug18vs4AJxD4Y41J0Y5kDdaY9uL9Sd
9jjcaYPuL6g74eEQAg0HqDv3w8LtHzTcoO7cjys8Aa+lo7o=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHaqufRPayL3gXkOlX/LlP/b/5ykbO9zbI799aCe
kOMJXAf2XQ349zPnv/0yntz6u3qT7bM13VYlG3AeuJ+l8b9mG0y82Z4BDDgO
QGgGBxFR7vpjP/xtpl7bGTrnPNuBCaeyGw6qMDgsgajfr7m2eLXFfNYDilOv
MzR7MjgshZi/f1+zLuPVPJYDG+OdG13yGBy+Q9yDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHfCw2E/NByg7rRHDzeoOzHEYeEJAPaYoEI=
       
       "], {{-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}, {-3.496096202021787, 
       2.3900949888469327`, 0.08194179651477952}, {-2.6043306250898257`, 
       2.49777818943246, 0.025741404070748052`}, {-2.503903797978213, 
       1.6099050111530673`, -0.08194179651477952}, {-3.3956693749101743`, 
       1.5022218105675396`, -0.025741404070748052`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIObyubgsOJ39gNzB2sNzG1kcps9ZctHJeMt+9o7u
I+az2A+IXAtu2rea1eHUBYNDzO9X7Wc+4vpI+iz7Aa7Xmo73r7JBxWftZwAD
jgNQ2uHvWo3yG4Vpe/5a75J9YsRx4JvItX0KWpwOJyDq7X+Wl1ifSOU48EZz
Ta1jCJfDSYj59t8260WumcFx4JFdk01SHbfDNIh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+5HDzeoOzHEYeEJAHHOos0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb49+R3Wxf3AenbRS9T49gdal/e3r7lxyR7rhDn
v5ExXAf22nz/4DyF3eHvw/PzZ3t32rOuWvhPR4/zQNy86h+Kp2DilfYMYMBx
AEo7BNnosoaLuNr8Do1jvHyR7cCixBb2e6YcDr8g6vd/W72Hadli1gPOhzn4
92RzOPyBmL//I6M0S2Upy4GnKr1isxZyONRA3LP/A5o41J0Y5kDduR/dXqg7
9+Nw5x50f0HdiREOUHfa86OFG9Sd9rjCEwD/Rqog
       "], {{-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}, {-3.517187752402836, 
       3.357803627531438, 0.0974340437929547}, {-2.6319072044486687`, 
       3.515617989451559, 0.0603803181271666}, {-2.482812247597164, 
       2.642196372468562, -0.0974340437929547}, {-3.3680927955513313`, 
       2.484382010548441, -0.0603803181271666}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEG3MftfdnP3AizOd58Wm8jhcFfvA8FNi1/748vUv
9KvYD7gZb7y/cwevQ3/K19DfqRv3b9gd/kV8L/uBxTNvvI+5wwcVX7ifAQw4
DkBoAYfpy537ff/n7AlwWcH9wonjgP5m4Y6LEwUceiHq7Rd2BIhfaOU4EJum
LrBYWdChD2K+/cczP5R2nOA40CNpPaNkq6DDZYh7MMSh7sQwB+pOe3R7oe60
x+FOG3R/Qd2JEQ5Qd+6HhdtLaLhB3bkfV3gCANZ+pEI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID49+YRdfyP3Ac/6H+YW+vwODCfW/IpirrDvSDKo
jw/jOnAnJED1Qgm/w+pbssttmArsXQxn7NfX5jyQp7VCKGMXTDzBngEMOA5A
aAEHGfF2sdR1WjZ7zqU7XLjCduDkq9XfTisJOKyEqN9fMfd8w4KVrAcmXQ1/
O91VwGEVxPz9pjnmBwvqWA5EH2B+kpwh4PDvONg9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITALpElXA=
       "], {{-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}, {-3.5362689625872843`, 
       4.325259033086965, 0.10780612765928528`}, {-2.6597459628311695`, 
       4.529146138511783, 0.09608097776553255}, {-2.4637310374127157`, 
       3.6747409669130344`, -0.10780612765928528`}, {-3.3402540371688305`, 
       3.4708538614882167`, -0.09608097776553255}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4kIXuihJP9QPr7TyxSYUIOEvz9TE4J+/d/TxU2
WBzNfuD9l4URgk+EHNLi49dce7Vl/+9NnDMurmU/UPErYA1HkTBUfMl+BjDg
OAChRRzqzy/pj80r3MPq+y1dL4jjQAfr+uDvvSIOKRD19pyz3pyPWcJxQJA7
bvk7aVGHVIj59nzPH5l3f+M4MFOA9/fTlaIOYhD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAA9Zmrc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZbE2jTV8Z94Mjhr9/rmoQdQj4EMR/927Sf5UR3
Lac/14GmJr+lIWuEHY5NzWOJCarcz/Tk6L4Wdc4Djo7Lg7SuwcQz9zOAAccB
CC3ioHKJLfK7pOmef9JWjtU32A7s3xex9qqmiMNhiHr7P+YlTd82sB6oq90Y
tTpYxOEoxHz7X8HrDhd2shywseHiaKwVcQiCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAq8phW
       "], {{-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}, {-3.5532712057632896`, 
       5.293353840873434, 0.11328943868710814`}, {-2.687494244927965, 
       5.53847889737809, 0.13183561781754752`}, {-2.4467287942367104`, 
       4.706646159126566, -0.11328943868710814`}, {-3.312505755072035, 
       4.46152110262191, -0.13183561781754752`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ4gd9PG9jfDgcXcFt1NK0UPHAo8djFEfr891/4J
GnXLGQ4cYr8Qs0Za9IDOQ72Hvfu32LfGe4jsD2Y48JA5Q+9arwhUfIk9AwQc
gFAiB/zT/kzw9iq0+eaQf70x4v9++T/TL2oWCR/Qgqjf/7rx3jrmjf/22/3Q
Xxz8ROiANsT8/Q8P+ba1cv7bH/vleEltmNCB/RD3YIhD3YlhDtSd+9Hthbpz
Pw537kH3F9SdGOEAdad9P1q4Qd1pjys8AehjrlY=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUPLJc/4uq2bOr+M8WM
yTf9mA5Uu1SfYFwrfMBUawP75rs9+5/tbNiYo854wG6R7ZOGazDxmv0MEHAA
QokcuHZWyFCUz2OPSc+/OWob/+4/FHtIul5T5IARRL19hsRfS9+k3/tbd7eY
/wsSOWACMd9+zpLf14qFf+53l3QPrq0RObAM4h772WjiUHfap6OZA3WnPbq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAEkooqA=
       
       "], {{-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}, {-2.310075459334159, -4.462891124238714, \
-0.14271392748137285`}, {-1.4445737499249551`, -4.7060347804248615`, \
-0.10042972870477429`}, {-1.689924540665841, -5.537108875761286, 
       0.14271392748137285`}, {-2.555426250075045, -5.2939652195751385`, 
       0.10042972870477429`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Vybv9yBmGA/YB/xaqbBU8ULHLzvfgu532Nhs3
qzR3MByoNw05mKsseOC3Wr3xNc+N9vNuRE5ydGE4cEBq1YNtEwWg4gvtGSDg
AIQSOOAzrY4h9UKOzRE/n9s15f/3N55abTfpDt+BnxD1+zvmztj2892//UxT
w2tVdvIe+AUxf7/PmycTy9L+7W+OZ96zbSrPgTKIe+DiTVBxqDsxzIG6cz+6
vVB37sfhzj3o/oK6EyMcoO60Rw83qDsxxGHhCQBS1bE6
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgPnFq99Vf5rfL93Wse
PpgcxnTgBFuK38ZS/gM7+939vp7N3+92reCDpzbjgRRmo+U3dsHE4/czQMAB
CCVw4Mj3CWLfG7T2lAbLyees/Lvf71/amslKAge2QdTbv1pmY3cj6Pf+OX/O
Rqi7ChzYATHfPv5XVKzLnx/7X/0yYd2dLnDgJMQ9GOJQd2KYA3WnPbq9UHfa
43CnjSuav6DuxAgHqDv3o4cb1J0Y4rDwBABBeLcr
       
       "], {{-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}, {-2.3384267856882803`, -3.4718030810301665`, \
-0.10712294581215505`}, {-1.4616040559471155`, -3.674401807986821, \
-0.09547578114449966}, {-1.66157321431172, -4.528196918969834, 
       0.10712294581215505`}, {-2.5383959440528843`, -4.325598192013179, 
       0.09547578114449966}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6nOn/909kMB7Y41q/9Xst9QFammi1Daov9/sMi
pe/SGQ6c015V/CuY60CN6hKOB2dX2d9P7LL6bsxw4LnoVcu/mpxQ8Vn2DBBw
AEJxHLCRv7fRKizNxtHmdZfgjP/7JV9pHWO6xnagCqJ+f3PFNVFlg//7ja6E
9rCuYT1QDTF//5EtBxeYnPi332dfQxBHE8sBaYh7MMSh7sQwB+rO/ej2Qt25
H4c796D7C+pOjHCAutMePdyg7sQQh4UnANnAoq4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewHlk04O1/wVo39nCqR
vKcxTAey8u/Wn5jCfqAg4d5+bptiez9bru1FeowHtm5/Z59yCiaebM8AAQcg
FMcB9t+P5ePZDWxSWl9PlFr8d7+3h+CB2aYcB/Ig6vef4LqubOr2e/+0CUoN
5tkcB/Ih5u/XmXBoq//LH/sf3jB2uLyA48ASiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA8ayh1w==
       
       "], {{-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}, {-2.366917531924889, -2.4849645070759623`, \
-0.07148402475128206}, {-1.4808390979345027`, -2.642020364891229, \
-0.0855718330639844}, {-1.633082468075111, -3.5150354929240377`, 
       0.07148402475128206}, {-2.5191609020654973`, -3.357979635108771, 
       0.0855718330639844}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP62IuiPSCbDgYRVilE/e5gP+G1kCMktX22/pKDn
L68bw4HXx7In/o5lOmBaxmAxz3+RfZDFsX9sygwHSh9vPfFXjxEqPsmeAQIO
wOhwqbDYTS1xNjH9xUyfdv7fL2o5JY9l0d/9xhD1+3fIPWd5Uvx/v1aRxl0O
l9/7TSDm7xddF8V+Tff/fofVe7x5n/3Y7wtxD4Y41J0Y5kDduR/dXqg79+Nw
5x50f0HdiREOUHfao4cb1J0Y4rDwBAC52J69
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7v12H7V1ZoMtHeLyTX
Z1oi0wG/P/Z8zbn/9z/fFOQ5/UObvfoqM7XTBowH1P/Jtx/cBhMvs2eAgAMw
OuvVkfTLss42m1dP2pw57+/+NwwFNvNVGA48gajfnxqumn7Z5vf+m4wPKuw8
GQ48hZi/X4J5h5Tt7R/7jzIFbL2by3BAG+IeDHGoOzHMgbpz/yY0e6Hu3I/D
nXvQ/QV1p70vWjhA3WmPHm5Qd2KIw8ITADZMq2Y=
       
       "], {{-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}, {-2.395165371281734, -1.502519492476819, \
-0.03684391366627121}, {-1.5022155123688876`, -1.609810554839941, \
-0.07044714869685079}, {-1.604834628718266, -2.497480507523181, 
       0.03684391366627121}, {-2.4977844876311126`, -2.390189445160059, 
       0.07044714869685079}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPYT3e371IThwKoTn1OP63zf/9XlQ1b/w9n2ncnq
nc7KDAeOtS5613Liy/6fugvmxE+bZH904+QjCwUZDjx2Cix3SvkEFW+yZ4CA
AxDqw/55PglR83/52ZTPuVG2587//VZVsYLV5q/3f4eo3//WYuPbip3/95d8
2aX0Le/Z/h8Q8/enXO1MMZ32f/+6PAmTwmUP93+GuAcuvgYqDnUn3JxiqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwWwkNN6g77XGFJwB/9sFU
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7zfn6Vy8W1k8XT7RYLH
uapSmA5M+CfF7Jv9fv+T1oPPy1367S92JLPaGjEe8KjvbVy2FSZeb88AAQcg
1If9k96ffp3M52UT/87ia+vsv/tjHCz366h+2P8Aon7/3juFr7jNf+/f0VBU
F+n1Yf8jiPn7ZU6vuj/x0o/9IgdX27blf9ifAXEPhjjUnRjmQN25Pw7NXqg7
9+Nw5x50f0Hdab8QLRyg7rRHDzeoOzHEYeEJAGNTuuo=
       
       "], {{-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}, {-2.422763365772555, -0.5243400200337339, \
-0.004326663743797126}, {-1.525580660274528, -0.5787952829846525, \
-0.05012859920712154}, {-1.5772366342274449`, -1.4756599799662662`, 
       0.004326663743797126}, {-2.474419339725472, -1.4212047170153475`, 
       0.05012859920712154}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjg4cPYMCNzZz4AKDpgYg8BlHOKHMcQh1IQ96OJG
EPX26OLGEPMxxE9D3IMhfhaHuAkOc0xw2At1pw0Od2L4yxhHOJzGEW7o4QkA
EQVB6A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM5PP/hcdwbzAQYoaDh+9Xzb5Jn2X12uvS9OZYKL
M7b2dbHwTrSvUnr9facRI5p4oz2UCxdnMJ4xkT3bx4Znt6ZAz6y/+2HC/1vA
6veLlwUrSJj+hoszQMzfr2RYa7Dk/A+4eB3EPRjiUHfuF0MzB+rO/dxo9kLd
CeOju3MPur+g7sQIB6g77dHDDepODHFYeAIAnIBtHA==
       
       "], {{-2.4493063074013928`, -0.45, 
       0.024976831851240444`}, {-2.4493063074013928`, 0.45, 
       0.024976831851240444`}, {-1.5506936925986072`, 
       0.45, -0.024976831851240444`}, {-1.5506936925986072`, -0.45, \
-0.024976831851240444`}, {-2.4493063074013928`, -0.45, 
       0.024976831851240444`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE652pliOu3//jV5EiaFyx7af3X5kNX/cPb+txYb
31bs/L+/+MsupW95z+x/6i6YEz9t0v7yOTfK9tz5v9+qKlaw2vw1VLxpPwME
HIBQH+zn+SREzf/lt+foxslHFgoyHHjsFFjulPLJ/jtEvX1nsnqnszLDgWOt
i961nPhi/wNivr2f6G7fpyYMB1ae+Jx6XOe7/WeIe+Diq6DiUHdimAN1pz26
vVB32uNwpw26v6DuhIdDCTQcoO7cDwu3ddBwg7pzP67wBACrErpp
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC6apSWwfRrzgRu1K1o+K7y3z1K5+DayeLr9IsHj
XFUpTAcm/JNi9s1+b/+k9eDzcpd++4sdyay2RowHPOp7G5dthYnX2zNAwAEI
9cF+0vvTr5P5vGzi31l8bZ39d3+Mg+V+HdUP9g8g6vfvvVP4itv89/4dDUV1
kV4f7B9BzN8vc3rV/YmXfuwXObjati3/g30GxD0Y4lB3YpgDdef+ODR7oe7c
j8Ode9D9BXWn/UK0cIC60x493KDuxBCHhScAM4izag==
       "], {{-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}, {-2.474419339725472, 
       1.4212047170153475`, 0.05012859920712154}, {-1.5772366342274449`, 
       1.4756599799662662`, 0.004326663743797126}, {-1.525580660274528, 
       0.5787952829846525, -0.05012859920712154}, {-2.422763365772555, 
       0.5243400200337339, -0.004326663743797126}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBZdF8V+Tff/fofVe7x5n/2w99vIEJJbvnr/Drnn
LE+K/+/XKtK4y+Hy2960jMFinv+i/TH9xUyfdv7fL2o5JY9l0V+o+KT9DBBw
AEo7hEuFxW5qidsTZHHsH5syw4HSx1tP/NVjdDCGqLdfUtDzl9eN4cDrY9kT
f8cyOZhAzLf/tiLoj0gmw4GEVYpRP3uYHXwh7sEQh7oTwxyoO+3R7YW60x6H
O23Q/QV1J0Y4QN25Hz3coO7EEIeFJwDbRJhI
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC75t7gocRLzgbJf8VNdVP7b67D9Kys0mWjvF5Lr
My2R6YDfH3u+5tz/9s83BXlO/9Bmr77KTO20AeMB9X/y7Qe3wcTL7Bkg4ACU
dsh6dST9sqyzzebVkzZnzvu7/w1Dgc18FQaHJxD1+1PDVdMv2/zef5PxQYWd
J4PDU4j5+yWYd0jZ3v6x/yhTwNa7uQwO2hD3YIhD3YlhDtSd+zeh2Qt1534c
7tyD7i+oO+190cIB6k579HCDuhNDHBaeAAaBo+Y=
       "], {{-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}, {-2.4977844876311126`, 
       2.390189445160059, 0.07044714869685079}, {-1.604834628718266, 
       2.497480507523181, 0.03684391366627121}, {-1.5022155123688876`, 
       1.609810554839941, -0.07044714869685079}, {-2.395165371281734, 
       1.502519492476819, -0.03684391366627121}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6y5eACkxP/9vvsawjiaGJxkJWpZsuQ2rK/ueKa
qLLB//1GV0J7WNewOtSoLuF4cHbVfkeb112CM/7vl3yldYzpGhtUfNZ+Bgg4
AKE4HGzk7220Ckvbcz+xy+q7McOB56JXLf9qcjpUQdTb7z8sUvouneHAOe1V
xb+CuRyqIebbz1Odv/7pbIYDWxzr136v5XaQhrgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4ACOubuQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH61XU41opv5gLz6mf068ewOyyacnS94q8Z+TpVI
3tMYpgNZ+XfrT0xhdyhIuLef26bY3s+Wa3uRHuOBrdvf2aecgokn2zNAwAEI
xeHA/vuxfDy7gU1K6+uJUov/7vf2EDww25TDIQ+ifv8JruvKpm6/90+boNRg
ns3hkA8xf7/OhENb/V/+2P/whrHD5QUcDksg7sEQh7oTwxyoO/ej2wt1534c
7tyD7i+oOzHCAepOe/Rwg7oTQxwWngDB4ZpX
       "], {{-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}, {-2.5191609020654973`, 
       3.357979635108771, 0.0855718330639844}, {-1.633082468075111, 
       3.5150354929240377`, 0.07148402475128206}, {-1.4808390979345027`, 
       2.642020364891229, -0.0855718330639844}, {-2.366917531924889, 
       2.4849645070759623`, -0.07148402475128206}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZ582RiWdq//U3xzHu2TeVxqNhl53vw3c79HXNn
bPv57t9+pqnhtSo7eR1+q9UbX/PcuP+In8/tmvL/+xtPrbabdIcPKr5wPwME
HIBQAg4+0+oYUi/k7Jl3I3KSowvDgQNSqx5smyjg8BOi3t5m42aV5g6GA/Wm
IQdzlQUdfkHMt7/Vybv9yBmGA/YB/xaqbBV0KIO4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+WLg1Q8MN6s79uMITAIPwqug=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7QFHTxbiPzAR2uaV87DfgdTq3e+qv8Vvn+7jUP
H0wOYzpwgi3Fb2Mpv8POfne/r2fz97tdK/jgqc14IIXZaPmNXTDx+P0MEHAA
Qgk4HPk+Qex7g9ae0mA5+ZyVf/f7/UtbM1lJwGEbRL39q2U2djeCfu+f8+ds
hLqrgMMOiPn28b+iYl3+/Nj/6pcJ6+50AYeTEPdgiEPdiWEO1J326PZC3WmP
w502rmj+groTIxyg7tyPHm5Qd2KIw8ITABGtr6s=
       "], {{-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}, {-2.5383959440528843`, 
       4.325598192013179, 0.09547578114449966}, {-1.66157321431172, 
       4.528196918969834, 0.10712294581215505`}, {-1.4616040559471155`, 
       3.674401807986821, -0.09547578114449966}, {-2.3384267856882803`, 
       3.4718030810301665`, -0.10712294581215505`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH54yLetlfPf/tgvx0tqw4QcDgUeuxgiv3//68Z7
65g3/ttv90N/cfATIQedh3oPe/dv2f/NIf96Y8T//fJ/pl/ULBKGii/ZzwAB
ByCUiIN/2p8J3l6Fe1rjPUT2BzMceMicoXetV8RBC6Lenmv/BI265QwHDrFf
iFkjLeqgDTHfvl/upo3tb4YDi7ktuptWijrsh7jHfgKaONSdGOZA3WmPbi/U
nfY43GmD7i+oOzHCAerO/ejhBnUnhjgsPAEuVakc
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN6k2yTiVsZ8YOezHWuamoUdlssfcXVbNnX/mWLG
5Jt+TAeqXapPMK4VdjDV2sC++W7P/mc7GzbmqDMesFtk+6ThGky8Zj8DBByA
UCIO184KGYryeewx6fk3R23j3/2HYg9J12uKOBhB1NtnSPy19E36vb91d4v5
vyARBxOI+fZzlvy+Viz8c7+7pHtwbY2IwzKIe+xno4lD3WmfjmYO1J326PZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAGV2bIA==
       "], {{-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}, {-2.555426250075045, 
       5.2939652195751385`, 0.10042972870477429`}, {-1.689924540665841, 
       5.537108875761286, 0.14271392748137285`}, {-1.4445737499249551`, 
       4.7060347804248615`, -0.10042972870477429`}, {-2.310075459334159, 
       4.462891124238714, -0.14271392748137285`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILY7HuAx6//H/bt/6fJbrBQ9sHvTFambJ/fZ1+t3
twqGftx/KfDklipp0QN1Z3r3TGjbYr9/+tFDHas+7H+5IiVqb68IVHyJPQMY
fNgPoUUOZGiVfTorVWjTeKGk6t2qd/vFw2cvdSoSPlADUb+feeHLL3dC3+7X
W2fm3fpE6EAtxPz9LYVx+acZ3ux3Zb304XiY0IGdEPdgiEPdiWEO1J370e2F
unM/DnfuQfcX1J0Y4QB1pz16uEHdiSEOC08A8orAVQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBE+IJHY67/dZeF+yS0v
VjTP+bL/3AnevU/XCh9Q1Enf78k2fT9vVMkVR79P+9OftN37dA0m3r6fAQw+
QGmRA0eXNMi/0A/e89xbPLwm+fX+mdKViryaIgfkIOrtz03XW/fj2LP9Ruaf
nKSCRA7IQ8y33/bYlbVU69H+00HZKerVIgfEIe6x34omDnUnhjlQd9qj2wt1
pz0Od9rwoPkL6k6McIC6c78qWrhB3bkfV3gCAENxo/8=
       
       "], {{-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}, {-1.3074142524896448`, -4.464479631202829, \
-0.15399484397074759`}, {-0.44277975827814153`, -4.705014545315876, \
-0.08654007014229913}, {-0.6925857475103553, -5.535520368797171, 
       0.15399484397074759`}, {-1.5572202417218586`, -5.294985454684124, 
       0.08654007014229913}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEM29o6Js4cf9botU9jzZInggNvzI34zNO+23xqj+
9hP7uF8/R0LDWVnwwKsnTf9clTbaR62bVKve/WG/uBnPlIUTBaDiC+0ZwODD
fggtcKClVn9FSV+OjffiWywbX77bf3Hy8+t77vAdeAFRv3+621bOpMtv9y9S
P7++cifvgZcQ8/c/etnPJ7z3zf6S3dvazabxHIiBuAcuXgwVh7pz/zQ0c6Du
3I9uL9Sd+3G4cw+6v6DuxAgHqDvt0cMN6k4McVh4AgBFtrmQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPEf8LydbSqxc9J+k+hP
t0+u+bL/5gvuC2/L+A8kqTz9eOpbx/5Zuj/fpoR92p/zhfVF2W6YeMV+BjD4
AKUFDgTOeym38qzLnjNLeFXMgl/vP8X6t9tFSeBAAkS9/QxPaY+cZc/2T+H+
Jd7pInAgEWK+fdo7jZxFPx/ujxX8vvhsmsABD4h77FPRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3YkRDlB37j+LFm5Qd+7HFZ4Atma6Pw==
       
       "], {{-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}, {-1.3363574191970282`, -3.4729523642627917`, \
-0.11867803594150737`}, {-0.45980333298826614`, -3.6737400266827285`, \
-0.08210962647842927}, {-0.6636425808029717, -4.527047635737208, 
       0.11867803594150737`}, {-1.5401966670117337`, -4.3262599733172715`, 
       0.08210962647842927}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC7WVEtXsfu4/94FZeH5tdwHuG6I/4r5stl+kfQR
F4krH/ZPeSCetD+Y60By6alFarNX2V/kTVLiyfqw3+sD98b7mpxQ8Vn2DGDw
YT+E5jigvn1F+1ftNJu4J9a7n2u/37+N/4ufwjW2AwkQ9fv3nigvOx/+bn+O
/Iu5DmtYDyRBzN8vvXaz4fbmt/uV9O+8SWhiOcABcQ+GONSd+/egmQN15350
e6Hu3I/DnXvQ/QV1J0Y4QN1pX4QWblB32uMKTwDIp64Z
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBPYD9/9sLtfvKt3/6Hnf
VeVdX/ZrXStJnTyV/YB2oKuX/Y6c/R+Lj78SjP20XzR716aTp2DiMfsZwOAD
lOY48EOiP+P+O/U98hKFWndcX+9/PcXV18yU44AGRL29ncGjkB3dz/Zf0+ye
lZPFcUATYr59nEdw/ZSLD/cf2Hfh+aL5HAfuQdxjH4MmDnWnvS2aOVB32suh
2Qt1pz0Od9p8QPMX1J37H6KFA9Sd+y+ihRvUnftxhScAOA2p7A==
       
       "], {{-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}, {-1.3654950603405707`, -2.485713996326056, \
-0.08320617339913328}, {-0.4791620690881889, -2.641608869101888, \
-0.07268869937669903}, {-0.6345049396594293, -3.514286003673944, 
       0.08320617339913328}, {-1.520837930911811, -3.358391130898112, 
       0.07268869937669903}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5/Nyh+1rUP+9dttv16uof5QABHpPAD79X2oS8f
ThHs/7C/REnT724s04GHUdZJU40W2a/6UnCqw/3DfquJIsvf6TFCxSfZM4DB
h/0QmuHA6TdJfn4hcTarxeSy3xW8399z99pGpUV/99+HqN8frmtz7c7Dd/sl
d69NdnX5vf8BxPz9TC5RjqeD3u1fOqNFNOPZj/3+EPdgiEPdCTdHAmoO1J37
0e2FunM/DnfuQfcX1J0Y4QB1pz0s3NZCww3qTntc4QkAh1iyzg==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/vv85f67WOt9je7tGS
ZJEjX/Zrqr4Lyc77v19e9A/v5PRMe/nCS4ZcSZ/2TxEqX2W6HSYeac8ABh/2
Q2iGAzMFg8yWaqvaHJKNnvPa+vX+bWVHtFJVGA7IQNTvb7HeZnG9/Nn+nLcd
oac8GA7IQczf7xYpePXQ5of7FVN8G/RzGQ5chbhnvyuaONSd+5vRzIG6cz+6
vVB37sfhzj0wf02F+gvqToxwgLrTPhYt3KDutMcVngDY0aCt
       
       "], {{-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}, {-1.3944131960809822`, -1.502938348477095, \
-0.0486615386368611}, {-0.5008001745126557, -1.609564863601969, \
-0.057964976488012875`}, {-0.6055868039190176, -2.497061651522905, 
       0.0486615386368611}, {-1.4991998254873442`, -2.3904351363980307`, 
       0.057964976488012875`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDbT+zZBOOfDfmnmJXvW6Xzf/9lQk+nYrtn2VSf9
uHk9Puzfu+ZQbcmJL/t/nC5gbKmZZL83ZXkrm8qH/XFhD+2sUj5BxZvsGcDg
w34Y/TFYcG3beT+bNrONXz5tf7/fJdi2qdv89f5vEPX7eXOTXj7Nf7+/fVkV
i3j+s/3fIebvn7xY+N4N9ff7z/zc3rZo2cP9HyHugYufgopD3Qk3pw1qDtSd
+2H2OkPthbpzPw537kH3F9Sd8HDYAw0HqDvtYeEmBQ03qDvtcYUnADNouvs=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr3f/3C70btYuzb7RxrV
z8xOfdm/oPLLfemc9/t1vs6wrV1Ra184xbZYOvXT/gs2v97zboOJ59ozgMGH
/TB6ieIqDuHtFjZy11skT5q+3j/jIRPHT5UP+zUh6vfbrOM0npT9bL/BYVaB
T54f9mtDzN8f1drnE73w4f4TSzgkXud92H8f4p79kWjiUHfut0YzB+rO/ej2
Qt25H4c796D7C+pOjHCAutM+GC3coO60xxWeAOT6uVI=
       
       "], {{-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}, {-1.4226672975718835`, -0.524511498680574, \
-0.0162185287953971}, {-0.524561007755691, -0.5786708421747833, \
-0.03794081469881218}, {-0.5773327024281165, -1.4754885013194259`, 
       0.0162185287953971}, {-1.475438992244309, -1.4213291578252167`, 
       0.03794081469881218}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4sP/sGRC4s58BBXzYb2IMApdxiB/GEIfQE/ag
ixtB1NujixtDzMcQPw1xD4b4WRziJjjMMcFhL9SdNjjcieEvYxzhcBpHuKGH
JwA+ZE/p
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5SjP2SZ/R9PwMUrA1XZdk2ucveXMzuh+eZL3Dx
Equ8tee2N9rLcMv/UUn7hCZeaA/hfYCLH9i2/fTadlubUy8Psm8zfg0XL4Ko
3z/pcjN/TvozuHgxxPz9MXtdxZVmP4SLr4a4B0Mc6k4Mc6Du3H8SzV6oO/fj
cOceaTR/Qd2JEQ5Qd9qjhxvUnRjisPAEAG+9eME=
       
       "], {{-1.4498128457508597`, -0.45, 
       0.012977048875352748`}, {-1.4498128457508597`, 0.45, 
       0.012977048875352748`}, {-0.5501871542491403, 
       0.45, -0.012977048875352748`}, {-0.5501871542491403, -0.45, \
-0.012977048875352748`}, {-1.4498128457508597`, -0.45, 
       0.012977048875352748`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ68WPjeDfX3+0/93N62aNlD+8+GmkzHds3ez5ub
9PJp/vv9bcuqWMTzn9n/OF3A2FIzaX+b2cYvn7a/3+8cbNvUbf4aKt60nwEM
PsBo+4/Bgmvbzvvt2ZuyvJVN5cP+uLCHdlYpn+y/QdTbV5304+b1+LB/z5pD
tSUnvth/h5hvb6b3bYJwzof9UsxL9qzT+W7/EeIeuLg0VBzqTrg5e6HmQN1p
j24v1J32ONxpA/OXC9RfUHfCw6EdGg5Qd+6HhdsZaLhB3bkfV3gCAH/3tpE=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7ZuyMySP/7/oJt785rKr23f7jd6F2sXZv9I43q
Z2anvuxfUPnlvnTOe3udrzNsa1fU2hdOsS2WTv20/4LNr/e822DiufYMYPBh
P5S2X6K4ikN4u4WN3PUWyZOmr/fPeMjE8VPlg70mRP1+m3WcxpOyn+03OMwq
8Mnzg702xPz9Ua19PtELH+4/sYRD4nXeB/v7EPfsj0QTh7pzvzWaOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J32wWjhBnWnPa7wBAC1L7HS
       
       "], {{-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}, {-1.475438992244309, 
       1.4213291578252167`, 0.03794081469881218}, {-0.5773327024281165, 
       1.4754885013194259`, 0.0162185287953971}, {-0.524561007755691, 
       0.5786708421747833, -0.03794081469881218}, {-1.4226672975718835`, 
       0.524511498680574, -0.0162185287953971}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGZyiXI8HfRu/9IZLaIZz37YB3BECj/wXr0/XNfm
2p2H7/ZL7F6b7Ory2/5hlHXSVKNF+1eLyWW/K3i/v+futY1Ki/5CxSftZwCD
D1CaweH0myQ/v5C4Pau+FJzqcP+w32qiyPJ3eowO9yHq7UNfPpwi2P9hf4mS
pt/dWCaHBxDz7f/fDYqfde3D/rWbbb+e7mF28Ie4By6+DioOdSeGOVB32qPb
C3WnPQ532qD7C+pOeDhIQsMB6s796OEGdSeGOCw8AXyEqfs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII4LLp8qp/Z9/z7z1P8LVP/bX+ev9VrHW2xv92hJ
ssiRL/s1Vd+FZOf9t5cX/cM7OT3TXr7wkiFX0qf9U4TKV5luh4lH2jOAwYf9
EJrBYaZgkNlSbVWbQ7LRc15bv96/reyIVqoKg4MMRP3+FuttFtfLn+3PedsR
esqDwUEOYv5+t0jBq4c2P9yvmOLboJ/L4HAV4p79rmjiUHfub0YzB+rO/ej2
Qt25H4c798D8NRXqL6g7McIB6k77WLRwg7rTHld4AgCpBpkt
       
       "], {{-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}, {-1.4991998254873442`, 
       2.3904351363980307`, 0.057964976488012875`}, {-0.6055868039190176, 
       2.497061651522905, 0.0486615386368611}, {-0.5008001745126557, 
       1.609564863601969, -0.057964976488012875`}, {-1.3944131960809822`, 
       1.502938348477095, -0.0486615386368611}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZeu9lwe/Pb/Ur6d94kNLE4cN0Q/xXzZfP+PSfK
y86Hv9ufI/9irsMaVofk0lOL1Gav2h/3xHr3c+33+7fxf/FTuMYGFZ+1nwEM
PkBpDgf17Svav2qn7bnIm6TEk/Vhv9cH7o33NTkdEiDq7RdJH3GRuPJh/5QH
4kn7g7kckiDm2xdpqqWr2H3cf++CsvD8Wm4HDoh77IvRxKHuxDAH6k57dHuh
7rTH4U4bdH9B3bl/L1o4QN25Hz3coO7EEIeFJwAEq6hk
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL4UHXbAVPz7fgdHfYnYBHaH+382l+t3le5/9Lzv
qvKuL/u1rpWkTp7K7qAd6OplvyNn/8fi468EYz/tF83etenkKZh4zH4GMPgA
pTkcfkj0Z9x/p75HXqJQ647r6/2vp7j6mplyOGhA1NvbGTwK2dH9bP81ze5Z
OVkcDpoQ8+3jPILrp1x8uP/AvgvPF83ncLgHcY99DJo41J32tmjmQN1pL4dm
L9Sd9jjcafMBzV9Qd+5/iBYOUHfuv4gWblB37scVngAIQqJs
       
       "], {{-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}, {-1.520837930911811, 
       3.358391130898112, 0.07268869937669903}, {-0.6345049396594293, 
       3.514286003673944, 0.08320617339913328}, {-0.4791620690881889, 
       2.641608869101888, -0.07268869937669903}, {-1.3654950603405707`, 
       2.485713996326056, -0.08320617339913328}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH70sp9PeO+b/cW7t7WbTeNxiA0/8jdj887909y2
ciZdfrt/kfr59ZU7eR1ePWn656q0cb/34lssG1++239x8vPre+7wQcUX7mcA
gw9QWsChpVZ/RUlfzp6odZNq1bs/7Bc345mycKKAwwuIevutMaq//cQ+7tfP
kdBwVhZ0eAkx356fe0dF2cKP+90Wqex5skXQIQbiHgxxqDsxzIG60x7dXqg7
7XG40wbdX1B37p+OFg5Qd+6HhVsJNNyg7tyPKzwBfomzNA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7X8fqkHvP3/a53BXekGPE7eN7ONpXYOWm/SfSn
2yfXfNl/8wX3hbdl/A5JKk8/nvrWsX+W7s+3KWGf9ud8YX1RthsmXrGfAQw+
QGkBh8B5L+VWnnXZc2YJr4pZ8Ov9p1j/drsoCTgkQNTbz/CU9shZ9mz/FO5f
4p0uAg6JEPPt095p5Cz6+XB/rOD3xWfTBBw8IO6xT0UTh7oTwxyoO+3R7YW6
0x6HO23Q/QV1J0Y4QN25/yxauEHduR9XeAIAhpuyvw==
       
       "], {{-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}, {-1.5401966670117337`, 
       4.3262599733172715`, 0.08210962647842927}, {-0.6636425808029717, 
       4.527047635737208, 0.11867803594150737`}, {-0.45980333298826614`, 
       3.6737400266827285`, -0.08210962647842927}, {-1.3363574191970282`, 
       3.4729523642627917`, -0.11867803594150737`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG4pjMs/zfBmvyvrpQ/Hw4Qcdm+6InXz5L79zAtf
frkT+na/3joz79YnQg51Z3r3TGjbsr/xQknVu1Xv9ouHz17qVCQMFV+ynwEM
PkBpEYcMrbJPZ6UK9+yffvRQx6oP+1+uSIna2yviUANRb1+v390qGPpx/6XA
k1uqpEUdaiHm29sdD/CY9f/j/t2/dPktVoo67IS4B0Mc6k4Mc6DutEe3F+pO
exzutEH3F9SdGOEAded+9HCDuhNDHBaeAAzVuPs=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbji609+urbftO1U2bfaBF2kEjs9d/usnC/5JYX
K5rnfNl/7gTv3qdrhR0UddL3e7JN388bVXLF0e/T/vQnbfc+XYOJt+9nAIMP
UFrE4eiSBvkX+sF7nnuLh9ckv94/U7pSkVdTxEEOot7+3HS9dT+OPdtvZP7J
SSpIxEEeYr79tseurKVaj/afDspOUa8WcRCHuMd+K5o41J0Y5kDdaY9uL9Sd
9jjcacOD5i+oOzHCAerO/apo4QZ1535c4QkAE6acfw==
       
       "], {{-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}, {-1.5572202417218586`, 
       5.294985454684124, 0.08654007014229913}, {-0.6925857475103553, 
       5.535520368797171, 0.15399484397074759`}, {-0.44277975827814153`, 
       4.705014545315876, -0.08654007014229913}, {-1.3074142524896448`, 
       4.464479631202829, -0.15399484397074759`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczqwf7Hr1CU8K0UPSB8OkH4Us8/+UabP
/ktrt+7P1eM7HCsteiDjuqnQG9stUPGl+83E2x+u6xWBii+xf8Yk6nVLoGgP
AxiIHLjWcX2ny70Cm/sQ9fanXlTIBRYJH0iDqN//EGK+/eSLH20WPRE6kA4x
f38GxD32sbuyoj+HCR2QhLhnfyaaONSd+x+hmQN1J1QcYS/Unfuh7rRBc+ee
+2j+grrT/iFaOEDdaZ+BFm5Qd9rjCk8A7DCuRg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAkfuLb8+7J5Uiv2f2eO
Ny3IvLR/kcZ2f471wgee5P+S3C+4ACp+aH/glNvqLddh4hP2v4+ex7x7fd8e
BjAQOaCWurDB7kTUnq8Q9fbrs1VuVGuIHHgMUW//DWK+fdx1jw3fA2DiC+zf
Q9xjz+Oc21FcKXLgCsQ99h/RxKHutP+OZg7UnVBxhL1Qd9pD3WmD5k6br2j+
grpz/ze0cIC6c/97tHCDunM/rvAEANbYspU=
       
       "], {{-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}, {-0.3045027929542561, -4.466307923050252, \
-0.16568287806566326`}, {
       0.5585535390243542, -4.703517494256951, -0.07152669314103544}, {
       0.3045027929542561, -5.533692076949748, 
       0.16568287806566326`}, {-0.5585535390243542, -5.296482505743049, 
       0.07152669314103544}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeKu/bp84QE7twgeUJyRUGySstM+5n6v
sP62jftPxPWbqikLHhAXeO1T8XYDVHzh/pT1x6UmTxSAii+wfyc3XeFnS+4e
BjAQOHBe6q5WsVmOTRREvb3FwoJTN+/wHRCFqN8fDTHfPt/p4ZTNO3kPiEHM
388BcY/98seB8b3TeA7IQ9yznwtNHOrO/TFo5kDdCRVH2At1536oO23Q3Lkn
Cs1fUHfaR6OFA9Sd9lB37teBhhvUnfa4whMASwOmrw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwHfFwrDG5qL9gv6GET
8GTtpf31y2fYTqngP5AWs8DhTP9UqPih/QeCz8h57YGJt+4/qsR/+6Ji/x4G
MBA4ELKo9cGV74F7+CHq7RWuzfxwS1HgQDJEvb0AxHx7hzXGD7c6CxxIhZhv
LwZxj31C09mLE1IFDnhD3GMPdad9IlQc6k57QTRzoO6EiiPshbrTHupOGzR3
2vCj+Qvqzv0CaOEAded+MbRwg7pzP67wBADkramf
       
       "], {{-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}, {-0.33401604091785, -3.4743265786345203`, \
-0.13076979192258442`}, {
       0.5415745076593318, -3.672697089056829, -0.0676007184997242}, {
       0.33401604091785, -4.52567342136548, 
       0.13076979192258442`}, {-0.5415745076593318, -4.327302910943171, 
       0.0676007184997242}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2bJf1K7oXmwt9wGzh3//X9q32X5D0ART
YbbV+3fWLXw5OZjrgKfO3/+Hg1dBxWfvj9l/4ctJTU6o+Cz75y4/GAVa0/Yw
gAHHgYn+K1ZVfEi1WQtRb7/EQZ/b7BrbATeI+v3rIebbezTGieWsYT3gDjF/
PxPEPfavD/YqLmpiOWACcc9+ZjRxqDv3Q91p7w41B+pOqDjCXqg790PdaYPm
zj1r0fwFdac91J37d0DDAepOeya0cIO60x5XeAIAsqysoQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewHTrmfX5v+fNL+U+qq
X5yeXdrvz83wYcM09gM74kVsu0w6oeKH9i9nZaiIOA0Tr9z/643tmyP1/XsY
wIDjQN6vCXdlGV33nICot4/89b99uQnHgW0Q9fYnIebbb/zyn98/k+PAdoj5
9msg7rHnev9/+re5HAdOQNxjvw5NHOpO+1No5kDdCRVH2At1pz3UnTZo7rQ5
geYvqDv3n0QLB6g7969BCzeoO/fjCk8AxEqwGg==
       
       "], {{-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}, {-0.36378498764196615`, -2.4866553064733674`, \
-0.09559136150501202}, {
       0.5221271591828324, -2.6409162994733557`, -0.05866963149497644}, {
       0.36378498764196615`, -3.5133446935266326`, 
       0.09559136150501202}, {-0.5221271591828324, -3.3590837005266443`, 
       0.05866963149497644}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHb1/vNBX1hX9jAfuOGy/6gC92r72kme
L33sFu03Nf/BfCyW6YB1c71eNvsiqPik/bOk/zA+1mOEik+yV/lyvuVqetwe
Bgg4wGNQ7xvLE2dTDVFvf+YE+x/LRX/3W0LU76+BmG8/fSL/j2KX3/utIObv
3wFxj31SlPiXtc9+7L8Gcc/+XWjiUHfuh7rTfhrUHKg7oeKT7E9D7YW6cz/U
nTZo7txTjeYvqDvta9DCAepO+x1o4QZ1pz2u8AQA1z2orw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv5/f/fag4plno3791in
x0cJXN7/jLln2ZH8//v5J4U3zeUph4of3v+Z0S340XaYePr+xzvCvrw+2r+H
AQIO8PjPe6NrarxnF0S9Pdv/mGt8KgwHeCHq7XdDzLfn/bdzjawHwwE+iPn2
0yHusRf+K9ask8NwoAviHvuZaOJQd9rvQTMH6k6oOMJeqDvtoe60QXOnzS40
f0HduX83WjhA3bl/Olq4Qd25H1d4AgDUiKoI
       
       "], {{-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}, {-0.393362316641488, -1.5034989636824452`, \
-0.061260172886108376`}, {
       0.5002570104284851, -1.6091375137523605`, -0.04437837718380681}, {
       0.393362316641488, -2.4965010363175546`, 
       0.061260172886108376`}, {-0.5002570104284851, -2.3908624862476398`, 
       0.04437837718380681}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzx7f89cF//ZOt/3zyxLUayrm20f6BfQ
EZ80aX/cPt2u9BNf9u/56SQWEjIJKt60X/++2FHjlE9Q8SZ7Q93bvV8W++1h
AIMP+x97San29PjZ+EPU2y92vFQ6w/z1/l0Q9fsDIObbuzYveW2Q/2z/boj5
+8sh7rF/caQs8eSyh/unQ9yzvxJNHOrO/VB32rtAzYG6EyreZL8Iai/Unfuh
7rRBc+cefzR/Qd1pH4AWDlB32pejhRvUnfa4whMApP+t+Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXm/f94SFW+P6Yn7V3i/
E0zWurzf6IVvfGzu+/11tw1SEkrCoeKH90t+WbZ+3TaYuPv+gxq9J/w/9u9h
AIMP+ycnXl6xtFt4zzKIevvPrTorVqh82F8DUW+/HGK+/XPuyIBAzw/7ayHm
21dC3GN/a2Lrj5+5H/bPhbjHvhpNHOpO+xVo5kDdCRVH2At1pz3UnTZo7rRZ
huYvqDv3L0cLB6g791eihRvUnftxhScA8QS5Lg==
       
       "], {{-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}, {-0.4222630617365743, -0.5247599788390629, \
-0.028997051226052385`}, {
       0.47612322836711235`, -0.5784594165300123, -0.024702386464896992`}, {
       0.4222630617365743, -1.475240021160937, 
       0.028997051226052385`}, {-0.47612322836711235`, -1.4215405834699877`, 
       0.024702386464896992`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBgQ4ewYE7uxnQAMmxiBwGYf4YQxxCJiwB13ECKLe
Hl3cGGI+hvhpiHswxM/iEDfBYY4JDnuh7rTB4U4MfxnjCIfTOMINPTwB7z42
qA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID57BgTu7GdAAybGIHAZh/hhDHEImLAHXcQIot4e
XdwYYj6G+GmIezDEz+IQN8FhjgkOe6HutMHhTgx/GeMIh9M4wg1XeAIAlqw2
qA==
       "], {{-0.45, -0.45, 0.}, {-0.45, 0.45, 0.}, {0.45, 0.45, 0.}, {
       0.45, -0.45, 0.}, {-0.45, -0.45, 0.}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4srfDpnzzb/sWRssSTyx7azyxLUayrm70/0C+g
Iz5pkr1L85LXBvnP7Pf8dBILCZkEFW+yX+R4qXSG+WuoeNN+Q93bvV8W+9kw
gMEH+8deUqo9PX57/CHq9+vfFztqnPLJfhdEvX0AxPz9cft0u9JPfLHfDTHf
vhzinv09c138Z+t8t58OcY99JZo41J32gWjmQN0JFUfYC3WnPdSde9DcaQN1
p/1iqL+g7twPdae9KzQcoO7cX44WblB37scVngB+HafS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK4ufDpryv47+73vfOHjUXlvP2+JirfH9MT9K7zf
CSZrXd5v9MI3Pjb3vX3dbYOUhJJwqPjh/ZJflq1ftw0m7r7/oEbvCf+P/XsY
wOCD/eTEyyuWdgvvWQZRb/+5VWfFCpUP9jUQ9fbLIebbP+eODAj0/GBfCzHf
vhLiHvtbE1t//Mz9YD8X4h77ajRxqDvtV6CZA3UnVBxhL9Sd9lB32qC502YZ
mr+g7ty/HC0coO7cX4kWblB37scVngDBObGu
       "], {{-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}, {-0.47612322836711235`, 
       1.4215405834699877`, 0.024702386464896992`}, {0.4222630617365743, 
       1.475240021160937, 0.028997051226052385`}, {0.47612322836711235`, 
       0.5784594165300123, -0.024702386464896992`}, {-0.4222630617365743, 
       0.5247599788390629, -0.028997051226052385`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4V/S62OHa1fVKU+Je1z37Y33DZf1SBe/X+2kme
L33sFtlPm8j/o9jlt711c71eNvsiqPgk+9Mn2P9YLvoLFZ+0X+XL+Zar6XE2
DBDgwGNQ7xvLE7enGqJ+/yzpP4yP9RgdLCHq7Wsg5u83Nf/BfCyWycEKYr79
Doh79p8P+sK6sofZ4RrEPfa70MSh7rSvRTMH6k6oOMJeqDvtoe7cg+ZOG6g7
7c9A/QV1536oO+2nQ8MB6s79O9DCDerO/bjCEwClbqIu
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ55U6q/fcad/TdZL/1cpv7fvnvtQcUyz8b9e6zT
46MELu9/xtyz7Ej+f3v+SeFNc3nKoeKH939mdAt+tB0mnr7/8Y6wL6+P9u9h
gAAHHv95b3RNjffsgqi3Z/sfc41PhcGBF6LefjfEfHvefzvXyHowOPBBzLef
DnGPvfBfsWadHAaHLoh77GeiiUPdab8HzRyoO6HiCHuh7rSHutMGzZ02u9D8
BXXn/t1o4QB15/7paOEGded+XOEJAKS9oog=
       "], {{-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}, {-0.5002570104284851, 
       2.3908624862476398`, 0.04437837718380681}, {0.393362316641488, 
       2.4965010363175546`, 0.061260172886108376`}, {0.5002570104284851, 
       1.6091375137523605`, -0.04437837718380681}, {-0.393362316641488, 
       1.5034989636824452`, -0.061260172886108376`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmELbTyehz2WL/+mCv4qImFgezh3//X9q3ef+GoAmm
wmyr7d0b48Ry1rA6eOr8/X84eBVUfLb9Egd9brNrbFDxWfufu/xgFGhNs2EA
Aw6Hif4rVlV8SN2zFqJ+f8z+C19OanI6uEHU26+HmL9/R93Cl5ODuRzcIebb
M0Hcs1/UruhebC23gwnEPfbMaOJQd9pD3bl/J9QcqDuh4gh7oe60h7pzD5o7
bdai+Qvqzv1Qd9p7QMMB6s79TGjhBnXnflzhCQCJrKYb
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF632zwvJfLO/m8CDBmcSewOp9zPr01/Pmn/KXXV
L07PLu3352b4sGEau8OOeBHbLpNOqPih/ctZGSoiTsPEK/f/emP75kh9/x4G
MOBwyPs14a4so+ueExD19pG//rcvN+Fw2AZRb38SYr79xi//+f0zORy2Q8y3
XwNxjz3X+//Tv83lcDgBcY/9OjRxqDvtT6GZA3UnVBxhL9Sd9lB32qC50+YE
mr+g7tx/Ei0coO7cvwYt3KDu3I8rPAGUf6ia
       "], {{-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}, {-0.5221271591828324, 
       3.3590837005266443`, 0.05866963149497644}, {0.36378498764196615`, 
       3.5133446935266326`, 0.09559136150501202}, {0.5221271591828324, 
       2.6409162994733557`, -0.05866963149497644}, {-0.36378498764196615`, 
       2.4866553064733674`, -0.09559136150501202}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY6HzLXbeIu++WPA+N7p/E4KM5IKDZJ2bk/5n6v
sP62jfb5Tg+nbN7J6yAu8Nqn4u0GqPhCe4uFBadu3uGDii/Y/05uusLPllwb
BjAQcDgvdVer2CxnTxRE/f6U9celJk8UcBCFqLePhpi//0Rcv6masqCDGMR8
ew6Ie/br8IUH7Nwi6CAPcY891J37daHiUHfax6CZA3UnVBxhL9Sd9lB37kFz
p00Umr+g7twfjRYOUHfu50ALN6g79+MKTwAjjqA4
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJbIiaq4xnJnv/3vlJh7JvwOPq4VBje1F+wX9LAJ
eLL20v765TNsp1TwO6TFLHA40z8VKn5o/4HgM3Jee2DirfuPKvHfvqjYv4cB
DAQcQha1PrjyPXAPP0S9vcK1mR9uKQo4JEPU2wtAzLd3WGP8cKuzgEMqxHx7
MYh77BOazl6ckCrg4A1xjz3UnfaJUHGoO+0F0cyBuhMqjrAX6k57qDtt0Nxp
w4/mL6g79wughQPUnfvF0MIN6s79uMITALTioh8=
       "], {{-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}, {-0.5415745076593318, 
       4.327302910943171, 0.0676007184997242}, {0.33401604091785, 
       4.52567342136548, 0.13076979192258442`}, {0.5415745076593318, 
       3.672697089056829, -0.0676007184997242}, {-0.33401604091785, 
       3.4743265786345203`, -0.13076979192258442`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM70r+SPczpgH7srK/pzmJCD9OEA6Ucx+/Y/yvTZ
f2ntVvvJFz/aLHoi5JBx3VToje0WqPhS+1MvKuQCi4Sh4kv2P2MS9bolUGTD
AAYiDtc6ru90uVew5z5E/X4z8faH63pFHNIg6u0fQszfn6vHdzhWWtQhHWK+
fQbEPfsXu05dwrNS1EES4h77TDRxqDvtH6GZA3UnVBxhL9Sd9lB37kFzp819
NH9B3bn/IVo4QN25PwMt3KDu3I8rPAG39qcS
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7YyhegMe/2/i97JpX3tAk7XFv+fdk8qRX7vzPH
mxZkXtq/SGO7P8d6YYcn+b8k9wsugIof2h845bZ6y3WY+IT976PnMe9e37eH
AQxEHNRSFzbYnYja8xWi3n59tsqNag0Rh8cQ9fbfIObbx1332PA9ACa+wP49
xD32PM65HcWVIg5XIO6x/4gmDnWn/Xc0c6DuhIoj7IW60x7qThs0d9p8RfMX
1J37v6GFA9Sd+9+jhRvUnftxhScApw2rFQ==
       "], {{-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}, {-0.5585535390243542, 
       5.296482505743049, 0.07152669314103544}, {0.3045027929542561, 
       5.533692076949748, 0.16568287806566326`}, {0.5585535390243542, 
       4.703517494256951, -0.07152669314103544}, {-0.3045027929542561, 
       4.466307923050252, -0.16568287806566326`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK64l1Pief+1vcD9mh9sK0UPvH+zIb3i6l77pS/n
+rbZv7XnevX3V6S06AHvz6Wzlj7ebH/pyzm1w/Pf2bN+rfu7plcEKr7YngEM
PkBpkQPCC7YzcE0usJneOiNHbsMH+99cjUzBRcIHPCHq9+tyG960Sfho/02U
iXXZE6EDXhDz9x+ZcNI1WuCT/UeFZvafYUIH3kLcAxf/ABWHunO/Hpo5UHfu
R7cX6s79ONy55zKav6DuxAgHqDvtYeHGDw03qDvtcYUnADNgt8I=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIHrm16ftkpav1+px3z
/F5ffGZvrDEts3CD8IEJZ96bX3+2ZL9ijP/yrxmv7SVFTm+xuAETn7KfAQw+
2ENokQPlWnPXcWQn7nkfGKHT6v3J/vlrE+/j6iIHeiHq7e8v3hDBNf2L/dnr
mdP6/EUO9EPMtz/3laO1/9E3+y2H5z0MLRc5cAXiHvvzaOJQd2KYA3Wn/Qc0
e6HutMfhTht0f0HdiREOUHfuT0ELN6g79+MKTwBWurrI
       "], {{
       0.4406940533877688, -5.298527104669883, 0.05530303664006736}, {
       0.6986806420697439, -4.468395797789808, -0.17777406090024198`}, {
       1.5593059466122312`, -4.701472895330117, -0.05530303664006736}, {
       1.301319357930256, -5.531604202210192, 0.17777406090024198`}, {
       0.4406940533877688, -5.298527104669883, 
       0.05530303664006736}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ6VePL5hPlv7HNqir2WbxE8kHt+VYLXvx32adNu
v9+6/63956BFhlLKggc8u2Ret63cYG98+u33W/ff2VdqXpTonSgAFV9gzwAG
H6C0wIHKZy1GZkezbdKkOFuEJnyw510be+7pHb4DHhD1+8+aCHGoKny0l4ra
Pef0Tl6o+Ib9xv7SPeYbPtprsEtmb5zGcyAb4h4Mcag7McyBunM/ur1Qd+7H
4c496P6CutM+HS0coO60Rw83qDsxxGHhCQBI9azg
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4LfgP3H7RV81YuHy/Sv3p
BQzrntmvk15+YnMV/4Eqs0z/cMf5+yftTw1gCH9tf703+EnkXph4/34GMPhg
D6EFDuxi0j10gjtqj7nC2ev1IZ/sRS2v8QYrChwoh6i3z3OYtf7/ii/2mkVr
pJc5CRyogJhvvyQhvb3+7zd7u9VNmj+TBQ7chLgHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15/4daOEGded+XOEJADx7nmY=
       "], {{
       0.45758907679283756`, -4.328789248178778, 0.05184612490425521}, {
       0.6686325248437331, -3.4759504204758596`, -0.14341420644110717`}, {
       1.5424109232071626`, -3.671210751821222, -0.05184612490425521}, {
       1.331367475156267, -4.52404957952414, 0.14341420644110717`}, {
       0.45758907679283756`, -4.328789248178778, 
       0.05184612490425521}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILYoUO+/lP3WfmLxUxurWu4D69NqOEPLN9tXfz2y
5aH7O/tt32do1ARzHZhq/Dux8MtK+71VSbc+KL+3v13tI7JPkxMqPtOeAQw+
QGmOA4EMf9Q4F6baLDx0bhJ73gd71ZbNrx2vsR2YDFG/37l1rir/nQ/2Xhzp
15vXsB6YAjF//xP3nB1iXh/tC3qkDh9tYjmwDuIeuHg+VBzqTgxzoO7cj24v
1J37cbhzD7q/oO7ECAeoO+1h4TYBGm5Qd9rjCk8Anu2qjg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewHHNp+LOXctmC/TOz3
c34TntkbCVdY6c1gP7A61vsuj8e0/X3rqtPVPV7bz+S0kRU/AxNv288ABh/s
ITTHAb5z+3gTJgbt2anh5PMm+pN9+rfDj14YcxxYCVFvXxTYMuPG9i/25960
H72YznFgFcR8e62qY0+OCH+3N33svWLXbI4D9hD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7ty/Bi3coO7cjys8AZlZpDk=
       "], {{
       0.47708548159050357`, -3.360106621681593, 0.04340077715472844}, {
       0.638261629818642, -2.4878141493146844`, -0.10867845184899426`}, {
       1.5229145184094963`, -2.639893378318407, -0.04340077715472844}, {
       1.361738370181358, -3.5121858506853156`, 0.10867845184899426`}, {
       0.47708548159050357`, -3.360106621681593, 
       0.04340077715472844}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4w0M/+7PjOnukLY8vkHuYD1jP2npi4cZX9q1Ml
7ouuvbNfsyhs7fZYpgOXd11u3XZ6oX1p6i7lwOz39mGBq6/d1mOEik+0ZwCD
D1Ca4cDmHu77t1bE2rieVcoL9/pgHxK7Mshj0d/9FyHq93fPcr2zbsoH+5W7
gpZOcPm9/xLE/P0X0jO82O5/sP8n/uf7jWc/9ltC3AMX/wsVh7oTbs4KqDlQ
d+5Htxfqzv043LkH3V9Qd2KEA9Sd9rBwY4SGG9Sd9rjCEwDQkcAk
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7vf+scwLtIevr+nnc3
FQWqntlrJl30XlT4f78ta/aepvN9+92+vxHgsH1tL7rxherFHTDxuv0MYPDB
HkIzHGDXj/z0Zo3nntiWzu/ViZ/sy5Zz505XZjhgBVFvv4tD+P33Q1/sX/uJ
39JzZzhgDTHfXqx3zrNile/2id+U3I9lMRx4DXEPhjjUnRjmQN1pj24v1J32
ONxpg+4vqDsxwgHqzv1X0MIN6s79uMITAFP0pts=
       "], {{
       0.4991510472470452, -2.391504741244447, 0.0295696484488244}, {
       0.6080497644704068, -1.5042232636794342`, -0.0747023466272946}, {
       1.5008489527529547`, -1.6084952587555532`, -0.0295696484488244}, {
       1.3919502355295932`, -2.4957767363205656`, 0.0747023466272946}, {
       0.4991510472470452, -2.391504741244447, 
       0.0295696484488244}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG6zDqtSkn9vX6m+e3Wfzvf9rP8F/B9pzLZnqbX8
I5b13n5Zvrps/Ikv+9eHcHc5Sk+yb9onU8e99b395e2T+/RTPkHFm+wZwOAD
jN5/1jzDOlfXz2b/go8OVaof7KMm3Hi0wPz1/rUQ9fvrHB83fvH6YL9FYeNR
x/xn+9dBzN9v++jKobyCD/YCGztXPFr2cD8LxD1wcT6oONSdGOZA3bkf3V6o
O/fjcOcedH9B3YkRDlB32rdDw60CGm5Qd9rjCk8AF6ym6w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/3t7H9s345Z8L+Kys8
H7nmPLOPXrr+s2r++/2ccX/9e9Ta9mddUfmoZPbafu2l6z8nbYeJl+1nAIMP
9lB6/0bl4LclpU57Tk/NbX+X8sl+pZhIs5nKh/1sEPX207Rv8909+cU+WFeD
Ldfjw352iPn2CQc9pp3W+27/x9mmc3HOh/2tEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3O+AFm5Qd+7HFZ4AEl+yVQ==
       "], {{
       0.523625995532506, -1.4218551013456981`, 0.010299579419318135`}, {
       0.5785247554904833, -0.5250986033436529, -0.042746715891330875`}, {
       1.476374004467494, -0.5781448986543019, -0.010299579419318135`}, {
       1.4214752445095167`, -1.4749013966563471`, 0.042746715891330875`}, {
       0.523625995532506, -1.4218551013456981`, 
       0.010299579419318135`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhj4YH/2DAjc2c+AAj7YmxiDwGUc4ocxxCH0hD3o
4kYQ9fbo4sYQ8zHET0PcgyF+Foe4CQ5zTHDYC3WnDQ53YvjLGEc4nMYRbujh
CQDSikhp
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIC74mCKfNvuhPQMUrN3RWLbuZM/+Bd7OWTPTn8HF
Sy6s/iln2Lz/wlLFrWeMX6OJF++H8D7AxQ9sKP7a8cd+j4Ru/lLJtE9w8SKI
enuDqHtexme+wMWLIebbe7T7fvAx+g4XXw1xD4Y41J0Y5kDdaY9uL9Sd9jjc
aYPuL6g7McIB6s79hWjhBnXnflzhCQBjMnoq
       "], {{
       0.5502195943040942, -0.45, -0.014056551925218786`}, {
       0.5502195943040942, 0.45, -0.014056551925218786`}, {
       1.4497804056959058`, 0.45, 0.014056551925218786`}, {
       1.4497804056959058`, -0.45, 0.014056551925218786`}, {
       0.5502195943040942, -0.45, -0.014056551925218786`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILZ9dOVQXsEHe76NnSseLXtoz/pfwP+Rxuz9dY6P
G794fbDforDxqGP+M/v1IdxdjtKT9u9f8NGhSvWDfdSEG48WmL+GijftZwCD
D/Yw+qx5hnWurt+epn0yddxb39tf3j65Tz/lk/1aiHp7llrLP2JZ7+2X5avL
xp/4Yr8OYr59u3VYlZL8e/sK9d2r+3S+27NA3GPfBhWvhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPCzcBaLhB3bkfV3gCAGbQok8=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILavzbucseihPUdF+9sdau/t29j+Wb+cM2H/lRWe
j1xzntlHL13/WTX/vT1n3F//HrW2/VlXVD4qmb22X3vp+s9J22HiZfsZwOCD
PYzeqBz8tqTUac/pqbnt71I+2a8UE2k2U/lgzwZRbz9N+zbf3ZNf7IN1Ndhy
PT7Ys0PMt0846DHttN53+z/ONp2Lcz7Yt0LcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+pOjHCAunO/A1q4Qd25H1d4AgDiharV
       "], {{0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}, {0.523625995532506, 
       1.4218551013456981`, 0.010299579419318135`}, {1.4214752445095167`, 
       1.4749013966563471`, 0.042746715891330875`}, {1.476374004467494, 
       0.5781448986543019, -0.010299579419318135`}, {0.5785247554904833, 
       0.5250986033436529, -0.042746715891330875`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL6QnuHFdv+D/V/xP99vPPthbz1j74mJG1ft757l
emfdlA/2K3YFLZ3g8tv+8q7LrdtOL9zvelYpL9zrg31I7Mogj0V/oeIT9zOA
wQd7CM3gsLmH+/6tFbF7SlN3KQdmv7cPC1x97bYeo8NFiHr7V6dK3Bdde2e/
ZlHY2u2xTA6XIObbJxjoZ392fGfP+IWxZXIPs4MlxD1wcSaoONSdGOZA3WmP
bi/UnfY43GmD7i+oO+HhsBIaDlB37oeF2z9ouEHduR9XeAIAJUq8tQ==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL789JiRxPaH9nbCuwqLtf7bv3UO4F0kPX1/z7ub
igJVz+w1ky56Lyr8b2/Lmr2n6XzffrfvbwQ4bF/bi258oXpxB0y8bj8DGHyw
h9AMDuz6kZ/erPHcE9vS+b068ZN92XLu3OnKDA5WEPX2uziE338/9MX+tZ/4
LT13BgdriPn2Yr1znhWrfLdP/KbkfiyLweE1xD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g7919BCzeoO/fjCk8AJCmfWw==
       "], {{0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}, {0.4991510472470452, 
       2.391504741244447, 0.0295696484488244}, {1.3919502355295932`, 
       2.4957767363205656`, 0.0747023466272946}, {1.5008489527529547`, 
       1.6084952587555532`, -0.0295696484488244}, {0.6080497644704068, 
       1.5042232636794342`, -0.0747023466272946}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7inrNDzOujfX6P1OGjTSwO69NqOEPLN+93bp2r
yn/ng70XR/r15jWsDlONfycWflm5f+Ghc5PY8z7Yq7Zsfu14jQ0qPnM/Axh8
sIfQHA6BDH/UOBem7tlblXTrg/J7+9vVPiL7NDkdJkPU21d/PbLlofs7+23f
Z2jUBHM5TIGYb29RoN5/Kfut/YTipzZWtdwO6yDugYtPhIpD3YlhDtSd9uj2
Qt1pj8OdNuj+groTIxyg7twPC7cCaLhB3bkfV3gCAMjAo+I=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7NXWxWduOh/WmZLeGuKewODm0/lnJuW7BfJvb7
Ob8Jz+yNhCus9GawO6yO9b7L4zFtf9+66nR1j9f2MzltZMXPwMTb9jOAwQd7
CM3hwHduH2/CxKA9OzWcfN5Ef7JP/3b40QtjDoeVEPX2RYEtM25s/2J/7k37
0YvpHA6rIObba1Ude3JE+Lu96WPvFbtmczjYQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6c/8atHCDunM/rvAEAGmOnLk=
       "], {{0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}, {0.47708548159050357`, 
       3.360106621681593, 0.04340077715472844}, {1.361738370181358, 
       3.5121858506853156`, 0.10867845184899426`}, {1.5229145184094963`, 
       2.639893378318407, -0.04340077715472844}, {0.638261629818642, 
       2.4878141493146844`, -0.10867845184899426`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDb2l+4x3/DRXoNdMnvjNB6H3POrErz+7dh/1kSI
Q1Xho71U1O45p3fyOnh2ybxuW7lhf5oUZ4vQhA/2vGtjzz29wwcVX7CfAQw+
2ENoAYfKZy1GZkez9xiffvv91v139pWaFyV6Jwo4eEDU26dPu/1+6/639p+D
FhlKKQtCxTfYz0o8+XzC/Df2OTXFXsu3CDpkQ9yDIQ51p30amjlQd9qj2wt1
pz0Od9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwA37KMQ
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5uZ/iRgfWRfevKX2t4Lfgdbr/oq2YsXL5fpf70
AoZ1z+zXSS8/sbmK36HKLNM/3HH+/kn7UwMYwl/bX+8NfhK5Fybev58BDD7Y
Q2gBh11MuodOcEftMVc4e70+5JO9qOU13mBFAYdyiHr7PIdZ6/+v+GKvWbRG
epmTgEMFxHz7JQnp7fV/v9nbrW7S/Jks4HAT4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+3eghRvUnftxhScADLCW5g==
       "], {{0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}, {0.45758907679283756`, 
       4.328789248178778, 0.05184612490425521}, {1.331367475156267, 
       4.52404957952414, 0.14341420644110717`}, {1.5424109232071626`, 
       3.671210751821222, -0.05184612490425521}, {0.6686325248437331, 
       3.4759504204758596`, -0.14341420644110717`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmID4y4aRrtMAn+w8Kzew/w4Qc3r/ZkF5xde9+PW7D
mzYJH+2/iTKxLnsi5OD9uXTW0seb909vnZEjt+GD/W+uRqbgImGo+OL9DGDw
wR5CizgIL9jOwDW5YM/lL+fUDs9/Z8/6te7vml4RB0+IevulL+f6ttm/ted6
9fdXpLSogxfEfPuKezklnvdf2/Pfr/nBtlLU4S3EPXBxAag41J0Y5kDdaX8J
zV6oO+1xuNMG3V9Qd+7XRQsHqDv3w8LtIzTcoO7cjys8AU2IsAw=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4Seff1gdUjex+bRLlVHcIO1zY9v+wUtX6/0455
fq8vPrM31piWWbhB2GHCmffm158t2a8Y47/8a8Zre0mR01ssbsDEp+xnAIMP
9hBaxKFca+46juzEPe8DI3RavT/ZP39t4n1cXcShF6Le/v7iDRFc07/Yn72e
Oa3PX8ShH2K+/bmvHK39j77Zbzk872FouYjDFYh77M+jiUPdiWEO1J32H9Ds
hbrTHoc7bdD9BXUnRjhA3bk/BS3coO7cjys8ASbvs0g=
       "], {{0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}, {0.4406940533877688, 
       5.298527104669883, 0.05530303664006736}, {1.301319357930256, 
       5.531604202210192, 0.17777406090024198`}, {1.5593059466122312`, 
       4.701472895330117, -0.05530303664006736}, {0.6986806420697439, 
       4.468395797789808, -0.17777406090024198`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7W8PF7yYu/9r7vpFn1Vooe+PHu6MTjBnvtLVd7
L/0x65+9yZd05hJp0QMB8/USb5Vutp9zdWlQje9/e6lfmxl39YpAxRfbM0CA
A4QSOZCr/yeg27zAxkh07TXHSAaHZ6w+/1yLhA/4QdTvT9aKWtu8icHhLPeM
P91PhA74Q8zfP9WeveUoN6PDZsEnvy6GCR34BnEPhjjUnftToOacgZoDded+
dHuh7tyPw5175qL5C+pOeDgYQ8MB6k579HCDuhNDHBaeAPT8qmA=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIHHB/wLVrQvHn/Lb3M
yNW5v+2bXaunaWwSPsCsnal7jWXV/tzpW9Zc3fbX/uAiW2+RmzDxWfsZIMAB
Qokc0PmpU71pXeoezy1LNaeqMDrYxx7a8lpN5AADRL395AzvYC1PJofaXS2Z
131FDjBCzLe/I/OxZn8us8MecXe5wyUiBxwg7sEQh7oTwxyoO+290OyFutMe
hztt0P0FdSdGOEDdud8DLdyg7tyPKzwBIROWmg==
       "], {{
       1.4406642841535762`, -5.301189047566042, 0.037798341297327606`}, {
       1.7021599343900928`, -4.470759818154412, -0.19025279298221853`}, {
       2.559335715846424, -4.698810952433958, -0.037798341297327606`}, {
       2.297840065609907, -5.529240181845588, 0.19025279298221853`}, {
       1.4406642841535762`, -5.301189047566042, 
       0.037798341297327606`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN5Sr5kX6vnP3jy36f3mLYIH3MUtmG/V7bA/+7/A
s+/2P/vzHmvmKykLHjDYVRU+MWSD/fP6HSrHc//bZ6hc8584UQAqvsCeAQIc
IJTAgZ8PFJ/PMc+24T2wOFfGk8HBcHtwwt07fAf0IOr3Sza437aYxOCQmLf8
wK6dvAf0IebvV3N47RF6m8FhkupvhRnTeA64QtyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwB+/+d/A==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Thv/A5h3eccZG6/fX/5/n
+Cjqt72elktpdC3/gbOqd+2UzizZv7/+vELh2r/24qKLdq3dBxOfsp8BAhwg
lMCBq1+STI6HJO5RcJiR767J6FDydZ3SSgWBA6ch6u0dGgzu9wUxObx8Fesa
5Chw4AzEfPvEAyf8rlUzO8Q+4Mn4nShwYCPEPRjiUHfaO6KZA3WnPbq9UHfa
43CnzQE0f0HdCQ8HfWg4QN253x4t3KDu3I8rPAGnipmB
       "], {{
       1.4574363849823695`, -4.330782047795958, 0.0347557263614637}, {
       1.6716289083269396`, -3.477846748236157, -0.15661547760642103`}, {
       2.5425636150176305`, -3.6692179522040416`, -0.0347557263614637}, {
       2.3283710916730604`, -4.522153251763843, 0.15661547760642103`}, {
       1.4574363849823695`, -4.330782047795958, 
       0.0347557263614637}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmILaKcyyZs+Gf/b/gK2+tarkPcM/Ln5Aivdm+5mWD
b4bCf/uQ3t55NcFcB1Jr7bNvV66031dyQM1kwn/7Vcfc/PdpckLFZ9ozQIAD
hOI4cNmWq+WhVarNwqPz3zw1Z3AIs9y5wfEa24EkiPr9Tt32N0/nMzisKSpK
bF7DeiAZYv7+xwH3j25czuDAtEZb6GgTywEuiHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScADh6hHw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdPYD0yaxTHrTsGL/0sbw
Nk/v3/ZcTMGTJGaxH0jlYeb5HLpg/+UD2oeXLP1rz9qo6clzFiY+YT8DBDhA
KI4DfzKjMl9ZRu+ZLp81T1eX0eF33bVtn404DiRD1Nvr2l+xiY5icvj2d03u
81SOAykQ8+2PxNnd7mhndvhQ06xyewbHgSkQ92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6c/8ytHCAunM/erhB3YkhDgtPAOtJmX8=
       "], {{
       1.4769389546218403`, -3.3615108230395725`, 0.026778118551493257`}, {
       1.640703042065311, -2.489215714163841, -0.12249534424509298`}, {
       2.5230610453781597`, -2.6384891769604275`, -0.026778118551493257`}, {
       2.359296957934689, -3.510784285836159, 0.12249534424509298`}, {
       1.4769389546218403`, -3.3615108230395725`, 
       0.026778118551493257`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHYzXPDSSPa/PZvFnJ19PcwH2I8tm1lqvcr+psKB
2Wcy/tuvr9pbvSWW6UDUTUnBnzUL7XMFHvimbflvH773nu0tPUao+ER7Bghw
gNIHHLIaZOarxtqc+s5/84wqg0Ngq1OL96K/+yMh6vdPfi+/aaY3g8MirlaO
6S6/oeIL98c+1+9OK2Rw+NJ/vOfRsx/7WSHuwRCHuhPDHKg796PbC3Xnfhzu
3IPuL6g7McIB6k579HCDuhNDHBaeAA2DpIA=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7v/xNyoSUievH+3ctK
zCbY/7Y3NSw3lyj5v3/5MdGNCudn7o8LtpI+Mf+v/ewZu6V5dsHEO/czQIAD
lD7QpTpp8ofG0D2B15I+SRswOmw2Vvr0U4nhwBKIevtFa44+MU9gckhNd3ny
2ZXhwFKI+fafmzSuB09gdpCYnXbtbQbDgd8Q99h/QROHuhPDHKg77dHthbrT
Hoc7bdD9BXUnRjhA3bkfPdyg7sQQh4UnAEs1qdI=
       "], {{
       1.4991562191741747`, -2.3923967123733894`, 0.013428601068172417`}, {
       1.6098989548450404`, -1.5051335095537164`, -0.08904117700472194}, {
       2.500843780825825, -1.6076032876266106`, -0.013428601068172417`}, {
       2.39010104515496, -2.4948664904462836`, 0.08904117700472194}, {
       1.4991562191741747`, -2.3923967123733894`, 
       0.013428601068172417`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Ds/rBzN7/9ot+GPd36Xzf//O+4Jr3W2fZe2yW
eb1783978d/l8TEnvuxf/or7xPxzE+2XRPZ9vXvzv33P3936eimfoOKN9gwQ
4AChPuzPuiP8Y8taXxu9yxasgsIMDi9ZOhYsNn+9fylE/f6YZYVcSmoMDpc4
BRzd85/tXwYxf39X5Sp+Y0sGhz18Mx6+WvZw/3eIe+Diu6HiUHdimAN15350
e6Hu3I/DnXtg/uqG+gvqToxwgLrTHj3coO7EEIeFJwCcs7sn
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7v3xrDfKFKesH+t8y8
0u4Wv+1XL9jP2F34fv+nC5GiPyun7v/W2NarPOevfeiF+w1Hd8DEW/czQIAD
hPqwX05P4fmSp4F7WPfbWL4zZHS4Kj7Bfq7yh/3vIertueoqi+4kMzms1leo
t3L/sP8jxHx7Ptttq09NZXZocN+w73rWh/1bIO7BEIe6E8McqDvt0e2FutMe
hzttvqP5C+pOjHCAunM/erhB3YkhDgtPAOhqriA=
       "], {{
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}, {
       1.5797889527235025`, -0.5255410153731569, -0.05754431034997633}, {
       2.4760698927773994`, -0.5777103285699278, 0.0053749971532055}, {
       2.4202110472764975`, -1.474458984626843, 0.05754431034997633}, {
       1.5239301072226004`, -1.4222896714300721`, -0.0053749971532055}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBjhwOHsGBO7sZ0AFDibGIHAZh/hhDHEINWEPurgR
RL09urgxxHwM8dMQ92CIn8UhboLDHBMc9kLdaYPDnRj+MsYRDqdxhBt6eAIA
pSs6aA==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID7GVe2+9cIPewYoeLEtMeLI37n7W2KW658z/Q0X
/1g57WnTv8n7ndZdFn8+6y+aePN+KNcBJu4hsEIkd2XAnvsaYiU9Roxw8fcQ
9fb7AnVeSKQywcU/QMy3n1vlFLN0OjNc/BnEPRjiUHdimAN1pz26vVB3wtyN
7k4bdH9B3YkRDlB37kcPN6g7McRh4QkA2mF9Jg==
       "], {{
       1.5509541313373787`, -0.45, -0.02928835668028898}, {
       1.5509541313373787`, 0.45, -0.02928835668028898}, {2.4490458686626213`,
        0.45, 0.02928835668028898}, {2.4490458686626213`, -0.45, 
       0.02928835668028898}, {
       1.5509541313373787`, -0.45, -0.02928835668028898}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIO6qXMVvbMngsJtvxsNXyx7a/7wvuOb91ln7Y5YV
cimpMThc4hRwdM9/Zr/8FfeJ+ecm7te7bMEqKMzg8JKlY8Fi89dQ8cb9DBDg
AKE+2GfdEf6xZa3vniWRfV/v3vxv3/13t75eyif7pRD19h6bZV7v3vzfXvx3
eXzMiS/2yyDm27/hWf1gZu9/+0U/jPu7dL7bf4e4B0Mc6k4Mc6DutIfZ2wO1
F+pOexzutEH3F9SdGOEAded+WLjtgYYb1J37cYUnAJXTslI=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7SOnlF1pUf9gyF85sCtN7bb41hvlAlvWD/W2Ze
aXeL3/arF+xn7C58b//pQqToz8qp+781tvUqz/lrH3rhfsPRHTDx1v0MEOAA
oT7Yy+kpPF/yNHAP634by3eGjA5XxSfYz1X+YP8eot6eq66y6E4yk8NqfYV6
K/cP9h8h5tvz2W5bfWoqs0OD+4Z917M+2G+BuAdDHOpODHOg7rRHtxfqTnsc
7rT5juYvqDsxwgHqzv3o4QZ1J4Y4LDwBuJ+moA==
       "], {{1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}, {1.5239301072226004`, 
       1.4222896714300721`, -0.0053749971532055}, {2.4202110472764975`, 
       1.474458984626843, 0.05754431034997633}, {2.4760698927773994`, 
       0.5777103285699278, 0.0053749971532055}, {1.5797889527235025`, 
       0.5255410153731569, -0.05754431034997633}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmII59rt+dVsjg8KX/eM+jZz/s2Y8tm1lqvWr/5Pfy
m2Z6Mzgs4mrlmO7y2z7qpqTgz5qF+0995795RpXBIbDVqcV70V+o+MT9DBDg
AKMdshpk5qvG7skVeOCbtuW/ffjee7a39BgdIiHq7W8qHJh9JuO//fqqvdVb
Ypmg4gvt3QwXvDSS/W/PZjFnZ18PswMrxD0Y4lB3YpgDdac9ur1Qd9rjcKcN
ur+g7sQIB6g796OHG9SdGOKw8AQAUR6f7Q==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb8tS4w4v4P+wsnjYJV9P7b/wm50BIRvXj/7mUl
ZhPsf9ubGpabS5T8t19+THSjwvmZ++OCraRPzP9rP3vGbmmeXTDxzv0MEOAA
o7tUJ03+0Bi6J/Ba0idpA0aHzcZKn34qMTgsgai3X7Tm6BPzBCaH1HSXJ59d
GRyWQsy3/9ykcT14ArODxOy0a28zGBx+Q9xj/wVNHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAbaqJS
       "], {{1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}, {1.4991562191741747`, 
       2.3923967123733894`, 0.013428601068172417`}, {2.39010104515496, 
       2.4948664904462836`, 0.08904117700472194}, {2.500843780825825, 
       1.6076032876266106`, -0.013428601068172417`}, {1.6098989548450404`, 
       1.5051335095537164`, -0.08904117700472194}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH4ccP/oxuUMDkxrtIWONrE4cM/Ln5AivXm/U7f9
zdP5DA5riooSm9ewOqTW2mffrly5f+HR+W+emjM4hFnu3OB4jQ0qPnM/AwQ4
QCgOh8u2XC0PrVL37Cs5oGYy4b/9qmNu/vs0OR2SIOrta142+GYo/LcP6e2d
VxPM5ZAMMd/eKs6xZM6Gf/b/gq+8tarlduCCuAdDHOpODHOg7rRHtxfqTnsc
7rRB9xfUnRjhAHXnfvRwg7oTQxwWngAsX5ka
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5wavZ89+GHvUBzzW2VdHaHaZNYJr1pWLF/aWN4
m6f3b3supuBJErPYHVJ5mHk+hy7Yf/mA9uElS//aszZqevKchYlP2M8AAQ4Q
isPhT2ZU5ivL6D3T5bPm6eoyOvyuu7btsxGHQzJEvb2u/RWb6Cgmh29/1+Q+
T+VwSIGYb38kzu52Rzuzw4eaZpXbMzgcpkDcgyEOdSeGOVB32qPbC3WnPQ53
2qD7C+rO/cvQwgHqzv3o4QZ1J4Y4LDwBu36R/w==
       "], {{1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}, {1.4769389546218403`, 
       3.3615108230395725`, 0.026778118551493257`}, {2.359296957934689, 
       3.510784285836159, 0.12249534424509298`}, {2.5230610453781597`, 
       2.6384891769604275`, -0.026778118551493257`}, {1.640703042065311, 
       2.489215714163841, -0.12249534424509298`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFZzeO0RepvBYZLqb4UZ03gc3MUtmG/V7dgv2eB+
22ISg0Ni3vIDu3byOhjsqgqfGLJhP++BxbkyngwOhtuDE+7e4YOKL9jPAAEO
EErA4ecDxedzzLP3PK/foXI89799hso1/4kTBRz0IOrtz/4v8Oy7/c/+vMea
+UrKgg76EPPtt9Rr5oV6/rM3z216v3mLoIMrxD0Y4lB3YpgDdac9ur1Qd9rj
cKcNur+g7sQIB6g796OHG9SdGOKw8AQADzaV3w==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmILarz0sK5vhp72b/TJ/Tht9h8w7vOGOj9fvr/89z
fBT1215Py6U0upbf4azqXTulM0v2768/r1C49q+9uOiiXWv3wcSn7GeAAAcI
JeBw9UuSyfGQxD0KDjPy3TUZHUq+rlNaqSDgcBqi3t6hweB+XxCTw8tXsa5B
jgIOZyDm2yceOOF3rZrZIfYBT8bvRAGHjRD3YIhD3WnviGYO1J326PZC3WmP
w502B9D8BXUnPBz0oeEAded+e7Rwg7pzP67wBAB3v5IB
       "], {{1.6716289083269396`,
        3.477846748236157, -0.15661547760642103`}, {1.4574363849823695`, 
       4.330782047795958, 0.0347557263614637}, {2.3283710916730604`, 
       4.522153251763843, 0.15661547760642103`}, {2.5425636150176305`, 
       3.6692179522040416`, -0.0347557263614637}, {1.6716289083269396`, 
       3.477846748236157, -0.15661547760642103`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ5qz95ylJvRYbPgk18Xw4Qcfrw7OvG4wd79KVpR
a5s3MTic4Z7xp/uJkEPAfL3EW6Wb9xuJrr3mGMng8IzV559rkTBUfPF+Bghw
gFAiDrn6fwK6zQv2zL26NKjG97+91K/NjLt6RRz8IOrtLVd7L/0x65+98Zd0
5hJpUQd/iPn21xo+fi958dfe9500q95KUYdvEPdgiEPdCTfHBGoO1J32c9Ds
hbrTHoc7bdD9BXXn/mRoOJyFhgPUnfvRww3qTgxxWHgCAOlOoY4=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHY/JsvWqPLT3uXFjoc23cIOjg/4Fi1o3rz/ll5m
5Orc3/bNrtXTNDYJOzBrZ+peY1m1P3f6ljVXt/21P7jI1lvkJkx81n4GCHCA
UCIOOj91qjetS93juWWp5lQVRgf72ENbXquJODBA1NtPzvAO1vJkcqjd1ZJ5
3VfEgRFivv0dmY81+3OZHfaIu8sdLhFxcIC4B0Mc6k4Mc6DutPdCsxfqTnsc
7rRB9xfUnRjhAHXnfg+0cIO6cz+u8AQA8TmPGg==
       "], {{1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}, {1.4406642841535762`, 
       5.301189047566042, 0.037798341297327606`}, {2.297840065609907, 
       5.529240181845588, 0.19025279298221853`}, {2.559335715846424, 
       4.698810952433958, -0.037798341297327606`}, {1.7021599343900928`, 
       4.470759818154412, -0.19025279298221853`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmINY1yI02+8jmYHji/eKOlaIHrpZ27YzP2WN/8pTH
pEpvdoeyVq/cDdKiB54s3lj96tMm+5RUlZN7lrI77HZaanajVwQqvsieAQw4
HCC0yIHqtFrlO1PybebMum3mHMXh4Lo36qR6kfCBRxD1+81Nt+e2beFw6Kra
Osn/idCBxxDz918+P2nJST5Oh/PmAjHlYUIHLkPcgyEOdSeGOVB37ke3F+rO
/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AZRarC4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PuEDUt8v/jWduH1/xvFw
L+ZdrA4FloJhJluED6h8Ef/rnrN+/5bH2ksZ77I57JjDoS11CyY+fz8DGHA4
QGiRA0XeL4Mm6mft8ZG5EvVPidPBI/n7laeqIgcUIOrtZ1is2PrHlcthwrF3
K097ixxQgphv/zikRuB3BrfDdc1ndRsLRQ5IQNyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AfzSfOg==
       "], {{
       2.4415193419221497`, -5.3045316493149475`, 0.018969162302250916`}, {
       2.7059604234085484`, -4.47341104096585, -0.20308814741695236`}, {
       3.5584806580778503`, -4.6954683506850525`, -0.018969162302250916`}, {
       3.2940395765914516`, -5.52658895903415, 0.20308814741695236`}, {
       2.4415193419221497`, -5.3045316493149475`, 
       0.018969162302250916`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmEP3H/cwLRXYHtdZdk55sETwwLeBfT+jj7fbxf/U7
PmSzOxyJqOFxVhY8UJK9Iu34zfX2G/6Ju/zYyu6QpGPXtnCiAFR8vj0DGHA4
QGiBA12RPVcvdGXZBDC+2M3uxeFgs7z58547fAcKIOr3L2S6UM4/hcOhwo/9
eeVO3gNFEPP3f2TeYSx+j8Nhy9euW2bTeA5MgbgHQxzqTgxzoO7cj24v1J37
cbhzD7q/oO7ECAeoO+3Rww3qTgxxWHgCAI3cqOo=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA/+BwuXcwtk7N+9vcn0X
Yr2B1SEoLvXRjAb+A287+Y/0+azaf1CpfJXsDTYHzfVGhT4HYOKz9jOAAYcD
hBY4MGvu9h9lr1L32N/tCH2kzumQvSLt+E15gQOvIOrt63YJrj7iz+VwPeBs
32Z7gQNvIObb750+i2F5ObeD00/jsN54gQMFEPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMAmrqc8g==
       "], {{
       2.4581333076753618`, -4.333340593063415, 0.016264586231646463`}, {
       2.675018691382798, -3.480034218257422, -0.1703606024475165}, {
       3.5418666923246382`, -3.666659406936585, -0.016264586231646463`}, {
       3.324981308617202, -4.519965781742577, 0.1703606024475165}, {
       2.4581333076753618`, -4.333340593063415, 
       0.016264586231646463`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGaK/X+IMYzdYcb9Ha/TarkPqMfE9q1Yscl+zYuQ
66v72B1221d/mhnMdcD0wsW9Dx6ssA8rWfU69Di7w735tj/PaHJCxWfYM4AB
hwOUPtCo2/I5dXeKzaruUJFVFhwOygmH2IyvsR0whqjfHyK+WiOkkMPB9UAL
b9oa1gMmEPP3/1vEYPtvJYdDhoK7yMwmlgNqEPdgiEPdiWEO1J37YfYqQe2F
unM/DnfugfnrLtRfUHdihAPUnfbo4QZ1J4Y4LDwBAQenGQ==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLPYD/jMWMujkbtj/6dbx
aOEVrA77d3DU1sxhPyByWifs6bOl+yvfPl7LeYXNISGmxc7uHEx86n4GMOBw
gNIHJvw7fzzTIWlPu5BM0DdtTocFi6sPHjTkOCAEUW/Pp2qx5E04l4Oj+/em
5mSOA8IQ8+2nmId8e9TM7fDwVZGL61SOA74Q92CIQ92JYQ7Unfbo9kLdaY/D
nTbo/oK6EyMcoO7cjx5uUHdiiMPCEwCAj5re
       "], {{
       2.477597807858436, -3.3633454387878277`, 0.00872019253053169}, {
       2.643606712471798, -2.490882514632804, -0.13705185404883644`}, {
       3.522402192141564, -2.6366545612121723`, -0.00872019253053169}, {
       3.356393287528202, -3.509117485367196, 0.13705185404883644`}, {
       2.477597807858436, -3.3633454387878277`, 
       0.00872019253053169}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7L3Xr/Yw+7Q2jmFZl5PcwHvh5W+aC/dKX9vE0R
r7w3szs8/vBo775YpgNLmiQWnJJYaO8fqfN16U12h6KKj3H39Rih4hPtGcCA
wwFCMxxIbbnMtbwuxmbjsstcUWocDrL8sk6Oi/7uXwRRvz/Jd7noFh8OBys5
q5Yml9/7F0PM3y/0pUqBr5jDIVw3/NjhZz/2f4a4Z78wVDwMKg51J4Y5UHfu
R7cX6s79ONy5B91fUHdihAPUnfbvoOEWAg03qDvtcYUnANDrogs=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/3M609v0Xt8Or98ofS
zd8sZHV4bf1/lWX5//1rT9w/K9m0aD//w83S3y6wOXydW391zm6Y+KT9DGDA
4QChGQ7I/yxZc/VG3J4Pcj5POPU5HVgNHaYaKjEcWA1Rb//QdsYJ4TguB+6k
Bq1kF4YDayDm21+KebJGtpfbQWDygf1T0hgOMELcgyEOdSeGOVB32n9Esxfq
Tnsc7rQRQPMX1J0Y4QB15370cIO6E0McFp4AiG+rbw==
       "], {{
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}, {
       2.612275031121414, -1.5062506453545674`, -0.10431166423424715`}, {
       3.5000835461342934`, -1.6064274528809768`, 0.004134856707837732}, {
       3.387724968878586, -2.493749354645433, 0.10431166423424715`}, {
       2.4999164538657066`, -2.3935725471190232`, -0.004134856707837732}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA4Lecz7/ii7Q579v0sTdL7vf6knYL5DcZa9pYUT
p9dNdof59St7Ek582T+nZKvKheyJ9rIyC1mWvmF3OL8/xM0g5RNUvNGeAQw4
HCD0h/0Rh5onsXL62jx+HPc7SpjDIakhrHi++ev9syDq9x8/vvfbVjUOh8MM
a5/Z5T/bPxti/v5Vq2U+CVhxOKg2MkfdW/Zw/3OIe+DiKlBxqDvh5hyCmgN1
536YvYlQe6Hu3I/DnXvQ/QV1Jzwc5kHDAepOe/Rwg7oTQxwWngD84KQi
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7/3+hU01tVZdK/b/L7l9
X2weq0N0yK26hSXv9x9kDP6nFrNgf8Out/nc59kc9LRy9wfsgolP2M8ABhwO
EPrD/jdMpn8dXKL3NLgKTfhiwOnwMstzwXWlD/sPQNTbM3arKLxM5HK4dHWS
w3rXDzDz7RsvmG24O4nbYY/DnQdtGR/2L4C4B0Mc6k6c5qDbC3WnPQ532qD7
C+pOnOGAHm5Qd2KIw8ITAN69pfo=
       "], {{
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}, {
       2.5816407345077046`, -0.5261004423591564, -0.07344885461707322}, {
       3.4750645333984003`, -0.5771389524162092, 0.022410344560020643`}, {
       3.4183592654922954`, -1.4738995576408436`, 0.07344885461707322}, {
       2.5249354666015997`, -1.4228610475837908`, -0.022410344560020643`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjgcDh9BgTu7GdAARwOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIA9mxGvg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJb61Cyvl83iwAAFCbMDwufnL9+/51t41sk5rHDx
RhUx+Xr7+fvjfmtvTTnHhibevx/C44CLHyie5GLPFbVnEcsVr9mGnHDxOoh6
exfOFVPNkrng4g0Q8+2f8dY8uDiFGy4eD3EPhjjUnRjmQN1pj24v1J32ONxp
g+4vqDsxwgHqzv3o4QZ1J4Y4LDwBQAFbOQ==
       "], {{
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}, {
       2.5523340665952334`, 0.4499999999999999, -0.04577348652701718}, {
       3.4476659334047666`, 0.4499999999999999, 0.04577348652701718}, {
       3.4476659334047666`, -0.4499999999999999, 0.04577348652701718}, {
       2.5523340665952334`, -0.4499999999999999, -0.04577348652701718}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF61WuaTgBWHg0ojc9S9ZQ/tX+oJmO9QnLX/+PG9
37aqcTgcYlj7zC7/mf2ckq0qF7In7n/8OO53lDCHQ2JDWPF889dQ8cb9DGDA
4QChP9hHHGqexMrpu0dWZiHL0jfsDuf3h7gZpHyynwVRb29p4cTpdZPdYV79
yp6EE1/sZ0PMtw8Lecz7/ii7Q579v0sTdL7bP4e4B0Mc6k64OfOh5kDdaY9u
L9Sd9jjcaQPzVxLUX1B3wsPhMDQcoO7cDws3VWi4Qd25H1d4AgAIL5u5
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK7XP+mvlMvi0FnnbvdJ7739wqaaWquuFfv/l9y+
LzaP1SE65FbdwpL39gcZg/+pxSzY37DrbT73eTYHPa3c/QG7YOIT9jOAAYcD
hP5g/4bJ9K+DS/SeBlehCV8MOB1eZnkuuK70wf4ARL09Y7eKwstELodLVyc5
rHf9ADPfvvGC2Ya7k7gd9jjcedCW8cF+AcQ9GOJQd+I0B91eqDvtcbjTBt1f
UHfiDAf0cIO6E0McFp4ArvKeeg==
       "], {{2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}, {2.5249354666015997`, 
       1.4228610475837908`, -0.022410344560020643`}, {3.4183592654922954`, 
       1.4738995576408436`, 0.07344885461707322}, {3.4750645333984003`, 
       0.5771389524162092, 0.022410344560020643`}, {2.5816407345077046`, 
       0.5261004423591564, -0.07344885461707322}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb+UqXAV8zhEKYbfuzwsx/2Xw+rfNBfunJ/ku9y
0S0+HA5WclYtTS6/7Zc0SSw4JbFw/8Zll7mi1DgcZPllnRwX/YWKT9zPAAYc
DhCawSG15TLX8rqYPf6ROl+X3mR3KKr4GHdfj9FhEUS9/bxNEa+8N7M7PP7w
aO++WCaHxRDz7d9xt97/2MPuEJJ5RWZeD7PDZ4h77N9CxUOh4lB3YpgDdac9
ur1Qd9rjcKcNur+g7sQIB6g79wtBwy0cGm5Qd+7HFZ4A33iaug==
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINZbLB38qIjF4cHNuoZrRv/tmdae36J2ePV++UPp
5m8Wsjq8tv6/yrL8v/3aE/fPSjYt2s//cLP0twtsDl/n1l+dsxsmPmk/Axhw
OEBoBgf5nyVrrt6I2/NBzucJpz6nA6uhw1RDJQaH1RD19g9tZ5wQjuNy4E5q
0Ep2YXBYAzHf/lLMkzWyvdwOApMP7J+SxuDACHEPhjjUnRjmQN1p/xHNXqg7
7XG400YAzV9Qd2KEA9Sd+9HDDepODHFYeAIAWKSj7w==
       "], {{2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}, {2.4999164538657066`, 
       2.3935725471190232`, -0.004134856707837732}, {3.387724968878586, 
       2.493749354645433, 0.10431166423424715`}, {3.5000835461342934`, 
       1.6064274528809768`, 0.004134856707837732}, {2.612275031121414, 
       1.5062506453545674`, -0.10431166423424715`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP63iMH230oOhwwFd5GZTSwO6jGxfStWbNofIr5a
I6SQw8H1QAtv2hpWB9MLF/c+eLBi/6ruUJFVFhwOSgmH2IyvsUHFZ+xnAAMO
BxjdqNvyOXV3yp6wklWvQ4+zO9ydb/vzjCangzFEvf2aFyHXV/exO+y2r/40
M5jLwQRivj1T7P9DjGHsDjPu73idVsvtoAZxD4Y41J0Y5kDdaQ+z9x7UXqg7
7XG40wbmL2Wov6DuxAgHqDv3o4cb1J0Y4rDwBAAedp8h
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM45sZpTtobFQV60d/euLHYH/xkLGXRyN+z/dOt4
tPAKVof9Ozhqa+awO4ic1gl7+mzp/sq3j9dyXmFzSIhpsbM7BxOfup8BDDgc
YPSEf+ePZzok7WkXkgn6ps3psGBx9cGDhhwOQhD19nyqFkvehHM5OLp/b2pO
5nAQhphvP8U85NujZm6Hh6+KXFyncjj4QtyDIQ51J4Y5UHfao9sLdac9Dnfa
oPsL6k6McIC6cz96uEHdiSEOC08AUMSTXg==
       "], {{2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}, {2.477597807858436, 
       3.3633454387878277`, 0.00872019253053169}, {3.356393287528202, 
       3.509117485367196, 0.13705185404883644`}, {3.522402192141564, 
       2.6366545612121723`, -0.00872019253053169}, {2.643606712471798, 
       2.490882514632804, -0.13705185404883644`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP7IvMNY/B6Hw5avXbfMpvE4TAv41xP6ePv+hUwX
yvmncDhU+LE/r9zJ61CSvSLt+M31+wMYX+xm9+JwsFne/HnPHT6o+Pz9DGDA
4QChBRy6InuuXujK2rPhn7jLj63sDkk6dm0LJwo4FEDU28f/1e/4kM3ucCSi
hsdZWdChCGK+Pf8f9zMvFNkd1Fp3TXqyRdBhCsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEALMkod0=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbOSP0f0cHiUM07I/ipA79D4XJu4eydm/c3ub4L
sd7A6hAUl/poRgO/w9tO/iN9Pqv2H1QqXyV7g81Bc71Roc8BmPis/QxgwOEA
oQUcZs3d/qPsVeoe+7sdoY/UOR2yV6Qdvykv4PAKot6+bpfg6iP+XA7XA872
bbYXcHgDMd9+7/RZDMvLuR2cfhqH9cYLOBRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwBq75Vy
       "], {{2.675018691382798, 
       3.480034218257422, -0.1703606024475165}, {2.4581333076753618`, 
       4.333340593063415, 0.016264586231646463`}, {3.324981308617202, 
       4.519965781742577, 0.1703606024475165}, {3.5418666923246382`, 
       3.666659406936585, -0.016264586231646463`}, {2.675018691382798, 
       3.480034218257422, -0.1703606024475165}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL58ftKSk3ycDufNBWLKw4QcrpZ27YzP2bPf3HR7
btsWDoeuqq2T/J8IOTxZvLH61adN++fMum3mHMXh4Lo36qR6kTBUfNF+BjDg
cIDQIg7VabXKd6bk70lJVTm5Zym7w26npWY3ekUcHkHU25885TGp0pvdoazV
K3eDtKjDY4j59roGudFmH9kcDE+8X9yxUtThMsQ9GOJQd2KYA3WnPbq9UHfa
43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAMgFpRQ=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJZd3fyeZTqLg+Y1yUa/PmEHqe8X/5pO3L4/43i4
F/MuVocCS8Ewky3CDipfxP+656zfv+Wx9lLGu2wOO+ZwaEvdgonP388ABhwO
EFrEocj7ZdBE/aw9PjJXov4pcTp4JH+/8lRVxEEBot5+hsWKrX9cuRwmHHu3
8rS3iIMSxHz7xyE1Ar8zuB2uaz6r21go4iABcQ+GONSdGOZA3WmPbi/UnfY4
3GmD7i+oOzHCAerO/ejhBnUnhjgsPAFPaZe6
       "], {{2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}, {2.4415193419221497`, 
       5.3045316493149475`, 0.018969162302250916`}, {3.2940395765914516`, 
       5.52658895903415, 0.20308814741695236`}, {3.5584806580778503`, 
       4.6954683506850525`, -0.018969162302250916`}, {2.7059604234085484`, 
       4.47341104096585, -0.20308814741695236`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM77nM3y7h2fw9uZcW9lVokeyBS6+aK7bbe956JP
TF88+R2+7H7pISwjemBOovXsTZGb7FUDKxl/LeF3+HW3ZAlnnwhUfJE9AxgI
OEBokQMRvjuY6qfm2eSFO/9v0hVwYFPqjv5WKHxgFkT9/tvr2v6xRgs48LiI
bX/zWOjAbIj5+z3ZTv3t6BBwEE5bKPQ4VOhAOsQ9GOJQd2KYA3XnfnR7oe7c
j8Ode9D9BXUnRjhA3WmPHm5Qd2KIw8ITAGUgoHk=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSh84GRDd733ld37+RQe
W6rv43WoEppsOnOb8IE2hthV7b2b9rNP+DhH+D6fg23nyVk+t2Hii/YzgIGA
A4QWOWAS9kH60eu8PX/M2w3LJgg4HC4zS92sInKgBaLe/mc+X/IbBUGHtrc5
p9I8RQ60Qsy3/7p86pSkjYIOXimL9aXyRA4ch7gHQxzqTgxzoO60R7cX6k57
HO60QfcX1J0Y4QB15370cIO6E0McFp4AdYmgyw==
       "], {{
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}, {
       3.710107463666265, -4.476352259400707, -0.21622988032011106`}, {
       4.556562697496302, -4.691395793388974, 0.0011863463318433354`}, {
       4.289892536333735, -5.523647740599293, 0.21622988032011106`}, {
       3.443437302503698, -5.308604206611026, -0.0011863463318433354`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN4g8S32kDy/g3vgIQW7rYIHbrpr2R7W3G5/KvXn
5MYsfofW7sYDdcqCByq4Hi+LfLTO/ummPycdtvI7HDrqkLB/ogBUfJ49AxgI
OEDpAzs6hLgX7Mm06V3GODteVcChuqTOvvEO34ESiPr90r7MZvu9BBy+v/hT
x7ST90AZxPz9Kz6zXJQrEHAoiq3e1zyV58B1iHswxKHuxDAH6s796PZC3bkf
hzv3oPsL6k6McIC60x493KDuxBCHhScA3taehg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvEfkFPMLOSQ3LF/tuHb
4+xbeB2uFafMLGvhP5CVPdt7g8CG/WdnfHvMfIvP4bXlJh/rQzDxBfsZwEDA
AUofYN28VqP6WNaemZtZ+P5NEnDgerws8pGcwIEMiHp743ROmT+qgg6ix3w3
H7EVOJAJMd/+jBSf1q8dgg7yK7/wLI8ROCALcQ+GONSdGOZA3WmPbi/UnfY4
3GlzDs1fUHdihAPUnfvRww3qTgxxWHgCAMRgk2U=
       "], {{
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}, {
       3.678850754562714, -3.4825241906231894`, -0.18461297046761505`}, {
       4.5401343565350665`, -3.6634861856200236`, 0.00365097547078104}, {
       4.321149245437287, -4.51747580937681, 0.18461297046761505`}, {
       3.4598656434649335`, -4.336513814379977, -0.00365097547078104}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIJ61N2GTTgi/w7sFKXeO1HIfyDOWfmkou8l+z+Wp
isW9/A7zD7yddCOY64Dd+3Nmb9VW2N97eWrCzmP8DgEPyjzfaHJCxWfYM4CB
gAOE5jiwWSY8okAhxUawe5b5YhkBh43ynduEr7EdsIGo368kZprvZingkGgv
lKu+hvWALcT8/cYLzy97GSrgIBQ/W9m6ieVALsQ9GOJQd2KYA3Xnfpi9G6D2
Qt25H4c798D85Q/1F9SdGOEAdac9erhB3YkhDgtPADECmQ4=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPvuBEqu2S58ebtmvdH9C
RO9qXgfnIyreKfPZD3z05ch7d331/on5HmuOXeVzUEqapLrpPEx89n4GMBBw
gNAcBzymbYz+aJy+x/zE7ZUyUwUc7s3NveVrwHHgHUS9ff6E7cGWWoIOe61v
b5mdwHHgA8R8+2URk/+G7hd0mH3To//lBI4DxRD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAMplplI=
       "], {{
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}, {
       3.6470476573032444`, -2.492831381576873, -0.1523306806642988}, {
       4.52075058797933, -2.634347341146244, 0.010814721094927732`}, {
       4.352952342696756, -3.507168618423127, 0.1523306806642988}, {
       3.4792494120206703`, -3.365652658853756, -0.010814721094927732`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP402Ydvdje/Q+Lj19xHe5gPHHf/Wbzi9Qr779vv
xqVv4ndwdJq76UYs0wGD1t/fpeYusP99O2+98U1+B4WFfpFv9Bih4hPsGcBA
wAFCMxxY0vHDvWlDtA3TJA+NNGEBhwN7k3zVF/3drwdRv59VZWLAGTUBh/rq
o7P8XH7v14eYv599280KIysBB3tLjRelz37sPwpxD1zcDioOdSeGOVB37ofZ
ux9qL9Sd+3G4cw+6v6DuhIeDAzQcoO60Rw83qDsxxGHhCQBDpaoH
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/3Zx8q9G5K2bTf+cgh
dqWlvA7XlB00xKv/758Q4cTP3LZiv2LSQ+aJl/gcXgsqTOneCxOfsZ8BDAQc
IDTDgfIvieZr81P2vPfjr9s+TcCB6/t7UytFhgO9EPX29+bK/cnTFXQQfXc/
u8SJ4UA/xHz7c290q9SOCDrIPz2/cF0yw4EsiHswxKHutL+PZg7Unfbo9kLd
aY/DnTZKaP6CuhMeDteh4QB15/5UtHCDunM/rvAEAGxLlYo=
       "], {{
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}, {
       3.615280131564128, -1.5075918604915728`, -0.12051907308195917`}, {
       4.4983861897860224`, -1.6049377165038257`, 0.023173217069706202`}, {
       4.384719868435872, -2.492408139508427, 0.12051907308195917`}, {
       3.501613810213978, -2.3950622834961743`, -0.023173217069706202`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHacfv625VF+B75rqz0X63zfX5yj/P9kxkz7Bn5T
24s3+B24nhy/nXPiy/7Fc8VXtX2YYH+gfda8jDf8DqyfHueapXyCijfYM4CB
gAOE/rA/eWONdLe1j43Cnk0bTnMKOHyXtlCZbP56/0KI+v0OFamJ04UFHN6Z
F3io5T/bvwhi/v4EEwmhZFkBh2fBK3J2Lnu4vxDiHrj4E6g41J1wc95CzYG6
cz/M3m9Qe6Hu3I/DnXtg/mKB+gvqTng4cELDAepOe1i48ULDDepOe1zhCQAe
eKll
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7vv3PlxQaGCxv2m7GH
d8kv5HUQdl5/qrri/f7qY93TVmct2z+7Wfto/wU+h86F4U9t98DEp+1nAAMB
Bwj9YX+aqvwKy3VJe4zssmR3TBdwsNYP4X2o+GF/JUS9fWrNFasCfUGH8rgV
UoecP+yvgphvP32XXYTGcUGHTb1/1Benfth/G+Ie+xlo4lB3YpgDdae9MZq9
UHfa43CnDbq/oO7ECAeoO/ejhxvUnRjisPAEAKHjriA=
       "], {{
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}, {
       3.5842083968149794`, -0.5267882881396561, -0.09048767031498518}, {
       4.473188077503202, -0.5764158901397218, 0.04086006831491938}, {
       4.415791603185021, -1.473211711860344, 0.09048767031498518}, {
       3.5268119224967984`, -1.4235841098602782`, -0.04086006831491938}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcDh9BgTu7GdAAQIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIATatHNg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIHbn909dnM/jwAAF7NsmK9q5btivz9XlfGg+L1x8
y6cjOis2Lt0vwXpU8eF5PjTxqfshPAG4uMMpP1UekaQ9JbWy+fwzEOKbIOrt
X/yyuidnIAgX3wwx3z6mIsJX7wRCnBXiHgxxqDsxzIG60x7dXqg77XG40wbd
X1B37jdACweoO/d7oIUb1J37cYUnALFVY88=
       "], {{
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}, {
       3.554510871386728, 0.4499999999999999, -0.06355655975104223}, {
       4.445489128613271, 0.4499999999999999, 0.06355655975104223}, {
       4.445489128613271, -0.4499999999999999, 0.06355655975104223}, {
       3.554510871386728, -0.4499999999999999, -0.06355655975104223}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE4wkRBKlhVweBK8Imfnsof2xTnK/09mzNzvUJGa
OF1YwOGteYGHWv4z+8VzxVe1fZiwX2HPpg2nOQUcvklbqEw2fw0Vb9jPAAYC
DhD6g33yxhrpbmufPQfaZ83LeMPvwPLpca5Zyif7hRD19g38prYXb/A7cD45
fjvnxBf7RRDz7R2nn79teZTfgffaas/FOt/tCyHugYvzQcWh7oSbwwU1B+pO
e5i9rFB7oe60x+FOG5i/vkP9BXUnPBzeQcMB6s79sHB7Bg03qDv34wpPABv9
oRE=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIL7Y1eS/vpDHYc4Ttg07Td7b37nyYgPDhQ37zdjD
u+QX8joIO68/VV3x3r76WPe01VnL9s9u1j7af4HPoXNh+FPbPTDxafsZwEDA
AUJ/sE9TlV9huS5pj5FdluyO6QIO1vohvA8VP9hXQtTbp9ZcsSrQF3Qoj1sh
dcj5g30VxHz76bvsIjSOCzps6v2jvjj1g/1tiHvsZ6CJQ92JYQ7UnfbGaPZC
3WmPw5026P6CuhMjHKDu3I8eblB3YojDwhMAchimoA==
       "], {{3.5842083968149794`,
        0.5267882881396561, -0.09048767031498518}, {3.5268119224967984`, 
       1.4235841098602782`, -0.04086006831491938}, {4.415791603185021, 
       1.473211711860344, 0.09048767031498518}, {4.473188077503202, 
       0.5764158901397218, 0.04086006831491938}, {3.5842083968149794`, 
       0.5267882881396561, -0.09048767031498518}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIGbfdrPCyErAwc5S40Xpsx/2x91/Fq94vWI/q8rE
gDNqAg711Udn+bn8tjdo/f1dau6C/UyTPDTShAUc9u9N8lVf9BcqPmE/AxgI
OEBoBoclHT/cmzZE7/l9O2+98U1+B4WFfpFv9Bgd9CDq7b9vvxuXvonfwcFp
7qYbsUwO+hDz7T9N9uGb3c3vkPj4NffRHmaHoxD3YIhD3Qk3xxFqDtSd9uj2
Qt1pj8OdNjB/HYD6C+pOjHCAunM/LNzsoeEGded+XOEJAFg6osg=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5RW8K9uZzH4ZBpwp5FFv/tsw8VejelbNrvfOQQ
u9JSXodryg4a4tX/7SdEOPEzt63Yr5j0kHniJT6H14IKU7r3wsRn7GcAAwEH
CM3gUP4l0Xxtfsqe9378ddunCThwfX9vaqXI4NALUW9/b67cnzxdQQfRd/ez
S5wYHPoh5tufe6NbpXZE0EH+6fmF65IZHLIg7sEQh7rT/j6aOVB32qPbC3Wn
PQ532iih+QvqTng4XIeGA9Sd+1PRwg3qzv24whMAPICOCg==
       "], {{
       3.615280131564128, 1.5075918604915728`, -0.12051907308195917`}, {
       3.501613810213978, 2.3950622834961743`, -0.023173217069706202`}, {
       4.384719868435872, 2.492408139508427, 0.12051907308195917`}, {
       4.4983861897860224`, 1.6049377165038257`, 0.023173217069706202`}, {
       3.615280131564128, 
       1.5075918604915728`, -0.12051907308195917`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZeeH7Zy1ABB6H42crWTSwOecbSLw1lN+1XEjPN
d7MUcEi0F8pVX8PqYPf+nNlbtRX7BbtnmS+WEXDYIN+5TfgaG1R8xn4GMBBw
gNAcDptlwiMKFFL23Ht5asLOY/wO/g/KPN9ocjrYQNTb77k8VbG4l99h/oG3
k24EcznYQsy3n7U3YZNOCL/DuwUpd47UcjvkQtyDIQ51J4Y5UHfaw+wNgNoL
dac9DnfawPy1EeovqDsxwgHqzv3o4QZ1J4Y4LDwBQUWQgw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN7id5MlpJHHIVVte4FYPrtDiVXbpU8Pt+xXuj8h
onc1r4PzERXvlPnsDh99OfLeXV+9f2K+x5pjV/kclJImqW46DxOfvZ8BDAQc
IDSHg8e0jdEfjdP3mJ+4vVJmqoDDvbm5t3wNOBzeQdTb50/YHmypJeiw1/r2
ltkJHA4fIObbL4uY/Dd0v6DD7Jse/S8ncDgUQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Ampqe0g==
       "], {{3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}, {3.4792494120206703`, 
       3.365652658853756, -0.010814721094927732`}, {4.352952342696756, 
       3.507168618423127, 0.1523306806642988}, {4.52075058797933, 
       2.634347341146244, 0.010814721094927732`}, {3.6470476573032444`, 
       2.492831381576873, -0.1523306806642988}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF7xmeWiXIGAQ1Fs9b7mqTwON921bA9rbt8v7cts
tt9LwOH7iz91TDt5HSq4Hi+LfLRuf+8yxtnxqgIO1SV19o13+KDi8/YzgIGA
A4ze0SHEvWBP5p6nm/6cdNjK73DoqEPC/okCDiUQ9fanUn9Obszid2jtbjxQ
pyzoUAYx336DxLfYQ/L8Du6BhxTstgo6XIe4B0Mc6k4Mc6DutEe3F+pOexzu
tEH3F9SdGOEAded+9HCDuhNDHBaeAA22mDc=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIM449Xg1dx+Pw8G1Ys82uvE7yClmFnJI7tg/2/Dt
cfYtvA7XilNmlrXwO2Rlz/beILBh/9kZ3x4z3+JzeG25ycf6EEx8wX4GMBBw
gNGsm9dqVB/L2jNzMwvfv0kCDlyPl0U+khNwyICotzdO55T5oyroIHrMd/MR
WwGHTIj59mek+LR+7RB0kF/5hWd5jICDLMQ9GOJQd2KYA3WnPbq9UHfa43Cn
zTk0f0HdiREOUHfuRw83qDsxxGHhCQCUlYvl
       "], {{3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}, {3.4598656434649335`, 
       4.336513814379977, -0.00365097547078104}, {4.321149245437287, 
       4.51747580937681, 0.18461297046761505`}, {4.5401343565350665`, 
       3.6634861856200236`, 0.00365097547078104}, {3.678850754562714, 
       3.4825241906231894`, -0.18461297046761505`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPZkO/W3o0PAQThtodDjUCGHTKGbL7rbdu+/va7t
H2u0gAOPi9j2N4+FHOYkWs/eFLlpf1648/8mXQEHNqXu6G+FwlDxRfsZwEDA
AUKLOET47mCqn5q3RzWwkvHXEn6HX3dLlnD2iTjMgqi391z0iemLJ7/Dl90v
PYRlRB1mQ8y3z/uczfLuHZ/D25lxb2VWiTqkQ9yDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08Aa8CXvw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBbbcOWa1Vweh22zYy48nSjscLKhu977yu79fAqP
LdX38TpUCU02nblN2KGNIXZVe++m/ewTPs4Rvs/nYNt5cpbPbZj4ov0MYCDg
AKFFHEzCPkg/ep235495u2HZBAGHw2VmqZtVRBxaIOrtf+bzJb9REHRoe5tz
Ks1TxKEVYr791+VTpyRtFHTwSlmsL5Un4nAc4h4Mcag7McyButMe3V6oO+1x
uNMG3V9Qd2KEA9Sd+9HDDepODHFYeAIARb6ZSw==
       "], {{3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}, {3.443437302503698, 
       5.308604206611026, -0.0011863463318433354`}, {4.289892536333735, 
       5.523647740599293, 0.21622988032011106`}, {4.556562697496302, 
       4.691395793388974, 0.0011863463318433354`}, {3.710107463666265, 
       4.476352259400707, -0.21622988032011106`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOY8o/zqaJmwg99v8Yz3q0QPSAecZ9xZt8t+o1Hu
x+Ylwg6dy3fNmi8jemBf1/3VF1ZutI+Yue2H4yVhh6PBsWf9+0Sg4gvtGcBA
xAFKH5hgI38yuiDXZkWaJ/s+XREH6zWLjDYUCh/YA1G/3//sJL6aaBGH8gjX
1ITHQgf2Qszf/934jqhVp4jDJpYX0wVChQ5IQdyDIQ51J4Y5UHfuR7cX6s79
ONy5B91fUHdihAPUnfbo4QZ1J4Y4LDwBQDylww==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIHDu/Z6xSscmD//2m3
7256KORwtTFgb8RO4QPrf/+JONK6dX/D6bd5NwuEHV47rIhbcwcmvnQ/AxiI
OEDpA3suXvpS8b5wT4OJ0ES1fhEH0f3hC4OVRQ6shai3Z8xUUfKVE3XQrlvv
tNxN5MA6iPn2jXPNNhevFXVwsGV/8itT5MAhiHswxKHuxDAH6k57dHuh7rTH
4U4bdH9B3YkRDlB37kcPN6g7McRh4QkAfNSs8Q==
       "], {{
       4.446602686144281, -5.313432754060626, -0.02261242355976882}, {
       4.714623967510865, -4.4795749765342965`, -0.22960469296484698`}, {
       5.553397313855719, -4.686567245939374, 0.02261242355976882}, {
       5.285376032489135, -5.5204250234657035`, 0.22960469296484698`}, {
       4.446602686144281, -5.313432754060626, -0.02261242355976882}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF59+aa4fr+wg3bnnPojWwUPPN+gyawcuM1etvcZ
/6ktwg6ybMKhN5QFD3RNM2dpObjWvs/tM3vqLWEHvuZOrTcTBaDic+0ZwEDE
AUILHJBd0cz87nSGTdFOnh+zVEUcHv98s0r9Dt+Bdoj6/Y+LJD+Yeos4HP98
M9R/B++BToj5+0N11F5cKBBxWPX2GEP5FJ4DzyDuwRCHuhNuzjGoOVB37ke3
F+rO/TjcuQfdX1B3YoQD1J326OEGdSeGOCw8AX7empM=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwH+vKnp/du2bP/b4Tj
xoY7Qg7LFN+//9nBfyDBa9d7DuXN++vXLIhwyBN2uDzh+/eaIzDxxfsZwEDE
AUILHJin9vAJ39P8PY3B8cv3TxRxmG7O0nJQVuBAHES9PfPyfX71yqIOuvkc
HM3WAgfiIebbt/yS/Wa3VdThyDKeHpdIgQM9EPdgiEPdiWEO1J326PZC3WmP
w5026P6CuhMjHKDu3I8eblB3YojDwhMA8Aae1A==
       "], {{
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}, {
       4.683173925161513, -3.485317056463843, -0.19930555921848897`}, {
       5.537169907483723, -3.6596681540899216`, 0.024954461592410312`}, {
       5.316826074838487, -4.514682943536157, 0.19930555921848897`}, {
       4.462830092516277, -4.340331845910078, -0.024954461592410312`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIOZ9aby5fKWwgxSjjlNUHfeBmatfs18t32jP4Xb2
jP8xYQfBMFkdmxCuA2eePIkv9Fpuz7I47Zn6Y2EHztV8YnJanFDx6fYMYCDi
AKE5DoRkvjy/OSPZ5k/MTMkbMiIOP0I+vnx4le3AKYj6/T92GhlvsBRxeL/y
0eXDq1kPnIaYv/+z2BmfjjARh+f/Lu9d2shyYDrEPXDxZ1BxqDsxzIG6cz/M
3u9Qe6Hu3I/DnXtg/uKA+gvqToxwgLrTHhZuktBwg7rTHld4AgB2yaTn
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewHjotXCcbP2bnfxN3k
juINIYfcnAara4vYD7TuWsb9Smjj/lnKUu8EcoQdzMwcZLMvwsQX7mcAAxEH
CM1xwKjnQMbtkpw9aXeeCr6fLOJw6uT+R1P0OA40Q9Tbn9lxWvmeuqjD5Mn1
RzVjOQ60QMy3N5y60fTsblGH2Fj7Ffu6OQ4chbjH3ghNHOpODHOg7rRHtxfq
Tnsc7rRB9xfUnRjhAHXn/vNo4QZ1535c4QkABlSbCg==
       "], {{
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}, {
       4.651104317658282, -2.495069664572104, -0.1682770311360975}, {
       5.517904318733632, -2.631539151635964, 0.031807544072237376`}, {
       5.348895682341718, -3.504930335427896, 0.1682770311360975}, {
       4.482095681266368, -3.368460848364036, -0.031807544072237376`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA5dH6oddlTY4dFzyQy2XuYDPSp8zRd4Vthbnnos
8+SGsMO0WWmuLHFMBzbncjJ1cyywl3layFf0RtjB23ezEpM+I1R8gj0DGIg4
QGiGA1e28a97viPK5olU38deYRGHrNSZu34v/Lt/I0T9/uOmMo+l1UUcrpwy
Kv3u/Hv/Joj5+1cHrLqy0krEwc7gjP7npz/2d0HcAxe3hYpD3Qk35zLUHKg7
96PbC3Xnfhzu3IPuL6g7McIB6k57WLg9hIYb1J32uMITAFbOk70=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//739/lKvtpsn1/UMTx
XeevCDlM2vJ++e76//unXkqe6/Nx3X7NNcl307OEHTxvfb98dz9MfN5+BjAQ
cYDQDAeq9S/rip7M3HM9eI7SjKkiDreFWMQEFRgOTIKot1+33MLVQFvUYbsq
h46SA8OByRDz7Vt+X0k/cUDUYZIFj5NxAsOBtxD3YIhD3YlhDtSd9uj2Qt1p
j8OdNuj+groTIxyg7tyPHm5Qd2KIw8ITAFR4qAI=
       "], {{
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}, {
       4.619023991127767, -1.5091673571695932`, -0.1376248429459686}, {
       5.495552964467648, -1.6031128909181338`, 0.043679309197428254`}, {
       5.380976008872233, -2.490832642830407, 0.1376248429459686}, {
       4.504447035532352, -2.396887109081866, -0.043679309197428254`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIBb9oXg65pGwg3ZBS+dhne/7+62+aO7rmGHPF3Dw
ju0bYQfZBWujm0582Z9Q41uoGT3Bnn1Fwju5b8IOfBeu6TqmfIKKN9gzgIGI
A4T+sH++SmP6LCdvm5/h8wUfcoo4PIkPWlJr/np/HET9/k/r7ZQPCYs4HN+/
xON33rP98RDz979mv2eyWFbEYbX89zcVyx7u74O4By6+CioOdSfcnGNQc6Du
3A+z9zHUXqg79+Nw5x50f0HdCQ8HGWg4QN1pDws3LWi4Qd1pjys8AY+uo70=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f751x7nzVp7db9tlWC
obsvCTnITindolb7fn9N8avHuc/X7Jfb27EqNlPYge+UVdTkfTDxOfsZwEDE
AUJ/2D9x64wXBmIZex45lYcumibi8HPWo6BtCh/2V0LU2x9ufbfKRVfU4aPp
0aU5jh/2V0HMt196IpXh+WFRh1cXlv9QSvqwfzbEPRjiUHfCzfkENQfqTnt0
e6HutMfhThuYv/ih/oK6EyMcoO7cjx5uUHdiiMPCEwC6Tri6
       "], {{
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}, {
       4.587632007445626, -0.527612201225504, -0.10863888017492673`}, {
       5.470253784431534, -0.5755304662070981, 0.060720615193332494`}, {
       5.412367992554374, -1.472387798774496, 0.10863888017492673`}, {
       4.529746215568466, -1.4244695337929019`, -0.060720615193332494`}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhgQcTh9BgTu7GdAASIOxmBwGYf4YQzxf/9BoH8P
urghRL09urgRxHwM8ZMQ92CIn8YhbozDHGMc9kLdaYPDnRj+MsIRDidxhBt6
eAIAeUNHcg==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmINa4w/eMw1rIgQEKHN8JB6iqb91/dNKWd6yXEOLM
k6UOGJqs2Z/sGfWdKVMYTXzOfghPBC6uoyqmcKUhfc/cbUs5/k5DiDNA1Ntb
53oL/tIVhYszQsy3v6H8UfL7EYS4A8Q9GOJQd2KYA3WnPbq9UHfa43CnDbq/
oO7ECAeoO/ejhxvUnRjisPAEAJHdWYk=
       "], {{
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}, {
       4.557651133210165, 0.4499999999999999, -0.08262856678987253}, {
       5.442348866789835, 0.4499999999999999, 0.08262856678987253}, {
       5.442348866789835, -0.4499999999999999, 0.08262856678987253}, {
       4.557651133210165, -0.4499999999999999, -0.08262856678987253}}, \
CompressedData["
1:eJxTTMoPSmViYGDgB2JmIH7Nfs9ksayIwyr5728qlj2077f6ormvY8b+T+vt
lA8Jizgc27/E43feM/uEGt9CzegJ+3+Gzxd8yCni8Dg+aEmt+WuoeMN+BjAQ
cYDQH+znqzSmz3Ly3sO+IuGd3DdhB74L13QdUz7Zx0HU2/MFHLxj+0bYQWbB
2uimE1/s4yHm24v+UDwd80jYQaugpfOwznf7Poh74OLaUHGoO+HmyELNgbrT
Ht1eqDvtcbjTBuavJ1B/Qd0JD4fj0HCAunM/LNxWQ8MN6s79uMITALm+nWg=

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmII42n/VfwkbIQSduA98u6/f2c669z5q0dut+2yrB
0N2XhBxkp5RuUat9b19T/Opx7vM1++X2dqyKzRR24DtlFTV5H0x8zn4GMBBx
gNAf7CdunfHCQCxjzyOn8tBF00Qcfs56FLRN4YN9JUS9/eHWd6tcdEUdPpoe
XZrj+MG+CmK+/dITqQzPD4s6vLqw/IdS0gf72RD3YIhD3Qk35xPUHKg77dHt
hbrTHoc7bWD+4of6C+pOjHCAunM/erhB3YkhDgtPAIqDsTo=
       "], {{
       4.587632007445626, 0.527612201225504, -0.10863888017492673`}, {
       4.529746215568466, 1.4244695337929019`, -0.060720615193332494`}, {
       5.412367992554374, 1.472387798774496, 0.10863888017492673`}, {
       5.470253784431534, 0.5755304662070981, 0.060720615193332494`}, {
       4.587632007445626, 
       0.527612201225504, -0.10863888017492673`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF4dsOrKSisRB1uDM/qfn/6w71Hha77As2L/cVOZ
x9LqIg6XTxmVfnf+bb85l5Opm2PB/idSfR97hUUcslJn7vq98C9UfMJ+BjAQ
cYDQDA5XtvGve74jao/M00K+ojfCDt6+m5WY9BkdNkLU21ueeizz5Iaww7RZ
aa4scUwOmyDm24euD9UOOyrs8PC5ZAZbL7NDF8Q9cPFHUHGoOzHMgbrTHt1e
qDvtcbjTBt1fUHfCw+EKNByg7twPCzc7aLhB3bkfV3gCAJTDjtI=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5h0Z5hbi/kcKfvefVM+//27+9ylf002b4/KOL4
rvNXhBwmbXm/fHf9f/upl5Ln+nxct19zTfLd9CxhB89b3y/f3Q8Tn7efAQxE
HCA0g0O1/mVd0ZOZe64Hz1GaMVXE4bYQi5igAoPDJIh6+3XLLVwNtEUdtqty
6Cg5MDhMhphv3/L7SvqJA6IOkyx4nIwTGBzeQtyDIQ51J4Y5UHfao9sLdac9
DnfaoPsL6k6McIC6cz96uEHdiSEOC08AJK2ggg==
       "], {{4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}, {4.504447035532352, 
       2.396887109081866, -0.043679309197428254`}, {5.380976008872233, 
       2.490832642830407, 0.1376248429459686}, {5.495552964467648, 
       1.6031128909181338`, 0.043679309197428254`}, {4.619023991127767, 
       1.5091673571695932`, -0.1376248429459686}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP4sdsanI0zE4dm/y3uXNrI4zFz9mv1q+cb9P3Ya
GW+wFHF4v/LR5cOrWR3OPHkSX+i1fP+fmJmSN2REHL6HfHz58CobVHz6fgYw
EHGA0BwOIZkvz2/OSN7DsjjtmfpjYQeO1XxiclqcDqcg6u053M6e8T8m7CAY
JqtjE8LlcBpivj3vS+PN5SuFHSQZdZyi6rgdpkPcAxeXgopD3YlhDtSd9jB7
OaH2Qt1pj8OdNjB//YD6C+pOjHCAunM/LNyeQ8MN6s79uMITAMm8oR0=
       
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmID6X5XfKyEXIYfGiA+GOJewOx8WrBOPn7Nxv4m5y
R/GGkENuToPVtUXsDq27lnG/Etq4f5ay1DuBHGEHMzMH2eyLMPGF+xnAQMQB
QnM4GPUcyLhdkrMn7c5TwfeTRRxOndz/aIoeh0MzRL39mR2nle+pizpMnlx/
VDOWw6EFYr694dSNpmd3izrExtqv2NfN4XAU4h57IzRxqDsxzIG60x7dXqg7
7XG40wbdX1B3YoQD1J37z6OFG9Sd+3GFJwDWepOK
       "], {{4.651104317658282, 
       2.495069664572104, -0.1682770311360975}, {4.482095681266368, 
       3.368460848364036, -0.031807544072237376`}, {5.348895682341718, 
       3.504930335427896, 0.1682770311360975}, {5.517904318733632, 
       2.631539151635964, 0.031807544072237376`}, {4.651104317658282, 
       2.495069664572104, -0.1682770311360975}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA7VUXtxoUDEYdXbYwzlU3gcnm/QZFYO3Lb/cZHk
B1NvEYdjn2+G+u/gdeiaZs7ScnDt/qKdPD9mqYo4PP75ZpX6HT6o+Nz9DGAg
4gChBRxkVzQzvzudsafP7TN76i1hB77mTq03EwUc2iHq7WV7n/Gf2iLsIMsm
HHpDWdChE2K+/erLN8X1+4UdtDvn1B/ZKujwDOIeDHGoOzHMgbrTHt1eqDvt
cbjTBt1fUHfCw+E4NByg7tyPHm5Qd2KIw8ITAJxik1I=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5hfcR50EvIoXLTs+dlvvwOffnT03u37Nn/N8Jx
Y8MdIYdliu/f/+zgd0jw2vWeQ3nz/vo1CyIc8oQdLk/4/r3mCEx88X4GMBBx
gNACDvPUHj7he5q/pzE4fvn+iSIO081ZWg7KCjjEQdTbMy/f51evLOqgm8/B
0Wwt4BAPMd++5ZfsN7utog5HlvH0uEQKOPRA3IMhDnUnhjlQd9qj2wt1pz0O
d9qg+wvqToxwgLpzP3q4Qd2JIQ4LTwDAO5dU
       "], {{4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}, {4.462830092516277, 
       4.340331845910078, -0.024954461592410312`}, {5.316826074838487, 
       4.514682943536157, 0.19930555921848897`}, {5.537169907483723, 
       3.6596681540899216`, 0.024954461592410312`}, {4.683173925161513, 
       3.485317056463843, -0.19930555921848897`}}, CompressedData["
1:eJxTTMoPSmViYGDgB2JmIP5ufEfUqlPEYRPLi+kCoUIO0gHnGXfW7drvf3YS
X020iEN5hGtqwmMhh31d91dfWLlx/4o0T/Z9uiIO1msWGW0oFIaKL9zPAAYi
DjB6go38yeiC3D0RM7f9cLwk7HA0OPasf5+Iwx6IevuNRrkfm5cIO3Qu3zVr
voyow16I+facZ5RfHS0TdvD7LZ7xfpWogxTEPRjiUHdimAN1pz26vVB32uNw
pw26v6DuxAgHqDv3o4cb1J0Y4rDwBABZ7Z27
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIK5POunTEyTkcODQD2nWacIOh/fsdQpWObD//7Tb
dzc9FHK42hiwN2KnsMP6338ijrRu3d9w+m3ezQJhh9cOK+LW3IGJL93PAAYi
DjB6z8VLXyreF+5pMBGaqNYv4iC6P3xhsLKIw1qIenvGTBUlXzlRB+269U7L
3UQc1kHMt2+ca7a5eK2og4Mt+5NfmSIOhyDuwRCHuhPDHKg77dHthbrTHoc7
bdD9BXUnRjhA3bkfPdyg7sQQh4UnAE0JpXE=
       "], {{4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}, {4.446602686144281, 
       5.313432754060626, -0.02261242355976882}, {5.285376032489135, 
       5.5204250234657035`, 0.22960469296484698`}, {5.553397313855719, 
       4.686567245939374, 0.02261242355976882}, {4.714623967510865, 
       4.4795749765342965`, -0.22960469296484698`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhhQcYDQH/aj8lUcwkJB4CkO8asY4gwoACEeAlFv
j138KYY41D1Ei4fhMCcMh70E3InhrxAc4QB1D0FxABe8L7E=
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIN77Of0ZZ5aqAwMUOPPMkPw2Vcnh8vf376I/qsDF
dTkEBJfwKTu8+l3+fW0FQlyMpYMjqF0ZykeIw/io8gwMMP0w82DiMPtg9sPE
Ye7DJY7LHFz24nInLn/hCgdc4YZLHAA8XFso
       "], {{10.707106781186548`, -1., 
       9.292893218813452}, {10.707106781186548`, 1., 9.292893218813452}, {
       9.292893218813452, 1., 10.707106781186548`}, {9.292893218813452, -1., 
       10.707106781186548`}, {10.707106781186548`, -1., 9.292893218813452}}}],
     
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx83XlcjF//B/72mqnZZyxJoiRahIikuUKIlK0kaaHSgkSSJJWkLJVWaZEW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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJwUWnk0lW8XNXMvrjs2SFIkZUillMrzqlRKNJEkQyFDJSU/JCGZKmSWITOZ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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634046824210587`*^9, 3.56610118555791*^9, 
  3.614727747819401*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->
  "During evaluation of \
In[266]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FindIntensity[{
\tRotate[PointOfRays[{11,11},BirthPoint->{-50,0,-50},NumberOfRays->66, 
\t\tMonteCarlo->Stratified],90,{0,1,0}],
\tMirror[{.9,.9}],
\tMoveDirected[Screen[{2,2}],{10,0,10},{0,0,0}]}, CreateClones->clonedplaces, \
RunningCommentary->TurboTrace, CloneSortLength-> 3];\
\>", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[267]:="],

Cell[BoxData["\<\"Starting FindIntensity\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748169944*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.61472774817169*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748172902*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748174406*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748175789*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ReportedParameters", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "ComponentNumber", ",", "SurfaceNumber", ",", "WaveFrontID", ",", 
          "SurfaceCoordinates", ",", "Intensity", ",", "RayTilt", ",", 
          "IntensityScale"}], "}"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "True"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "True"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "True"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "RayTraceFunction"}], ",", 
       RowBox[{"KernelScale", "\[Rule]", "Relative"}], ",", 
       RowBox[{"SmoothKernelSize", "\[Rule]", "1"}], ",", 
       RowBox[{"SmoothKernelRange", "\[Rule]", "4"}], ",", 
       RowBox[{"IntensitySetting", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Energy", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"IntensityScale", "\[Rule]", "1"}], ",", 
       RowBox[{"Print", "\[Rule]", "True"}], ",", 
       RowBox[{"Show", "\[Rule]", "True"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "Last"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotDomain", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "30"}], ",", 
       RowBox[{"Plot2D", "\[Rule]", "ContourPlot"}], ",", 
       RowBox[{"ContourLines", "\[Rule]", "False"}], ",", 
       RowBox[{"Contours", "\[Rule]", "50"}], ",", 
       RowBox[{"Full3D", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Hue", "[", 
           RowBox[{
            RowBox[{"0.65`", "\[VeryThinSpace]", "-", 
             RowBox[{"Intensity", " ", "0.65`"}]}], ",", "1", ",", 
            RowBox[{
             RowBox[{"Intensity", " ", "0.9`"}], "+", "0.1`"}]}], "]"}], 
          "&"}], ")"}]}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.001`"}], ",", 
       RowBox[{"CosineCompensation", "\[Rule]", "True"}], ",", 
       RowBox[{"SequentialRead", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"InterpolatingFunction", "\[Rule]", "False"}], ",", 
       RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
       RowBox[{"SampleFactor", "\[Rule]", "2"}], ",", 
       RowBox[{"RecenterData", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "False"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "False"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "RayTraceFunction"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "ComponentNumber", ",", "SurfaceNumber", ",", "WaveFrontID", ",", 
          "SurfaceCoordinates", ",", "Intensity", ",", "RayTilt", ",", 
          "IntensityScale"}], "}"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              RowBox[{"-", "0.25716362450394076`"}], ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              RowBox[{"-", "0.20894586657610764`"}], ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              RowBox[{"-", "0.15866659941944686`"}], ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              RowBox[{"-", "0.10674081148451012`"}], ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              RowBox[{"-", "0.053665831713801466`"}], ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12466412750975449`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9921989998544806`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12366774926052157`"}], ",", 
              "0.053665831713801466`", ",", 
              RowBox[{"-", "0.9908714681023482`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.12071443736935271`"}], ",", 
              "0.10674081148451012`", ",", 
              RowBox[{"-", "0.9869318232655329`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.11590842336638632`"}], ",", 
              "0.15866659941944686`", ",", 
              RowBox[{"-", "0.9805050472187214`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10941318578989292`"}], ",", 
              "0.20894586657610764`", ",", 
              RowBox[{"-", "0.9717872090206096`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "5.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10143786368263699`"}], ",", 
              "0.25716362450394076`", ",", 
              RowBox[{"-", "0.9610292555606718`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              RowBox[{"-", "0.26234905020307786`"}], ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              RowBox[{"-", "0.21336541617394114`"}], ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              RowBox[{"-", "0.16215242212418296`"}], ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              RowBox[{"-", "0.10915127252144464`"}], ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              RowBox[{"-", "0.054898121469328154`"}], ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.1032114988594292`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9946594324205597`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.10216889932717235`"}], ",", 
              "0.054898121469328154`", ",", 
              RowBox[{"-", "0.993251082188896`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09908130037300125`"}], ",", 
              "0.10915127252144464`", ",", 
              RowBox[{"-", "0.9890747674586308`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.09406540679727479`"}], ",", 
              "0.16215242212418296`", ",", 
              RowBox[{"-", "0.982272004713218`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0873034537478253`"}], ",", 
              "0.21336541617394114`", ",", 
              RowBox[{"-", "0.9730638756754987`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "4.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07902706958225461`"}], ",", 
              "0.26234905020307786`", ",", 
              RowBox[{"-", "0.9617316143970648`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              RowBox[{"-", "0.2675171674347271`"}], ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              RowBox[{"-", "0.21779436157605978`"}], ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              RowBox[{"-", "0.1656610631683382`"}], ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              RowBox[{"-", "0.11158536345734764`"}], ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              RowBox[{"-", "0.056144952082315444`"}], ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.08022395618002894`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.996776864124978`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07913648616962783`"}], ",", 
              "0.056144952082315444`", ",", 
              RowBox[{"-", "0.9952814480901364`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07591912684959796`"}], ",", 
              "0.11158536345734764`", ",", 
              RowBox[{"-", "0.9908506410355126`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.07070234298087896`"}], ",", 
              "0.1656610631683382`", ",", 
              RowBox[{"-", "0.9836450532824073`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.06368886477222659`"}], ",", 
              "0.21779436157605978`", ",", 
              RowBox[{"-", "0.9739144441734611`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05513453624226406`"}], ",", 
              "0.2675171674347271`", ",", 
              RowBox[{"-", "0.9619744009281384`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              RowBox[{"-", "0.2726119897120954`"}], ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              RowBox[{"-", "0.2221879537384492`"}], ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              RowBox[{"-", "0.16915930015623132`"}], ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              RowBox[{"-", "0.11402124038819833`"}], ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              RowBox[{"-", "0.057395526614351905`"}], ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05550407078053427`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9984584608919839`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05437470942412291`"}], ",", 
              "0.057395526614351905`", ",", 
              RowBox[{"-", "0.9968696727755858`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.051036980385933`"}], ",", 
              "0.11402124038819833`", ",", 
              RowBox[{"-", "0.9921665099031627`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0456363114221045`"}], ",", 
              "0.16915930015623132`", ",", 
              RowBox[{"-", "0.9845315933226515`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.03839747149925789`"}], ",", 
              "0.2221879537384492`", ",", 
              RowBox[{"-", "0.9742474774901829`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "2.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.029601895429975576`"}], ",", 
              "0.2726119897120954`", ",", 
              RowBox[{"-", "0.9616685660102264`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              RowBox[{"-", "0.27756221025801525`"}], ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              RowBox[{"-", "0.2264880531274506`"}], ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              RowBox[{"-", "0.17260318952360035`"}], ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              RowBox[{"-", "0.1164295882292911`"}], ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              RowBox[{"-", "0.05863521630269491`"}], ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.028837886389672874`"}], ",", "0.`", ",", 
              RowBox[{"-", "0.9995841016685771`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.027671807509747046`"}], ",", 
              "0.05863521630269491`", ",", 
              RowBox[{"-", "0.997895877573547`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0242296110335731`"}], ",", 
              "0.1164295882292911`", ",", 
              RowBox[{"-", "0.9929033572981408`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.01867265711723329`"}], ",", 
              "0.17260318952360035`", ",", 
              RowBox[{"-", "0.9848144347248685`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.011248868313824816`"}], ",", 
              "0.2264880531274506`", ",", 
              RowBox[{"-", "0.9739489846764025`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1.`"}], ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.0022660029891737325`"}], ",", 
              "0.27756221025801525`", ",", 
              RowBox[{"-", "0.9607049935683369`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.027034186241583776`", ",", 
              RowBox[{"-", "0.28227860674455335`"}], ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.017939339701678922`", ",", 
              RowBox[{"-", "0.23062051860164648`"}], ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.010389026737014294`", ",", 
              RowBox[{"-", "0.17593574615651805`"}], ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.004717020297217631`", ",", 
              RowBox[{"-", "0.11877188198555239`"}], ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.0011947437689776266`", ",", 
              RowBox[{"-", "0.059844629589486664`"}], ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.`", ",", "0.`", ",", 
              RowBox[{"-", "1.`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.0011947437689776266`", ",", "0.059844629589486664`", ",", 
              RowBox[{"-", "0.9982069890040961`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.004717020297217631`", ",", "0.11877188198555239`", ",", 
              RowBox[{"-", "0.9929103634110814`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.010389026737014294`", ",", "0.17593574615651805`", ",", 
              RowBox[{"-", "0.9843468298053318`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.017939339701678922`", ",", "0.23062051860164648`", ",", 
              RowBox[{"-", "0.9728783873079796`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.027034186241583776`", ",", "0.28227860674455335`", ",", 
              RowBox[{"-", "0.9589514799762336`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", 
              RowBox[{"-", "0.28665176520219454`"}], ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", 
              RowBox[{"-", "0.23449272005655067`"}], ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", 
              RowBox[{"-", "0.179084609142376`"}], ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", 
              RowBox[{"-", "0.12099857469262404`"}], ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", 
              RowBox[{"-", "0.06099862217553049`"}], ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03123678205604177`", ",", "0.`", ",", 
              RowBox[{"-", "0.9995120126575684`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03244848274895308`", ",", "0.06099862217553049`", ",", 
              RowBox[{"-", "0.997610276641123`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.03601575082609204`", ",", "0.12099857469262404`", ",", 
              RowBox[{"-", "0.9919990980917203`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04174460784574958`", ",", "0.179084609142376`", ",", 
              RowBox[{"-", "0.9829476539898385`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.04934101026641162`", ",", "0.23449272005655067`", ",", 
              RowBox[{"-", "0.970864887070477`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.05844703460027827`", ",", "0.28665176520219454`", ",", 
              RowBox[{"-", "0.9562503383805414`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", 
              RowBox[{"-", "0.29055072248501823`"}], ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", 
              RowBox[{"-", "0.23799169260507777`"}], ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", 
              RowBox[{"-", "0.18196009715941192`"}], ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06986197639580305`", ",", 
              RowBox[{"-", "0.1230474840787396`"}], ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", 
              RowBox[{"-", "0.06206538388989124`"}], ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06508523706730886`", ",", "0.`", ",", 
              RowBox[{"-", "0.9978797081391586`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.06629773728899667`", ",", "0.06206538388989124`", ",", 
              RowBox[{"-", "0.9958677111709967`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.06986197639580305`", ",", "0.1230474840787396`", ",", 
              RowBox[{"-", "0.9899386955342055`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.07556926063258967`", ",", "0.18196009715941192`", ",", 
              RowBox[{"-", "0.9803977814587206`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.08310561200528738`", ",", "0.23799169260507777`", ",", 
              RowBox[{"-", "0.9677052296563229`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.09209297899613456`", ",", "0.29055072248501823`", ",", 
              RowBox[{"-", "0.9524175349514787`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.12804399273755415`", ",", 
              RowBox[{"-", "0.2938234238737764`"}], ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", 
              RowBox[{"-", "0.240983759674929`"}], ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", 
              RowBox[{"-", "0.18445433845929105`"}], ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1064093585628226`", ",", 
              RowBox[{"-", "0.12484286361745245`"}], ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", 
              RowBox[{"-", "0.06300585322900583`"}], ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10171885894892709`", ",", "0.`", ",", 
              RowBox[{"-", "0.9948131853439258`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.10291089377969836`", ",", "0.06300585322900583`", ",", 
              RowBox[{"-", "0.9926931098785509`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.1064093585628226`", ",", "0.12484286361745245`", ",", 
              RowBox[{"-", "0.9864539055698663`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11199398408147578`", ",", "0.18445433845929105`", ",", 
              RowBox[{"-", "0.9764394218552954`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.11933599002429171`", ",", "0.240983759674929`", ",", 
              RowBox[{"-", "0.963164445490934`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.12804399273755415`", ",", "0.2938234238737764`", ",", 
              RowBox[{"-", "0.9472447051881135`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", 
              RowBox[{"-", "0.2963001790695192`"}], ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", 
              RowBox[{"-", "0.24331679010864474`"}], ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15107408781789927`", ",", 
              RowBox[{"-", "0.1864424947584157`"}], ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", 
              RowBox[{"-", "0.1262959126112777`"}], ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", 
              RowBox[{"-", "0.06377386035353474`"}], ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1412367994467605`", ",", "0.`", ",", 
              RowBox[{"-", "0.9899758413628261`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.14238173372280713`", ",", "0.06377386035353474`", ",", 
              RowBox[{"-", "0.9877552007646911`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1457363479514075`", ",", "0.1262959126112777`", ",", 
              RowBox[{"-", "0.9812289535798822`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.15107408781789927`", ",", "0.1864424947584157`", ",", 
              RowBox[{"-", "0.9707810340845394`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.15805952188353672`", ",", "0.24331679010864474`", ",", 
              RowBox[{"-", "0.956981779969281`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.1662979709580812`", ",", "0.2963001790695192`", ",", 
              RowBox[{"-", "0.9405058153667079`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "5.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.20674988227882843`", ",", 
              RowBox[{"-", "0.2978014237406486`"}], ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "4.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", 
              RowBox[{"-", "0.24482648071692906`"}], ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "3.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", 
              RowBox[{"-", "0.18778737376879306`"}], ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "2.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", 
              RowBox[{"-", "0.12730772843935015`"}], ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", 
              RowBox[{"-", "1.`"}], ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18468536437295216`", ",", 
              RowBox[{"-", "0.0643175465301781`"}], ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18361903731082785`", ",", "0.`", ",", 
              RowBox[{"-", "0.9829974817551899`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.18468536437295216`", ",", "0.0643175465301781`", ",", 
              RowBox[{"-", "0.980690863317676`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "2.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.18780433783963357`", ",", "0.12730772843935015`", ",", 
              RowBox[{"-", "0.9739210814887567`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "3.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19275084333363007`", ",", "0.18778737376879306`", ",", 
              RowBox[{"-", "0.9631111123059446`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "4.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.19919423361903812`", ",", "0.24482648071692906`", ",", 
              RowBox[{"-", "0.9488844248024556`"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.`", ",", "5.`", ",", "0.`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.20674988227882843`", ",", "0.2978014237406486`", ",", 
              RowBox[{"-", "0.9319703848276152`"}]}], "}"}]}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "3"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "True"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "True"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "True"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "RayTraceFunction"}], ",", 
       RowBox[{"KernelScale", "\[Rule]", "Relative"}], ",", 
       RowBox[{"SmoothKernelSize", "\[Rule]", "1"}], ",", 
       RowBox[{"SmoothKernelRange", "\[Rule]", "4"}], ",", 
       RowBox[{"IntensitySetting", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Energy", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"IntensityScale", "\[Rule]", "1"}], ",", 
       RowBox[{"Print", "\[Rule]", "True"}], ",", 
       RowBox[{"Show", "\[Rule]", "True"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "Last"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotDomain", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "30"}], ",", 
       RowBox[{"Plot2D", "\[Rule]", "ContourPlot"}], ",", 
       RowBox[{"ContourLines", "\[Rule]", "False"}], ",", 
       RowBox[{"Contours", "\[Rule]", "50"}], ",", 
       RowBox[{"Full3D", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Hue", "[", 
           RowBox[{
            RowBox[{"0.65`", "\[VeryThinSpace]", "-", 
             RowBox[{"Intensity", " ", "0.65`"}]}], ",", "1", ",", 
            RowBox[{
             RowBox[{"Intensity", " ", "0.9`"}], "+", "0.1`"}]}], "]"}], 
          "&"}], ")"}]}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.001`"}], ",", 
       RowBox[{"CosineCompensation", "\[Rule]", "True"}], ",", 
       RowBox[{"SequentialRead", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"InterpolatingFunction", "\[Rule]", "False"}], ",", 
       RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
       RowBox[{"SampleFactor", "\[Rule]", "2"}], ",", 
       RowBox[{"RecenterData", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "False"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`ReportedParameters -> {
      Optica`Optica`ComponentNumber, Optica`Optica`SurfaceNumber, 
       Optica`Optica`WaveFrontID, Optica`Optica`SurfaceCoordinates, 
       Optica`Optica`Intensity, Optica`Optica`RayTilt, 
       Optica`Optica`IntensityScale}, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, Optica`Optica`EmbedRays -> True, 
     Optica`Optica`EmbedThresholdIntensity -> True, 
     Optica`Optica`EmbedGenerationLimit -> True, Optica`Optica`OutputType -> 
     Optica`Optica`RayTraceFunction, Optica`Optica`KernelScale -> 
     Optica`Optica`Relative, Optica`Optica`SmoothKernelSize -> 1, 
     Optica`Optica`SmoothKernelRange -> 4, Optica`Optica`IntensitySetting -> 
     Automatic, Optica`Optica`Energy -> Automatic, 
     Optica`Optica`IntensityScale -> 1, Print -> True, Show -> True, 
     Optica`Optica`ReportedSurfaces -> Last, Optica`Optica`SequentialTrace -> 
     False, Optica`Optica`GenerationLimit -> 200, PlotRange -> All, 
     Optica`Optica`PlotDomain -> Automatic, PlotPoints -> 30, 
     Optica`Optica`Plot2D -> ContourPlot, ContourLines -> False, Contours -> 
     50, Optica`Optica`Full3D -> Automatic, 
     ColorFunction -> (Hue[
      0.65 - Optica`Optica`Intensity 0.65, 1, Optica`Optica`Intensity 0.9 + 
       0.1]& ), Optica`Optica`FilterTrace -> True, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`ScoutRays -> Automatic, 
     Optica`Optica`ThresholdIntensity -> 0.001, 
     Optica`Optica`CosineCompensation -> True, Optica`Optica`SequentialRead -> 
     Automatic, InterpolatingFunction -> False, InterpolationOrder -> 1, 
     Optica`Optica`SampleFactor -> 2, Optica`Optica`RecenterData -> False, 
     Optica`Optica`InterceptHole -> False, Messages -> Automatic, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`RayHistory -> 
     False, Optica`Optica`WaveFrontID -> False, Optica`Optica`ModularSystem -> 
     False, MemoryConstrained -> False, Optica`Optica`RayLimit -> Automatic, 
     Optica`Optica`QuickSurfaceSort -> False, 
     Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`RayTraceFunction, 
     Optica`Optica`SymbolicValues -> {}, 
     Optica`Optica`ReportedParameters -> {
      Optica`Optica`ComponentNumber, Optica`Optica`SurfaceNumber, 
       Optica`Optica`WaveFrontID, Optica`Optica`SurfaceCoordinates, 
       Optica`Optica`Intensity, Optica`Optica`RayTilt, 
       Optica`Optica`IntensityScale}, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJyFmAtQlPUaxjeh5KJA44JoiWgQjsFI5BSI8C7CeCSO4EggZCCh4j0NFQIP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      "], 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`CloneSortLength -> 3, Optica`Optica`EmbedRays -> True, 
     Optica`Optica`EmbedThresholdIntensity -> True, 
     Optica`Optica`EmbedGenerationLimit -> True, Optica`Optica`OutputType -> 
     Optica`Optica`RayTraceFunction, Optica`Optica`KernelScale -> 
     Optica`Optica`Relative, Optica`Optica`SmoothKernelSize -> 1, 
     Optica`Optica`SmoothKernelRange -> 4, Optica`Optica`IntensitySetting -> 
     Automatic, Optica`Optica`Energy -> Automatic, 
     Optica`Optica`IntensityScale -> 1, Print -> True, Show -> True, 
     Optica`Optica`ReportedSurfaces -> Last, Optica`Optica`SequentialTrace -> 
     False, Optica`Optica`GenerationLimit -> 200, PlotRange -> All, 
     Optica`Optica`PlotDomain -> Automatic, PlotPoints -> 30, 
     Optica`Optica`Plot2D -> ContourPlot, ContourLines -> False, Contours -> 
     50, Optica`Optica`Full3D -> Automatic, 
     ColorFunction -> (Hue[
      0.65 - Optica`Optica`Intensity 0.65, 1, Optica`Optica`Intensity 0.9 + 
       0.1]& ), Optica`Optica`FilterTrace -> True, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`ScoutRays -> Automatic, 
     Optica`Optica`ThresholdIntensity -> 0.001, 
     Optica`Optica`CosineCompensation -> True, Optica`Optica`SequentialRead -> 
     Automatic, InterpolatingFunction -> False, InterpolationOrder -> 1, 
     Optica`Optica`SampleFactor -> 2, Optica`Optica`RecenterData -> False, 
     Optica`Optica`InterceptHole -> False, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`CloneSortMethod -> 
     1, Optica`Optica`NumberOfRays -> Optica`Optica`NumberOfRays, 
     Optica`Optica`SymbolicRefractiveModels -> {}, 
     Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SurpressMissedRays -> False, 
     Optica`Optica`CustomParameters -> {}, Optica`Optica`IntrinsicMedium -> 
     Automatic, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748194347*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748218073*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748220909*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.60551999999999994717114759623655118048`5.802728405508805", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.60551999999999994717114759623655118048`5.802728405508805, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277487896433`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277487911577`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748792655*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277487941437`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748795525*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748797348*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.61472774879972*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748802187*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277488043613`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277489355383`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748937463*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748938916*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277489415293`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"PointOfRays", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"11", ",", "11"}], "}"}], ",", 
               RowBox[{"BirthPoint", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "50"}], ",", "0", ",", 
                  RowBox[{"-", "50"}]}], "}"}]}], ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "66"}], ",", 
               RowBox[{"MonteCarlo", "\[Rule]", "Stratified"}]}], "]"}], ",", 
             
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", 
                 RowBox[{"-", "1.`"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], "}"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "50.`"}], ",", "0", ",", "50.`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.7071067811865475`", ",", "0", ",", 
              RowBox[{"-", "0.7071067811865475`"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "0.7071067811865475`", ",", "0", ",", "0.7071067811865475`"}], 
             "}"}]}], "}"}]}], "}"}]}], "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`PointOfRays[{
           Optica`Optica`Ray[]}, {11, 11}, 
          Optica`Optica`BirthPoint -> {-50, 0, -50}, 
          Optica`Optica`NumberOfRays -> 66, Optica`Optica`MonteCarlo -> 
          Optica`Optica`Stratified, 
          Optica`Optica`SourceTransformation -> {{0, 0, 
            0}, {{0, 0, -1.}, {0, 1., 0}, {1., 0, 0}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, 0, 0}, {{0, 
            0, -1}, {0, 1, 0}, {1, 0, 0}}}]], 
       Optica`Optica`SourceTransformation :> {{-50., 0, 50.}, {{
          0.7071067811865475, 0, -0.7071067811865475}, {0, 1., 0}, {
          0.7071067811865475, 0, 0.7071067811865475}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-50, 0, 
         50}, {{2^Rational[-1, 2], 0, -2^Rational[-1, 2]}, {0, 1, 0}, {
          2^Rational[-1, 2], 0, 2^Rational[-1, 2]}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 66, 
       Optica`Optica`BirthPoint :> {-50, 0, -50}, 
       Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       Optica`Optica`Stratified, Optica`Optica`SourceID :> 74220, 
       Optica`Optica`SourceFraction :> {1, 1}, 
       Optica`Optica`SourceOffset :> {0, 0}, 
       Optica`Optica`GridSpacing :> {#& , #& }, Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues :> {}], False, False, False, 
      False, {{-50., 0, 50.}, {{0.7071067811865475, 0, -0.7071067811865475}, {
        0, 1., 0}, {0.7071067811865475, 0, 0.7071067811865475}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727748943569*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Creating embedded Ray code.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277490490227`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Building reported parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749533863*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.61472774968402*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "4356"}],
  SequenceForm["RayCount ->", 4356],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749685597*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4356"}], "}"}], "}"}]}],
  SequenceForm["RayPartitions ->", {{1, 4356}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749687084*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749744392*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "RayTraceFunction"}],
  
  SequenceForm["OutputType -> ", Optica`Optica`RayTraceFunction],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749783765*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "Last"}],
  SequenceForm["ReportedSurfaces -> ", Last],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749786358*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "ComponentNumber", ",", "SurfaceNumber", ",", "WaveFrontID", ",", 
     "SurfaceCoordinates", ",", "Intensity", ",", "RayTilt", ",", 
     "IntensityScale"}], "}"}]}],
  SequenceForm[
  "ReportedParameters -> ", {
   Optica`Optica`ComponentNumber, Optica`Optica`SurfaceNumber, 
    Optica`Optica`WaveFrontID, Optica`Optica`SurfaceCoordinates, 
    Optica`Optica`Intensity, Optica`Optica`RayTilt, 
    Optica`Optica`IntensityScale}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727749788823*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "2"}],
  SequenceForm["maximum used clone sort position = ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277552024527`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3451", ",", "17", ",", "0"}], "}"}]}],
  SequenceForm["Histogram of used sort positions: ", {3451, 17, 0}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.61472775520436*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({3451, 17, 0}\\)\\), \
\\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] All\\)\\)\\)\\)]\
\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6147277552469683`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "3398"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.09407717691303388`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 2., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 3398, Optica`Optica`SmoothKernelSize -> 
    0.09407717691303388}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.6147277671956787`*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxk3WfUbkWV7n1S00ZUVPTQoAiYaNvQKibk6TY3xoMoQmNWDrQgSlBEbRDF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   "], {
    {Hue[0.65, 1, 0.1], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxMnQd0lVXz9W8K5ObmJrkJKCICUoIdFRUEGwhioTdBFBKK0gUVsVdUsKK+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        "]], PolygonBox[CompressedData["
1:eJwtmnmAz9Uaxo+tyFJJka3GEi0oLSIqW4uZYZhJ2VO2MRiVLS1oMIt9d1G0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        "]]}]}, 
    {Hue[0.6317465266531687, 1, 0.12527404001868955`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnXe8j+X/x++yGkbJzB6JFJFRGVkViuxjHM6x00mSUOqXzTlGZbWLRFvI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        "]], PolygonBox[CompressedData["
1:eJwtnAd4VkXTho809RNBQWnSrYDSpCi9SpHee5MQIgKidFBAEpJQDYJio4mg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        "]]}]}, 
    {Hue[0.6195775444219478, 1, 0.14212340003114923`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnQd4V0X2/q8UBfta6N1dC6IoKq50UBBCR7p06R2RXgMCCRAQFcuK0hRs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        "]], 
       PolygonBox[CompressedData["
1:eJwtnAV8l1UXx680qC9i0I0vKhKKYtAgIKNBurulu8cYHeIrJlJKGKioQynp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        "]]}]}, 
    {Hue[0.6074085621907269, 1, 0.15897276004360894`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnHd4VVW6xrdtaDNXx4JKUSmiIIijjigQhEiTDiIgIEqXIhESIHRCBykG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        "]], PolygonBox[CompressedData["
1:eJwtm3mcT/X+xz+02O79pbJlKUsJkVJXkX2rlDUhpOwZWWdorGMwlrJkK6IQ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        "]], PolygonBox[CompressedData["
1:eJwtkk9IVGEUxQ9Gi2pZjQbp/AnaBCnioqBFmyLLUNyUVkoytlJn4caZpHEV
1sI0kBS0ReToWEGLAg0SdGEYbcJcKS60mEaEWTRKLUx/l/sWh/Pefe87995z
vmhborGrRNJZcBjEvkhRkFmW2i5L6YQUmZeaL0g9cenvpPQPvKOWpDZFrSUr
tYJ7C9JLajlqL0akEXB0Tbp2RToCx1LSGZBdlc5Rm4KfJKWn4HZBWqunDzyG
9jh4SO8WZhhllgpmCoNy6qdBOJipAn7QL32tk8q20OZ9GtSgM49eA7MMDEvP
QCn1EHhO3zD9e5Net+8bGXY6L/2ES35LkzekQ/BsWvqU9rlt/hPscZOzIbiD
Hpv06ILr2b0B9HXjGUh+YOdqKQVrSNofRBOdS9SqP0ozKdc5iU4T55oX3EPz
8lfcdTsLrmnaxwIf33MuytwRUMxLc+y9m3dvzKNxvGrFs96Ee2heTgd+H095
dpbhRNz9bqLHI/69z5lXy5693QHLxLIp3XJvT8HFRc5flP4s+j62l2VsWUfa
pW30HqNXC77zfL3gfpvv5qF5+T8nvcbbvZzvbLvfDe7NHXgoyGZw1Xe0XauW
pErwGV+LzLm0In0DOzzPdfs3+8dyt/zfBnfzDXyr3z3ayfu9sfuzsk4uV6Uf
656VZXYAlKzNsw==
        "]]}]}, 
    {Hue[0.595239579959506, 1, 0.17582212005606862`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtm3e8j3X/xz80FP0iqyJK6Y7bKKFkRMNKZkYlVDaVOMcex3GMY5NOGd0I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        "]], 
       PolygonBox[CompressedData["
1:eJwtm3e8z/Uexz9USN2brMquVHaJki3zSGZGhTRwjEo41nGcg2Nmk8q4ETJL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        "]], PolygonBox[CompressedData["
1:eJwtkk1I1FEUxX9jhJlCBLXRytpkZBREEO7aKC2aAkNXYRH0BTIuciALFHIz
jWNlNFaLipR0VasZKld9gJOtorSNNesaraCIkIL6Pd4sDvf/8e6555x3t53s
60zVANvFalFagJ8H4Nl52DkHreLQEPR0QLYMN2chL0ZEVoxVYF0S3mbi2dDz
1N4fcryS61wezorvU1DcDf8uwI33cMz/qT5oKcEO0VKE/Xth0llf78E3sVFs
EFfKcf6I9WO/InfBqQfwKAePxapJ+/w2lYbaUVgjjt6HTpGU96C8BXkrarhs
+2n1LPm8LJqm4Y26Nlufq+eFeDloFbf0tl5vdypVjaJ3Eerb1W5ttGfO3i0D
0DwOW8fj7KDhoVom1JRQW6IUgtW7eTU2yTkG6YLn1NVfiB6D1+AleDqjt4S9
n/T6YVjf+6BhBtrV3SGG5B8Uv9U/4/wVay7lOfFaz22tjrO+y0T9tyvxrsKd
jZrhcbPMlaPH4DVwBu56Z2SdtTAccwh5fNFjzR74PB39BZ/NAzGzTX5bW+2p
sx426yPFuB9hT65WZyXNfsX3P23wdzbeS7ifhrvOFL2eS3ouFe5X/4uiy/y6
zKBnwn3U3xPn1Tj3ojov5eN+hD1Zku+XvMvW69VdvFaJvIH/hP3d8nSnI2/g
r52HjPtXNx8zC9n9B8ObxCE=
        "]]}]}, 
    {Hue[0.5830705977282852, 1, 0.1926714800685283], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFm3mYz1X/xo8oWsiSHqUULXYtY8lOyjK2CvVUT6WnhSEmjH032YZRlhGR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        "]], PolygonBox[CompressedData["
1:eJwtmndgVkUWxYdVKSogzUUQpYiAFJEuqCgIhOpa0BUXlaWEgBKQXqSFGgg9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        "]], PolygonBox[CompressedData["
1:eJwtlXtM1XUYxh+8JEPloqiYiKu5HAjYvKYTNUNJxlwyPTK3VnMWlQsEdAqO
QAUi08IJZCMPoIa1Nv0HctGaCqZzLdGMNT3HcGPIOnkJndNjm/p59/398ez5
ne/lvTzv+33PSxsLcwuGSfKBkWBNvfQWmF4sZaRIW5ukR/9Ip3OkMLynVKoC
99ukIfAAvJwslTZIL4ak3ziXCE8tk5LAtOMwuM/dX9gbgnN78APirklz35Cy
tkuTgtLqFdJkuGWL1Are7eDcbOkd+JUPpRlgSRdxgfxa52tKyJ21Ox0/SJdn
Se1wd4HUBX4lvkPp0nk41vMXA9/eJ90BQyek/8DoMDHmSVFwI7k0gPHkeZa7
o4g/5UcpGZR/LH20VLp+RXrG+lMwgRguEkt8yGljGrUFuEM+38LF56SchVLR
OaetaVyyiXWQ1Ej+6Bd7Vhr8W9q1UvoXTr0opYE8dFoPhvUSyzLpWhFat5Dz
TGknHEOOsQVOG9PozXwpYpEUeUE6fF4K4Pcb+Pc66RLo6+TOPGKu5vdBqQek
lJMbeMxeEnuP4Jar6I+/8kJpDrbmgkbW3mZtO2up/E674GpstR5F3bLI9wW4
/qR0ECzFx1TsPcTeZHJOAAObpf4MaR05re1x3z6vH6wvwl4My6qdDbNV0Sdd
QZdP+lwNrBb3qHcvus3/mn1yqPRysZziuRuNjRudbt32t3TTq69Jhd0uF8up
lNrEEfNOeKJXw/dqXX9Znx26Sa2zpK9uulpZzRI5+0cmfRdw/WV9FunlfhId
1nAvF9xj/S74+Qj9kCp1wl+2S1+A3SXSX7ytOr6LKqWr5FZNbgF6KgjGeL24
mDxqBqRPwaBfugX8Xk0jqfPrvIvlvI/l8GfY3Av6z0jZ5LmBWFvo4VYQfVT6
jhjGwmFiegL+x84TEAaTprB3gJpiZxH2ZsJ7sFUF0ujZhfh7FY5nFkwAl/Bx
N4He2I/mfF8GK7iTyd1MOKqZ9wTm8z0PJNKX2TOkBXyPR6sctDqFVqfR6Qx4
/3t0B+O8vTi4mffgB3GcS2btKHo/8GaIjxrVsXcA5PxJnvRkFu8iSE1vAF8F
/QUmotcpdN7R7mpitTmBvZXYG4GPWcSTDp5xLgYN2iqc1qZ5BtpPy5Y+59uH
1utARz8zchXzpd/5MX+r8NuK/9XEMTzobI8MunwsL9Pf6hBi/rQzS+7AIb+r
/220n43dOfmu7lb/Sq/XC+mLkiY3g7c1uV6ynjK9TLefyty8TMDXWGZQN7bH
wNXUpGa/e5v2RovRLZpzW+EjAaflsYCbWza/jntzalyZ09t0v8V6BHN00Jvd
NsOvk2cXeY7odfPI5tIHaLeWmm+G11PvvGY3U222VvW5vq6B9w44LfcNuDlj
88Zmls0uP9qk844PN7i+tP6Mok/b6NfRcIQ399Tr5ofNEau71T+v1v0vPaYv
ngNG7sGj
        "]]}]}, 
    {Hue[0.5709016154970643, 1, 0.20952084008098798`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgmYj+Xex28hSk5FhdKRI6ksZc2aaKFCIdKikGGQIVtI1mQsg8GEwox1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        "]], 
       PolygonBox[CompressedData["
1:eJwtmndgVkUWxYcqClhApVpYpAiEIkVAFMF16R0EWZosLaEEKaGIUqWEGop0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        "]], 
       PolygonBox[CompressedData["
1:eJwtlG1M1mUUxq9HSGGpOKRmblb2oSYOeDAUBHypJaKpqxxuvs6Zb/gBmjmT
2uAB/eBTPgQPSLVMa27aCqfiO8MXwEAwKFIMYxMicxNyAWb5MrTf2f18uHbu
//2/73POfZ3rnIlrct/JGSZpCXgKPK6SqhKl0/lS+FfsgSsXpP5xUmFAusq6
HawqkKKmSCXHpb690l8go1BKmyvN65aeviaNBAMN3AUD/O+IlQZZP5snPQNG
HZQOvyz58fvWCWk+/hZjR5fiGyStl14Fmd3O73xsD7F/B38A7yRp/27uXpLy
UqWsjdLNddKf4KUKaSL4lRhD8dIW4q0jVw8xFpH7aPKJAs+xPw4U4XsVMXZg
J31I7DnSyU4psVmaAqLxc4RcPwm483Zv1ym+we5sKeFt6fUB8iT/VOAh//QY
KYX1MnJcCnJbpBPpUg428gdp63QpAusvlz4GXs6mkd8B8rtPbg+A9318g7Wh
3N/FdsDr0dd4G7YyRzoUgq19X0h34KUQ+8t70kXWjz6XppVJyWUujsXbvBk+
qEf6Hs6xbgNDodo/wgYPE8crlWID8FoMRhyThoNIaniK3K9Sm3i4iQNd8PYp
/DUWOs2YdgZ5WxXn/sGGbSBf1sEG58N8nYWTGtBKLWelkANWvVL9AunJbekn
uP4Z/N3FeXz3d7namwZMW6axBcRN599c4sY3kQuoaYeD2dLX8JYDp1nwVgun
SfukqSAVHqYDzxbuTpZa2Bu7nxqD5TelTfOkNTvgkv1o/nfiJ4LzkSDuGzTG
Xjx2PXxvAB9QkwhibDvuamU1G1sNZ0lSDPYcsc+DFTulOt42xNuekKeanU/z
ncF3LRrOxF7fDufcja52ujH92Fm74wnxsxJf//H9YppUnu10aHocEarNcGwY
CAcze6QZoLkInjPRKevuG1J+BnXDPs/9F8Bd/A2Cf0N+7zU5zZh2HqKherTU
hqYyuD8bP5eLnF/zf5QeLCH/I9hKcAh8y5tnwksyNRhGP4SB8bX0Dgigh0qe
tXUtfH2EBhOkM9+zV8xd4DvPOpm+xM4KEi/o9u1/U51UjV4uYVeS42Xirmhy
NbXammZMO8E+9LcQfrDn/G5d1ufeaG+NoYfrmA2R9PYuOA6AKHLLwveYWjc/
bI7s4c5p7u7tc1o3zRfn0j9o7LsrzItGKbbRacE0kYg2bqERL9aDbwE/vu8y
Q0cSswQdd8J9EJvvkwp87n32zs9qqOE0qQJ7LTS72rF1xKsHQeo/hlwqel3P
Wu/a7LUZ7Ed/o+B7eYGbbTbjShtc35VhN1GHbLDR5lMYc22f04fppG2n81ve
6+adzb0zzL+pzMFY5mHCRd4N4kDKePx/iQ5aeeMMNNvqesd66Dp66gAT0NOb
r0i/3XB5W/79vCOcOg8edPownWz3OS5KjYs893+A/z9Sv5aA48Y4mhPS3Bs9
rpesp1bzjkXEiEFX/wPS07qs
        "]]}]}, 
    {Hue[0.5587326332658433, 1, 0.2263702000934477], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgd0V1XWxe9YYFBQR1B0FBGpGqpiA5SiA6IUwQIWWkwooQpBujQpIgGS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        "]], PolygonBox[CompressedData["
1:eJwtmnmAj2X3xk9Zq7eVUkkla3ZTlKXX0iJJqN5KJUvWsS9jF9NiyzbGZAuD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        "]], PolygonBox[CompressedData["
1:eJw1lntQlVUUxdeY+QKcSc18TGOWKb4w3y8cAUfLqSZBU5tUFFHkqYmm5osL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        "]]}]}, 
    {Hue[0.5465636510346225, 1, 0.24321956010590737`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgmcj1UXx49eafHmlcpbaaFsmcTQJAzZSotkK1okGTGDoQZlHwbRDGNJ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        "]], PolygonBox[CompressedData["
1:eJwtmnmAz9X6xw+JukqydyvLvbbse2WXspVKuNwiN0uMZcZOdsZWyDLGVpkZ
jDVZQoytEMm+Z535GWPP0kI34vd63/f3j4fn+/mccz7Pec6zvJ/nTJH2Me9E
Zw4h1OOfLPx/6asQLkJzJofwGVRxbAhxVUMo8FIIY77l3dYQBv4jhB4VGAu/
cE0IeSuFcLpUCOP7MPZqCEXyhLDu5RDi4d84y7vXQqj9Vgi5b4RQvlsIv9fk
W2VYIymEER+x9jMhdHmB54tC6NU5hAnI8RxzPjkdwg1k+Rkq1DuEwtDBhSEk
lAvh+wKsOzCErRtD2AKdZe1z0PUo5tVgvZJ8Ky6EdL5RM18Id/hm+r4QKh33
+m/XC6Ey/DerkBXaPj6EHVCWGSE8AnXviHzQxo3ef2H2s64T89jzztIhpLHH
t+B7nwshJbP32wf+Fjp6E129yH5+jA/h5E5k4t3dRiHMSw8hFp1cyBrCAOQZ
DT+Ib2xCnjbMeetmCBkp6Inv3SseQgX0v0/75lvxzL9wPoSia0PY/XwIE6uE
8BRj35sfwl50OZsxzaaG0JHFhhQJ4XAd1j3M+UwLYfMjITzeMIRfUtFTD7/r
8AbyXgnh034hTM3L3lmvN+sVHuPvZ+M8M81Bhm7WXWm+cQ5dPn8mhLZ8axDy
FoQvjk6TkScF+Sqxv47spwO0+kgIX0NroTVQ+V2sBS34LoT50EJoEdQCHX2V
HQUg3xXkO7/P9qHvpfK98gkhlIPas+8O0OxjyPcs9oQM07G3qZ+HMAVawxmu
haJvcW7Qer65AfqdNQs94/3fgX9nOHqC9kxBb9C/htiWX8M+X8B+1rD+19Bc
1k6AAvZ0ivM9yxnO5ywnYpN/FLB9ToJ/uBoZStnm78PXxX7vM/Y8z55B7gZ9
Q1imdxVDeB9fWR0dwp+5QqhaDZk2o0v2lK8QOngKG4C/M8G+JpvbhO29gswb
GyBP3RDqHw2haVoItdjLGWQuOxQ7/NH2fqQ8vrAMYs9RjN3HfqI4h0sjrNsn
avPtA9g3Mj0C3WEvd6G9zB/K/BXYa9Is5mOTg58LYRZzvr1qm5ftd6hOLOgS
QomvOXMo+1zWhCbstixNCR4d0FXvrpwP57cH/2s5nbP7iVjyiv09FV1kJPI+
4j/T+P34SZ5lYu36IfwNPjkD3T5reRfC590RQh4o52chPP2ZbWp1xKZkWx3x
4Sh8+UnWPM557SGGLITPw5n3IrZkYm6A1mPLG6Cy2Ogk3i/AZufGhrBf+mNs
P86zJ/Y8CJ++zO9/s6fB8Iexz0PQcfz6BFR+MHuCCq1HL9Cji5EF/0p4kZjD
+Axs6yPi4T1i1AFkmcf+sxB/VqGT+fCp6PxR9teDM/2eePGQM09g/AZ+1+Ks
ByFfdfR/Fn8aDH99j/XZoXEIr1/g+U7PjYK+Zf6kkSF05qx28r38fC/mjPci
HZ9BH+Px6ezYXre/hzAOfsCCEP7iXQl03h9+DOexmN/rsclKExlLDKnD2Yxg
/Yusv3yp9dOXNXuw9j9P4fevcgbI1AVfPYQt1WL+YObEMT8ZHWxHF22x4cHY
X/MJ/n0Q+UohX/kkf7ss9hRNPDhMfNldyzqQLkrH+d1PzC+xPYRixKvsxKtW
r5N3LhFTGZ+XeLGVObN/wY9S7U/6XQ0+H/Y381H0jz09wJ6WYB85iW9x2Mhy
+N2R+ZsYXxh/+AR5V75oHbVbyZw02/9EdPoQvuzBEF5+yuPLwZdFp2WgovhA
MagAMo/I4vPqz3lNm+7cVDE3th2DTrG9ilAXbDcK+vK4ZSmNzm6zzi8DLOt1
/G/4bPZxzmdbrVUIM7Cl9cTwg+w/FZ2XJ950jXUuUP44sBcb/8Znr5gUA38M
GfZzFvnw6ePw6XMt39uVsWnev4GP7kW/o/HPSei6NTmlAeu9j33Vw75aEw9b
DXFOVW7tNtJzs6Kjb7bwDn//gfnx7GEleym93WdVjmcxnGeNONuCvvE+Y3Nt
wGYKoiv0V3U/cZJnhaHP2PvnUN2jjm2Kcevvh7CUZ6/mcQwojW214LyKMncC
8ePAPGLEIPQKJaCLRGgHMm6HBpErB0NXtjteKX5u5nlJZN5NrD3xLvnyHr59
3vG4P/q7Ap97rf2tOXtsh37GpNkXhA/Gwrdd49itOQ2JV59utS/JXibDRxOj
8ud2/IqB701OrVnHOTiAJ7qjv2asPZL8eg9dnMQGWhV0vDwBP5b99WR/dRlT
i+/v4kz7ItsU8sdD8toHcxwfh6DPlj+QZ/d7rNbYAD8afBUL3e+FX0Mj8YHx
z3r8KPic6DDvs/bpOei29gO+wXo9eF8HPn5SCJ2QPws+PhO+DD5an/EJnMfT
zE/En2ogT1fstRixYtMy5xrlHGGtRsnoBfoE2SZALzH/KPaYmfWmTbLNyHak
A+niHda4iD9WJSeMO0EeWIdtQyWJ1S9AL4NXShfGb5kzHP02RydvMjcOGTKQ
pXKCbUM2spz9rN9v/XVGvkKsfTLNeEf+ewq+Hs8GKd4zPifyTF3r+HwfGfvw
vXlpjt+9GD8ffjgyVUK2fuh/IPr/YrfnVubZKN599bH3I59ojWynYo3thPHO
EJsnYyPb+d57JdgHsXQf8WsL9pCJfDzqZ2yHmLgfvis2/z35q97NSK7m97Yj
ztn6XZN4cI28s5N4EN3AOWMW8eBp5M8pzIDu80Pp5xyrdb4z0UcNYshPzH2K
/d0a4Jii2PI0v3/l96W+jodXwJfL8N/6Ny1PHcZkAvcuTLMuuuATyWnGUMJS
nZDrQ2hyjO1F5/slz1cddyx4mjXvkUsTiTmhujHqT+hmZJp9SZh7BHwd5DnF
t4aQ3ysQT2unOvdFsb+KxONp+MzPYNMbjBnN2Du3jN10pr/DX2V8poa2gc3o
Yx862htvzCnsKYyr8cJ8i7GlQ1vt/5OLhTBsgmsE1QrfERu2QZUmG2sL8wr7
5kq17csHLpDvS+6z7QnjCuueSbNtKUechj+Cvw6saUy/CP+uAB4vD+XG1vJA
f0bGS/4/4LPGODcoR0wgV1SJsq3IZs5iq/1/NDYSnhkA36Ov47nwzDTet+S8
WkBxYOfp0IZE43GtkQL/YbKxpDBl52RjfGF95ZDT2OL4q84dqinGwrfbZiyf
ig20Yd0uUGeoLs/rQR/uM3YRhnkVPf97CXYPRTGmK/RbmrGi9PEL/LG9jq3S
xwH8dRiY4BDxdBZ7Hg7fhzPpDU1l39OgMiN89sr/9VKNUYX9dMaXeZcPHeWF
3mQvb0EvHrc9KUZXhZ+Zbry9k/M5hL01xEYaQAvA8MnHrCPpSjlDuWMUMo9A
l0uwr1j4ooP9+0t+f0Fs23nEvimfkG9cj7cvyiflqx+c8VjNKc7cu+TXO1Ai
eSIJmtLHtYlqlMl8v0Kca1HFS2H1+D72VcXkRN6PPOHYohjzEmfdrIfzR3fy
S8oqn4HOYiGyL4JOYsO/FjOm+gD7nL/cWLUaNn5hHDmE+NS6qeN7MeJx9Y9d
r+tZrmvgl4i+lW+j7voMoyJnrrOfF1lP8aoy32pz1f4YmnD+5Lf/rHTuE2Z6
hfdDJ9i3VOPnwq8qHrRvCzMdS3ANr1pJ+GSS4m9f27fw6XnstRA10NAizpcP
kX/zzYhskhH+uQTXUjrjB8TX2rvsm/uJZ3XgN66yrqSzmYeI7djQgQbGi5vG
8q2dxvuKn8LeTbCNxrdc46nWm4dtJEVqUtWmD8ZZFq3XE98ZMdT5viv6q47+
OqDPbk39+2V+v/eNc5tygnJDIzBFPfJBAfQ1An1V/Mm1rHoQ4/sj/zfO38pZ
yl2fx7oWkYxXiB9Jkfj7Angs82hywB7XUqrRr8CfiHVsVYxNwPY/J17eRt7u
b5JPr6On2/aFh/jTX7eNEeXvilGH4TtFGXsIP0wht33xiefuRd6uF/GR7q7H
a/BsI/j6QKzXk/6npbvmU+33PNi3IFSLfF8TmqKzhRre9Hkr3r8Gnw6VeNuY
40Ank/h32uF74I+F8c4lwgwvsk7JRa4VZN+leL8AnbSv4nilXsgk4ufEGH9T
315xxNhFOWkKz1vwrDm0gXVToIbwDaA43k2H3rvsbzeD/sH6RaBzr/v3P+Hv
/oZ/tXCOVO3w8h6fnWqKPMSznPeMJfvgU1k4/9K3jQWEsQeg29LE/rWcdwf0
1eJD7GmDsaUw5l/w2a4bC25Ap1nh46851xbjvGfAL/7TWH8k31gC/wB7Sazs
+JncE3/6g3jf2t8Ttj+SYCwvzJ0Z3zqZ7n6S1jsFnzPFvSLZTCFwwx8/uvbQ
/u7CL+X9pSruHxVn/lNgoq3ovwYx7mK8Mbaw9liej4NmxduXVXPkQ69ZFnm8
YuQS9Jtnkd+pJv0UW/6Aeu8h3xuCjGOiQ3hss3sfqtkOkg+6dHI9qJr0/STX
PKp95FPvsve/bXZsU02em7pka7KxjDBNrl7WkXSlGLII/nFk3FTO/bfdyHpn
IbgBike2GdCpgc696iEe4nnvj1yrCxMKG/ZKcS9M/japn3OiciOlZLgCvsjP
+B3ljJcCeKnpaNdOqqHexfe3XHU+HNWGeEw90zYyXzm2GfEq5Rf7VrW21Ex/
hXAzzWtrfMZ998TUG1OOVa5Vz03xQz0x9U4Tlzl3Kf8UG2yMJ6wnTCVs9VJ/
5+rK2Od2cstHnxvLCtPeZT+jiGfd/24b7Uwsn0j8uPyG59dlfvFEY31h/vrE
iyoZjuUa0/yqe8LqDc+FEqDUb52PRrPH1cT/e52NLeVDd/ClrGDgWpF8+Bj8
duZsg76Hdgp7IdOlvJZxNb4zZoJ7cerJnSQXRSe5d6T9qzdYM8O1vuynOnzB
A67NVdP/gH6qZvi3ZJbsFVM9Xu8rwK+J4AvFuOzEust9jV1V065QP5j3OSLv
1ZvMG+knKAbUJBYcnOdaVDVpJeJ3q+mOz+rRqFezvAv4AIrG92Og2cOdexTf
d4HVq+x3Laya+HH22wH9tx/vHKRcpB6Pej36xlR003q0f2v9n1k/C79LNXaO
UK5ogj80TjZGElbKtNdrd2RMU9bKc8O9d+Xot6gTG//ON1qyX/bcGfvYmGz7
Uc3wa0/XCPIv4e9Y7KEF41u39BlNYPzXN3zWOvP0dY4Jig1PYhs5oBJ9HUvU
k27D/vZtNh4tXJacDX/6nPGR8M8Z+Dr4XO217kmqN6kaXrX8MGg4FH3GvSf1
oNSrq9nfa6kHpV7UPPBUEpSfuQWgesSIe/8y5lftP2+k46t09n/EwwHp7tUo
hm4jt7XaZn9qx/ott7knod7EcrDBV9BrGcY+wkCqTcI6Y1X1rMpjKzvOOZar
RlOt9gR4Lzu0CFkWJzjHKLcox7Qh92RLsC/IJybynYfxjiXCm6oNd3BmCxsb
I7wx0jFCsUJ4fgOxI+6YdScdTuvjHK5crjnfM7cE6+crYJ0X1/dPuVenZ/mJ
fVd3uZer/HV5l3Um3QkTCRuNP+HaXDX6UGzp6CLXyoqP6m0u3OleuHrit8g/
b16wrcnmUvDvQxH/kM3KdtcMsm6l48VL3aNVbaM7lHRiTUzEv9UjHsfZ/hbR
lzDCr/BrYqwfxdwcyFKGZ53aOWauJNY8n+jaX3hKvZTiybY/PSsBPyTDWEyY
rOF5YzhhN8XADsS/Z6bYF+QTjX53DFYsVgy/hX8NQSeT3nYMVyxP3+3emmqy
vtQxpca6XyH81A38VDGC97ci8x78qeM+Y7Fd2Eh7+P+Soxo0dT77A37NROdu
9VAPcg6nqSFOrbFNy7YfI8dki9xJ6W7qyWjXPurZjmXv1696PWHA5OXuUatX
rZpYtfGiGOdy5Wjl6uGc6fDS9udh8FlSnCsk3+FY27xsXzWUaqlhcc7dyuGn
+xpTC1urJ1tJePuc7750/9Effr/w39u+P8o8h5wxx/0o2X/ry+7R6GyEOeZh
H4/t9HzdoR370D1J4RnFo+rEnzTOLK6R+2+6S0mMdS2unlA1fPlIrGXXHj5T
77Ofz1M5LErxqpPlaYvNlyMu74/Up1qzS6xtSLakMx56y3dUuqvaBK7cDN2M
1H/Sn7DRX3N916k7z47DHVMVWxVzHtxBjnTfhUnGx+e6J6x4I/z3DHHuwDbX
Popn+7a5Z6bemWK4Yrl6fOrdSWcd0N2KCD4Wvp3KWS7l95J4Y2Bh4e4XbXuy
wTKcTRI+9k55+9yqQe4hqpcoDP1BrPekvemOTHdlk9e6lvpfv4P9nEk3dlTM
PA2flu5aRD0y3XWoB6/zV401kHw69ZrHC3NOueY7JN0lCbM+P8o+Iflkn2s3
4psxxmbCaPfBX5Mj94/KobvnGaMJqwnDC8sLswu7C8MJy+2K93zdsbbv6Ds6
3dWpp6zesnrQ6kULUzbh7O9H8IVsfiL2cDRiL/LJx7D9/knGw8IAV7Cvpatc
i6tnuAy+5D3HC9WAJeA3nTaWU88lBb515LzUo22FfV3bYNtUTfcF35qe7m+p
hjrI7/9SI7zbzN9cmeCekXolu3h2m1ri1m3zslHZqnpqkk1zRvBuRqJ7QYo/
MX3dU1Strpo9Cf8v+p3vXpSfhc1mnfbdsvphM+HrL7CvCCNWJ94O2+peq+yn
NPbTbKLHak4R1iq2z3v5ke/fve07ON3Fqees3rPGaKzOfynn8ex3vsvXnX4B
+AtdPVc6US+3J2NavOQ7uhGJzjHKNdsZc5X1o3s5dqgfp7vw87vsu/JhxZYq
Hzt3Kb9nveaemPShNXPwvWxxrpXUc2pOrJyxAntaYcwp7HkhEt+VQzYTO29c
tW0qht6EP0I+OAy1wRfaQuu6WjbZTxO+9d0O13bqAagXoB6Lei2qcc/fNCYW
Ntadj+5+cpz03YDuCJ446Z6Kzks94TmH0X+kPyuMeRDZozI8XvbUOcMYSFhI
d6C6CxUmFjY+wZmNnWAMLSwdw7ue0H8uO9YqfrwP33mr7yblvxWwvQTWLNvE
GHfdAWM2YTdhUGFR3ZHqrvQo53AMWjHfe9cZ/YkvdYz0D3Tn+yn+9nUkvyvm
5DjjnqOwir6RyLfmRuKB7pjP6S59q2VXT+p/valIfSKM2Zz8exCfO7DKd/q6
2y/80PrV+IIP/Tcg+lsQnanO9swW9wYU485uscySXXdCuhvSnYjuRvQ3Lfrb
lpOrnKt0Z39K/bW9zhXKGXXhq0bsS3dI2a655lSuln0o1z6cbfuUPSq39Esw
ntEddLx6W4nuxSo+pMLfj8Rf3ensx5a+WGHd6Q6/EfiuODm9GHSdWPcz9FtP
12LC5MLmujPU3aH+BkZ/C6M7x6KRO3jdxefpZawuzK7aWBheuVM59FPsadRs
vxd+VS9PfyOxJvI3L/rbl5pJ9hedUS34X2cZuwjDdMJ//h+wQMWJ
        "]], 
       PolygonBox[CompressedData["
1:eJwtlnlQllUUh381mZplbqWllZQgKIgIqKXGooImbiiaCZasggqaOFMKhqbY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        "]]}]}, 
    {Hue[0.5343946688034016, 1, 0.260068920118367], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgmYT3UXx0+RtIhoUwoVErKXJUsqoYRJvYqX7MY2lomIGVuvMvaxhDJm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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXmAz+UWxo8t1I3iqhTXUpR9F0K2QrutW3KzJEzWLC1SKlOWsWYLZYzq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        "]], PolygonBox[CompressedData["
1:eJwtlnlQllUUxh8102kSc8kNtcR9QdxARCU1F9xyyXWm0hT3BhQREsUlQQd3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        "]]}]}, 
    {Hue[0.5222256865721807, 1, 0.27691828013082675`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmnmcz/X2x0+2pCyhlGSpe2+SnStky2QLWdqUbouyjLUsuUJoLHcwGcxQ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        "]], PolygonBox[CompressedData["
1:eJwtmXtgz/X3x4/b9FPJF9VP5tqvUoQid6ZmWkmib1+i21dR29xTa7mMJppR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        "]], PolygonBox[CompressedData["
1:eJwtlntUz2ccx986yP2y3E7FFg4WiXSkyGURyp1jztlVbJMKETuahk1mLhEh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        "]]}]}, 
    {Hue[0.5100567043409598, 1, 0.2937676401432865], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXmcz3Uex9+xYkuOdaUyZDfZ3EYYR3KXo5F2y0rS6RyT27hvM4YiR2EO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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXdgz+f2x08pHfcaqdFSgt5Sm4oiEtxabY2irXJL3ZZq7F17z9ozipKg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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnlwzVcUx7/VWmqJGC81NAvpKBKy2RPEFktFVVttZNqI9SWSSEuoqBAk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        "]]}]}, 
    {Hue[0.497887722109739, 1, 0.3106170001557461], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmXtgz/X+x1+nkyQp1xzKreTWidzvSuGk3Or8KqmoXAoxTpNrNmO5hbEQ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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXl8jlfax69OLW3VUks7qLXWFi/Vt7Ul7xjLO6Zim2kZbRmtpWmrdFCJ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        "]], PolygonBox[CompressedData["
1:eJwtlmlQV1UYh39uWeNogmCDqUSJuIEsIrhgsoijgUXTtDgpZUKBAZKgLAqV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        "]]}]}, 
    {Hue[0.485718739878518, 1, 0.32746636016820585`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mXlgVtURxUdcqAtFINayVJSCLGoEFEFkE5FFDYtdUFFEFBCoiZgACQFi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        "]], PolygonBox[CompressedData["
1:eJwtmXt8z/Uex9+nc+i4lFw6LnPCMrdKFysmQ4tFx4g6lVMHXdA4RSYZMhO1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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnd4j1cUx79GzJjhIajYe8eWSIIGVYL+QWtWi5qJnQiSECuRUHuG2qs0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        "]]}]}, 
    {Hue[0.4735497576472971, 1, 0.3443157201806655], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mXtcz/cex9+2Bx5zjG3YTGzkUmaO64ZyKXPfjGGXs8dMNoSZpDBEimPI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        "]], PolygonBox[CompressedData["
1:eJw1mHt8z/Uex98SRSK3yi1MZnRhFLnvnJNrhzniHBwyHRIrQy5ns2FzCXNZ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        "]], PolygonBox[CompressedData["
1:eJwtlgtUj2ccx7+GDNuYMlItErmMJNfSxYYmRuNgF7ayxmhH7hSWYreSO4ux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        "]]}]}, 
    {Hue[0.4613807754160763, 1, 0.3611650801931252], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmAmUz2UXx68W8kZFKDREylJvtuyE3uy9mZTjpI3OGMN0LDFjGTM1SIVB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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHlU12UWxq/Z0VLLTJ3clyy0snKbXBvRUtB03FssTR22RkdRAU1FEwg1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        "]], PolygonBox[CompressedData["
1:eJwtlnlwj1cUhl9LqVhalaBIlZAIiqBI0Maa2CPJyFhbhiSWJkISRGhttYbE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        "]]}]}, 
    {Hue[0.4492117931848554, 1, 0.37801444020558483`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHtc1+UVx0+ubOUt81KWVt61qSGgotle5rygq0xnL5auTFMx1yhESUgh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        "]], PolygonBox[CompressedData["
1:eJwtmHt8z2Ubxy9K5yfKIROmEJUWI4cnnmzllEKOPZJTYkqY2Rib82EeRGGT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        "]], 
       PolygonBox[CompressedData["
1:eJwtln1Uj2cYx79yZkPFhkYvirJeRqhEhqlJaTZHhh2b93ejWdQUYrJhlI6M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        "]]}]}, 
    {Hue[0.4370428109536345, 1, 0.39486380021804457`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHd0l/UVxq+IPUWhVqaAIklBQZAZAQciIEsjIyjQYAFBMhBIIKKEkQDB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        "]], PolygonBox[CompressedData["
1:eJwtmHlU12UWxq+EzTkmuZtalksaWiq4YBvlvjep5XLEdNQUIpUEN0xTK/RU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        "]], PolygonBox[CompressedData["
1:eJwtlmdQVlcQht8omomCUcEClgkIih0iig2jWHGMBZOQgAVFULEBBhFRUAEz
BuzRqNg1UcFYIhZKUFCUiAW7PyyYkMnEH6KjEXvy3Dn3xzN7+Ljn7J7dd/de
98lzgmfXkrQa6oD3VKkdVJyTLneQTm+TnP6UHCEvVboxTBrPetcO6TNvyW22
tJ31DtgwRVoPeZVSylCpALvhF34D78VScIgUVcNZnH+/l5SNDx/O94XU99KS
cGkpNgUWw3D2BcHTY1LWp5I7Z/T5UeoN3sXSxJ5SR+xo4rlKXKOwpzmzGK7z
7DWYzG83+V841jcdf1D3rNQB//F/SXs2SruhLFva0lUqxx5eYuLPt+6xllhg
PvEkQDyE9eb881LiNH6H5lGS32jpv2opsEgaAAULuSf3deG+fWZItQKkt5ek
BZukJNiTg1/YC4XtpUpiCNovjSCG+gt4lju+g5/u8ywcgaghUmyKdIB85cAF
7vk39yjHPiSOQgp5l1ha8ncruJXF3SFhEbX1JU+HpSk1pg7TsL0fEBt8f09a
DiMfS2NHUa8MaS5xnSWW+dgfiG09XMlFEzDWzncuenh+UHoG29kTyt6JnBEZ
Kx3sz5k3JOcycgDFG6gNrEEf0dRtGnXr94RckrcAbI89kj/Ecz83ap2Hn13c
cTdMeGzODsf+Q14fwUs0sZXn2i42+rJ0tm0lv4Frkon9W2JPnmJ00gF/q9Hd
GvDimURnqTX59oA2sPAQNfXheWzBKnIJS9gTw940rCO1cILqddJjqLH9v8Bu
oTYR1CYLGzQX3ULBc2r7BRrCFqOLEnCuMZpoUmPybeX96UnpCaw8Tc3w5ZAp
ZRLDbWLJwA6KkwZD13LpaB+pYbT0G/6L4DvyuQxes3c0e99jnU7gA2KtNb/F
YJvS3IvcuBM6qHcEfUEZOslGL6+2Sg9K0R94kssT3KPnA9N3Vv8N3SfFkatr
c/iN9XBwIB9jOHsqud2O/x3gRK84wsdQxP8qSqTSvdIktF3N/6MTpRmQT2/l
QVmlyW0qZ31MDA2ghrgS0OmQZKkZNWkKjjGmVo1Ze+F7Fuf5UYctnLUV0tF0
GiyF2i5okbp55JrZFU8dPmHtDsep0zHoQm8NcpV+ZV1+yOwZZeX4Jn7Bk9ja
QMgjdDZC+gq7aif1ZdaFMusyWa+Ao2c4A/wfmJz1wkbYsyY/1cxLa27Op24J
kAyXqd9ibO9os04pN1qyNPVmOnWEdxeML1d+G0LtXvkTG7aC2l2FBvGcC+3u
oPtA9I8dR5+FQbo9Q2uYTSFHiR3abzNzIZj1R9YMbsFcoC+ucP8K6Lae2URO
uzObuoEfPLfr8AybtYVcQzr5D6OnjrDnJT36CtoTVzXxdcIGEFs/SObsUp5r
kWR60erJTb9LGyGa+0U4UB/OfXzczNsLzNu65PtD8J3HfAY/O6a+zIPQA+iL
+l/inDDW46A2/qrwuyPDzB5rBhWR85OtmDGcG0ve4+AWmr0J09Hhwy7MT+w1
zrkKntTuNvrzwOYwO7NhJj0Rxzz9gF6oj9bqgROMJJY+aDjtDzNHx6A1F/w1
gRfsb4zWwjcTB+t/oRO5ecpzXdFdbfLvAK3RTiv4md5M7Cbtx7ZDn22hc655
3gd7g/xeh3p2rdIyTf6tOpSStzk8V4Z9d4uZMoBZHG/0ZenMmrPWvHWHmbyj
WmIDiL8Fee6Lvb1CugMFp9A++cvHziSfs2AjOXUnH474c2XtBt2Sjb/z+PNn
hvSEK7xPLsNqe0a1o+Zt6UcvGGa/vwZjHYinoiU5qqKXoTkEMOf6QtBS87/Z
+A2tNDmvRc5D0UAYONMfjWEU2j6ExsdgL/HOjuS5i9g39PhbcOGd5AwL8ReK
3xTsWXJ4BkqgO70dSX4H4W8gjM2nb/2kL7FuvEtcocie09/QP5/b778R2HRm
8zLokMZdWjNz6fkQ9n0NZ9D2icFo/66ZtdbMXUB/JUJ//BWhhyTWdclBHfDk
jIFBxEoObpSY+egdab47rO+P7uSkAE0MJsYicnIKXJmHF5nZ56hBQ85qBE/s
76BqbH9m8wCItrUdyCycbs1ZKFxiNLaPuAKp58BMMzusGVJAXX3wX4hNIJfz
oCe692BGNOW3GHppDXXN4R0bT47nwVjODIad+HAlzz5o6T373kEzeiCKmZdu
9Qb5coC694w2X6PRCPphMkyCIuauF98+XnbvDSMHbfjbE9Yx59fCInt+JGKH
8h11swdz0P6msr6tsrjTZnChlwobo1vWnem3h+TqOn3Wg7r7W/MffV6C/Awz
ozpyt7l8E8VBzDnzfAl6Xs2ZqyAYja/34Jnl5IFcNwE/uwbnqUGjKlNDlyoz
p615PYF946EYP+nsDWHv/3FA7Yc=
        "]]}]}, 
    {Hue[0.42487382872241364`, 1, 0.4117131602305042], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHl0l9URhkfExorKJiKLVMDEskPYF8EQBUqxLaigQtUiYAxlzcISlljA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        "]], PolygonBox[CompressedData["
1:eJw1mHtcl/UVx0+Wc8srBpa3lqgU2EtBDTWZl6xM0JXaUtNuJmiaCaIr8QJm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        "]], PolygonBox[CompressedData["
1:eJwtlnlwTmcUxh9KM2oUiS2KlkyikogEESSWCI3GmsSEkKoxQkJJIguJEUt0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        "]]}]}, 
    {Hue[0.4127048464911927, 1, 0.42856252024296393`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtWHt4zucZfmjXui4bRgipw4U6JMsqQSItNVojq8RpdJeyLhuVsEuCCHIk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        "]], PolygonBox[CompressedData["
1:eJwtmHlUlmUah+8Wl067hOVauaY5o5kLaTPRjFtBJ0UrTWxKUxBTQTBN1KRt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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntMlmUYh3/aNN0SHFgILp0cPgQZZxTFw2eSKHhEWytFnQcECjQVnKAi
6nSGkfNsqA1zgYEoqHkO8ACKaVZGlE1dim5ZBpSHQWLXu+f949r98D3v+zz3
/bsPL/3nLEzM6CwpG7rA5d3SiwDp2AVp/XxpA5yulkKipT6bpJGsnfBgl9QE
EWVSc4j0UY60CfJh9EmpKkIahc07KK2GcC5421Py4J1Ye3/CGimT97Ng/iVp
HgTclgaNkXxWSa9yX/Ek/HkstUE7xO2UxkBUieTFvdHY+sPSFRj+k3TdKY3A
/rlCegT/PTZndGB7HyWWMGLkbMdeyR8870hfcF9brnSqhn24wVnfwaiV0jQv
ziqUwuw4Q7FXFnEndLuKj/AiVVqDeIvY27/c+DUYv5w7OAMyIB1K2evH3kT2
3sSHCO59g3g/+FH6ECaUmP2p2J8XSo0Qt5h4IeQIMYTiB/Y+f98DDzueXlgn
moyEUHR+jzOWobnD1tIPW8/zV+F14jrgJ5Xn8z557A2deWcs74TzTmCBNBD2
428RFMyTUsh9Erok3pSmwMW/uXOyVEht+DVLk1gHNpv8WXms3kx+Yegx6R/8
i8am10lBQ4kTe62UPMHURs6EaRAQhBaZ1BD35MPhBehMPRbNM/Vm1V1Pzl4+
RHLH9q1AQ/DgnlXk6BK5ijth1nWsx7IeB1kHjR7ZWG9y5gOpK42WoWj5Pbn9
ASLxMQLCoZaGeERtPDkl5UZKR9dKA7bjIyxJNj644UMPcAF/znHADc5J5F1v
1jXEkEEfRZGTI8RQAeX01CHon4fGcZx3Fz1PS5MhEfqjwYki6WyKdAa2Jxtt
/dHWHb/dIOygyVUEds8tcgDOBvynt55SX7uoq9HkfAI5HwbDoSfaPRwsuVab
nrB642Qtd8GsfdL5QGqf9eki48Nr5KGW3quDRPZr2K9k34WcuEJ3zukGURe5
Ay2isU3l1CV4UmNP3KU7rMfRc4n0XgL2OHd+DX4tki84Wkz9e+Bf9VZp8wBq
lV6KhCh46xn18i79g21Ei1/Andp1g/hvpIZBxIh15f1wznG5bTSztBtw1+j7
8A/qjhrNgFHkwwmx8A55WbHD9IPVFwm3jWYTsR7WbEHLdrR0R+NesIxYsmBr
vokn3ppFO019jmE/HhIs6Nd4+Neum1ZsRz15ipFeIaa+xNkPWnlmOj7sLZY+
g0Io48xSuM4dFfTndGZYJXVXARfQvgmdJ94zc8KaF2523J7k+zH9+hccZ/a6
U9dnmUNnysw6jFkbAqHggy/B+OKN7YG/LhBMbZXQM5/u4RnWYXD2vHTLwZ3k
2gvt+sw3s9eawZ3o/RI06EZtbNjCrCVvY6m/rKXoBHn4cAD9HHxH5uDDXFjC
fFoMI6ilc/RHBuvP8Xsf/FpJjNTXM/rt/U+k3dwbc0AaAkNB9n0vubsLd3aF
B5zZBOermCXUdTqaOdDoHBr5YTcyEz6Gp+T4CWSS83Rm2GLsVmLaAgHMWA/6
yB/bit8tUED9j+f+9dwxk9+nkKOb5GoG6yQIoa6CqCvvPNPHVj/3pFdcocau
4RrOcNrfjRnU5yyYDU3och+C7TOCsHPxtR6fU7C1aFMHL9GmA4pZX0SrdtZt
cBmNkpegE+vnkIMeyeiSja0k/qPQb4+ZP2nMjTZ6sh2a0egOGm3LNzVs1XIO
szcbcktNngsLTI9YvVKK3l2ZOd3poxw0jPSnd7hvpPWNgU3Mu3zwIl+lxLiB
9UB+D4TfU8zzQawj+E7kzuaMDuYlZHeYerPq7gz6rUWDejTYSD83UKcONJvB
/EwqNLFYMa0ktgXEuAo7DO1ioJj/H46Ql9/wPafY9HIOOU6gX8dDBu9dJ94L
VaZGrFr50n7n26/QmG/dZUjjuXX02UL2q3i2usrMSmtmxtqzZxv1+Yja7jQc
Pa9JS+nhTBiWhi+w7RD34/s6fouxv3Uh/B/Rgjat4EvN+ICjxHwLfJnf6bWm
3p+zn8o6DWbiQxKstnunFX//Bwd0cjs=
        "]]}]}, 
    {Hue[0.4005358642599718, 1, 0.44541188025542366`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHlU12UWxm81ms5Sjri0mC2IS1rp5LhkM0crxy21KStzsmksFSsXBDUF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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHlYV2UWx0/aNDrV6DOuYJpNKmpqmqU46jxSuWAZJmKuZeWaCUKBK5S2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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntUz2ccx99shnFoKbcxKsmdNCp2dmhazRaOW1PZmLJkity7uMz9lJj7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        "]]}]}, 
    {Hue[0.3883668820287509, 1, 0.4622612402678834], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHl8z/cdx9+01m3asY217mOOrJ1RNce0HTq0j83V0lJn52hCCHFUilQF
QxArpY5kLOqYKwSjxLEkEkVbR+bu4WonEleD0NDnu6/P/vB4f/P1+X4+7/fr
/Xq/3u/Pr9ZfY14eVtrMxpUyewhbZ4lZ3yfNvssyuz7C7MovzfavN4sdZ7as
ktnXH5hlbzJ7qoJZzZFmBwvMZrQyKxpulj/brLCe2eG1Zt2+M0vtanbvrtnZ
NWZnGpo9xx6lCs2adzLLw74SyzrOik0zq7DAbNBv2He12bHtZiOamM1JMDsa
no9gb75jFt/YbMUWswe5Zktrm312jTPwoSl7TighjlFmm54y+3CpWW/OONfM
7P5us/fwp1Uvs3nYf0SZ1Spj9vf32JO9WjQya7nO7BRnZAPGvAtmTTLN1hLv
r78w678Bn/Gz+2LODN8u5NuTfDsHf05jz/PtlafNHt9sNmWZ2c9+azYZ+8J/
+a61WRvshcvYDmYXsZsHmOGW9SHuolVgAz5X4syq/Qdfm5tVxr6Wh09gu4o4
Tk80K2nHOfhz/QPlwnPS5IHZv5ualZtu1oF/k8CkAv5GLjLLJadFxJU1W+uj
Wb99j1laXfKWaHaNfVPB7Sp2bopZDjFm4H8qOYghF20WKE+erzLYv4w2a1+R
dzPxIXxbiufK+DQBn7ftVf48j5X4tupGs2ZgUhO7c6/WbCDuyvlmKfjQkz32
zhGXIjj3HXzIxofX4VURGB1va9b6LOv+aZYcwf7DzIayfmdls/fjzbqyLov1
Gz6HMwXC1jHus1j5mgEOr+0SJo7N+DtmnbubjcLOhQd98b/0VTiIP3fI446t
5A2O1Od96w6K33FYS0xVNmifRuRk7Hr5nwKGs8aJJztJ5jP48Tw5aoaNOyCs
LpP3igGTJ9jvAByd0Yccw7EWmxW7Y/BcOMuxf/oG/leH+8mcu1m8qg335y8E
e69BzuyZTr54fwYc0vGtmDqtTz2tBOt69c0asqeBbzOvi/vEAseqwbF22HL4
Px7Ol8XezhB/DJwafKn9L7F/6XvC3/OQyF6/Z8/6+4iRenu5M3UwyKwHf+e2
MPuK/JffKN1w/fhXnM5qy1l/Yt9j7F81X2f4WUUZyqXndM02s7vkIIKcxiVR
G4ulCX/Lku64/txGh4agEeWINxL72ETV3Snqrst81VEEZ53g3Cacm8vzXXiT
wp41wOcW+ywjX0MLFYPHciHSbGqIKwH7oEBYlWXNsKB1XjfJp1W/o9GVtqGW
/d2SXPl2C9/iAm8PpEtTXB+S0YmIUIPnqMEjA/Xcg3c14O061p8gvxH8W8Bz
Jb49gIbEoHWHtqs+vU5T8edXH8OTlqzBTp0u3XP9iyGui/hwCB8WRWnN46xp
Ac6HwTmJNTXD/r9As7uR3z+2N3v1XbPGIY8NsbMTdO5Bzk1OFLd7FaquvL5i
iW9yOPfGQem76/w18DmerFhOY/PB+gg5SiKWkuPSYdfjtCxxoy7ceHaE9OTh
QtVBYh/VZPVN8tP97Rh0zGv3GXTjDXSjEfbh/eKb8+7wBvHEe4jv4Xt5zTSI
VS1k8v+jYqWfXanZKdRO0Rt8g17uQZf74n8u2jUMP/pR67Xh5/JCrXfd7R40
/9XF0hF/rhKr732fO9RUyS3VyAtwrR8x76J3XIyUpri2DGG/tZmqKa+twWhO
LfRlBRg3zhMnV/KculRYrcBGhTWR2FsxZmOIZclK6on6/x/YZm+VLnis706G
00fJGTyvDvZlg854L+0eNNDj+KRAevYVtdxhgerF+09S0K72C5VXz+8ksK9K
3mfz7W3y9eVlfXsOu2+C9LwGtf6HwLE2rO8U8uUamUnMU4jrm7XqbX5W11Xi
oq9vxnfN39dZzqlHV6tevCdfmitNGI92fgQXjVjqsjaa7+tQ11HYMkFDXLfG
hj7VmnMOT5SG98xXb/5hzy3qx66fZ9iv3Hn2r2Y2E77PDrG3QX8qxwtDx/LR
Y5pnjoDZjyLF8wxiuR1ycRQfDsOf+vT3CqPln/u5if3vgstYzrqzUXnyfP2Y
8y8HTcukDkrtkR6+ROwluzWfPMAejBXm9cE+4YBwcDzm5OisQ8s0Y7lvj+Fj
0XHF6PNIP/wrBp++2HaR0hnXmx5w9RZcLY3+fLhFs9PKLZpvfM4pYm1v9Kgy
sU8ab/bndOmh62JigrAac0e91nvu8/gWmyTNce3xPun90vM9Lcw8BdT75LBn
AnuuoE8spGanZ2t2dF39OTXR6qxqx2soDXz6s34Q/FoedNX11f/2999w5hN5
6hHeK9aP1/P9RZpXfG4ZgKZOy9ZZs7Cp21TjmdT4cM4q4Ky3+a576Fm9see+
0Ex1CbszXVrnM0VhuvZMTFFPdT2pDrcHBJwnwZ3oRMXtfPd+7DU+jToalSt8
PkHnSo7JT/e3IHDAdevTwB/P7aY06fzH7Hf3oDB3nlaHJ/lwI433j+wXlx4h
1m/DrHgda/Tow6+ji9ghxHOAuIZhb+DTcnLzLbYkcPIlclh3uOrF6yZjjjRk
IhryEbPmVjR2F7bDefH5SXi9vg212I339LxzxFAMhklgOSTMTtHsPxGM9nm/
xmbNFOaO/a1Qv22pm7ojNef4vNMAbHfjT+N01a37E4M/R8AkAkzysHnZ4lsX
7NHAjcFwoeJorTm2TLrp+hmFDxXOq/ZdA/aHvulzbvoq1azXruu763y9fM0K
rkvz3kTLwrx9Cj2sE6+ZYVC2tM/r8STPLeI11zWF/28VCZPFY8Bvne4Oz66T
H+7Pas4vt0+9zHv7wMBhjyMj9M2r9M2kMG8718YUimPeu7zenAOzqL9qgQNV
sDtCz5pAXbe/zozYBWyv657mvbXmEs18PvvV/Fx8chxWwK+37ijXPlf67O5z
acfR6sf+bes0zS4+w4zBr/Yp6mXlwWcauekF32auFic8p57bjmhLYX+0H1vv
TenJDr77NF75/R37bUjRe/9/P8PPGhorLXP+Jy8H5/vqp8X31ec8XzdjdLd0
zpSHMx1PiIvduAfkJAkrn3mjl0i3q8RrvnHMa4B5vVCzjmvTt+V/Iv53Cn3N
tbZzuJ/6PXVUuBfEYeOSFbv386vhPptN3h4qUh0UMgO+GPBfGCXdd0zqgM29
QarB6H3qEx5Lafb46Tlmtxe530yitw5UrWXAux3hTuT3p6Ghx21lho24pjxm
ROr+4PnqMFq8dH7Wu6Z50eM9QyxDU6RdI7Fdc7Sn7+29zXuc31G897j++Hzd
MvA2NUd3MJ/3fO5r8v/5AZ3oPVJ1PTVFMXvsY8CgTsiL/wbg/rmf5cH1ZNB2
n51d913/hy/SXcK18QZ951T4HeD4Gum18784XXcA73dfz5XGudb9BLsyS7Xj
/cHvsd7XfKaeQu7z8L/uBM0uHqPf13OD/niteAwei9+9BocazFksTnt+X0lR
P3OdWRiv3w78N4TiAumOv5/P+1pBE/w+4fdD15kSdLpHtrjnHPQ68D77wz38
mPriZwWaj50/UZm6g/n9ojV94bvwe0Vcou4b/r6kQDOT95RDPEeH+07CBPVm
x7MH3C89U9p+k+/OD1IsXq85I9R3vP98DzHHjQ8=
        "]], 
       PolygonBox[CompressedData["
1:eJwtmHl0j2cWxy/FOZxTS1G7qd3QDjW2GGZKp7XVMtZYWzTEGttEEyQqqpOG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        "]], PolygonBox[CompressedData["
1:eJwtlntYj2cYx785bY5FOXdwPm5yWodtbdgS2xyH2TWbMaGJyGGIHJJlTl0M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        "]]}]}, 
    {Hue[0.37619789979753004`, 1, 0.479110600280343], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3tY1/UVx9/eurhZqZk38pa60ulaa3lbPU+2aiWBJjPco855RXSItwwx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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHtUllUWhzc42Vo6ZRpmiiiakjmV90QrZ4W1tFqpo2JQ5HhLxbxfMtQp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        "]], PolygonBox[CompressedData["
1:eJwtlnlwjWcUh38JWtXSWFrCtYt9jS1azNBaWmkJFzeGaNGMBKEkDUHEXksl
Y00QFTFEEm6s0xtrZJlmBAmJNR2aaE2r1JYwRPW5835/PHPe3Hz3vOf8zvLd
llNmjw7zlBQNNWD+S2m0Q4rE9ngq+cKEPCkQfr8jVQ2VrsdIFTul57CDL+7p
IRUckca9lcbCy/+kJ1MlB+dVSdJKWAEfeUhjvpNScqSJ/aT92Iwd0mGoz/fr
QfNEKZGAanM+dUI6CW8K8NFfuhEqeeZLzk+k6vkmJndsAXelgcO4e6kUlCtN
hqQwqbKedIV7S+AatImXWkNuFHF3k7JTpZoHpEGc38c22EaMkJHB/Q2k8LmS
vQS/EJotPfaTapVJS5ZJMZCVavzkYcPnSBEQeJi8Ydxh46NJHJq9ki5PkN4+
5J5H0gfgeCBV6yD5bUGbNeQHnYmhE3gTQ19vyYM4j7qkI9CG586ji5PzJXK5
CIl7pVFdpJ3YR+T1EBzp0gtismNXom8AOq/AFsZKRdCQnD6GKU78dJemYfPR
2tmRO+ahDec8mLSLGsFA9M3Cx/1gctpD/TpL/hFouh5NIWu6qdc+/r8G3ddC
HjXLhZrHpLNNpFv0y3X6JIc+GXGUnkCT1XAsRepOrEexL2bTN/AtcX8Dk+FQ
fakcTbvTZ90gZ7HUBx/eaOtVLH0IhWjqM1K6gH2ziH4hp6bn0B1scNfq2TtY
7yVSY0j/RUqD+5ukZzZ0opZe5fiD9cvJkf5fSP9HvTTnRdhwiIBo+rOksfSA
fGLJJQ5aLpR+JY/YNGZhg5QMz7nnGew7bvqrFnVdhu/QXlImNfShnm0hjNxn
wYkFUntq/tdPzEO8mZUL+CuEIghFrxAooTbJaFCE3cTfG+EesVzks0hiOUit
J1GvDKwPmrWFTmiZSa/dxG8Ysc6GWeg6Ezr9LV31l7piO2wnBig7KH2Pjvex
l606PCCnIs5XoPK69MNgdgB2dwizBsXochWWrpBuk2NCpnRmq3QaXFadL5Lj
DvplO4wMNnE6iTOeOLbB+jSjYxw2h52QDenWrvDn+XNZ9BNkwxzy8WdO5uDb
h+9EYu/QP3ch/Tz1BXspmg2R6pJvHXplSiv+T55lUA6N6M+GUEo95hHzZuoT
xmy8x9za6LEW0BI+w/dgGAp27p1BTq/ptVcw6gy93Uf6GptOfi2IZTzPjecZ
B/Rmb/SC1vRfGn3YFluHeagNt+iNsPbSl+4+PEtsfaWn2N6H6HOoIufXMDPP
zGcZ+q5LMt/5gu/8G85Ogrk/mhp2ISdf8u4Jf6LdH7Da2gGf4seT+nvAQvbV
WuLcwH4ZQtyfg419NOkrzuyhyegaBPYUk48DW0l9KqA2OoreiKQPngSbnbSV
PTGaGMdAJc9WwD9o4Us/N6ZvctkTOZDMzP3Wkx5h3ppZu+E2OpSjyT3YnEBu
9L0ffdcfBkA/Ygwihnjmx4+Y+kFX5qYjNWrOvrqBJjfhCfc8hhBrTwdjS6hr
McRR111N2bfHzAy7Z3mB9Z6LvkT8aL3bh/jWSe+wM94FP3z1hS0HzP0J2JPo
mglnzpt5uoWW8y0tI1PNPLnnquFis1unslsd1CAQAqxeHFVqet3d80n4vI2c
A8gpmfNeCLT29xJ61oYeTaE9PdkOmjnNfmuFXW71Yin9HsN5KeRbu7DgoamV
u2aD+NyGv/3Uw849Y+GatUMSo8073P0uX5Ru6hrLvcO4czicZs5OgXOaibMR
+aag0X4I4R0WxF2h2Lrl5v38qsDsUPcu3YbmEcxUucvMmHvWBvNeHQSzrBkb
wLnaa3YK70ZPbAX9Wwk30XIXMRdQ+4PceQh82KVtoMxl/N7DDif3YeBymb16
EuuBH0F1y287+vkAOqTADctvcarx6fY9nVom0S8zsBeOmN8yhdgKeqoSnnLn
Yl+eYVa9qE9d8Ioxs+xDz85Ft3kQYO2BkdzXhPrYYBP9a0fTKuqxAM2iYPtG
egl+Pm787sG6iCeBuLKizO8T9++ULtx9iffMZWrUlb3eDa6hdQnUcGs+kbuq
qJ/1W2EtddoAsdCHZ3vDCMtHIT7+B1+Moeo=
        "]]}]}, 
    {Hue[0.36402891756630923`, 1, 0.49595996029280265`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtV3t0z/cZfsgup1OXDG3cQhyX6rKpUtexVhtsVabJFNXT1iUyZyXp5ZhL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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHlYV2UWx4/Somn1iOZuPjoGuaSljrlkObk8ztOYS+aoT1OZjLiikCho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        "]], PolygonBox[CompressedData["
1:eJwtlnlQVmUUh39IlopiTqmogEITnzomGoQKpgYp1ogmEIvaIqIiBaK5pKYm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        "]]}]}, 
    {Hue[0.3518599353350883, 1, 0.5128093203052624], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l3lw1+URxldOUaC1WGgoqdJWQUCxhcrVoWJbqtMWacBGGaatEm4NMcoh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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHt8T/cZx5/aUFa6uawuLSVsFZRuhhKXunXda8awudTrRVkx98Ro0wSt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        "]], 
       PolygonBox[CompressedData["
1:eJw1lntUz2ccx98j20FlLkPut9EUbWNK5TqMXdhxOSw7R2jJ7EhYksLi1Fxz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        "]]}]}, 
    {Hue[0.3396909531038674, 1, 0.5296586803177221], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3tY1/UVx8/MW+hiCx8mpktnbs0st55pXtDMmdU269nFPWvWs3kL0hIE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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHl0VuURxgdkEShiWxQIIHsLIYDtUQscQIwebLUSZPGI1qqAJrKDIFsS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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntQVVUUh386YmNpzmSjQmki9hBErD9MA0XJfPSQEaVJzRRBuWkpXHTE
FMx0HM1nIBqgpYSJIBogAj5HA0URfIGvuL5fXF/gIOLkWN+Zff74Zq05Z5+9
117rt9a93pNnhs1oKSkePOBkmbStv1SNrdsoueHZfqkZnkOPPtKZeVKNgzVQ
NtWsP8X6ikPScaiCuJ5S1HppIN8PgM5HpD2s88IumCWdfV3amCQVbJJ2wRs3
eAfdFnDm+9Kb+BvcUvZwqSV+Gn461G6X/gFHhXQsUJqG9Z9m/G/xi5OlEriS
I12GnBgpj1iu4b+aKbWD2OnS5wOIo0oqmiu9EyDNyyLmddIsyCnk3QdSE7EM
XSENg8s8c0GtZV+Tvp8h/Vcr7esg/fY3iXNJLeAguTnoKb1ynfOgPeTulrbD
OSvOUVJjg3SJc/ty7nnObbNKehl82LM7ZNvnZ2HjyKsTXOzdbah0J0F6mE09
ONL7V6kevwFu50mzydst7GanlAHfwXRo+ksK4N0zbOhP0kgYVsydON9NXjpX
Sp0g/aa0ZIS0aDE5iCYOqCe+INY9wNaQ92o4YN+xVyq5T8GC+4S0MIg13PFZ
LrGgk2asXxrvIR4tzIH4LJPv+dg09k+FaHwfnkViJ6OPHb7UC818gz8RLtp3
v4AdvUEaAw50Fw3T8eNY/7RUCj6ANvtSs2VoZwf6gkfLyRecfSglh/IeW8iZ
u+CXbdIEzl2F9XwhfTqRe3Inrzr0CCnko6m1dJ07rcNfDz24vw94w9stOJd9
StH7MPIRSA3L8I9AxBTz3pP9xqGP8RCBFieBk3ot49yZ2K2c/ScE/mD2CKCm
IYukwTC3BD1St+vUNGk+8UI/7tSR+y4lp0V8l4j+fNmzBH8PDJ1n6lpHXYvZ
qwQuFkhX2ecCtoGefQzhxDcG4o5y5kfSC+6RZOejH7F8Ra3GQjnfuPj2KDaT
mmwBp/1NLDaYXhsE6y9QsxBqiq1izUnwQFP/UjfXFXQB52A0MyQM2hJXpbcU
s5Ta0pOt6NGRM6Uu+F3hJHVKol6nsQHcuw9U4VdC/XLz7hS+g7iiYeUa8s1M
icRvRouL0eL5aabvrP4L5XkZ97iYSAzENgaqbU00LDf7Wvvfp7+6W33mMn1n
9V9osen5FObAKPywYtNfVp/dcpn1d7EeuWY+tsI2ooUnULST+vFsN9aX9X4Q
zjnhnJvOuW1q6H0o535HYaCt4SDsQjTwI1yy61dUYvJg5eMl9ujPHq2x7aj5
fLSzhJxGUfcpcIL5UgEnmGcTyG02vdWZGDpBR6hHN5mr0TnfeEHsYe7UT5qB
LeL5CC+pA7kIZ+2X4CKXtdC20tSqPz2fRQ+0525bsW40eA/WUocP30UPxLwW
UmAQz4LBbc+okETTw1YvB/HsY54FY6sTjD8Qvwvru8Ide67cxt5gr5sQnMEa
OE09XlCXQPwKYj4OxXa++7LX/vvMZ9j7Mz3Yg9ru5d7s8wie2hp5gu3NHPGH
nenScHprKrPEYc+kQnK4mhyuAaedo8Yo1pOz3lZvTTW/a57MqZ5oyhcesOd9
8Lhhfr+WUMNPuNMQ7jYEOwcNxDvN/ax7DrffnSPmwgQzq5uZ1b7kxw8iiGcS
fJFu6jIefzPzZBP8Aa05PwPbiA4Gc/cI9JfK3EmDOHvWrKSnY9BjLNQ9Z358
zVzEjkW346DK6kfwYY9jrF+LhvLyiZGeKifWfPwC+H2H0U4rnvVCt/7Qvpzf
OmhKNfveY99kapwE5flmnl8lLxuZLxsg3Z5bfpZmqKcb6uAQf0QOs64b+7wF
2ba+cokpKcfElYrdz3cHYsx8t+Z8W2IoHUQM2MlZ5r9HJLMrj9rlQ8hsctcL
zaKTM2jmLDjYPxr2JZvf8DaxnMc8+4y5lovNpMe3QCJxJcBdh9H1AkvPiWYu
X8szurb0PdhptONH3d6DnvC4wfzeNzUYPVi6+B9tvYtV
        "]]}]}, 
    {Hue[0.3275219708726465, 1, 0.5465080403301819], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFV3tQlnUaPdmklZNWU0a6uGZpFwVhak3IMd1spNlt1VrbnXGn1htiboKI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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHd4luUVhw97RGZFmcpsy1SqQKXsJb2uIiCjV4WWKgECYsKW7UKEXhVC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        "]], 
       PolygonBox[CompressedData["
1:eJwtlXlQlWUUh3+Z4IDVBH84iVqa+4aaea+QWwqjzrRJas1YOiIiaoCg1igi
Y+qEW24JXsGtCFlEEbgg4kiyiBWlIjiuiSigjpBoiTCmPXfe749nzrn3+973
Pe85v3O+XsGRQREdJH0NbnAkRsqCtMPShYHSYId0YqdUCGH4DfwXit1fIH0z
UspbI+1wSjuh0lozhOdF7HESfl0l+fpIY05J42ECpKbx3zApA1uRIJ2FS6x9
Y7i06Hdp6CKew6Qj0kRwbJJu2aW2YimWNaugYIU0sKsUk0h8u4kPHmdKN9l3
Kuf+t0V6BpUrzFnprOlUI5VOkNxrzL6u/aMjpCj4+LhUwn0+xT5dLbWCY6/0
8yDpeK50P5u4Rkj3sKlh0iF49Fz6e67UBdsdekD9ec4aJT0oImb8OphHHMHQ
6baUOUXyxE771pwXxHlJm6VkcFyWdkMiPHaXqsnBIPIyEHyhvh/xfy/Vcr8q
7u7/o/ROljQSQrjfPAiDz6jBRnL6HrGKmCNjpeIk6Rdo3EoNwd96ZscetNY0
RFJX/APgYM0S6uaejCZ45yh0JO6XIfm+5P2hdDFeWk08sVCXwTry3IC9fFpa
xn4LqE1hCPWBTeRzH+fl5kgP2bMFtq+VsslHd/b0zJM6w1Xu/C9399tFfH9I
L8HsaOlLWEEMXuyxHGsnPhsUHJXGUaMY7hZCnX7j+TxsC+8/gj3k1wHFMUZf
SfiHiCGZ91KxNdTxEvS7RU7I7z5i7YPfF24Sy1+w6460fiq1wd5jz7swirXr
2MOGtVH3UdBi6eEh1jNO8oArxOLfX8rfhqaKjY6fYXfQFzthd4rpKY8ozsFP
gMcVxA6Lq9Efev2EZwnlPIfhaDKLumzD30JOi/Br+a+IOE5Cdrq0lf2G0Q/j
VtJzcIF3z8O5cvP+AmL5okya7CfNwtrInR3e4mzvodKbKUavLt1uoKcqqGtP
8vcne56DbsTjA6+hu77ktDN2ejO9AzOaTY9dizI1dtU63cr3d8Q7ewl5Iz4/
4rSBHQ5z10w4Ch/4ozfsiwXSc4jGDx/A/GD+pDNj0iDTaWoVQM+8wjmd4cV1
9B0odbghNdHz44i5HR13RINukIlO3mfQbafWWfhHoNmaF03YY2g4B+7QN7dd
sNaPZ7XYxdRwEcSS5yryV8c9LqGTGmhINPfpWkKPcrehEMyat1k7B9vOnmfo
1Sry50ae3OGHHdQe4pZJzsGcfYCck6fZ6LgNbTvRdT4EULsQ9jlBjqZxThBk
HzBr8rC9mVt9YKXVFxtZ84Q6tkIZs60U3PC7cO9T+PXc4Q6soe8WvssZhZyB
Px0/Bv916uQFzcTdBPusGZ+MjeR+ERBdYvQ1HB2sg7UQb2lkPfYfS+8n0JgX
+veGYDQ2Ba2FYvOIxwmOg6au4cSfgJ8IY5hnHw1hbmGd/J8P51eauVLPXOnG
Wd2hFf8n/nuSYWaPawYFnjbfgwdodjL+FPDmO+QFc+dzn9HSzFJpAOv7Q7u1
Rw37R7M+Cjbjx/PfYp7ZeccGZewTx9oKbE6I8c/gO9FmPnyO9lLR+9Jq07Ou
3t2w1sx5D+baw0r6ABZmmL0jsB7s6wk30NN1CD7Dd5L8PA3lPWZCGLShk1fR
w4g9UjnzpgyO5ZgZmocdgl4GQ7P1XTpG7SeXmVkYR34D8ANdv5mjY6Gn1du9
+dCH8+5X0MPSnI092vi+PIU29HuN+rbj25ljS+dIo6355ppzeYVGOwWFZr65
5pw7sbnBfjS2l3mQgvUpNd+rVnIUQP4DoZG+OUescWgkAX0kwgb6MR58Q41G
5hPzXr5/dRPRErHWkbvbUJdrvok1zONGft+FAuLOhyTrWzWJ+8woNbWehe1J
7XtBNXPiIoy39BWwnFngMPf0470ZxDYTbNRiD/nwoR5XiOcqjEUXY6Ag3fRi
EfYsMVbAzFAzU5rJ9/8rXHP5
        "]]}]}, 
    {Hue[0.31535298864142564`, 1, 0.5633574003426415], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3tQl2UWx79lNtLuumSak7fCrJ0Q17zXbuMlwLSaLo7WlG1OKl5wFHQ2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        "]], PolygonBox[CompressedData["
1:eJwtmHl4jmcWh0/LVC0zNbXVek2rQ419GWIvWnSml6qZ6ixUR6kkDBVLhSSm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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntUz2ccx99zt2JONMuwhdNcMre5GyqRfzY26uwc4yzp4pKkGmIuGzIb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        "]]}]}, 
    {Hue[0.30318400641020476`, 1, 0.5802067603551011], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtV31U1/UZvdaZLaXFOgdPWegRbeYitZUlR91KZ9pcTctD29mqkwO1VuLL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        "]], PolygonBox[CompressedData["
1:eJwtmHl4T2cWx09raZkZ1ZlGUNop1RJbammZmdpaBtN5akyVLlo7DUIsMYKg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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntM1mUUx7/asnlJsU1MlhZpJmqCF6ZMU4epCc1ZGtU0XQhqViCWNC4v
FzHMC3gBE0pSrDVQRIQUMBVBruoLmWlQCiqK6DLMGyi6+vz2/P747Dx7f8/l
nPM9z3le98DQd0K6SgqHp2HFKSkUrqRIO4ZJYYynJ0lvwPoEKWScVF0steyX
AoZLbd8xl3EzlPH7p3z/inlZh6RsKHBI+eCyWRr4qnQnT6rNkVy92L9Iilot
RUPYds6G6ZFSsKdUki157pO8mdcUJfnulqZB2TLpexzOWiJdr5ZaoSVLugYF
JVLVeOmDDVI656VBYoH062jpZoxUmC/tZHwU25jBvhBRLs11wwfiiGbsgB7E
3B2cl6VHM6U67PvsWcneOSXmLOvMPGLeD94Os8d29jiYLCUNkPzwuW2vdBv6
2rE/YO97cB8O2L7mYa9HEAcEVEqfkL8S8jiP8bsQjB/VE6WRy6V9aJILWxFr
ry+5qpeWp7MG8slXIHmbSv4mpEk+4H+A72j03g6pHh8boBf+9sSXnzYRpzWG
5D34gPZvH+VMCIDHpVInVAdJGyZIXcqk59Ct2EM6vELqzbgPuKPDSzCj3Owb
iz53yPm/cB/2cL7b5+SC76E+0j9YF/zpC/M524m+i7AF+PMzbM6UxnaRXrfi
ZJwCYXw/w7wV2MkrpSngQ64ngKvD7LGQb7XkYCk5cGIno8MUmLfaaFiLhn7U
mz8soM7mQ509fyY5e0QMD6F/M5q+KfXDrqNmDqPrEvTLpWb2gzu57+gnBXEf
+v8oPQ/N9l0pRofhYdIIKMK3WcTuTb2PgbHQB3rDtJXmmwvjstvoPUeqwY5r
Zz7cw4+7UEEdfEY9nMA2kOt6CLLrIRB7M1aKHCP9UChlwm5Yg5YJEErsZ4Zy
Fxkv5h75kqNAbFdy/BQMDZFegROsSRhLbWNLHkjHYFaRqWF/argXZ/xJDgrJ
wSX0vAzxFVIcpKOhgzgSGHchX4Jn7flPrkgXT1MPk1iHbWHdddgWzV3g+/pv
0SgXjcCTvI6C8Rnmbnsw3sqeW+BIE7U0g/sSJ73I2kHQ3sLYnzxhN7F3DHfa
jTVJjJPhGafUDbrDY3Rx3cYeaHmOeTvxYRexZEJnKrrD2eXGzybWdth7RyQS
M/kqgvJd5I993MlXKeMyiDzBHPBNN/UaGiy9fIOY3mIe1g9//eEitXABphJn
IhpMx1ZQdxdIVwA1WMm4KtvMtdZ8SLyVxLsI24h2v6NhHFo6qdFaWEw/CYSP
oBvnXl1K7OgwAO7adyyY2mmON7pWoOusjewNp9dyr/BvEP65Qn+4hN5NMII+
VI/m7Wj+Gn1nJCyw9EDfUYzP0wvOQQOE0wMc+N7TeivIy5wU0y+tvnkIHQ7C
Rvvu3MKvrdT7FujaKHkRWzdsayu6c97H7HeD8U04lm16f7nV++kxXhAJEXDA
7m+52N/I+xk4Cxu8qftfpC+5S+EQlWfepQDOW0Usd1gzkXtzkhyeSjYxW7EP
sbWqJSde6O8J0+pNX52BLeT+HoJVdu8ZSJ+J47xY6GSfNnSJZ1xj9UgoCDKa
jqbv3iI3f8My9FvL+evQzYM6GQZO++07ib3/BTUMaZkmj7PJ4xD2Hgwx7BlK
33VgL7TxOz1iMr21kjqrglJychx8ckyMk7CDqfP/2MeFuu8NfSDefv/isA/J
ySPosP3vZE0NOToJdbxntVD3jdGlgfeoBe2uQXKMeTeL0LWq2PwHqMFWU681
MDfO1OxCarYH73FPCLJjX2z1H/wMgkq7n32dYP5PWP8rrLnWmr/sGBuws6m7
DDQcQt1dpJYb4Q9yeB467DsRn2zOtnwotf93HMdGkq8ISEMPlsuJDmuzTM1G
Mz5CXEchlT6eAtvp3618C0s3/1es/y1rEsw7fIz9angLq6EK2un7L7DmSaoZ
X6ZfXIVr8D9oCIFA
        "]]}]}, 
    {Hue[0.29101502417898384`, 1, 0.5970561203675608], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3lwltUVxh9bQEAcwLIJWAuRNmxlCx2RDhaRtKAdZtopa82IbDaAQJAw
JGGXpSwJQtiUUKDUSQgCiUJMICF8YQ8gIlNIAWNkaYgk2KFCymZ/Z87945vz
5ua+5577nOc857zt3pryh3d+JGnEE9KPsV0SpfvNpYxr0nOzpcGtpbwPpYkb
pYEtpNX8P/aidLKv1D1e2rZfqmknnSuRvs2REntIS09JhRt9fcNS6doE6V8/
l8ZkS9H46t5J+miX9Gmq9DXr37G+aIe0opv0Hvb8Aak3z2czPQ6Lp/Fp6Q6/
H34t9ZnIWZx7rIn05GSp2XbpbrTUY4o0YJs0pIvU7WNpJjHdfZE4KqSSsfy4
3zl81/tKSiCG1QnS1oiUyllrOLfOZPdpvudzbsog7vOe9BnxnyTOvVmcRwz/
I5462D4bpFUdpVzWb52V4rqzl3NfTvX9Z1jPzPRz/46P/eCZAp7TN0nf35Vq
h0q9UqT/huc72E650gIwnJ8v7XokdRgm9bznGBlWe/H9/GXpjwOlHeyfz9/x
z0oXkqSFxJz5Engflx7/RdpMjhqVSgfGcz/erWX90TdS1u+kJ65KW6qJpwPv
fokfgrwHVvOwL+BzUHupmtxNLPVcDyLnDR6Qm5FSfWzcHGk3d4nNcL/mv/9K
6aUMX7f/t+K3iefhRxwvw+0X8KdlrfSQe7XBfvE2MUPAQ8Q4cKX7OZrv97F7
dQLjhqV+l6eww09Ki9vin3w1g2NnwL9tiXPUuDr2MPnmXjFDwAybDFZ72J8F
BwrXS3PZX4KN4c4r8D8gWSqPOLbV5OjsIc+d5TxrHz56ShHiqTzu2EaIt/0P
zp948vj7qe6zCJ/3iKOxYZJGrvMcwxow7Bl4ksI5FyJ+bjZrvzzKe32krti9
NdQAMc97CB92eMzPL4Bj3CuGs+K4V4/g5wQxPgd2p+FMMRw4Bs/Gw+Ej2Pvj
Hc/yDMfd8L9E7B/P4y6x0hRiX5votRxNrfS+5xyLfCddD3c0Hr3BvntjpNHY
t8D9P8RTthNfa6TDP5E6TwO7gHlreF18Sxr1AvdZhoZQj5dZH8a9FhHHeZ5j
eL7IHSZw30vYwmW+/xp1M2q8r5exfmWq53QbZy3J91qwmrCasdr5nj0tQt6H
g3fKAo/tDPs383uaGswip13Y9yI+Ox52TA3bT8F45nLnxm24sS7VdWkStbUg
8H/qODAa57qRVOI5sFxcIm8/Ddr1M3xGhee+hz0Oi8f42OsD58BE6roV+CcR
wwzulxzWjSOmlaaNZ0ucl+Z/T4XrpunnbXQ0OWjXLdbnLPSafUztTtjk3DMO
9g/1srOIPfelZey/Xgm38l0PH6Y7/4yH+fCx81+lL6nfetRv3Qf+/CS24hN+
nNtorjSy0PVwNRwsrXTtMu2sDn66FaAV7En8FbhiY2e43vZA9/5GzY6C28NZ
zyKm/DZwEt7Vhw9Pd6V+sUfJxaQ/wyFse3jYlPU2rLdN9D0nePfZ7b7eFlsd
dL4u2vyPUI9RrP0m6HwtujKvyLmRBw+rwWcF+OzL9f/ZnlfZ+y136fS6lLOE
HMPJLeyZzL0jW6SCzsSDbZfiGj64XJoW+l16oteb1Z3pfYzVO/yvyfJaspra
y/71gUs58OSb+a5Rg1egsxHPy8ND7tf854LVXPSCJR0Y6/+zPY+xU7Ldj/l7
Ldlr/CA1vvBdj7OEOHuFGEZneo+0XnmJvnaqxGvTalTZHrNpj/Vg41s2uDXZ
Ay7E0Bh7uNy1egQ6PWil63M0942Gc5m/RauxXQ96nVq9zuSdOs2kN+mbK9Z5
/OM5vx53XEn8DbBVAedK7M2Qi9PUQdUc14GNq6R+ya6BpsHbL7hWtIR7qfB/
NP09DftO6DvWf1qs9dis997I9J41nDqexv9K2TO11HNpOa0ltvJNroFr4MDL
zBmLuO/aFOeWcawhvJp9yPlsvS4tzAbG9zG57mcCHEkI/nsx55Sf8pp6kO61
YTUyFH+fV3hvsh5lmmj4XwX/K9TVv8ldBbkruAMe/fihdWu2wm04uWqr9wnT
hEnE1o8aT6HGs6nxnArv79bnL4Y+GHXZZwvjT+0Nj8PiuX7KsTMMe3GvzTmO
uWGfgiaMpcbnYst2eR9pmuC9xJ57o2H9w6xSCJ+PJfi7Db/yecvmriiwb4Xf
JuDWDm4MTXAOGBfGFXsuRi53HTQ9NI3MmODcWAquw8L+mt3EF3qNzTXXA56P
uEfhXee59bSOAcOlH0mvhNisJ9v9DYfpcCw9YHjnXZ/tTCdNL9us9Zg7Jnov
t54+nfeqyddW8nUuyWc+08964PTqTtdt6zmZnFvOua13eU1a/Guspyd7Hr+2
2Wy/64/p0Ijlfnfj49vZrnumf6b7ltMp6P3Jdc4rmwEHznFtr+Hcy0FvL2Eb
hpmqK9p8mzzGopkFaHVS6GvFaMhnYW40nUsKfdn6c/egA0Xk7ir4VsGNG9jZ
4d1ceDhotq9fY31y4HZ8hufM4rcZsO4+11jTWuuvdlZT6rRp0Io38PE+8W8h
5gg+FodZ/f0k1zLjZAN8NL/qdWczyJbQCyZne++32p/BuY/SnA9r8d02fF/Y
HJEeZhL7zmgZ+mZzbFGun1uCbUy+qjj3mZ1ee1aDqTu8rqy+IswgKVNd90z/
bHY0zpxP8vne9o/Kdu023AbAr7JZrp+fZ3rujQN74MLNoFfrM5yLxskurA8L
ubb7tQ7xZ3/oOmicMe5bLRlv7TugDI3ri/8q/r8tz/NbNde122KwHG7kuTN7
IrMcF8PH6iYn7Dde3AwcrsRewX88z0OIoSZwxnyPTXZ8muz0by3rIzbjVM7y
GHIO+nxmen75gXPLeGJ86Vzgfsxfl4BDFvc9Fvp11nlm+zCLmpa8Geo6a4/P
eaY/UehEszDzD2QGOTHPZ4BjPMft9ndtnn2K5zw402i39wPD2fCOD33ZNNi0
27hk3wfHw3wby33j0jw2i9F6vOmV6VaHRO8R1seiQp1uh5NxYVa3ualN+O5o
gb0WvqfsG7Q43+O0eG1utnPz8F3GekIMsaDNG8NsuQF7Maz/M9+/N4wDBWne
R62fLmb9gyP+bD22U/imNn2yud963yvkqmP41uuW67OCzQxXmR22rfZn+9b5
E9gepRaGYluGudd060jANpq7tor4fps7WgStbr7d53XLr83I9r1t+lw/wXNj
OXqGeJegQV8Qw/JP/PvZNNnmx+P5PlvaN1lRvuNp30M259lMZd/Z/wf5qC57

        "]], PolygonBox[CompressedData["
1:eJwtmHlUV3Uah18bs1wobSaFdrVyya2xxW1syl2czC2bLCcT0GNumDIjILgl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        "]], PolygonBox[CompressedData["
1:eJwtlnlQlVUYh381ueQSUHKFRBNNBRdQ0UaTJkVzAWacHFMnl0kTNNxRcLoi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        "]]}]}, 
    {Hue[0.27884604194776297`, 1, 0.6139054803800206], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHtQ12UWxs9Wrlq7upa6oi7BCiKakpcabad0y1SMUktz0t02TVkyJS8N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        "]], PolygonBox[CompressedData["
1:eJwtmHlUlnUWx2+OZXuhY2U2lUIllTmuU5pLijqa1klt1DTLSZCaU6CYqYAh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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntUiHcYx7+2WZkJK7cyMqGikNlwZA5dRDvkMpeZHUPMJddFVLpNkduZ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        "]]}]}, 
    {Hue[0.26667705971654204`, 1, 0.6307548403924803], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHl0j2cWx2+sc3SqY2lr1CmOJGjpMLVvUTNqLGNMlZbqaCsJcgZJqmKp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        "]], PolygonBox[CompressedData["
1:eJwtmHlUlmUah29T02zasDoj00lJUDP31DQtPB3ItTJLS+0MLrhWmkqlKKRs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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnlUSFkcx7+2Y451rDOaOccgZN+XwRkzplA6doYwYxdmKmtDIktolCx1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        "]]}]}, 
    {Hue[0.2545080774853212, 1, 0.6476042004049398], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHlY11UWxk8z1Tj51ExZTetkNphZ7qalVk5mWm5ppY7MZJkptlFUWiwt
IqKJSC6Ja4RaKi4g4gqoIMq4FmZZAoIyuaSVTxamJPN5O/cPnnv5/u733nPe
8573nPu9dVj0gJf/YGYbLzL7I+MnW80i7zXrNcLswhyzgTeYpfJsdpj3SjCb
wm+TWTPmhNmaTWalHc3yGMeXmMXfbNY10ez1OLPTrcw6LDN76rzZtz3MnmYs
SDX76HqzZ/i9Z7rZ1DvMdiwxu/Q3syOsqRpl1nqVWWIb1u0y211hlsBZzdg7
8m1/vu2QWfRMM36y1bx7YKTZr8x/Hm7W7xXWNDI7udhsDmefasrZnFm7G9vv
Yu9Ms+kLfX7/G2ZtMn2u39uFczex//5fzA4ONPuSceAOs3925oADZhsW4NPf
zWLHmUWAyf1gciae5yPdnrXYcBSbXsD3/rFmPTh7JzYc4tmG782S+4E1Y/tl
jk+/YrOX8SuVc5/m/C7s2YE97wTzfZyd0d1sV7nZX9LMGlxt9mM2ts72Nd9w
btkxs8a9zT5j7II/3a4BV+zsiDFf8G47xlFzzeqfYf967MO3YZz1cY7ZCuKY
QfCHzPPftOa3C2ZDifEz7L8cWzqu8jVbo/A3rNF+e/nrAs4to82WTnEcTmPP
/axZ8CwcYFxRYHaCeZ96j5/iuB97+vBuVHOzvthQHGN2M35tXuW4C3/F/3y2
7/MA795aZPYvODMGLD/n/StYH897XZh/iY+dGLfMdTtlbxk+rH7A7K0ysyt/
NGv1sNmis5zN865g1fy42Uz2v5az5jBmTnfedoG3PUO8Dm4xK58E5veYrSNe
BWC0BJvT2L/uhJ97N/6+sNnXaG0PeDLuJrOv3+N/7Hmf9ZWMy6vNauD2i6fB
Fawuuh0fV3AWf41ZU/Wq55Xy6ycwfzTdufQrXDpc5Nxu85zZRHgQz7mX4sv3
8PCSFmbXjDZ7BLvfwf67sO2VPc5P8TRxPXu2Jxd5ZjPgTTOz4zzfQyxbYEPK
RrNb4H9P+N8k03NGudObHJoQzqoCs6eDzZ1XOEbCahaYDVgJBtj/ADbP+N75
GUVcfsv2uTjbhFz7lLjUjvD8lw4MPe82ybax2BjN/OH7yAPGixf5+s+w8U18
j8WGcdiSWO7zInKiYC02tIVv7zh3FffD7L82xKgYrm0c6XH8irxLWQp/bjUb
DB8q4z13lGe/vE/s/2F2xymz2yM5sw/cus3s7AK3QbbkTzV7gnfv490CfJxA
/uYzZhT5noXJ/IXnlXAgMs2xHcKYfc75ducZuLHe8+5acr0i2KA81v96rrys
gnPj4FLNFo+34n4mi/xH656A/w2KPOf1bivs/xKeJcK3x/CvR7Vz5hj+RkZ5
vCKIV6d036eCNQ2yXG/fJr6Rqb7naDSqU63nSH2F64tiNzLG46r49iTOD+1w
zOfmeQwUiyRikj+LXLrObN6bcHIQnBzqMZ643nNZmq3YC8/mC52j4moveBS5
zvEum0h9+disETycxziFdb3h9gdwexhciewPT8idRq+hI9hWlkts4POcJmZx
vJuAhlaAw3/Gkmvsfydxj0iBn5luW83nnnvKwZXgVDjccT4CzoOJfXVXs+f3
Uz/iXccKj7qmay5t60qtGo2/b5S7HbLHnve6ovqyEC1fVu31K5exwy6PaSb6
9lyM46n8yBtCHUA/r8fuLUH35mNvUsjTDzegU9Ncwzuh5dGHXYcjE1y/FKP4
Gs5GE20Y9Znc3AyHU/qabT/pPsiXGMamx53btfzeKmhvO8YicHkKm9PBfmEh
OURMl64xGxHndfkL+HJFwHnWGtdcae+0WM8fcf5xeDT/kPcJmdSp1uRIQ7Sl
5VTvFaRjX4Pbeexf3BP+HfZeQT1DP2xoecr1eetL7JWEht0CPzgrI8dxE37i
pfj5DdzfF3h+OfxPi3V7vsvHT3KkP33LJDjYmhwrAZ9I7Jq71XETftfWO+bH
wOqx0Bt8Ac4N4cxacmEb/jbDnjPkacYEOB9qijReOiI9kfbnYN8sbPuQeH1W
7lpR/B14Bw7kwIED7Hk5Pk7Crp+q3bYmxGsGWvkO/E/DnveDzfr9m5DXsfj0
Ojk4mPwZ+C4afcFtlu25r7idDdn/U+y8Bp1Zwjgk1OgCcnRYiJ16q2cDN86R
x5FjPS+UH6oxqjWT0YS3sH8MPho913NpzsMs/CrFzwPseRG6mhfmD21zTmj/
Pxd7XyL9mUV8V6T5GmN94tuOj3BSjVGtaU9vUJnrGOaz34xVvmYm48F97sti
Yc+7X/E8K9c5J+41hIPbTjq3S096n6F+I4O924aeTX2cMBW2O4lbXeBbPNry
7HnX9OHnvY5KG6WR6hvUP5SAz6YYr9EVc722STOjprjeSffuA9su4HykNfbz
bP1KnxcwfpDg/UM6+1xCvxX3IHmFXh0NfBgKVlFhn+5zXIu1v+q/dFxx30z8
E0a4/enYEB3WN8KupvWeL4+VeE+gnOrLmU+VOx/Ei+3pPtczxVIxfZP5oznu
Y2KM80M8UU9XST1aLQ1irCZ/bu8AxgfNngz97eOM17/m8VLcFoW7gHJdmqu4
LCXmN4UaIW1LPeq8KqGWvbTTtStnmmuWzh1OPLuHfq8g27kizohrj4T+X3Vp
6DTn6r/hbBG97M3kY8kxr3+qX5cxdoSLm7Gnwzbv4VRbJ+JL/ESvBaoJVeTS
Yvrqq7K8D5Y9sqt16IfH/kRPWMdZcOOvF7xOqF7sAudBh1xDpCWVBd7LHUR7
hp1wfYiAq/Flrl3SsBkfeH2ZT+1L+gTsW4L5J37/UY90mjhcmeX2XM14lLq5
ExtuxJZ9E732qQbGEOs2qkmMB97zc3V+QvCr22R0J9kxKQaTpsHmiB84u87z
V/UkP/Q/vcDnoYD5Dfi1P+hnOrV7UKi5Oj8avStjz2YnvIfQmm5w4MkQC+nH
5VGuV9JaW+7PHwTPyqAJqhubg+5dhl+vlnutHM24JTzX73XEPYlaU5DntUQa
fg7+Z55yTZY25+f5mkLGEnJ+Erm/46TfkXRX6ogGvgZGbcGqWb3/pjWbqHFj
2KeOefNJrsXKQeVi2WLv35aC31vjvDeeDCf7lnh+Kc+aguMatKgx49FjnhfZ
yd7TKL6rqS+ls53n4vuyvV6zOn8LX0O/p55a/ZNq9EZ4tXaC1/nD8POujV5n
t7/r/bT66mTwORV6+O8Y60pdG6WRS9e71rVD8zrnex+i3kTcFYfbc86kfK+5
u1/0uCp2qpMX53t9L0jxu7F0T3fTrQGrYsbkc94bqEfYFjQkt8j1Wrr9aaH3
B9onjriPBaNvsb9jrXNdmKi3ig14plCvbwKXFr2Yj/e+XL1iLn16/XTf838L
vHfU875wbMC7nmtDyLkbf3A+i9fLkz1e6rvbBc2/Cp2PC2dNJXZnX/dece7H
fk9Tn69+Xz2HdLJ3gtcJvdsi2rVVGrtohN/Dtb473KgO9/SqJV6nxfPodd4f
S5fKlnivIH4OZv2roUZHM9aWul/yT/mpPP1FMcTWfsR0zkL/1qA6dXq354xy
RzrXPfTV0ntphLQiCQxT4Uni3XBivHNLHHuC/ugQnNk7kHszuVYYemndq7Zn
e45LX6Xj4m0V8Z++wXts3Qvjgl7pTjwoxbEVxj/D81bk/pljjq+wumeyf+NQ
LcgZZXZb0BnFp1e42+qO2zjkS0ad55Liovik1ngfq3tnYqizhyBgdfiGoz5U
fZtyfzoa8KezfmeIQGeGh3u07tPSLPml7wTzdrkvk2u8vxTnp7BHQuhhusf5
9yPF6+F011Hpg/haXeTfT3aydihn7GmHRhPfPSGXdf/ODX17VrX3OqpNg075
9wjpqvqj/FBrdJ9Tn6q4DEzyO5Vqk74/NQ/33L/N8Lrye30Bn93w/GdsyeO9
/5a7PfqucyTUX+nNmHVuWyzjdRVeI1Qr9oVvO/OJ1z2h9tWMcD9/v8fhX3mk
n6V8bhPwkTYsC3kk/bskyvVQ38N0PxPm0iDdXdXPR7DPRyHfdT/QfUB6tXKv
fwdUD7C91LVMmnZvrfcRuUP8/9Vr3Md1a/x7j+45wv9w+L40irr0wzLPL9UT
6aD2zyr0PFQ+/rjE713Suk70HTcEHI6DQ3nQcPlUGO4v0rnEoEvSp7bxro36
7vV/QjJRig==
        "]], PolygonBox[CompressedData["
1:eJwtmHlYlmUWxo+7ZVlmNNpMV7ml0mJmaqIJ1khO7qmUS4uKjpoa4FKCG7Jp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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnlwjlcUh39apqaYKbHFUlIt1dYusUZCi1RiSWwlWiFBakkIglCqH0IW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        "]]}]}, 
    {Hue[0.2423390952541003, 1, 0.6644535604173996], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtWHtUl1UW3ZaozeRkaZo9zUdk7zR7WD4qw7FSJ3VpvtLKXD4SX60eoIlW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        "]], PolygonBox[CompressedData["
1:eJwtmHt8z/Uex9+K0qlzujE6Oo9HkUucExPpRC4VowxJyOSaJWG2lcy9baLG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        "]], PolygonBox[CompressedData["
1:eJwtlntYzmcYx7/oNRvXNWOY04iNKSozZx0cYwixYkVEWQ7FNiE55EyIkY1I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        "]]}]}, 
    {Hue[0.23017011302287937`, 1, 0.6813029204298593], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHt8z/Uex9872VA6lNvJnWMm5rIkKVLHdYySFtVYiVFuQ5HNmDW3XMtl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        "]], PolygonBox[CompressedData["
1:eJwtmHt8z/Uex9+TUacIhW4WGSsJk1unHOQ+RC6FyK0clful3JtNU24bqmk2
YuMUkYjYDZvLDCV0Ywjl0gyd5HYW5/nq/f3j9djnt+/3+7m8L6/36/2pNnBE
1+ElzGxaiFlJ/iZsN4sHh+PNjoDjxWaT+phFhplVuGQ2dxT/v8es0gNmzyaZ
1Z5l9kANs/KdzZYUma15zWw16Jhv1gn0WGWWVddsC7hjkllqitky0GIn34MW
i8yag/afm0WBdRvNLtc328z806eaXXrV7CLoM8Ssr7DK59KcpZiv1QFf/3/P
mY1h/bqjzeqARszVGLRhjdagF896gx3DzMZWMMvn/br8HscZxoKDrHEIfPqN
2bVHzVLuNCs9lLV2mWWDDJAJxv9mFtLJTEZLGGyWhq1SQaVks8og+YLZD82x
AXvagW0ysVlWF+YQGN9g/9fBsYnYFmyZy/9B6GecBxwL7K01yvH+i7Pctv9s
bZZ3xOxEnNnPoBRnKw1W8H5H+acm575odusHs5vgS3yw4TU/k87WFtu1A9cS
za6CySvNpoDb2Xvp7W4D2eKBN7F/RWxfiWBI4/lHPAc9F2BD8BlzrgIpG8wW
gznMPRvcx9z3gzDmuKuWWbWnsBn/7zmSM4BurNUd9OWsfcBbnH08SHyfM2Hv
Ye3MqseavfuL2Qwwc6/ZLFB5jNknzJcYSVyuYz7meHGln0FnqZeFH0H8FPwB
6l82q9GdszfD/+dYL5f1QNgZs4fBtD84Wzdi6m7sdtjsND78FYwhJseCFGKi
XGDv4eyvCT6JxpeFTcy6MM/2s6xB7HWqxp5mMBfzvcN86/9l1oH5HmcvUY3M
HmS/6Wv5uwzb1+bZE5wHe9adzri92b4nWW+TWVfO8jxoTa60AQWc6Qh4hv81
1VnJtxDO/15DYivD7ADPetxvFsMe2vO8+i8+353Y7/IJ5izyXFBO1OH5S8Rs
711uM9lOa2gt+VC+1BpaSz6Sr3JSzbaBsiPM7ganPjU7CZry7F9gAWeav9Zt
LtuvJCbGVyXe2F+JTLOP8fmSVz1nlDtXsN+foH+M2YAYj3nFfouF5D8oyvVY
UcxEEDtHt2EDkPlv8gbUJN9qgB0fm+0EA2e5Px7CRy2I/bOseQZEc4Zp4KMv
PBdqg0TGXci1ziCZZyl6Bx9Hp7jP5fsqfBtKLi+sR3wwLnnIrGpnn38TttzF
nnYmOQeJi17GZ7seww8PEdOc5wtyfi14Aa56EWws5Dm5uxT/VuN5/nv++0Rb
0gn/vMbvN/k9DrTh3XaF/ruImHkvmz3lmP1IbB3rCLdx7lM5Pp5APMYUwC2s
9T0o9wG8ADYTg7X4dg7xMJPzncR2J0AScbII7NhBzIJszrwFXCXfroD9zPEt
mMDZxic5B4gLKsI5hY2c39LI58rsuRK4F1QEM7J9r9qzzvLKYH9XfBXFWXay
50jGo+HAgoPw8FazhqAKMRMGypDPd4HV66kVoFWx21o2b814crbPpz3EMk4e
zjlAfzhoAIgmBt8G+4nJb8FAOGEAyOEsuaDOZed2cXwuXP/lfHITJGOnFJDz
ilkcuTwRHy7GPktY8+fmHi8Rs+EM1Q6QDrdmgF+vcH7iMx/7n2Zcm5p4rabH
rGK3xF9wDfzbP9SsJef9nG/XgHD2VAPkY9vdIB7uSQDZxFgW6M5aPUAsPokB
o3l3DIge5bmQTD79mOEcqrW0ZiP8MZEYmzDVv9G3W4vcdlXAIHLjZXBfZ/dB
Hr44B9eenescKC7MWMPZwAXWuQhyZlLTsdcjHfAh++vHeuEhznep1JOvinys
nNvIeBH1OWmj+1C+LM965cAb35kNBSGbPPYV84r9Ped9/hrMX4r5p7/r8f0z
8Toqy30i38gmsk0Svv4IVIc3w8HbU537VQPWpbiNZCvlsHJZnKz9ac8N4ZkD
y4kLkI4PMsDhZK9lD93L/Pyed9JrjWrOh+RBw6PO3eLw2D+8RqtWdwIPM543
D7+BrW/Bi2Af3NgYLdSuKTnwNfUq02uJako03zcfR0xTP2+rA7+yj7yzHm+q
Fws55zdD/X2tp9rxNPsveIE4JL52kd9fDfH1pRkyWL/Pca9lqmmRxPZw4m19
X4/xSPyxM9Azeq7a1xtf9wpqrGptLmfMAeWoreVBEvpkfGfXJ9vxWy4x8Eug
507Bfd32w/HY4wniL4L4a4G+ag5Wss4qMCfQf6V5fy3vj9zktUw1SLVoJP4a
AXZi913gsVvY+BneLcV8jDcM9fnj8OeeZNcM0g5dVlMHwZkcjw3FiLhQmkXa
ZflptM5p14DSgjWJ4QjwYKBXbuLP0DTnPHFfSbgwVMj02qQatWW2x5RiawV1
6z+gH3t9h/iqFcFaCcx51HNdOf8DvkkK9EnXBtRA7Bd2yWOjPTm/FO4YEfgj
kf3Wwv5zB/tz+VC+/HQf83D+asTgPurXkkTnHsVEITy9B27KB5vRUukbXBNJ
G0kDSAtcO+DxuRAf/8l4Ov+LTXSOF9f/BAf+CObyv3iwh/jMB7eRIyUDDhIX
qUapVpU+47monFTuL7zgtWii9DvjXUdc+0g/nMR2iy/4M/G9atVh9vYT6E7t
7gHKUlvLBJpW2vY79nIo2JP21g2bdk3wmFBsRLGX9uucI8WVqdiwQx/XsMuL
XWNLa7ck7lsdd82r/UiT9SBeQ9H8JSd5TVdtV4wp1lQDVAuWfULs1nUbt6RO
vLPGa7tq/PAhXkNUS8Qx4hppZGll+UC+OMT7B8E1OPu6+oJDnhvKkWxivxc+
SGvm9XYO8ZXwpms7abww4irndXgCzCQXZoG8G9i1t8dza/j4uTyfTznUNs81
rrRuKnGWBtqlu7bYTk61Z9w4yXNN788Y5ZpE9VJ8HMLesoL+Ylo/njGuzR4e
B/PJhQVprhmlHVU/alC7Ksb5b2nKw9hh5FWfXxwzmvGGYX4+9VfPY99uzNWV
s02Ez5aMJ/bYc83AHpPz/H96lkT+fAhPhgT1sCo1dSJ81ggN2RAsp5avAFvf
dy4QJzTg3MuyvddSz5XKOCrOa9/fPUSSa0RpxRPE3ElwD/Wk7HOuh9pKG2Y4
V4lTxC3SNNI2dVmzHmgCZ2yO8jXu4HlmkddK1UxpPXGauO0wcXMEDIAT+oPX
4bU3wO6PPXeVw6vI5QRib2lr908vnv90xblbHH6Y8bQC39sk0JF34wp8rD1X
OO//02/VyFtfEZ9TvddVz7ueurqvwOfXnHmMVwR8oZjePcFjRLEijS6tvmOI
c5c4rAnxv7PAv9Uc2uvYzc5d4rB/YI9KAb/tA5Un+5l19s+wwWrw9FHnGnFO
U8bfE4PfpXtNUW0pS8yXAVGMO4BXyZX4eh4T/8VfzdGQzUAmPJN1xjW8tLw4
QdygHlC94EC+HQQem+3aS5o9Ar1R7ajvTXuszHjmCo8vxWAUtXXVcq+tqrFz
iLdscjZrvtco1arYoB9TjY3k+xRskiwdFk1+R3uPrl59EL3iK+A8eyoE+/HF
t6A+70au8xxWLg8iZwaCWdhqNmgIR11/iX6L/GvA+N2VzgXKGeVOneC56kFj
9M0YYjQz3Ow3/leNZ+HF/ruQ3zUYf57ldyv6XZ3fH0z0+aTpz8O/C9jzfO0b
7Xwf6Brj/KAepCfxV49vbgT7yabfjVrpvaF6xMFzXXNKe6qHUS+jnl+9v3om
9U6qqaqtz3LGlvGueaV9dYeiu5R70PwVTniPql61frGvpTWfZPwSnFyqj2vO
L8itmoE+FseIa7LOeTzpfe31/E23jWxUxHh1lvOB7FOV5yuKXLtqzmbFbnPZ
Xj2KepWnsnx9fS9bq+ap9qlHVa9aMehV1DOqd0y84FrnceabUOw9h3oP3UHp
Lmp7oH8Uv7/BB8N+h3efdz2/hnlunXZtrHopLStNIW3RjNrSHOxNdi0j/pF2
+vOE9+LSQ+r1e29yrlA+KrcfOeBaUHcI4YzfKnCurIR+Hc14zTfsD5TGdrfH
+Z2I9GpYG7TjUe/B1YsrB5WLihnFjmJqLba5wfrXwWa0S3quazydX3dSH2KL
Buec68X5kYybHvS1tYdmjMd97dpWGnc63DEMvTwUpJDTi8Ey1ovClhvwd23y
NS2o3/qdwrjVHuJoj3OouFQ2l+2lMaQ1dCeou8F2oD14FBtEHPAeTb2a7uh0
V6eeQr3FBzPcXtJL29DS54n/7tjjKpxzF/kQOtS5XRz/FL56NOAT9XTh7G/v
UbedbCjtX+Wi71X6rTLjyCB/FKPhRX6npbst3WHqLlMaU1pTHCAuuJ7q/YQ0
5/3U/nPEz9lR3lOpt6oa472++h/dBeRnu/+Vs7sZW9AfqQaoNuhOQO8r5t74
3TWHtMcRYr4AlEA7hYD5cNUC0DfBexnt4WXGd19y/tCdoe4OI4o9lxQPNYu9
x1OvJ00jbaOeSL2R7gB0F3DvJe/d9b3uetP5X3Q/1xPtyM/yrFluit/R6q62
XpHnrzSvepHfD3qu6AzLOUvtoP/Wc2nj7sH9r/hR2ulUkueaakb/Nc6J2q84
YBT52uagx6I0hHpraWz5SjFXB98mF3utUMwp9kr+5evr/dC/PCblXz2XtpSP
9b00eVXOmrHW7+Z0R1eGXvSRIH/+tiF67dhBv7sQB4mL5s9zbaMapFrUZ4rH
nmJwJPE0g5iIA9vwVc5k1ySq/9J80n76n57pDkB3Aao5qj26E9HdSGRwX6ke
rudxt7lsL0236X3PEeWK7mB0F9O20HNJPVxn+u2LvHMBJBOXKal+56277xh8
FbvINaHmk0/b3PQ7Ut2VKqYUW7l7vXdSPG+VHqP2LQWd2VsX8H8NAjVf
        "]], 
       PolygonBox[CompressedData["
1:eJwtlnd0j1cYx79GRk9rxB4V5bS22rPUTiTUjlVBUUoSBLUzCLFl6bGSlAS1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        "]]}]}, 
    {Hue[0.21800113079165856`, 1, 0.6981522804423189], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHl4z1cWxg8q6NPW0BrLjNqNqr2d0urojH2n1Y2iHTRjD7rbdyH2mIcS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        "]], PolygonBox[CompressedData["
1:eJwtmXt8z/UXx8/I9VfUosuUa1bJUv365dJvcguzuRVySRehEkNRIffbLiqx
fthM2rJfRptLaXeTy0SlQolpufwysubWmKZ+z9fjfP94PXz2/Vze533O67zO
OW/NRox/IrqamaUEmV3Hv7tXms1vZfbHPWaXEsxGxJvVftqsUV+zLWVmI981
ewEsesvsbTD7C7NZ4KcXzQ6DbJ650tLf6Vxl1g3U5boZ73/BvcHpZr+yTosO
ZsOKuD/BrCtoyO+3gN8OmJ0Ba/h2GhibZfYKeDPabEq0f0Pf0hpaK5Hf4rH1
5L1mz68wy+e32dyrw5pdWTvpK+z9t9nPNc0Kx5jdk2F2d4bvQXupnmdWDazk
O8kgdTq+AD3wQ08Qf5L9Rfj7X/D+e8lmi8HUGWbTQMjbZmUNsae12dZUsy5V
vnYTbNyKLX/hm2vg6WKz4aBrIs+A19jbJDCM34aCz/DBFjDtrFnQI2b/vMts
RZxZR3wSDgZzbwiYdJD1HjLbx/2JXEemmH10K3u43+zjNWbbAv6RD5asN/vH
ePwPlhHL5eCRQuLalriGsH/2uWIhv4PGrNEEDPrWbCD4mr1/A1ZsNHvuQd5r
Z9ZmkVnwVbPRkWan4Es9rp+Zg2/uMPv8YfaXw7PT/dtaoy1rdcPHXUGvBdgK
cl91fjXF3u+xt8dhnutmNmaQ2ZMVZl/i491g5N9mo8Bs9lCtMXF5nOfxU/oa
36v2nPAeMUl13ysGH7G/t6biQ1DwOf4HtcvN1uOPKWAnXF71u1kGvmlNjKYS
q5vxd0mUWdQws9g/zRbw2yPcawt+4fkLk83Og3K+fQ703+73/+J7qXx73Tj4
Gcz+4GDn7z0nlBtTiPFUcPdRYoXtZezvDPvbu8SsD892fZSYv2y2v9j3pj3u
5jpyE98CmfhpA9g7y+wi8U4kBsn8fje+DAUN8eUtYPZFs3bdnC8zL7qP9L2M
24n/NLM9G/DpBue0uF3+utn7YWYxxOAg8R0AX7a3dz7VY787J5rtmOg5qFyc
Bcdngk1wfjMIgZOPEttM4t2LeNda49+L5XsF2Ntjv1l3UO0auQWWbff87Ei+
xxZ5DiuXL32IxoD/waGsofCkH7kbw76OYVstnsc/t3I95Yzff6M36/3GM6+6
7VpTaxcG8l0a8zixO/OO2WkwnHWfAYW/u3a1434M94dmua9lfwT214Zj1Ufw
HjZmEd+ni1ybpFE/jsQu9tIVnAcXQJ3A84vwWS2uB60jX0AdfF0X3AafbupD
nrbgX3zVM8fXks8uFZBjxKIxiCJ3e4OOaE84uAxnroCjrFEMSsAv4HKCa7Fy
RrmTk+C2duCbPf6Cz+x/ahs4jw8GEr/DKz0WEeH47Btye5NzRxzK3GI2BxsS
mpstBWNjyd0Nng/6u5jrSLjeC/RDV/qDti/BdxCBQ3qBp+J9rRT28wFrnyL/
wm82q8SmUq577/HYPViD777sOa/cb0YuNAdnt8ErsLsUXpa6Jj4d0EBpYVN8
0QQsQKMXguuwfyr2/0mO7+X7k1lzErgfrWoDGp4j7v18T9pbDNxdCFqy11Dw
YbnnqnJWuT1iN3Vit3NcXK91ChvgfnRTsxnYmXfOY6sYixud0dxOIOVj8gdk
B/yv++JC8PvE+X3XLGlXcLznkjR64Fb0E/69wfrTwDH8e4Cc2g8KWHsrqM8e
6oFIOBsFEtZ7bZOGS8v/cwgedDF7lRpWSC2LWAynQDh+6Qj2HvFYKCZfcv0p
79zOuzP4ey+5U4Q+7QIPXUIjQPLvroXSxNvQ84RvXXulwZFo8Tb2VwgeZq1/
gSA0w0BXYtINhKAfdcPcJtlW/XXX3mnEqPYm95F8pZqu2p6LPfM7eT0s4Lq8
0uzQEPd5EL6fgla/CYqXwX3wUBLcATexZjA4kercEseOcR1H/saC8+TaBRBF
/Y0ESdnUcNAl23NDMQqh7t2306wVOMG3ToKam9xW2RyE7T+z16NgLxz/6iXX
LGmXcl6535g93xngpLh5Ab3aOdT9uxv/NnjTa5nycw+5VzDLY5/G38no5QBi
9SSYgIZOBOfZ/2H2n9ed/LtMvIj3ZrCRvWwC/T8hrg+Yjae+3o49r5Ij4x8z
u7eZ2bPU6SB8PrWL149h5Fpj+PpAqHO2CddxrBkLstlzDhhCTg0u9h5EvUhn
crsTWI92fgKiX3GtkGYcWumaI+35Ad36Mcc1RPcVc/uIGI8lZ8AMcmtmALqu
wW81wUFy9gCoJNevJnoNUy1rid9DQfo+s7X7/Bv6ViG2bk32GqNaI87Kt/Lx
RXydX+K9l3q4ghLnhLjRGY50AS+hoS+CFHEPNEB/66O/G+lJmtGbNMiF5+T2
uvq8x3UetuWCcnLvHLhIPI4M8fyvAR8HkosDwAvk4kjQAV+0D9Q01bYk9CSx
3H0q35bA3bHU2mNo8FXqQGO4dGeCc0bcyb/oXM99Evsves1W7T5Mr3oE9N4L
h0EVHLgGPv3Ba/c18mU163Qrca48QU3KozZNht+Tsr2nU283Yil6ttR7ZPXK
2pP2phgoFhFwqCdIQ7v/C9K+dn1WjU3l+vzrnsuK71/qX3fRU7V3/qYSl6Q4
7y3UY8zEt33haB9Qj73WB6t/d21TDdmF9g2P9/ipJm0oc06L26rJqs051Pgl
9LeHiFF37p/B1tMTPSaKzedlXq+l1+q1MvP9+VmD6ZnnEUM06UZQBy2tC4rp
hY6A0ky+AxbDjfH0n5G88wDvhrzlvZd6sFB6sXnsaS54Da5MAi1znRviSCjX
mcfZS4jzbeNxr1GqVeqR1Su355v9+PZl7G/OXr9K9dqkGtUb/q6CO8lgINwY
JCznGtTEV7XWucZL66+txd9rfcbRrHOCXDmZ6DVLtesdfPIuCGX+aAn+oBeq
OOY9q3pX1ZQP8P3iU96Ph2HznkTPeeW+ZhTNKmH57gv5JAHfzMP/4/i7HTWj
nHoZxdqRoC3vtgOJgXhrBgmhft2Oj28DK+FhconPLJpdVMNUy/SO3lXNVe29
+Zz3copX2hWPsWL9Nz12VozXdNX2luRGKHie6+cynAPiQs14f14x35DvPpav
3+X9gtPso8z/Vgzu43uVxOZKqfdg6sUagRD5GZ/3BtMXeG4rBy8Q36fI10Fg
AL4cCOKJVRyIAbGgVblrqTQ1jPqYx95zwQ2sVQ/cNZf+EOyDS9+CJ1ir/zq3
QbZoZtTsuApffwCGL3TtloZHl3oPqV5yDWungSL0btcZ7/nU+7VghmgO7gIt
QcT3Pltoxsigjq8j19OX+syq2bUmNtdI9x5FvUrQd+j0d/6Mns0vCmgHGlJW
6Zoj7RmOFjwDdjCj5fX1+W5Xofdo6tVWkuvJZ73nV+8/j1yZD5pwrzHIHcV7
o7xmq3ZrRtWsOgrNHTnHOSvufr8Dc0AlWn0VPEAOtwGT0KrJIBOuZuz0Gqla
mXfRtfInNLkK+1rFeOwVc8VeM5Vmq9p8sw7oACfan/YeR71ONXqxoPe9xqjW
yEbZqh5Wveyx/d6bSgNPcF2V6tqnGqda+CK5OfodnyE1S5bAn59BJ9bqDHKI
Z/ZC54y4s4rfnrgT+3uSV+hFUaLPxspJ5WYuGpaz3X0i3wzh+cE7vMdRr6Ma
o1rTSz2gYjnRzzI0M6Uudc6Je0vhYMIG78nUm22nxuxI8JlBs8M21vrilMdU
sf2RGB9aEdD8X30G1yxeCmfufcTnm+np7kP5cjJ2vw6q8Y0Wka6Z0k6dGejs
QJwX9/vRc8xt4z7MfNlnAs0Gmkk1m0Yfd1/IJ9fIn4aBeqyZKDjOewT1Cu15
pwM4F+iHVIMvVPpMqXnp3+hTI56/KdBPa0YdWuZnIDoLUY1WrV7/stsim7pj
WzSacUMfn+m7k1ediP1jIIoY9N7uZyw6a6lDra0LDlV4rVXN/bHCZzbNbvrG
TYEcUC6I8+K+Zfl97Um9hs6sdHb1ATmwGrSDi23BbPJ2DrjlrPciev7Ws+5j
+foANh0El2bTg4Cz1IIy8EmF9xLqKU7Av9++c/2QHp/l+rUzrqXSSGnloMA8
pnq7Fr3eOsb7JZ1ZLTrpmiZt+4zc2DLO19Ta6gnUGzQI6LVmbM3ay055LRF/
l3N9JDBPat7W2cFSuLcEzCCHZ4IJsT57aT5v9Sdz7pveK2ieiDjsnBQ3lUPK
pYoCj61m8FDen0cOzE3yGUOzhmqcap00QlohjZXWHuPe8enuY/laM6RmSc00
mm3kc/l+e4nXbtXwbVzH0E/3p5/uRY0On+yaIm0Rx6tjVwr1NLev6/39i3xG
aRI4P3sh3s/w9LdmmGL8M5ScHAIOwqEfwAFs2w9m0OPOBJvp3zaBcLSlI7j6
q2uvOC6u38FM3QjE00svAq9c9vqk+5oNlgfO27JZsxX2pFW5PsvGNVV+Rqez
OtUI1Yrn6DmeneEzoWbDbV/5rKieTr2dzuyk7frG/dS2ghepCeAgXPthrfcc
6j1Ug1WL5WP5WjOTZqdO7OGxQA+sXlhnnjr7VA+lXkpnZjo7U04Ew+97yt12
7WHZRu+B1AupZ1bvrBxTrh1FXw5XuOZJ+6S50t6dhW6v3r+edSrY4x+gHO6e
A5VcXwn8pnuNqOkhua750n75PDxgs2z/qcLX0pmYztrS6XnXgq9Xm32z2mu0
arVqvGr9jfTU9cd7j61e+y04O66pz6yaXf+eSd8GnsWvz4Hhe3wW00w2XPnx
HvkB4tKIMehBTLov9jM9ne2FpTgXxcnq6Gs2GpS13mu2ard6XPVOyslgcjM6
1s9m1F/HFnhPpfvqjzaidYOwYSAoRteP5vmZgM4GtKbWvi6g59rDrfB0Pjk/
D7QaTXxH+xmczuKS+cYqMKHUtUaa8wx1LjHZZwHNBKU8v2+s57ZyPIr8npvl
s6pm1vlcxxf5WZ/q150pPnNr9laOKFdaL/JcE5/Dyr1GqVatRpM+BAur/OxV
M4DO7pRTyi2dYeosc1iOnzXrzHnEHD9TVa3SHrXXiN9ci6RnOlscF/CfNGoB
/psD12anew1XLZcmShvVw6mXa8cM0TbTNUnaFFvlZ4c6kzmOHlw/ymunauhp
/D1ytK+nM6iPXvKYK/Y6Q9NZWut012adyWwu855evb3+D0D/F6AzIJ0F6UxK
Z1PyiXyjfFVvdg/++ryv55RySz2YerEM4pIJGsR5L6+efkK+94zqHfM/5rtg
FfUgeYyf6ehsJ4w9tU7yHkS9iDRG39YaLfj+Da95vHWGkbTFzxjEb51Zf73E
7P/4GdhL
        "]], PolygonBox[CompressedData["
1:eJwtlnlQVmUUxp9sQHFUxGpyQ8lcUFnEzLXcEis2cYHUERdyyw01yX0BRQhx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        "]]}]}, 
    {Hue[0.2058321485604377, 1, 0.7150016404547787], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHlYl9USx0ctd03RJJco1wyk3Ci1+5iaS6Zo1hOWaT2Rli3ictObIpoI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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXmcj2UXxs8osrUhQtnKvmRrDPXaIo1971XKErI0yKf0Zl+GxijryL7N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        "]], PolygonBox[CompressedData["
1:eJwtlntUz2ccx98lKTuOsePSWOQSlYysiRyXhhZdNuQ6Q26tUGzMVFoUSjaX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        "]]}]}, 
    {Hue[0.19366316632921676`, 1, 0.7318510004672384], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmXd80NXVxg9DUGiFlxUpFLBYgiBSCrhe/YADBysiS6n1LciIiWG0DkrY
hLBCWEFZLVNkBQI2gUhIAgFZIWFaUXgRZAXCEkE0wfT79Nw/4P7yy/2de8Zz
nnPOzYP9hrw2uLyZ9ea/CqxfDzbLbGrWNMvsXJrZI634XYHZ3kSzfzQym7ze
LH2bWcpjZtOyzVasMhtX0+y5oWZfHjC7/rRZg2KzE+PNOr1sNvCM2aPLzE7X
Nfsiz2zbALO15cwaLWA/z3t5/pDnERlmNRuadZloNr7U7PHOZlWLzHIGmeU3
MftxtVmHoX6Wzhx+zawoiu9YBySbFbKn1xrO5Yw+j5jFcOZjfN/vQc6ZZPYw
+qxsbZaLzt1zzUoeN3uFtUuyy6/Ot5WxOeoPnJ9qtgzdpqPb8flmQ3LMXkP/
ISPMVn9i1g35nZGfdNjlT2EtPW3Wnm9vxpv9zM9HHkBn1lzO/iO2GLpUQVYP
zlqcZLaq0KwW9laYazaBfX2R05Y9Z382m4Nvt042W4T/I/D/AX5fdtHllJOc
IvfPr1gLN5sNbsm5+GfJUmSi20NfmTWJdv1lx1n0jkP/r9h7I85sfg30IYZP
4YMn+fdhY7Ms/Haqvtk7+GkqPhrxG7ME1jj2zaxsVsxzI3Qax7mfFvkZOqvk
Pfxxlp+Je+18s32DPBYd8OeLIV6RPP8z02wu77tMNxu0zGOkWI1dwd4WZvEf
4MMj/jyGd/duIR7odWgfOEt2/WVHQ75/DJmvLjfruMxjUYYv08BlbTA8DLv/
Z6A/9wV7ET+Y/a2d2bVD4HCb+3Mxfr2KnZFtzOqhVxt8hNutZK3ZrttmozuY
JZ/gxUqPY9Fws7qZvr8+a5/3Xf9ozv/XP8w246txo82+QafZ2JjJ+d3nucxS
bJ+1Dkz9HpxOA3Pvu87CUTnsvYVud4lvtR3uN/kv6YTrIF3G7/Dn6by7iY8S
64ArznkS7P6dc9ePMlua5Li6RvwjL5hVfJJczXPcyN4l2HsH2z4jvpHY/c0g
1+1Of4+H4tIVeU9Ee24qR0uI9XpwuArsd4z2PFW+3oc9fwVvlVkziMsCYjGU
eE0by3M9s2dTyFnsXIu9Jzk35yr5QZ5OJKf7kuNzKpHXvL+Nrq3xw4+sNQZ4
Lv+dXH5sm+Pze3Daj/i9iC29dhLXEZ6DbTm36RBwDEctQV7XQ85Ls4j/9hCL
nF3EdYjj5HnitZSf03i/epHZb4hFMfq/Q56WB8P/roV+YHgs7+eB85c+x0/b
PAeVizP4dgE6fEpMl/NNJjoMxlcZ6HYRHepwTslhj2MZaxQ8kP4S8WfNxhfr
8ckafBOHng+x53HsKk1yX2XvMdsJ53yAPvWwqzZ++QkOeQL5O/nmzotg4hTy
0GE5OmxlHcW3HYnXJb5bmOexVszLVjuPic/EX+KxZhcc04p1Y9aniOky8vcI
+TuGfwP5tg929R3t/tmFfzJmg1HsaoYtd9nftgv7LxEf/J+Kns2QU2WKWTve
n+R9AVw/oyt7WB866xwyEIwtzXZ+ew0+fzfYHss6coDrnLyb2KY4HibEEO+A
7R1wyJRhZvc3A+PUhRnEaDd71rKn50yz5pHousvrjbjF8NvpzY7JKjz3Pu18
+Dr6HtnpNh5kPbUdjKDbnXFmV7Kd0/7LbdS1P3RCP3x1jp83EPdS7J6KfhX4
dl6e54HeC3/folMkukUis1KK50vUebg5Ad+/Qp3BBzuRs4j9e5HTgp8LqTtv
45MH0O99dBuAbueDzm/xfJTcyG4P3o6CQ/SJRJ/70WcSHHiIbweByc6c9ywx
SgEPleCOhN9i6wR8+Dpx60ZtetrrqPL0Cj6eF/i2K/ldDj2bkFMTwd5R4j6M
vdn4+eyX5NA95ESM6yc93+Ssiwf8eTTnP/W514eIqWZPw4Mt4cNRxLpgtufO
m/BzTX5XAwzU5X1X/HXkCXRFh9HFzr1XiXvUBse8eKL9BY/vUwu8rigWDWPB
XsB5ATbWL/badIPfJ8S5/mPg45MzOAsMzMYflcHM1dpgBB+/NcdtqYstndc4
l6ov6LnTOaQPa9ss723U45yDe/+Gz/uAo9XE71ZH8p51/VDntMnkWWp47nDE
eVx5JO68sN1zTb3Jg0FmQ3zciVpzB3srsL8tvmqOr3rA4W1D/1NxpP+s9y9/
TSwCPpWLP3H2u/DYCOL/An6phn9mkgf/Ik5xxGt0GX4IfZH6own94GL4ezzr
X/h2N/pXxa/FRx1LX/Bt1TfpEd702qOcVG6qzn962u2SfSOK3bfTsePIJO9D
WqJPLhx07o+cCcfuLnGcC++L2T+SWO8rcdwJf8LiklCD1OM0u+IcLi5/AHsa
Y1c/dPyFHqYV+udwzsulrtsceHcY9eMOMuqQQ78uc5uq0BfN+Nz7T/Wh913w
fqaw2O2W/fKL1oTwLOwKt6PAbfUyfz8Ff+fD1ZPoRfezdjrtvUQCdbVamX9/
P+sz573//IRe4m7Qs5R12m3Pramsr4D5usS6hL3RoecU1hQbnT+SteodeuDe
6M96rbc/q+4WnHE/vU7Otoc3TyC/Heuz4XkMXNEXHz6LzB3p3kupp+oBtuOI
RVVyaju19LfYX6EBNTDBa61yavpYz0/lab1i73WUd/lg7FjIlxPk325sONQL
HqOOpV/xWraU50pgZSt4WEcORSR4LFbhpx7nPXaKYRrPHXjuwnPeFcdUf+r8
B+hv1IJM9L8QsCc+e/ia174u5PQrIdaKeW6R91TqkYV1Yf7yT/BikPPeJc9n
5fVMfLDutvtP/UsvepEkOKEm53ZGnzww35u1gG9a823+JceuMHwIjDVa47V1
H3E8FrCtXlvzgPr21tixOdS7zR973ip/v0BGAske3Yf9P3t/pvq+nfefg9ca
1NYHwWNUmB1Uew8Xuy3x2HSM86LBfxoyOz4DpxPf63BcbuiL5mHHwaDzncnO
6eL2CvRyO8PMotlCWBfmz5BrrUJtHUQefwaWRoPnF8FSRor3IepHPinysxoi
8/oe51JxamN0bUlN+R1rmwXOveJgcbS4unqe13LV9J34pFvwrXzcP3CLOGZF
yH1xQGrgTHFnjxCX7qxZk302fBidb2z1fFHe3ErxOr53kc8hysEL1L5q+OQ0
MntybkbwbelB5MP1SY8ib7jPKuKTm9SBFtj4Lnu+pMeZyZ6R7FnKnsvDvC73
ow+cEd4ns3a/4vJ7sT6/0nFemb2ZRR5T9W5trnjcyxP/77Z5vd/3jeeb8u4U
OpZb77V1HfbGhx7sIXrXuqGfjFjnvYt6mOvUpfgtzkWqpbUynPNboedbIccj
+fbiDq8pmj80V6uP3QN+dsc4t165AY42ec+j3qfJeM+FdHLzQJh3bi5wvaV/
c+zIynI8q4+rEnp19RoDR3guqN9U7yJfnefbjak+y2imaR1qlvTVzKM83YKf
SrOcK5bFO+4Vo8/iva6LZ0YW+/ygfiNK8516D3h7HLqnxnjc1cc1j/Ue+6Pj
Zm8M8HpxKtn7Odm4O9p/pz0tYn1eEs/cICYTMrwe5XHOrZP8nt74NmunMMtr
pm8Q673Ek9SBjjO9p1VvuzjMxePX+SyqvrEb52Yu8j2aD9RjqdeKwcfDQ3yv
Y3f34P8o5H3V32P3Z3rDj3J8Rt5AzjYE59+h28qxPgdqBtEs0m66z4NnmNdm
LvQcVx/3xn6/K+iT6liXP9PRbfFyn2s039we5/1qDLrcH3qqsYBl3kHvwSqs
9P5eff445JQf6T1GpSzvM/Sse5cVcxzz4vjfpzjGNDNFoNskdMvlzInZzkua
28ZmuC1rC91O2au6tPWC9zmNkPF68EnXmW6z9lfDB2MGuswmvD+yweuO6o/m
H9WCnFyfjeWTCPanw8NNNWeh80FqRxa1Y79qx1qfNZqzXkTXYWDsEmvP/c6B
4sLvs/3+4iZrv4C3sejVZaTzQ+sinxmEvYsp3t+oz1EvOSrEaCDfZZx028XN
74Sarlm8/CGPi/i+Gn7/8Q3qDmuTE17X76W+5yb6++q8H1XmfcJmOODEfK+b
Efw+iv64/f9Sc/f5rCiu3oPPN34c6g55WifN5yDNx+pf1cf+ss65Uvrvp99f
H2wRj1YN+xNi/H5E9yQVtvg8oB5DvYY4WL2TMNp4gdfuzuhzb5xzsri57yif
NxvjhwaZ/lwjze+kNLt1Y3b7dpZzmu4e/v9rt1E90akUx+pCbDm+yOvbkFif
XSVHsnMGOidoFilBznHwcJe1Jnh6GDyvYe9zWZ4X5dn/0Uaz/0PnKsRnE797
hD112PvuHe8zY1nnhj0pGx1nwtsD052LlbPK3RR0Ok++74A3VhY6PoXrNGQ2
R+YG1mlhVhKv19/qmFS+bgx7aiMnMsF7ravoPJUYx9IPJLMWEo+G1JeDn3g/
JN8uK/Y7Kd051B/i87n0+fUA97v2dCAX2oXevjX1ufgnn50P8O0xcLWiA7rH
+52F5DRAztux7rdSdOiJDQXY0l22vOO46rbPZUnmMws8fvJ/G+w4Gu5/dI8o
f8ufujPSHZlqh+7JZuU7JtNTnFvFsYnI73HQfShfpoceYxF7/5zq3CUOE0aF
1Xrg8PASer/m4HGJ343qjqsiMv4923lMfJZPjdnL+566J4t2fhBPqEcUP9xT
5jOA+s/iWX4Xo1rwCD44G+a1M6yV2FeOvr18mddy8Vsp/pv0ns+kuzgz4nu/
i9ad9H2bvJ/UvNhqsOed6qRmDM0ag5BzKfCV5kvdKwnb32L3utCHrGE9Gnpp
7f2uxGOn+49+4f5ENUdzo2Yr3Y39iflqZg84l7nwnjCrbpDMUR4H3eENDfda
umPeF+7YxdPHD3jN0p3u8ALvI+NZh4RZQDPBX7Y4PkuO+N2f6qnq6uXgK/ls
0Q+uwz9/8LxPbet9ap8Qx97EcWu+3wnobiA/xp+35XsvpT7hHLj6hRzZxLeT
E33ml591f7Ys3IlpntA9jnjpVfi5fah9uhPVnbjOmoa+ucOc54/B97eWO2/M
3uRzjuadWpxbMcRU/VpEmB+b4vu3g59Vt7M+hEta4Gty8LOB3uuq5+083zGp
u43EcH+SwDpmn+NQeBzN82vkTi45NDdwhfCuv3OIM8+SL3dP+P3P/Dyv8eLR
ZPUVX3v91V2IOEvcNXGh86Awc5rYNc30+Kby+9347WP8tpf1o3DWZfLguUR/
v4f3tULOioN/2ONyxK+a5TTT1WG22xZioT735laP4/hE77FU+1QDxb/y513O
KQ/ebnNWZX7fC6yUUSt7s9YgL84ovuDr0YXOA+olmwauE6ZUgxWjL49636Na
r5ovWZK5BfmF6DAfHQpYl8f5vJOzyv/peSnvznHGj5zVCr0Ohv0vJPqdsnps
9dq6N1Ffof6iXpjXWhx2n8q3FfFhk8P+XvPcqxO9Nul+UbmknKr4gd+lahZ+
aYPPHqp/+jtV2XKvX7pf1N9/qj/u9fLVMLvpLicx9JbNmVnnjnLO1N8Koib6
nYDuBlYEGzXb6W8V+jtFZ/BwY7XfN44HU13n+VxznpzOyfazsllv4M/LcHv/
k/63CnFjFzhyU5jj0lj/hMyWyHxjBTwQMKZeT3OCerB+SX5nIfk6p+oWt+dX
rF2Dnvob2qS/sgecvEWO7J/itupvKUnhPlP3ms8hv80L4OK235NKf/0dSb2g
6mm96X6fJ5yIi/8D+i8XdA==
        "]], PolygonBox[CompressedData["
1:eJwtmXd0VlUWxQ84ghAQh4BRQXqRpiKgUlyCSo0kghQHdBBEenWkSBNCh9AC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        "]], 
       PolygonBox[CompressedData["
1:eJwtlntUj3ccx9+sbQcxK+YoO2Ou01xSZi7nKFMuTamMLWObSxShjWamlFlG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        "]]}]}, 
    {Hue[0.18149418409799578`, 1, 0.7487003604796981], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mXt8z/UXx0/0q18ll9BVEpHuhS5++XWR26gRkty6qClRuvAQYRa2XMYY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        "]], PolygonBox[CompressedData["
1:eJw1mXt8z/Uex9+mk0Jzi5BcKjOiKEWU3Od+yy10w1JTklOSW3PbZuYydtxl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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnlcz3ccx1+uh202mrmPMCOxOZJrzBFGqJCrejAyOTZXj410SY5CCnMf
I5k9qAiPLmM5chYi9zEWUeYxGsMU9vw+Pt8/no/35/f7fr6fz/t+f5v4Tx86
rbyklVAJmi6TTtaUcn+UhidII+B2pHQLAgqkM20lzz1S7UTpSnNpaax0P1gq
hJvsGdBf8mffiGxpJORM5B3ou0ua10ZyQzblbFfuiI+RnsRLT6FeplQXGkB2
C+nRNAiSiiGjWIoZJB1ApnNfGszYLnX/QgpE5myVGteS/GZJPvz2hZA0KRg8
FkrNO0gf/Sb9s1MqgcgzkndX6ehkqWu09CXkc/ZJJ+nOCundPCm2vfRnuvQB
+laBPUmSA7a/5ZzoRdJiyMBp6RZrpTBnyX0GPsA3Rey7gXQJlNpDyireh4ro
99/n0jF86jsBXeEOtvyFH8tNgmMEAFJvSav7SmNDpPdmSpWhjP+y+O8tsnqA
9DGMKzD+Ho+sytkl+LQn8bvJ+besuIWYd97wznrO3QDuz6Uuw6SByAr56ARz
M6Q87C08K7X7Dr2hFs+rsa828skFYmRjrXNvSFv6SAnEpi6+qQMTiL9nXWkY
9sTj961wF5sz6mNShHSYHMiCl/h/OnnwHNkQX7YiNo2QO9jza4TRx9LrBPH4
iZi3JjaBnD0TOnBPGO92RL7YIP0LqbvRA3+fC8V/h/AfPJtqbByA7nsfcOcA
YoD0IGaecOyg0TWAM7NZH4crcdJluGXHr08YMThlzk7hjpnEJxCWX8OvblIc
MnGKlATePN/YGBs52+E1sYFx+GEsNCjEZ+74CfkgBR/DyHNS56+oEWR53i0H
Sej3Aj13IwcvMutk1jthFySTR0kwe6/k1U4KQh5/JLX1YC8+qsL5H0KEndtz
kVfJzWtQezrxhFPkxGvy70SC0dvSv4gYPaPeJuXib+5NJR6V8UdksjQfPkHf
6uB6mH2dyGdkNPkSBRMPSAddpd4L+J+YjGjC+1H0A94vtHxahE8hhfoIpT6u
su4/w6z3rjW1Y9VQa3yehZ+nkludiF1nyP3W+M3y3yny5jSsviOtggphZv8a
1qNyyLMG0mh09WHtC9U4rypM4LxPe5A3nDeSfDzvQo9AvqbvlILXeul9R/Id
/Z3vSy2hB74+hO/dHphatGqyPrVfDyZTT1vJm5x10tosbMUfa5B70CcFpoTT
D4mN9z7OXk4c4Sw6vvwae5CzeR4Eo7kvANuGcF9N/F4LfHhnFHjyTr0a1BHr
vMfoDAWl5IUffkU+ocd6N5RqEBNHemUj2G/3i33IDPybCcM5exjUyDX7h7JO
wUej8dtepC892A82Yd9GcHpI7Q+kVyITqcNdkEWsXTpLR5BD4A32eiPdYQCM
t/3rj3Qmj1qCn3U2jCQOh8lDxykmj6x8asnZLtyxgjwru0gM4B284Iy3F02e
W/m+367Zoew7bveBbGsGsGcZpNn9NhXZhjnRdpq529LhNu/kksOu5J8XennC
CuprA3YPZp1+nPfhnB2XTOzMZ35chAtwojq9g/NcDppzOiBv8PsmLKWul0As
fO+LLkgHepcT+zwXmnljzZ175NsdbLqErpuI02ZoFm1mWGaxsduyv+8O9mJH
Rfp7b9Z9oHm80WEM+enEugXMYR0ET9GlVUfpb+Sh2dQebPgFu6jpftuwgZx3
Y5ivpE/ls74EocyFEBhEraZQqwORbuRWFHk6nlzM3MRctWCeZEJt7HHGnprI
ZvS4z6D0B34zW5qy7jdfCief0vB1GnMnHeJsf+RT+22wr22x6eVWT69m+6cq
0pFvhkT6dzi96TCz9wg8ogcXQ0v7eyKGnnmVOVTSTbqO3Ir98fD4KDlALroy
M0vZWwbjyX1/iMCeBOz+hnURZyVxRzOej6JOfaAbvk/A95fQ63fqIQtC6V8h
UMQdr7irPTNvPe+vA09m6EJs9MHWd/Sht3A33XwTFKSbuy0dmiaau94kmu8f
6zvoGs+XsO+6JfeZ+ZeNH86Tb3ngQc8ZBPev4PNevIcsO8+d3bkL6UEcPWE3
uZAMB5mxyXWobfpk4RGe038G46OHrItgSJr5JvMi1ku5JwZy7Pl8BrkuD7sg
mNiGdsEv5L4X8R4Myje1VzLVzE1rfkYzY6JgDM8LmAubifML9oX0RCf6SjR5
uBjc+L8XLIswfXUUeryyZ7sffkikNpPgtD1zKs0y30DWt9Ap8nMb8dqPTk+Z
sSXwM/uK2bcF2YJZ5Qzh5GcYBBATd3J3ErLFfLOeyHoe/o2Eh/j6AYwJNv65
x3oPd0Rwx1zuaE5PdYI/7G+tiO2mJqzaiCAn5oJvgKmdsGLjG8tH9/h+nYzP
xgSY/m71+Vjq5zL3L0fOWGDWcQfMXLfm+xt8XQapzIvzDvQHfHuB3M+DPvSm
7nwnzEHn/wGsJiK1
        "]]}]}, 
    {Hue[0.16932520186677502`, 1, 0.7655497204921576], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmXucz3X2x49LS7uu28olWipySxZJqSyxpEJTbpVS1iWMSzFZwyQGkxm3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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXl8j2cWxS/aqbbW2k2trSX2XQ1lBGOpJdYmaKm9rcSuHaktNILEkmqV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        "]], PolygonBox[CompressedData["
1:eJwtlnlQV1UYhl+wxqZMMTXA3KggMMMFstSyBA0yBYWMzURFRUWw3HLDXIGI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        "]]}]}, 
    {Hue[0.15715621963555404`, 1, 0.7823990805046175], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmXt8z3X7x6+cSuUQcuvI5BCpPErq7idyTOwmcSNJKadiQ2x2k4qZTUOz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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXtcl1USxidXbWsjTTfXSi28sQqpq2blppb3Ei0XI3TtoqZShpoXtNRK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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnlwjlcUh39MYpsRlGTsRNQapLWrxFJKCbFVE0WbIqGVhJBFokp2Yosl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        "]]}]}, 
    {Hue[0.14498723740433317`, 1, 0.7992484405170771], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmnlgz/Ufx18q6ZcucpUK6ZdKRYl0uVWM5IhcFXPXRiL7CTlmcwzDsg0/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        "]], PolygonBox[CompressedData["
1:eJw1mXl8T2f2x48O2qFDhZbWvgxtUYoqqhqKIpZWp7bQToVaQxlLqhgkEksQ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        "]], 
       PolygonBox[CompressedData["
1:eJwtlnd0j1cYx78t4dQ4RlNVq4LGqBB7xIhNlSopYhx7HCO22tUskRAriD1C
jFA7SIMaIQklRiVNkNYpCdoaCYKk+rnnvn98znOT3/ve9xnf57nXbfik3n4f
SloPLvDheSmik3TwjhQD+yDxknQJLoNvSykZu+qktBJ8AiT/ytIo1mPTpT4d
paGzpJbRkhfEnJKWN5X2Yl/5S68haJEUCG7/SAk9perYzTOkTfByu3SultQm
QvJeKJ3tLH2bab9v/PDIlupCY7jYne+wz+GJ0iG4s1OqUY/nb0inEqV4+OaC
FFlRimP9e740eZA0bCx+jJLywId4/26Oz6xf834ezGbvp+w9ir1zr+MTHJws
HYDSJ6Q9jaRS2K2rpFB8deH3QlAYgtkvCDIfSCO+IvYg3iWuA/DBQfbyJMfY
bP7OgmZLecZdComSMvAhHa7ipx9+pmAfTCE/daRUClSNnFSHjJ95Ds6n8Ewb
6d8JUttY8tNQao/NWYLfcGy6dBQqbiMP+Hl9pXSDfa6DG/u4lJGusd5OvNtg
D5T+Wlps6kMOjw2WpheQM5gCz9nzGdxeb31Kw3o9xh/eaYPNmyO9AY/l1AhO
xPNtah/Ofkn4mgiROWitD2Bv4fdNqM93E8h3A2wWfz+E4zy7tIE04DD1CpR+
bUxe46TTK6Qz0Mipf0NsK3TSGto/krriSztsKt9Mgzlp5Kg9NcWuHydtgLXU
eA1EQg65L7FM6kCO2kN3ePElWidvyx5aHyYuwLIOh1C0HYzG96H1aNiVbvc0
e0feJ09dWWNbXJVqtZaaY7dtIMcbrN/G/wDiuEI8Q4jritNTtdHkPmq/f5Tt
EdMrgXE27mBs/QC79zr2joDV8GyCzeW6HKsHo4vivF8MXInjDnFEniOHf1KL
LtIgbAAaDoTK9FwlKInGMgaSh1Abi4lp/iv6uy86MLGSyyAIh6nk9pMQ/Lss
fdpKeovtiI46QRL9lwjTCqxuZmA3z5R6exD/DmkCfT0RllKTCmgiNt5qxGjl
Jj7cgDSnP1OxLuStMIznnb1F0dd4aRzaasFsSsggP2fxAxLI0wVoTj520Fsn
f5Le873lfPe/HbbHTK8tdfxfgi1NDGWgCT3XGBbzvyn8FvbI9rDp5THOLBuN
nefkY+4rq1ej2xU8uxxi3pLTAeSD/aLJw044SC3jetF7z6gL8XZh77Y86wWt
4D7PvKAfN9OrG2FTrNWq0Ww3fu/B892xJfGjBKwOxle07pkldWYed4JofDmJ
TzuxZ5058Au2GHsXh9EbmV9QGO36ouGwQ9SZ/k+HwZHovzZ1RQeL6a8QGH2F
b1LTvej43Xxi550A3ollj+NQwtFJ8XybM5O7LjHSQOLo6YdPrDvHWP0aHbd5
ZOP2xnbg96Sy1OG49BiewFA0fRJtD8N6Up8GsIJZOZKZ+ccDO0PNLC0fZc+D
thF2hppZWoycfATl0FtKaWofbfNq8tvBmQEZ5HL4b9I9b76BdZ2EdmE3sewC
rwRpYQvpx9FSWb5XBorw/bQqaIEZdxHtJ0AhtHYOHbhg16CzLGZ/HLN/M7Nj
C+x2ZuaubHummbNtFfV8wixeg51Jbr+HTPJ+D8KTqYcXswVbj3o2pq4RwbbO
pt5N/5L6dSO/2E3r+A74oOkwtO2LPc55cAKS0Xsw8yAJ685sqAnl0eBMfIl0
tGk0GsvMyiOnPsF2/po5bLRvemDtI/v8OmwIfpdiHe2cBeZMeEz/BNJHd+nj
adRhepQ9H805OYsaD2Z2vmHdJBcffIgl184AMwvC0c4ANOSywOrQ6HE2PT8L
PseXo77k+A3n3DzmAhxz/DyKddsvVYWS9H7iZ5w3c+18N3O+V6a9E/TOtPk3
dYinHtnUZa2/nYtmPm6EqeTHk7x4oJ264ItOhnA/mEhds/DhQFXuLOQ8iTok
g2uInQOhzswzs8+de0s35lUt7At0nONn82DyMYj51IoZPxi7gHzNB3/IpaaB
2bYPTT/uZ7aOaUaNzjC/FtmzztO5x5j7jNte9MHda/dazlXWNWAqs/oiM7ss
89uP9SRIJdZq+H8b60L+i8BW1uJ/UVh3dFEThpO3YVCVXo6oyT2EdQFz7DQ6
zk+3dyVzZzoy3Z4R5TgrEtFmEhx5ZmdXLPYad6YUeMHvz8GVmrijw4+xW4lj
C1ymnm7k5wq2KM94o4mbI5k7rF222TuWuWs9f0rM7JuLDeFO9l0FeoAzMZR1
GCTjy3N86eqcw+Y8rsJ36vC9ytj8cGIA7zzi6s8Zn2fnvpn/5q5j7jxFuYNW
YKYUwVYi9jP0mc9l67uJ4eIte6+6xgxLhCRIPUA+oS/+pzVBz+jiDedKHvTl
bK7G2dwf+zLU3lWrOeemOT8jbzMj23EG37Z3Q3NHjJ2KlsH/kJ2hgYfs2W/u
AAM575Px7wdmnus+8ggv+a4H+cuNtzU2tU4hf7S/JrDu52i2b7S9e5k7WD6x
vIN8vneXOV7A+oszVmO1sVfR6DU/O+/M3Jth7pZ16b0oW09T1xHObAzD1/f4
0wNf/fA1n3UB/A8zrlx+
        "]]}]}, 
    {Hue[0.1328182551731123, 1, 0.8160978005295368], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgmcz9X6x091qW6blAgtiuLKdkuUbEUpS1EXUbcQMfZQkm52Y4lmKEYY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        "]], 
       PolygonBox[CompressedData["
1:eJw1mnucz2Xax69tN9VTbVIiaUtIQlIpbc6HKJRTSNumQs4dpCbWJsTMKBoU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        "]], PolygonBox[CompressedData["
1:eJwtlntMllUcx79iCE7bzEvUms1LZYaVoIhX1DLwSryId8PbdII3UEgU301F
BRtKKhMql4CJlooFiCGoKSpmlGLLhJwkKpgrb5hoKvY5O88fn/0e3uc553x/
10PnmYvCF3pI+hg8of9NqXq05E6R+uyRAiFypfQRLK6Rfg6W4rH+pyU/qL8t
dQ+TrmNz46QlQ6WEC1IcxEPL2ZI3LL1g3y3D1uVIr7STri5kPc83oGandBnu
V0uHhknHEqTjpdKrfaQK7I5k6Stou1q6OUFq9lCKuSLFwtAiaQgMLrL71rLv
DUdX6FzpD86/BLNWWv1xNVa78aFmv3S4k/RonTSWcyJgGzqa3paOLJV2foZf
0GOz5Atr+G5/gNRYwpnFnAkxFZJroJQfjWYCWfaeNOei9PAn9oUFaDwZIs2/
YmNhYpL7BXtDIXHeiI+7DktT2GcyrGHtRfZYiw1MJw9wl306cMZtbHCl9AFk
1UvRo6RyND3Fj4ae0hNsqyypNQzmfRCMhqF8l8N3VTekLuT3ItYDHc3h8kFp
Qy/WrpK2bpcyoBvx93sH/cSiOJWcQH/ie8pfWkEc/dHUK936Z/yci9YTaC7D
/0y+y4A9+BKF5pPEJSKX+EI9Glaj5TSaEk2dUBPLsX3IWSAMYs+B8NIOaW8P
yQdbYOLqIqd3bbxN3Duj/wj79KYmNuwjhnCO9WdhSh06R0qT6mwNmlp0O2ft
pkZbsr+rjXRrPnV2jr3hPusaYBL5ryK/E7BltVLScPTXWn+MX97Uqhckl+F7
XykFG70A/wYTI3LStEV6BnE8VxCrUNYs5nlJpdVotBZX2u9LKm2eTL4mzKNe
B+H7L+T4mPThy/y2kbzzfA8+5cw08OGsxiDWsHYUvMg+Y5x6MHXhcZbegFZr
pTsjiNN1KQ//ylnzLTYyX5oGX1NvadTdgRRbh6YeW7AuDw2ezh5mL9Nfps8W
OzXchv7b7tTdl9gXTtCTJ6zPxvejaBiPpnnozKF2siELyujL12OlqU5uOlIH
qejZABnHOZdYZmJ9ssk9TKV26t8k9+m2J0xvNB2SOpGbp9hcft9loJfr6elc
7D03OYQYYrwIsunbhu74sM/6bHxP4/xrnB/E+feo6YQ36IXPmV9oq4NhzLv3
oYA6udWevuG5/TdSOzjmzKOjpVa30T/3b7SG4i827DyxwXfXeTvLzEwrpzcC
OpLzPGqe5x/Bj/c9oZx9otqinVidpo7LYQkxXIbfj3k3iFk8EAZAPPXwZDn5
xpcOEMb8CSUWW8jzNeJwFWYQo5H023RsJH3dtRl1zT4PoBGiG4jFWM7Eztgm
zYT8M9bPSmZbAc+F8IC989g7aZ2deWb2/cqszO4v/Ybte1LqB8OJdQhUUQef
UA/V2NfQ0RXOE9POb6GLmE5nzTSIhlXskdrEbNvEnIPZ1PRE+nxiPPVu4HlW
jn1nvmlBP3hRk0H0x3J+T4R/IJPv7uTYWWFmxoE7aIcCaIM/u/ntVBQ1C5vw
afIAegjbjTMCWPuUGnNRH+GQjZ9D0B/szEszN5OZO7V8l4ItnMP+sJcY+pD/
POwK+tpdZNebfVzk9QhnhGG96IF/6bcOC2zPmt5N/4scMne3Ys+S+3NwibiG
k+u0M1an0duF3Poyxy8k2jlj5k3Md9QzPHPqfxg5/4HcJRHfNfz+mBw8gWre
V4G308dHidl46m4cRMCf9GBUGjXi3Acj6u29bu73qfTCFPAiLr/7MrvjbH2Y
OmlGfNymHqiLYM7uwnPzEqvJaPNhxoTQR7Gs9+Z9y7W2D00/epTY75/DPsbf
/yCEnip+l382Eu1dY+6cZGIwjvitP2PjauKbhR+exNGDOf09Og6Cm/Ncftw5
bntfmHujFZqr0Pw8NpO/MyCAuyac+6t3rr3jzF3XyP8Wpfxv8QibF2fXtM62
fhv/N6N7DFrHlNgeM712kLgVQT/n7gsssrVvemC3M3u2E7//AbpXf0M=
        "]]}]}, 
    {Hue[0.12064927294189143`, 1, 0.8329471605419965], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgmYj+X6xx+ScqrTJnXSzgkHlaKyJR2USGUpJVlCzCCyNClFYpBtxlC2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        "]], PolygonBox[CompressedData["
1:eJwtmnmAj9X+x08SdVstpUKlZLmWKOu1tpCQyhIpkWudMRhbLrpZsuQiM2bc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        "]], 
       PolygonBox[CompressedData["
1:eJwtlXtMl1UYx7+LbJVmm1iZ9kctRVwplwS5a65Ubm65SSRSRBO5XxSsVCqh
BAyvQOpyYXKJCXJzA2thGhIaLdGgEHSoLS5hYXgZXqg+Z4c/PnsOv/flOc/5
Pt/nvM9Fp6xIfkBSNEyAgj6pL0iqaZfyWG+Do4ekJmfparJUx7oedu2UdsJI
vjToKG1n7f2n5AU+cNRF8qiUjpfzv5B6XqpdKK0jlt6WjoVJcRulEz3SSXD/
mpzTpdFM6SXW8+GdVmm2j9SxRxo6KF0Dj3SewVgp+8+V7hMd4snpK81ok7Kr
pI8hiX0SYeqg5BsiORI/z5A+e1EaoP4FhdQKVzjTZeg7ZJ8NEgOp9415aPKe
VLxbOghu3dTyiuRK/C6RumE/+7r7SXN/Ihf1ekMruv0Aa3ul00vI85HkzHNX
3ptNnAmzoHS/VAKTLknNr0r3NkkhDVIwpJ+TnNDKO4m9NkjxnPMM5/yb2oYh
vgTtDHVSkBt/E/22cs5npaoWaSs9y4Hab+kjzECHbeQrJt8jaPgwhKPzTVca
XitFUG/NNPrAeUc43w1I4Ld4cGimlkXS8l8kz6voD77gv4w+E/3W8Td0UF86
dXYS2yGN9dlS+8y8sxxNI9H0NeLEGM4NRegVMV8Ky5a2cJ4smMD5fOhDLvuu
X0NOyLhChPVQ/IxU9qMU1Sldoq5t5F6JnmGwGL8dw3cvExvwSCN8xbvHQ6WK
IZvD5DIaGi1bqS+OOpvQOL9LurhY2tFl/WV8drkGP6BRd790C31vw8Rd0qPQ
jW7OaH+B6HSYnoIr+9aw/wi+jqDvbfQ/sdf6wfjiLr1w8aTXxCw8lw2BA8xZ
MLqxx1LWywas34zv3qYf4Wi2pNx62ng7Fx6kppwqOw9mLjqZj9+nSnup+fFY
aTLc+ZJzoOMo8dMj1D6H2vDbhM3SQ3AXvy0hT9oR60Pjx1nj/hzNwwNodm3I
ami0nIQuW9DnsS47r2Zuh09Sh5f0Pesd/1JfFDoS156WYuEutd2BCnxXhP88
8KHOSv/9LO0ewWMrpELi8QS7LmDd/Y3UAxncK8ucpPd/lcpNHyGa/wvwl2IS
rP/NHDieYv68pSnEZO6gFIhp4jk6xxKv04t/YB/Pw3lv7ynrfzMH9/HYPUjo
tb1K6rUeNF6sRYdEZraeuIn52ggu+NUVv45lsRczWs28hTKvKaxTz9k7wdwN
IWPkiMTzxCrqroQAvNGIN/yJkw+gIxxmBmfjod/wUBFeuDmFntFrT1gAXuRe
AD4N9v51476Ka7e5Q8kdBMFjtp+mr5n4atRD+oB4i3wzuZdfZ70KImAhd0MA
nDhg71o/1u+yTxoe20Cch99cYDsa5UNXv/XmDXy/mnm7yLy9SayjjvpCO3Nm
9vLW2WeRPFvDneiAbme4ixurmcdqm9PkLuFeyeYOLSP249k+mM7vz7N/d5k0
7Q/mMpDefGI9YrwSwfNVEEB9K3lvEXFoyPrzryE7i2Ymo6jnLdhMH17Aa5nE
nvEZrcy0ehvdzffMfNeq2+19mcv6QpmtoYeYgu9SxzHrp8ZrepLYyZ3RAc3o
8iG6tBCfGP++tOXY75z53rnj8wJqKE+y/jdzcB09hiGe+WlhjuK6rIZGy9Vo
uBTNKuLtN8R8S+aMfzP28dsX5Mkj39Pn7X1u7vX/AZTAFZs=
        "]]}]}, 
    {Hue[0.10848029071067056`, 1, 0.8497965205544561], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1m3mcz/X2x99F+hW6t03qalepUGQNuTdLtqtISWQt2zAhyySVay0XxYwt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        "]], 
       PolygonBox[CompressedData["
1:eJwtmnmcj+Uaxh+l+hxL52jRpFJSUqRGtqQzZd9SSaHIUibLGLuZk1YyJEsY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        "]], 
       PolygonBox[CompressedData["
1:eJw1lW1M1WUYxq8Y1jzTtpLW1pxv2av5ki/1QRAUsTBDIadri1akhsDBLEEi
0RPTWiqSL9kw2RAMBWLh2qyW38TSc+BIajg4kjV14TI3iE2zRv3u3acP1+7/
+T//536u+7ru5z4T89blFCdIWgFGgPE/SuPAqpCUu1IquyUl90vhF6S5Foul
CKg+J+0C+8GJVOkT4sZbvuddYullfoNm0L9IaiL+VSHdAc+3S2kPScsapUye
F4MxldKZ56RNv7IflIMScm4ASTGpcyEoY+8JqWuOdO0DqbdeioHc9dLRNPZe
kD7qkrZ3+XtbL6aWR+C3nvjLh9LSJeC6c7ca2r+RToJgUPrnJemuIfbxvge0
9Umj4V4L5y3k3AwO7OWMx6UQzx09cEmXosRDHVI9mLNPmg2+4uzNT0nbStAs
IiUm833E1+ybKFw7QdFpKYBm96JZdpS1FCmvUHrmW+lZ8AZar1wu5cNryXnp
RRA4JI0E/5ZLx6fjT4vUDd+fQB+4Qr2XiBOoKZHnsdT+8HFpMsgh9wTOmMpZ
A3AcBGHWz4CU/31Gp5+/JBd4j/dPkiOdXCXH8APsPcvZ5BgudD/N15lwnTkb
/sTWDdKNJPLBKxWktbgn5k05NR/Bq1fwLAX/l0/jGV93wqOq3n03/0MgTD8k
0RcHyFcDCrrRaz4g/oAebegSIV/yTXKBEO+3gJKd0u+c38yeB+idKL3zYMx7
yXoqHd4B+AfQ4Isa+Na4DqbHE7wbx1o239zDt3eDWC+5yNFS5t/anh2taDmD
uojVw9LW1/DotHtq3gbY9z66jYrnsFzmp/n6Orn/zpamD0p74lruJjbRF81g
2qCvzyBmwWcpaN9Nn4IU6uiHSyrxSpk/z4u599YDTXjx6NM8t0mTGvC9wX03
/9dxBzvo52Lin3XS2SnUXefamsZ2tnHI2CZN5I7pO/iXcuYC7vlFqYH+Pgx2
UO92sCted9Wwe2ce5sJpBZ7Ox1sN+Z1KGPL+sj5bSy0LqDefuAluFeAgnEfB
q7XP753dvxEn6V0Qxc8WPO8k1sH7Kt/VX/Y+tH7cCN9SoCL6Mof7gGZvxevM
C/kss5k2eg1ngI+r8eMxtMh3XU3fN68yHzLpr63wJ1cn97uCPRn0/KKga2ha
nkPTyWh7FL4Z3JEL3JXF3Jnu36SL4BR7XsbzoqDPFJstppfpdgTkMwMaicfQ
tQ2EbqBHllRJ/Iz9a8lXSxxYjS+glp5InMdMKvIardbeeC/29Ho/WF/Y2cYh
Ey7nybEQbre/RtdZ9BHxbe7DO+DT+KyOBP184xHAs5GgkD5Op58LiGkF7KH/
9g/4mn1jfIzXGGZ1Avq9in4390h/gPsq/aw7nNUYltbMlT4P+5p9Y/8D9n/w
ffzOnhpy383/a/RX1VRmyGFyx+f8/TGftTZzbababN1H/yXTh4FS//+x/6Gs
6z7PlxH/A0cF5Ro=
        "]]}]}, 
    {Hue[0.09631130847944969, 1, 0.8666458805669158], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFXHd8iFfbPvRt1aYlRilKy6soghC1R4wUtQmxU0lsWapDlaQ1S1CqKrLQ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        "]], 
       PolygonBox[CompressedData["
1:eJwtm3e8T/Ufxz/ya5lJdopUZGdmlL1vCJUQKntm3Xup1E9cuYnMrDLudSMN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        "]], PolygonBox[CompressedData["
1:eJwtlGtMzWEcx7/avHDZTOYdL5hShxKzuWsuKxWFbCkzTrlU56xMtSSzzIjG
XONkbK2OTK2LV71DWhipYzidNIklaqYaG7lsPs+eXnz3e/b/Pb/b9/n+/nPS
c7fnBElaCSaCNrd0d61U4pM8V6QK4L8kvQFHb0sfI6TiQunGM2nPKvzGeqS9
IKpb2rRBSsPv4LwABPZLXcDxVMqlSEKmtKNdSgY7QcxqKQW76KoUCT5VSeUL
pX7s6a+SK1G6WSZdo5/r4M5zqQYsL5VaE6jxRfrXIf0FkzulxjXSJGxxPbWi
6BnrKpDcIIaYN8RsJqboJT4Des2nZ2e3ndHMOh9/C/eWldpapmZHlrR+m5Q+
Kj26TG1QDjdXwaVWacIK6SK2+phUBeoapErq12Pn1khxkdI87H24eAA+XJD6
QNB56c8MqZfzimrmAo/7qRknPem3vBp+b+VLvgXSj0q4IH8puePI7SLODTwD
0lA8HA3YHCZXGu/VznulYmdRZzZwkjOX3BnYLdxJBMP4v4GQI1LYRmnJW8u1
4fzUd94hmXrYl257Ps35IbO0AJfpLVzKxsbkSLGggLhqNJTvs3lN/hFyj5E7
tUeawltNBUMV0iD4zTsURePHnvATv06qZd5atFX3zN41MSnE/iLHMLmCf/It
RfLCRd47aoE8ejgMvvI2O8P4xjk+x55/NxMLxpqtFowmGr3SLvi557VaNZpN
RQ+x6CGC8yB5vgD3+IxnD0mL8c/E/z5gNWe0d5JcZ2aif/TbiG6bqiwPho/e
gL3fF7BcG87j26Qy9FJ2gB7P0TcoGZ/7OHYfcYFg6QXnTuDzWx4MH85Rq8OM
Ufue5l0Lu+h3PRxik7Klz+zlbTQ7nfcJBunMt5Q5nV7Lj+HpIOiZxr4xXybn
LI+9a2JCx/Ufgt1Nj9Fb2akR6RW+1zV2b8z+JOH3cy+WPXGwB+EG1G2ivgPb
W2D7OtJl993svdkbsz8NzJLJvc4suw9mLyLR8Vgo2uUf8R+IJzwP
        "]]}]}, 
    {Hue[0.08414232624822882, 1, 0.8834952405793756], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnHmcT2X7x496KjstSMiSVJY2JJE9RCj7ln03tsyYafN7kJElZalUss2M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        "]], 
       PolygonBox[CompressedData["
1:eJwtm3e8j+X/x6/qS0ZWcZQRQsqoZJO9CS1k732QOodTyq/sFdlkn0EqpchW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        "]], 
       PolygonBox[CompressedData["
1:eJwtkUkoxGEYxn9NORGOcjLlIpqLbZAlMwhpStaTonGzJkscUFwYJluTEibJ
CTdLKeFAc9DcxnIUBzUcieT5+ubw63n7/9/1+ZzdA839DiBTJIm7Fzioh1vp
7jSEhTMKWaLtDWobYX8e2hXXKe58s/9MztMkXNTA1zOsXMNqAhOvC0cJrEnT
92E7A75V8yN+xecKfIixkObmQGAQUoYhWXyFYStP+dLgAjT5oDIOpaJMzOv7
nFjyQ5pm3GhG4yE0CNcJFOWDewY2Z+Fd8eUpnO3BuegYA68Hsh9g8V5z721P
09srfJrlkfZq514X+KVu7VQi0hSnikAfjFdqz6jtaXqHI/BaplsiNtfUjD5C
l1e50o2EHxN+u7u5wcw2OwTFXzksS1sTnrdIh6ZgWCzKmx15NBKynhnvinVf
oW7LPbF3m/t7YnBVDd0x66Px09SbPhVx62NV3L6xeeujc/lTAMfSf1I8jQw=

        "]]}]}, 
    {Hue[0.07197334401700795, 1, 0.9003446005918352], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnXmczlX7x79lLYRKlH2Lin5FeLKMvSxRyJ5d1hmpMNP2ZBtbiwiRSs0Y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        "]], PolygonBox[CompressedData["
1:eJwtnAe8T/X/xz9lj8pIyCxEGRUuCdcuI2RmZG/uReZtI5uIKKuMey/ZiRBK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        "]], PolygonBox[CompressedData["
1:eJw1kM0rw3Ecx18pCUflIgdPo2W1FGWkhMJRnhIX1HLZfg2/be02TrRa4+Cg
ZFFzYLOrclXT5KTMSdzmT/D0/vbl8Or97fd7f96fh7bV8EyoBmgWtcJ/Cw8D
0CddvoIV8Z6BNxE4hxsfDErjRxAT6y7069vaGVTlyTRByoFt/XOFcwhhMReF
knyzqvU8w8QY9Eg/Q/AlnEf5xKbIjkBE6qlA+7h80qrqPsSiuFfOfNTmmvzX
IHgDELyzc5p5zdxm/gtx4oecdEp9JkXySbONwq70esu+d/TOleT/w7wLYmMI
8tL9LOyJ74RylOdeQmMKGkT9MSx5dYMIdB1ApyieQmuv8qVxeadV85OwGSbL
7Gx2X/jfR1osw8uwasr2tubGdWlo6VaPtO1lenbE1Ed38VXszcztfgFzinKc

        "]]}]}, 
    {Hue[0.059804361785786964`, 1, 0.917193960604295], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnXt8z9Ufx78Uuukm93tu3ahcIrewJSK532YMFbEp16koZC6jRLpRueui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        "]], 
       PolygonBox[CompressedData["
1:eJwtnGd4VkUThg9ItUvvTYqIgHSllwgoSgsIoSuKtCA9gKKABEJAMXSwAKGo
VFF6VRFREAg9Cb1XaQFCEsp3P9/Dj3NlTt6zu7PTdnZmdou+/3HLPumDIDie
MQgy8HfB6CC4XDkI1r0SBNXmBcG/V4Jg3/NBkFY7CHYBp9wJgmfeDYKzLYPg
5q0gqJ4YBGVDgqBEniB4aUgQnNkXBBfqBMF1/nee92ILgmBh2SCYnysI9scG
QdvoINj7YhAU6Mx4D4OgzxT+/1IQdCkTBC8ODIKqg4LgYasgeMDz6HYQ5KF9
9oJBMJv2GSOC4NMZ9FU6CBoyRtvwIDjSNwiWZA+CNrmD4NmZQVApKghmvR0E
M3l2XqLdoSCIqhEEZbIGwffANxm/J329nS0Ivqb9hE1B0P25IOhWIgi+BP55
bxC8Q9+fgv8X4F8yIQhepv/vqgdBKeDj9LmIvuOZb8H94AfOE3IEwRP5eOi/
w+EgyFs/CH7PCX7A7f4Ogs9o+zlPB+C50OxeoSC41DYI0qdAu5FBMKNNECQ3
h643oUdaEFRszzeVoP3aIFgLP1a9GQQjavG+Owj2pAbBiTeC4FanILj2IAj+
e2D4ATwJkunjLvi+6D4+pq/vIhm/cBAUbxQEd84FQTboXTVLEPxKn4fPBsHq
0YZ/4TnE+3re1wOv4znGeyHNv2YQ/JiJ+QJ3ZLx5HYOgP/MrOjYIEvmmAvxZ
zfdHgG9Ogu7P8g08+gReZYSfRfl2W+sg2IDstEsKgk6hpvm83kHwJ/SIA98P
wfdb8P0MfOs3BXfe5/P+w7IgqJnFOJ2g/9b0/yLy8nu1IGg+PgiS7sO3DkFQ
GiFuyG/fpLmv3g2CoB/y0gl854NvVXh6GN4WhOavvQWfkfcCwOcZ7wb0+Qsa
HuPbg3zTjW+PNwyCcSOCoCX8WQJ/csDTUPg5DflqAO43+f4q3z+MNG3ieD/J
+zXmcwzdaPQMvJF+dA+C1JJBMLAYOIxDHnn+AK4Mf2uD6xZ4OgjeLkEmNwFX
PA++9L8KHCsB/wbNdkC7mswnL/Svhr7NRxcLI39VEz2mxh6ETD0Cl+TljPsq
+oA8dlnI2Pzv6SJBsJL+XqW/dldpWzwIWkHjDsBTkLF4cGlCn+3gR37kpzyy
1A4eRvI+sa952accPKe/yXx/mO/PFwiCAaOQu0j3/UNYEGyEnrt2W1bnwLOv
ewXBP/w+md970X/+OHSLOVRHVw8zpx3MrSr8ewi/HvHUhZ8t4GER+JsOnjbj
vdKaIKjBePkZry68qEmbENquQaY2I1v5+H5bbo+RjfmlMf9bzP93+jjfB3sE
vSvRdwp97AH3nHOC4H1sTQb423I4co/+/of+htJH9rnIHTLbHnotwuaFC36s
v8PhWYXNQfAk481CXh7Cr6zApdeYl8Pg+UnmGwpNm0DbaujEBxuCoMfkIBgM
LgOxJxPh10h09CPkKdvT6AfydXprENxFPqang4YfInPrwRP7G18KnGPgH/O5
yXw6wc/Ww42zcH+ePgrQV27oUQB6fAg9cgCXZIxi9LXrNewVcDZsyn1sS16M
e7seQXD7D3jCb3vg1zn4VQf56Y5+HILfX8HvUGxaDLpRti4yAtwPGn+Q0zbq
J8Ybhs63b4fdwz4Xwj6fgMb5sI/buiLzj6D1BeQM2UyF35WBX0YH14HfC+hP
C/RnADi9gn7No8/+wGvhSWH0Pz30moo8ZQGnG21to2SrRve2LC5l/HWMHzrS
8GKetbxvZ03a+w72Hf79BfwpMnbqOc9/OPBu5G8GsjGdJxfy0XMwPIN353h6
zIeezH8C81/NHD4YQxvmU4a5hzG/Xsyv/WX0HHu/Ky+27hPWxzTbpjPgHAuc
eg8YfI+if3eBP2I+O5GHf3jCmE8iNrfzW26fQPum2LPi8OIkMhX5DzYR+e+O
rA+EZwvh/4ad9MVv2bAp64G/usjage69VhR6Qfvs6NcRfl+TmW+Az7Ge1cbW
vMp6+hTraUbGu/CmbUoU8pgvwbZjEPPpBj9rYt9b8vvH4DwTfDtj74rAj0+a
gB/zH897Fd4n856B8cbR/7j2ttlhSbZhsmXxyMALadYB6YK+WcN7+6u2LZJ5
yf44dGBBfmSfNtHAD4chq6xfZZhDz+1B0Pio32OxMV9pLYf/7RlrGfxcDHz9
ehCUQ34zwu9vPzWNRevT4H8PeAny9WVuz6ki68MycGyJfVsIPgfApy787dPR
NvsbZKktNLgIvBj5DAP+izV7YT10Bnn8A7hWon2ZRfxeGziYiNwhGzOZYzrg
bchMd/yZy/zvQj9wgJ77waUv+vom+hrG/Fsy//Aq8AnZOwD9D0H/v8FxH3Ai
/B4Av5+CHstZS4rzfSG+f4k5daWvJ5jzZfpLwWfp0BMbRp9nGHs8/M4LP48h
X5mwDw/5vQu/52T+S/l9MX08oq/m0KQ07bMwh2bAixjv3Q62ad2h9+wb4Im+
zETevgc+g09WENs6k/nPRNfj1tt2V5ANo7920dbNQshXRuTrjWj/9ipPVX5/
Ex9pAOtFf60ZrB3zkY8noH162XPon4nx9wHv57lI2wPRxrUSMhaFrE1Hxrdh
bxKQhxnAr+DfVGJ+/4DvE8hfdfq4j6zVRIc6Q8/XeP+tmP9XA3gVNOsN7YrT
Z5mrXsO1lt/ERldD/58Av87g1onnbfA7io28jD2aBQ3GQrsK2O/7zxrnevTX
Cx591sDfHOPbzrxvhndNeAbx/Wps2tAm9klGw4/ke5bFU/B/K+9HsBc16bs5
Mp8B+z50BXAF66R0syTzj8J2tGW8KYz3OjiORNYeMmYK/e/8277mIWzQe/2h
60bsD7K0CH/nNdbDYswxH3OtyRyXMNeB6FQR5L0eMj0AuDT2MYCfN6BJEeZW
Mdq0eZHnZdqekA/bwOvdCMb7Ahv0XAHbpE6sDxeZczJzT+GZzO/ZWB+jWB+P
YL8C9KM++vUG+jmB9eMk/GjF/Msz/+bISAvg0f/Ytq1gvgfRx1P4723hJUtD
cBL412Sv5QvQ51XA1/agm8y/F/ydQX+/Yn/T8M2Pg18H9DMv+BQCl57IZ17W
jzUXbKsks/WY6yLmNIK5Nce+dcFeX4Om66HtBp445v4F+tQN+v2OPGyj/0+g
9w+17UMNAR5Mmw9puxN7ORC4H+MNZrwhPKNYK1ozpwrMrz/03IO9XUqbpej/
U/gH57An7bHpM6HNufL4M8jXI+iTCn02vsBawP7iOvJ5Blqc5kkP/ysg3zmQ
3Zw8FYFbgmNN8C8CPv9AizeQ1+p5rFPt6a8UOrG0htfkp9H3dviUs5Gfdsxv
GnOtQPsw4CHs1xaiy++gM08gCxeRj4vIRzfsxQ7WoknI50hsydVzprX2S/sZ
ryHffIp9jGL8xsxtOzxOhR4/YhP/AZ6a5rHuNgOH67ZRslXaY/3LXmhlsnm5
BvoOhh6dkaHT8H8TbW7QNpxnaAvohXz0Bt7DE8tvTyDPsfKFkZF50CaWZxZ9
V0Pm/oT2Icy/MvO/x/cz4PcAZPxQtH0M+Ro/g39X5GMyv7ehv0b0X4rfH8V4
r6g1P/d566B0MT8yuH0VcrEUvcKfekj/6cB9f5rXCsmQZGkBa3a2gt5z/g3t
hsZZVuRTbGV+H2JDS1e3jqcH/6no0/cNvAedAjyVPrJhTwbT3zTgrP+i89iz
FvSXBfilaOu+cBbuKx77n21YL0dD79civFfayrMeWRyN/t9HfvOz/g9BntZj
n+/S3zesl1Gslw3pryJjFYWecfinX/f1/rgP/mYU69ceaBoHbbsj3yuQ3w20
T6b9q/ir32GvHpxiz9gYG8AzmLmXgSbF8S8n4m8m42v+C44Ni5tncWnWael2
NWTqdfRvIet3DOv3bvytVHzLrsewnbzHQ48y2LJ3pSPPeE9/j/kM/8e2PiP2
JhRZqQSPb0O/Z/imInBB6DEZeuyFx43h9RB8um+g9VzG38X4z/6HrDHfPfLB
mPsM+pwNrbLSx654+gX/9G28hmotrQGO2bAVndCH9cj6KnRuHLo3DxuzEni1
fM7KXlOPw+/vHli2xtDn98D1j9BXiPXjDWThETjeR3aOM8dWzLXjb6wTJaAV
8tUB+BY4bga3p9G3n/EXGsGz8i/Y572EbRgCvp/R9wieudiXkshofuh7Av05
hn26t8d7Me3Zk4FLykbVtk8h3+JijH1X+bAXgE9h8+chHyuwOWnQ+iW+j+D7
PvyvP7/FhDvWMQmbcgt6/QB9LmC/0kGTMtDmN2T2L2i3iTnnifOarrVdMiXZ
+hcZyfMUdhWbkwlfbws4dqXvX5nvFfzF7sjXZ9B6L/SLRra6Rts3fht5nAct
toPjMnBdgD/7NfYrA+PnyGceZQLuDo4f0N9a5hsB/vWxb1F53KYe8EjoFaX9
DTiuhF7XeE+Ftp+C77dan9Lsi14Hn7fh5/f4iF+i38cZ/9oWx0QUGwmFJxP5
tgfyc5O53YfmHwJfRoergO/T4H8IWRsBPs8U8Z5Ze+c20C+kjnVKsaez2Ocr
IZaJBsjGCfZX67BvndDv48CR2IcayHc7/KsI/Pnc0PRbbHMRbMIQ5rc73rIq
GytbWwt6bcOfeQ/53IC8dcFfysB+MD/69B7wL8zpnWyW2V+B15/zXkIxjA3A
UeA3nblkwz40wPaXwN51w95FQc+OjFeb8UdLfmjfh/bdZth2fMCaMncHdozf
v6htH0S+yPIky5J8aPnScejQXehdHXrUGGMfTL5YDZ6NjH+D90Hwbzz0bgG9
T2IfNrzpmNDmUdY56Z7mWIO5Zv4avqPfH8PjLMD5wbEufR1nvcnN+v4ffRyr
5vmnjXdMTLGxezzPAn87m/1iGe9htZdNxf50yOmYXRpwfnS4xHPWmVLMpzjP
AOALyMtRfPePkZ8BWtvZjz4HL6ql2RfcAH4zkYXmyGtvvp0Ojs2Aq4J/M9bH
DcjjSOY6CZxmlbCMNb5GH9jnjcz/E8b/Cl78zfdfMN8qyPsa5j+F+Q1i/N+Q
gZB50I4x59f3nqIG8HL2g7Gvej8Rg73oS5sJjN+fPn6nr6HsgRNZG6Kw13fR
xUX0N535RdJnA+b2N2va+IqmycUBbqO2W/BPPqavJ+DRWfjRAxoNxL+fhM7c
a20fT77er6wJPVkbZjG/X4AfYvOLoptFeF5Bd2YpXpPTOH2j+N/fjmXeRb7v
It/1oV8GdKs+v/el76bg9BW4bWa+9ZnvlVFe++RDvYsvlR17NwV+H+D7/NiT
cdC0MfRbif/0+mL4CD0PVrHOzAHfJ3leYvxUZHof+rL9nmONjaDvX8B7kamN
7e3zyfdTzEWxl+fR5w+B26GjqejqAvbQV9HdD+DRKuzxW/BrGfuPj5Dxj5H3
mdB0KbStvBr/A3pOYryh6NJa8M9ewDwVb189Tf+NbTO3QI/GjJm5vWWmEfDP
yOgE7MGXPCuARzO/RsynPP7ym+jS28zvAO8JjFkHXD5c61jBPmTwEPL3D2NE
MlZuxlzP2GtSHcuejA1YDdyBNo3BvRHPQvDPBb0/gN4Z0O+C/D4HG/l5a68x
WmsOwpNy2L+yPPlYu15A5gby2xhkMDtwOPhcquI+1XeB/Y5ti2btj9hGylbe
wGZ+9J/3HNp7yEcqylrxJXPsxlw/4vkKuAbrwTW+TaNNIXSlKjx4jf5/RH6L
Qd9p0PQQ9O3NfGtgb8PRyXnM9WXkLxzcT8GP8OJeQ5Nkr6FfNdpPqIrebGI/
vNa8nYvO/IutP8f7c1q/a4IH60tmnnH4yhHMsT/zf4/5naL9Z6x5B+m/ULJj
aTkk48BVmM876Pd6ZGw4Y7WDR3XhVX2eWbwfpf9KrA8vMd+V8OMj6NOYvdnb
zGcJ+vhOnGVdMdsVzO/MR45tyJ+7jHwn8M1m2g8B/0jwHw5OX7S2jCwDn/TQ
PIz5dsfmvYztW6o1p4pjjMuBu/1n2hfg9534d/vRgRu5rBNPoRuvwtM18PIc
8ncxwjECxQqkU42gffIEbFNJx0QVG1XMULHDluhgi+H2UeSr6Jt7fHuZOTYr
aJs+jPaFk02rf6BfC/rvsd3zU8xGsZuizL9Pbcf8x/f2HlN7Te1JtDcpyO+9
+b0tv49hLzyF/tMVdMxvzVrniJQr0hqTE3r9sNey3RD638X/aYEPW5PfE9HZ
5oqfDjZvtUfTXk0+lHypcdBrPvRazR7zyXK2L92RrUrI+FD5ctCoCvAWZO5f
ZO8Tft8MnAF6Ds7pHE5efM/0EbaF08FnjfxJcDoD3Bj6v8l8WoFDPa396Mg7
2quhI+d5L8t6fgJeFkf+fsxoHRwKfpWRrybI15dPI8fQJwf713ef85qbE/h0
gvfiouEZ4Otp3rtexb4+2w2bG2FcbzTCR8NXv4l+XA51PmMDuOS84ti0YtS5
gF8b5W+v82zk+1c321brd8Wy22AjbuLP1cBetJVvwVMROC8yuAf6FVoDT/l9
PX0WBt4W41i7coLL8O9qY783Ijv9WK/7Qru85912P/TfS/t39zt2PCYLe2fg
iV9hT0p6z6K9y+m19rWGsac7PMY+vnz9Cuhkpjn48+O8FitHWBVa/I0MVEIW
i9P/duD64LuYtmfxR/Li76RLcS7tEvL4MfbgATSfBr1yKh+m/fgdw9Ix6drZ
3t67b4Pek6HlDHRoOvP7F57Xx//IetNz74JOPwn8Hzy50MAxiavAD+lvzEse
Yw28uQiNlzP2VHh+Afg8a+j0Wt5zae/VBXkuqnwiOCcy38zglB98vqP9Ivr7
Bf2KlS+MPcjNeL9D07PgUgScMoDbRnia5xnL7CbgMujTUGTvKu1fBp6EfJ1A
vvogb++hC8mM/6PGVzwa+BBr5BroM4v3A8Dp6P+93I7pZEfeGys+xvjRrHcD
sM0d0d821ZwjGom8v0T/L9F/DWQ2H/z9JsV7i1Pw4wTvb230XuAXnsvM7xf2
RO+jDwPh5wLsy9dp9r0Vs1Lsaik0j6V9O75fAtz9vHm7A5nqAXwY/h94xzH0
7shK+w3WhczITIcNXiO1Virmv+2KY4iKJVbmGQf8zU78xxqOKd7FV8yGzKyu
5RjqC8Bb8IdqM9aLigfxPmyGY8+yZ4pNa4+nvV4O5vAUtEkGxxvoW1PsTyvk
5yA24Rnk4UfoPQdZSIIGx6DV19CsHfZ7JTJ+E1yLsT5MwhYXgl61GK8I43Xi
29rsuea2Mc/F+1fA95canrPm/vQWr50pyH849M/O92P4NpJnCt+HIP/HsKUl
0dk3gAugAy+18xreB1505ZsWfLuMPXzpE94TaW8kHW8KvPaCZVE5qmHKxUPz
DuBXGxrHAZcE359Zn0uCb1fwvc8cpyIvU3hWIe8lkYfismfIU13a77ni2oAF
/L4buBD28gpwBeRlGro26rz3DicZIxL4DfovrVwha35IinPyys1rjlPBffYd
01Y+RWHGOxjt2I9ygsnI0ujz7ks+hHyJUcm2HcqpfZFsmZfsK4ZxFVmsA/3y
Kt7I/ypiz5Yts+8gn0G+g3xc+bqx4PtguHM02l91ZIwEZOVLaNDpLe+3VvM+
IdK/PWT/MWEr8raQcVlvUsG3LPvVtgtcz6CagXcV+4QG/fi+P89t2pdCRrMg
q5nx6WZchA6ST8ZbgvydYD3dneZYh2Iuir3si3DuIBx70om91SDs+7ONHbNR
7EY5UuVKFVNUbHEvY7RhrCzI6E5kNZ42K990jFyx8r3YmEXguphnH/CL4Y/x
4SkObm9A0xUVHXPuhzw15n0l768zxycXeg6aSwB+YcztNeShNfIQho1qzXvv
jbbNY9GXXsAP9jp3FTDfr5nvHzudu1BNg2obtOfV3lc+dk3VQiz0WGWxcdOB
14Lj1BbO4SqX+wr+d1Z4Vx4fYiO0uJnmWGMv8EnFvlSjv5YdnRNrBj4Hbzo2
rRjcIeB60Cvo4Jyzcs8ZWEOfQNfToHEatP4P+buP/P2D/p6An3kSbQvCoHcK
442ORe7wB9phn7thnx/xvw70vwz/qC329dh8xzr0v+PzXUOhWgrtiTcw38MP
7Hv9ypwTgC+j7xNe9Rp+Cfj4UctCYdafVXPBh/WiK/B1ZKQ469vEi6alcoIL
sU9H0OfxTRxj6gS9Vo2yrQyQz7a/2QeQL5CCjFcbZZ9Z8l/yZeY3C/xo/2UT
1ws0Q/63xDk31pQ1cjNwXWTqNvYvHvrUAc53w7FB5eCVi89Mmwb5HAObhb7V
Gum9i2zcCnTrLPq7tqljdordnUTeDtexzyTfaTD29bNQ5+S2w68IePB2budc
DtP/cnTo7zxus3UfvMdm/Aj9M2KfaqCLJcY69qYxnqP/unHeGz9P/09Cnx6j
rTu9eTrCi5b8rzH9/UCbMNVPXILe0HMH/zsBXEbrM7pylvHPg8s79xzLV06t
6T2vsVpr5dN8jW/TN9q60BL7/zHwh8ynd6j36B/g/2Slv0Ja78G5Ab7hjKuO
DdelzXTgfhucK1TMTrG7LHz/fW63efKuc7TK1WpPpb3VIvTnMvpzhvWtBf1V
Xe9YoGIafaFXlfOuHVHOtTJw/APLmmpqVFvzOeMNY7zD4JOMb9fkoHNNsldp
fVjPGe8dZP0t1pg3gb9A38shy/npczRwA77fw/cN8O/qA589almRD3QOuC/8
ejoD80YG+gEXSvXedB30PgNtUtiDXHvVe7r/7+34PVdur7GvAZeB5tmxXdl4
ErFf53lOM78CvF8E/mO+YyUlkN+tiueohqyLaxCOg/+4RMe+B8LPMcB5mH92
fP9H6Hw+4NQY11bkRn+eRhayIj97ijhmcR5dyAkPutb2nlp762p880oe1zRk
Qb8W3IZv+PpfQoPsB8D58e9VeBoyXpVJtl16rzrJa4bWDtUAfMV8T2EzyoFP
Y/arHf/FbtDfXPqbw7MUOO8D43qT+XbGf/hyq9ca1SDERMG7B65VEA6fAM+9
bV97Cu+xwEG4Yz+qaVBtg2oCVBsQhbyd11qKz/lBbtNMtIsdaF/+Ku1v0r4e
Y2bBX/oImxOFrfv6OvJT1jmuicC/oP/rmiNL4FhUuQ/62NfFPmtleDcMmi2s
7Rybcm3P4lPvpv9T4NCUb/NOcqxXOZJB6PsX0Kx7iGOCg6Yge8h8F2T/W3Su
C3P5gD5DoUVLntqM1xcfo/XT/l8/4F3gm/cp+6jyVbvfdX/1lH8DLguP/s5u
Gi8XrcBpCbhV0p4N3n3x2N7pf5HA7zHmvBcsg/eR17FxrgWQjZKtGsbvz2dz
DeEV5bORyRvZ7BPKN2zANw1DnSNVrjTzbtOzLL8/4vc6j+3TGJ56cc7ZKner
NiF8/5BvXmngNuJFjSmuZVIMV7Hcyd2hY3rsLDzIDC82ofN/tXZM4BvWqzDo
nQf5SqKPe9DrO2i+B/7k4P0Wstgcmh9t6ZqHbfheTXk/wntT7FcW1p8rtxzr
1/+uAg8b4VhY5dfZZ2PPL91xbjgNHtSk7ZVJjnUoJqDYQH/W2HdYr7tpP9TD
NXKqlbutPTXy2xd+tw9xPWhWeJub9vfRx9b870P4kREa3GfsBzyZgN9hjHjF
jljD8p1EDnq7tk454+u3XGOpWkvNuR1wI2g0vKNzmsptLtvp3PEp5luA3yvQ
Z7lQ+zi5V2PXDvu3ueAwP8Y6IF34lP7mDnTOWe1P800h4OW7sEvobmHoeQVe
nVnFegU+IeBzA1/u+h7DRdCf1azf6ec6HqM2P9O24GH39ZA9R/V+rJvMJxp8
qsseYV8KYLO/xVYcREf2R5oGosU6zY/x7kGzBw0cr3+Nuf58wrEV2ZQVwNWw
L7Vz+pt00PrrRNeeac+ovePKCPvy2sOm3fEcNJdK6Pj7rG3lz9s2KgeSxvix
t1zbpppV1a6GIVO9GjhH1zbBNVKqlVIO71Ps7yDeP2jlnPqkPq4ZUe3IAWSq
fbRrHFTrIB9qHPT+GfxaYa+iwHEF8Hhkempz51iVa/2c/gqiv/3obyRw25ms
06Udsx6Bflxc4NoCtZlA2yTo9R/0zMOak2Osa5RVq6w9zGrGXpbosRKg337o
MeK2+/6d+TZBt/vwe1iI6zv2xbpmSrVTivl1B34Wm9I+l2X0OeAD9L8ZeCL6
8Dq8vIGNLN/cNUuqXRow1v6vcgQx+G6T8FeztHMNiGpBTjHGeHgzCJoPh/+d
wacp491phv9O34mzvNblYL7vMN+eG70XvcYc7zDX20mGNWfNXTkV5VZ60V8f
+qsc79jXYHA8QPum4baNiiEplvR6vGthlZOoDtwBeu4q6xyAcgHzaPN2Vsc0
3gefTxca1xjkexqydpw+DoY6xqFYR136PxrqGLdi3QNHOLYgmog28gHkC+ib
s8BFYV7xrthdZLYP/fXHBrxfzjWsd/EVwpCf5M6uqVVtbceF/r0+9qhkN/q7
69jfUdan+59YJ6Qbo3iqy3bvday/Cc8S4FLdXCusGizVYq2KtT8hf3g18LFZ
huUja6/YD3y6Qc+RrEld7zpmoNjB9+CzBXzO8b7jNcdozgK3xGcq19Y1MaHA
h5hzMeb+AzzfjX9TGBmJbekcg3ING+ljFu9FymCrZ3uPob3GEHiQiH8T/lge
ZTP7DrHMSnbf4L0575fhWcEG9pHkK/0Jv1bWsj53oX2+3sZVMbQKG7yn0d5m
JTLZOMo1vartVX5TtQPf0z6mlmsEVCsQvtCytAl+15kHfeDZgVDXDKp2MG0z
PsqLXjNTN9unlm+9n2+OJjnnptzbINX/Y1+evuHYkGpwnwE+BM4LsIe/K+YV
4ZiCYgvC4SRrZ+Vw9/UP+JdDnpo/tC+hGGYz4OuMcSnUNYuqXezEN3Vf8P9u
8NvUSMfKtCfU3vCZhba12tNqb3uB8aLxjeLYD2ZEHl5kf/kK9C/HMx9enEQm
7r1gHZWu9ol2bEZ7Xu19/z7kWhmtqVpbXxzi2mzlNMolugZNtWhh4PMu+HzX
23Bbnla8f8t7G+ByldCFNcgU/c2p55oG1Tbk2W3dlw04Ost7Pu39tEd+irmM
Yb7FKrvmJxJ4Bfyr+aRjNIrV/N8nzeM1ZjzjZbph36GmaiqBt2JvFrdyDHwd
a2US+l+OvksjXyUZ6/U0227V3H3H/jsWfD96zjWabZNsk4TfMOTjJ+gz6rG/
pDMhpWn/RqJ9Z/nIVbVfpX2U+AU/KyGPGbY4tq4aA9UaRG1wrWgvdHQs8BO0
TxfiPfpD5GPpXuvyZ7yPHmKbJtummnTVph96XL8fz562Mbb3CvxPLewaQNUC
xgwxLwcwxzX0/Qh8Nj9vGyNb8360a/0Us1fsPjXCsQH5B+n5vkacbUt6xn/A
b6/1dmxfOSTlklRDqlpSyfSfwDV621dSDlm55Gnyubs45jwde/fhfscbtWfU
3nHzIcd+JQO/Af9E+16hrgFXLfiFCOd6tEctjz06B41eL+Gav7PA/zLfpFyu
6VZt9/Qhrv2orJwB/bdIsqxdgybNgY+kWhaepc9E4I4pzn0N4/dv6esCOtC0
sfeE3U87R6pcqXysRvQfy3wOMZ96ohHwS/RZItT5jMJxzoEqF1qW9sVp/32M
8/VtsU+LsA3zBxvWfmMc8vPHINuaj6DvCOhddZ7PIqmGUrWUhSf5rI5kcK7q
RZDXP8q6BnIUvNs6yPm4/PB3O78dZo/QoZxrPK6MM8/Eu//LFP3PA4dWZZ0f
jkefPl0K73P5f8OXOqan2F5FZLwJujib/r95xTlq5ar3gv/Qsq7ZV+1+3GDb
bu2xtdces8m5vyTs7XdR9oHlC2/lmxDwywQOWULMY/Faa6rW1sXI2y/Qqj/f
5M/E/8FhPbQ8DY0mv+IaO9Xarbvp3xQjU6zsRKzbT0feRyAflWi/irEa8r98
sa5hUC2D9nQV+K3MAseulDPYoHg17/PLevyBPe2TyzdXjDcHupWD378t6z7V
9xPr7MurTYZ1rpFWrbS+ybnAZ770u9Yw+VYf01+7EL9rbauCvFTSXgl8L8Gb
MfjErRhrJf7Wj+zd0ie7Vi8ja0brY8gK68Wq+s55roDWB3iGl3WOV7le7em0
t6uoPSD9z7zoWGsN6P/EPmQQn/69Mo7R6uzZd+DX7xWfwSgI7g0WmDfteR/0
oWMiio2oTfY56Mpt5/pG0N/gS86JKjcqmbhLX6Vpv6Ssz7O9wPeLdzpWMwz+
zIY/je65VlEx2MbA2SL8/Xlk5BPWzxknfPZIa87xWOeslbtWDfl+/O33F9g2
as5dgRcN8lmKJ5lvVuZ7Ef3Nw9w6sAZ3HAP++BTNwWV7DebR0zkJ5SaK8jRD
tnNDj7ZlnBPZzP5wBzbnzayuOd0JXHee9VH69By0/f6m56Kazu+AP0HGB1dx
zli54x0xzqX/gf3YCfw5OJ4H11C+v9zDZ/RUe6r/jeC3AQudq32K/gcCz7uA
jCCLc8B/j/JJfJOlnGusYsB/PzreG13/AflcRP870cn274Mf62VO5SqwQWty
+X9P4VsuRL/v5bJOx0LLgv/Co5o+01YI+HC8z85s4/f4eNfoqlZXNTM3RiOf
d12Leh0cqyOrv4JP1nLGSbgdHu3cgmKSx+DnTzdda6P93SLg7uj0lmcs0xlo
v2aB56qaMtWWSSelm83gQcps26z8j/0t2cIu0Cxzi8c6L/vI7zn4vS/vA/h9
CfPN8p5jmi2GmEdqLxtYD95VuGvdUkx1cIR9bPna1/CXcx22jHZ5rA/h6EPW
IZYlxSgUq2h612cJZKOaAa9ERtNX854tO9+P/Qc6FjCOeZnvfmRwYYjP/2TH
Xiyivx9C/L8D/PYy7+VCHHNR7CVHhM++rYd+v8fb55DvoZrbiDjXfKn26zLy
UIj1/LNY52aVQ80EPpcG2HdWDZRqoU4McbxYMYWqRxgf+/FUAZ+BWgz8HPzI
rlgKa1xb1Xok2lbIZ5HvkvVx/kE+1rSFPsOgswyqcVowzjX/2hvKhn1M28GM
1yXE9Z2fMd9ad5wvV8yxNvDFHo6FrGW/kZn1shw0v1HPNa2qbf19kM8WSiYl
mxuxF8Ny+pvyfNv+lmt1/1/zDZx0ED8yHbTm99vAy7EXlxr6DMgy4MyKAbay
DyRfSGcedPZBMbUM4Prip84lfIPMXuW3oudduxmPvh6KdE2cauNUo7WD9/f7
OzbXQ/4W8x06xLBibKN43xTnWoj+vH/J+3c8w0Ncj6eztGPgX+cWznEq13m1
t78dwPOVYhNTvB9Vf4oFVsGGbIZfY8GhH/p6MsK5B53JuoT96wyN3qzpmibV
NqnmSLVHyok9PIXc3nQuXmOOBf4cfCPA7wDy0PuufRL5JjoDEU/7no/rj8LB
b90O/Kxz9n0OQ8+yEfaZ5DtpjdJa1eKifcv6rEcZ2R9Pv+i9vdaXCOQzsp9r
n+VT/3nbZ5x11lk1L22wXct7O9f4Of5TY/mD4DdV9JTPCr0+nO9aGvlQpZNc
g6haRH2zCfr8Ck6vh/oMts5iz7/t2K982Hm3HVNWbFk06gT87x3XzsqH2Al8
oIfnKh//FrZk0yCfzXuepzny1uywYZ1B0VkU+djytcXT7xm/P3PIUNw1SqpV
ysGYpZj7s+CQEzgd883W2WeyCvPt04d9tk0x4GeAz1zw2TKd2dTZzR6K/4R4
j1BLe3/w2aX9FDjORF5a/Om9/glkPJr9WhnWgD4tvKZpbXsq2WfDJkGjAqxl
rRXDBpdnkZfC+NbF/nTsMitr5hJsxwzoV72Vc3zK9W275do0nUHWWeRWtK/L
78/QvhDt/5zt85TK0W5T7Sn2IK6qa0ALpTmGJ1svH0K+RFH4W7y2cxz38Nez
3XOuWzHR7MB/xXgvLBuh2pq3mHOtENc4NYMWt8Ndmy4c377tmmzVZnfg9378
viHG671szlDe46H3Euz/EXgwNso0E+1UAzFrp30eyWYu+it42zE+xQYUM7gU
7xiB3lUjsU21Y1u9F1dMOxr47DX43sz1rqqtfvCJYy3KSZ5Fn85cc72yvjkH
PLS3cVXMRLGTLPDniTau+Vbtd4HePuuiMxg6i9H5vvuujX38Grhdqs/a6AxN
+1TfKaDzeIPpcxLzjWUPnI+9cEPe2yQ6B6NcjGKOij0mH7XtuUf7B+jPiCFu
qxiQYkFRUaaVau7fvuwYimIp6nMefdePc2xeNd6q9VbNpGondSb6kGKvw1yr
qpoR1Y7Ip5Fv05JnMPamCO0H5bEOR/d2Dly58Duqz09yTle5Xa1BWotkA2UL
c7H+XuE96yDHjnVmR2d32n3is0U6Y5qC/KQmuS/lZFNUv4RNnAcvF/AsAr/M
g9x/Zmg6YQk+EzjVz2mdmaT9ATJ/tbVzQMoFjQy37h5mfcsK/SeGW1Zk01Tb
LBqKlqqZvQttB9zx2SjlXHZrvzDStbla02fD36zYw6VNXHM9mflk4f1eEf/v
SeAbtx1bV83SZOxfGPocW8o2pV+0fTr5dvng0dvY0x/RqczFsEPo3JRNPjOp
s5NRvH/D+6xNhlUDr1r4yZv8reIRI7VX24K9K+U98tvjodPj/d5CxRjh79v4
ABXDXKOrWt3ova4lUgxJsaRGk8wbnXnW2edJm9y3cPoJXBYtM6waux+Bd93x
Xrgn/Nh9x3ck6K4EzXEBc0tY6LHlj85DFwcstS+nmsD+wL/Co/KsZRmx178A
d+3pWucAe76F97aJlv1GyNiP2l/HeK+mOzaKYs8nJbiWR2eSJid4D6fftSfU
3nDeKO/FFeNSrGsfcx7A/F+FxxWTXLOj2h3VgD27xTEnxZ505nXdYNcMKD6q
mvVd2IOB0KgJtqIW/BoEHK8zdoof8HwNbSfwRIQ5hqBYwrF456JUk6nazOnJ
rm1SzGoa8Di+P1zYbb5McU5duXWd2ej+H/Y9wbRVDFWx1Lq9fXZoPv+byW9f
KaYJ/zfTZh74/xBr3ohHkqV7Mc59q2ZnCfz/ONVnI7SGaS0butSxCMUohgDP
gcYbajtmpdjVROXUNJYe9C3Hbp/FVk4+J/DEKNfKCYdPkJUfP/RZ2zv0f3wC
+CX47Ir6+Bq4ULTP3mvN1Nq55IRrXf/v0wHXoY936etX2j9Cvicin9Xq2GeS
7xT0cSz3F55GUb7zQndfKEfTJsExFc1H+UTlItWH+vqOpwLfj7zrWIFiYquQ
rYfh7ktjauyG8KAL/CgHPxoDvwX9+pVyzVtO9Cn2pn1J3REwF3gk/uRxfMem
zHEouDRKcVvVJKk2qXGMz0pPhD9hW3xmQGcHcuo+iQVuo7bt8JeG8N453Llg
3Tmiu0fyn3Qu8BY2Jy9wyh8+66+ccxnF8/b6LIZyLqo9UsxCsYv7yucDX2NP
uaqI95BNFC/d4fpbncFbDpyw177YI8YcFO49pfaWumMhF/ClQx5bZyIqDXKN
sfav8pmfjXcOVblU5SyVu+wR4bsJZJPrJfgOCdX6yIeoArzqus/W6szOauDJ
PEeLek3X2v5qlHkln/gSa00f5TvetU/bC/hOjH1b6bB0OXGhbcte/ndE+5de
hpVTVm75m0SvhVpTZykXO8a1mIoZXIBXC/b6bh2tYfOAz0U6VqgzY4v4vQnP
e4VtM98BngS+yaz9ATIexfzq87/PsrjGrwHwF8hfg1eckxwV6xyrYqnaw2ov
qxyXcl3K6e9QbiLGe0H5RPKNUsFvQhPXOB3FdyyCTDaoah9Nvlpt3ltXtc8n
3093nqiWSd+rNmoq9m9zKd+hortUdIZAZwmqYu+7M7eLF1zrMo3vLwH3ZA6R
OXwGXGfBM23xWTbF2M9jv36KsK3Rmqu1V3dMSP50BvIH1sdf7/lsoM60rgQ+
wxr+TGXnTJQ7GQVNy9XxnDQ35RyVe8yKDSqJLfpyiddu+Zu/4iu0TnKuYBL0
bKlYWarPDsfR5v0tjokpNnaKMdsAH39cb6Yz6ofGeM+pvafuQOoKvsnsYUtU
M012Q+sK6MDOKs7hKZdXMsK10L8hD+ewLRHhXot1BlVnUS9jQ8Z1co5LuS6d
SdXZVMlkOPL4QqJrr+SjylcdMtZrg87MDAL3PyNcK6o9umq7dKZBZxt0B43u
oikW4ViMzkzEKv9BmwfM/RHPDeYzMtGxYeU4Y6Dlu8c8d8WwFMu6cMG81Jnh
p8a6xly15qKJaDPvBja3OfRB32KBy490rdKrjF8de1Jqje/e0Jn4l4BfYQ80
oLp92MysTznuuZZOZ8x01qzwbd+FojN6k6DFlXCf1dEdWCH8tnunz6bUYD67
dL8BNKoNrVZiL5YP9h5Qe0HVQAXg+kaac8k6U9QQuH2Kayt1JqVDimvcVet+
ked95p4a67OFisGkxfpMtc5Wf8XTFvl4cqxl5UhFdAP+rYLeGavZhsuWq4ZR
tYy54U8m/IHyp+1rqOarHHBlZKJCqO9I0F0JddJ81lx3GM0Z5ztYdBeL7kjS
XUmZvzVvFDNQ7GDTTt9loZiGYhsv33VtnWhQFrh6tM/W6Iyuzuqm4IPO6eA7
UFrD65AR5pVqkvske83Q2pEZeUwe7TlqropJzQWfyTccu13DHnzSDef0lNvT
nvn1JN8pprvFdEaoCnNfN8pn9XTmSmevVMOtWm7FNG9jH2akuNZ9tM4DARc6
6bu0FCNVrLQk9E2BvgcYIwtjTdtrWqumbCrwVNok0v4z2k8Dzr3Xa5FiYoqN
5Uu1bGtN0tpUCprfyWsf8CXgUqm2Db/x+4vA6Xn+4/trPLPHWAYkCzpz3RfZ
mJliXJUDVi5411rfJXad/83h+0vRxlV3cuhuDp050tmjtqyH6ZDd1dGG5TM3
Qj5uHXSsKT/PkwPt88j3Uc77zh/ec2jvoZrvK8Cdk3zXUorq3YGraY2v5hzr
+/S/jf/9Eeo75fLx3jHcsT3FbPPT/uZl18rrjpJbwHkO+2yoagTqPcL2p7r2
XTXvqn2vP9ZnX7Xn1t57b6pz7bojLQ548Fjvf1XjPI39x9BRlvVc8rFFa2gw
vYPv1HkT+zhsoXODiqEpllZir2uj1V612zqTpLNJqulOOuc1X2u/ajB7oM8/
Mb+wIj7jsCjJNXeqvRMNXoMW5xb4bindiXF+gfdc2nvpTrMR0OLdVJ/NqSWf
FNxXJDmWrzPevwC32evYuGqg2wIPUAxW+VXk/VEf5xCUS9AdFdmh5wX25LOb
eY+uvXrlDc696s4J3T3xwmr7ppK554HDUj22ZFqy3aqn12vdwZFH9aWrfXdV
eXhUFfi3Xegz9iIPMlAxwjXxqlfUmYLxkT4jrLPCOgPRRfHESJ8t0JnfEoq/
Il9jMrmmtN5B3yGhuyR0Jlxnw8+n+K4q0fTHJNeEqjZUd0rpbqlukcblNjiW
5dsEnrL4H9tpkwj8S4Rtge4gWBHhM8U6WyyanIce42N81ks1/qr1V820aqd1
J4DuBvibPlaFuaZVta3HkY+fkI/zOtMC7zYz/zM1TYMtwPtvurZec2qA7N4f
ZV9WOcIhyFvVOK81unOuSpx9GvkqqsFOQz+3Rzp3ojtLtgKP+8346kz0xPG+
805338mGr4bXrRIc+1IOdg7+4nu3fReK9FO1KZmGO1apmplay6H9Y3l+g/HK
/e07ZXS3jO6oKz+R/8/zWWX5CPIVJuz1WTPtOT7FHj9112fLVaO8Hnq22uDc
hXymUOCqjPlvLZ8h01mydj29l12Njqy86TVPa5/OQOospGLmip3LJxoJfAeb
Nbalzzzr7PPPg91WOT/l/nIhn6nwIx/++dUx3uNpr6czehkm2UeSr6SaitAk
75G1V9adKj8At9zis+o6A6CzALojRXelqKazKfKemf5vhZlGGVN9p53uttMZ
4fvwY1uE76bSHYu6a/HfeJ+10Jlana3tNdhnWRVTVmz5UozfdWfDZeCjKZZN
5SSOpDhHolyJYqAfKBZ83bXO2gNMue4YuGLhkjHJWrZ4n93VGbj34Heex+1l
U2Vbd8DT8azNa/FxVrD+vYg+LW7pM7g6i1sswbFd1fCqllc1taqtVQ2SapEq
T3K9iOo1KgKn/eG7PRQDVSw0trv7Vs5SuU7VAKsWWDWL+dn71U6xLVJNXB3g
cQmWRe0RtFfIhwz8Xcw1EKqFUExWsVmdIVga6zs0dZemfLT9fJ9+ju/GUw3V
Yd6X8TzZ3DZGtdG6k0Z306hmrhOyf2W24x/6Zjm/XeV9ZV7/T7/lXuOzcKpp
ywV8BJ99V2l/880n+CujfLZENQNlT9sHly+u+a8AHhnruw91xnME8PVx9u3k
45+6EgR/QcNKhU3z7bd85ly1Bf+vMUAeqmzw3kN3aOgujVp8sziXbXht4NAL
1k3J4ALke1Gs402qsVEtUOQe12pIR5byfbob3u9Iv9Pf8B0BuitAd5C2P+ya
Bo0vmyXbpTtldLeM7tjRXTtnV2GXCruGVbWs5Te61kpn6nW2Ptvj/KD4rVx1
zpveqyvnqNxj5wfeK+uOzS6qrxrju3Z0RnQT/N8X7bM52mOkXaVNnM9eKkZQ
nW8fnfLdMzqzprNrskmafwhPiwuO+Sv2r3yW7uZUDYVqKXRnnu7O27vevqDO
eOms1/wxbqs+RMvpd5zrFo2nAd8Hp7NhXiPSUnxHiO4K0Rmc7/CfaiQ517uv
i2vbk5HfWw1c49YJ2j5I8V1G6uNhimusVWs9mPfoFNfsq3ZfbdS21D37Gv8/
swdceY/vmpKNrAK8d7Pv7tEZ80vjnKNXrl5nNg/y/WlofrGBz6BeTvAda7pr
TWc2dXYzz02fHdUddLqL7iH0Xlzce+ICiq0/tt86kxkxxGcMdNZAZ0ATdPfW
Q59F0R2qIcA1r/hsvmyIbEnsDt8VojsjdHfEDXC4qnpD/tcYXEucdq2c7sTR
3TiK4SuWL3/jPvb1Ovx4GOY9nPZyNcNtu/W/vLzv3OOzw7oTdAdw+ijXVmiP
H3HJd4TqrlDF4Joy9oIU3z2mGqfMk3xHmO4KE043+f33s75LSndu6e6tOwft
u+rMdijr1+fgOPVd3zGju2ZOJ/kuBt05oLsHdCeW6hNkEw4A95pv2y0b3nuw
79DSXVqqud8Ibs/Ndf274kc/4x9/dN5nWeUzFBvjMz86+6MaJdUqxYD/p2He
ExxG/y9H2ldWjVoXxh90y3cLaI+tvbbOCOus8ErdMZVgH16+vPYA2gtMSfHe
QjGXycDte/iuT+2htJcan2LZVExVsdX/VBMS5jVUa6nuqNFdNZKxK/RfLsV7
f9mwnpGPz/QWcZvcfF/tiM9Kaf9+UrWIvXy3lGqyVZs94o7vTlKN9K/Qa02M
7xbcSv8bEpxTU25Ndyg3gNeZ7/tuQOW06yf4jk7d1akafdXqKyat2LT2oJWA
i/S2r6ccxnHGWnTr8VkwfKrFwAcjncvWnStF6GvUOZ9d0p2i1fltcYJpqRyj
co2nPnLsSnck6q7Eavd9F63OWOishe5E1t3IOkO5BnlaNdi1+LqTSHcT/bLL
uSDV+Ofp5Zyjco86UxYS5Ri4YuHieUKk78DVXbi6E6GA7m/hf1sLu+Z6NN/+
Gem76vS/Ubxv2+5aDZ1h+RM480WfDbhXxLmV/Pfti0rn8wKfibcvrhi8YvGf
DvFZKN2JMBb5Pxrpu6Z0h1IJ6PNEqveSqlHJtMw5b+W+dWZEZ0fS3fFdUcoh
vQ69Sqf6bsZn2COUAV643mfBWrOm/rDeNXKqldOdlqWxReOgyfFS1rnP7rqm
S7VdiqkotqIzeTqbpzukdJfUyydYtxv6DqXR213Dr1p+1dysRH/eSvFdKopJ
Kzad/gvfvaQ7I8Owl2Epru3QmnYd3n9w17XbOkOgswT3bztXpzup04BfTvVc
hKNwbdXDd5NpT6i94Yqdzu/qDMjPwOXX+O4z1Sit2W0bKFuoGGcu1urZo00L
+ThrwWdHhGVfZ8p0tkx7eO3ldQaghHIPt3x3s86Mh97yHZK6S1Ix1kh4lXOE
z3KLJqJNhvu++0w5F+VeRkf7rkfdcaq7Tr9N9N3lyl+o1jJI8Nkj1UC9jj37
H3h3x4c=
        "]], 
       PolygonBox[{{59216, 19268, 59218, 44551, 44552}, {44552, 44551, 49132, 
        14301, 49131}}]}]}, 
    {Hue[0.047635379554566204`, 1, 0.9340433206167545], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxMnXmcj9X7/9/2fc+SfV9KKLvKnjViGPvYRiXGGoZSIUOGFlSfUiIha3sI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        "]], 
       PolygonBox[CompressedData["
1:eJwtnHWcV1UTxi/d3d3dIi3d0t2IIL10LAhISMhiERaC5AJSKqkgoIICIiW5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        "]]}]}, 
    {Hue[0., 1, 1.], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNvWd8VlX2/n2DEEhCGl2R3lEUsYAoKiJVB+kdAokohoAFIaggiBSJ6Ah2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        "]], PolygonBox[CompressedData["
1:eJwtmnmAT2Xfxm/7HjMjWbKORK9diyWyZS1lm7EUorGMIbuRDAmTid6nqaed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        "]]}]}}],
  AspectRatio->0.7568269733048165,
  Axes->True,
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Frame->True,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727819570068*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="],

Cell[BoxData["\<\"Ending FindIntensity\"\>"], "Print",
 CellChangeTimes->{3.563404695187516*^9, 3.566101212057523*^9, 
  3.614727819607738*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[267]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindIntensity[%,Plot2D->False];", "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"In[268]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "3398"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.09407717691303388`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 2., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 3398, Optica`Optica`SmoothKernelSize -> 
    0.09407717691303388}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404777812903*^9, 3.566101323509776*^9, 
  3.61472781995735*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[268]:="],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxknXlUT8//xyuliHZLpE1CIVtU0vsdkSTtCy2IkCVLUQittpSSSqLNkqUS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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxEnXm81NP/x+euM3Nn7txt5u4z995IyJZK1hZLRZKK7G0IiXallJIWZWkh
W1rspZClLGUnIlki2aJIiIiyVPyeL6/P9/H748x5z/vzPue8P+dzPudzltf7
fRr6Dux2ZXYoFBrTOBTKIX4+NxTS/3rC7+FQKI/wKoyjakKhTcQH1YZC3ctD
oQnItU+FQkMSodBDsVCoCLn5yVDoZWTmlIVCMf5fh8xq/i+A/zrxXPhh+OPg
v8n/buQzHvok8vmT/xsInxJGkOci8ixBdlRpKLQe3k7C5KpQqE9xKDSJeCfX
JpN2Lfzj0O1n4mbotikaCpVxbRLXeiF3A/Ep5J8k3cfI/E54jJvbRXxSjWPl
/wnhgWQQo+cvxO8TPiA8mLReD8K/Ft0eQ7cGyniUeDP8LCru0aJQqDLsOvqD
uILwNfTDpP1CMWlr4E1Fny38/xA9O0dCoeH8X5R0Po8gMwP6Luip0M8R3636
JDwE/zPF8PcSf0nYSDiPOpxGHp24x2UFodAP5NuYcpagWxPi6VwrJ/4J2Rh6
Lkw63ULyieeYr7qbyH0tJM0+yD5PPXYhv76NQqHdXPs82/cwGplRhDpkzim2
ns8QDoyHQlMoZx3036SrzA+F/iIej2574U+CHlwdCt1Mm5pPnR8K3ZrnejDx
A/AmESYTXi8JhY4m31XU5afoch/6DYOfXxkK3Qv9NboPIc2t8O4ln6HQt0Hf
B72atB+Q7n7k7oB3NWEUIUqa64i/pLwDqZ9/qPPcPPJH52/4nw+9hThC/DBp
P4T/ASGb/wWEhfDGkf6RHOczn7AIejzxPEIB+U8g3kj+9xFfT5hIeBt+b+Q+
0buQNO8rZEqTzmMr9GLim0Kul0L4NxBvgn899VtI2dOUF3QC+kbooqRlv0Wm
nntfw/22p42/xb23pt7W8r8ddZWL/mXEjyJ7C2E6IZ50HX9N2s+p28XoNkt6
kvZj0i3h/85a191w8v42w7tKWxpM/FGR6/lJwkOEKSHrehryP5LvWbSTHrWu
j1Gk7QZ9D/RI6KdCTjubcAb8uXo28KfQJv6lbUwmnpl0G59GXc2Cngt9I/Qo
dFtOextIHbwOvz06vg//q3Qo1BL6Yp57mrwO5373534LeLbLyPNcrr1L2zuf
dFcRjyGfKM94MP+vhX6ZPIdCn4n8EOLzkP+V9MOgxyDfuS4UagXvEvK/H9m7
yb8r197h2rnEw4k3o8MxyFyOzOiGUOgE6KHQQ3gOWeT7EHoUUm9xQi7/v6Hc
ZuRzP/xhpH+YuCf3vps6Pp08H+D/ZmQGkb6W8CX5n6j2T579w25LY9XukIlz
L8Ph7Us/tpRn2RF9X6Zuc7neHfkX4HWnzMfJMx/ZK5BdCt0I+Zu4nwbip6nP
AuSfoz7Xpk2fTdqDiAsJCcKypOPnkbmmgrokn7HoPhIdniKfK/l/OO2pGaEB
nS/n/ynIX0p4Gx1WE86EHo38q9CDuL4Feiiy+xCOpu22pE6aUvf9ketEOJWw
Kun4Q8odQNyZcBrhjaTz/wD+CtrIPdluK9nc42Xqj7nH96iHPtRrK9rkXMr8
kb5oMPw11PNP0EOgz0CH7tID+nt4g4hnZPvbdS/hPsJ2+E8Qv0fYQd6/8f8B
6NvU1ghjSXM9+l9LfCLlZdMOz+eeJsD7DtmB8Kcjfws630g8CZ1vhZ4HfRP0
i8Tz9W1UnknHN8NvS/1eSdpj1X+S11XQbaBnJ63XLchcwbP4hTJOUjskvgKZ
m7nWnueQQ8gihKjTS9B7NDKH1Pjb10jvZdJ1dyf51NJu/1A6rt9R72/sidCd
SHM1ebaj3L3kPwr6Ua7dTp1dVqQOmfeLvFrzLK5E/jHawqOEiynvG9rSsfAH
wN8CfRz0FdB3J/2tuJ1y7+W5/Eseo/VtpqwRxG0p63d4DyLzGuEznleO3keu
zUn6W3gHaf9CZiS8xfy/n3yykLmG/7vgPwzvDZWRND2zzOOMhYRFhN+Q3Ync
Q9Avov/plNmSdnId/D3kcaX6Nuhm9LeroLvRrj6Hfo7wDKFfFs+c0J78LyI+
iPyfht8XehxhI3QO+fSH7kf+n5LHrbSLK2gvA/RN4dqF8D+BPxP+RdAboGdB
H0CYSPu5jWdeF3P+1xEe0RimkG8tz3Mr+UfIYzj8I2gDW/j/PffwLfGbhKHw
PySfqcTvUee3U7cFyFci8yz0GmS+Vlsiv3Oo3x/4vw75aci/j/yb+vYSBvL/
N3R4leuDpAftabwC1y5B346Ekwk9CW0IbdXvk+/XlHU18fn8P47QmrCLOjpa
33bS/1Fm3hvQd3Bf4zQWRK9ribeR9nSu7Ued/0nftZP/r1Nn47n2M/QdtKP2
XL+I0Aude+jbhs4Z5H9V/4rMRugvCV00JkCP10jzh769+qYSpqF/b9KepW8i
afegT2d9A7lWQh63I38S/y8nnBrytQby+41rW8j/I+itxLP1baj2eOB28rkS
PfPgD6aufqLOfiRcDf009XwM9bgAehhlzCVeQWhL2uH8b038B+/TDuTnwH+B
MI8wn3A6/D9IGyffM5NOexz6noEOP+u5ETojsxOZGDINxK/B24Nu/0Ln0c7v
JE1r2kkE+jeNwTQ2hq5GfhN1cSRyKf53g+5KWIx8Pv/LuH4XdAl0FfQS6AGk
jfM/pfcEugi6Avoy9IlBFxAuhH6J55UDfQh5f4M++ci8Td4nouso6qMx/FUa
a6lt8X8gYQX0RdThdq79jf7vUS8XU+Y76ovIcznX7yLM5B0Ygvx04pf4f5r0
IuwmzenEVxIep/z1XOsNfSl5XkIIocONpPmV/AuJO6P/s8j8RboK2uFjpLmV
driJOloCfz3xE/R1HdH5XZXLtX+QLYHfLumyGvMs+qHLZeS/FJl3uccu6PoB
9CT4EwkfQr9CuJfQjTT7UP4b0A8S6jQn0vuhMSHtaz75X8j/rKTb+Ifwfya/
/ZF9lmtVPMf9oO9Eh0L03xd6OfwR9R6X3UydHQJvhb7X/L8Lueegd5Dfd+h4
ENee538d8Uquf0Y4m/5nKfGNpC1Pemy3jXIXkOfj0NPgr6PuPiTsy/8PdH/Q
7+uZQn+q706O328eVYjsQnlJvz/rpX+Zea9B/wJNVxt6Cnp7meeXT0CX653i
/j8mrxroH6E/gf6ZuIhwi95hMlmosTX6rOT/ipD71rTmm5qnajwM/Sb0n9A1
0C9A74DeSvwWYbXG6ISXQk5zKdde1XhYeiP/IvFv8A7Pcz5bCJule8jP6S90
WKTxODr8oD6D8A6hN/yP1Z+oDvV+ofML6NiQdJl/abwdcp1Lp6d5jkepTfB8
2tNmTiK8q881aVvAf5G0jZLO+2/SPqx5DfQvCtAvaQwM/QV19Rf1NE9zDOj1
hGbwx5P/RvgjyT+Xtj6D6x+R3we0vZnQR6hfps3Pgv4Y/kj+n0M4V8+Ddr6K
tANJeyj/US1EkaHvyxw/jz7v6NkTSBp6jzLXEsrU36vuSPAUbe1fGGfrOrzV
Re5vh6vf59pX6k9J/znxH8Rz0SOXzC7j+sfI9y112qsIh6L/dmTGoc8bKPA2
ed2tsTq8X3L9/fmI+7oT3hlqe8jfBf0Z+X3J9S8Ih8N/RfVG2mlcW44O7Qhr
NS+G9wbxAfqWoPt2nt1X/P8J/auVDl2uhT+W8Ar8qcQ3EFZr7KexHqGp2jT1
9ia8Qej5W5nrbgVpz6/2d2QSL0c2uk1V34ZuzUgXp6zJ/B8FfTXhJdKfX+py
jyS8S/2sIdCNhCZzfSW6voXMQnR/mPC61hHK/uvaQk+S7tsyr9ssLfV7luNu
L/QCPysJdHH/vcN5Hr6FptAGKsi3L/ETSa9hLCePR5Nei3kC+qmwxz4T6bvq
qecuQb/ZX/1eoeknwx4baVz0ecpjpOnUx77Izw+7nx+J7CMBPYf4duKTkDsV
/m3QbaHvhj8b+kTow9POZ02Nx07Pw7+U/3/BfznPY5u6iL8BneEfjK6XE6co
/6FAH30/FoYtr2v6xqwkXBbwlVbfjpO43/HELcjjDeojHbHsC3oX8zyW61pv
nd+m3Fc0VtO3mjnXGsprA30A71wn6mZWcC8nc18dCTP5X0s9zCA+Dn4RdX0e
99OctpCE3440d3Ptj7S/b7rfuWF/L7oiX43Micg8xP+rCHcQOkjnQud5rPTQ
ehg6T9f3EH5nwp3QJZRVpjEcut0Tdv5KezD/b9H3R30woR28a5A9nXRdCq1P
y6T5ut6SdlcSc/77ouetxPsQHw2/Qms0wZh3ZVBXbZKubz2T63nvJpR4rnoz
7fImwgmae5D2G3jzaIhjkG8L74oyzy811x2j8RW6TOW+nsjzWsq18DYh8ztl
Pw7vdc1VKf/+sL+/TQrNb03ZVVzrqXUt4gepv9spp4vmacxRbtQcnP8H0EbP
hteCZ1irMRzy/xBXEi6A/kkxdbUA2f2QbUfajvpO8/9I6H3JZzb0ecjcSbwv
Mgv1PKG7aiyIPpmI29Gp3O9HedZzKnOuw0hzKi/pVOrmAO7hXr0TtInrSDOb
+BDu8Vzu4xV0OE5rPOT7CGlPJl4cPPfGpZ57aN7xQNh0nyw/hxXBs3gQ/rJg
ftKGfDIx1+er6s+KnWdvymxLWJTn8dKTxD2z/B4+BX0C8c606bfQZz+eQQ94
09DzHfLoQb6Pqd6J+5L+UegvqJ/7wubfz/3+SLnn8768rv4zYplxGkdRz4M1
F1Y+hW5L52puQngAuj3l3k5ZH1Nu93qPq0WfR794AXWxTXVR4fh94k0Jj781
9j6FtNuhN1HuV3UeM3eA1xxdekb9/y7K2Tdiuf0y6K3+AdnNhAXc3xSe0Tnc
V0vS/CLdoI+A/g36AnR4Luyx+5/wD4uYPqvIdSJdB1MfvxM/gD59KHOXxn5Z
Hj//HtDHcP93a2wv/eHtJNygOQC6zSt0Wd+m3L/eRhsbDe9tPQvCcOhhhR73
t6PMRsEcYGPK87Zi4hvqPDf8qMZzlNfzPE8pq3If/Sblrqb+p0U8Nj2BfPYL
xuiHxtxvK/2AQs+FLyFt05jnj2v5/xtteEeJ9TqJtBdzz6sD/aTnsCzPWUVr
3vo4so8RviePJ4lvJHQg3dc8u1nksYTyDow573cI1xb6v8bhJxf5fRGt+c79
xN3J87xgLjsC+iLo76FnQW/nec+Hfo57PyDtb8XT0D/Sl8yFfwj/94d/qto6
/BZZlm+e5T5YY3fV4zbk56k+9E5pDkNd/cH/RWHPkTVfPgx9ekQ9J9f8Yo70
zfK85h7oU7Jcx40iHv+fTz7nFbpvL+VZVGluwLM4Pmp5pf0k4Wc6j3JaIbsg
zzouCr4R0q1p2nML3eP7PO+O4pHP53WukxO5fkbUawRaH6is8nNdg0xurtcs
1FfM1DOhvKfJuwnvwpd65uSxoc4yx5HPOtrJV9CTkV8WdntVW+0VNX8KdHfo
rwP6iDJfP5Ky2pJ+Rpbb4U6e40ERp/8HXQ6G3qxnXe/6DNNn/IQu2wjPUE4H
9PmOtt+d93EL93gz+czm/1Gk3Y38d3luO1uDNnZW0AZm6luZ8Ty0DeWfnLHM
8dDjtQZOXz2dMBd9HiFeRDieemhHOJW+qZK4gpAP3Z9rlxHC+n6R/+XQR1N/
o0m7h7LP4P98ZDsRR5EpQ/dLKOMK/t/D/Q/QfBmdK+DfRfqB2iNBfo7W2KHr
6W+O1ViU+xtI35hLHudTf8O51hZ+Kf9bEFKEcsK+PMcRmsuTZxZ5fkI9Ha81
XvK8gb5pCNeGJi3bh3xugbdB+2nwj4BXofvTXhs6VhG3IuxH2saEaq2totdQ
ZNuQ58c8l63U5XeMfYaSz1vkcwjXGhHquP4M136gbdTzf7nm41oPhd5OPJx8
XkU+o+8v9fA69Bx0PpVyD9N3E/520v5M2Jf/zWhvW8jj22pPQPbT2q3eU641
Ibyo/hMdXlOe/P8VmV+KvXaymDoM874liU8h/6bSkfSjtD5D2Ad6BGnHolMz
PQ/NP7UOg2wvzR/13Sjzvb5FWE24GtkDkG3ItV6rsiz3J2ED4VPCJfl+Xo0I
tZTdAtn9uPcV5Lk/fcfr5HmfeDle0x/E/d/L/3OQWcCze4ryO4W9v9Ekx2lO
5524B5l66FZh808i9OP5DNDaDbx/9cxVD/AzGrvmeE/iSvKfS9qztTaIPicj
MxDe+2lPDLrwDn6Y9pj/dOjFvG//oHtn6A4al6kdce04+P/CPw3+IdTfXWqH
8A8hFBGKlRd6nkCaOuiOhAMIBxKi3FeEcCF1s5frxxDK4d+P/gPRdTf/Z2r/
iPr7nmf9Eu35VGRj6LmL93SWxjzEm2kz58Evhv83bWMa/Afh30HaxtzfRfQJ
e+DfDP9h+PfA36G+nzz/gf8H7+Ze4j2UdxQhpfVo7n0XMjuQeY76yVE/Q9wP
HdpqDEpZz/NMntO7gfxTvOPHak8X+kbazzroXuj0D3EbQo2eWY3XnCsofzXp
j4N/GXGTGq9pp+DfpnUQ7QvrPqnPA4m/1PiGOvmdOvmHcv7m/2eaSxH6ce+f
IHMM+bzB/X0KfTnP4GStTWktHvpOdPwQ/qXQD5F+PfTHhINIs5S4KfFTpH0a
+lxkEugwFbkvtDdAPdSj2x7tw6LfYdBxrRuT5/vIX6J3j/hi4iHqH7Qfpr4N
2UfIYxXXJvO/CekL0b8n9XcE5V2E/JE8m6+4vpEwEZkLNT/O9j5FZ/WvhFe4
tpbQj2tDxecZDIA+hrRTeXfGwruWd+cIzSHQ6RZkD6SMGXqvKecG7TsTTtMe
M3Ed4SToD5D5nPtbgMwnpD2BNjqJNLN5dl/Dvw36X/hnIduJMlpDP0od3Qt/
qdoX8ZlcW0X6HsTN0ecm7vdm+DcRmiN/DfpcDz2Bd6SBPPZSBw/Xum8tpZ6u
h98cukjPH/7h0AnoL+lLGwszAD2Z+j8YOgrdnjZ6JHQS+j50mEreHSh7bNr9
yj/kfyjtdAHXblDfyn18QTyOa/vUeF+piHLqa4wZiEF3pf20QSaf+/iI9+Bo
6KP0PMjjKOrkQPI/njo/QOt73OMXGsNxX8epv6OsNPU5GvoT+Ku1lg1dS14n
In8Q8qOQvQbeCfy/lXa1TeMhzbXgH67+Gv7l1FuUfGr4P5M6+ZZ2/Y3WvWkv
uwiHqJ9C/ni1We018YwmaC1Ma8jUyTfIb0b+QmEzoE+jPVyUdL/bBXq/fPP1
Pu/muZ9BnuOI30TPB6QD8Snc631qx9TLL9TJTMrbTryCcl6E3xsd+vB/pb4/
yD8DfwV0T+3hoftyzfPUxrjHXuQxhvAW9XYP/Mbqa/M937yG8CT0OdpjhJ6c
9LxyNHou09oJ187n2kzynEG4INdtXHn21r6j5lBaU1f+5NsHuhX1fBrtbRo6
v0761YQlhAHIPKA1Ieg3VSa63YZMf/iP57tc7TtOSDrvq9DhNa3RQ48nnA1/
EXXWDv7VhV6j0Zi/LfXwstYLKP8qdMwilOv9rzdeYGi9sRLCRWiPf2rKeIit
SWMkhAEYHzIu4l6tHaLXT7XGL3xHWw5XGqOxmevP1xvPIGzIz7XGQmxFpiP0
DOjuPP/PKH9D3DiNA2gb/0aMzXgtWJ/dFPJa+jfE2WVe1/1Ka3dagybdx3Hj
PS4v9Vqv1nzXxb0Q9oAwEOj/FPH2pDEjwj/cHjI2QfSoYJ1ZeWqhs0Ot8RRz
640tWRAylkMYj/uhfyg1LkPYC8kNrTLW4geuf631T0Iqz7gMySwJGZvxIPGP
pcZWaB1e/4UJeTjkNflJIWNlVMbAeqdvwvu0mfw2ESo0nxGORWvQmh+VGg/y
GHI1/H8y2Be4PmScip7NDO1zCAOUNEZDWA3tJQgfIjyI9gY6Vhn/0YE4j7xL
yOtRrl1V7Xr6vdZYFek5NeT1da2zfxnyOvwXxP+gSxX0mmBNe2q19ZrPfQwn
36e1pqu9fehPKOtk4s7c00b0WMa1n6F/insvZD7v97xi730UB/sgz0D/yPUf
4t4jqUx6fV5r77/Ba6W5XI73LY7R8wx5PfjFIq+HD6UebhSuQG0S+efi3oPI
Sbrehdv5iPtsp3Xyaq8PH6W2VOp9D+1/6L/2O5S/9jq1ltsKmlv5b+1fewDa
c6lIej9C+xRlSdeX9h20tq+1/u38P0V7SfquEaqCPQXtC4yo8t7CLtLVVni/
YD66Tyz3vsXclPPWnsd3Ie9r6Dn8W+o9bb0jbxCSSb8f2jfR/sOPIT8b1Zn2
Nr4nTKj2M93FfV9P/g2kv538U0m/eztLvcch2Tzu+8A87y+tD3kfSvs02tu+
O+U9qd+T3tdQWfll3q+RjrnQz9AOOkE/S3xdufFON6XcHwgj9YjelVrv+T/O
w1ui8Qd0U2EP+N+GNG0ZB96c9F6/9v0vShjbIezHY8gv0Zo2su3KjfdonTLW
Q5iPlwIshjAZLxAuSxifIFzB5RXGkJxAuvcCDIlwI/rGCpPwbLYxe88G2IZ1
UWMzhOsTrkN5311mjNPzAYZBGKeVAQZDmBCVeVeZsRvDSPdUtrEtwmkozUcB
VlBYkJn1xiQexL0/zn19CP1wvTEUbwY4hz/yjZF4K9t4CWE5Vgc4CMmsIlzE
c5+R6zH8FPJ5l2/BQPrbi7UWwbWLiB/nnnvyLRgp7ABhEfK9U8ZlCB+zNsBa
KL95ZcbIvJLtMeKQCmMzTtO6KPp9JN2Il9YaJziCsh4uN27jZM0Hy40HOUGY
qHxjTt7ONu5FeQpT+lC5MSIdyo3jEE5EY2vh4tSPbqf+zi02NnE5/LlJYxeF
mZyXNGZSOMwna43BXKF1Tejv9NzTxjEKL7pDz5b/XxEfST0/gcy30MdCPw+/
q9aDGxk3KvyocDP3Ji2zuMw4UuFqlkKnio09/U3PjPxnkn9JjrGlwphuJ7xN
vWzWvlK98X5Fed5r7FtsXOWvamfocDJ105xya5AbTButIs7SeiXt4+2MsbHK
U+3jzbSxnamM8UBPQt+WbYyt9nek31Pab40a86m6Ea50T7axpn9rLFPm+hMG
VP+FZdX1p8qMI9Wc8eky41ezg/0j4V7FV909Um5M7DnlxscKL6v5p3CwwqwK
r1YVdtpvso2NzclxPd7A/U1JGMs6PsCc3qS9QOixCeNvhcv9K9t7VReUG+d6
lvqCGtfZbfWuA+FchX29RmNaZG4UpiHpOaywbYvgd+X9uoBrH1LPp6BmNfX2
dL2xLufRF35O3V5GXWXR7u4sN8bhV57HjoQxD8JbCLuhdYiVhNJK4yhqkelZ
YAyG1oefKjTGIplrDIhwIc9nGeOhdB3KjAn5hfAc/y+lzH9JV4L8/fVel/gC
fX6h3BWqa/W7wi9pf4FrFyN/CPdSjPyDlcZm/C5scKHxKMJpLC80lkPjuvvI
cyTtcirt6HruvQ7ZCbSxG+C/QX5TiScR7oGeTPxDytiTbwIshNY+D9U4nPZ2
IfS76HZLg/FLa6FTMe+zCasxmXJPLzAuonHa+xJrkGleYYzHZ+TZJO29O2FA
hPXQPp32k04P9h6FD9me8fr/goyxH1doLkC4ie/nONIsVntOGQujNfCr4J1a
4LXxWyu9zv1Vymuo0l97bV2jHv/uJc0Y5K8p9Dq2MCNvBevYpxV47VkYkffy
vL8xMssYlheCddQt1OMc/n9D3DFtHE0/6MOoq8ZafxUGnni/LP8fkmc6Qsgj
7EvYR+vz5FHBc7yM67nQZ2k9XPvcPKt+0OugLyBeS1ymeqc9pJD/kP/nwX+X
uBT+V7SjjdobgG6D/pXIXK7xIXXeXWM56uGOao8TstD3b/WBWovSvVFXg7R+
jkwn2n93rnUjFKFPOfl8pPUjrjch7yihGn4VYQC8euI6wpXQ42lXVeTRh3YV
0f4OvDXCdVBmOelShMe0lxH3Wu7iKq8Hf0eaZmnva70j3IXWafWctW+C/n8i
81PK+yyDCIW0570xr80Ls3R02tirDaS9h3uZpv1N4idI8x7l/5M09k3zoIVZ
3nvRmvRD0NOpgz7QFdozQP59bajLjoD7/kD9Vpb3dLQ/k6DcS8n7wrj3147J
M/bsd81D6o1Fehsdfkf/3wgPqz0nfS+af31QazzdMmSvDPBQ2qc+utL4oiOJ
NyIzgvJ7UIfrao2V+4q4RbHxHtO1PlhlvMWJxGMrjDFYSl+1JG48gbAdZcIU
RIwlEKZgBeHgkLEGB2ouEjLuQxiGQ0LGYwi7IQzHxzHjL4aGjBkRdmSExmYV
xu9di36b0Wk0vH7VxoHo+uelxvEJyzEoZLzfT7nGW44L8H0DQ8ZyCL8xBPrk
uHEdg6Gzk563CGMvLMphIeMrHqkwFmUw5a6JGd/RUvVI2i3c45pc4x2Ee9iH
8E3EeIiJyIV5J0+D1xM986E7QJ9E/VdQD9sCPFKbWuMBPyd+n3Al5RxP/d9E
BT0RNxZGGAzl/VSAwaDr+w/XNA6Z++PGjQiv8U6BcSbCy0j/Un8K/8NqKM0z
avsR41JW5NoOB7VCY8jn24jxIWuEDSPRp7IpgDeCuuvH/+tpM92ixp61r/X8
u4a+8RFhFMh3EfHWhPfvhEEVfnUC7atlmbGmwj+o79ZesfaT1S8LQyEZ9cV/
xI1ZelVrwsSvE++kjGtSxkx+Sn7naexFuJ/29AryL8eNmTyrwPg6YfKEY9U+
9bXkOQo9K0jfmwp4kAq4UXtDPIsWae8ZfQC9sNR4vk9IMxr5W+BP4V5W8ZzG
Cl8HPa/S+ztbU8b6ZVHmNdpzajAOVnjYk0j7FTrWU1Yd+vwe4EWFaR1HuDhk
nI5wa/1Dxq4Kw3qenmWDsabCnA6g3DOhr6g3dnRAyDg3gaHU5r8oNf5UfLWt
r3gGf1HWQOKF6Lpa2J06Y03vCPB+K+F1iBt31K7WOKbTkTkqwKteGjJ2dUKp
MVIajwiD24/QVrZYKqvO2GHx1Y8IhytsVFvCC1of0PpcjvG3F8B7v9S4Xcno
fyywUZBtQ5i4d9g2FItpM32gH8n1OusE4fkZT92sPpm4DXWzsNZrSs25x9vS
Xn/aQv082eB1pxphy4N1V+El9vCNPorQVPPdAJtxOvm/wXM8gvJeI14UNaZC
OIp3Kr03tz/9WLLae3Pr6d+6VhtDcq/WgSn3Cs1FiE+p9HpwM61L1XqdbDb8
9uR9UsLYjzlqk1FjO9qQ3+PB2u8TxCdHvC7cMeF1YK3/juL5dtecRvO4AmM8
xhOu0zPM8Tv5CuV9SZxHXIB+hbTPIeiSpT4NPS+hjZ4Arw3hRu2t1vr7/Aj3
cSV0EnoJ9GDSjOX6y+TTkPb38TH4dWl/Jx+Fvj5tjIqwKtnkfxPym7VP1ODx
w0qNnWr9zX8eehzX+hD6Et5JOt7AvYxt8Lf7JWQaoVeD8LjktZqyv1EfSZwf
YH++zfFYTX2DcCDtCoxvGkw4knqrod6+VofGtX01VyDvlyq9Rp7hGb0e9d5E
/1yvT07L9jNbFfUeh/Y17uW+7tS8uM57CNorGBSso96UbRsK7SOIHkhoVe69
g6PR8+1gn+IW+OcnvK+g/YsZ9bataIxe05Ke58v+4nbegdmlXjd9Pljv7aVv
YtTrwFoTXpz2GsE+DV53fYwwlf+f8Xw70W4+1TpzsC+jfYtHZO+ATm3oZxal
PYdvJHs34aDyjX16IO15WJ324Cq9z3IUaQ5IeP9iIv9LuNZS8zCeYdOE9zK0
f3ErdX5/sP6vPRvt3VxDfvOiXofXuvxY4osIx3HtKuG4so2t0v6E9inGIP9K
1HtG2j9qmfB+yqmqO/qBTsSnZXvPpD10B81xhVMiJAl3pP1MMui4Eb1m5RvH
M5N6nEHoRjgs4f2Ljlpf4H+R7FLUx1R5D6eB+22e8H7KyVpLKfA6vNbTB3HP
lbSxpehbQ1n7Q78MHadt/lvgse+yco9/s4PxmMZmuzVWyfOY7W/op8s9TstK
eU6i79vqGo8jNZ58s8ZjRY0z9V15kfzTuZ5DaWym79GRZR4H9kbmr5DHjBqz
6j3cy7PaE/f492Dqczjx+hyP5cPBeL5XMD7fRZqM8g/Gw0tTHp/voZzl5R7j
L0/5XVf+f4Y89tf4+t+Q5w75XCsq81hVY1bpt5D8WsU8Dv4rZvySsJqnJv0d
F6bx42rbDqxXe6swjunHlMfCn+UZV9SrwHNMzSU7J213orHBi9x7aa4xWH2Q
uSSY/66VzWCxx+PPQG/R8ya/H4h3x4wduaPcc9KfhQGIe2xflOs5oeaGwlL+
QXv4lTzOrDJuR/NYzVs/KPFYWWPxmRWez64sN85E422N84+q8Hh9G/k3Snuc
/ni1+z/No1Rfa0o8/zlN+I8Aa7lV4+QC425uIBRoDVc2GpTdtcA4To3hK2PG
oP2CfItC44V+0BpxyvihCPGqas9rl3EvhyHzHWm+59qb1Z6PLoc/hnvbig5d
iRsixigKMzqWd78nddKC+LioMZvfkfb4AuM8hffUnEFzh1Xk8xr13SHA/8Uq
jdf7WOOnuHF8v5F2G+XvyjEG8uJCY0+FtWssnFuh53JvVdt+4Zka44mEdxKm
qLTO+yn3cH1Sued/DwnHkfZ6/p2q26Rx93tl69rgvZc51Z5vrgnmO02inqu+
zf/GRZ4Lar55CPwRxJ/ALw9wo9slk/TauPYIrqj03PBxyn2c+/2U6wl0K9Q+
o9YH+H808ofDq6V95qe9pj0XHZqR/9XIbEAmDn8b/AfhF6SN5Z8PHYH+Fnoe
dCJtTP3D0CcKl0o4RvidhPfptDf3bqX3/g6lPk4KcBFtcoy7EOZBdm5vlxun
cVbKmA3hLmQXNy9hLMV8/ncOG/8hG9G58O9JGJMh/IDwBkfBXyE8f9Q4EOGy
DwnwFXXFxnYcHWAuxD84x7aZit+QTZwwcwEOpGuN19NeqDVmRJgS4UYeQ75S
/DLjPLRGdyzP8HH41fBfLLPdp+w/mxJOrfF64Da+n4/zHPcPMCinRYx5OFJ9
HfVzN/d1Jvd+X9r2iUuIz6HO2uYbsxRKGL/RjvAh6c7X2hf8AUnjjvpS7mPk
s0XYP+LbqYOe+iaS73L+nwWdoI7/4Dnt5rk3pZ1eqv4hagzM5UljmYRxOoJ3
7B7N/+kb7koY8yHcyZJyYz/6EV9abBzLoeh/f9pr1cI1PFpujMel5cZ9HJHj
+hIORFgO2QM/mvZ6szAdwoQ8G7Md8q3ociZ6tiLfvqS/k7g7dXKL8MaEZlqr
rLBd8GPltgOWvW8X0k6rsk3wecj3qrFed1LnV3CPe6O2O5ZdsdrOF6pj3Vdg
M3w1Mk8HdrivJT0W1bjuGvgrEra3XZm0Xa1sZrMp/0x43XNsL/tYru2KHxdO
h/+Lc23/qfXsR9HhhaRtb2WH+zLtM6fANqUPIX828ULkX4IXKrDtp+ywX6ZO
ziDNPZr7xmzn/CzXd6Bzc2Se0/sV2HSfgT5Pc/2qHNsQyyb4Cuibqmy7fFHK
5csG+PIc2wUr/rzMOCPhjToQppPfoZpf5BpzJZ7sxJvCuxVeg94Z4T5yjWua
G7d98pO5rhvZHl+WY/tixZ/JbpQ8VyVsE14Q2ImP5NpY6vYq9HyRa29pbTNs
u+fX+P9qYFcum2bZPg9Bvnul7czXltsmW3bYA+F/X2W77Gvg12nuA39/7nec
bPcJLTU/pd5upN460raujRov1xj+l8LiFhqnIVzEH7wXZ6Hzt1p3LDSWokuF
8Rp55V7Q2VNkrJXwEcJlbIO+Pmqcxv78P6XCmLhs5Hcj80GhMRg/EH8vXAj0
3irjlsrRt5D4XNnfZhs79x35dUOHc2ije4U7Zgw8TuulWksk7b/CjhYajyL8
xl/In11mrJMwT/q/s9g4KOGihK0Txk739rPs20n7U52xJMKrbNe4sNx4ltxy
4xyuzTZe6FyewzkJ4yVOjRhTMUlz1CpjJHZwr2dWGzvRkrSLa40/moPubUnX
JmFMxyPwB2s+IpxOufFTR3Bv6wMsTVP+t9U3Q/b+/J8VM87kOtKsqTKe8q0q
YyqFr1R/14P7G8M9XBM3LkUYlQnwZwT4TOFthE8RRkPzamFDhBER5kTYGt2j
5t73lxvP0Vx7Z+j3vp4t7+y79cbDrA32Cv7Dbep7yT3VJIwLrSw3prRpyvjS
drnGfu1Gz7+F/0SuPmF8qTClwpwKeyo8k3CmI/ONZxK+VPOU/mXug4V90v+d
6p9LjIvNCTCAdfDzobMTxs49KVwicQG6bKm2jh+h83PUVwf40XLj7Hpr/qh9
KdIVUWfN9Cw191TfyLVCyvml0NjBifCnwz8N+i94JcgfoX2OhPG2rXONSbw4
33OnCVyvJhwH/z3k1xYa19qL+vxXmADa8I20gS/QrTe885Nur8IdDQ9wsIfm
G0OaKjVWSfjQ//CrhPfqLf9VtXGpwpluzjKeSbKH1hkLJdnDoC8h/7xs436F
KdV8LSfbeOB9iC8uMx5ZtORerTImOUVdxbmvWMI45acrjU8uh98JvU4pNTa5
WHWYMBY5o/kcdCnhK9rk3/QPxZrfck8dNReg2xhf6P0UYfFlB/Z5ML/YFbEd
9Ikhr/N9D90HurLIdon63yuQ6Qt/XWBDvZ7/H8pHTbC+Gqswb5jstsjnwcCu
rQD+q8QDUrYDfU19o+ZERbYb/I7/nwZ24t9CL6A//THXdrPvx7zO3A16O/c4
q9j/ExVONzplW9sfcr3+NiZlHbWG+WLc62XKc7rwjIHd92eUtTOgtWYm20Ot
m2l9V7o10ZpgyjpeS50XFXit+WWurQ5sWkX3CNZx9wvZ5vVF6MZaRw3s/yJa
r+Merwl7ff4xxmeTtJdNO7q52Gva78H/hDZ5ArJj+VaPCrvOtLZ8ecpr3f1T
tvl7Icj/Ea0Bx73+PzpsW0XZLabI/zrZbNZbl5WBfFmR7Xv1DB6TTU/c+jwQ
rGfzioValTr/sPYGIuarHoSxkY3wsSGv6WttX2v+e8v8fwPp/tE+Em3pTe3B
cC+riC8mPh7eG8Ece0+t15n7El9Oe/6FNP2F70bXbyk0lrGc0mq+/Etgu9ki
ZIxQY/L6EPrZuPdHmkNfjUzbYP16d633aPoQj4F/fjCHOYCbOzago9oH1Loo
/3eQz27qpGWe81gbrIEfiHzrYL/t4KT34ko11pLhpuwCuHYc6UaRTw+tz8dd
J125/G6u7VRlo/oNelxDfJswLbTVzarHUq+vf5brfQjZQn8a1PPnwd7EOPnA
kT1UsKZ9R/AuqG1v0Lgr4I9N2S/CO+T5Wtz7L9pD2lTrd2Ua+aSK7ONgA9d+
Cuyw1Va1dqw15HbB2vLm4D34k/vsFbKen9a6P7i2xvtSynsq9FUp2yW/UOo9
LNnkir8x432WKzPW+fNc+3fYhW47teeVZyzV+0FbUruWHbr2WnrTDv7U+Chl
HGIsz1jEaSn7FxIWUXi3dJ5txbUH8jfy10K3ydhu+nt02RMxrfd/Qsp+nrRP
oDwlr//CNu7O9Z6K8szkGUc3U/b1IWPnhpFnldYl6MNvTbnMCeW2W6/PM4ZK
GKjaIO3KIB/JyTa/Os95XRExVk8ywzOm5UNpUyDzbMh24vtAvwe9rdZ+S+ZR
n9VF9mOlesmJ2neV9Beu8p9c+93KTxpT9Q3PYjOyfwd+NpoGuMo8rXFAZ0WN
t/w8wE+GoWs1fiwwfTvvV7+IZa7nfq8gz0/Is0mB9zt2kecxGef9HeUfl7Gt
99Za9wXSR33Bt8jvjvhaVZH9cSnt17INj9hOXL64duT63TgqY94WrZ3zjvwO
/Tjxm+rb4v4/Nuw2I4xfS/K5MmKMoPCEqre1qje+C23j3h8cE/Z7qHfw9zK/
l2u4l0Lh/JCL6ftc6z5f7+YJwp6Q9gz+z8mxLbrehUMLjI9Mau2L+ukfMc5z
UMZ4zBHk82SwZyjb+XLteSH3XL39l3wE/3j4H9c6HkNZ62vd5kVrn/OdQM/3
C2yrrm9BssDfC9mknxAP7NqRWQr9eNzpzgn2FdU37kA+EeAmt0EXBTofHmBH
y6GfoE4riSNVxquKfkZT+aSxeD+X2ldYcZ7xnwMibv9qw8IXqs2vIp6dst+G
n0rtG6FRUP9XVZm+g+tDMq6nGO9OaZ7zXBay7zPhSoUpTRfZF4Z0u1N+piLG
uw7NOI6T9saU02wutX+M0iAf+TITjvfkQF/xnw4Z26j8pZ/4JYH8JRHjm9Wf
5NF/j+b/2eqLKH9f8j1C61a1xsAqz8PkeyriOmyHbm2LjZ1dp7FQzNjf9dBf
BpjazUG7UZvpRT/WW5gNHtjTcbfFKdqjQf6TYK/9XeJExL4D4nnuj4SxVhDe
er6+fUn764hWul9RP6W+ZUet6e619lUjefVjk8LGPAuXemml6/MTdPg56f5T
/egvpHkMmU7EzQvcnlX/6qPUjwk3rPZ2fNy6nUR8Ytx78D2C8Y722Y8s9Vhh
ZLH3qyfoW5/jfajxqo8yjyuOi9sfgsZT+s41CcYVGoNM4v8+BR6PaQx3lOyf
il0/5wTvwQ05Xv/Qntz4IB/lpzHZERl/0z7TPn7S3xKNlV6mntcGuAHtrUu3
b8o8PpX+N+W4n2gTd/4tMx6vbiCfVhl/l79Q/RT73W4d97hS32x9f7/kf0HU
feavta6zrmqHek+pi8OQfbDec5pZ8H+mvfVFn1MYhx9M/oeqLuAfkrHsDOi2
GfsoqCW+Ns9r0bJjvQheTp4x7cvQpzl5jeH/mXXG2w+jnGz6syzCiZof0Y+d
SVlvawAnTIpwLdCfke5TwrHILFTbD9a1BlP/U7iXxpq/y45a94k+G5HtTj6t
tRYB/3D1k/D/FA5Ttp3wH9QzCvs+t8TdX+h7NrjePh5z6Qv3Rtx/PxiMXxYE
dfhDrX2ctM74W6G5hf6/Rz59I/7e/VjrMf1srX1G/e3WN3xj3O9zVOvO0NGo
v3GXRjxmkIy+Laoz7d/XB98djf8vqPT3sZi+8MJKfxPLoCcTLlZ/zftyhmxO
Y7bX3Z+0fYJv3xdxfx/13DvF/S7rPt8RuCZqGeE0dI/yH3UMdbU+Zh+XD0Lv
j8zReZ5D6X5nB3WicZLmOMfp+cg/AjKTqZeLiJPU/RTir5A5gvZQljY9kHJS
0JugB0P/m/T+WAHt/M6w92xbZblfFKZefePepPesHhDeO+o+RWOW5vCbIVsj
/yjotjHHa/FdA98RsnmehT6jiTNp+6KQ7wnta2iPW/JXEO9DmxyFTFp66bsf
8/71jdTtRI1XhTfXOi8y5chMJM+e6ruhX4Q/UuMR6BbUeUUwHrqbb8ocre0S
f0s9l0b93RpEfgfk2YdSSfB9E72g2GMDzROGEB+cZ/z6n6S9KuL6vwuZsqjb
qsb1GvNrn35ExHME4WHu0/ySNM3z/F3Vd0D2CH/X+nov4l9L/N2Q756Tke9Y
bPpo9B8W8ZziSOiB0E30XSa/2qjp76G3xq3n78TDIx4bDyU+NM/jysOC56O9
mc+DdqK5QSfqf0vMfknkI0Q+Q7SPfwTltyy2DyCNOzS+19j+ct7HD5HvKuxi
3H2jfAbdrbW7mL/Zc7UvU+Q6P6vO9hnncI+thWuKeo6TIwyE8AzEB8l+v9DP
rH+95+ddSHdfnedC1xC/Rv28WWS81ynw1gU4sFbF1kd8zePUzwvnprn4huC9
+LLW34vxvEcTKjzfKazwfFDfTfk/einu+ZHe65toS1egSyXtJwe9YjHP0c5B
5uy495xK4F8bcfs7lvtqKlwI9FjlFzbGskOe4z3U25mk+zrm/doqZL7QM+H+
J0TcR3+u75L21+Q3QTas6NAffoV8fJL/+IjfB73H2ssWtvAfranneQ/7aerh
uoj78/EZz0eLSfsE/KXFft9ODGS1D/5MnccsRch8SD8fVRtA7/3lXyTsfeoD
5JcJvXsI15Px/Lck7f5T4x/NldRPah6hMcHFle5Hb5BfKcZUG3lmecL48b59
KudQ0B2rbSN3MvEphMnQnYjPod/4EJm/kI0Ixyl/rMSd4L8P/Sf8i3nny+T/
CP4+2muE3pe4ilAa8DcgNyXI868yY7faQz/F96NvNnVAfDzhY+quPXHTavul
Okh7R2XGUHWQT6Zq+6LpTNwaub+oi7OJO6LPCPjt4B9fbd/TJ2h/kDBatjLE
q7W/IIwDdM+k1/1qoBc12G6vkvgt+G9o/wV9+1FfL0Fvp/62EZ6RjxLi0cgc
Bf0m9PeEJ6F/ID6Qd+RB6KbEW/m/MEj7JvL78awHkOeF5DkM+mb5iqS8Wvk/
I16LXA/k3ydeR+gD/TFxJ/LKoQ1U0y7eTXq9aTpp/ynzGlkC/ZfzHk3k/cgg
m8W1bOokWzjclP2q/E0+cZ7Rv9AyarqZ8mbSln5QP6zvAvIJrUdW2Rdsf+mm
PQ/5BSP/lsgfRzyjEe0J+nLqaitlrUPuSHT4iPhdwiHQa4m/5loL6E3EH1cZ
9yX812XC7ct2WFhXQhP5BSNOUlYV9GvQG0gTg/6EeJD2N6HfUP5xjyE0fliT
9j7dW9z3O2nvHb0GvZ7rhwd7Sder7jVv4f8HdfZ98q78oFMXnyCXTT+zgfgI
rt+B/NO0u180t+L/32Hnrz3Ty6iPg+Ped1yqeR911RPdBmtdV32fbJob7Bsh
xLt4gvycU29HcL/LiEcHz+s45NdCL4R+sMq+Oh+SD13hBAL5Q8jnSOLp1HNz
4l7wWxBnkraBPBb6aMIl2u8mfqTBfrx/QJ8IdRhGn+fJc029fTo8xPWl2heD
/43mg4QL9FyIp8M/G3qj2pJsIbRWKd/sSX+L9U3+u8zYRPk3nVllH6KziHfA
nwI9u8rrnOoPJqLzJvJLB3u0V3LtAOiBxIMJx0IPIb6u2j75FvIsxlXbpvNh
6LHV9u33kGyrq+1/7xHoHtX2O3q19ldrbKu1r/DUNd4rbC0cdY3tsPaHblZj
u6v9ZM9dYxuuA6BvqLZfvsU19uOqdUStU54RzLM037qw2r70ZiFzUbXtR2+t
sZ/AV4NxgXxla/71W619MMr+sQfta3S1fQQ+gPwt1fb7t6TGPh5lF9lAPfWp
tn+8GTX2yS8bqINrbeMmn8NPp+3PV/Y9zeG1qbGN0eG1tnWST/6X07aBku/9
F9P2Q6t117219o2gvfrcwJeC9iVvQrffq+1LZAv5za72GPKxGtt29ZTvDnQ7
ucZ2Qi1JN7zGuINja23zJT/Jd5HPwTW2RWqAV0YZv2rtgrhTjW2Ljqi1XZv8
K49E/pwa2+4cVWs7LJ0dsFL4xxrjH46Bd36NMQtHQ2+i7R0XtJNzqo2BHc31
/tX2wX4ndIa22h2Za5EZVeUx2WjipdzLjcTX0w7PQOZy+FP5f3aVfTOcIyxP
mTHzx8iHYoN9Ql9S7/e6mb4TpD2Ya3cgcyhxX67Ngr6Q+Ab+9w/y/B4920AP
g15BnpXF/p4eQz7X8G4+QHwJ1+qFARZGIGn7Lp2BcEu9fThcQHwdaRPF/v7e
mLQfBvlj6I1cOXQf4uVJY0rk8++Cavu1nUw9bCuzDeyx8r1B+BK6M/Ggaq+l
zEXm7Grj01WHZ1Ubk673SHbB8huvPuTKavuDnwN/WLV9vd8PPaDaPufvqrFP
eM1/NQ/uF6z5a+2/d9J707LZf7zB3/yx1GFx0nbU8nPfJWm7iR6y70/aNkq+
c7torA99OvEW6uxd+cOVf6OkbV5OU1/EPb4CfRz0/tq/E8YR+krqri3xGMpq
R/wW/ON1T/TnhwVYgUvoi66k3uZAfwq/Y4ABepo+vn3EtvwtU7b1f73ceFX5
4hY+dWnadLXecdr3M7IPEzYG+jno+dDXx+xXQJjqEvR5Hv4C+MvJv0PEGKS7
+KY8y/+7uPZOvn2Dq5y7krapvI/7u0LjCH2P0G+R/LIi/3O+3xO9L4eiQy/u
pR9yO4STJd6AzDbo8+FfwD3+Cv0WeeSG7XNbdqJKK9tOvYd6H2eh4yptUoVt
q3k6+TSJ20/CWdzXMmE4hcGWj/2o7+fFqO9dWNwk6T+Sn329X6TtJts5Ya1k
y0a+66C7kbarxgPQnXU96vo6V2s4xA/Jpkd7U/BfEM4V2WOFS1Wdwn8mYv6T
XJ+Zbx9/J0bsk0EY7tbkOZ16n8O1u9PmZ1M/VbS9hcLYwuvA/X7HPRYKt883
/knS/yoba9LeoPUi5G7hvm+OGyt+E3GjuLHic7j+coAH/jPffazq8mrSvks+
peTbA30vFK433++TbD2omtB92mcrsP3HZSn76Xxadi6634if0abg+/u1xgDw
P+A+P8t3uqvDzuuOpG1/59M2vsm3LbDspbXGIt8JWkv/rsDnO2jNaHax1zTk
J2FrgdcoRC+t8HpJWD4A4vab8L81JhnWaM1EfhKy8rzGGqHcO5V3qdejVNZd
wX/xU+T3hdZn8v0d+hh6S77tkzWOKC62/bO+T7reR37IkNmT7/Nm9K1SffaG
/wb5/5NvO+FLqcuNUf//hPb1FfRQyhoOf43WcKiXR2WDEPU7sirt82EuI5/X
ItZHdbSe61uDPO9D/p2o2+SZGpNG3Sb1zZL9dz1tJrfUbVI698z4fXpGOIGM
89G3+ALoH6CXQ79FHu/m+zvdK+N39Fn4b8t2J9+26qX1fp4Pwz8T/e+O+R05
XeOyiOXWEe/HfdyC/DatOYR9zsufQayzHCaT9sOIx6JX19nW+zmNU5LGQ71K
21hcb3vkFfBrgjGq/r9F2bNyjSG8l3r8njKukk85dCgLbJLPCRs/pfMd8qir
M8LGNg3n+vOUPY+8Xk3a7kBnoHyOLqciswCZxsi0iBvjpXlPD/hPQA8l/yEl
zidMnudpnVo09TwC/jBCBH6vcIAbI+3WqJ/vFzz3DyjjX97T5dTZ0WH32z1S
9k31CjqcGDZWU/jM2cKMxY1fPChs3KZ8bR0S9PGqo+eSxnuuIe3OqL8LwnN+
RjmnBPRHEacRzmwmee6Kev6wOm3eS9Rhbdi2zbJ3vp0yZ8dtZx4J+LJ3fjvt
b84ryH+r/buwbaS/g06Ebfv8HmVlAv4W+PGwbZnfh18f0COo27fQ417KKKSu
LhXmDn7HUs9br6MO+4Zty3++1ka4xx5aB5JthcbpcT/f8ozPVzpM345UcI6D
/CmlbQ+0Vut5ET8j4QA/yvj7uIHrX8O/KGy5zRHrsAT6m6i/L8r3qXzbawhf
9XPYGC35krpVmMF8+755TuvG+bbxmJK0bcfkMvfTkr80sA+RTYjsQSYmjfOa
gMyzEb9rFwff4wuD7+b6jJ/dp1p7RKZfgHv8OO37eIf7eoX6O4Z6WK53APqo
uNvbc1of5h5aqL2Rz2nEn5Pu0pTPkLma+iko8L0/g/xW6vo7wnzSxwpc1rO5
Xhs4Nm6ZDRm/F59pDso36E749/C+folu3YQbVb8X8/ulM2UiEZ9zItzmR2nj
K9+uDf0HHhHGWP7l/o56Tqr/31J+o2JjTA/gfZ9D/gvIfwD8fYuNQ51T5/dl
XdpjfY3559TaH63snGXjXE6698PGJV6Sto+7O2s9/z4uYr+CjxK3C+hrY/al
pW/l8eTZVuMq7nW43inhf3lGEf5fmm+blM/CpuUL+E/y/KPE2Kb1YWOhGgV8
4ZvkP0vf3hvz7b8rrPG/2g7lHJSwzcwUrv0jDG2JfXbdzPjugahtTpolbEcj
3bQ2oTUKjd0PgX9wwvY1+eR5oMZx6NhSPksjtmmRnzDlLbsY2cpojCF7mQaN
KbnnLfSTd0Stp3xFCkd3tcqETpNPDnVekvB6hNYlXifOz9hmZxT1UFlqTJ6w
0+fV2+/ZUdzXkoj5wulpvUDrBqvkq4M2d2i2sXyF5Ls4YuzXuHzn2ZprH4WN
wRPmbRz1MDBmDFiYcvvl24aoV8z1LLxZAflcEDNO7sqkcWgXlRm/1wdeOtu4
vL4BNi8sjHfMZQxvsG+wPcRDksYMXkbaQYQu2fa3/KHG+ui5Hd3nVHndewP0
Q7S3v/Jsv92mzHbYbajPGvh5Ma/bNuO+by+yPZXazHX5bk8FGdPy+Xx4ieVk
e/YVddhGa+Vc/0r9dL71WFLsPGWfUClb+0LbKbQtsJ28yioutK271oFPrbct
XC3PYj/ZMgVph/LdGUf+X8vPWL3t8SqReYT8FxXbtue5Cq/3xrROVWjbfv2/
lXyui9n+aj+uTaRNn0x+Y+BNzrct2IEJ24bpv9rdpKDt7a42pnJUYP91Lfxj
hRXVnnPU8jfJFidsH6d6F9T25de0ndYW4Seok6i+xQnbZQ2rc/6T0vabPSbI
cwp6jg58vcnH9bigXX0ath2k6Kx66zsxbVsxpT0m221Q8rJH24dyGiWcz+Vl
5p1L3UynvltHjH3NaE85oLU+LXupbNrBZHS4KmZM6rCYfZOq3WueXR+3X+4f
w8btyg/b5oCWneT7wbroe8QH0S7P5B1r2mDd7w70v6XU7Uo+yW/Rmgi832lL
Q9HzPLV39Gwc97xMdqzyHac5xPlcuzHteFuNbdk0/h/F/wXkNyNm27buwXxH
tHibwrZ3k1/HlwL578O2MZTN6sqAf3W27VplK7m3xu330aANjynz9YvRbU/G
9XY48Z3o8ETEtrWaBy0O+qjZMT93+Y9rVuX28TNpT9KecIntbGUrq/L3aO4v
G5aEsc3bKvxdPkxr+NzX3ALPkaan7VdvJ/JLI54Xy7/id/W2Be9HfIIwq3H7
19V6t9a9VxHP5vrkmG19b4OeFLPO+rbrG6/1dPni09zuXLVDYSgCu93p5Luf
9upos/F62+vGiB/nOT5GeJCQDjDPw5CfW+G54e/ltvfUHHEkeY5oMKb7vQaP
MzSHFRZ8Lvc1jDiXb9zDhe6bZGcn35iaz+pae+5recT2Qpvr/e1rRv3PI681
3N/QRvbPqfnrcH2zYp7bS74442cpn/PHo2su72GVbEDJMxXglSdQJ0NjxmyP
hx4Usz/hq+lXu2bbd7rwu1fCOyDAMw/K93drsPAjUedzHWmHxOxnuIH860uc
5/wiz4Vl76p1CPkI1VrExcH4TD4/ZSMjP59J6uEnnvcb+fbneW+Rx2rC2J8d
YO0nBmM5yWscpvdRPj5HZ/udE35d2PXTKv2OjJVf4pjXN2R/K/y96j6n1jh3
ycu/5X4NzqcA/qSkbYcnCqcRti2x3g3xRMvn4eHl3g/at9LYfY0xs2o9138i
3+sAd6V9f5r7d014LUM6yLeq1i2uyjaOX3h+4fObJW0rXVXmsx103oBsn7MC
nKd8qURkix22veFYnm8dbe7sRrZ90x5jnPQ3c71LnvdHvy7ynqDkZbMmfkzz
gLDtSvcP5EXLv8q/cWNnu+bZF8t/e3zw9xYYMyC7u32CsmJZ1qUzdC704pRt
33LkC6vKuNaN1NNjKetVL38qtOEzkS9Mey9UtOzvHio2Dkr5Nwv2eAtlw5nw
/uGpebaB7RaUW1ZnHduT3275zqPcpyq8Fy8ffh/zf1CDz+b6ocH77zqfSOei
tSqwXz/tfcufn/bulf73Au/pK/3OAu/Ly+ec/AI2DfJsVmkdtO+svXzt6csf
3Tch+7/T/Y/mubTJ8/lrWr8Xllc43rUBLdzDqkD+DeJk1LoJ26Y9d/m22xAy
LkL0//CchwX8OSnfh/zdDY5YR+lwQrBHq/1Z2VSelGd/O2uKfY6CfHecVuQz
vXRWhM5Q0Nhb50BM0XhBWEz+t6Ie39dz4Dn2izvdeVn2TSS+fOB3KvLZGPKz
dGPE8Sj4PQrsf0n5L5PtWIn9cugMF9kCy9/He8X2tyG70xOT9tXRXLjIIp9J
Jh2m8Fw/VZvk2X2rMbPG+uSxh/vZoHvk+i3k3b3IZyc0zjj/z+jrbqA9PBF2
+liZ989lo71vxn6lNsoXCzoeHfU5JcKg6Jn8lfSeu+ptL/+bJG2jEC8zT9eU
l87S03MQnlz22sKUCyeu/Y12Ab1f0rIqX0BRPZt/a73Hqb3Ov4Qzj3l/sxPX
phGfEoxDGlUYC6ByVxYbr3KzxorIHxM1LTtTvRNh4i+KjA2QTYXs1zsE+h/W
YF4uMsvQOU3eU4VxitsHk8rYpv6QuEq+BFJul3+UGsfeJmiro9B1EvSqlO1q
Rbckr5a0mYkBvbzY/3VNNtKylRYu6Cd94+BVa8xWaHyA7Ni1tyM7etm8Cxsv
+175qhDvwjynl2+KCdD1Ac5ocp5xR1149pvQ42ye47OyY9VafaHPNxDeSDbX
Ol9BaWV3fJ/2drk+Xn7TkS2K2T+GcEHya3FMlm2xpwT5ryi2vGTeqvMZQ7+m
rZvs/+U7IFZorIZ8Beg5agxZD79V0ucONeLZLaAerxeOTuvZMWM8JP9osfES
spXeWemzb17kmfeJ2zeGbKsPrzee4kfKjVe531+JzLKUy5efqKEN9gXyS4Nt
A3oGdaj66xPoKbyGMB7Ce3Qkz3r5Wa13XyTfAcIaHVpvzMn3afvO+g+nAf/J
lO0eomWWvyDv/+0R9Lxkiz2yyrikecgeI5u1ADOmM5j03Ntn2b+o8Ec/hWy7
LWzRDuiGqNOKP7fKmKjPZW8XYJbke3SB7HO4XsO9Nwry0f8uAX7/V+jG/8PM
Qo/I2Bdros5+WY8OypIdRutAZ2GrjgnoqzOmdbbayIx9EBULO5axH6IZsquS
30lkB1TaZuPYIK18FonWtUiZ60b+FkZGnFb/1W6nBO/I/cXGVkk/+Vv7D2MD
/4UK45r2JW4aYJlkx960yNghvS+timyvr/OVDo0a66Qzok4IsD2ySz+oyBgj
0YurjScTFk7+X9Qurs/Y9uScQOeXqNsD4Tem3Ooynz0inwOHB7jOg9UvR439
aQp9B+1skM7RZbzRrNC4I+FCE+jYImr7+RZBWvGfCjBF4guvNC7PmKVF1W5f
16FPfpFtbTQGEu793mDuOYO22I94F/35FeTdNGJfgs+Sfzb3mEDuPuh7C33O
zUbt8wuXBb885XNLdEaNztfSGSTym9chab9POjOkV9yYQPk0eIa0hxX5HKwW
9T435lzaQFr++5B/njZZk/JZlyXc/03I1GoNXJjSPPv0eJxrZ6RNf4XOX5Dn
rcKFal4a87k8lVzbP+MzLU8hfgLdlxJykZklLGe+/Tn2R49f8+y/cWjU54+o
vM7F7kt2CONX4DOb9P06IeMzlQ6j/NHo9hPl9UT/Oq3/59gPwzWVPt9lNPFH
wvUU+jyVJPd1AbpvSPlcHZ2jpHMoU1X+9rdC/tUCf+Mf5TmtrPdZOt2IX63z
+TgHaT8/47Oo0sRvw1+o9pP2eVLCBO7UdzLjM5t+SxvbKd2E9VxV5/NnfoF/
VKHP/NI7cwrlnhI1tlCYN52RozaayZiWT4wuwXhBB9F1J30N8ffkd3ra54pu
rPH+gPwT6XyvmqhxjutI8luB8Zry57y32Bhj2Tvr/CWdLyOfe5fU+XzU67nf
6eh2S1BvCwp9dpLa3sBg3CS5B+DdX+jn3S1mPLPy1FkTwjv/hv4f61sUt13x
s1XGSH/NO7hbGKiE8dJj0G1y1JjnM7g+O6CHyc9HzLbB90Vsf6081wd4ap1L
safYZUjmUdlDI/+39CTPu0hTp/WBiNuufKGckPb5SR2p17OjtsWM8n+fjOPP
6nzukM5Xktz5WmeO+kysAzJu16cS90W3PkX256I1Np0BKx+JX6PPnZSX1LyX
+x4St5+WWYzfbon4/J2/0z47ah3P6+I6nzd7HXW+BP0XF1r/C6M+c0c667yh
ffTO5PqsLY03laZ7gc9q0jh1Pm23Gff+HnXbpdjnIums2IaM4xPlvy7iteUT
tF4ku7mY/bvpjDOdOScfidOLvMZ1Cv8zwqTpPuu9vqi1Wa3RHpryWpHWSivj
XmuSf4lFxOcicyR0Dvd7RczY+Pnwm+fbTn6evgkR292fiZ4VAV9rZlrTkP+i
2wq8Pqz1ZK1naL1Lvsvy671GdJP2TII1uW5aY8h4TWJ82nvTnXONIXgi4/n7
uLTXKuWTSb6VbqPOa4X9JT6xzuvJE5DJrTcuYBp0lmwiIj4vZzSy6Xzbyb/L
88mPG4ffkPKZNruI53G/c5B/k3JGRd0366yc59QPRd2HT9JzJD5IexnFbtsN
/N+JTD/heLVGk3b9zRd2iHq4Tnhp+NkZn5nzLW1mDfIdYrYd6CP8BjqcST//
Fvw3C93m7xWuOd9nUlxKPiOi7p/HCbOd7/vaUOj3Su/SAGTGRN1um0Vcls4G
mis8XsTnCt0U8fluajP7Jby+pHXSkyL2Eae1DvmOlQ9ZnR1clPJZWutSPldN
Z6XJh2x9xDLy6dNP459o8F0o8HqU1mXrUz77aEfKa/Nqh7Kr17OSDb3s5atK
vb4/UW20zudaNqf+xta7bffSeTW8F02gV/NeXFHoc9ckN0N7SQmfz3Vmoc/i
lN3BjpjfNfmtfbnYZ7epf9dZfzpb80/43ZHvFuDz35ffbfL4U/vLGa+tTU17
f+GqfPsF+KLe6/wjtR+R8HqU2qXWk7rn245ea1Gn5/vMKu1nVNHGjoH+W2Xl
26b+sYzXpq4ln/xir9PqfJaDuZeDgjVinZmi9i9fZyUlXuO9QO27wPsosoXZ
Veg9C7W3GfJTTD63EB9Y4vVk5XNB2mdRdc14D0Rr/jqfqzHX9034uc+N+n3X
Pbau8/7F1WmvscnORWddZRJeX9b7KV8a6g/28ly3BvQ/0GH5tlJbI+4tXwQR
+8Wao/0p+b+kfrcn7FPrySz3x6Jv0/i/yH2x5O9C/k7CC/q+puxn67lyj1PU
/8sX2ewS57USmYsL7INabe8O+MfHzO8iDEGWv6d6b3Qul87k6pYxfX7a57fo
3f0IfpOIfX3dCj2owGcX6uytbTyjH4v9zg8u8lkwovWt0FngS4K+Q32I/EQP
LAr95zBW537J77R01lhL+zf6xkhe53Cpb3kZ+stgHCjf0xo3Kr4P/k5hpIkf
qLRv6kQg37/A58TJL8GoYFz5itY3Mj5/vLPWnos8htN/nW+uch9F5raIfV8r
3+FBnT0NfUGRzz3XN+sR2VtFTVdX+fvXBh2urHOZ0/QdKbRvYo3zfo/Zp5nO
FuxGP/aExvj0Y78KSxCxT/De5H913PLSQX2TfG6fl3Y9fc0zysq4vjdB76++
HfosrpfyTI+O2D9GAXmsDvvcnE4V7lNPpax0lfv2DPFCnYOObg8TnxBzv6S8
dP6OvlNr0e9b6vwFZCr5X1Pl8can8tdLuVXwelDua1x/tdBlCMskv5cn01/d
Q/1vCdtHyd1Fxj7Jf+alRW57Sj+T9Jcg+wf3chPyx0S8N3hF0vtTF6Lzh4V+
J3QvZbIbCPYRdybcJtdp/Srjs+m7kt+KQvfratNXUVY8bp8wfdI+L0vfFPX3
OhNOfX68wbR8dKwKW1Y+OzaRzxthnxG0scLfufYVPv9I35wPkXkHmbcL/W3S
mXSlQbnvBOl0rlBH+DdELaPvkL5HOpPuB+owpW865baN+Vw56X1zvc+qi6HX
n7Ttd5Btpz2alNvgCzo/IOb5g9JfFejzAdd+rfO5dkeRx5Maq8bsW/6AoB3J
n7XmIPIhL9/if/N8F0Tsq+fDwGfPe/BPj/lbLP8+m+GvCft8JZ2TprHNT2q7
tJuW0GfwjEYX2B+Q/p+o+Ui+v9E5GftQuTjt8YT48r1zf8RtVX6BZCcoP10l
2d7n11mIOtdqSoHtCuUbq3/MZwqqn03E3U7kF0j7EsIVKI3sCmRf8A/l76pz
Op3j9m+hfWwprfYuhJ/vobZb4e9RHel2a48m4m/P1QUew+neNwU+h9aj84EZ
6ztItj/lfv6LKu2PR2MPjUv07RH+WT7KZGegb7V8mQkPLf4A0o4ssm2j/Czp
YHTVr2iNC1W38q10VYHHIvLZpDGkfCv9AP8vntfhEfuZ+arC45uOxEO1R1Nk
PTrHPLZRWp2TpbHbV6S9R885SHtN1PyNWhdA/5YR+6IZRrnNA1rjW/liE5ag
qNzPZ1mlz4u8ILhHYRD2539n/u8IxnXyn7Mw47gFz2F3nf3r/MCz+L3Q/nb0
LZavHY0BYsI3Fvm8S/H1HP7zzQN/Ucb0NtnL0J7i2T7jMqvc7/I9sqPM+KzG
vmmPnzSO0rkJu4Lvi9q/5uD5wXetU8xjVKXRNz8c8E8S7kftmvq8vcJz/B/I
/+iYz+vVGQw6fyEayBcyFltQYtvUF6psp/qzfMTFfEan2pLGCucGdSibE7WJ
l2VzUWe/dufwnraudz3/yj2OSNvH3VXEoaCey0jbP2k/Sr3RcVqB5zbyc9eq
zvG55NE0E7wTpJ0c+DhS+06U2J+R9HlA49+IfSSJlm8w4Uw0JtLZo02gD8r4
+jDyeSBjmebynVVi+2L5Xbou8C2m8dWFMZ9pKloYFtkmK69L08b73MXYbFe1
zwv9jr739mqf66Q1c62pC8utdXX57BVG+eZgD1E+ebX3pv1Y+c+V71ztb4se
EGC5hOk6lmf9QtRnDQ4J0gq7pWuvBLjLWdnGdElmerZxxzrncES28ZTvBnxh
xuT7d4b2cGPGS87Mtk/gDwK+zv95L6DPCLDGt2pPs8A4ZPnGPbrc6T7QumKA
A5UOR5a7HPkcvitmnLPkuwT4TPnzbS2f1Mh0r7ZP4C/zfTbfwiLjOeXv+EHh
vYSd0f5ykfHM8o88T+fQkc9O8pgiP8XIDIDXC/17JuxreFGRccaie5cYC7tX
34Yyn5nTHt2uqzK++AZ9f6PGlN6R7f1UnRuo/VXt7et8xuuz7a9Y/AT6HFtu
uXGk3Z9vWLbs7xrsD1nypbX2hahzLMtr7fNRvh/F1/6wzn3UXvBZpZaZAv1J
1Do+KqxAhXHdF1X4/KZN+T43Uxhc4ZV1zpPOatKZTTW1xuNuDdIug/8YcbrW
eNpvg3ayGvq7oA3cWua07VI+o0hnFb1H/FTaedTW2mZJmOMvq4y//T5oDydy
74/rfUW3e2PG7qq8h4TriPgsqD8rjA2+jHhkg8+SWk/8MDKvRHxG1PyYMcOi
X9MZAbwj39CWPosa97s027Yv2wNaOHm1W+1/L4gZ161zpIThFpb7pJTPQdIZ
S69m2+5EtPxX3hY3NnxZts+K2hHQ7cstN11YqmyfmST/la8F9OvZPk9L9S07
BdkWbA7eX+GidXaUzo2aWOU8ZwsLU+IzrlSenpew09JPWO6/gmens6iEfRfu
vWO5y55RZkz330GewlrrnCc9J+G/9wR85anzq4RXfz1iGbXp+2PGV+vZCP8q
HKzwtMLH6mygrdnGlkfD1ufvCttBDNLZywmf6SXs94PC3kRNLynz2U+dqNv+
Gn8K3yA8J3QJ9Ovaz6w0Zv8M+QlUe4j6/xMFPndJ2OvFBba/0HlX6yttH9G5
3DhX4V3VBoXzFd5X505NabCeOnNqUczya4J2qrO11B7ui9lGQ+eQyS4jJ8jn
oZhx7u9A9ymxPYZkhIsPh13nS+gflsSsm86BShE34/neHuz9tA/2wLQXtpZ7
311hjPGj2lPW3Ar6tbR9xMhGXn4BLhTGAPoO0lxW4PGo1t/lO1rzSc1tb6mw
jOawPQjb1K8QPxwzJl/5CqdfGPYzXYyeC2PGbz8SMz5f9a53NRXc7yBhYRLW
ry+6xYhfQrdRCeOf9dyHCQOTcD4XZZz/K2nbDkhe7WpMwuc/CSetc7/0HGQX
o3cpL+x3S89IWG2dQSW6Jmhjz5SZd3rK51VVh+1jVzjtmuCZPon+v0aNt38i
Zsy8ztUSPly+R+V3VD53dT6WzlQW/l4Yc53R/EjS+asc4bp1RpXa5UUlxrTr
rKubAt3zc4z3rgvoSQmfh6VyH48ZDy/5PRW2W23Fu/tkgW0BpM+zlJFHuo20
0+sSPltLcjrXLF9zhFpj/4WJFx5eGHbh2//TlWf5tZ5pWXBOddhnVfcs9z0t
k3/CjPnvpi2r+9VZYF2QeZd4cIX783+C91rnrKn+m1Lu6eV+HveQzzsZ11v3
Gts0NAnbrmFEhW0fzteZdBn7fT2jxtj5w4J6nhfoLFr2ETpD7Efy7VbjehYm
XzYU4kdz7DdZ/pNlJ/AEbXJpkcvQGdnif5D2PpPa+xzq7eIS2wnLr++MhP3P
CvMvbLX8DbfI8VnXonXe9CkaQ2uckDG+W76Im8O/pNxyK8vsY7h12H6GZXcm
38Zl0Gsz9pt7MnlcWO4zxBcTP1NgG2RduzNhf8jCcD9fYFsL+ZFernFFzBj9
0XU+32OTMOMJ+/AV//aEbSFUXhHyK6HzSL+d8ehA9PiJ+PWYbS50Pprw78p7
X/S4N2Ff1sKvy05dZwXq3JAni3ymuerk6grj5fdW+LmcFLQl2UnIB7a+i/MT
9pctXL5kZEcguwudqy1f0/JP3b/EvrJrAjsE2SPI57autwvbH7Vi/Zc/7VsT
9r2ssmW70SFoD7LlUN59UvZJLJx84xxj5UWrfmXT3TKgZRfSPmybkfcz5veQ
30X68J7CXDfinUq6/NVlthNUWW1l903draAeOlH3l5f7fPaXkfmx0vYzsrnY
kvZ5K98SN5d9VcQ+ml8iXX5gVzOk3G3qzTLbynQP24fzoBqX83HGvgGOkD0a
14Yi3w3+A9T5U4F9jeSXJZy/ZJbxjF6I2cbgxQL7mlZZjYM+X3twp1Z4vfCp
Kq/Va91E6/M6O1q05s//1Fvfr9P2BaR9Me0XXFPg/QPR8kUs/mnERwR+TuQj
pTppbJcwYo8kfA6f2tmoCus1uNx2EPKB3TXHbUt1JVsL2a/obBrZsFxZ4+cj
m5Q3uKdoYCMkewzJ6szKj3X2DfQvwh4mbAOjtANr3B7WUYdLEj7zRvYbF9b4
Hd2/3r6s9bxk66T9yi5hn6FyKs81m7I+I+0XEft5PyGwv+gctKtLa9w2ZFci
/+6yGTme/5UZ5yOf3qNpS33RsbiR7TLk2/t0ZPoKy642KL8NGfc3Z9bY77z8
z+sdkA2LfG/3VPvg3hOBzc9gndEi2yvSvSKbvoAfjdhf9aU5tiORH3DZkpyS
Y/7JxENqrOPnGdub9Iffi/9jckyPJT6I9nZ03H6xDy62zYx8Xx9YbJuZwWHb
bMk3+eCg7V0ZtMMmxfaDIR/gKnNAUK5svsSTPZL6IfkvPyvH9mSih0NHaSuR
UvvU0LMdEvQ5eaW2H5NPbdngDA2er84+k8/TpiHb4Mift9qBbKSGQ1+TYzup
4UEdyn/r/sI9VfherwruXXaVsq/kM/LfmVvyZfafHzPqfGTY/xVEy4+YfHzq
zDP5O5QfENn87KDtXVthfZ4t9Vls8t13EDJTi00fHPLZYvIFJ19/b+Tax+sB
0C+W2o/puP+dtxb2GWqrNbctsO/DnwK+/G9KB52vJp+GdUGb0bdue6Cb/H7u
1V5ukI/8Mk4I2zejfONdH7Z/PGEhp4SNnxTWTucDCsOmc3p1XumikH3+TQ4b
o1YU8G8M2Q+mfNHpfO26PPueWxny+SnCtgoHe4PO0yT+rdIYWPGFd9V5KcLe
CXc3LBi7asy6NGGf9bKn0hkfwrkK43pXtc/pFqZuMnlmwVuY8tkVOsMiR+vD
PK94YIs1scQY1hvDPptc+sqX5qQS+2u9Bf60cuNwc+Uru9KYwKnlxnDpbBhh
5CaX+PxF4bROrveZT+W8s53rfa7SyjqftbSCPHYSTynx2YjCkKXrfJbS9xmf
BXlr2GfI/FXv8h+qNv5XmGDhj28oMW5NZ0rJn9btYfvg0tlRwouNazC27o6w
8XW9Az2F2dM5UjpjZnyDz0ARHk++v24uN7YuH/2a8104vMj5C3t4N/GJWfYD
r/Xef6EH6DsQ8d6NzmjRHo1sdXT+zFNh+4jeGuxVihb2UxhTnTXzTEALa3pb
uXlfpIxH1TlxvbKMP9W5b8KgPlzhfdwt5T6vc1HYZ3a+qf0b6ZhlfKpwqrvk
k4R8zijymTSNY8YHnsm1k+XzFP4G2d4R9y70mS/fJHxGnfCr3Qq8Nyo/Lz8E
+k+CfpmyFoZ9jumiUp9LJwyrcK/Sc6zmPlrHJJ6KvjOgh0DPor18mfB+rs4k
1ZxmZ9jzmkXB/Ehn+urc2l3h/z+vV7HsLjW/3xH2mFhY+G1hr8vIt72w+Fpj
ka2EMPf/s3tU3ELj6KCuhLVKZjwW1xhbc0ytOzyhta8C44aEDd6Y8JmnS/Te
lljfs7O8TvBb2GsFLSosP6vc/ti1bhqF/3aF0yWp/70Jn2GgNf2LuO/rCywn
mwDpKRvPfWLGFKm+OhXYR1xHtauY9yn2Bnur2mPdQ57Dtd4fM/ZGZwhob2Zn
sAeh8wXUKc9DPqJ1o0qvXa4NdNM5CUr3u/bmM5b/utrnG2h/7WftVwa09jVO
R+ZV6H/oD/YThhV6d9rnRC0P+6yoHxPGxcyAPpr39DXof4WZl0+tIqfRPqHO
M9Je4c8Jnwn7XNhnACuek2Wcj2S0z9ucfM4S5oAyBxV5b1X57kp4D2t98O48
BN0Pehrv8OHUe2fGDE3LfL7Vpymfr/hA2Oe0pbUeX2Bc10tBG9ZZuruoo3uh
9y/zOzU3bNxDK3ToyLt9Z8b7CPJv/xr8fsJNhY1F09lMy8I+W1H7Y9JN5w38
XGWMx5fo1D7mfWX5M9pBnn1J/26d9+W0P6d1/7Njxp5sDPY1VNYm6Nnyo5Hl
syHvCfYIdstmCF1nqs7IvzTjNSWtPWp++UfY80/Z0wg3I8yMsDMbAzpRY/zF
lLTPO5OM7KfeKLDNks4mHFZmW7HGlDkR3W4vML+Y66UF/kbrO1xSYH/r+o6L
PyhlOzPZm/XUOhV9Q49Sn03Ytt5nDkbrjaEUllK2Url1PnPwBe5jBs95fMwY
pjnQ02K2qxpVZruWA8vtL+tt6mAIz/qPep9duCJjOy7Zc2ktfWSZMZlNyu1r
9lTewaUhn6kqn3rypyf/rPLTiur/+W2V/1b5Cn4moOXH9ZUSy2kZS2eqSl7+
UV+P21+fxgxj6hzLd7i+16fH/R2Xf0Jhf1/Osc9L+b4cGrIfQfkTbBmyTz+d
7dod+to66yn/gRsCefnJXBforLMw3wvSyg/hkhLjLHVu1mlBWcIYb4zZv7N8
C8s/oWj5JVxaZ7lxOnOT+pqb7fXtQwP/PIfI743Gk8X2d3ZA2GcpaYzUpSb0
3wGtmvsvDubd3YP5ps5t0hyzVdh+vrQWIt91u9UH5tj/gOjDgzUAnUOUCui9
Yc/ljgr4mmMcH/aZUhrXay6lOZrGyW2DsjTn1bkksqeSLZXORZevB61dXFzj
M4g0/9IcVnbgmoPIZlznDXULxn3//h9T5x0nRbF98V02T55NM7M7OzOgYgLF
HDDnAIZnzgEFFXPEnH3m9DA99JmziDkgKOaccxZEUDGgmBDD73w5l4+/P+bT
d2qqq6ure7qr7j33nDivtzqsz7NKyevIfnGsJnJaA0s3PO9jkUd5HLmfWT/P
/yyaI/Yajce+xMQT/r5A24l44qm6Vzv0+5/a/tjj+DmxMLABb8Wzmvg/NrnD
5AyTnwxWgHzjd1qcp0wuF/ldB+LvhR9Ix/u4xVgqNEj4P6ND8l4c9+mE88/R
UDk66ZxSbHKaySEnh5lcZ3JWyfck15z84QW56Gz7up1DTDl56I3gM/o5Hxa8
DHrrYGZmBx4H/MdledvgfMC9goUFRw0naEer8fNo8Z5cZ37aXNa6QazD7ukx
9h9eVvC24G6Zy8HJip4mczO06cAVryL7et1j18FbiFaS+jyc52HRHANoFI2J
9RlrNtZ0+azXJ2gFwzXb3mpOXXiR0YZmncP6iX1ZQ+G/aQkbn08z8WPWhXDU
ant6f2tA0T5rov1jLYrvYvtW60rznDw4bY7iYfXGljMmYIPhTN651ZoFlYQ5
OeEe7Z8wt/Mlstdo83wALD1aB9Q/v8HaH9TZo87aH+y7e501RuDJhQv0pMCf
cI99GuMJhvnchOeulJOXjbYiuorkX6AfSU4WOeBoo9fVm1OWa8fzBB5Q6pOf
83rU55rBlYUGernePKBor5NTRC447VTqzQtKHfKUpiXM9X18nTnbczFWcLWi
B7y+7PH6Tw6WPanbmizMq9EKB78IjhFd42V13Y/nPVwwhpr64Kwe67bWz4Au
a9mAE5hab50asAG8W7fosP7MXfCOJ42T/Erfh3RY334FtBaTxuIyf92xzb59
7vnz0sb5M+c/MmX7BtlbBtaXeTj45IGyj6y3LuUisi9kvVFz+QBd/1rF84in
dQ8MS/hYh9SbMzsf9ydaVytF38CF4m/6od5zmGqrNRfBY4LLRMvw6DbjrMB6
jUkZX/Ek9dv9znm70zom3J/6687X2YYbFj78HvhAtD1N/SlVrEEBl+w50Qcw
G4cl3CZzoe9zxstNlL2Rxu1pbW9HszfhMWecp3R7v43JCUq7b+CUDm4zNoN2
Li0YMwYW6MCE7QdUvmvg8cAxgKlG+5J5zxvdwRtftM4O9/ye6ut6GtudWq27
ga8SDcJaPPM3b7WP6Koox0cGVw86ZPjTPmOrz/YN5uShHG2y/XqtN/hdze87
NP96wvf2r1b7XeCvGt7qmPLFkRe/vez+GeOry7InlYxVeKLbXB7YYBXQlwIn
NIiYQZtzxreTvWOH9cQe1jlekDD2u5e1j/bv0fbOojWOwHbCAYJW4BpRB43p
DaMdtKjRzprTa54uNJ03IZ6SNaZqis5jnzbjLnluX1KwvV6Hcz7QPQWndWPe
HDdoY++vfUcHtvMMPQcf533YZ4wiNuvfORnrlFEHvi7GhzjsuLwxghw3k7Xe
Nj525oRogJFfDD58I54DrLMq5rb5Tf3ft9dzDfz24PGov3es+9A2ox78u2iQ
EcevL7rtlUvO0aeceeGmReOe4am7r802+OdniNXx/ixaZwGef7Qe4EeH/xfu
X/Q74FpfrWKdDnjOT8AvlHB9dALeJW6u7YV6/uTRtdXvP7RbFwK+97v1WyVr
rYGH66whgJYA+bNTK25z1Yq1LXaI/2a37B1ln8t9W7WN5lFvwvc8/PwPplwf
fn60ltAeGMgzJGf9ALQDjsm5HD2C17qtg3RPt3WOqLNonbVW6A8chT3RZ3J+
Byes74Dew1PaZ2WN1UvBS4p+IdqFcFJtHf8j/KLo/R3dYC4NdJTJmWrqdY7+
nRVrvcHVsEo/56STAwD+f3jY5Kd/kDKH/M0N1l7BvrLO3Mxw2t/SYD5m7Kvq
rP/CNYK3ORHXDn77N1PmYoOzDV78Ea3WhUEHBxte/d6s+d/GqfytbnPwn1Ew
Rxz7wuF2hb6fyrNe1/e+quf86KseHbhB8IRgKcmpeYd3t9qZqHb+2+W8QHIG
yQ0kZ51ccnLryLUj5471Anne5IeTx02+NTnh5HAvFuVwti8f7TzW4Nxu6pBr
DQ86udnk/ZLDTX4subHkqePHI1d95TgW+YZo457V6rynhau2n+y1v436LzQ4
d5BcRHIJF+p0Th65hkOjHC7XNeNY5JF/3O08xuu7jOUkl4f4yFLRN3jayb0j
5478uwFZ56j21jtfkzxb8hd3DpucwFTksTK/YA7CXASOcXIIyStE63ahrMuZ
n3zWHVrS2i6c9VyEech2MeZo8h4T+5IzeFz0B13dZTs9RyPXEN8fPkY065l7
YjP/HNTp3MA884hua8SjFY8mxb9V575ea8XDNQ/P/EVhr15v/WTqoKEM1pH3
Ou90MOrjWo3bx/fCuG0Ofq3i/KMNtN240+9AfAAb6/uFrc6H2qrT70lwf8w1
zm/1fIOcu7NlP6P+PKPjniP7pibPNbCZ26D1TJ1fudfTzqH7u8GYcXDbYG3f
i3wTdB63b7deJLgu4pvEf4mBPpB0HJZYDzhEcIpgC8HC49/Bt0NeFH3GF4S/
h3LypJqjPnmFX4LP1HZswdh7xoT/Ef42+oaPbt1Oz/2YA4KBv6zVuYr4Ucjl
wZfCHAR/CvOQb7qt7fnfgjGW1Nmq4rkM+zIP2bbTcxjmMmCYyQUDrwweG3s4
mNmKx5acLOZiXDvigOBrwdmCewXjD7Yf3H4q7K5Gz30YT+Zmy0V9nhX4e+gn
WFbmoWBlme8dlTBelnwr5l/YzKXAwlKHvB5ygfvarK1ALhDXiDw7cDDgYeAm
3SjwkRvGvAObucfZCeOV0TSZlHeeGDlirA/wJ7JG2EdjktB2F/CqeeNC0S5h
zQueOce7OfDGYKPBKVMObxo4Z9oHa8v6kzUpfGhgPMF8ksvGvAabeQtcXeSr
rBo4UzC7YE2Z41A+sJ/zcsjPgfvriLDBpcI3c2e8R+AmIwdtw0ZjUWmHvCyw
rPQTLO6YTvu94OIi9weOoK97rXH9QKs5YPB54RODwwfeWsrhwIGXh/qbq87s
butfvVD03I36zLvggL2/1fwtP3abD/XZbnPB0TdyCuC/hTOnqWw8JphJcJbg
OsF3gv2EH4c68OuCuwSTCfby9agPl+wpneY+ggMJ3By4z5GBA6UdcIBvxr77
BN6TOmD8zs/4/wvH+1mdxliCtQQD9mqreUHBEj7WamwpfJ7Y4AaZ0zG3O6LR
GDhs5ng7qc6jrcYrwvk5pdUYRXCF2GBO4fwEH1gtG0cInhDOTzCClB/aaAwd
2DtwcGDVwJWBmwEvA84T3Ndv3cbMbdptTCXlxwS2jn3BO4Ep478ArgxcGu0c
12j/N/f5+oE1A1t2fODUsIlN/NJtLOBa3eY1pZ+VsvFXL7aal7WnZm7Vvcm3
6jSmCGwRmCzqgMs6NmOsEryU87rN4boVOIiauXBHVYwBo52v+xm3xvgTFwFr
Rx1wO9d3Gg8FXu+vbnNhfqR775yM+ZrB/pyeMcbp/EZjsbBbG4yZog9gpcAE
gccCBzIha2xVS4MxP+CB8Kc9kLANt+p9ncangN8cHPuCh4InifscPWC4Zypt
nrcwh+G5BKYBnAg4kssDV4KNDxFsCBgRcC5oTKETyrx0oygHz/FIp2P3r+i4
V2bMNwrX6OSksT3E5hvBp6rsYI3HtRmXw616Q8aYCXgjiXWCDyCu3Vww/ucl
sENZr/2Yr4IDmY+xkJ3Oer0DD+aDYRN/n5BxO/BkPt7p+Dl4insy5veE2/OJ
TvuE3u2wpgyadvh2Ho1zXKTOepSUr1NnLRf0TJm3o03Hmpw5fyFh/S3m9ujA
fsE92WktPuoT/0ZD9stok3U8++K7zsa+lKNnSh3WDmir0g7rAjQtZ4VNH9DR
Q1Mml7DmJeVvdtrntHPR12hW9OeAinVX0V/NtlqbdrE6645+H/1Hd4xyNGno
2+won5yyjR7NKXDqyn5DxykmrFnDmMzstL7b2ZpT9SSsmYtPDH3Pn1rt71ok
YY2qqxqs4fhblH8Y9elfOWGNHOzTC973vdC3ZV80O59IuQ5+s/c77X85rssa
WL9F++gqwhkNX/S6ZZdNI6cwYW0sjvsxmnEq30NjtXDC+o/4uNCtQmsDf92n
ndbnOqXL68pUm9csiyfcPusNeKf/in3f7fR5n1awziPl01U2KGGdSuq/mrIm
F+vQLzq9HhpZtI4fOowP1FmPEi7r+W2mbLOeYg2Fzs0CnU9s1k3dOlZjm3mq
Nyl7zYfWHzzWHJd1EHp/tM9v6GOi78a6aVjZ62B089B7REuRNTC82c1t5r+e
XrGNpt63CfNv0yb6m21ho7XHvrR1V9Xtb07bVdcZXjYvCs8ctGtHV/7Rjawn
74V3eNHaV/BlsZbHlwnPC77o71IuZ20GNxU8WqyzwPqiXwUuCy0wNBTB/aJr
mYnxRNsqG3XuLdguFqyzCWcXmDF0ofCf4jtlvYZe6Wt1oaHV5rX/QerfwDZz
jqGNi82ai36yL+s7NMfg2MI/sFTY8GzN6fRaahzxwZx1JR+NfbvjuPChwWXD
Wm9WyjwSrB9Xjn4+FOvHapu5uc4kv7LNPDZwy1CO7vBvneaNukHH2rnsdeo9
VfPZUB8Nr18S5q3g3OG3Qbdrl7J5zMpRjrZmPu6HSsHrYLhz0AiGr+15tTO6
7DGYUbEuWCnGAY2zYthwyqFBuZ/q/pEw5w5tVbPm6+H6jipbV/n+qvniaB9O
tn3LPs4DVWvL8h9EF/LMiv3ZxCIWLZiXCB4j1oxwyr3UYB/2oDb7sc8q2O7X
ZQ6cwdH+qlGfMWftDJcNa2b0fLkWrD3h+IGfiDX1DlGHNS+8S/AvvdVg/jba
RKPqaN0ny7aZAwetLnj03mswVxU8O3DsLFQwfx08dmiQwU/HujiVdH1+Q/M0
HffwoNiXdtDeWjbqw8/DvvgKHtEYrdL2Dx8XfQPvBJ8PnDsL1s7w6qDtBU8V
fGVwVc2smAfs3IrjGMQzZkYd2mTNfILsFdocG0HbbsU28//AwYP9SYM1uagD
D89OMW7wSF1Y8fGfQte0ye0TK9ko4T7QPhph9O2kijXC6DO6ZkuTCyn7ywZr
w60me4bsDdLuM2v204ouX5xYgMpXj/6fXzEf0ZM67t6av93Xav/k6aq/FmNS
sA7gWtH+Mvo+TPYQbdfU2G4qey38IXzX9uUu+wfgoFmt3nwy1GE9fofKN4zy
y3XcHbR9VMccnjCvzk8N5jQYLnuu7LEVx5oW66urG5F2m/h2Tij/w5XCmhTc
EvEL+HtGt5nD5+2C7dXBGRV83FTXPznq8BqBdWJf1rPEPQ6IduAxgc8Ezr0d
E7YTjeYOIk8frhU0IteR/VWDObjgMSKu97X23SH2fTVs+npy2nEUYijHl83p
AgcM8ZPtow7xFjhWiLm8oj5v0+bYzZUVY5fQqjq6bG6lNbTvFtGHjYnRqJ/b
tdmfAmcM3DHEfnZVnfVl/9Bg/r0N4n6+ucl9ppzjcix4XS6tGFf1go61nI69
WZvxKLWkrwvHmhHtcw5fNLnP7Ptwk/krfm/wtSCfmVxmcvkPlH1TvfkS4E3A
JwJnwijZl4ZfBa4B/CdDNf+8RfYWsndKuD55KPD87NFmjqDri87xX7Vg3qDd
o/yaqMOxLpG9S+xLvIX24TEYH/wA8OE8XDEPcFPNeRPogrGmWKhm+5myfTt7
tdnPAwcMXMnwwOD/2Sv6PC7KiUFTPiKuBccd0faPX2i/uD/PV793ll3UPXli
2ffXJ1VzQZDvf5/2PaNsbiU4li5X/UPbnG8OFwKcCPA3TM853xyuKviPDmoz
NxD8BpRPqDeXxb7RJvxdXAv4sMA10Qd44E8tez+4hdYquB04ulcpeGxX5v3W
ZN4fOH/gnMTGfzUy6/7AzwBf0248b1XnPwVf3x6d445Zl59Z75jMPnEPcD9g
E68h5wWdNdZuV8W9xP12dNrxSP4Xm6jNk9scg8OPREwRnxJ52dj4muCQOSHK
xySci01+//k6x4W0/QkuyoL9YeTxw5NATj28CuQek4NMvUzY+L7I/yd3Gw6B
zYITgP3vqpiXF175HdTmtSof3GWOlGvaHBcYEvvSH+IGlG/Q6Nz8C9rsNyNH
m7xrcq4PTTgPHL/fM2nzCMAhAOcJnODrNZr/A06QGr4OnVcF/42OtXfSXAC0
ie4wucBLh98MG1/ZhWWXoUV8sz7ntVmDGC1g+BAG67d/FeyfI+YJ9wAxAvgH
PolYAHXaog/4RbkWZ8f4b1lwO1vAqZl0HBc/Ifw/Y6LPHxdsk9M9p+J90URe
v+C6cIfAe3RyXDv8jbQDP8SlZesRz9clbva1wx86Wn3bIp4/C8VYwXO+XcF+
O3LlD4kccPxm5F1jw2lDXva4KIejhrxpfHfXlu1vgw8JvuUrec6ozt+6hy5p
Mz/Sz8R+2qybsHXBPstxBXMqUA7+8MSs2wTLSJ44MU78hPDE/kv20TyTC7Y7
uvxM5p6H/yeVMWcO/YEHhOcD1xvOoiPCBtuITXyT2Cntw4VFPvjlcd3hWYCr
AT4c8vu539B7JhednHS0H+BTujmevQ9WzM/9Z8XcPnDH4yeE0/umGNtBJdeH
732sjnVdm32V54NPDBv+K8rRXDgs+sD12DKOy5jDYY+OwwLerRti36vL9un+
WjXvBHwRuTgXbH5D34H6G/UzLzbXES6jnyr+f6FnDacE124JjW1dzce6X7/f
W7HGBFoT5J1912a9SPIKsfF/kbP2bZs1XIjlEtOF7+uRivnk4ZWHA5yYN/7S
5xLGAeJLheef+sR/ZxXM4b8z6yPyYuI9grYFfFMb9DOX2B3RPjxU6FJsFb4p
4rvEdnctOLZLjHdyxXFj+NrhPiffHP7zd8Per9ExYfbFr/VYxKCJRcMHg5YH
/ls0sLC3aTSvPPzyaGxdHDY88yvoWj/VZl56OCPpGzFQfMWcO35deL/hdue+
QcMLGx0xOPPh1odPn3j+gzFW833CbdZEg6cbzvDdGs1/9nC0g/7XI1G+rPow
sc28/VcmPG6MD/pftL97o3m+yd+Hmx1Od3Kwyb++OmH+ffzL6JHBQbBvozXL
Jse+q3TZ37ySxnZEwXzwQ7rti6YdfNRvRvvsC7cA7eDHhm/8kRh//MnkbOND
RguLPGpyqG8EZxrXBZ82ue7kuX8RNn7p1bvsV15bx328Yj4BeAXgB0BXYL4G
QcLXgnaerNjX/VfF2lLUGa3yPWU/12bNsltV/5U2+6LxS5PDjt7VPgX76eFF
ILf95TgX9L7Xln1xxTwKr0Y5fm/y6vFvo6X1crT5RpTjh3+24jz7rQc4H5r8
bXLEd817TI6U/XTFGJMO/Refrzg3GtE0xg1eA36bG+OGTxw9rtfbrMkFZwB5
5uSYk0tPTj1+e3TT3gz7wyhnXNBZeyvKd4g89/tVvrvG59kYK/T1yOFf4DP/
KGxiT+Rr42OfF8fFJz+34P7A4XBtwfXJgf0m6sMtcFDBee1wD6zT5fjVsG77
5zkW5zw+4Xx2joUm4MS4z/H5M27kvJNDT84z/v/DC44bkHeLlhS5yuQpn5Rx
jjB+8jEZ5ynje7874dx2/N77ZZyvTazhobK10tBMIwZB/jZ5u+RYY5+m3zbs
snbwB5prD+9yG9cXnKNMfj7+evLhfmtznPSGgu0dupynR74e+kqHR9++UvuT
Es41xcdNTIG8aGIAfWETUyA3nPaJNfTGOcINQB4fOWDkf5H7T145cZAJCefs
E1Mgf/bH6A8+eXJE8bGTz0tuKn7//4WNX52841k837rMPcBzntzwhqrnos+W
zQnwTbR/VsY2uct3JdwHxnFIHIsYxGWRt7tMg3ORv4594SGAo4Drh27dtNiX
/F7qo2tGTjf9IcbxXNlxhn5V570ybsSmiTtwjvz2IP7hqP9UjA/6U+TSMf7g
PMGwtMa1QM/rrzbnRY5osY3/f6D+h3+3Oed0VIvxoPj9yR0lhxSNKnIc58a1
ow+/xzgPDxucMnnK1CGW8UbFWGnyHcGW0ia5iZMTzq/EJneRHEZiDY9rWx/l
45r8/GF9jSZXY8J5i3tHfWIfi9Zcn1zIKQn3n3bgBuD/Qlzqg4r7Qu7jlnEu
xETIRf2D906X8zKxyc0kz5D8XPDVz2WcW4i2F3llqbCJORBXIKZwd9QhdkL+
NbmO5DlODBudO3JgGf/tYzxpHy28/XXsJ/kfqC8nFJyDQH4isQ5iHsQowO41
RX3yebHpP/mdjMmERuc4pmJMjis4V/RYbU/LOwcSnbjp0SYxFMY8E+XkkKZj
XzjCwPwwl8Y3io8Ufv5a2po97zRYPwK+a/xpzM1ZXzE/J55PjB8+LNZG2Kx3
wKiCVV062gZXxJy9X7frwpEFdoBy1izgKMlReSqwBOwL5gEcJXjKSuAFWO99
FXUOj/aZFzMnZj4MDnMv2T90GfeHzdyYNSL7Don6rLcbYw0Bzynnvm+Us14G
t8E6lTUs+Tv0ATwnfBhwZ8ANCO4CLCmYB9ZqcP7O56Frsi4Da+RT09ZyGN9k
bQfyd9B3IIcHe0KT+XSpf3eT89XIW5vYZP8ZuBZ8aGBbsO9R+UdNroNvCGwp
uTngZvDx4FO7vcnnwvofXkrWbazxWLuRw0N9+ApZNzJm4HPYFz8RHNdnRX34
8eDwYm18Q8VjflhcIzgy94j2waGwdmXdemKcL34wOAz3jPEEq8m4wTdCTGkx
2b802iauQ0yHeM6iUU5civgUGEJiNcSWiBNhE18htvJnlBPPAd/G78SVwL4t
kbDmKfExYmxzGh0HG5hwu8ToqrKnNzo3t4t5kuyTC7bJySV/l5ze5xsdq+G4
6KcShwTLSCzym1bHOIknfh32O43Gs1ei/R2jPuXfljwm33e5b7XoD7E+cPPE
ycDpjE7YzwAWFUwq/JXgx7HBprKGZl3dFv87fB/4KuBbhHfx3P72Pewf/8cj
4j/SGGt39mU9vmscd0ajsVJwwcCLAW55VMIca8eqrzP1ey5ij8QLiRX+Fv3/
otH8MewLzoo2F4pzASO/cFzfGWVfh4Mq9m1zv+GT/KbiPMsDBnjMwdODpd8o
7mf8w9yfG4eNnhq6aKyZjur0+umgDuuQoWuGn2TNqrE2/Xq9vgGzsnHUoz5r
MTAslMPzPLTq/JXfe8wlSzurw02bNX8sfNPd5BHLXpf1eMY8s6ypyZsBS8T6
FNwQNnk08NzCoQePLuvfw6M+eCJwRaxlyX0cnXT+Ixx02HASwpF4WLTJupn6
rJ3B/oABwodBTgy5MfgTqhlrC7KOrpWcXzlN57hnp9vetsOc6/Cbw20Oxzk2
eZSj+8yJuKbeqyX8Jknjs+FFJK+P/zV1t4r6h1VdZ8mq+fDg+IUTb2ra/Oo8
Z+YE9yD+mpkFc83t2WG9N+qT97Ny1eOahMM/7fbhlxij7VH6rMS6A44Jbb8s
GEPO+c7PCcq6ffxmJwdXITaYQPIQwAfi42Gs8DMc1GesVlPF9/Wu8czk/oZL
kDxO8jqxx9Xb94wPGt51cibgRSJniOftrlEfHybl+Jk/zzj/Fs2bXWJfyr9V
+Q6yZ4b/Gz533is8P3ePZyPPeeIlcO9vEjbPfP4jG8UzmVgEMQniDEekfY7k
WTzY5Jxb8m2JT2H/V2XLJd0f3kHsC1c7vuYTss7LJSeXd862UQefLvbbMW74
y/CpZNudq4U2Z2fGPNFwROcy5nCezxGdN+/n1uGDOSTGnNxhyvGbwbV8QBwX
jkTs69Ak1XNqOnMObb8o2E9G7u9PwRENbu/igseQXNEvIr8bnaOnErbBUGYy
5jokV3jtPscqrta1/ppncMK4Ap5XYCx+brQf7OC4Z9D5hd+GdQHvSrQEwGqS
08Oz6AXWMnDCaZtWH17mXZEwB8XtKdvq7vwPvwFNmKl7fQltH2r39uWovwzY
BeYh4OnRHtP2OdX5hPenPgcE1uJj2Vez3qnzb5TfjC9On5cSzqV6MWGsOzlT
b8teD0xO2JfG+whsDXM/MC/g6Zm78q55K2E8Cf14NeF+sX0t7CejfXAzHfGb
ujmfkwJuitf1+1RtP0sYf8J2arxnaf/DeKf8HDbH+kLbjxLGkHAtPoj3yLbR
N+a97Vlrn2v45+umY8PVASaXNR7rDtZV4LpYl04o+Ngfdfqd+0G8j1p1j21O
fLvX79mp0c+7eIfhy+k2DmVavJuYD4BnAnuxeYz5ZsDuqr5etDM3rsuedcY9
vR/v9ydTPi9wM/BYwTU1puA8BvIfwCV1Zj1ulTrnrZ+YMC8o+D3y3MCpHtJn
HB+8tviY0aXgWc1cmvrMh3m/4A/lvYAPFf81/zU0BuB0v69inyg+WfyoPCt5
T6C/CWcPPD48Y8eFvxoOH/zBpyfsE4ZDlRx/+GMHlGxfqTpN3da/GF7wcc9I
2G9MbOHkhOMK2Pid8TmTt8d5bRDPBPqJv/n7GBMwVPir6RvvL/I9yaMA+wp2
lxw/eLNp57wYH3zb+NAXYG/PiX3JPT036sDxB+fcixWvs1lvww34ZfwXmIP9
Hs8B7j2wu7xXwPTyXgZPDPdxfdbv9W3D34lPFl2AXyv/aISS83FRjO2pUZ/r
Mj7q45/E/31+XAveXRf8vz5zXruHP5trCu4YjBTzJvBd+ANY57PGZ93/cMJr
f3ImwJSAIcFGwwncCDgm8EzgesjjIZ+nS/bXFWMrnuhxrgC4BzAHb2XMVXJI
5BCAnwA7Ab6AOuQlwCkCtwg6X+TN0D5YKY4FlggMBvgmcE7dTcbIgJVB7w9e
KDA64HMyUX9B36gPJop9wdOApcmHTTsXdBl39U636ywV9cH7rBzt9yTdN+Lv
X+oc+2s7scfPH/B2PK957pFfxPyceXgp4Xk76wjwZ8znd4o6YAl/iHk7WEee
XWDv3o/5fF/cMz+FzX8fvAnjRh4GulJrxBiSM4ruMPka6B1jo0cMDohrRw4N
ZWtFnWVi320DO7NawvgZ8EPgiMAIob01NGG8Ehir1RP/5MRgvxD3Cc9JeORy
cS3ALF3RZe0ddJnx0+CvgfeNewzfE1yC+Ph4puITw494X5Tjf5oU9cldQKOI
3IpUxXzy8B7wHuZ9PCEw8k/Hf5n/BzbPITC898b9jN8O/xr+MfC5PM8XiWOh
y46vCQws/cSP803UhwMTXsb7E+ZIxEfGf+LZ4OOaFPvin8NPlw8/HP5QeD7J
nWCtT94TOHc4I4hHkIv3bMLnA//6MQnHP/FdEK/FR3FB2PhL8Dnhe8IvBW5u
xbjPwXaB8QI3B+/aCjH+XAvshQNPt3z8f8lzpA9Tw/eGLww/GL4u2h8fNv4a
fDX4vSZHnXSU49epj33x4cEP92jCfADo0M/XoyfuU3A5PHL4k/ArLfDzYeNf
goN8h5jzoxfBXGj1WGMS/8Z3g/8AThDmz3B3owlBrJycEWx0Z9jyG74DNCfW
j7k97a0f8yvWueSosG5FwwEOffjzwS9gg2HguNRhLUwcmLjy4qqzes38JIvD
2511fjK5QuQNYaNZAT4EfSmwB8M7zLlCbHpOlM/XnOKZkzQWhVzqNWRPB//T
6frsx3HQDMAf8r+0NTDRxYQnAN0EeANY0+PvIE77XsacOKxBni2YFwc+oSO1
74Aofydjeyv9tk7W9am3T9paL+i8nKzvVdmn1Fv7hXIwV+tmzYUEXueJtPtQ
12x9sP5Ja9yAoQC7A44Cfxd9Y63xofrTT3Xn6f4/EB22pDEGw6M+WB7WDawf
wH08XTCXFJxSrxe8HkLjae2sj0X/18q6n3DWgC3iucwzGS4mxor5eUlzieWT
znPn2TcvYXzjVXpef67t8Zr/z1XZ7wnzfIG7/y1h7H1n1Xq8x5O/ov1/TVh/
Fl1a2tmn7PfOL/FfS8r+IeH8St47P8Z7qr3qY+ThaNc+T2ic7pX9vcq+Shj3
C4aXPEn8S+RKYjc0WU9+bvQNPxX4ZuaNaNfOThgHy3yScvxOYCTBrYK7TFed
N5uoep3F2LLmSkffeCZ8l7AmLvmR4HnQQAHLhA4KNhidhpTvT/K70KNYLek8
9C07jW9aR/fq+wXjcW4oWo+M/xVYIvgGGP/vWbNm/f/iN965c+L9+x7PB+37
bsHrYHj2WQuD8/05zhGtR/I8j6wYd0yfwSTTl6HRH8aD+uCRh2at98k9dH2T
9eZma9zfwf/L/63DOnTFKH9d5zgjYfw373buJTBr5C3CnfFjYBH7sx7oNj4Q
PiIwhviK8Bnh/zyqbL6rnfAxwOEvexfZ52jfG/G5ouuLJgFzE20f7zEv3Im6
D9/U9+9VnkSzUftuqfIXeoynoy9g51KaJyf1+UD3+Hnwnqn8GdU/uclcFfBU
gP8E+wl/yJFgEbQ9XX24U2111Vtr9bEe88OhCXsufCWsa7vMHcV4MSZTeswV
h64rWFNwpuR2ggEkXkKsBNwo+FGwnUOKxgzP6zReGO1msMJLdpqHL8faVHYL
95fsG9X+rDprVV8pe1qd/yP/67HWMrq3H+k6fpg1z8bLGefWoic9SON5Bc8E
9fmnorn3ztR5PFiwxi58fYeVzW2yOD6YNueOzlJ/dtG13jnlHNJrdKwZYMw1
/keUrc31HGNTsD7nY2h4lc0V8azKDywaUwyPH/hfdDvBAMMFx31CfivzWOaw
YGXR0ATjC74XbOaSSfuo/522tvLdgW0ckjR+8tWC/SWXdVt/a2A8bzfImv8N
POcSSbcD3vPZqANu5/mCdR0v7jbOc7Go/1LBuarwycEzB98cfgxws+WkMa7E
BOD5IkawRtbl5Nvi14LLAy09OPB4/t/SZB4v+s/9zXtsmXiXwZlH+3DZbZP1
vhx7WM6aoztq3H8rum9Tu3weS8SYTNL4LqTtiroWK+o+WVd2f+4Z1n465kuq
f1zN3H7HaztM7X2hfcc2WZMWrptpOper9f/4nz6ZtLWL0WdFm/W5LnPiwE/4
oe6lxZPGBE9Q3/qnvR6ZKPvtjHOXl9e741J8j8TAm1yfeMo9eff5pSZjntdP
W6+Z3F60Cp4Dm9Blnd+Hu4wR2y/td9x6vDfT1h3GzwaeG6w163j8FL82Ot8F
G38FOSY8l8grOVrjsqXaO3KA+pw0Tzcc3cS6sYl33889lTSmEU50OMSZSzOH
xtdEPJc5NuXE6+fPjZOe0zK/xWaeDJc7xxjW5bYnRPvwxsPDDgf7483WjwAf
8kHYYD9+KZif77QOx/+pDwbg6qS1NObnabYZ/wE2BCwH5WA89sn4GOABKGOf
WYEHoT6YEPi07pRdz3y+n+1p2i6TsbYUuKwNwgZfdEWz9RTBPoGjQW/jiFgv
n5m0X34v3U9nJ60/BU7p7Nj3G53Lucwr0IkNXjV0qhi/W2MMpzRbjwOcD3N+
cg5ZXxyZcR0wEvDSw9EPfmB0xjZYh/di3/mYkKTrsXYgZ5F2WDuwprg99oW/
HE5+chs7wwYbAIcH/QRrBQ4F7QewKORrkv+JLwJ9FnRb8HWi4wJGc9mqsZB7
JB3f/DbtOvhV2LIPei7o96Djc0vFuMIR0Q45zfAzws1InjN+U/w2R/Q5ZxoN
GdrePdr/Iu15/lKN1hZDY4y8b3SmsMHEEj9Cu+jFWPuAMWUdxO/UI56L3hc6
kmh+rRo2+fXksBM7GBQx1i2iTXQQ0OEAJwOX126yG8G2JW039LNGB3XAzbBl
nwV4nOtj370z1pAAn3Nj0jaYG/jO4N+7sNll/FYf+AvGHwwG/4Ob47+wFDwk
sgdr+1LKvmJyytap2u+9NuuLpOv06+ct3+G1acvYphzsHMcFLzey0+exU4fP
adc4x5213SXq8xt12omHV11niLatcW/f3GzMOf+X1fs5Xxu9S/CZZ8Y8imfp
Wp3WvFyKeZT27Ur6HUk+CT4ecFwrp60lz5zmoXge8lxcNety2hlSszb6gGrk
2ST93m3RvumkOSXINelMes7B+xa9bN65+CvQXCenhu3fCdsbNtmG72JKwToV
OT3Lu6rmybgPrWy130/7fK46pap9IQ+qfOton1ykQtV8GA/0uD2OQY5RpWre
kVt7/MEmRyal8oJ+b4t8u+9jbs9c9buYrxLP/Tbm+d0x/yanjOtPzKC5yWuI
WbGO2KvoNcIsjfe+Rc9xf+z02KDJzdwiWbW/7ZCKfWXfJOzvatDvuaTfTZwb
50g+0UTVz6q8Bv9K2Zw6d1b9bsrGmCwW6wjysJbS8Xq0b1eHuXiYs5OvR94k
fSbGcXjRx2vR9b1Nn02Zq6tsf22bkvZBzSFHRvfU9WigtPvdCvfkjrqfx8re
g2d10s9nMI+X8wxLGhPJlu/k7oOx5DvYSOpeEc/z4Rnb5On/oGPtq7KjO4wV
BS8L9vPShHk58XuggXuK7HW1vajZNnyfG+j7qbLX1/ZbtTNc7TThk066HCzs
hSl/x6YMG6xsV6/9T/Mq1grlvwNueeM4R94dD0Z/8P+gjf6fpHG9kwrmr4bH
uqJr0ZL0OC6a9RhW8elVvX2ox7kC+DrwgbRpm0iaC3qg9m3l/6h9F0n7N7A0
/I6Nv7Ks8uakc7UWy/pYtXo/d4fFsxcsLfjaBThZbPCxaBFfmHQey+SwwbJO
07EvStpP/Viz7auarYVIm3BusOUY4GFO0311CnHUDmPG8eHzrmHuDOaH+TPl
4ONXDZ828YWzms3Lm0uZmzebsj1EdW6u+ftX5Jd1+nkJH1hP0XGGEjo85HKm
rCH3c9X2LNXvp7nfUaETOa3Hfhmez51wMKYcT+Q42TguazzWelN6rRcA1yH4
N/gOsdG5QBsD7QxwWejRfy171Xr/zj7gFsmJJ8d+AeYLG5/bdPXlmLS16sHW
PZP8B1/3VNL4rp9z7u+88CG1pLxOb+i1htvpeg8vpHNej2tSdOygojqrgoFM
2SaOgK5uNWXceK+2PSnnmfQvOu5a03aA5p/vae6b0bav6DhMWdtdOj1W8ALS
Xl+0v2jJetM7aduWshYp2p3oSvP99XqXYZOz0J1xffDxi7dbszOp79/2WFMR
/Tj4lRNRH43gnriO+A/Rp0bf8Hyeh7K/037NJY/Vkd3m/udawEWAjxceBHyU
YN7QsMAPCWEtWht/F8xXC+cs3H/oSFDnrkZrasCLCmYPblRs8Irg7KYsKNcY
Paqx+rvm3ynH53lxtLkiOBN8hUnnw45vMN8uXLsv5W3fQ3wzaV5a8pE3q5rv
9txec95Sfq7OcUCT61GHMuz7G8zxRPusnbfmnk76/QfXAhoP+G/Ri3lEdgkM
YdI22jH3EodNWqvicfVnij4v6PuhDd4eFtsXw4YbFI5QtAvg+oXzV0NY90hw
h57WYE4HMJ5gBeEthb8U3YbHtX0ijvVw8JqOkj2q1315sWycLxxJ83G/eXPj
gl99KGkb3OesDl8r+Bop4zewrgvOrdjgazIxzpFzejyO+5Du4RVZQzOHLfoZ
eZS23SnfS9l+3vIdLcNrdV8tlHYd1o+Lyl5D+9zVZJvcVOYqi6XtL3g9Yw7/
+WvCHj9rl9G9MalqmzI0CtAq4JnPthL2gfEd/YKJ4ALxARd8fJ71POfBDrP2
Y923c95abicQU1H/xsoe2mUu/xXT5vPnPcC7gbaW0JgvnPa753btu3h8x6YO
747Pkz4exyJ39Y+keTt5b9BP+vhmxnoE1H9AY7J82j4W1uArpO2rwu+yXJTD
Y4Y9uN6+GerDadbX57jWReTLwJOZtq+pI+ncY/KCmSMukfY8kGNzXMbx/vAz
MG88scn+F3wv83+PvoEtrUWfuR7949rdl3N9+nBpi68d8cv5OeLpf67n4lGO
L2PZ6P8UXcdBPNd1HY/J+p3B++Iv9fnPpLlVD6h63PbX9r/a79ekuVivSFuf
F4wiGqXYV8g+VffHz8wNqtZ5n81/vNf+RPwuT/X6fvsm6f6frna+Tfq3RTv8
bsrjU0x6X/LUVu0wD+t3Kl+n0z4neFuzGWuvw1NchNs7Ze5NeJu74/4/IW3t
avJSiaEXo86hVT97D6l6P8rJBWvVM3CO6u+p8glwVybti7wp7TGBA393/bZP
vc/r9JrHZGTVvzN28OXDa/Zb0rm98NT+FeNZaLdv+hnZ+2mf31W+b9X2XJ5v
2n6VsX16jP88njlV52JTn/zrxTvsU+rWf/pO9blRbR6kOo+k3T7vUzRk/05a
U5bzbVL5wcwdir5WpS7rrbMvPvF+8IqkrDP+I2SxKeN40e7Gph3yPftFHepi
z88T13GXTDtPHl/R9JgzkKP6pexNZO/Ra7z/uKr5vYekzO85s2j7RZ3TFxrz
ZeA3V/nIXj/f6nR+j3WauxsO7yXQKZe9V5ePwxxl1fAXc60ehbs65ecJuUWL
aP/pardT2/+pbKWUn/+Diuaq/BfvT53vyinr7JADsErK/Ja8R1ZI+dhPop8h
+xjWd9quxXMWnJL+g6un5oce6wYXXbajtmunXA+eebim0QyCp3rDovGW98FV
ojZPTTm/cjPWqynPyeE0+7fsjVR2SdX22Kp1q0+QvQh+b/12vuxN+5nHjPk9
c3vm9dhwml2ufY5kzl42FyycsOzHHOTUmC8drnEZqPbmantcyprQzF0urno+
xrxso+gzff86xnxOgzWbqQ8n3vpF8xo2dnvueVI8T+BPPyneQcybmEuhp/1c
2scjpnZRyly68Ojen7GeF9pJi3JvaLtNl+cCzAmI9SfTtpkbNIGHTJlnYxnV
3zJlf/4w/NQpv4OYU8BJzbwFTg/st+M6cp3gYlqq6Pf/a53mZVo7rt3P2v4r
Zb593jG0yXtnE9k7pcwjcTLrU9bjVa8ByAHI1Hs/+sZvp+q3TbV9psdxAeqQ
I8D7hHcMz2S4Rek/mgIcZ7vo/wNxv9HPkRnf39zbH+HXlf2j7IW5L/S5tNnb
hWM8/9IzYoDsgTrucsRbZQ/r5xzDRaLOU9pnYMrcweu2W2MYfeFpan+plK/B
fbo/tlAbYwdoLZvycd9SnYTu//9l3e7onOu3q/5d+q/O0e+b69qdpfFcMvp5
Jhjo2Del+jdnfbxPdaxB2uaJB6jO4LD/GzZtjq353I/SWI6vuf46uj9nJv2c
4Z3LeXEvkS/5hM7rPylrBzT0t9bCVlXnlvdPOTdzWNH2zhqnIRmPFfjncQ3W
ckDHAQ2Jd5lLyv6w3WVTO63b8H7UuT7qHy57bbVTS3ltcjD3sj436jquXnTs
/X/aHqGyQ1PWUtlf2wNSfq+sEXWoe23a+8IVsLnG6sCUsawHpF2/H8+Mqt9L
b8Hjmvbx/q3vQ7X/sbyrtd1ZY3yHfjtcvzVpHD7gv6T9DpL9uc7jUW0fYV6u
+gtpLtOmfe7SeXwNH5uO+xHvUH1/K2ubOf+MpGMZxNnZ8p3/wu4pP5fBq3NN
ZsbzH8zujKh/h+p9GG1eIfvNpDUvVtSx3oi1xvM61jsxtqvkbG8DDi3n/jPO
r7a77MNO62a8He280u51x0lwF+RdzrXbourfz+u1tsZrsVbiHhkb98kpZXM/
LEZONvPluHYTZR+TMu9BX6wJWQ+OUz/PTdmHz72EvWyX37fHxLtytLaj9NlV
9vFqZ++U417tXcYHXY7+V9Z1mF+x3Sfqcz+eF/fk2dqekzJnckPWz3/4vdle
EPYVOscr8LmWzX1N/WXAiPUaJ46PCL7ls6MdYge0D2dle68x5Efqfri06vrs
tzbvSp5B2t7b5L7Vqf47svcL+zZw+Clzhsxrcn04N2ZmfH+jJ/Vd0mPBeXHv
HxH1v8n43uS/cHiUYzNvh3OfOQbzDWzm8MN07vumfH+fUXV7r2mbjjg18WrG
kGOhITAr6THfTvVWLbrPqxQ9z9wr5ftzm7Rt5pzcv9zHvONOVb09eH8V3TY2
c9fVs67DfT4m5vbMf9gOink+83Bsfoc/Cx6tncrmzfoqZc3J63Q/f50yfgNO
xW9T5iiDU5FyfK1gD+DzGhhls6IcfMc3KWP8Fot94WMEqwFmAz4utGLQp4EH
Gq4w9DngDVuuyTbYkt87HQcnHg5WAa60Be19F/2BZ+uHlPf7jbFJ+RjwahEz
B1sCL9ePKeNWbsi5Dv7Y9crGaH9dNhc1/WEsOP8vZb9ZZxzIL9HPG7Xvrynz
aG2s77/L3kDbTXN+H/OuZ/tL2Ee2uk/0Bw4u9oWnGr0+9sXHTl+oA18Xx2B/
3un8Pi/qgAGAOwwcwB8pa/XxLkaXDxs9Onz41KdfW0Q98BDs81fK48iWdvDJ
/yvKscHmAH5nvLYOG56um3Rec1PmHLtE9sspx09v0vbWlHWXrq5aMwd9zif0
/YaUMe1b8Z5IeR47NGX7wUa/n3lP8+5t0LP9UtnXd3hLOe9f5tqX83xTnUVq
tpmff160Xu/m2j6r/+Z1/NfwdcAZIvtw2Wtoe68+nTxPc7bPxGerY92X8hz4
O32uYTy1/W/GOsGcA5qiaIveEj4b5uXMyZmbY+PLwb9CHXwdt8Q4qKhu5y5z
fM4omnOScUDXZeui5+AP6tl/W8r5BuQZMDe/MTUfijQ//4ByePBp76Zok/Hl
GIvzzsi5Pm1uV3Rb2xadU3BL1Adrf33K2Hvq3CH7IPXrpUZrWKJf+W+1cyfP
tzrrb1CHZRU5dPfEWG1fdM7A5HZrY46PvrHfhKhPnylfUvaL+u2uGHPapA45
d2haolOFNtUBRd9L+zPm6sPMlHkOwU5eHhhOYgnofDFXnFux/584wB8VlxML
YB51edSBa+qKhGNr+NXJwycHH34FeBbg1fgzuFDgVYZ7GN4HYt8Toz58Fdvp
hMYl7GMnXjwhcK0tWWs2jIwYN7wV16rOVlGfeD38E/P5KZrNIXFN4h8+D/oA
z8OE2Bc8+UOtrkM/wauCW4UHBC4K+ka8Bg5juA/gPbi5zxwKT+g8Jreah4I2
ifvD4wAfM1wINyQcAydmfVPs+2bYcCr8XXF8Fd5g8ubgagHTTq4BNjl0cB7D
NwEvBJwO8BzAjfwa2IOEMQZwMNA3uJbhP4B/AQ6ED8P+jpy46BvtEDe/I+G4
7WbdjuUeXHAsHmw/efQP93m/5yrmYxgfbV5X83OYdxM6G4zVjc2+x8jrHKRu
3lF13gZaGOD90FcgnxR9BjQbiAPW6fNWypyfJ+v/8Jva7igYDwJeje8vpMxh
SgzuR31/I2WNBrZvhk27fId/lfbejjZH6Z5+X/YM/QE+5l2Xcgy6IY7LvmBR
XkkZl3JZzvWJS16ac33im2zfjX3hJaV92hhftZYHXKM8MKgDRhEtEe5PYs3E
PT+IfdFr4P+FXgbxSOKScJbSPv1rabL9URyXGOtHUU689JOw0bL4NGUs3+Xq
52cpx17RPgefvlHVOuJoevcrmO+VuowD4/9x9If45odxLWhjesp8qDO0nZZy
/9h+Hja/U49z5r3/RcrvejRAZvy/+tg90ebUqH9Fzr+BdUQfj+cPurvo9KDX
Q57Ry+3W4L0MHW3wAXogT+41dx4YMWywgjunjRfkQx1yKN7NGNsHru9JfDuy
H1H9p6rG0k7SPXtG0fl8r3cZA0gdYvdwMcLJeCV4M9XfQfYk7XuD+rF92njF
Lm070taNYNuZduy8W/+RfVRW1H7PVK0PuWSfdSg6os51JfulwTGeEb5isAHg
JXeIPj9XNU6Z4xKjJn5PnPpfaXM4wt/I+mjr8BWDWQbTTN46uKt9o87rVduv
qJ0RKdcB8wzeDT0PsHCD+4y9uwwe96oxcY9pfNZKW+8VjB/ckCMW4D/b3AfG
hzZHxXHRA6HNO5uMmaRvC3jmmB8zN2aOvE2UvxZzb/QmltYzfJe0MZ8X6Lrs
lTZelLJdo5w5O5qa6GCBx8MGT/i47qXd0sYEZrXNp30N0PfAxldzb49j+kvV
jG1AIwS8BH4g/EHgHNAMwcYvlEaDSfbx6stxKm9Le35FnVTUv1P353h9rtXn
FvWhNW2dj2yf9VqqOr/GtPfdUd9vVZ1E+OcHp80TCo603Oc5/gXw5Vf926Pa
HlJ0/YOLxpwOjvpwjhLPJpZd1L4H6Ldy1Roo9AFuWHJeyIfhN8Ykl7bm2s05
9wkMB7iPhlhrjFd5Ke1YOzk16LqBYQCPjc1kBVx2IexG7duTNt4BfWf2vb3L
GAhiONiMfTbGHw7X7rSxf+BeOC5z2EWybhO8NzH/3jgufi98cwt0b7CZqzOW
jXEt+D/xP9xPdZrTxtAQB3mo6u/408BhNkc5vrtsjMM1umab6TOY9XfR9885
RWONuedvU5vnFZ0Hf6PuhZ1kT2Teq+fSFG0fTQVPe8r84OQ8kv+ITV7kdVXn
iX6g5/n56sPDKXOwf9poG+70ZVV+f8zlvu7w7/O1ynOeA1M+rdHHoH140OFD
hzedyWm/WAuw7ugX48l6c8O0cZjUqY81woYp7wuPOnztj6Sch3WBjjUp+nN9
1fY5veZwJyeV8wWLulHaeFG45PEn4kvEx/lg2OT6vZhyzi/vvpfincL7Dhuu
CbjOmQN8ojafTZknnXc0+V/wqpPHSk7u4ynn1YIRJedzZpQ9EeX4MunDyyo/
sL/b22eAeSpok7xTckLp2wKOfLRa4bpHr/WhKB+b83yCuQR5Z1Piml6Y8/H2
qPPYT4lrSp+fj/bXKfs9dXPV8U/GhxjoozmPP1hi/qfgZcEjnYQvRdtTiBfk
HOcg7lDp8PadLuNw14rnLfje1fU5O/Zh3+dVZxkwxlk/mxKBnwdHD74M/Bnv
EzBrq8R75ETtu2ba+96hNcgQ7bsGzwjweDwP+4zrHxHvgpeIvcl+QvfAjyVr
x87WdvO034nEIrHhxiXnhec8Nli1J6r+b93f4/7Rf/DJxegPeDowy5wbeSsP
5cztyzkyHuvFOw7cM/fccvBiqWyztN/THGPz6APjvXGM+eScMcnwHoPxXj+e
jWw3CJt3KO2DQyZ/f3i0CaZ+eDxXyf0BYw2+Gh/OOtEfzmPVOBe2Q6P/a2u7
brR5ZfSNMYEHGv8+/kx8lpuGTTk2vkx8nhwLf+YVgfkBC3Rx2biepSqOYY6O
9+ZK+OHV77+7zVcBbwW8FjldHxZ68EKQ30o5ubF5lddnzP8AdwR10Js9Tffv
92nn76MBSx10YNHQ+TNtLk62f4Wd6Xae7jYFYzBbMsYYJeBcyhhjiRYtNvqz
DRnXoWyirl9jxrqEjxR9XOJW7epbP5X/Tcyj6OM9UHReM5yqjAN8lHBP/q/s
PDZ4K8hrQ7foA9k/at+TmcOHDSYWexXWWbxzwv5D98a7UQe+Hbgz4M14IW2d
KjC076ddB7tDfWvOOCf6l6qPRR/gzPg0+jA3Y3102vkzZxu+jq2in+TxUfZJ
1IHr4JMo/w9z7LTPgzxx2iT3/K+cNdrhEKEv70cdxon+9PVzLnNT9A2MCTq1
4EzAj6CPC4YE3wK5/Ue3mMMEvSV4QOHtgCdl82bjv+amjSMa2WctpoaK9ffQ
4VsQb8QmxvmEjjk459glPpxFZR/U4pgm5YfJPlD3587guHW/HFCyL+ZbXdNH
VWcJcGYNvn/a4t6gfMmcY6Un5F3nEO0/L+2+0Sf6Py9sYo7gn4h1zk6btwLs
NdwkcKCA1WY/6sPZAkfGH4y/6vydsU1Mnxz8H6P+Hs0eT/houGcb4t4mF577
lpxx2qc+/BWJvI/NcTN594cxPCjGdmj07ecYZ/bFhpuFOj9F+Qeag/4g+5Ky
f58dddD5ovybemtzvR/3JDb3KrwA8Nhwn6Ahv0rGXN5glc/ps4/koYp5T1fN
OA9gtYy5UMkFGBffseEUXSljvarmmsu/6TVPNzjHWbL71Yxr6+51bgH5Bvgf
XtP1XTRjfB1xKuz1G42nWzzjuNXIDmMrXlfdTTSnWSzjeDDtwIW6Tfg0aJPY
B3EK4mfErJ8pum9oaxIXJO4I3w4cttjEHxt0v7RnrA25hNrPh8193pHxtejL
2z6g2XXhVQHbd2B8xy5o25XxfQWvAzZ4PDh34eoF08q1g4dlf9mHdxonPrrD
fEfLxpisqGMtH/0kpokNjnYlMAAZ64d19loH89b+5k6GQxkupc9aXAcsLtja
FTOOxS+cMSc1PEvUXyTzD8Z2YFx3eBVmps258wzYyrTzaScUXY7268sq/zxt
Tph1mm2TL3B92biVN3Wd69TP6VHn75zb4R7rF+XkL4BB/Sbt99Pkku171H6z
/vNrqu7UgnMoeIaTTwG/xNdpc218lbbNM/+tmr/Prbo+ORgbq85hfeaxWBK+
UrU7K23NZZ4/S+Xsn6YvX0R/yKvA5pxWyPv+Ic41WNulM8bNPll0vBbO8I/U
/yUzzn+BMxjuYLituA+Xivp85x4+PbZLxP0MD9OMtPmaeNfx/kN3/fFon+NQ
3hbvRPIPEmGDF4Y/F8xwS8792yh8lXATw3dB2VJRznf6eUZsB0Wf8aUvrf0P
b/H6gHUCfvRxNftJpup6DtR/YRF9vif3tL+37/YaT/Rd1pii8Sr/Qfa/td+P
2s6Gd1vlr6JfT1xQ9ta6zx/RdoMO47K+VfkpNWO1sMEAgV+izdO0vUyfdvXn
kprj8/mcYwTE3LH/o229tnX6zGK+C1ZU+34s+42c+0EfttJ99TI+DPS2Sq6z
I/6fnPt2nur8rrZmyn5W53WYzvXQdn8HuzQva3zUn9r+gUaa7N07/UzdCoyY
2vqo3m1uqu+v0J7sc9Xm76p/trbbsT7B54FeZ85t0c4lHea1rSeHtd310RnH
XlSfufp+rPafkTVWjb59yXVQndv1+Zo4er3P4+s4l9U6jcUCk0Uf6P85PI/1
/SqVr9nja8r1OrHe/Lw51ofEarXvm9pe12F/ayZnTWSeyeCbuW+rC+xG45LB
G08umvu9Pq4F1wQbnkmwGDy/eHaBR+4XeGvGknqMw1FR/ke9+bqTsq9p9jOP
fXlmgzUAc0AeJeVt0WY/7duac6yZWDf/B+558BPgKJ4Av1Bzm+hQk49JO+AW
cu3e9+MW84P9lrWeOM9+3gc8/0uyG3PWyL5Ixy7Kzmnu8SA6rdo+q7FaWu0s
pU9nzniSDm1/AFff4HuY+s093ncS77Eej+0pHR77bIz/vLyPdUiz6xZi35E5
t/0Tfvy8+8Y7aIuMMSvgVcCtYMNlTdvpuHYf590fsC67lxx/203bbpV15YyJ
of/Yb/czt1ZnvOOOVvkYfeZkbf/E/azxWVb2gJxxcaPV1mbMxfQ8HKrnQI/K
19U4L8x1izrE8xYOe/mUNc7RNz+gwXXAz81ROyuwTm4PzAX/cZVvwPpXn2/A
ZqjOeowtua0526/UOQd6/ajDdoOwrwybOmDUOS7486tKbvMXtCtL1sXaWNsZ
efcTXtl947w4v1ElYwRHavtY1v1cMWJ54O2IzaVabRPze0bjNyRnfB7PVfwy
+F4eirku8cp743lL+aFd9j2ketxXzuFlbU/UWJygT0Xfa/pUc9aDf67TOPJP
OlyH8rK+/1f3eVn2FTVjlHpzxilxTbDBMR2Ud3tDG4xl6sv5Ph7e4H05Z/S0
NpL9uvpwTIwP40TsfpOcY+Vr8q6gTXAvWdt3yZ6mvt2g31vIu+o0tuawknE6
YHfA6b+gPqwm+whiiLLXkj22zlvqgMM5pGRMzXol970nzgXsJ1hS8J8/Z31P
8szcXMe6Vdu1OlzGb9OazL35c9QBf8q+YIT3U3slfToa/L//Nf77s8Pm3cGW
3+AM5HqsE/fSxurDSjljhfArggPAlwiWGf8gvsHmsME4D9c1Gi575Xr7BDbL
2Wf+c+wLLm/XlOvAk3B8yXWO03ZVrpU+1zXEfRf33rU19+eamvFK9AeM0TMa
z5Vlb1vnLVglMEnglbDBkYEdo81D45zWjfP6n9q6kLZ7/fuqUYc5bz7mwOCc
c2Hz7CfnBO0GOJXhXz48eOZeyJgz7WT15/mMeZjBEL6YMV5xls7tJdlzisYe
gkGEl4AccXLLr2txnJ99j2swPwH7gqNEN4D5D3lUYHsmpM3T2NluHR34Z+Ci
web3u9PWgkIHCh5VvsMtfEbexwX3eF6f25tYMf/w3VH/vBb3c3iT50vPxbkc
lfN37C5ifBnHAy5qsU0sYLbG89WMYwSP5OyPw+82W8e6mhi55qs/6PyfVvns
onll4JfhN+I2xJzwua2ZNCcIfCB7tbg+nOFwh8Mhznp56egPuIjnO739rMPr
adbVrLWZ8z4R9ol522AzTsr7mUWb1H0qbJ5fT4a9cvTh9xhnMHyMO3zFjC3j
+i0xVv2+ps7lVpXdnDafD9w+YNbBBe5KXCbwf+g+oREFb8p83pN660OBMQRr
+FOTP+DewLxdnXY5+EPG5PboD8fheBwbjBvYOLDhD2r7cNgcC60pOITAxt8U
fWPfW9I+NhpT4MbAgMFFdGvUmRv1qMM1gicILqAtcu4b+Dw0mq6PPn+S87HJ
K/xU9kNpa5bdVLR9Y9H9og5YMnSm7ktblwfdnAfS5uOlP+PjHJkn35t2jgPH
vD6Oe3/a9eFvgcfl/rBvSHts4UrarNPcw2t2GM92R5wj2/Fhg51/OPrzcc79
QfeKftDmtdp/Sov7wPPzK555afNBLRRjwn27Qs24tqO1PbDF+Gmw00frHntA
9nYtxlPfHzZ+nwcz5mDn3Yg/iPfjYjm/L7FnFV1nb91fDa1uZyuVHxH1yQ2E
O+s+2ffIPk7Hmpyx/+j4vH1D4Ohb9H59TPaoLvuHsPEj4Td6NOxvisb7fF1y
2xOj/WPVziNhv6br8VHG/u5ttV0zY6xmqtu8g7ke8/jOU/mL6sMfavM32fO0
vYj4Ary6A8wF/WvGfM7nlc2/9UvN+ZF/ZJwjid9vbrQDRy82PsBM1udILh7c
AdRHGx0uQzgQ4TH+W8f7S+WLdTn3ChufFdyucLyChb8ub38W5XBUAhBCPx2M
PHXAzNeX7Efp1nl9U/K5v9tl7BVjQp4CuYGTwiZ3YVKMP3lS5DWRN7QnuWrx
zDksbLQhRqqtB4gdlfxMQzeC5xw5R+xLTu6dGesfo31Avic2HG5oItyVMZ//
GxlzIxJX+qHm78toe4w+78t+DL9T3s9hYiJwnPB8HgX+oc/H+UrP//N1jR7T
NVp5gHOb3og2v1adi1VnctXxydcyjm8m2t0+7+6R0R/6eWy3ed3aCs5TvS3j
nNY99Lkjzh2dAfQGFvyOTV7qV0XnQR6mNrZs9W+Uo1HAPcn/5sC45/kvcMy7
YxwYy1u5P6M+Ogfk0ZKXiVb0+HhfU5/+DqpZ7/rgXvdrfPTtSI3VvfGfujnj
dvifzii5/S+Lvk7sc3ujn0s8E8Eon1P2fT1HY/Vlzv5xfI/3E9fn2a9xuxBs
fNr5UGdrDM/S52z8LxrnL1XvTbgcytav21v2Jp3mtRqq59in3Beqe4S+H0Rs
M2387xWBMwdPC+fhGWnz+q+oNp/j2PA4qf8XpY17R+MODbzP9NtQ1flY24Fo
6FTNp/6hxuQL2eNUZ1rV3MtwD4ETgL/n39E+eVfkpMHT9aHO98q0+7pynznn
/ugzf9GlaWtHfqa2Lpf9adW805elzdF2X959BoeNvUnWeWnr9ZlD+lr17Slt
D0+bL27T+J2cNfD2F8b78WO1O1b2h7FFWxFea7jErop+wvEGL95s7v8ub68t
mnOMcwH7/UHO+XW8d+DTHhvtoKdweZS/n/O1wM8yT/abaecpg/2/IPrD+J6f
NqffgIx9leT1n6zzOhzfc9UaX/Ch4/PsZf6Y8W8Laxxq/Jf7meMaHyv+VfKk
+2ecQ3d0s+sQnzq+2ceg/Wrec1R8sN36L43WbzMKztXLxjw2mbFmGznya7b6
O/Z+zbYX6ec8eupQRtwJ3mpiXr15t4Nv+g7tm844N6ki+zDVe7TJPln6A/88
XPKcF3zy/fM+z6XIe8o6xgQfCzn1b8neu8/52tjf1XsMGU/yKWijN9pZTfU+
0W+L6t54v+pxfq/qHEPGh/x06pajPj6Gnox9GpT3RR/wVTO28IcTE6T+obIn
FT3Hb+9xnhZ5Yvi212p1O8RGmnL2lQyKdopxjZgjvBTzhIuLHpOLir5/4UPH
D3N62dqYz+k59Lw+k1X+FXw5fdZPOFB2d7PL8ReV9f99VPa6eg780WT7btYU
VXPVfMZ/lvd7lG/XZ37H6+E9Zf2atjYi/IvwMJb026aqAxfjzzr+NrKLsmer
vSfT1pukXeyn9elpNv8iWo/ki8GT81SUsw/7Xql3yF0lxw5vK5prgnnpQjEm
L6fNS8k1fzauO3G9l6KcfLTn085l2zbn79jV+I3j8mzlGQuXJrEcnrFvM55t
3pe6zJmZ98JJiI4mxyfPlPvqjfifvsp46DNVdebm/P3JemtavpI2N8Dyra6D
ZsodOp/XZd+u7e85t8P9OSfj/z5jiy4MddB5YU58dfRhTtjznwmqf1zauSfk
D5FH9Ih+fwafUNr5aZP0/SDZ+8nuU5sHp/8pw0ZvmH32T1tX5Xad11Fpc6wd
kna9YVE+Jm1N0o+iPvlK/E8PiTpw83NP8ny9peR2/hPrsiOjnDrYzP+n6HNo
2hx5tHdAtAmn3JjoA8c/JJ4DT8dzm3t+pM73tLS1ZU5KW28Yrrn1g7OCOTR6
kmip0t56+IK5J5qsF3xsvPt+zHsMse+WfVfe+1N2fIwtuSbYLzSZdw2tF/ji
ePeeEO/flfr8/B5RNS8efYKf7ZOMbfqG7jH95PdLiuZym9blfCHeV+hgct5H
xzijJ8Ox4H7DRlMHrWYwqOBfwbKCFwUXCyYWbCw2eNGPk87vIreL3Kw3s/YL
MWc9NutnzhE1lx9es3+J+vibRmkeMVKft/V9L/yJWfuartC1uYv8PtXZreZn
XkLPiq1V5zz8583+Tjlak8epzbOIRzT79/OzjhnuXPNzrlV1z8a/nrUPeTt9
b1Pbr2gss3pWnqvyxUquR304qRaKft2LT4ZYStY+MbZ8h7MC7op3w+6v58h7
so+s2SeHjV/uYLVzkD6f6vtn+kzNmlvgtaz9cRfVuYzfyKOjPnaj7JT6M0T9
6VPbE8J/h+8u1+nvs9s9tozbYdperc/rsq/r9XiOaPf35/M+Hj7AV4hpZO0/
6t/j7zNU70VtX8r+k7+IjV9vT+I6GpvjNMfuVb3/qHxTXZ99Ovye5zfikmiX
8h5HvxQbzD+6oGi74ifnfTpf6yXeWfC5z9dzydonjj8cjZTTZbf38/qIOrzX
duswzmWh0j8+9HdUfqO2N3F++OFZexCraDBX3PisuePQbETfEd4+MP+3xLHY
j/3haaI9ytH23Knd5c9F+zdEHXghpsY1KqnOGcR3Gr1G4xxZf6V7PSbwLF2o
sguy5ivDvihr7jS2F0b5BWFv0mhdHPAIaOLQ7sVZX3s4zy6K+ouUfFzGAY2X
f2c9LuCI0MFlzkRcAL0WcAto6ZyZ9bxmVJQTL0AD5/isMSf8R+E+yAae4aSs
cQ7oh6BlQlx4x5o1AVasmoOQcYaHEE7HaVljpeBr/Vz2tTrHGr7udvvgsadk
59PN1H2j67hSnWMHlD2eNfcMcYQns+aMgYOB/vD8gD+GOvhR2U4Je3TN9cnH
RM/oUdmDVf6cts9yv8k+qGYbHyn+3+eifO2S83Kb8OflXY7vFJzIsTEOu6p/
u+jzFONVs1/2fLT29L/7G1xPl3n9V8warwa/1Apcyybzai6btf9w85rtzbTt
67Bf+YfAF4PlA/92dWBR0yqrVzvLZYOTs2hf89lF4/fASYOFpm9PZz2O8LuB
Wab91XUPrJw1rg0cHng8eM/AAC6fNVYNLi3WwXDQweMP98sl/c1RCu8q7452
fNSyN2Qe1ePcxAv7m1cOfrlHde5rlhzzWUPbA3XsZ7Ien6tqHrMLes1n+3HW
3D/L9ff3cWpvj3jW4PfmGfNiPGeIM7yQ9fOfvHv2hc8HTqOHsl5Tw0v0QNb8
RSvr2E16J7UUXPejqL9sf/PojqnZt8X7GX/C0p3mXC3oOnyg39/POl4yrGRu
gAe6zSn/QZQvRrKU6qdV/67+rn9ej7fUeaDBWEHuf3I54Vt6MGs/z6po6cpe
Rdt34R2VvWzwkmLDTfqhyu/nv6/yh1V+n+wCWMEW2yvIvlvbe7J+V03O+j4n
b4vt5LjnwYDBJbS/9nuh7Hfny3qvje1vbqedB9gXR3/w432p81lK+00kXqVP
nz6TssaVwWE0RnU+bfW54ItAO4A+oLlCfY7LY/aTVl8L+KLgJB8S9+errX72
wtn5MrlFPOfxmYSWN5ret4Z+NDrSH8W6l3Vwj/q6tO6vG3QeN4Z2ORrmX1e9
pmDNMa9qrBRYqi7V31DXaTud64oV60ysp/IVKtaiaGKOVDFnELqjvar/X9Xf
S/X3qTiXrE/1R1bc1x7ZFdXZjThf2TqhcMW+pt+nY+MbVjtV1fkJ3vr+1uKc
B+6zak1M9DeHVa0dTN7XU9peWDG3Izw/51f8XwXzP7ZivuZL0CKuOKeFXIzL
K+bZXkn9eThwXcQ7zoRrUvZZ2l5ZMd/uVZyHPt+DK6pZO5t8tl9r1uzgOdVX
td4x+sjkqaFVfY/sKRXrBaNl/EzFesHkkr1QsY4tGhL1VWtho7vdWLWGzgnk
l1Wse7IOuXjgdqrOBbtOx91Q/7du3QvLobNac/xuVY3VW33mqXpT9Y9R/aVT
5lf5ROWbq7yo8kMr5o6coN8PrjjPajpahVXnll6jbafGfzbXXe0fVnF+1F0q
71D5dyrfpuwYKzHTdrW/o/qzhPqzispf0ec2Xcd3dcwP+vz/21T7vi97I9mD
td/wqvmy4DT7i3Uufg21s6vaGaZ2hqqNnWRvwn9d9rVV56jeq7rH6/t2bdbG
GqM6I3lOgreqWKvvRtWtqPxgvWfqVN5f9pX4pNEfkX2t7Bz5dL3m81pB9jDZ
vbJXlL1sxdx2DTrWGirPEM9U+eP6jNV5vaDzOJL5H88ScsZl7642ZzMG+twm
u6jyofDVqp2p5P5on8V07gXZQ1TnPTBoHEv2B7IHohUv+1Pme7JX7TUf8WDZ
g2S/Ibu/7BXQmZO9WNl8wPz34Q3eVNdlUT2LzoC3M/K90RoYUDF/9zXc+6rz
hp7BK8s+oGLdx0+1Xa7P60bu86uzxqmAJ4ED+KqseYAp47fbNUdZt2zNy89U
fxPZjTrW57JH6/OVyj/hv1N1zvIiGsNt1ecVWvwff7di3ZGB3MPqz1m6l3bX
dR9Wtm7BF4yPnum36Dhz1NeNVWceHPloFkV+Prz94GDo023N5qiekDVfGTyR
6LXDG3kZ72r63Ww+WjiXn242dyY2/Jl7ggHNmmMa7uRbs+ZeZr//6jO9xVzU
zG/JdR2lft8I3lB9eb9izZJFa67LPnAjwnd7adZYRuKz9AcOS7Bq12SNAaU/
V0YfwG3CVbFR4HawbwC3VnJ7cC6e2uzzWTf6dlkcaxvmw+pjf/VhRY3VoRqr
T3U9p/RZS7io8kvJk1E//qhaU5K13FpV60Uyf12tah1DtBd3qllnEH095qIX
at9ztO/vspeP2AExBDiZ4WGG83nHAdbkWBR/W9m+ErRWzypbUxZf09HgvGX/
T/YJsnds8z35YMU5zGBrry1b03E8XG36XN9mLbBTVX4wucHwoJbtI/6ee7Vs
zPcv3HuhLXQiWOsB1qXboL+1ri7WNfpN22UjDkI8ZOmIRxOX3rBqju69ZP/Z
Z73SmSr7S/aTxLxVfnOP9QJof3m1v6vG+TX9PrXH+mc8q8nXhhP2d54fFefs
Lax2RpXN0XBcxRy55Jeio7HDAHP0L1I1bzCct5vWzAkMJy85bnC0MvcdpvJN
VP83/V8O6W/+YeayG9fMLQz/8CY161+yxttPfVu+0/Nh5sULd1iP4Ckdbytw
Fjnj5Sp6D5f0Hzih5O9b5oyng097m5wxfDvp2bxLzvg8sDT75sz/w+9bR50b
at73E92PN8p+od42v1MPXu5d1M6OxIPBYpH3JXvNLpdhw42yfLu/Y4OL2y5n
HN2e2o7IGVNGX3aO/sBxhU8Qf+DtOu7esieWzWmEDdaL8r3A08ChovZ3iz6w
3T3sz0u212Nu1GnM2gSN2XNq97Scc/zZdwV9ds2ZJw8sIrwjv6vePvr97fh9
B+K1PN/7u+6AsvtLv+FRBL8Gjg282dS8bfBsbEdFOWO8T4zz+JrLJ5U9BowF
2ESwoCPCBlvHOYKRYwyXi36AywSf+VjJY7l9jGcbnKg55wWAKwHDAX7j2bDB
m5yg7Yn6nKE2L2ZtonMcq+0B+CQDLwTHA7wM4L5uDBsOjLFR/0C4uqN+Z4O3
B4S9e6/5q+6qGW91cM6YK+qwD5ycK6t/+8extlZb41Q2UM/DeS2uQzsTam7z
zpqxTNSnXq7PuaEP6/9xis73FJVvqD7dr3qnyj5Vx7+o5PN7Vdf8lU7blNHG
fnHcs0rGW+1V8jXh2oAXO07b4/WZ0miuYMb2P2X7pLkn4VB7QOUb1/lYjOex
OfNdsM/Rsgkzc2/RnyW03a7VY84YUveEGH/qjon6/HZCtIPu5DHRh5XbXe/0
qH9M2HerD4fkPM7ksJJPu4PGZfk2582SMwuvBbwYrH1Yf2CzBjlX23P02UT2
EnrWnUEdHedhtbWpyk4P/8DZOWuMrqbfhupzJmOhz8Vc1zr/P2hnX/Zpd7vs
D98GHCVg/8jdJJ8TrUk0FsmfJHeSvElscjMvJ16Zc976WTkflzUaes3kFu5R
5/xC7BnRn7OizlMp7/st+Add6wtU9kW7tfzI7Sevf2bZeZa3VD13I4+RHMYP
2u3bWEpjsGeruWDggfm+0efJOaLZjS8XPoEvy+Y5uK1qfCPnCAcJefocC471
btYWOXPuDmc+k/P6eHSrc/jJ34d/d1zOHLzwGcAbQr4/ekbY8IeQ60/9Qqyt
aYe188+d5hM6quTcUsaWPNgHVXY1bdZ5e03OPD/wF8F5BJcR/EPX57w//Dxw
BqGZBEcQNtxB1/DO4PnZZZ24a3NuGzwAOc8L+Nqx8YnAhwovKjzzHJP68AzB
Dw/PDnnH+BVuy9nPQPvY+AfIm+ZY+AvI9789Z34Afr896sMtBD/RKk3mWaFN
OIXIcSY3m7xs8pux0bSCIxZuWbhjwSveH/bd/Fdy5mBly3e4A4+N3yhfu818
svADoNFzT86/g5GAwxceqmtjbBkT9rsn2lkujgtv7aJRH0wF+JA7c/YZwVvw
YM48t6z7yec8O+yHc84zXSpsysmbpA5+gkqf+/I4z71Wjzk8tNicI5hM9hsS
/rH5uJWc8TzgTsBMgAsiD31g1vnj5JGTT07+OFyL8PzC95tQ/Rr+E22v6+/t
0Zqn/KU5Tn+V793kNhaJdgarf0tmzX9LO/ADL+BTxAYb84727c6a8weNgkrW
/wV00qpZ82KRX087cDfRNsfgfoNDYEDW2EPuPfjuydOHWxhuejArcBcslDWP
QbLkHPepms91kpOLj0dzpP1oT58n9H0UdbOOjRJv5fvcLpdho52HBt8IzhHf
b+wLB90e2u6ZtZ7RRznbYCl5XhWyzr/mPXFA1nHMjfALZq0lhG8f/l/83rS3
X7R5heYM+8q+F8xVzfbWNcdw94n+0G/6QUwTbs/RsS/1aWebmnPA6QPPzPVr
fjee0mvt5a6sc+zJd0ZjAw4NeDDWzDqvFn0qdKrwRZODjEYaHBvk91MOpght
PTT2iBVu0GZeNvx4cLNho3GGbjhtwnExJ+/YHrE54nTE//Atdkcf4BFBow+t
vr3qjbVDd/CZJsclORb8I+hKoS9IrPDFnNuhzbujfeKGA6MOXCdckxFxjfZM
WbOKHHN0AwZljYkl176U9bsA/eRi1hrKG9TML8bcfrdWl5NnD+53vl5yo98v
fVlrdPB+78j+o02NDVcYnCEcF34PdDyoz/uItUI565gg+qr0B00D3k30h9z/
lpI1YN/uNp9PT9bvJt5T2HD7tJbMN/Net+OMtAm/DXogvVm/sx6O5wBYthEq
3ytrnOMhOu5I2R3NxrmCdwU7uWW7Max8R4tyx6wxLWApwbWC1eQ36iwoQ7cP
/OzEvG3KVtH33bPGJ6P3he7X3S3G5GyVNWbo3rz/G8RhN87a5j8CRnrjsMH+
gBGCtxo+E7gIwSahE8ixJkQdcEJvBmYJG7wQ/dk16oB3RY8TDC2YKM6LWP3h
GpvDcs6JuEfXfXnmhPq/7MiaQWN8Tsk5HNQhj+PAvPeh/uYl814kNXcd0eXc
i/NKnk+dnvMckXPiXIgRE7eeHvf/dtpur88Y4gTtHh800RifHbLWppygfbaN
OuikoZc2HSxTlB+t8p3b3M7DLf7Q7oLft4t9N8t63MCNXZj3+HMt4A4fHuXV
knWwK0XHvI7OOhY2MmzycLftcOxrWsF6SmB6wHWQVzgma21W8B6Uk19OLsNB
WfNasz047O2jPnmI6DeQN7VEs/Uk984aRwHeGBudyb6Sn6ULa4wrJfOBflRw
2YHxjB1Udc7hYVXnWtEm+VZgSo/IGl8Ktpf7H0zXgQn35ymVjwMjkbUeLDi3
LbLGhoG3w041mi90y6zL4NX8V9Zcl4WSbbjBGcvNYjyHhf12tLFltMnxGAt4
vuHMpF34PKnH/mAByd+nP2CKDtX2sKy5nq9rtQ0P9LiyOZ736fO7h3fSZfU+
zuZxLHQ34RqHR3Rs3nXm68n2Gaf5Lb5QfX7P2LewZLvzzcg1+05j+H3OOSPk
jmEvrOO+wpwu53sTTc7ZsifXOy8cLgBy7cnBbw+beCvcCuDWuCfZl/uW7cth
8yznmc7/YxX8y2r7zJo1B1+JYz2pz3OyD1L9f7V5X7Al56hvL+SsIUj+LMcl
Z3a9aJN3xAp93v/EmrkB6Ce57B/WzBPwkbYfExfJ2yZPnXx18uKb9XtBdlNs
i+RQ9Yu8dtnDmp2vRt4aOdL7djq2TOx9AP7vvDHTYCWwwV40aCzeZK5b7xx8
jkVe/NiyMc43qQ9j+txH/Hj0qztvfN0veX/HhouCsV3AVwG3xU7N7ls67xz5
ZLf7+B1xujgH+g9mEOwgWLjN251TSk7Q7bqPX5d9m7bP1NxXsHbw/cAbBe/V
W9q+nTNej3jLkzm/9yer/hOyH+81BxBcQCn9Zx+t+VlOOXmc7+TslwI/NlP2
n11+noCjBUP777K5bM+rGfNFOXpu4ODAvYF5I/9les66zI9FObg0uFieypl3
a9s+z+++Vf+npI2NA7sFVxecXU/2GocFHgvMFfgrbHBZcKE9lvP8BO4z5iDw
od1E7Fb20rq+U2rOSX1T5WPKHivGDF60KTlzzSzRYSww48k9/0rct6/lPM7v
NZn/Bh4c4uBwsMDPAgcOnF5P5zx/YHwZWzhymedwLeDvGtRnfeX/ap5+eqv3
hdfljFa3yZwH3hU4dODNWSds4trcj/3jngQniQ1uBAzJgLhvyR8np3092fV5
2+SS/5Lzd+wFv/2l9r9UOxfJvr/FOBrwNMSmeefw7pmRcZvkzy/IrccGLwFP
A7we5MZPAlek8jbdt8152/wXyYVvlH0wGGrVb4i+kZNPbv51ug5Vree1e91q
JbdJfj65+dPCpv2+iOPy+K30zE/VrRtasp+kErFd9JK62627Ta40ehKUgbUp
thtvc0SzbbAnFV2Dnnbjjs5t977kVvN7KeqAQ8GmDXL52/LWSaRuIerTBpgh
8ELgQcCCgAO5VGM3pN3xPzAdtcCK9Cdftd2YqFfjOzY4mZ5oZ4+asTEjtK2q
f2Wd8wit6d6teXxn6vs7spvIH6j5edcUY87zDW4IMDCFbvM6PI3eGfNYlQ/X
99dqfhdM7/W98WvOWktgh8EQsw9lv+WMt1y21VjMJ2P+QDn30sGdxhrDh0Hb
PdH+IZ3GCIGfekRlC+U9ntzDA+K+7YpnGlhocnwr0edO9XlfcEwl5/pxLuT7
leJ5zjkyByDnh3cu+FD6BhYU7CcY0OXBeeasp4WW1hLxnXz8v7K2KYeLBg4d
5j/ktsB3A48Nuflz8Gl0xbjGccGdcj+DTb221ccCa/pXl7W0H9B+P6rsh5zf
t+9E+/DzgEWdF317I2zWhr/F+DOe/C+5Hvw3X685l59rRI4658J5wMNDP+Hk
eblmjO1U1dlJY/4+80eN+asqf4+5X681yMh7xLd8hP7np+adwzjfh5+3P5yy
U6Kc3CPylPBLo1OGTb4SPmraoY3ju51b+WPwV5C/Rw4N/uwTYl/y4uENuUB9
Xl/1Z2v7ScnHJZ4Bd+vMeP6AUyWPkNw/8vvIJSJvijyeJaJN8qMej2ORszMp
6pDXc5S2Y/L/5KBgkydynrbn5r1mYU2PjY4OW367o8Xzk/Pzntv8R/28U2Vz
i8aZnhf7okF/Qd7z/a3j2Xh38JrAgYLeYFpjdVqMz0btHtOJYOzz7h95Z+SZ
kXsGRuWBsOkz+V3keZFThi/o2Dh32jgt2iH/7Jh8cBMlXQd/ETFDxpk8BThC
4ApBIwV+XWw4Q5bWdkjeMczParY/1fYPbQfps3mjt0vqM1T1l2E+knd8c7m8
v7PvCyVzhDypcVpcZUvknd+wiLYD8+Z/qe91jgLt0+bgaB9u4X/xvFL9LfO2
91X5hurzWnnzx8Ili30a+ELyA2Rfp/Kl8j6HdQN7OTiOy2dQ9Jl31gVxXV5W
Pxfj2pWc67BEzMHWkb1GtHlnm+35fMj4RmRfrvJVtV0l+kycdrk499XyrrNr
o8eDcrC4U2vmARqq5/ParT7uMWDy270P9e9pdbu0SV8Wj/50hj00YuXLxJiD
Q+Hct1ad6czHmAv2un+0yfez+/z9i5rLhkY5eFfeLxuoTx/rfM9R+fUtXqef
nTdOmtwU8liO0v6XtjovlJxQri3XstTP5eSOkjc6ttV5mORgkidKearZeZmU
tzVbD2GRuAfgLdg/73X3nzqXA/LW1PsCX5/sKXpG7Zu3Debj7k5zBlAOf8Do
vL9TH3u/bueq0s80mNWM29xS57VFi48FrwOcJZ/lnF8/SfWn0udm53KQ0zEc
DIPGbYDKfiTmzPyDeKbK7tWxZuEj1va+kp+r2Geo/9/kvN7EbzIt59zntdu9
7mLNhb2WPt/q+x9t9jtw7uQhkY9E/tiG8Evj56yaB4B+kk+C7wu/JH5L8pex
WSNu3OccqOmqPx6MncpndjnPiTwo1sXnw52VsyYK8/R3Y65+SLcxa+drv2b1
6zCeJ8QvSt5+qe1Tfdb9LtWMCxuRN47lBI3tXnlrkYPr2ztvLN+5GdtgHd5o
dR3wHsxzRuYdJyRuOCrvmB3xO8qJA76k+nvmrTl+HBxqPPOKzncn7524/jGt
tvH1kbP+77xz2Mm7PDNvPThyJcmZBDt6RN45gTznx8QzFvu0VtfB/0mO/ul5
5/g/ofNNg//R+f6kcd4n7/gm+p6H5K3FSW7jwXmvt7+v2f6u5hxD6oxR3+8G
D503ZwjcFXBYwIPR1eM+MbacH2NO3X3Vhz3y1p5uaXcd+snxR0Ufnm11HTTB
PwP3rLKTS9bp4h3Nu/Jt9XlX2T82W+doN9knNrqNfWL8n1E7u+etST0qY/tP
1R/QY/z+hiXPpeAUI+dsIc0tr1PdPGtZ8O15+xxmq86lsierzfX77KPaSuPw
fZT/pe9/99k/MrRWN59c4WnZq8me12ff1k81tzc22vxa+16c91pjjn5rUd83
0H4/qfyqvH1T5EJdmbfvnNwncqDwk1/Gszn6w5bv/IaeIbqGxDFmkYMp+6EW
++Opg38enOeNeWNW0ShAq+AlvatvytvWac/Pnbsmbw43cqOvzlt7nFzma/PO
fd603TbzW3KXyVUGR03ZNVHnmm7nOv9VtBbw9Sr/osWacePy9uUSM78hrju6
ltjE0r8vzXfB1d1WUBva3pJ3bsWteduzo4zv38ueq3G5jf9Ln/O0ydfeSuOZ
zPp8G1td97ao/8P/FXXm8VJPbxzX7a7d22RmvnfuzNw73ZlryxrxQ3ZFxS+p
lAplJ2SnLNGmTQuiJMoSKsq+Zw8llCVKyZYWlOWnVNbf5+1zevnj+zrPnO9z
znnO+Z45y7MGGuDpvVxmGQbjw1gBF3HuVfp83Pc+9lNgeL/oCRJfk1hv3GVe
j/uOQ/w34sARO7RzwuWxmT2qyjjovf8TlzOURad7Xtx63cQQxD7o7WBPhGwA
nhI82CfiPnfx/vGAg7/WR+LWLcc3Cb5b0a1BBkc+8jjKU4YYu8QnfDSU/TbA
xMBDFx6dePTm8fMDPZ9EziceEnryxBQltui2GKKk3MGQ16Gnjg5wywAfFmRo
zENkZ+g5o0uJbjPjOiWMLbKhyWHe4svkzdBWQ8rnxx9T5pHDB4cHTlwm6EGv
f2EYf+J9tNLYvhL3N+kT8OHhE6OWfGICYr/yYtx3Se6w3MG4f2VT3vPnZ2x7
xTjD60Y/HV8t6Ks3wede3DJI/OhgV4NNDbY1wNxZiZO1gDlWsF0OPnTgG2Az
hA8d/Of8o+set/8dfOmQj20R9SwIdZ5UZzl5j3r7NnkvbrshfIgtittXG3En
gcsKzsePG3ypzfgCEvyr0ifKDMOLfIb9KW5/O/+N7GfskOCHh3x8RvWKrDOF
j7S/M/YvtiDluDDEjUPHqUrtfcz6ULCPtCVx60Nxd8S/G3dJ/LcBc6fcSfNj
KTgZ538ccPBPSD4+CZsW7MerpNb79eLQR+IPfho3L5eYdMD7Vtsf14q4fXIV
ZQ3jnw0fWtCJbtWkvHWP8FFXnLVfsJ3Qz8mYZvy/4U/r87h9ahHvBvjYattg
MebYYW3M2K9Pado6Nl/Grfv0Up19Nc1W/fGC9YXQG0oWHLOS2JX43yI+JT61
iJsDjDyGeHfEyUNXB/2HDXH7lsLH9fq440Hii4y2zshYlxl82uAMiQ8s5DnI
or8V/Fax5+a6MD+rC85HZlqeta7YU/qOKeZK3Loxl4d6OI8Rb4fyxJpEJwUc
dGbwTcT8xy4MG5mN8X99q26KOw+/WT/E7dP8Z9bjsK7ODDBrNSnv8FmFzSP2
kPC0/0padwUdlv1LjEPZawMO9pLcA+AXcy8g75dQlrURGNx/fHkwj1LmK4PP
HSKeNZ+4OmW7aOyjd9Pgbta7LXHfx5pmTT9+vbAHpI/Ugw05OPBcvtc3fkK4
+TrfkZ8M6/ALmsPPxs1zho/UNOG9ERk0/ibwNfGqxqo84XMUfAD028g7JmEc
5NTLY/ZBjxwOXHDgFeDLA58ee1U7dlsz9JNET2u9SwiubmzfePjI2/YeGDvH
wZX+DVyjen4V/Y8nXS4eyiITrww0nJ1yvXOUZrLWX0tnvY/TL/Z3bLyw9dpG
b1Uoy3qLzJX1+Y+8x+RPpTHldUz86/+vY6CHOjk3cD7ATxFlkceyf+GHq67c
fvqB2csoFwtlH1B6m57ueo7WfD6Rca71fxkfeegwfhvOVNjbV9R6zu5W8Nh1
TTj+aX3KtqTHZ61LTT3oYxdUfp+E/d71yVvmcVreNEahj/B/ysM34nzN+ZWz
Kz448duIz0Z8NwLjixPffPiK5P7FXQzfkVtDXouQj8+NnULZPlqHVyMHS9pX
Gj7TemTMjx3Dtwv1gj9Y73YI51jOs6yRyMBYM4nfiY/dIpX9Ap5AwjwE0j0D
jJ9D4D4ZyxuJSY/MkXHEX+InRU4ZW9ZJ7NU6he+C765/xgT7NeZgwj4S4RPA
Q+Fejx8DfCbig6CT2vpTcFLpkXHD+PXFXvevuL/HHqHs7uH9XwEnre93ntKt
+ChOuL2JrEXs7QnHqM0UDIPTLmG8ScIpDrQBE6+pOMDkAeNfk3sJd0LuMFeG
bwqP6skit0W/wClJ+K74Z5jnvytdUu/z3RuCpyc8PrGmbr9doHWhvul1KvdV
0ramRydsx8p/6pjwP2qfMI8Mvha8C3gl8C/gd5EPL7JFwWXL6kx/u9AXYrCC
D18F/Vr0bKcUOUXvFr1ldH7RA0YHuFeA0TFGrxkc8rCxbRvqYX2CNnTr2RfQ
WUR/EprAId4rOoaHJ6xP2TJrGF1E9B3wjYLNOb5SgIeHcyzrJ3zHp9mv4vaF
2obvFre98NISvzutkc/anJ85bz9aZnze7xD+p+ytzK3f4rY3J/091MNZ9rCE
9xh8BsKLgC+Bf1v83D6dcd6RIZ/2oQMfGdj2/hbqgZ8BDnwM5jM45NN+q0AD
ez1wIYzr/mFskR+doae/aNhX43Kg0nkJ25hiz8mZf6bSnnpGF9mGknfgUY7y
nCFP4vvoOb/IdsknBXhipfNHFdne+8zQVtuMbSqPVjqJ/0fAoa2J4Te207SL
vTN3EOihfcqdBo7q6RnoAN5Tc+9UwTfr//WE4P3Un+cL/h8gf2UfvD1h2rbZ
UGNTDb3o6B5E2xnr4TKX0H3FFhGbxEkZy6sODvkva/4dkLCecOuEy6Lru3vW
ZyX8caInzzgzr2nz5NAu+rytAz76xugfo6N8Shh3xpz0lDDOqvIfGHkbfsvZ
m9jv8F9+bICh5cBAD3XxW9Pxnz0MHO7I23i4twnuEDcML/cU1dNZ8Id6fxH+
cmLm+QBfGbON5LoK52+D+wser7KXwrePmQf1kL71AHg3xbax6h/w67Tu3ACf
XPfcbpx1kDnUmB81KGaeVV7PQMFji51ep6dEfRkZM2+LtuBdAcO/+qHCOJT7
TGffcXrfEd2VvNs/V23Vw58SzrrAHxsc6oEfBl8M/hj2lyOAsf0TPcMF7yB4
iNKhekqFMyzm37RRH96Rj10jOA1hTAaHvtD34aEtcIcFnFzoI/2CnhGhL/O0
Vk5Ery2nM51wRin/ZvbrAFcE/JGBTvJGB5z1FYZ3CvSPDO2ernFuyQTQOH+p
8blR+V8orQpjwjiTXhvgD8oN079fVecEwfcWG74lZhvhm2OGd2hsXtwdMd8l
/ihzLEziYG7Dm6Syn6HbLPi/ypsK70XPkY0d55J4l72rTePNoU6+yU16bi82
f/L2UD+xOyfDr0yZ5wLcKtAADjw0yt4Wvin8z/Ex8zyxa54Q6P8q7bq7qN36
vOG3sMdEZztmnjT8afjU8L07BroZh/aC747ZxxljMo0zcng/LeC8Wed+v5v7
9x39/VL4l8fMt50YM620fSf64TGPxcUpl2ms77U3+lLKv0f5u+ZNT4u87ZrB
7xL6dW9oF7ruCbRh68m3OFg4q9Ou55uQ3hXqPDb0BRhZ96QwzvBp8RGAf4Av
tOi8qPXyJK2fLfBRov/QGYJv0d40Q/DhovcFwU3gAwi+Ve82i/aPOccqf5pw
DlX+YMGD2efRjVE9QwSfXrB96E/ImguOqYqcEN+KK4XfT3Wej79A4WzFpqdg
m9PfBZ8v+DXh5IRzKvJM5R8l+ELlP5ewLchs0XFD0raJ/xPck31f+degc8jZ
TvBAwQ+rzHJ0cZROFf484bdXnQfr3VvwYpU/UnWO0HMd9lBKH0r862OOFN4F
+fieQ7cQHtyN4f2xamugyh2Ttd0G9hus/R30uw96DUnb7e4F311t/Tfu9mhr
X+W/pPRs5T+veTVS3yqlNe0ZeB+cj0Tnp2mvvyuIYaX8N2lL+Q8J/kpwF3Ay
rndFxjawryD3V50T8uZPnFmwvfAeouECwe8nPZ5nqeyCpHU1+wp+Uu+OE93v
KP2LczvnNcGrBa9Rv0+G3xJ8ReIzcqPytyj/FOU/pGep2n+PPbnGstsZSn8V
zm/C6U1ZxlLfZSL8E9GzH/pdyu+VNE4vle+l/1Vz7VE/6zx7Q53t7zorb1He
Z59e7P85y/THK+8a4ZQgX1LeRaqnjepcrHqG1Fnf8FzV86DKzFDemwX7w2D+
I6doLPzVomea6BksOh8QfLxwbmL+ifY3lNYJp5Voe0M49wlnHTo4yk8qP0K/
AD/Wyv9O+d2U36feOrZ3Cn43af/Z/dCfF5wS/lP4PsrYrzj+xUelHduRGI/X
pB2fkTiN16vO6aqzk+oZyB1Y8HH8/zSG8wXfrnqGK/8hwZ2V3z9jP+f4Pn8J
noPa6s7cFjxbOF0Ejxb8iOCugm9IeK5iZ4QsiPUBeRDrFusXMTvh+eOrC10v
fI8hD0AWADMcvjn+XQ/KO7+10hfLLJ9Ax/7vEsskkEd8FOpBdgCfm7LwupFX
/BRw4L/DB29catncVzH7mYJXg/8vbA/wx4Ve1PBGllV8G2BkFJsCbVsrnc+9
u2W566Qt5BPQA1+9N3FoY+adcEf/LuD/XmmYmO+R+nN6zPHoZ2lufVZqHwW7
5S1TOr/WeWcKZ7LmXA/Vc5bgSzWGfZSepucC5JrlxkFuVK2yjwr3mZz7+EXo
18ycY/Diq6FnmX1o4j9zYJ1lMb/kLTsh3vy2WPPA+LLGfyR9wYdkL2Lwxoy7
RHOpH+2n7UeDOmcVu9yGUHZgoAEeFzoV+PBC7wK5NPJp/NbGRNM65TUVDUfq
qdD/5w/1vbfmWbHgxtg5lTr/ZqXjNIYlzexrCHkH/meR7/AbfHwNlWRsQ09Z
5DDIY84qsm4J+PhVQTbUtJllJfBtGgd92vFVhseGNpuEdtuIttZq57xal6ft
k8pcZ7Nm1kWpauY6GQfkMJWBNvxPnBqzj6ZbK4N8qNSxc8ubWf+B+bY2zI1+
VYbRjeFuiDyGPQFdla9j1ldBd2ZdwLk57B3g4BOYsUUXd5dKjzl+b7B5p621
aqeH2l0ds75EN8GrYtZ9gZ6ygNMnZz3iRvo+0+A3xhx/56ScdaJPVrpKa8QS
tfNdtW0HqJN7K/WjN4NuPHoZ34S2Nlf4fMV/P5n3vC6v87j0CfO5LG9djU21
HvtjYx5/YmigF9JeZY7nPKind7Ft+7vGHIOGtFuAiY9NXO3XSq1PQVl0KtD7
oH50P4gncmTMMT6exLdKzLb/MdFwpdr5VunCtMu1Uh+/F91HcFYrta9lYPwt
0xYxuaGFuCHUSYySbXi9i0wbONtidkPnq6X2e9A99L1TzH2jX8TQIK4Gvrxe
LDUMv+Je/EXodzPRNkNlL4v5XhTPu3ypxnOZaLg15hjJz+p3B9F+ZYN9LxwT
s3+HW6qMT1uvip7jBPcttj+x7oG2xWnHJH877d9dA/3EGe8SM12L9K4jaynx
OeOGT1E9d1S6zhcC7V1CX5Zl/E3fIQZs3j4YJuTMu0MfaHjRv3LuZ4ocp7sf
8xy+SJ37yl0QnQLultwxkbNfGHDuxzZB8HrVcbHSS2K+uz2tssNUdl7OZx3O
PIzLpxXGH1js+Oy9wzgwVifF7LOiV8zw6crfUObfwJ9hRy/4w7TLnRzKcg/m
PnxusfN4R5z0xaXOv0X0JPKe88x/9C+gh/sv8covDPRsa5sxYWx6BrhT3DDr
Rnne8eFvyVl/Crwbgg7A+THrAxyttF3Mscnwd9EuzPO1FR6fmPp0nM4QXPYv
r7E+AmP6XhjbfgFuUeXvgu4B9/QLYi7zBToVYR4uTbvtttXux3mhL8xVcP4q
tW7CuYE27D2wa0CncWrC5wbODFt1njlH6RL93jHlmG/z8fPc3Dol+CQ5XWej
XVV3G+W3Fc736NGI/lE6f/ym33Wa89cLp6twdtbvyYIHcHcRXBB9OwpuQBCF
TpvKtlPZzdW2tVqOb3RiUsI/Etw8ZZ2vY9RWneDrBb/MHE45xtcJ3LlUthP1
K/9g5S9T/ib0CkXPVs2VGtGTr7be0eOcpfG/IHhP4QwSbT25q3Hn1vOsyp6q
Om/Xmep3kfiY1sPtNSYVGqe5Kvdr2v7P8YP+To19nG1R3l7CuVA4R6rc3xq7
z1X2QdZn4bTXdxqntCCctsKZxd6qcZyo/L/xTcI5lnVOaZOcY01UKN1H9Lwk
ejYqHR557r+NLEXPB8o/izHH75Ty91febM698FwFTxQdW0XDI6K/WPlrBR/K
2V9l9oDvoLS78JLo9RCLM2Uex59Kt3AHgccgmj5Q/WO1l14uuAj9IfW3sdLG
onW+5lOR0kZp+1MrRT5cZ1/gy0R/sfLfV/6h6PaqfLlo/g55uGg6W3UeKtwR
yA2RH+obfakyJ5TZl0sX4eSFc4BwegneVfCBgv+ose+bz9O+Y+LbbD/sIQqW
PdUqnVtnmezVGtsPVNeuZfZb8gq+UxhDwbOF943oatJg3234cFuEfWu1dV0X
M9f09FfZvfF7r7LD9a4g/GFKfxdOJFquE/wd+4DgJlnLWPdQ+rB+v6/9qZfo
vF4464XziPL6C14peI7gKwWvENxM8Dx8bwo+Q3l/Jm2vPxi9rWrLYJ9ER1vw
S4LPV3pNyr7vy1X2VZWdqfwruOtF7uNpxCIQ3lR4U8zttOPWxETb4ynHK+pO
DGrhTxPORcq7WnVtwY8N926N3dca5zs0TrX45EQ2xdiUe79hr+Es0E7w83zX
vGUCTeq8f7OPlwj+JGOZGHKZtpwBgsxlTd485t/0DUfpu3WM+769pMK6yvg5
OQb+Z9z7LjoP2ErAh4bXQTwVYhu/VmEceKHwRSnTv8j80Q6BX4rfpLah3WMD
Dvj35LxPbp83XeDgW2ld3r45fxdtawUfFTcMbb3i1qvuprR73HxZUn5fXuz9
gX2CPeSEkA8NH2BTGbc8aK7G8HjBE4oMs2+xZ7XUWJ+tPk5XWzdHHgNixD2X
876aytsX1VGBTsbsuDBunJGAXy/1mRMa2KcWV5g+aKP9noEG7i4nxn1/ea3c
9xzuOINyjmc5TrScprarVXcta7B+78Bepfn/eI1taM/S/Fkpeq9V9kjNjW8E
jxM8XvABNba9HK90qb793Zo/y+Dt19i+/TyVHRr84eAX59OsY4wsF87u8HfU
bgafW/gR0nq4pc735VdYV/V+E/IEdF6U1xe/5IInK/9iwTcKnir4QsGjBN8p
+AzBvQRPEDxM8FvofQn+VPVcLHiEaJ6fMH/pasELhdMFGRG+PtAlED0HKv/W
pGk7Ar1Q0bQvvG2N2SE1toe/VelE4lZyZ0MfWPW8rXpWqp6snlNV9kelPVTP
ZuXHNaaXCT5B+buzBtMHZI/oeOD7Ej0C9EFYr9gnlQ5I+l71Y41j9eELZ4Ta
2of+CN5J+C0FL2Xus24FPz/4+4E3tUL5uyj/vyo/DF4wsS6U/yWy7Drz0L5B
Nit4iMoN0bicjdwEnxRab/8S/nPs5Zo3LVkDE45Thv7wAcIZo36diP5mwrEU
iVd4rdJr9Gwqsl4Q8eSQXR+VtR+gtkrbZC0Tvh9/rgWX319pX6Xn6flSNJwf
4K+2c93gtFH9JTn7BN1b+AdlrQ/VOmtfy/iCnhh+k39g1vRCN7xI6usb6py3
neHX2S8LxjlE6ZkZ+xs8O+OYeNCPXtNHSs8S7q3KXyb4QsGDNDdiGpeNyCSU
nqX2TlF+B9Wzss5r/u2CrxT+HXquYF2r8zr/lP7j7yL3E/4A1XOB4H6BtskB
H/2qI1Rn/4TjORKr8rIwDryfHOokViQxI7e9vzx8C+STvH8xpOBPa+SYmdSJ
PJN6rgxtxfQ9SpR2ytjnNL6k0V9ClwkYH9Q/lVn2h5wR/Qn0KOZpHVlfZviM
IssFwfmq1HJFZIfIDbuqD7cK7py1rA05H+97BBzkbpNCPjC2YOgroKtATE1i
a9aq7J36PUXP4IRh5m377ZwODTD+kICZ1/BzOffin2dMqPOtcB6+S88wPb+r
/vP1/hPBp2nNWqi95AylJ+j3hIR1PtDzQL8gr/9Ec63bXwu/UdL+aS9M2Gcs
3/DC8B2nwy/WWK5X+h89Fyl/v4J1m68Pc5K8i8M47xp5/PkOHbPmhcITBXdQ
+N/9YyMTeBE3KR2fsO3G4ar3dKU/19re4aaQz3tg9FLgYVAWHji2ANQJLfTt
loT3b/QrgOnjK2o7y/9G8AblzVKfxmmuHq05fI/yv1f6t2j+APsb5eeqbeuw
ER8A1fbD9IXKNha8lL5qPF8TfL3yv6Z+wQPwlaL/zr6q53PhvM5ZGh1CbBc4
Iwl+H58Egp9OOQbb8zXWS5yVsN0o6UOhX/QRXv/okPdwyN/2m3KPqK4T8Leh
eg7IWtb9md71EdxJ8CiN4VM6F/2kOXCZxvVaneHzFfZNd1+1ffB8Jlqapq0L
G1ParNpxWj7nvWje0NjnqA+JnyT81fjUq7Z/5XlqN+JepLE6UGW7ZPwf7qp0
BWcv4YxU/mOhj9C/XvmblH+f8rdP22fBIUrvUf5+yr9WZRcIHim4heq/LG2f
0NcpTVWbx94M+/eUdSDWKK3lLqb8hPJ3rreeOv76vlX+GtWzVjiPqf0ZeuYE
Of/MxL//75lhHXhE6X0J66uQTg9wpwCjg3VUwWsDelb4rL4nYT0gbAruTTg2
0wlZ19ct6/d3h3qmBbhpqB/8bfpd9wScvcKZirPV+Sp/LnL4gs8M7GnHCF6l
92O28/l+bt76Jh0Lpu++UOfLSvcRzqXC2aD5/SfnX+pOO27BuWmvM3eG9WeB
ng7Cb6d2HhT8aMJyONLHwrjNCPCDgfY5ob//SVl/YmON8x4JfQF/dijbPevf
jMmU0C7r230Bn/qmhTopu1BpR71vn/XaxhrHfR9/kNPCGM4JZaDhhoDDGriw
1HTT7telppe+sK6jM8f3+0T775GaP201fhN1Rvyf1ogRtdaVJQZts4L9DBB3
+TXlnS06Tlb7t9XaTnxByP9IeGMj20csVh2dVGeJxmGI3q3XvBisdLlwpkY+
wywRPA6fAvjsVZ0DVOf98PD1nV6AJ6v0E2Q/kc+T6wSnI8tNDq5xjL3pxNqK
HEtmssZ+rd7VRJa/rNFTHVl+tEzPnZHPVD9VW6ZxB3I65d8V+dx1mOq8QHV+
rHSF8u+JfKb6TPC9kc9UqwQ3jjwP90k6JsYkYtzpd6XK9dO68oXgpyPfeT/W
8xE8Hs4O+GDlvtbcZ9qDOXuovx/VWa/2Be4rkde/KfCEUvb9/YjSEQ32Acfc
Plz4N7EuKf1cv5+IfNf+WnBR5P/Faj1RZFnVN3qSkWVVH9ZZ7/dZtVVab99V
bZT/pZ43I9/rvxK8XeQzz+AGx+Hm263U70ci39k5s3Ge20d5LeodUwd/qh9k
7f/hTe5hortNmWVtvwnvgshyyXYquwFfI8195u+HvK/WPmou294+k4c2OKY1
ctJGKeuDpzQmp+fMd7pX+f+DZn3LIQXzKuFdplX2tnSIIyO6D1Adl+PnQHgd
k47zMzNtnYFxwm/I2ycDsb3fydsHNL6g8fVNLGRi126v+n/WMw+ZpNJv9WQi
y+y4p3DGuEu4l+V9xyXmxu961y+yjHVdtX3bvKf5MUa/z9Ha30rtbBS8f2SZ
4JgG2yQjSz1a6TPCX17t+FDj1Jel+FuFfyT6X1P6q/BOiawngH+GJWHM29dZ
L/2SvP2N4PsC/UPso7Gz/jDveDHEjpkvuJvG5D+qc0PKsjDkZdxV4RvDK8b+
6/DIMXBuJhYicmeV7an8DsKZrrYuFRzpXZnW0mpwRNO5kWXTbdi39J+arHQV
/z2N7WqlL6m9vbQ2L+E+krf+YFvmYbX9Yy1Q/m6i8x5kltgbqt71+I/gDM88
1Lr1lPL7iP7Oor9W78eoTDvN59Hs4ZTV3NugOfaLaIlEQxYeTp31r0+qd7xL
dJb3V7qb3h0inBvSltcgu8RW60T4W6qnNzwbPQeUWUZ/mOqcJNoWi97/5Rzz
9g589uo7Xqt339daVoid1YGq5xS1932l2/olZxvTRcrrK9wH2aMytl1FR3a1
0paq51XuJYKPZn/S2LZLO14CcQ343+2itoeG/HWiaQJ2/ugvN9g+Af7ewWnH
2ONcsS1WQSlzRu0+JvyPOMumbJ/PHKjXeN6EHSU6HsIbpLJjRecJke1ab9c4
7Zgzv62F2tlLTzm4+CFWG3vGHLd9UIPj2Z+oOg4jdpjqyaqtXZV/MPNJ43Oi
0snl5iFeVPD5fBb2nmrjCH2L4Wnb02ETh33cx9X22faW3g+os7+Qrsqfo7Jb
sNFR3aurHQfwzrTjGBKvC9vVw+BpFjsuwLlJ80kahHOlaDhHcFI0HFnnGBZd
hX+axqq1/te3iM5+ees/TlV6kfDPFn4i5VhjxBX7UfgX4hdc+c+pzlUh5iCx
B9/TcwY0qOwRdY5n0kV5A3LmH+wjmveHn6v+LqqxzBSZKHvxGvVllfoyO+P4
aK+Eto5nndVcul7p1BrbGDQI5+m049vNTTv+2tym9gu9R94xOPFj363Wul/3
FBy7DbvfdcKp4WxJfDilL6nd/iWO6zFZeHGtVw/hRyRlHzyvqa2d1W4r0Xx1
2nJPZJ3YMxIzEfn3GtU5X+VHcI4VzkD9bqf67xLOErW7SN/i/nrHbkOn4QfB
l7NPqa3Z3Lmz1v8cWet1d6jqGav2r4EfpfwHar32429yXMqxJol1iL3wH9XW
V7mTO47qnKnf17FfE3u9xLKAHTXuT6sPzYS/Me040cS1Pll5M/BbJ/hq+LGl
5p0NEfw4eujoU6nspGrzteayP0XmX71Rb986+7KnCG+MxnlujWUE8D+moBer
PfNa5X8Aj1frxVPYDAv/deHsFFlmMUDv+gjnMaUvKr84Mh9skuofTZwtpcP0
9CYOGeMqvI2cSZW+m7asEJnhKyqbiMxzu1JwPXxReFoZ+x94R+lAvR+isjmV
3TFj+zdiCr0g/F+T5rmtyNrW4DPOe2pv76b21Tk6b3uFw9jT0M3RuP0HX0AF
y5A2wutDlqGyawX/kjXfbA26CsKfLfzviQEA/1w07CYaWqTMJ/0B3rj6sgvy
efRnVGdJZN7geRr/3yLf44qDzgO6D/eq7Gcat+/gyevdQZF5gLtlbOO3u9KO
OdsX9lQ6St8vp3nYTfCL6k+D+nWc+vRtxrr+2Cj/kHX83R7KPxSZa4l9whfU
xs6i/2LRWK5xOkz5n8NjzVl2tJNoHKE6z8RPsdKRKnNAheMd7K53d6vccuVP
EG5difema0Tzgeh9wUdN2160n2g5W/gd9Ptm4T/MWbjMcqJLhL+UNUo0Ls86
duuNwmmR9H40Hj2mlONgPYxMLWm55R/IGtTuaSXWfeqs36XcS9lDVH6E6rlV
6RHqy+oS718DsKMTPFptxkRDsxLzil/V71Rkfux9KdvM7IW9PHpT+nYfowOV
tA0te9Nrwt8xsmzre9UZJ96s2toquEbwFnS1aCvsO7/oGz3V2PE7iF+DXuel
nLU0Xp8Rq0BpCTFT0KEWvWPh34m2oWqrb711jzg77aI22yl/BGtuc/uewO/9
aOFXKL+mxuvEsYKfhS+qMu2rvMZ+VOPYqxn6UuPYzyuVjoW/rflTpHo+z5o3
t0q0LeLcHJkP/LTgH5PWgRyfM89md+U9o+enpPUh4Rt30X+T2B/91d7OavcI
va9QvV+XORYA96S3VHY/0V/Z3HbSLza33gWyHHQbblD9Q4XTpLn51UcWOcbH
jnqGFjmGyB9af3ZXH1dw/tLzjPDPUF8eqrMstRkyYv1+QX1shc5b0vog7xMn
MGs/a+tU3zlqazM+rUTvvcTyFM5W1Tea/Rq5DGch/X5D8P1Kd9Ycnl1t2Sh6
1+hF50Xz89w51JeFwrlTv/fb3nvEeVnLsu9QWxdk7Y97iuAPNS43RuarD1Gd
PZABM8Z6do+s7/eDnt0i6wTerecK9EqIL8Beo75vRdcrZ52OSu4cwr2q1LKS
q9TPHdSve/EnkLOs5hz2NdUzQGPXWunQnHWmiEl0m+BZpY6bg79+fNpzX27a
3DpBFSrbIm075F2VTq+zby/meb7WOqfEeXkYWSk6OJz3VfZgjf9apWP0tBY8
V/gFPc3wRar0ENH6udp9QOnd9dZpJg5Oh5zjAx+rdHHB+1Yj1X23xn5f5Z8v
Gg5CnwO7MmL6COeXpPljo5PWn/tYOAvgoUSW6XyUtk4GuhsLlX9dZDnIbcjl
S6w7eq3aKBX9BWIVVdtH+BThvy38npFlKCfp3Uvljp8yX0/HyHKlIsY35vg1
bdSf7/gvaw7e2mDe/QPCvU20rVH+ZmTQ+n2Zxm2K+nGU2n1PfX9YfX8gZ9up
LHd6dNzxe4cvzRrL8LZyvhL+/CrHbJot+GT0uPGlx1kAH9lKO3C/4p6Ysvxr
iP7Xn7K+5Syj21n11wkvK/xRNdYnQV/kCKWHpQKfJWVdnQ7Kr1I6VfS0Ej3D
ucvnbad3pOpZkrXuwYeq/0D4iSp7LrTo977oU7HvJ63f85XGoqVoeEz1bOS/
LvqvQoeeu7bKLCJGCTwMjdugtOW//Rqsz4oPvUaCr4ms37teaWWF171f9PsF
+qMxWc18wTc0Z2/2JMFfKG2ssuMj66IXC54WWUe6SPCYyLrlFwu+KW0926F6
ujfxHb9K+S9H1rX+Jw645v+j+Cfgjol8XH3phM5uU/NCL1P+Gq3zvURPhco+
Fln//FLkl+hXCb5E8FTBn8DbzNl/dqrescKJD87eWsI+G1nvumONfdMcp/QH
4Uwqc4yqpXr/P83JYeh66BksnC/Rp0d3PHwX4qUOVZ23s9erzkcj68ajB9Jd
uJ2Vt1Z5jSusV9BVv1M13it7KJ1WYX2YGc2t83K83vfR0yrtWHvVOfsdb6/v
+IraPUrtPql2l8EzDXOvVjhXCGdDzrHOxzZ13+dorC5EN4a5Cb9IfXlDY/uJ
2jmYvU/pi8xRwVXKPyOy39jnkW8K/g39LdHxdo11HzdzFhbcUnBaOBtqrD+6
D7ragjOCE4Lncw8UnMRWTvVUVzpWyy96JgneT/k/19gObV9s1Zs7Xi9xzaYL
f2G59Y0Kaq+2ynexZg0++w7n7KmyU7kvc2dU/8cUOUbVR/DhVbZK72OMu8rt
rnF7Tv+vuPA3pa0/s0L7xaOcV2scvxDd8USD530X1XMu/Ja0ZXnThf+t8J8Q
/hfwEsutE7KHcGakHQ/6bOXHwv2oS2Qf0PAulsE3EPys6MzqXaLKvIi4yr4R
2T4ip99Rlf0P91ZeeeCTfCr413LrkLyuJ4k/WdVzPHfDUt/L/szYHwL+Eu7N
WhfocdF5XM7+g4kxdJLqaa+yPwj366zvcfxHtmgs3yz3vryD6t9b8/BlpWWi
bU5kG5C++v2u8rcond/ca8gCpV01nr8Ivopywl8FP0b0HKf8b4ltpN+HImuv
8Hr1oMa0o+bhMNF1TYPlJc+Kziv07psK6ylhX9A1rGmtVfblCp89rlWZs9SX
UmItCe6Ljp7gM2usZ7lJaSfV/5jWhDmi4Yp6++OJif4+evd0hfW+8DFbiU0o
9y/RcKhoWMDZKsgokVX+jC5BqWM2jcxZZ3lvYouhMyD4T+4BKlsaWUbQNGOZ
RixjvkXvpo6/2QQ9CcEDBY+AB93U8p0BDbb74n79br3P4Bcp74E6nxk4O/yk
tnqorYf5TyStCzNEeFcJ74+0eZttVP+yCu+DF+tZLvg31qhq2zUtE97VBetT
7aj+Dk7bF+p00flcZL8qyPrXZa1r96Da2q7W8kfOb5/n7Seuhn0hb5vGr/O2
pyht5Dl2iWj+UmOeFM2Naqwj+zX6coKPrbD+APHlsYt9iTNCg/X5+qvOuZHj
WWJXdYXgHWPW/SvW75XllgvMRg5Ybr21v1K2S1zJ/0v19KqxHkup4Psi2wR1
ajA/cazgiDlT4riHzVmLRM9zSnsLZ5PGdCzyPpX7hAA0Nf4f4yd3Vtrx3oj7
Bq/+deGsElzBup2zz92FedthLQ/n+UyDeW13aTzeF509y31/J34EPreeFO5I
eMTKO1S4E7ivIUNV2ZuwmQn3qZZq7/ByxzJb39y8SviTS1KOxTJSNIxX2UX6
hjNV32uq46ty64nlGvyffFs09NOzUt8ljg2E2l4Q7uY3Ntgv2wzGTWW+LHcs
1D2RHaR8P8IupryR17qYfndHP4e7g9qaoDnzk/A/1XO44FruwWrrB7VVLzoP
wi8MPh3RV1HZp1R2U86+HfBntKvaPUptLdH7WQX7QiFeFPxzfKGsijv2YusG
85gGCS5PO0b4FSqzXDReWu67yVDR85zgaTX2e/Nu3HzL67mfNzNfEf4JMffa
Ndi/yjeskwXb3R8f6Nkb3jFn0eaO8U0M8b6qYwfV35/61e53SfspqdTYfC94
UdCTXMl9oNz3+mdU/gECGOUdU/XxUM+Lercn9rSq54o6y4g7K/9ywevxeaZy
K0TLUtXZRjgHNZh3vFC09FQbj1dZzzDOmUL1fMKZM+WYOn2V34bzSZBHV6Vt
x3SA0gOVP6rcMui1SfvowhfWXpFjmSBP36Ng/xX4w1iVsg/lscpvK5xxgmcK
vqnBfkDQvdwpZ572r6T63VntnKP3xwj/JuHfDM9D724XThd42tW24QSP+b8G
ew7u4g2m72n1sZXSYeXWDbi4YD9G3fR9+mh8Njcx/+3EescLInYnPEF4g8RR
zarsxSp7l8btfuhRemqD42USN5O4kK+LjsW6c81TepDyr6o0f2xg3rozvynd
JW2/wmMz9im0TPOkgXuknt76L+RVTyppncnj4JuJ1v1V/1zB3VR2RpX1LU/N
O5b8aUqn1Funm7ixQ5ATq1+z1N9blD+8yrya8VnHip9Ta5/2+LuHj/SXyvSP
bMf3ULXj1sAn3KXB5wBiK49S2TkqO1tlVyvvIuEUMj4znqz6mwneQ3UMFJ13
oxeNbEz5+yu9TmXvU9kZ6EDCK8f/uNKm1Y4XAs4W7r/Yfqnv5yCXq7SO2t9q
exfV11t0ntzc960OnMuEc12leWu7qOwUzYHNSt/RuO2tOvuqTCX/68j2jF8Q
25oYCfAQ0vb79ZPgQaLtftE2k/9i0nHvTmfMVW7fcEe+QPWeWOnzxmLN3yWC
jxBOXXP7MYfn+VPK9iezRM+p9Y5bAJ/tkAbzNDeo/pfV1k7hLJ1Q38/h3AWP
Ex1f0fAwenPwjok9kHachQHNLNs6Rc+N6Nxwp2uwrvmfwv8/0i/22A==
         "]], 
        Polygon3DBox[CompressedData["
1:eJwsnQV0XLcShtccTsz27tredZkZUkqZmRnSFFNmZmZmZmZ6ZUqZmSHllJnb
93399xzrWHMljeBqdaWZf0bV8TuuvkN9oVBoGlUoNPL/trZCYbCQ+KfthcIb
XYXCxCGFQv/oQmFIb6EwJ8+mhj6esERHoTAJeoaGQmEZwr3Qi5BnEnkfI4wj
/iDl5zf/0EJh9e5C4Rb4V+BtnZ9QdknSv2kuFN4ifUfSX+FZA/nnGlEoPAC/
u0mfHrqBPN91wo/yo6CfG14ofEneZ3l2alOhsDzlZ6X8wzyr0Jbz6cDapDUT
5q0rFI4kzxPEpxooFNop+zB5p6Oj28J/0Rb+t9Ie2nsf5bspvxDPtiJtnXKh
cDv07qR1kH8t6NugT4VXO/Sl5PmcvGfA80d4tlB+AeragzZORfv3I9/ntOUX
6DehFyzClz68yvgsC8+HyN8Pv8XhMRFezxPWIu8GPNuasgtUC4V9yf8zA3YW
Azea9v86rFC4g7qmpv6l4Lcf6T+RviTxSymzMPXvBY934XUrYTTx6Rnv7Un7
ljbcS7yvKX1Yq6dQGEE6LAtrEt+kVCisRN33k28E/L/tKxQuoG2rMYYzEl+W
9s5F/rMIa5PnJ55dRvqGpM9G/FfCldBbQE9HvEL+06nrNMI85H+R9uxL+uOM
yQu2rb9QWJf4gc4d6vuE8f0Bel/a8xHxOtr4F/FO6rud/O8RFoHXow3p3wq0
t0j8JsoPpXwL4/IBee9ifOdnfJchzyOMzQ/UeWVX6l+X9Jnh+T/G7WTyn0Jb
Z+XZKcQ3gt8K8LsPfsPh90p30m4iz2o8m7U/8/lL6FNo3y/08Qp4j4eehviq
9Hce0ocwfzci/x3U1wX9Hu1Z0TlE+Z/IfzXPF4P/7OSfivQfmD+Lk3856u+h
/huJDyG9jfzfkf8K5yn0/t15l76zA4h/Tr4LoIcxJscwVkPJfzC/lf14vpDt
59llpP0Fz9HEG+H/Dvxeoi0Lkj5A/gq8VqH9u9Of8TzvHkMbCM3Mp3UpcwHv
Y2bKPEJb52A+bsu4fUid55L+IunnwX/1kYXCEcyfe2jnjPDrpEwfaW9SZnPq
PpjwDG36nTG6A15HU9/cxP+mzsdI+4205WnPzzy7nPTNSJ+D+Gvwa4f/ndTX
6pjAczbSLuTZS53ps31v4Pf/Gek7QT/RmDl2IOPztWsIZXvJczJp98NvNtcz
xugv6O3owzaud/4u6Nsi0LvTv3uoY02e7cp4LMJYjCN8Af0mZW5tygLZQfww
fo998FuB/IcSnwT/paDXJ30e0p8inED+w3n2EWmbdua3vTr0s9AbUd9ssPuR
cbqL+t8nfRL5myjfRfwU8lxHX6ZjfjxJf96hbXuQf13Cv5T5X3d+G0XnMO07
m/wPkP/MuqyXi9KmcaRPy29gHPHteN9fQB9CuTupbx3XC9qzCs+epuxZhHsp
fwvlV4ffPqRPpi2bUN9v1Hcg9FfQO0C/QVtmgcem/J+HfvyP+COUXxhe07Ge
PsXYjWNO7Mpv4Rrmx9eUXbuY9f9beN1O/vWK+d58B30H9HSU35K2rgCPJ/zt
wnt+0slW+Jo8k6AXIM60KXwDvSd1LM27OY/ws++wLeNJ9YUv2vP7uIb+jWBM
j6X+L0m/nLQj/Q2RNgt5HiDtfsI46DHk2Ym+Pwz9nms3+S8i7yGEoaQ/RZtW
pm3zw/N/0K/TkFcZj8VIf7WcMXQsBxry/VmLMX+bdzeEcbif/m1FRyaQt46y
90CfSXib8ruTdysGYgfSJ/o9Jv0+0t6D5zukL8WzccS3L+V9bUL+fvJv05X1
zzbZtl15/gr5pyb/i/D4jvbfQPxZ1p8x0FOgL4U+nDAc+jHKLO3ayu9nY+bE
OtTZSPlO+HTC/wvyX0zeQ11jyP8k+Vck/xG8o8OhFyf/OeRZhvRm+voV8SuJ
H00YSfrpzLd+8q/ImJ5G/FvSryPtBMJo20O4zrWcMRrKGH1D+jWmMf6jSLsL
egboZ/hAfca7uocwmvyzEO4g/QXaPAdl5yS8SHyzYubHL+S7m7b19uf753dw
cfoznDqmkPcTxmMV5s7TtHkj5uaC8JqB9MXIf5TvF3oJ6JcZh4tpy3zkGUb8
J8Z/An3fE/7PwP9i9xekT8349VP/Ejw7jzavQBvuYqLPRX0bMP+Xp/wzrr+0
43vGYix1PER8ddL3bsg3fw3iL8L/WNLng/8p1H9MT9o3G+2dm/gb8LiB+sbD
cyTxVseU3+vl8BpH/pN41t2UPdvrXVk/tyE+C+N3ImmHwvdr19fGvL/nCUdQ
/yPQw2h/PfweJ/1d2nAc82036OH07SvytcF/LvgdRP+/Is9lxPtJH4D/SuTf
lfxF1wjqP5Rnc7pekmdH4vNS/9nUP5bx2YvxOYb88xNfjPe1J/R2rl+U/RAe
qzF2PxEfoL7JlHkBfocwBqfT/zfbsvZ8TXv/dv/IO3yKsVmI3//OxF9vy+9n
JcJfpJ9L+Zkp30EffqQ9b/G+T4bXDeSdCf5/0P7FaN9Y+vQ78d+ov0r+w2j3
VKTvTPmnqWtO+N0P79fa8r04lP9/wn8p+nA58bUIMxOfHR6LOt7wO5Lv1+r0
7zLSPnYPRXx9yixI+ije3xa051XStvL3SPv/IO0c6puR+ncmz1tdmSPOlZcZ
nwbiP1HmjUL6ZN8amGOLk74A9dUT/4gwP4vfK/RvSdq/N3k+pP2LUuZx20yY
rinvpOh+DHpD0hYh/Op4uebS1tvr8n18izxnMj+mwGN/6CmEryk/mfPCR85n
+vsM+X8h//b09xX4bQGvg/j/O/y2Jc99lH2AMNG+Mb+Po60nwvc1xutGvwnw
m533MxXz7zX3vHX5jfpbXZH3dZ97I9rwFnUdMpDf05ykbUz/pqO/l9CWFWnD
m6SPpd9rknce8ixAfFrSLyJ9edJfJ70KfTx0s7852lKCz6rsBeaifUXiH/rN
p/1vUmcz9LGEtWnP99DHEV+B+u8lfj3536K/79HHealrWt7fE5T9mjx3wX96
6O17s5+/k7wXj8jv2/3BmvT/WOgVoNeH3xfDU8cezL0d6f91/rZ5P7eQd5fe
zO3LaO9k+B9AfftS/jTyrGzbBrJ23uyegPJnM6aTobvIN3Ew64t1L0iYmfjy
5L/L9RJ+LzEed/KeriDtyhHZ/y/YGd6nElaCnhP6OOJL0qenoN92vSLe5ngT
/4d39r/hOTPd716W8T2R9DlIfw7+9bS/nt/nTNQzLfO/SPoupI8mfUvSp4bH
tPB/lHcwJ/19GHoW0lvo84aex6B7oZugN4BenHc2M/mn4fl4+rcl9JzQffDe
HHoqnlegz6LOWcjfAz0Suq4+v7evqWMe6pqed/KVZy36Nzttn9V3SN7JhNOp
70zS6+jbBMbrZ/o3huebwX889I/Qo6E3hd4DHo9Cr+mZlPjrjMET0B9BP0x9
g/T3BPidAb9JvJ9poM+GXoD+nwevbaBvp63PUW5D+L1AmW6/1/Cop45XoeeB
fgG6EbqhJ2k+8/zbD70G/Znb/TbxbeH3MPx+Jm0j+L1N+bXI+xplmmrlPTsf
0xD+jo9r0dLw6CZ+H+/pJuibCetCr0cbPyL/IPNzF9o/iTEtsr6UCd3091Ma
uwPpo+hTF/Q7vIdryLuuewXm4qXkv4d3dyy/8YPgdyT8Nof3b+5hiE8h/4rU
/SD5ZqO9F3nGJ63IelCG97uUORTex9O/f+B/LGVaKd/L8wnkf4//h5E+yHj+
Rf4ewmi/V3xvvqcvrzMeLbR1CGVnJf9Z/GZvpr6D/fbRvnl78i1dmDbPQ3x+
wjae3eqyv/++M7IHzwxn2FfKLwF9vfMUfvPxf0vyb0D+EcTLygVoawt5fiC+
DO/hXtIuIKzlfhEeCzJeCxHeIL4a6R+T1klbNyb9GPq3F/we4dlbxewXxtpe
ni0F/9XJ/ylpTxA2cX5Rx9TUNy/te4C8Y+D5GfQj9oH87bYJem/oxYgvTNhl
RPbki7h++P4LWXPWIX4A9b9I21bn2f7E5+jMWnWMexjXK8JtliXMQvwk8hzu
b4f3twXjsRr0y5Rfg/KLMl9e8fxF+j2EDXsSjH/tN420SwaSvkFP9r87uZ7z
/n+C3/GuX6S/4u8LfovBr7U736KLyPM+5fvIvycdaOX9b816cr3nQc/q8JwD
nh3k/7MxZwDPh2syft+QfgDpS5C+aE/GZlN+M4uTthD0jtAjGvObr8D/WPif
7phS/1rk+Y7yB7omkj7W3xzxo9hTnE38oM70fTmezQa9W2/2/+5xPT/+2ZG2
rUqYvTbfPEvKY4Eav33rMgelWwm/Dc+cKsF7BsII1rIi6RXSrvWbQv4W6OuI
P0T6O9Q1jPbsDH0T9DPQv5O+PfTzjOcE0k60n4xvhfEZQfk6nu3Is5N7spfb
BfoU4o2Un969AOV38PvIHNuW33In6btCt5D+Mfy7oHezPdC9xIuEPXoSjDfS
h2tI+x/1r0/5VvcG7ld7cvbatVbfTYQvR0aGoixlGPXN7lrNs1ude4RviR9G
e5bx/RJm4/fx4sj0/w7C38TX59loyt5g/YzXpzy7kXgzzz4kfjRrxGrdGT/L
KtNStuXv2t/3Z7X8t/Sk7ueZXxdSdruejKUyPmV9u/alvTfzfOfB1GdZz8Ce
hdug/6XvZ9fl/f2vJ9+iBubU3c4dwlzw+h6eE4nPxHy7grTdKTsKfqM6877c
87v3n4Y2zwivmXi2N/l/oP6fGP/jie9A/hlIH0f6co5RT9a3zeD9S0POC8MJ
647MmcazzWMDoY8i33aU/5X/H1D/Pw2RN7j/2YT0q8k/rd8235/jx/PtyT8T
eZalvpV5djjP9iRMNTLfjGHEP2W+X+VvlTZs1RN5cg+8PobeGvrOUmRPU8N7
H/jtwpr8XW0stoG+mzZOOzI89+LZUPef8Jvd8aRMO/X/xvx4kTKbk34d7XuB
+HjiWw+m/jeh3yZs6Xi5HlH+E+htoF9z/ae/28HjFX+PjP+X0CfDf1HG9mjl
W4Xw2KInPORVx/z5BF79ynsoOx1lHiTtgZ7E3YO4F+mB347Qn/POH1RW6m+E
voxjfN6k7QfD/3nyPuUa1BMZibKS8fBfkPQ9/EZR9gviG9CfQfKUyDsjz7ai
/0sQ7if/X02R1wylvqWoby3aNLI/+6mq33foh4j/1BnZ3F2UuQJ6BPmXI/9W
8BtG/PKepI3kN/BzZ87XX8H7TJ5d5G+TZ+cTn5v2v0zaAoQbGKureHapvyXC
OvA7n/LPE3/Bb8yo7Fndu7reKkttrH2P/F7eWZffiL+Vzp7ITv1N+9t+2TMP
7X2SZ5v0ZD85SHxZ92e92b+3jciauDH8h9OHZalvbdJPZbxL3dlLeEb3rN5F
/uHkf881D96bQT8N/YfycmWpPTkf+o30W3ke4biRkWkq2zzVOQ59LevBydDX
QD8+Mt9oz2dXud4Qn+Rvxm9rT84Ou9VFvjuKPP+MzBp1Z209UzY3kjbf05P1
oXFUzoieFc/l/X89PHsL1+steTb9qOzBduoIf2XHf/v77skezL2Ya+TtvkvC
ps3h6Xrj/usb8m9Me47w7MCY3M3Y3EZ/Tu/K98/9rt+gBYlf0xtZ7NH2uTff
B9dqZTpT0ZYPKH9VU8bktJ7Mzx2obyHGv1p7n36bPqqLPHxef1/wX8f9FvEz
nDPKCyh/Zk/21e6vlcEp/3yVNh5L2vk832kw31i/tX6jbZ/ng7L7Eeq7l/hZ
hMNGZk/WRvk3oCfS98NJX8a9Un/0SScyLx5jbF9jj3UQda1I2x6H/ow8H9Ge
WchzPf09V/kg7+diwunkmZ0xutv9KnNqc2WopNcx9h+Rfg3pC1B+S3Ub5Jlf
3Rf0zqQ9DT0vdJX17gDoY8j7UjX6jy8Y++0sz/7iYPgdTPwUxuAw8hzYnvyb
Eg6FPhz6GOI3wu8IZTftOU+rxDtS+SX8psBve+ij3avSv33aokNSP3Sj+xfS
NvNMqY6A9p0I/Qn8FqV9S0Dvq/LP8zJjN6U7+oKllXnZP9o/yfEg/g7tvw1+
f0K/S7iKZ7dD/038fcLV0EcqJ4P3BHgeBd1M+16FX4X0fWnf/q5fpN+lTJr0
m6F/Ie0NwuXQt0L/TvxtwpXQt0D/RvwtwhXQF0I/Zt2EM6HPg36I+KWEM6DP
Ug5I/DzHFPpt6K15X8sTHoOeQH9vom1zu6b6ey1m77YzQ/APed9xn0LeFQmP
k3+c7WN+XMYcWxn6N9cU2n8Q82EZ12vGZ2nyTiLtg2r208vA72Rl7MTPY84v
PSIyrnM9+7X9N9T/yUi2UbcArXphqpr+dbLvn7KbEp52fEgnWqjW9KcfEw7h
wQTCs6SfA30ffb1QGQH0MMb7IyrYCPowxvtszyPELyCcavtJn6z+DvpX4meq
hyB+DuFk0u+kzBT6t7hn22rOkJ4ln2S/vBi/j4/IfxB1j6/pdy4l/2PkP574
K+Rf2flF36aljj0ZnzUZ36Ph/SR51iJ+MmMwkrl4HPlfJv+spdR/rnIu5Wml
2vvzOw49ZyntP19ZHvT30JtB70E7noa+jzqGDM+ewb3DCJ4vx4AuTZjO7yPt
W4n4UfRnWuXByhChl3B/o34W+ntla5RfHnpReJ6qDoD27sH7Wwz6LOjzXT8r
0SmqW7ycNizt+k/4UV0j9LL+/ruj6/oZnmOJ/w7PX5TlO4do3+WExYm/wPj9
TVqRPGXoexsir1xIfQD1PUKZn/n/F89+Jr4ReW6mbBvt3Zj4c8rEO7Kvdn+9
nzpO6H8IHZ4VeXZLp4pU9iTQ46FvJ/42bZypKXsi5Y2en1aHfh26oTN6SvWV
6lBXre1/f4TNek05T3geOIi6pmY+DGc+3On+bkiefUD8SfKMG5U9gPuBRsZs
rPsB2jXnYHQ86nre4nv2b2/a61h00sZ2+rJMb3TlU4lLYCwWYfyPJf6Y3yR4
rcCzo6D3o33LK/uH3yu8q2f4PW7NWK7UG3nYKw3Rv6oPvKUhY3wK/ZuvlPXi
ItcGeN9A+b/pb1dD9P9D+E28Dj3o/qUv+nP1/0fw7FB12cXoh9p4/kA18jt1
29fUztPdypTJO4wyz1N+JsqsAa9baOPMXdHrqt/1N7EI8WsJv0J/CL0u8aco
/z30zf5miM8N/1WI30D5Gboig1cWP74+8rOfuoNFuE6dXFf0AuoHlNkvRHwC
/Z2btuxCfN7BfK9OIu1Z+M3nu6OOAu9jSfK8R3t3Ug9B2k0824s+TlS+Dz01
73A36Kct73mOOu/y7En9SxLfgXfWz3g/TDuosjC2pr9brifyAvfM7p39Paj/
9Tfgb+FUfmNH1NJPJH78QGQfP/C+zy/nTOfZ7gLe7zrU1aSOD95PuSbCa3Po
8c3Z82wPXYB+n38PEfrUV1H/fiNyht8M+l/a9y5pD6hThG5UvkL8CULF7xX0
FPVPhMGOtM+z53R+T4j/Q/l31A0QSqSP6I4u5YSGyDcOKUYf1kX8QddD0n90
b0X7ViE+Q0+wLmvxjqYnfhJjtu+Y6GSeo8xM6rupa1fy99D35Uh/Q+wIefZW
90mZQ0ZEp6R8qJ72fkR9kwgDfg8Zs3lpzwBpvbzvM4pp7zSkPVyNPsG1ZjbG
/7zOtEd5qjJ08TfK25SVKDP5krJzt2e/dAf5lyK9QpuOp21/8/tdmfRV6dPr
pI9rzvna83gr7V+nOfvdnSm/qt8e6L07Il9auTE6c+Xhn1NmT+bPXsNz5lnX
772yMMIE8i/WHvnicYRV/UZQ5yHEVyL+hPrs9ugi3iBs3hH5aAft34cxG2C8
zqQ/R49InQsQ72VyLkp79ifvU5SfkWdrU3eFvLMzXiPp39q09TjKj6auTvVp
0L/S31boedpT/wTC0rX3tSi89yBPL3m3aM/a0UjY0e8Pz5Zxf0x/76WOR5RR
w6uX0EHa1byv1Sl/QEf0i8cNRNbkfP2a+raF39zw6nJOkGdT6A7iG8JzW+ht
oOeE3gt6l47Iq+ZzrWjMfF8Keij0aeobO3LeexDew5tzHnyM9Jl596Nq+tVl
Stlv3UD8XdrTQxtamfNthF7ij5N/1oZgRu50P0V/eolvSzi6N/L1c6l7Nn8z
8N8A+jLoQdInkr4cPI6A15FtWb/3Ygw2Fh/D+vIp6RuR/wryr86zfZgPWyoP
JX62ZwrlPeT5Hl4/EP5RtlHKWns7bXmf9q7Bs7Mp/wdlrqPsPbad+T97DR+w
IOXv5d328bCf+heCfsC5Aj1QjDxeWfni1Dcr9Z0Oz2pdZBvqn67pjm76Ct7f
t73Bg2xE3il+Y1hLVy3lfHALfN6j7HLKLyk/B+O9fHfwINfQvvG0b++uyDtP
bQh2bn/4v9Gevd+Nyh/h8RXpD7I3uZL6Zx4MfkOs25Lu+cU3tWf/OX0Nj/ck
fZiT+hYg/kg1Mmll0wOUqbi2kH8Hf0uExcjzP57t2BSZ0aHUcT/0Huq/xQ/0
RiagbGAf1t+luoOXEFskZkXsyuju4BnUGYp3U6erbreT39Si0Nv1Rje3S0P0
ZVdTZnmxGbT/SNp/Gu19i3czNWkP0d5HeQ98hgoL1vAei6vjhdc5Ddl/KgNS
FvQe9FyUOV98Ee2bFV4vqGtmvGagvpeZwzfx2zqDMkcxVxaE792Ecinr0UGU
fY783e3RdbxPf2fjWQ/01NDNhNk7Ig91b3QG7T22K/LcJxqyZ1LeLN7wQ+iz
ST+B9F/cozVHRl/tjHx0BfcepO/ek/3Yi+7feXaH74Znb9G/hcdE3zeSd7yx
Z2zKv0rfDiH+O/G/hkT+PYLx+oa5Nyf5dxFDwvg/NTTfdM+fw0m/fUTyjCTe
XsxavRjhtd7I890WfgU9jLQuwqi26OyUryytvAW6Km6zmGD8xkLwJNb/LO35
usZ/EuO9DvPzdX6/39HeT8XYFWo8itnDuZebmjBVMevrT5T9mTAGevre6M59
5nrbRvi9NTpAz/dNpDfRtuMZo6/FWzoHoL/gN3gzdAN04+jkMe/UninEW3oe
Zb9Ypb7lG5OnsTffXL+95bboED/jfx3v4l/yDKn9ZqZpz+/D31K1mvbfSp/2
VNcJjz0Y+wdp35YM5Dbd2XvuQvklutIn+/Yv6SOgu20P9HOUO2Ew+7sXyL8r
+duJl6pZX11nTyT9TJ4tJTaHMZ2F8azj+duOFXWeTrt268v35O7e6LeWpw3v
kd5J+iY8u7Q9ffdZQzH4vg+Ib036UcT/555b7JRnAvp7T2/0ZZ/XRZ/0IPXf
4l6L9p1GXX+Q/grpfzN+K8D7UOjRY9Km+mL2wD+0ZT/k3vgvf6+kPcsYXwC/
uWjfm9DLMX8fhx70myvGRxlYNfK5mZtT5m/KbkX+O6j7c+gW+K3Fs7c8L0H/
SvyX3sRvgf9cnm0JrQ3po/jFz0nfCbqJOjqdv9W8a9/5P7y/g0j/a3T69Cfx
HXh/b9DfG+pz5n2IvPPRl0dI/5H0Jz1ft0bnfRfjVQ+/x52/NX3VoPg56FPh
OSPPXutIWTHRYqOLfoOgj4CeWv02Yajj0Rz9xi+l4N/2op6Fa/rlDWnraPI3
k/d8vym0b6I6C97HI7T3bMZjftJbSV+1Evn42I7I08UfnUL6vO5fXL/hdx9j
vy1jumBX1nTX9jb68yC8TuNZnd9bnnX3Zg/vXn57v5HE/3Zdpfyx5NmA+EuU
2Z+5sh7pvb3BKIlVWoT2HaA8sje8lDnOoKyG/JfTngWtszf6U+Wby0N3Oj6u
UYx5R0P2F1f3RT6vnH63wcintoL+m/FakfpXUh81Ks+UV5Xo/67E3yK+O/l3
7Y4sSxmgssC1acPu1LXW8Mz3sZTf2r6Q/jLpj/I+Z27Pfu5E4h2ugeSfnvxP
w+sY+z8qOi7X77+gn2E8vnCPRLnXPQONCmZJ7NITyhmJLw6PdvG/9Olf3vcK
9Vl/3ZO6Nz2Pd7q2mO7OjLVnFM8qH0I/S/kP4fkb9PSd2c8XyPOv8vyuyM42
4dkcxKf3/F+XNvxC+lPwvL4lOh11O78TboD+CPoP4v8QXoKug1+BtnRSvkr8
n2HBk4r5F/v/HfQt6noqSTff3oPR/0/kXRzIs6prYSXnk+WJH6A+B/6TeZcV
ng3j2TT0f4a2yOD9fRcZ43ro05X39aV//9C2zhE5s6iTVTc7dnjw129RXzv1
bcmzUg1f+hvjswF0sTf6ELGrW0GXoX/vTLyXMn+oy/F8Df+9GO8l4fUs4WPK
r0WeHvdc8BvpWgs9EvpP+ZP/CcbofMr2ud8lbQ7xeLTn+HLS/yLfXoORP+0E
vxlJH9GbNce1Z3vKfwG9KOWng/5R/KFnL37PN9KWNXh/w/uzXv5VlzFyrC5m
PTiJV3MiYUexTKVgJ493P0Tdj/DsBdbfTSnzMPGT7QP0fmNyfjwN+hDiBxNO
ce2E76nEv22NfFN94Le8nweVB/dGf+f+9gboi6GfKEX+PyN5j/Q8xP8C9HWk
X+TeuyP2EedCnw19jvsF+n8+9LnEV+T9nkJ8Fvf5fs/UIUA/yvt9lrYc1BUs
n8/OIu0WwpfEvyLc1ptg/AjGaEXG9iH6+CT08bThwUowspPbgjcVO3sV+Z8a
k9+c+ojH6N9h4sd5dglp66lPIX478WNpz8PU38zcG9Ka89gkeL5C+pHwf1Es
uPODuo+kjWuR92B4LjoymBaxLVcTnie+OPmrjM3l0I9CbzYyOtk7OzNWysSU
jTl+1/i9dE1xf17O+WS8c2sw55+d/XZpc0D8adrz8ZhgOI4sB0P8UUfwYGKL
l1IeQv4XaeP2tHVn6B2g/xqa89IzlP9sTPCD//Tle7g76bsRPiP+Le2r57dx
DvTX0PtRfo/W5HG+ngp9AvHV4Tc3/D70vAu9DGP+VEfWu+u1PeDZV+T/kT43
UNfh0F9Cv1TJ+cxz2nH07z3+f0d965H+PvElKX+g+HLoj/yew/N++nYpZc6H
fsfznrIh6At6gyedFvoSMd/QL5cyF+anXZMYm/e7Ipu8ivQLSf+Q8AP1bQz/
yb3R5w+pzzfXb+8DhOHE1yH/GvB4kFCm/ok1e6BvuoJPGgZ9f2/shUwbIP+W
7j2UzzE2Q8R7l1JeW6JtCDfTl/XtA+37kfx39eb871xrbs2e7cPuyErcg7kX
e6OS9tgu8VDKn8XHiZM7bTBtsC3D6MPW8F+FOXoK72INz6vwvqQrsmpl1uJN
tSl4ui14WG0NlNec3JYyltXe4Tvm4h7QixKftRjdxyLi6ImPKybtBzG29O3R
3sgq/M3423nM/Tf09PXRR5pf2fjuNX7+7v39j6vxEx/t+esHeJ0+GH3AlWIQ
7QPxy6uxZ9Ku6VTS7+zN2f7+uuCljhYvQPtW9rM+EEyh2EL3lP/U5ptj7Zi/
WIkMVFmodahvEH8s3njZjuCrtVmYm+eb1GwZJnRHt+eewL3BJt3Bxm+oDKMr
bbStk5sjrx1P+v3u9+tz5vR85bfdMVYetibP9uL7sPOo4CUd33G1Ndi1+Enl
HvRlAf7PWIz+8XXSXiNc1xv964tjssa7Bi/Hb/ht4jd6jqX999q/upRRX6n+
+iTHakwwzhc5J1rzTf2btHMIbzSFp/pcMfIvtMWeROz8MeWsv7eSdsxg9N27
1GVNdW1V3+1a4ppyU2++P65/C3fk++B6I35YHPHRgzlje9ZWxvK5usfe7A1v
oE0/+Hsm/wjic3i+oO6lxQi0ZU5qf1On/KAtOpB+6NN7M1ZjPTPQ3o09L4q9
FtesLJD8h9Xn2fTQD5M+Bv7tPNuG8qNI31EMueWVMXh+IX1R3ucY1xrKbNkW
G70FiH/fm7b6zffbfyjzbznGalnC7bT9ZX7/f/L+Lxc/wrt5S31Wa9aMPwey
D3U/+sHQ6J+nUacF7zlYL9qJv9STvac6C3UXn1Rjo3EZ/A+0/mr0IOpDBrSv
g/+lrbFBuIe6P6vGZuJa8h9B/u0Zw/a66Hx2IP5tNTLsL0m/XFlBNTLzL6Av
hV6HNr7H3uoZeK5P/o+rsfm4RPwf6b9R39WkfQc9Sl0g6b92xP7uT+dKNTL2
D/i3H/FKX9ra5ffQ8381NjdXkH6wa431d0Ze09YXHd4V7dHnqtsb3pe2fkUY
0Rf5hbKFuaCnkK/N75/4U+bcObRtgPaPpP0tzKnR5P+iGpsX5RPHFIM3Ewt3
NfnHkL5aOfofbcG0Z5i6O9jzN5V382zmYmQhyjRmIv4L+a+C19WEX4kfVsrv
1d/t4YM5k3o2vUgZC+/yokrqvolwMfE6MeKF6CDq/f5WYwNzPfRRxej7tE24
uxB91EO0d3axbrS3vy/fZL/N94vPIO/JvPNx5J+NPH2knwi9sLav0GXon+F/
L3x25Tf+VV9srB5rC75f26t/adP98JuP/q5EXT9VI+Oahvd1fzH6tlvI+1rN
PlV9wwvQb9b29Npb7Ab9NPRSvQnGN6OOJYjPVI7u6gPC3WLToM8k/1nqL4l/
R2gQO+d+zrzV2CBsRPqW1N9CmY/VbauGIt5KGycXotNoc2zIv01bbBCbSP8K
eoXe7KfmJH609plDI4PrcPyq0YnIsxl6cjU2CltCb6O8iTGdr5Zf++AfPPOR
v5vxGCT/N66prdFprM+8/6gam42tKT+R8t+WIy9qhMfy5egQr24P/kHdojrr
y9uDZ1CX3QH9cWtk4PvQn015H8e71on/Jf4n6euJqaC+X+H/RzU6kN+hfxbj
TpvmYq04gfrOUB9G+ruupfBfDP5XVLKXcQ/heqo8VtvjJQuxMdu8EtlEifo2
I74N/BaB3xnwu5j8TdTxfmtkKMpStiZ9fnUJlDnXd8f4PsVc/FWMDWm/uz/p
DP58q77Y8Glnsmghtn1j6ePu/D4HWOMOJn2WgWCBxDzPSvxV96d1kTe9Vgm+
V9nm+ELsTUbB7w3lJbRhN/I39UeWtB08d4TfrjwbwW9vT9o3M3ENBdUl+w3w
WzBzf7DRm5J/d/L/Vg2G2jo/de/QH6ypGE6xnLNAz6d8Qxkq/Z1Rnau2tpx/
dyZ9dur4pC4Y7Dm0xa4Gw+2zU/wt8axeLBv8usjf3R37KTGEYgnrBqPDmYf2
tZaCEXmrPfgNsSNiaq5tD55IrM0/1eiQpoL+txh8ime3bxuDL24SI68tvvrl
9ug8tMlX/q8uRHmjuqpplAEyvr9Ug0m/j/Z+UAzG4jLo1+qDvXiC/j5He6+m
v/+j/TtAf6X9PvzeLgcDsgj92Kkx2JAueE7g3a5DHXf1RQ6mPEyZr7JfdR7a
5GsPqS5kiGcI+F3r/Od7N7QaeZ5yvRkHC/8Zg6rDmku8SjU6J23y1ceri2qu
5lvlGnU87R9WzdlInHs3Zf/2ewnfLZkvLbR9Dtr8Dby+JjxB+/5V/toZ/ODu
vKsx0B+2xn5+iVLw4toSHwT/Q9VtKA/i/5Ji6JW3EUa1BNN5O7wfh+5QnkKZ
u6CnKM9pjQ3QVz3ZM7t3flGZD+vHuvD7HXod8h1Me8/rzl7+IJ4NutdVzgW/
2fgN7wT9SVfsEb9siL3z5O7IavcfHR3lx12xLV7I/YF7G+jzqPtcwifw+pRw
KfFzxN+LHeiJ7c9Zo6I/87wkVkSMuFjxyV2x3RNDLpZcHLJ45NXMQ/zjnvCe
nTY+2h4dnrq8KmGb3ui4f2mL/lnd9wfqZzyPU+bJjtj0aNujTdGKPZHXr+R5
jGcb9ca+X98FYlyGUHbzauTLypkPGYxOaKg64UJ0ReoD7cuftOf6rpwX9b3w
MO2/pDPy23nGRKf3FeU2IRw+Onu+bWr6yjbtTcizRW90KOpSFm7L99895tja
eq99nngZbfNeh/6rLfYBx7i/ExdK+z7k/6nKGofEfqieMHdLbIq0LZqmK1gs
MTFiYyYR5hsVG1xtcbWx0tbqVujvlM9WgjcUd7gr/Kfn/0nqDsnzTE/OJJ5N
VoR+DnqmamwRxUSd4Hzvim2MNjTa0sxZzLdGnb3nxcd5drZ7T2VcYkX1H6D8
l7TyYPC7DzUH0yu2d8Zq9DPqafYl/fZS7AXEgmovOwPpq8L/GNa/V/h9vUOZ
Ayn70pDY74i7En/1DM9+Im01x82916jsn75zTIhPoM2vuZ71ZHz7of8HPW8x
e421C7E5H1mJ/w39cOwyGH2BvNTJqJv5neeTtG2nzRe7DlViL6Td0B7k30L8
8aj8ZqfU5Be27XgxOZR9lTJrNyTPl6Tty7NbRsUGsAA9Lf2di/acDf9L+qKT
UTezLvxO6oh9s3tBfQjoS2DW3tiCnqN+kfgX8DuF9t3GGC7ZHpvIU5UR1cdW
cqrenF2OJP80vcHPHMb7OHp0bG5MV5fgnHZuf6NNA+kXKqPsjQ8MfWFoo1ZH
2S1I31tdGM/m6Y3dmfZnb4tvpq1/MD630/ZNaM9+xGeizDq09+7Rsaecj3Aj
8ZuHx95qU3Hp4qfcf/XmfHc95TceEfn/1uKHxG/xbGf470f6Yn7vebY/8QOZ
b9Owdn7LGF3J+ywzZ5rhXWb+9PRFv3Mg+b8fHX3PQbTpK/dLxgezlh8zOjpL
dZdre36BXt1ypM8LPVVddLjzEV+f9i5Me89wv0Ce+6hvkLpe5J1Oob6RjPlp
2isqCxuMPal91yeNvmm+0F6Yb+Mrzgfy98GvMjQ2ueJnpnQFW9HBb+jHzuCx
xDpeoby4N/aHFw8JnkZbJPGnOzC/dlWmSfrsxcjW7hYD0hV93+3iO8ZEvyZ+
YmXy76RNHfnHQW9AfH1lvM6F3ui6xyvDJH4GddwJvSn04TV57ZLElxgTnzbK
30zbhHAY9NHtmcvyPET5Lf3toS3n0JauwZyPXBu1AVNf/AP9O5L8l9K/uch/
FvyeK6SOPaCnq0Z23dIR+e/lvL/VSTuAtEMHg0EaRp1/FIJNUl72r/oHwrqO
B+F84scxJ77qjs5R3ePLzKf1OiKzc7+rDm/Tjugnn3Nsx0Sft1pvbA1XHpP5
JmZK7NRyhH16Mx9N00eNvmou7MzZcxme7UXap13xdaROTN2Y8knT9Dmh74n9
eXZQa9as78UvEdZriAz309r72YOya0O/2xt/FmMLkTfNRX9v9rzD/LiWMby+
HH2h+A+/Weobb/UMTfp16pfKkeUp+9quEPv22z1Tao9I+o3l2C9rPydG4u22
+GzRd8uptOHWjtiTikXWh5K+lNbpCl5mOjHC6rJ4tmohPj4O6Iz9qFgLbfCe
F6fTGd34PuR5ty1ny3GFnN+0H3+B9swAr03gNfdgvsl+m9XpbdGV/eJXtPdG
2ttZiUzgUcp2dkRWsJf4OH5Pd/Ib27ArMpCHSe/oiGxkefU3lH+S8mfx7CjB
C7y7swvR1+sfZU/iW6i39bdUjK2+PhmeUu9CeLCQM3m5Jk/S9v6IMZG/rc7v
fybauyn1zEP7ly7Gll0fF0+0xeeJ/gf+YgwO68wZ8AjohtrZ0DPlYZ71O3LW
nOCarj8k2ryDcpPuYGHGjo7Nk2dM9ROTamdP/RX9RN5H6d/57bE50/ZMG9tP
avsJ9xZ3aPPRHfzOjsz3x2n/Fb3RXep76dC64NGeh+8Z4pnFsLbHr4f+PfR5
ou+T1s7YemmTMZ1ymM5g+/RpNFN7sA/6frIO8UHKmJ6kf90dkT0VWT8bhsf2
78dqZAhLkHfejsgWtIf0rKJN6XOM3U9teZ/Ki8RjviNGUfsJ8tzYHVnkeoW8
Q/3bKBPQF1ShI7IC8VzT+vtoic7ke+b8UPVNZFm9nL3nY4Wc98U/KgM5jby9
7ZGNLOdvuDk2Axe0x5+Qe2t9Vui7wj2te9vX/CZ3xB/BNU3R+fS3R2bztJ/+
jshyxDqIHRVDKv5TmdOzxHs7Ios6qD32HO81B387NfPrIuhjxQ4wv05uj+2C
bRIvvjT1HSq+pzn7Ff3hXE7805ZgApQlvEn+X+tjH6H8U/z8qDGRd6qTUDdR
IWzlHs35Qd7j62Mfon2/tm7u6fQfMGNXbEm0QdmHvFN6oqtcXXtV4nurz6Ds
6by/793LdgXfrw8RfYl4dny9PjYmixcjy9NWQ5sN7TO+dk/UEhvSEvGF6P8n
7pXE1tL/L/uDpZqB9CnEV6B9n5He1xJ8gftX947uOdx7iG85mvafMSJ4lsWg
927MGnlae2Qvyp7+qY/9yZXQ7xD/oz72I0t1Zn/7G/kvcuwJ75H2V33sV66B
nky8pyX4a8/iH0PXN8S+RxnsIcyHRzojmz3FOkl/vD72J4c5R/ztMl6/eNZl
XI4qRP6pv6EP2rJeKN/V/466y2MKkTHqL0d96EGeLwvxb/JJW76fygv1l3OC
8rcx0fGp6/uYZ1c0xEaujfreb8v6o/xWfz3KcF3v2jsi232vLb58Li7U/BlR
xyLUt3BL/BmJ99JX0HOjg9dyP7IHafs3RN83lDq2cn1viH+Dj+B3HLxGMSbH
deZ8OBVpy7Xk/HkS/K+oz5qmfcTx7Zn/99fHPuVE55C6pPrY6ywKjz0bs/91
H3wC4RLiD9bH/up9xn8NeN/YFfz6ce2xddHmRXsW7Zl2aIzNkbZHzxKWbokP
s7tJPxb6fGXn9bEHmqGU93cC8YbB+Dur0v6lXHOp4xjyn0v6/+pjD+N5wt+m
c+63rsiwtb/QDkPZ9nauoS2RP+zeEf1xu74wKL8b8TM7419GfPmvbfHxoa8P
fdLpD+900gdIf9v3T3pDd/bmnuk92+/k+aklMp/G7vis0HfFRObEmp3ZE7o3
3Nk9YWf8tyhL0wehvgh1LuHapk37ZvB6sT/f29U7o3/Wr4b+NZQBNhazP+ii
vuGMyd3tscfclPKT+T7f1B37W21htWH9z5bV7/SQYBDEItzH+AxpyW/+Ftbn
zfuDlxE3sxz1vdQRf2T6rNJ31Uj4/QDdA//dPL9TfkRL1oTbKL8MY/wceffq
jH+gB0gfRvqnpN9K+hfl4CPFSVbk35Zviz5w9F+2AuX/Jn6w52LSb/OMTX1T
9BFRjP8EbUEHqX9fsTfl4HP11aa/rfn7039tUZcajE8bfdsc1xB/W/sqo2Ys
PuuJ/fbHfcEz70n50dDvQK/cElndGOj1XOPqY/Oh7cfupfjLexRerbXz6a3w
X68l58/ZaF91SGy89Xe5dVfsObRZ0XZFWeIW0IfW7MGu8XvXkne4NvGq5y3t
Hym/bzmYUn//rgNiTcUbb+b3sGZvpv+gxQrxAacvuJfb4x9yYs0e7sdyfKtd
qH6hHPmVsh73xO6N/Z7cOiqYArEF7vvd/6+hfqMz9hL6ghjDeG/Xme+z9oXa
UGlL9VJ7/DFuU7PXc/3Rt4pncM/inpk8O7kmbt4ZjLdY7/kIm4td6IwvMdeo
j9viw2lOv9di9Ek7vjNrlz7HvhZzw/jMAP+LGZ8FGJuDuqN7et85496tO7J+
Zf5iRcVYirXsEoPjeakzvkqUEf5J3kVL8Vd2PW1vGcz3Teycc/b69thzabul
T0vlXZ6F/iwEE/wvaY/RnndYS85iTCZpz014U3k99EPEHyW8DX0m9CP98dmj
757NRsWeXZsebXvUUY+l7iM6M//dw+pLS5thbYe18de/kZhMsZm3EX4gvhjh
s+ZgihfujA5xKGMzU0d0i8rifofXprT/VtJ/a8v+8LNC7Gd+b8t+SX2j9jmu
ea59c7pn64wOUfszZWnqFv9oy/5JHaD2NuooW6hvxo7oLtXxqA9WL6zuZ9Nq
8IwXMtbLDMZf6EsNsenTtk+dj/jyqzqjCxrdHn7qu8Rzi8/ZpimYHPFMK/cG
+62OWF2xNrva7mojq/3qTt3xVXs983XlrmAQxSKKGV0cXpeVgy8WZ1ykPY/3
RvYh5lPs5xvui/UPSPnDurMez9aSb6b7Tf3a6N9Gm3b9Ue1djH/Pbzrib9bv
/T+Un5HyR3TnzObZ7av6/L7Fq1wxJDr14V3xEaKvEH0GaI99wkDshabrjD1Q
mWftI2Ijo/8gz22e3/RJq2/aCdXgc5QNlAaDVxE7qQ8NfWksXAmeTlxdD+nr
87+3JXum69qzvrmX0mj1jvbgf5SNiVkSu7SC58PmyOj8noovde/XRP7r6OsP
jOfwpozBmuXIOJR1bET5D4g/xfstk7/R9pZzbvP85jfc8642zdo23w//X/x2
dgdLth/j1wT9bVds28Tsit1dtju2vHuRXu/euzt74TryXOH+t5T95AXaAgxm
/+nZ2z7YF23IF26Pvx9ty/+ifXfTnvMYr/mJ/8B4HdsajOazvItve2LrIsZZ
/Lg2TIu4R6qLbdN0/KZnUv9C+YUoP21/fBHok2BB6APh9+XoYOLmgT6qEn3D
S9Bj+2Lj/jF8X2mK7fsW1PmL/kgofxDjNUN/fJ/sRJ8PLWd/qa2NNtGup9eS
furQ2Kx9V8x68zj0prT5qr7YWMzbGX+n2l58R/1Hqv9Rh1GJ/FrZ9DLqyPui
X9S37MmN2V98T/pR4qXJPyfxdbtj26cNlfZuo3m2AuVXIVzcl/VvkngL3s+V
ffG3Nt+IfCPVt4g5E3t2XEvky66fTwwNhlgssfoyv7+XNGb/JGZN7NolLcHL
iiETS6Z92RXqkwfiC0KfEPNqTy/GgLFcB577l2Pfr237TsyB/dzr9kd3qI3P
5/Tv+ErkVR+NCX5v6e7YzgyK4aV/a/TFfnwXnh1Rjs+s5dvj30lfWo9qc9Qc
HcFjNX3B2tQ1b412PfescGhL9jQv0J85WyMj1h+JNqraqrqnPK0zeCXtY/RR
4PfgEfcUo+JzTf8g1/dHF/yTMlfqf4/5/hTxJwmX0ZdXe+Nf0DbZtunJP+eQ
+Kw6hPbvoDxAf0/ax9O3zcUYMN8OgJ7PvTs8NmM8TvP3Dz0V5afT1wV1HkD5
DXhW1fcI7Vm/LzpydeXuZQ9z/SsF2/U24QV4Xe37Yjwe7Yq/wzr4Pea7pPzG
6vvJMzd1HQ7POuIvK8NujQ2t9qwb2YbmYJ7EPr1YzZ5f+/driY8qx1beM8M1
5H21mjON9t6nVuPD1TPVIYX4dn0C/lOLZ6qPvPtJ9YHwn15MCfFnetPeaWv0
maWUPZiwdDnfiz2bw0Neb7unaI2N85u9Wa9Obk4f7IuYQLGB2v/eVg1eaf66
yODFV+mPZsn6zAnnxsVdGQvH5KVae2ybPjAdw0Xo44fMlTV4H3vTnkv6szY8
Cs+V+oI7E392bl3s45+qZG4/C7066U9CT4bupI4pA/EXt11zMIJiBW8mTBkT
ny/an4l/OoX2rUL6O73BY23QHMyW2C19zOlr7jB+7+czdx+H/5tjgol3Pk2h
jX+4P9cfVzk+nD1zH1mIb2cxdGLpTlBnT33j+oL3vrAn/j+155y6PjaY2mKK
T16tkDO4eGRtMPX1unl9bDPPZjyWHRqfS/pe0oeHZ0r9S+jbQx8Gnln1F3Jy
JfhTv1XK4JXFa2OmTEZ/Hdqe6YPOdcP1Q990YlTFqioz9vt2LvWtTH2/U99v
pG/Gs5lGRAbifvOC/ryro+jfwqS3leP7wjPzda4t5fgi8Ax+Q198MnjmNo++
GjrKmcuewS+Dvh9+N8HvCcZ7RH9sYncn/8b1sZW9qD+/1dOob5D4OYQVoX+l
fbO7HtPnHWn/gsr0xOdU4g9EvyDDGO9nq5EpbePvqZrzzPK18nd1xYeDvhz0
d3JrNfo9dZ3D1PH0x5/wEkMjs+vrD2ZY7LAYX/Ubx/TG9lSbU8/Dd5PnGveu
6vRoz13QV+lbCfpY6E/gP5byCxCOgZ63FHnQhcztJtr7dG98Wfsb9rcs7W9X
n2L6t369L7aXi2ivXY59vv7stZnXdt7zu7KQxRqiX9P+Sd9E+jASr7p1b86L
3kGgvG4H9ajK65jDKxbjf3PNxvhwUl/e1hVZ8kasqRu0591sUh8b2mWLGTt1
vwfWx1+MGBP9DezTEezJEvR3Meoaq00r8VkIy0IvCj1zJfppfTfpE2S39uhc
1b1q8+N+bDPo7vrgV7Q/1h+dvn70oar/pfGE3vrYcH/WHczKYtB7dATLIoZC
+3zt9MVWiGmS38SOYJ1m7IwvH31aag8jRkP/PtP1BrvR1xX/9spYlLUoz1MX
MLQlOutVCI0twewrb1GGoyxnXEPkPxtSpqk+eBrtsbfryt0LC5H+THvsJ/Xd
I77F8472Iz3N8bGlPckq7fn2iMfSHl0ZorJEZVZn1eRX6nLUUairOIRwmLai
hcjHxBxZ/1YdwSJ93hdbjuaOyCO0/9FWu6859lalYnxD6vNiufboBNQNNLfE
H8fKyoNpy691sXefrzO+na9qjr5s7d7YmuhzWZ/S2kOJRdVmStspMTLqJ9RT
iJ0Rw6W9uL4NxXYdrs6e9McLOa8doUxM27lC/Km4172wLngi/Vu6d/XsrI/L
17qjv1Ie59572cHgXsS/aAOjLcxhxWArz+iMv2X3XuL5r62Lff+FxWABr+uM
vxb3Ru5FxG/p//Kbzvg+c4+xQHswTb6fDTuCddLOQ3sPMcVii8XUOT+36wjW
Tns//dvo88jz213kKbbkDHNtR/A+yuP/rMmrZq/E/ks7sPkHo1dQv7CL9r8d
+Yb5LXuxOfZkYhjEMoh5eqgjmAKxBfqouZe6d1Te0xIs1HyDsZdT935jS+zv
zuD5nS3xSeX3azfodVuCSXgQfmPhfxf0ifBfrjYers368NeXvzYW2lqoQxaP
oI8vfX29C79P/B7ShivJ/5BrQHds0LVF12ex94+If1D2pP2x9V3QmffhnHBu
HEjYh/hjjblfRHsybV3FnIs9V77i+/U34G9B+adz6ciW+NjWR5vrobKGpen/
vt2RLStz3q87eJCNGoKJUr/6dym+rdRVeF/I872xp3XNdO0UoyRWyTtAmrvj
k1ffvDMoMyfvVdV87/XdoP3tA8yL/VtiIy2+WBsvbb20QdU/nDal2paKmV+y
I/5m9FWwQmv2Y9or6gtBnwTqN3clrN0SmZf6k5Ogr2qJj7V36PvwcuTJ7jHd
ax5ezbfStUf5oPofsSojKbMGZfegD18MjQ2BtgQTuiLbWooyL7RHhqQs6Sn6
eKnyor7Im7VVmmsw9wMo2+8VY9MeeaF328wj3rU9Oml108qY1Pfv6P5xRGxO
HS993OnrbjYx4t2xJ/QuCm0itY1Up6huUbzxfB3B9zmffWfOd+0N9RWuDZG2
RN/0xZ/AffRzrPJGeCzVGsyKeCZt5rWd76WOSfA6Efoi6KmhH1c2W4o+yj2E
e4lHO+Pf4EzyHNeV+1+aPE+05P17P4v6z0VoywKD0XeuW5c7NbxbQ5/8+uZf
iDGeUfupavAc4jq8j0T7sXlJP4v8x3cFUyO2Rsya9uezlLMeK7MUrykGRizM
ffRnM+3VmB9LU99uTdF/9fZlrJbk2QPqill/2+qiQzic+EGEMXXx4XSwvtL8
3g+Jjbu27sW+8FqKPA8Wo4//Tz/aFF14I+nLNmWNPof0O/l+jibvujy7i/hW
1eg+9Zum/m0C69l58P6M/MuQvmM52OfNyd8Or4a++M46mvSz4XcZfTyD6k4n
7FoMhkksk2cM/W3v3B9s99fsH4fD799yfGsp0zxTXTrlN9TfE7/5d8rBQ+mr
W5slbZcOoXyr67c+AYnvTJ5e6C2gO92fDkRXuBf0A8TPL0V/ph5NW8CdtIEo
RDdfpX8XlPLtNc+O7qe0iaiPD7xFSHu3HF89tmm+/mBcxbpuAD1vf3x46Mvj
SOhFid9WSvwC6p9ePCj00dCTxBhW4m9PLKl4WvWh7lHdq4rh9G4J9RMH0ZbN
leFDd1fyWz+M8bhDvHE5+kv1mGLJfxRT25A6Fid/E/UtMSSYaO3leyg/vCXf
KPGoy5LnpCGRUSireMzxgd6KOfwC47V0f74Vp1L+R8ouCX3CkOgE1A1sW8r6
KeZzxkruG/Gumk3VscBv7v7Ih/UJ8ADxA0sZqzeo/y3qPwB6fejXoN+Avogx
aKwL5m8Y5RegzGakT8/8mEx8IcL4IfHZqu9WzxCeBWzzEsqmPG8NiU8cz1+L
9GfsPPN59vtcf+DMnSL04dDHVWMf/Ks4Kd7/DOVg8d3Tu7ffupp3rx9E5fFD
B+I74lvPOwO5E+xByu7TlLvCTlH+pq4E+lTi55Via6pOd3vPl6X4hlLGfVTN
XqTSFAzCodDXluKbSpm42AkxfGL5/jvj+z0qxbfbw4VgXa6Hfkn5P+EE6C3g
9ybx2eH5D/E99BHB2P9Ce0fRvitL8W2ljldd7/sDkfV9Q/iA+N+8w7tag8n8
i/h6lZyvP+qOf6O9S7ENWZiwDuX3K0XfI4ZfLL+YZLHJnuE9fz/vGDIe9+gj
ZiA239p+a1MpPmUD+B82Oj6r5id931JsAcQIrQv/lwgT3W805f6nV8Wcuxdp
ir/dfUrJK65I25Ue+nxsfXxcioc8t5Sx94zvWb+F8EhTfIYOqQbPLZb3FObD
fZS9uhQsshgjsUYnERZUf88c27Qce+p/lN+RvjNpy5Vjq6J+R9uOvXhWaorN
kPgS7VnG6DuPPHuQtjuhtSnPtG8ZRp+/1Pc8YSTxK0rBh/yHE1FWynhdOzqY
OfEBYjDFYr6hTA56l2LudxK7dBLv5/JSfGncR9inGHuPCfSvjXBGJZg7sXee
p8VnqD9+q5A73pT3aX+0VFPuUDtLe5dydO/6NJ1HXxPVxPVz6nlXTKTYSDHB
G8BvmsH4RXQN1xHPqZ7nmuKzbYK60VLmurgbsd/+3tTV61NP+5dTivF1OIn8
m5ejz/DuuVsbIs8XEyk2cmJ97s87vBj9kDry38vRJ6g7bmjIfnxL+nzZ6Bom
RflzKXNJH0MvFyMDVI6lPOsj8k4sxZZ6o5bII0rl6ALUCdyiPBj6Tuil+Y18
UckZxbOKeTbgt9ZI+h3abpP/gr7c2bZaV2ycvMutoj1ZfXz06b/FO9rGdUXm
4t1tT5dja6WOVV1rGfqBIdGp3Qb9TDl3SXkmfw36+XJkCWIW3lBe05+zq2f0
V/uD99uxMTw2hO4n/0PEr2S+/dsfmwzPrg/aZ+ipy7E9EqMzm3jicuLidrT9
mKYcPNF/uCLo1Shz7pDIRJWNrgR9NvSHzLcnHJ+BYH9vJyw3EJty7UHPIc+q
5G2A3+3Eb6f8eeJjy2nLF9B3QK/Sn7w70t7viF/Isw0aM8br9gd/7l7WPa26
fXUK6hbkuY6yLtdg9X28r19ozymkX9Ecn8/6rz4R+uLm+FTQPnLmcs7K7tHG
+lvqi6zgkMbgCWYrBzsgRkGswvylYFGaWmK/pj2bcX1g+r7tj9hFz4wb1cb/
pvpgGje2fZSfhbynNUYfdS88WlqCORKfcDL0Zc3x0T2E9i5cjr5evb22QAPl
+Hr0TsxN+oNBXLUz819s4k6ELdT1j4q8ZrdSfK+u0hJ/jZ/05VvdwhhtR9oO
+m9oCYZB+dSC5fiyVafuXYfv9OduHXUi7xJ/ty+8xADsqu8J6EuaIxO8rz9n
1M06Myc9u37YF1869dS3BfRC5dgyiWEQyzC5L3vxRtK3gf6qFF+z58GzmfaP
1/9WS2xovY9mc/cf0OeyH7hwIGUsO2J05FVToG+BPpv583d/zoyeHdVXrw19
Vym+mrzT0LsNtSdckfWhnmcX1PZ/+rYbSRhXyn7Ou8n6avs7bRi0Zeiv7dfu
IH3lutxx5V1XJffr4gMaIq+Xp7zVMatrXow2z1yfO6AWHwh+2rsy1bGpa+sk
/Ez/Oltij6RMXdn6maSvQNr7ldhqeWffB8Tfpv5L6oJJEJtwi9+jIbFxPAp6
1nJ0reLUtB3Tv6e6yl34vd5SyTvx3YiZ+qAv5xVtyybXfg/OEeeKGBWxKtrf
rtIUHb+6fueDtmX6BNU36HP+fhri01TfpsX+4GeeYn69DO/Zy7G1+g9zQtqf
/blbyzuq/iK+CvX93hId84t9uZNtB+bT0oXc1Val/Evkf9HzRCnfK31Lq3NV
9zpdOfjC/2yG6e8a4k+GRkesrri3HPmb2DFtKVbxm0z6e8ynGwbyPRcrapnd
qW9/wiDxv5hPHaQv3593oU5L3ZY++/Xd/zT0eOjfSplr7oHdC1+lTZ6yr6bY
R09bji2za+ocpfyeHybvVV6wOhD/Ttr2uAa4Fri/EesmBk0s2kbQZe+vUadJ
/k2g+6BngP8frhXU+Szld+f3X+b9buU7GZI7mfo9S/SlLScyvr9Db0P680Ni
o6atmvIBsQI+25a0/Rxz+A/w+1paXavr5dDY6Gqru2cx2Gqf7eRenWcDxGdx
T0F8s/6MjRgtsVrur14jf7/6I/Eo4nO1j6A/19OfzcpJE/Mh9kObP23/tO+4
nvf1TA0/fFtT7v90/r/dFB/w+oL/k2ent+bOv2m9m8nzK/RDpK9A2pw8W7Y5
PtG09/Q8/EEhNsPaDi9J/k7qerMx57u9POO0BVMituSGUvAs4lq0NRvVG19A
6tT093OLNox1wZCITSmx9nTWx15Rf5s3lmLLII/TSb+plLOvuB5tHTxzefby
jon91HdWY0uqTary4Odo/6UtwQiIFfjXb6D2ieRfAPp/peCxxWXrm847i7y7
aJmR8df4DXkWaIgO5ttKfBDpi0ifLMob1R800NZqffDos1Zyd6g6e3X3lt+p
NWdAz4I3l+L7sIlwMf1ZifTptT2Un/cDVRJXh68uf0XCdKQP8Kw0EH2Qe6+d
au3R39EnLfFh8Gsl+tRfu4OX7SzHJ5i+wbyzWfnPhtX4f9UGWv3Ap6XIun32
E+35sZjx1/fpHMyljcjzR13Nhlpd4EDOQsMbg3dQpq1sW5+quyk/qsRWTRtU
8RLjq/Gvr5998aCvU/532vZeU/AXb5Qi71buLdbjrVLk3cq9xW68WQp2wzyv
FzN/9BW10Mj4k/qsFN2BbfylGH9t2gL4jdmtpn9+qzfyRWWFYurF1nu/Tjf1
r0b+Rcm/Ofmn7Ys9rn7q9Fe3F/HbOuN7QftI8VjrVOJLa57G2G+r31+P38b8
jbH3/o3+dZM+FvpS6HUruStnneGxpxYzr4x7Onge4PmFZxs3544c7a+1f/7Y
90T+2Qbi40xfZ2vWRV6n/nh0c2yIxJfouH7ehvggqKuGfqA1Poe9y839/TXq
H3j2WSU6OXVzfvPXgteanskp9gTPmij7Zyl5lSF+btsJi7eGh+cD+6NtuD61
fitmj+9eX0zJqErkifrCtIxlG6vh/QJldq7kHfgu9md8K6VgWMSyeGZYrz82
z9o+uwd3/6e9k75zHh8df10tlF8K+nVtwPri7+y15jybvpr3o229/pu/oX1T
VePL5P3m6G+1t9S3z+qEoaX4k1MW6p0b3r1xaSm2LnvW5HGPirlozTfC+/W0
n+8dER+L+lrco1LzvdkWX5bDysE6aMOoLaP+0JT1eib/vDP+CvTdq88SfZcM
lmu24m3xrfmccgTyf0r+ebvjX+Kh4Xmnvt85+oMVETPieez8au7j864570vy
e3VNa3yM/Eb66oRlRkdGu2c5NoHaBprH79nyhKn0xUJ6t98D6Dtbg7ESa7VC
Jb7o+0nvraW/2RQZiLKQ9au5j00bePVDj5fiO02bR20fl6nEV50+65Q3Lgc9
qL8E8nQOZL+r7FwfkPqP/KiUu6Ll+T5tvbUU2a7fMG1h3itGP7dBR/yN7aVO
nrKd2oNRvlt7o9booD+G/t7vufL95vgbOJ0xmLMxPmXeqsTnnb7vvHPH+4Pe
qYRXB+Ft4nXwm601OhHt/WeD36HaD7dmP+mZybOTPuv0Xed+0zTLWHaNgdju
a8PfwPg87JrYGsz2hP7o8/VtVWIMVizl/kfvK/c3rT/MzwaiSxrTHPzPO6Vg
mR4nvK1sthrf8uouxDfP1Je7qLyDyruodqrE9uAk2rCM8mHSryN9/Mjg5eYq
x/ZFn9T6A/DOXu+l8n4q7/K9xz7U5c7zR6AXLMaXyWmF+PPxeyD27S32x8vA
+2nyn9kUGf3z2poRzoJefFjsUZ4rRtZuHtdb1wTXBsdoWdryFOlzkX4R6TOS
PkNf7ib/qiH34V5Bfd83xsZpcejtqvGXrd/sEYO5Q7K7M/gU75Y8pRT7J+2g
9M20D/V9PDp3hM5N/Nli5pc6De+bv7uUuh1Dx/LsUu521gZEW7TTSrHV25uw
RTEya2XXYii8j/lZ0s+BvpMwp/IUbebq8mw66LNKsRcR4yTW6VTlu4W0cTx5
b6j1X5sYbWP0/3NoU56ZdmF/sHLrMp6L9UUeoS2Fd3roD8X9srYY3umh/x/t
brW/FeP0n/9Unn3ZlDtnl3auwG8j+J3OO1xS2cNAsGWnEBaH3qIaWxDvQRGf
ud1Avt1/Mn7be54ciO7Tb/q2xI8qxZ5Su0p9pR1Ziq+0FQkb0v6NKrEv1s5Y
/IH32U7tfriQ+1o8r9xKfbcRZva8Qp3z8Ds4Tbwl7blDDGBTfIK4Xk3Vl7RP
oO9xf0g4vCk2gNoC3qxOx7VdG1/PMupMoN+F3g56EnXc1BQbgEp//Mfom35W
6t+EeH0p90kt25P7GG8jz6WM1wmM/0Hwf7MY20D31AvU9APeBeWd9srbnyxl
7+0cc66dXIpvsHUImxZzvlf3qI9x/ZV4v8Z71F+uy52z85ZjSyXmx/VhHGN2
AmN7YXP8EXjnvHfP99KeN8vx5+1dMrsWYq+6bTX3CXmv0FD1l9XYknkP0BDH
thxbLvMs79yvBj+tLYv+F34oBQvnnczezay/AO+n945o/RMtxLP92+LjbyXy
3leM78ad22Ifrk+6p2r2ovqqE1+3ajH+9PTF93op2F7vgPEuGDHrYtf1B7FT
NZh0semToS+t5r5Pfde5JxQPob+sKzujU1O39m4peIb/cA2kjS3H1mYEYf1S
bIq0LdKn167EF+7N/a7a8HofrPffiBVyjB1r8bj6odMf3Z7Ef/LM0JLfkHjL
40q5n1JbTO+HPdc1sZAz0Fzkn7sa32jqbNTdnDwYP2k+m6cae3rHShv+e4u5
P+ww4lvWRb8t3ti7tdbi/R5SjT/dh7rjX/iZUuRP3t3uGrhxKf739OOwNm24
hfjEau4f8B6C4dR9Kv2dUIh8QP+l6nxf782ezb3bIvBbRvkoYa9S8GMrFTMm
jo3+Mof0ZM+4I/FzSsEGaoOn7a543yt7Yz/7co3flg2Rye1Zij/Ql0lr0Oao
HLzd+02xoRUfuTXpN42OD8+nlF2Ugh32DvdXivFX+sSY6CjEZ4ufm5bf7tDG
4F2VWSu71ieh96EvwLOZGjIGG5Tio1DcjvgdfReuzLO+hszhhavxWaO+UZ+J
C1bTnptHR0azTin3GapbaWnMeVN/ldrOngX9RDnrs3u3IY3BM6tzUPfgnnLW
avSTO4zKHsC9gD589OUzIzxehj6skrtSf+X9Hl6JjwB9BbgHOILy9fBcT9kn
v/9zyL819JOUX0398kD81b0PfTD0ddR7T2dkT543xNOoj3YtdI10rVT+oC5h
Yeh9aPup5fgOHM2e8spK5Av6plPHo/xB/dnjDdFZqLvQZ4xnI59t6d63nLOR
NhDer6H9h2ddfUbo///rgcgWPuUdrt2X8/3bhdyhor+CS6ljD9bXxzwzkf4h
6ZXmYFyfpT07u+bDv8k7D4i/T3pvY3SWq/RFv+1eU5mesj11NOpq1Lmoe9lO
mWJzdHbzDMRmQ7/Inum05biknLObZ7L5oC9Q3wC9FvQv6gehV2oMBlAs4By8
k3dGByOg/zR9Juk7yfsYb6hG/tXdmDPbCjV56jcNwVjo/379Yu4me5k8r5aj
41XXq4+o7cl/bCV7vz/02UD8tXJs+7Txm6i8DX6LU/5Vnr1O2sGl/LbfgX6v
nHR5W8ayVw3kbszTGM/PytExq2v2zmDvDv6wHNusucfkPjXP3wfX5U4W7SeO
KcXW6z3xtOXgD5Yq5I4K9f1iEMQinKg8mPhalXzct6H9axN/hfxN2ktR31HU
9wQ856jLmOxejv68uTGY4qWIH1KJrME7FA+tRB/vb+tz0peryZPdG3pnxePw
emMga4tryps1fe4lfjsIBxSjX/JugDWUGVWC53Ntubou/qOLpG9P+kfK6PvC
U976gFeeoPxQXac+dPei/msGgpU+nfH6vByZjvPdNd61Xn8syg6f0savHP1A
I2v5NmLcaNtY2tAv9r8l8ij3Y1Pgvb469P7YN3pXiWXUJ0ymzNTk/4b6nif/
w8qHhwZT+nRf9CXa7vjsGfczPJue/FVtKsm7Bm36rCtrlPvH4czR6ZqTZwTx
H+jP0/z2voD/hrXf36t1sSHQlmA1wsRh0WGt3B+dk7onf7NHw3886bsMi05p
TdMIP1L3NDz7gPhx/TlLLgr9mWslZaYeFhvQsf3BM5xP+6fl2Yf98ZembLEM
/T7xR8n/DXVV6O8zfdnzuPcRIzFPf76hfkvdM7p3XKsaXzX6ZNR/gve/qbt2
P6H/U8+X2q5NWxf80C7wPHBYfNjpy+5Dnk2uy7MfavLtNZqy5m5D3WuWYltl
m54lbS3le9DfQj/XH/1cf2N8uKrPUx/oXTGDjOfqNf2btiszNWe8PvB7pD6S
d/DlQOSj2vp5Z9ZltGWNau7n0ueo9nvKEz8r5Nkl4omUQQ/NO/BdfFLKu59B
/FRf5NN+K7xjZSvbXw1vfZpqf6h+UuyHmA/frzZo72kLODy2aep41fWqM9U/
ivpXZWX6TFF/+hbp15P2L214Xdk/6XOJJaE9P/UHbzEf9T8kRsi1rj951cGp
i3sDum5YbOJ3hn6snLHUx9RAJfrbf4YGE6e+7HHSv4O+XfsyxutR9WF1uQNh
30q+R971pM9FfS++6fm3MTzU/24BPW9zbAR/HojPaX1Pa8OtLbeYGrE1v4uf
KccG+oOOYI7EHp1O/v2I/wDPT6D/Keb+q62bc7/d/n2Jj3MPT9oZpdy1rs5L
3ZfrtWvl6CHR14jv4DXotu8/f4979OUuqpfp7w/F2LeoK3MPp32M59MtjRO2
LQbPc2FDbLbFQy0Hsy0K8dGp/xRlBMoKlqrpE3erxPf5S6zPu1dyHl2Q/AsR
Ni8GT3QB6b+K3yZ+Q3/uFvFO2hv7gwfTd44YMbFiYh7EPohZEB/0l20iPqE5
95OKx7mVvLcRTizGH8yyhfTh9/ZgMu4r5E5A7Z/36UvZAwh/FuN/xrPktoQ/
23OeGqssohB/y55RPaveX9NvPduXuzLdw7mfFG9k2YmF+Lffry++BWyjbVUe
qy/MA8i/fiX72609mxZi/7JTX2RJX+iPrZI9tXvrWWr6X8+7s5J3tkL8g1/V
H9+iWyhv0D6xmL2Ed054/573XTH1CjMSPmsPxk6snf5wvnI/WUr8EPrwWV/u
0+LvvztU9L/nfVss1f/VqT9o9dVi7xduCL5MDKxYWJ+pj3T+HezYwfPLcmQm
yk5mI32TUnyk6yv9K34zU2rr4dLNkaG5/onnuaEhGB2xOuqH9AW6GWGugeCf
dBvqZ1//uOoTxaaI+VE/qI9gfQX3Qu8GvXw1c1cfsPr7UV58aUPubFIevSxh
w0J82uqvZoPafPmeNq81mDt69Puu//fXqfRteNbze72P8HZf5DUbFMJjQjE+
AsZ35pvqt9Xvk79tv0F+i9RRqKs4tqY/VB7YR3yz5sgXxZPoa1MMgFgA9YFH
NAYjrP5P/MNBjcEoiFVQf+tdB//pqP0+lYOl0ifE9ZX4iNDvjmcI1xvxLWLD
H6b/W5XyvTujMWdyvy/eUea9G96/4d1lqzAmlxfiE1p/T+Jfrm4Mpn3rUvBw
lxWS5yDP3dR5AOnTuwesxH+MvlZss/4k9FGo3YeYjqOqkTe6N/KOQO0nXe++
a4wM7mP32p4nGnMn7/4DkUkqm1ynI/44V63GF4A+tfVvdH85vrMqnllK8Ue0
USE8P/KsVopvHfdg19f0oWJLxGSqL3bP6d5TnxWvlLP/f7oud4Kt2hd8oL67
ryMcCe/VqonrI1r/Qvo71ffyHQ3xz/1gOdgSbZzFg9xdji2tmLBrK7Gx0tZK
/zfXKa/qi29zdT6LkP4StLbY3knn+U15iHn1QeF50j2Ke5Xj+X5NKsdHkXdS
H1If30X6h1L35B7b+x/F83m/7TLEOwezp3Nvp8/GRyi/MGPcXx+bn0XEDvXn
7vqdxF/1R2en7s5vxp59OT9vX5c76V4tRgakLEiZ0gqlyICUBSkDWg76Bvr0
c33ujL6xEjymvnJuIBxN+fXKGbv3mZ8HDkS/rm9Qv+l79gcfeEUhd3Tqr9T9
6emNwfA8U9vfPE9but3v0L7Vq+Gtj3H9O4mhFkvtnHRuXkcbthwTn7LiD/X3
tUpd+rRozQeE2NPv6+Mb4kzyt4+JD2fxfN+WYs+lXZe2d9+VYgvnsyLx1Sl/
Iu9gFn7/H4m9oE+/DQtGwP29/rJ/F2tAfefRn3U9L3ZnDyi+QYyrWFcxEbv2
B6MoVlEfxa5vYkrFlopBcHx6StkLHNKc+6PFI+rr46JC7vfyPP+ne01+T3cM
5P7OecnfUx/7LzHgYsHFAOwCv29K4eWeQ3vC8+Hxx7C0Wf/e//DstObcyad9
pPhBfSuKyd+3Jp8cT98u5/38THtOLkb2JiZBecBzpG9VF5uLFweC+dePmf7M
tAVQ3q2s6kroX/sik1I2pcxb2bfy1Y2IXybmy7NMMdh/Zdr6sxd/tD5tO6s5
+sj7oNeqi43CkwO503hX7Yebc9ex8vnVSb+A9G8pf28putELxWOQ//pibBeU
geiv/1HojuHx8X6Se+2B3K07D2vAXaQ1U/5oeF9M+k2kH80caW/KnHBuuJ92
b67M4YRy4b+Pm9gT75jz/uB1yPNlRzDPYp/18ayvZzEq4s2edg7Rnpt4Vqeu
t5i7Ml8flvs2lCErS75kaH6/3sdh2huEIQPRh3lXqzovdV9H9eWu1/fhOYq0
OSlzBvSZw4IHuriavb628N6fJF7ItMPFA7iWq0MfHh///QPB1/otvpnxWrUc
f5z6DhhGeh9pd/rNHB6fdOr/Kto/uJdh/G4vBq+/AW3r49nUpB3eF3voAf2J
kbY2bdizM3eM2B8xZmLNtBm9029nX3yRvyOmzXfp+tUdDKD4y38Ilw2LjwT9
seijQF8F+ihZvz/4+CXc3+p/YiA2MN4jqQ80bWPEN3i3q5gGsQ1z08fuhvjA
frcm/3Ot3rgr/hXdY7vXVka0fV/0Y/rK7lRGr6yjlLWxu5j7BN2fDkC/qn1M
f+Tp2gapw3M9/b0ULPHV8Oulvo8H4rtCm2/vHlG+r+6v2JD12PPae8oyxADW
zvvevasNvrb47gHdC+pz5utyZAjKEtzzvEX6/DyboSE+y/VdLr5s+pbIVJVf
6sNcX+Y+8/5s5aPL21bPY6V8z5RFiikTW7at9uYN8ZGqP+oFK/ElIIZGLM18
5XzL9Umub3JtpJbrDCZKbJTy9xkb0qb1Svneir3Ux4i+RnoructFHbu6dv2L
i+V7we9nKfsFfcVpQ/hkX/AeroXauGrrulAlvgm8U6DQH/9E2n+6BxjVEZvC
B7rzm9fW8My+3PXtmnh0X/DOxzC+d9hn98eeD5tjc3wNdR8HfS70KYzvr/2x
n9QXhhhI71PQ3lRfEWLevT9MeyJlrfro01ef8i59Q2lz+Edf7JWUNWjjqC9F
7TW13dPGwfswtAnSNkiMufdbqG/Qt4MYLbFaC9KfF3tzP5C/l58JW9QHA9RS
yXqvLfwUdca0dxz5F+6Kz4XW/tj4aeunf8LR/Tmfil3yTnbvZndNcW1Zkf5c
Uc75qFIfm1ZtW7WXU9+sz0j9QfW7HpN+c3Ps7f0eadv+kWsI+f/yfFgfn9KL
ud8cjB209tBD+2MvrL2eMviJXbmjUb+M+mc8kvn07UBkIdoMr9UX+XC5OTIV
5U3OR2Vnyoj1b6HMTtmdNrL6d3V/5NrqGu9ar3xP36/6iNVX7O2kX64+j9/H
MNJXo/6t2rOnuql23r1oaGyEtBU60PNQY555/u0u5+4iMU7Tk362+8ehsfnV
9ndV+K2pHQHPriP/F7XxWo0wWllAOWneGeHdEf+W4l9y35pvA+3DxKLsRdit
GHnKieSfh/wT/F5DHw89P+2bVXmT+/fuPLtS2SPps9Heg5m/P/YHMy523DsG
Oitpr3dNHEH6z6R/JT6kLn24Bnp0Ob429bk5VSn8jhmaOx2822G6Uvwzftgc
fwiDpdjKv9sc/x7aDGk7VGqMP5brefZBc3xe6i9BfwqW/a4l+P4x5fh6uKi2
P9ZfiLy+bcn81T+gd93MOzT2fStXI9v1jh/92a5UjS9G79zRP+OA41cfjJD3
IU4LfQT0483xz6A90mJDs0dwr3AM9Nih0TGra9afg3m1MdmK8fqU9AWHxce2
8lzxPg83x6fIlErs9TrFWpLnE+JLDMR3yd5isAaCB71RfR3pH5PeDL0H6fco
g6L8SozXnN3xUaGvihWhZ++OTwh9Q3xO+xevjw8AfQG09kWXPc/Q2Pdp72f8
ANpwTTH2kI6VOm91397h4t0s3tFyZH9sCrQt0GbgunLsJecemj2Ce4Vtlc8O
TZ8/rclvFxyaPYF7AzFYYrH0IaT/NO0/dq+Pj33xXNp77AZ9V3PsEbRn2LU+
PnO0P9C/htgs54RzQ38G3g2x7/Ccb4aU46tNn2xtldhIaCuhzO95ym/I+Pzb
Hf/x29TO/ytqewC94kDuk1oA+i7vRIU+3j0G8+Nl6ImVYCTFSjqHncvidd4c
HhmEeJQWvw/N0fnf2p8zuWdzMVne97MR4avhwRDMRts3gJ4C/WND8FabDMYP
sP6AL2M+rkr6S8Pjk3qxcnTG6o7157st7VmZ9BeIn0L6ouX4D3EtfJzxbyRt
sDN3u+hDyPuvr6xGN6YfGO8X83s4qSU6Av31KM9X1lxhTI+F3yTe2WfDcyfS
gwORmSo79c499ZfKTJSdKIN9U1nfQGS/z5L/x4HIW9V1/o/0Buj1eoO91IeQ
/sUnuccfFgz11pQf7prRnDtrtF8ToyFW41P6t4vf12LOkt55uS70ypVgwybz
bBXiS1HmUN8P+8n2UuwBDoI+Vhu5Un5fhwwPxkVf8+pH1dXfRp3n+m3uy7fM
PEvW9Hvbu5/V349CqnJ8xbjm9lF+ZDm+ifRBoy+aDRjTL5hfe+kPYSD+u9Zx
vaePv/TnPO5cPYr6/6AvI8rxXaNNuvjG2f3NNKfN2i94HvBuE8fIsVIfOVFd
vvtf0+BRT9n1h+c+H/fs7t3P8Ezn3pn8tzRHB3wtdf3q/Bwemx1tdzamvcN6
4MOzQyg/kjJrNSaP9sjeFyRvMYOTi5HZKbtzTb+8P/fxbDw8mOaPSZ9pINhV
fTzo60EZprJMv0FX9wejKlbVNtv25ZSp1mcPoP+UT5TJ1oen9/t4RvCsICZb
+9tSTV7kfT8bs187qVTDxrTl/sAHKrEFnsD8e34g+GF9t11K/q2Jf1aM7K+p
NfcdbTIQ//TeWXBAJecHfTke3RF/ht6xO7Q3mMRlK8FH+lt9mDruI/5QKfFH
CPdXgmEQyyDm4EHoi7pjG/Yl4z2xO3nMqw+js5TP9eXu17VHBi/nfYfauulj
bOPufIP9Foupd7zFR2qLXa21p2sgvt7ESIqVnKUruv41KT9PZ+yDlywEcy/2
3vsHjx6ZOx30p+B9Iau0BcP5VyX7r6Gjs6d1b+tvwt/GzvWZP3XlxPWZpO+k
pWwD+V+jjc205bWB+MY7j3p28uzflb2ee5hd9FXQE1sCMSv6v9DmQdsHZRji
ES6mz9e5nqjv7I7PIX0P2Sb3gxPED6qvGR39rnceei+j9zM+UokguY+9ym7U
eYffN9q/B/HZqf/ycmxMtTX1Tsx7KtFpq9vWJnrB/tgT7EX+DvJvCt/DGY8V
yH+cPkar8Y+3q99e0tfpjj+078bkjtUXK/mN+1sXA3AhvO+hvyNH5Y7m23v+
39K5x1k95398zjRTZuacmVNnzvmeM3Nmvt8zpUI9SH4rYVmEkuQuUrogkUi0
Iqnoou2i6CaXrrRWakXCxoPktmt1W78VueX2y0baSC79Xk+v88d5nO/n+/l8
77fP5/1+XayPglYLy6Cftr/RYwU0dejfkqMlV4tmytuR+Xl8C/kG8r1dp3lT
kvbwfDYyXhVvLHKO5B7JmZE769XczxsednjZ0WeBP/2ClnlR5Yt1DTbwfini
r/CQfDlyn46+3bnN3Z/DYw+vPfT5nywYz0bs8IhSf9/IYZPLhkNOvgd/xgl4
Wej3TGTPP7z/6COgp0A8ntwFbZ6O3Ia2r+t8baZvWnCuiD41fWv0B+nr0EcA
L46/15ByY5DBIldE1k5oofLJmr5U9d/p+fx3tfGa5Mvhbrym490TWn+K2BAx
JOIJg3RNNund9piW+azW+mJoEW7XMsdq2YFZc+P3a/+u0PSTYB7i7rMRTyNm
QuyEnCx43ldDx5b+peU7a/lVxGTAW5c73vdivfftU+3vrZG/l3xr0fAkXzpE
29ip9qu0P+9mrJ8FVw+Pl3Wa/pb+k9r2STh+dUFkrAQewj3JH2p/TtL7aqPm
XR/ZvxosfFed44dUnkGOAD6Ndru/rsUw3pc1nnedpudo++O17j+C/0kZ/zk3
Zs1AtAMXq7ypxhxpuNKDs+YWlRMTCqznRWyuT6nx1OQLt6j99ir7JbO/m7S+
oUV8x036zS5xm5uLZXKLbGMEx6b1f6b1Z8vtf44mItqIB6odT8cDBi+YzdXW
ryRGR6wODxv4L5+DyUkYg47+ZypvrTU02NBiu0T1U8He1rj/QIyKWNVJWuZl
ltU2H660Z8943R/PkfOrsQfNl7oeo5vsIwGHBC5JZ12zDcXxD94D4Jvxsocz
AnfkQKO/zWDywea/ovV1qbGH5PRG++HMamGOD1wf+jfsW2f91tT5x3Ssynh4
/HqGlZvzA/fnKx3j1Sr/s9r6n/CLmMZT/SktO1Pnc0TCGgAngXlQ/bJqcz7h
fi4CA1PmeYdF5hdxbgtaZp2W30EMUPX/1Hnpw9gXD7O4PSCuzPp72CdmDgHf
x5P0+0nLX0T/ucH5EK4d86j7QOubkzCG5f3Q8Va4S2g8EX/Bs/pg2p7Cm1V+
qdGxsSGl1r/4kedR7ctaOr9KH42+2pcJ82lWBNbSQ8MNPy/4Gmin4DF7pK7/
o1r+De3/a3Hjww8QL094DIz/IPinfZp+S/UriOVqfRu0vjHa5qn4G6j8isor
W9ifGz4P2/5V9T8W8XRoU8FZS6bM3+7cwh5lbXjedXw7ap0zR38DfBC587e1
vcdDcybhTqJpQLz1dpVnqu0LmrdE0w+E9rKdr/UdGhkPgdbdYpXbRebcwL1p
oWPv2OR3AO8CPGrA9/M8g80/WfMejuyfekrSGtB4aSzWMa3Wtmdon85OG3+B
Vt0jWn9btZ1aZy8jllmk8mV5YzV6sI3I+qXnJq05vkzl/9Tbf42YDrGdD+qs
NUabpaq/R8czSsfWW+UlkT2KwrTHLywP3vCSpD2HlrP9ep8LcorkFueH1t9m
jI0fGGNqxtaMofE7xaMVr9aOCevXoGfDNJwDuAdwvOB6Maaf2mg+F9raaPLg
S4onFt5YjGmnqf7aJuOuwV/zvsD/dHC5NXPgB+MRi1dsqsp6JpN1Po/T/hyj
NvnAGj9o/WRjxpuDcQLrxDPN+vHngAuBZhPx6aub7CNKnw78HeN5tHrQMAKf
zjPKs4qnFvzAq5rsOThf52ROwc97Z52LhXE/39w/8zTdCc1ycjGMD+LGLD6W
t6cy3sq0WRg6BkEsgpwHfNSHQnsbwiGHS/5X7Vt/1X2v/ful1h6ceHGSAyiE
5qPybeMbyrd0tdpfXm58dcda84XJLfDN5NvJ/fSlpr/S76+hv19glbvo+j/I
+07Huyvme+LRyPyofvSNSu2nyXiOWMrRpY5ProrszYBHwxXkwvQ7Q+sbj2Zq
wXqqaKfuVPktTffh+1/5m8VyySVZ+6+fAJeePiL6YKG1k6rUfmZkDgJcBDwT
Z6l8f+RcIzlGco2j1H4rsdWk8+nUoyWCRj35SPLt1B2m4/2j2jZTuUu1czbk
bv4SuK99mPbn2VbOYZDLeLfMeDYwsmBlX0o4379Ry29TeWvS+Gk8wX9J2z8c
r3Awe2D30JwAX0ZMgNgAmDP0eE8IjWUgh3x86JwUuSkwDPhtwuGByzMvYb0b
9F3xPkfTCDzmep2zNtWO0eQz5ouAxURD9jWuX+hYH5q1b0T2VF+ED2G58x1o
XqB98ULC+kKn6RyldK5ybFN1K3U+Pqx0vgi/rEO55qX25EH/9c+RvdW4J1ZE
9ujFq/fKYr6e/D3TaLreGlrjGK1j7pHVqn8ssvcbGIhVeR8P2CI87EbWGp9x
ddI5Z3LP3FPcW3hktyw4/1Or/R2WdH78FJX3lnoZ8BxLtf/PVdqj8tbAMRJi
JXwjiFeRX2dZjpljnx/Ze/vsIv7mnshYXzQdp0Qub9Tz8FMR/0t7sDoNSft1
gxffrbr94EW0rb31vnfReELrCT/K43S9eut42+h67ap335OcKrnVq3jeY14H
eHPyizxbeMYCQgN/y9gMjXO0zsEjsy9oUqNNTXwHbaIj09bnfyJw7rJTif0g
JkXmon+j38TIfA+m74xZzx08Fd96PIHxBn4aTe1yc77xa5iL5rbulSc07/6s
NZzQcvpfNJ+0vkO1vaMrrC+FzhT67y9V2zMO77h4ytqaHdSmSW0j/dpq+iK1
f1LtS9Ouy2j7z2TsMYJHKxobeI/gYY6XOdtoG7gPTV+6LzFwlVurfgLb1zEv
QH8IrobKrbW+o9S2J2PZmNuchb5d2rlmNMLRCoefDhcPTTK0yXqpzSTVj9H6
HtD0yrSxw+xzAW5g2tuGgzI3Y41f9L2ID3cKHCOGe/TvtGPHcf2foboNfK/1
HniH+CHvJs3rENjjFq9b2nRUeWKjY8P4eJ+l5dfzfo6ZEwg38Ku0uQ8cI/zU
wwJr/c3WNv+huu1paysTv+6suiMCb2uh6jepLkVeHTwn3+isY9xgC9B1JPZN
zoXz0yfweBGNfLTyyaGQS0HPdqHqf9Q900p1JwbWzu6q+3Obpvdl7T05HI6q
2m7i/uDZ0DInFM8f/d3zdX6n86xmPB6CXwPPBv3O4Wr7vZY/KeUxH2M/OJCM
r9GgR4ueHAu5lrPpA1Y5Roqf+d3afi8d2/xyn9/fafn3qu151lfLt9PvNLV9
X3WXavm71L47fLty6yX21m9KhdfJusmZoGV/SuBcClwQuN/sI/qipxKb1HSF
3mHd0FpN+1gH6HjuU93XKlcz1tW841Turt+4Yr7oJbR/tf0/aPtdY/Zj+0Pg
7aGhvz9tPWO0ccDMgp3tqvqBqn9cyyzN+vxfq/Ie7f/xWn5M1tx8OBgjsvbs
xLuTNr9X29s1r4vqv1F9peq6BN43NNJ/l/I7infVoxXWy2LMztidMQjxtUla
/ryE7zHutb7El8h36HwN1/JtM9a2Y97lnB+4W2X24CZe10fL7K+w5xPeT71U
3qXyGp2vJYFjDsQeriq1nlAntekPP6LC+pOnRtbOAWOHvtTlYDUr7AmNNzT+
rbQlJsE7lv7nUB3bc4G1B/CL3aD69aofA35T6x9a5nnoleFRildpdaX1WleS
q9W+PFll/xv8bdeTC4MDoenXtP1jYtbUHK3t79fvY+3LE/AB1P5WdNlVN6rc
7691aWtbzITfi9YlngflviZcmxvhQFdY8xnt5zfSHjufqt94dB7Q7zjEnBv8
hq5T+00V9tCZDI6M2HO1NfM+TdtTEW9FzjnfQ/rUrG9s1n1t1sm6uQfvzFqv
lmN/Xcu8m7K/y/261q3BsKhuPvqhmq7R+nI8K1rmUi27TNubGvh4jk34nHBu
xpD7r7SmLtq6N2heq0pr7OBVdVDtS3Q9N4OpyNpDBi8ZPLPe1bZXq82rZV7H
HYF9ssAepivtX4T/LffqWOLB2t916sN1KPE2xgb248LLCo4CPE38j1gWjVy0
cvHnoq9Xp3kTNA24N0YsReuLa9sLQnvz0cdcnbenE95OeIJVqv3zqq9N+B5j
fFOvebtLPCZhbILeKbGcDipPCoxxw28pExjfdBPcp4Q9ez7i3tP6kgnH5Ojf
833cqv0/QctPYX0qT4E7XFk832l7e+HBUx3YQwcvHTRWt2bsD3N8c3NIegb2
V5+h5c9Umz8F/j6h/d9d5WnF99k6tT1d1/8DTU+vd+yLmBaxrc2adwxYIzSF
UvaX6aT199K8jwKPsRlrg4HHv6Ch4FgxnsmNBedLri61RuvgyHwutNfB2DE+
It90bKk9JU7X9OkF98/pp4M3jpPPqrEnEfFnPI0PyznHS/4J/Qy099DU+0Lr
H0rfN24PXLxw0fhHTxrP5XHEp0JzMQ7oPrmmyXpIxELw6L0yMkYSrCQevJPz
xlDRv6KfBbZqbNrYe/rM9J3xZ+uv8keV9v/E1w+tqvWV9tsBo0bscmba2LUl
2r/HdL338/5W/Qo0DmPGEK7lmFX/aNzPAM8C/qKse6Pm9cvazxdtbWIoxFLW
Mp6qMqfo17THW6vV9i3yVaq/Me2+IWMwyvQHDjZzzIXYC/5A7Cuaz2g/g7FE
S+rZwNhLMBpgNabVmJ+NZzre6XC2VxccgyUWyzf3f4gvgamqcU6W3Czx2otj
1gAYzXgg67EVfTT6auSHX6lxjpZc7TmhucFwhMnPwi/5vMY5X3K/YyJ7b39R
Y3/vc0PnblkH+eV+Kn/fzMvAR7lD+9sjZwzyqoL1MliWmD2xe/STtteYUwh/
+JIGa9cTYyUevFvre1n7C6cOfSbwMa8kjKmFLwTfjlgsGk5oOaFPOqbGOUb4
jui7MvYCMw1fkhwquVQ4+X0j603gNfOq6n9R/Vkq92hhT3Py6wsLxuKAQQeL
flzo3AwapZepvqTO3ql4rB7MmUMBl4KcK3zK63W+f8brWutvlja/Hu/128Fo
hs6hkksdXeXx6RreOSXG5D4TuPyDptuhQaB7/ZHQsRBiIOjbkaPtpXvtqLRz
t20Cf/viWt/6wH0E+gpj9BuFX43Kg6vs8TWk1vFDtCU2Z+xH+EngWOfNvJNT
5syhvTAzMJduYWAvFdbBui7X8b0Sd/zvg1p7XuF9RZ+rB/d36GcHThx8N/Qs
iFXeXmI8PX1++v5ggujz4qmFtxZjgnMCe1TgVUHO9Sq8z9BAb25Nu4a0/ZDA
f3ZX/Yea/ka/wXqfzAYzoemP1aZ9lTnT6zIer4yMWXMG7Znh2v9YwvhmxhvN
dQ1raqwBjt/94MBa/PPUfl9gfz76JmP1vL2fdX/sdG1vsubt0vQ1gXOlD9MH
COyngPd4T63vjYz938gNLtO8A4H7E+RrF6n8o6b/m7H2NzF7Yvf7MtZ2BROK
R91Snb8NcXtswwfYo/UPVt2LWuf8jPt09O3QfCfeuV7zno65zRzVPRU5dobn
I/p+3E9oJS6HnxPaf/4Q8ldqP7fYf8TrijE+Y308O/HuxEMOv1jiZ0c3c4yO
WF2LtLGz03U+39T0Ht2zX6v9NWrfUtcvyztT+75X857S9Hea962mD1f7BcQF
db3XaH8Hck9wPdOeBgP3U9p9fPr6sw5xf5D+G96o5FzJvTImZWy6SPVfZ+yx
h9cefTzysWBsyWeT1wZ7iz5+qxaOERMrZnzbXsc7TOX5gT3E8RKnzzwq8Hjh
7zFzQudp+m+q/0L73od9UvnewNN4KuCtsFjnZWnCYxLGJrzfyHVtDzweYvxC
37avlpmteYeG1qZ7JOv8BPgstIro89D3ARMDNgYMJHqa4JOJ3dKHoS+Dpyl9
NjjNcJvh7+FlCgevW958q7vT1jSHv7ZI9/tK4onwe7P2KMWrFM1utLvxFMEX
DMwn2M82TX4v8X6CO7Bb09O0vzN1TO0z9tiYnDFmFOwozwTPBpqqjE/w6MC3
4Tf/hjpz1Jen7acOd/25yLnqHiXWg4QTguc4+R64IjxTPFt4Pg0JjPdcljFm
7/EG45vwKsJjC2048JV7MtZMRDuRGE/rjDHlxH7wLMW7FA3d0QXzpfBWRbPy
toL5MDtz1ixCuwgPxdlpaxCjRVxL/CTnHAK5hIn15uuhAYIWCHoGuzLW8ETL
E77RgYw1atGqXaxl1yY9JmE8Q/zuTzlrZuFdRkyD2AacgnsKzifggcp45K68
33G86+DX3KVnaazqz8v5G823eqLKHeusKYa22NrIufDuJc5Xv1lvPg4cB7gO
D6MpnrSGfoda588r6uxve1e936+zquxnha/Vnaq/IGf/FLza4EDh0QKHCm7U
Qk0vTvqbVldrvYAfNW+L1ldZMN8W70cwXPeqvKBg7aWtjLWaHGPDCxNMFbE3
PCTxkiQmSmz0u8De4uDZ8M5+SHXLVLdX22ut7Y1X+wk5x0CJhc7HE0vTTdrG
LTm/03m3g9kbpOkH0cNWfWeeh5xjQsSG0NRBW2eB5i0E28D9mjY+GR80/NA+
jvwO513+LXh6xmJ5e2nh6YW31yc6R99oXQ/qef0sdPmBhOMJPRqMlyd2TM6X
3C/5yrkJaxaN1bq2Rcb+4AGEFxB66t9qe9/od0Vozwm8J47UOn7Je4zAWIF3
1hmB/b/wmiWGuyplPBH4uhZFPiH678TC2x9iv0c82fBm+1vCfmxzQ2PDGDPM
YV/1ezXhPhl4ZfQj3gPvr98PoTWW0Fq6L+H8KHoYcPno09G3Q/MC7QtiRO1D
Y+7A3sHJB7+3S/u3W9vfmjBfeXto7RNyruRe4TDgOQqeGm4D8Xj2lXgO3ojw
nVn2Td1fzXQ8/2W8lDBnHH4L/dM2dda0uyXyPYw33Pk539vwy1pmrBkJnwJ9
7x8y9ovHmwhPH7yo8evF64f3/b5ye+L0qrXe94qMNaSfbzAm67fveKWxWugh
490Dx/KdvPsE9A3ggwwPjOfHK4ic+nTdPw9ovx4Eq6Xj3Vfre4Z7h5j2mQ3W
D1+eMUb7yQbrG+/N2M8Jr5wlkXOTaHTgt0ifDy9qcsj0BWdwfyWtQUz/GE2B
t9PWM0FrAM3/KOc+Nn1t9Ff3q7xJ909FwZ54K3POoZBLIWf7RNaakORy0aPG
YxVO5It54+l2kj9NWQsSPgXeM3BI1+Wt7/tUxv5Am8CPat0VSb8PynL2cGfM
h2Yx2sW8ixhrMubEzwk8ycmat1Xn9Dzu30ZrvcG5mqPpHP5GNX7mtuh899c+
HKNjH5qy3xn4dbRZmZestyZW25z78PTl6fP0zjqHSF/oPb5JVc4JgQPHEwtv
LDgHEwrGY+1qaQwUWCg8hPAS+kHzAt6HWveFYEdi9sshJkBsgPfjaYH7uPR1
X1J9t8DjPbQOwdyCvR3cZA9gNAjm5R0jJlZMn454JPhPsPjg2eAybNW846rc
h6EvM5T9Sfn9P6/g/iJa0GAqwFaQ7wdThKbK9aofxPtG+5/X8xOq3E+/Jq37
ypT92gY22RMejunzeeO58U7DQ6lE0wNUn8xaA2hc3t8YvjXEq9CGXhP52n/V
0vlN+gdoRXMOwbMR76hr5RgFsQr0PbbB1VF5utoOKBjLAgcVLuoAzatv5WWI
j4C/59tJzo3cGxqZaGWCYZ0ENyhjvyj40ROLeM3+rczBR8/siIK1yS4iDqbp
jYG9h4gZETtCT4y6pfqdVrA+yQcx7yP6I2ld7x41jgm0SvubyLcRz1e8X+Fg
wcVqieZYwfyqEk0fVJtswR54eOHBybq5YL1QvL1Li/qg92l7F5d5GfhYddre
ZVr3TO3D77POH3NuwUCChQTPi1bpHaX2o8QP8Vpd/1bahyk5P+M863gET47s
n/F2S3sIj42sQYgWIfPw07he53x61pg0/C6HNTmGSTzt60bHgK5Fhyzu2BAa
MifWWeMDbRn0pLrUGeMxoshBy9Y5J0luEv7llfRVUtYKm6nf4THnxvBi4Zu/
Rccyv9gXmK1fNy1/m85H14LztXiS8g3+NHS8F2/5v/C+y3gMzVg6rnJr4pmq
vyBpvYAr8HcLjI0gx0SuCQ4hXMJCzPiqyWo/JOkc5lq1v1nbe0/He7euyVq4
ECrvyNoT4VbtzyS1H5h0zn2p2j/YaK8UOKkLmdb2yqocs5qUMb43nbIG8+KC
+0TbtOyCWveViBd1qrMGLFqwaIjiaYfmKPxK4nloJs7W9RsYOd+AluOZqp+Y
NT4XrBaYLLBZE9V2QNIa64uJ/2p/fq20Z/rTGeOdnsk5Hta/yAe6MDCGnNwW
OS9yX3BopxacUzqfd1pz55rQaxuXtIbHllaOQRKLBHMJ9pK4GPExYr6NxZgE
sQk8ic5o9JiSsWXbcsfL0cesyVqDaXTeYxa0jJ4OPJZhDMhYkHzJa43mS8M1
gXNSX+93au+cY2q8a4lBEotEE+pDuB0qH5Vx//FhHc9Ilf+l7Q2o1j2q8zlN
5X05a5KiTTpC5SUZx0wfKjgmSWwSTEmvvMd8jP3o89H326G6l8vNAa5JOybI
OYCjckej8RAPZKyp1KfB/JC3U8ZQ3VfwGJPcGzE1xp4ztS+3J3+T4y95Ruf3
/wLHhuCw4u0LXoJYFBqzaM3y/E7jeLQ/fw/tIYSX0Hsl1j/Dr5prB+YM7Blj
oFWq+7bWYyP4ZmhLgmkuiazZi3YvGhs3NVifdo+W7azyIJV/1Tr2J6xRc1WD
NTl41mjzU+g+LX1bPI3wj0FDHi15ON74w+AveLTKn6vcLOXz/VbWHrB4wcIf
PKXanhR4U+DpirfrCdX2k8Bfgmk4kHAh0V9rHnefkb4jGvpo6aNRj//PL5r3
Q8IcMrhkVTre88u8jRZa3zitI6w25w48d229vbfheBBvB2MG1qyXtrE6tH4K
2Oe9WufPoflyaG3/qvJBlTNavk3cmJrSyO+Pc3XMc8usF5SPrO2P5h5+YOj7
864ZpXJDZMwR2KMLS4yXBT/BWK5t3PgfNDDRwpyq9pHKBXKC9D1VboqsT8S2
ZqjcOnIOg1wGOQ7y6XCg4UJP1G9WaL8BvMlGqH1dZH7FTzpXcdXfpOnbdD92
B+8DJi/t/sI5aY9PwJpwfsFyc09wb1RF7st21/rimp7RaC833vngTxlzMPbA
cx78OvgqtP2O0j7MyjsHTi58U7nxDPjnRklr3r+l+6Vc6+xabc9f8MrgRdAm
ZMxG/xrPX7x/wZjAz79B9R/FfI+gz3cDY3et7zat7w30B0Nr46FxRT4DTTC0
wdD8Ql8JzS+0v8Bogt+/Tsu3BR+oc36E7tsZWr6b6u7GQz50TI7YHDmj82vt
f3VvzB7zeM2jAY4W+Piivh/6tT9r/4/QA9+u0f6MeFnegqZFyv4qePniIQz+
A7/cM7W9SWi8hdasQ7sOjbrb8u5fHqrrc4fmTQ2doyRX+UWZ82ELI2vpgfEE
6/lJxty8I7VPR6OH2OhvP/2jPQ3Gk6HNMrbM+b5rVV4a8z6jtztC+3ui1jdS
9+uNOcfkiM3VNTe+hPsHLOI7qh+Nl5jeee1j5sTDje8Tmnt1Wdz8oI06P301
fbl+E1RernLvuD1L4g3Wf4bLAscArgH901zanA24G8QkiE3wPkZvGr54QW2H
Ef9OWQ+gne7d9tX2i0dTGG1hPPXQ74P/tVr72jNuPRH0RZjeoeO9mFxH2lqW
aAR2RlOv0VgfPOTQc2hVMBbqqGbGZ4F5BPu4U+/rVMH6xAe0rsO1vbaN5gzB
HWIeesX01/N11ttGLx/86Xnan9OLeNy79esXNwfhFrCwob3rOsTMn7svNHci
X7w/yGmS29wJ5jHjnC65XXLY5JPBPIJ9xHMO/TOW596CYwjXEI8SvErIcfTL
e3xPrKAdHlKN9lfYnDTHZ2toTTy08dBAQC8ST3OwEdckrNfRGX5ZwjER/OXQ
y4BrQM789dB9BfIZs2L2u63I+1sN5hbs7Ridw0+17lJdy/8UrF/1XcwxDfQw
8UDEC3EQ77jQ3/ttWfufrmgwP/DXGr/j8JDAXxRta/Ss8ylziuAWkb/AjwSO
H1y/KXHHU9Af4ViG6rc5tMbvh9ofAJxo/5KTJjfdvdz4LvLbaLmgUdVDxzKu
YP8GsL7fabpGy7fQupon7N/J+O4Gbb8SPHxof0/qLtX2x2n6Ti1Tq+VTaMwU
rMmCNgseN+j/kVMnt768mfPd7CP72rvC/VOeJ3K/5IDXhO6vTtW77Cz4uWn3
8enr4xmDHh+e83jPT09Yv/Ixla/Q9ehXbf4r30C+hWjYz8k7BgfWuF3g2Nzu
RmOZwDSh740eJusCMwp2lHcM75rLEtZXuVO/LSXG5PK9HanrdVLS+r7o/HaE
U0i8LWE9eMYIYDUH5Tx2IKaKv/IJxVjrm2rTV227VTieAH+Xfe+vXyqy3gfa
BXgojAzdX/yHttNT9cnImHWw63BI4IuQAyAX8HW58VvoRdSQG1b7ek2/XO++
GJr2aNufHDqXiEY/Wv3Dtf541hol8Aef1XSzao8PhxXHH2emrUHB+tDcRHsT
jBjxxTC01ysesuiloDcJXqMqsPY2ejWcS46ZY9+h5bOV1mRFn5Xx3T2BNWp4
3jgHnIvXdX5ebXRsGq4inMVzc+aD91L9vTo/89R+kY7pnGrPa6ll/x+morEA

         "]], Polygon3DBox[CompressedData["
1:eJwt13mcj+Uax/EnjH3fxjAVkRHKIFIOIiFLhuw0jqV0CClxSJhknxlR2Zcs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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl00lsTmEUgOFjKtVWS0sNHUgshLaxEFOVRCyKRKISQ1kIQQ1tqepgKEVY
isS0qxgasZBSJVI2NSxsTDtzkYhIlI2kkajnxuL873vOPd93v+H+UzbVVtQM
iogBMSYzIvHL6RH3h0YU8jUTI8pwvdjCm/G8aOBd2JYV8QqPaF5h3C9egZkm
alWr5MV8Az4xZjmvyYjYjq+MfaF2ku/2/Co24mu1h/yZvl7sN883PsAHj4rI
HxzxZnJEzuiIUj4DcydFrOOlvBEL5WexUxTzF9gnFvGMIcaIDXwp7hoecc/e
t/EsTB0RUcXfZFsn7hBv+c6kV7zj1Vgjpo+PmGXNtbzOu1PG2Av/OiGiXr6H
z/b8vTF1fK+YI6/2fJr918vb5PtwLn7Q18Dn8RmeN/KV3nFR3sTnYzMWqZXy
Ej375Qv4TP7R+APyS/KDeNQaetUO8RbxiR/GI+Izb016xBd+DJucRbczOM5H
Y5qz2JrUnVV5sl9RydPxh/Ms48/xlvjuTlZ53xlejg14wd2dtpa1fCqO0z+f
5/M8zMV+9/3X3f5O1p98C8YMU+/hg/AK7lT7kxZxgu9Sq8KNan1qy/hXfGye
It5hnlF4Tf7T9/hSnOK38Zyo501YKTbzBUmP7z3Hfgv4U99Yi3PI54/cZx5a
dvRw7eHqopAUyl1DLLGeXCyRLE72yBfhWCxWW8hzeAc+MCY7+a+Jbj+OKSw3
CsyXL7eEuKHPEmK1sde5Tz8g+ry43QBbjXaFu/pH8jKeigdMdEfNlUUTt4Xo
kqfgMNHJbTNcXdzkjj+ah///3/8DhOJ5aA==
       "],
       VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwV0MlOk1EYBuCPBcINYCISa927FJZoFd05NKE4AEJdkNiBtVpE64SKIzEs
gI26NzHQ6S4YHABthSvx+Rdv3vGcf0jnZ7Plroiowlh/xL3jETm8kY64T1+n
H+AbuCar0DfpHwMRv2CO/4kLJyLaUIS63a7sDN2dinho85sv8R0owz4/iC+c
jJjX7/GfbWdORSw7/5cf0j/S/aGHoQ2P+WPyjN0mv+58n31VPkIfcUeGvwij
NreSb5E/0dfwljN1/E3/TP9U3u++bXlLfjTJZU26Aef5T3bPZePueoEncEO+
QE/SPZ75ku7FOduOu17x//AOfJVfsk/pDvgV965CRf4FXtseJv8y+VdwBe7q
J+wXdZf5s/pruCB/I7tKn5Nl8ZxdWf5WXsJFWIN3/G3v992zm3Aa3sumZB/w
NG7JPtJ5egnfwf8B6GxSXg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzdSXFEUhOGDgE0IN0NCBimeKryLEGyAEh7NY2aAJZBRRQBIeBBe0g4w
a8F7sQY+gr+6T/d5996XHk4GMgURMY+RrxHLJRHfaXc64hqj/G1pxD1WdHf0
qCKilR7TjsqI2vKIQ76OPsgTeoU2/obW4xoNeJSd2D1Fxvnjvv/HN+qa8KT/
Y/6Ldv4FzfIWPPMp+x30FaveUyLv5H/yY9565sxf/Djfw99ggl+TTdJe8y2m
+HXZND03b/A/+E2aoReyLT7ht+kMTbv7zV075seyiP98n71K+ZP53byry36+
IxXRr1vQVdHEvKfbpl32Zuii7ouuEN/8b7c8Ky8yF2NQltBLDPGzujnkkcMO
fjsz574lZ1Xbq8G+LC87oLP0A/PAS4g=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Uc2RFEUheGjYy2pgxYWitHIlKxpAHLOmRKnQEOOM2AucktOPV81/vXv
s++9deu9l+juTfZkRMQgRooiPksivjAsV/ELqnFbGpGsiEglIkat9ZnvUGPt
FbW4N/cjpyxigC+5Tn/O9dzufJaci0HrV9ygv+BGzuY8DFnLt7dJ94Ykxtw5
rG+W39GCcV2Bfa3yB9owodsvjpjka//1QJ6S6+Q7TMuHuhmuN99jVj7SzXGD
+QHz8rFugW/MJ/Ki/O2OHyzJle7+lf+wbG607xEr8qn9q9xkfsKafKZLcdL8
jHV5tzxiDxtyod9rTz+Hd9DBm7pZuTP97riLM53b0l/xjP0jzibS34S39efu
2OF/LW1KcA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0Ek3l2EcxvEfMpSp0gplOFir9BYsLGnhnAxlHs6JWvAn00tAAxWZh5VC
2fNiLCi25nwW3/O9ftdz3/fz3E9JS1/t26SIGMdmfkTO44iz4ohsPucN3fiT
iN7CiEPu4TGuL414VBQxKnfr9uQuzuNq+0b0neY/5m5r35dE/JbXnZfl7Eys
yaf6l1iVdwoiVvjEXIdleVu3xFPOeKGrwqL5nv13UaFfMGfI6fghp/E/60Yx
b37ovQ8wJ6/o/uIZEr7zOX/XP+VU+yr5Dn/TjcjHSDF/NSdzEmblcu8N+b87
zph/+c4Da7/IP+XPvMX7uk9yh3U3aMdHcxtfo8Y576z54H9N61t1V2jBsG5K
1+/5ES51bzCkn9S/li/QjITuvjuWOS+Xm3S73MiDnuXIA9xg3pFf8bL7b8sT
uAUCd0x4
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LlOlVEUxfHtE4gD0+XOkmilYKHyBIogJCYm2FhQqoBoZYNcHHACUUKC
LYWJCKICMiOgPguCQsCh9/cV/6y919r7nPN9hfauy50HIuINvqci1nIR68hm
IoazEa/wjT9EXyLDPyY/XuQVIr7KBvkvkJZ9ka1ig7/N+4ldfoP5e+bX+TX6
HaSwpu/h/8MvfXVyBm+6xjn0L/8KVtRn6Rksq084rzZ5C5b0t9MRV93bh2uy
EXOL/B/Jm3lbyVvMns5H7KMeC/Jl2SX1Ct2WD9o7Z7+OV+TNJ++lzfo0rTIz
4KxNPMecvJrfJE/RP/YrzTyTLemf0s9mKtUXzVTRCnmBLiKPWfkGveHe1/bb
1K1mWzAjK9c3qiuS77B7Sr2Hk5iWj9m5a/eC/jzKzXT7H59kj93/BEd5/fQR
msx+lN0yc4TfRT/oi+rfziphSl/Q5/FenaP7/F5M6jvtdGBCfYe3h8NmHjr/
Ad7xb8oP8e7r+zDOGzV33f0LvqVMVuL34q0sy8vhIH+ezqGE/+bvZgU=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DlPlFEUBuDj35BlgCiCCMiiJlYgrSZKYYELSi0zhVtcKUBJtLBxXzp+
gqAoizIwA8wwI/4ODYprrHxu8ebdzrn3fl/jSG4wuyMipqCwM2I8EzEBtfUR
ffC6JqKlLuIh/QjqoB8GmiKmda26i7UR9bIZvuiMS/zxhojrZt7IVmWXZRkz
b/k1Pt8YMUuv03udsQXv+DZccP8Fu8/N7OPz/HvdnDOX6R68gr/pingu3YFH
7Xxxx1f4rluTzac78GPZE2iXl/hWswu6O/QVbxvCvenNsCi/hg/AQTitm/KW
YTsfdKf4q3YGdfPwUbaAnzr/EH6Gt92TNV82u6Tv4DfobX0F/+CPmNtF5/WL
8iqds/PCXWfpG+l7dWfoTvM/YYVvsHfPzNH0j+j98gFc0H0yexcmYRhuO+Ok
2TGzt+ib8A+KZkv+/RKdh0n9qqws63Ler/T/+A1+N/0bDptZl1VkzfwJeyW+
yj9wxzKU0xv4Pfo/6Zv5bnxfdyx9m3f+5Te9raL7jF/KXkGP/DxflZ/D/wGB
rHL6
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0TlT01EYxeGXSvkANC5IQHCEVjGgIFFWSykcOwV3RS0V2RUMLR9AgYKO
76AzApZCQhbcN0ossEFgxifFb865513uTf6JvkeXH5ZFxDxWD0UsVUU8ORKx
TAvHIopoORrxqjLiqbyVv5KIqKiOWNN/ynkHHw5HZJyTak2YUV+VZWVrdJ0u
yJeQcX5j/1ucNjtKD8gPos9918wOuuufWlZvWvbMOeEN7ejAebUGfRtqjfw0
XdfbxiftG9K/TTv1dqFXb0rtNT+sdpHv5ntwgc+YX9F/hu/nx/SPOY+jWs8s
RszV0I/qn/EJ7frnZH8wqv5FdtVsLa3DrvpfOzpoL815Yye/pX/C713Gcf6r
3m/oUvteut+um3TCzHPc4K/bOy6/zb+QTeIW323mEn7wv/ETab09sl/8JpL8
HnbN7GMPJ92dVXvHN6mlabms3uwifek8hRSf9+6cb7jCF/g8X6QF+l62wRf5
ZntqS/9R6Zvb/diuHD0rr5Pf5e/hDvI4Jz8hf8AP4D7+A571bR0=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0clOVFEUheENQ3CMRLDBiZDwAtjwAAIFFAVCgR0PQDdiCohK0STOTYwC
YcZzgNI6VOkl2NIqM5rvDv6svddeZ5+Te8s6u9NdeRHxDl+uReRuRkzeihgs
jSi/EfEQNai7HvGBDvEraC2Kbke8LIs4M9tzLkW76KjzY8hhBNUyrRiQ/+qO
byWg87w19Zp6Sm5dPU2H5F64p8G+DV49/WHvMG/OvM7dKTTyx+xIJe8wa9L/
lJuX+UXT+o/qT3hlPk4L5K/Kz9Jumdf8jNyme37rD9CsP6RvZSpl/6hbeH/p
PmrU/+1qRgsyqOW1Iit/R6Ycj/ST3jnijkNajwac8xeSbyPbpj6SrdLfxYX+
Hs3Sdmx516J+xlty8jm7HvMb7UmjQ32cfHP+Ca3AA/li2TfOhMx9/RO5PPW2
fcv6JbSZj8qt+/47/A2a5Z1iU70i852/Sj8n/1T2qT0T6kKZK3iW/AN359u9
K/tc/57fLzvOP5VtMsug02yKTvD/eWcv+tCDS+bfavo=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0ttajAEUxvHliYuQQg6rmcn+jEvQ40SUEyVRSgoXEdllU2Kop1Lpagpx
lk0hRZuZaUr4fQfv81/rfdda3zebigsdp9t3RESWiqURG/sihssipvdHDOFx
/Tn1Mewoj9i1N6IdUwfMmq+TVcu6qIoKvK2KiPOUVy/sicjhpr6B1tXzvDU8
6MYtt27Sqv4q7nS/DY+6ddbtGjOV6lbeSf0VPIEr5qfMvvKOl3kv8Z+5N7xa
O7/lk+o8ZWUF2QvM4y/Zc/Ud9SDuNt+rXuafcfsZr8XNAVzi3ZZ1e/ciXeL3
83PuTtBP+bb8LzXLSngXMadflPVgk/tP7TTxn+C6mXE6InuNf/Axv1H+CD96
hy3eD/sZu7P6D9QnG8WHOIbf5Q/UaTfuJx6eMv+NP6redOMeP6W+i2s4Qof5
h+iG51XruzFt772bC3bf4VuaT/4PPnM9fU1+Lzs19CV5Lq9AGf1nfRpT9Cn5
bvmd7nW5W+X+9eT3xTnZCnbqK/EaznhO0d5/WSdzxw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DlTk3EUxeEbUEAhiOAygywmJQ1gxSIuiPbaKgTD0GIDjpq4sGojuDv0
ytKouH0ZZdNGP4KQgE+K35x7zz33/t95U9lb18YSEbGIE6ciyk5HlONMS0QB
uzjO/0d30Inf5gPpiNVUxDGzK60Rl9GgfkPfogfXZW7L1PNXmiKWcVSd4Gf4
deq/OIIZffCfNEfU6pdkp9UD7lxCkpc3z3p7BDfRYqcZNWbv5afk39FGuWpe
V+kb5LrppNl33x76b/SweUY9jCGsuZOz10YPmT2W75Drt3sRVbwbcgsYxL7c
BP81XqHS/Iv8Vzyy+5muoYL/iV51+6mdh2Yf9R9w0CzJS6MW4+7MmR/g98pv
e+cXEpjll/NfyLzEAp7jGUZly8zOqy+g3e0tO5ulXf4GPen+vNxK6T/z/mC/
MWJPP4Q99QNvVNm9T4v6aX4Rlbw8r8DL0Qr9PbqrnzAv4K7+nLf7sMPvpWdx
h7/u/Z/4gf8iDlYM
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DdP1mEYxeEbpEjHSZAmrjoJowUShJ0E1NUoIyaawBcwMSDSBKSDI+CG
iYCNGRsfAuyC2F6kyfUOv5xzn3M/z79UXrvZ2JoSEeM4XhKxdjJiHZ1lEU3l
EV9k+/QpFnBPnqY/eyriqy6dX5Qv4b4uw/xN3sUnZNvIwjn73+VFuKPLlm3w
xVipjNikJ/ADJZiXvcYWf5F2O3OansEl/JTX0ScYcHcNbauI6PX8X7oq98+U
RryR/zb3OP9MltA/pznI5P/oenUvzGnOv6S5uOvceff+1ffpj9qtQRby9A12
r/MJfX/ye/hc5OCBud7ZZns3zNt2qvlXWMaAvtj9/5L/g87iLXbMH+wP6lvo
R+zKPtFJ/S135vH57qile7ohu7O+s0B2Qb8veyjrQKHswFyKd87/p2UI++V0
2M57eYp5hJ+jYzSVjtJ23Som+MvuOiIf5x/TKXol+c/4SX7K3m3PL/Re0+ar
unTd5+T7ogCP5MdohnzY/zsEj6Rhtw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0blW01EUxeGjFCCCQEKYMkfAiA8hHdQuK0WGNHTYULAWT8GiokUFNCaA
A0MJiKgd8zvAOwhfir323r9z7/nflRQr71/NPYiIRcqnIz5lIwaKEWVqzkSs
6Qe5iENal9/wabOxUsR/+Yh+0YZZohDR4k6SH2O/6TM+72w39shsJR+xig3b
0arf4FX5lB7rBW9o40V+hrXLJfmLO0/kLjtf2lfVO/SnZjPOPcQG5U5siC/Z
e453Nc7wr433yTX+gS6wpD7s7Ee9W551Zxm/pJT+zKxu1iMnfHfUNzb1Xr1s
VnGuCXsu92Ej/Arrl1/INb7d+D35Fq/z73zcnbf2pfVv+ib/ySewjPxDXrDn
mnbld3gW35FT3thDe/IknsPv+Gs7T/gf2jeb4vlM40+N+Cv/oyQVsFv37wFq
AUGb
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0DdOBAEQRNFGAk6A38XssnjvfUBIygnwLoAAIYiJiIGIEwAR3nsvcQHc
YXhB6/+urhlpJjWxNLqYFRHLpikRkUpGNOJmRcRkKmI9HbHLD+Rr5RFbfNus
8kPZDk7pJfT25XsmY0+7NXvPF6/kLTyDrfgtq+JtvBrb8UdWwzv4NM/2vk5e
K+vCGVmOrJvXyXrwV1bPe/lVaUQDzyuLGNa7tjfa+9yasB//9Jv5AJ/luXqD
/Eh2q9+CN3iM9zjmXUmdDd07+4n8EcflE+aBF/neU/kzH9GdlE+ZJ3uh25lb
EqdlJTiDL27FPGFWPHOuU8Zn3UpxDl91PjHL/71wf7fP2xfMG+/w3KW8wN6K
+fghb+NDvukfxAc8rA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LkypWEUheGNwJCQCYxHuwJt1uZufWjzTCg6OiCjVPU9dKAMoUTkNLme
zPMsxg24CI9g1bv2Wnt/f9WfmJkfnsuIiB/UWhRRVRzRgqlERHZFRBu/Uh6x
RquUL2+XbfG7dpfKIn7jjN0O+S/5H3Ma/2KB/U55E27Ssr1GXNd/lm/jDn3h
f+qKdMXUZf7o/is+mav5JD/L59jr5mtkPfhdliv7xtfKevHVm3mytK7P/Amb
qZ+vlt+VRNzTgPkBH2mQf7ZT540h/h+ey/9jjZth2R5/IdvHEfNVacQBfyk7
xHLfXbS74Z1R/bX+SH6lP8YKfYLGdDe6D/yJvAwX3C25q+ST/ms33drJwlM7
mXiGd7Jx9/dY4uZcdu39C0y5nXh/21yov8VJ84t36/VTfANO4xvjdkkm
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0btSE3AQxeGlRgWRwhkxJMwgotLiDKKFdiINrRGUaDQmEFEujrRa2jnO
KHLxDbw8hgKOAiEXNF6gE94A/SjOnN3f2d38k6RGi0PjDRHxnNInIvraIq7z
fCqisSPihvoCNswL2CFsRP0qGfGaWrCjdBN7p39PT808aY9oxTvpGN2Sz2Gd
8jd87WTEt0TEVfVXPipfUGftvjQ/r16iRcrITtvrprf6j/wD3cZ7zf9wq053
9D/5vizpRjtl5Fk81A30Tzboxl3sk++1bv7wwXtl97DP2AZ2xdxlymG/9LN2
jpg7i52h+/gu36O/9NtMHnvmTpO5P/qCfpvv0Jg6gS+7X9Kv8HFslW/qv/Dz
8iK25vdYpzLe4/Y5eoBvYKfUJV6RDXhTTp+298LnTpjZlHVhZV41U+XXzFX4
Q3mNb1FN1mxv1t4jfEt/HP/OJ/VjB/+rfErd723TvI5dVM+oL/HH/D9CCFmB

       "],
       VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwV0D9I1HEcxvGPLgpOlr/zPFrMxnPoILlwuCDCphCHBiPoDzaYZ0Zt4nJC
2pQFDUYkHG4VaaX0h4SWqzUHIdQOA3EoiECJ0MHXb3h4Pp/n/Xx/f76d124N
jDZExBwtHonYPhrxmv/hS50RNfM/8ze+ZY+2iE3zVBIxTc32HXvSHpGhgeMR
D+RrmYhW7C+Wlb+hDprFvmNPOyJy+D7+Vr5MJ5xd4lWdDZ1nOl06Td4/ko0o
0wJWx+awPNaKDTs3ht2mz/hPvIDlsGb7Km3LirKzul3yh7qPaIZK8m5Zopfg
ffYee9G3nKbf8qreBXlJXpKdoSeemdH/xS9i57Hnei+ojRK6LO+XL5gX02/U
b+dZGsIGsffmD/Qu/UfZddmBu8577zHPXpHfld+UD3pv3r9fSu8L+4J9pXG8
4Nl3dK5gBZ2r/KTObnqX5orOBD5kPoXf4L3YXnqf5j7n7+tMp/dt/09lOof/
0K/TDP4Yb8hFNNKkrOLcrLwqv2efonn7K3sT9tL80bzMa7xF9sm8aq7xdX4I
wu5dGQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0L1LlWEYBvBb1FRoOn5kHhwUHXNpCFFIwSAFExs6Q6B5EEkQXXRQRFAs
bSoaGs7qH+BRwxZxkODQpPlRYRpZ4pCLtOig4M/h4vq6n+e537cmPfJ0OC8i
3sJKIuKkNOIjPsOrNRE5erw8YgIuZNv84p2Ig7KInkq+IuJRbUQvvUNndQk4
1r/Gu7I5vIeL7kYs0f1mT/Up596597vupewHLjazbGaQ/28mo9+X/4RLb/+z
07l8QX4o+3Vzxl6XsiXZPZzgz8wV8htwX5aUldCN9IR36/jP3mnhG+jWqojH
9HvdA/6ZPbr4FjpFT8tTfDufNNtDd9Pn3jl2zwD/nE/YZ5jup690pfwYP8RX
05N0s7tG+Xr+i+/chK+wBVPyJ7jJrp14F77BqDN7+I1+xj6H8NDMNP4Nf+AI
Puhf4b/Qpp/FSWczN/9Ml2/3Dnmv/AX0QVbeJUubq/dGgZlCWJPfwmkz8/DJ
HTnZbXPr9A6dwwf4GhJIWXM=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0bEv3AEYxvHXLJrGaZXUcJLWaBWblqTOIpdKBI26cxTRG2gXISlnoLcc
g+GMp3aJ9A+gAxsLbaMbUzs0DNeB9GP45vu8z/v+7vK7S2by6fc1EbGE/fqI
qUcR05jBSUPEHJ/ycmPE12RELc/r6ngFZ3YFPudVfoAF+4f85knEhX6Mf/G7
1oiM/Baf3CTcZOVLuwm+4knOYc2+0f63rt5zJfMfeYOb9ddyWb7hbW7RpdxV
zRXzP97hW97jO04kIv56hwNz8XHEIT/Vddod6J/JXXI7f2mK2MU3fYe5X9/F
g3ykS8mjcpqr5kl5RM5zju90H+VZeZGPzR/kV80RvUihD999x0/8wImbdTcl
91tc5nNdRX7h9iW60YNN75r1TA7jWMM6Xnun536/AW7joq7gdsj8WR6+/295
CtO48Nn/ARZxTYI=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0b0v3lEYxvHbVjRRPDwY1CMmg79Eo7EiEa+LkA4MXhPPooR6j6FTw8Yg
GgMSUS8dmmiChQGJBBOJwSbx+Q1Xvte57vuc333OL9PW19ibExHfabsoYrY8
4jQVMYf/MS8d0VMS8RHPrZvLIi6wCburI/rVCtQuZcP8FY5goeyGH+er9N3y
WT4lf+An+Uecwics1rPAPyd9pRGL/BK9malGdpCJyC2O2JL9Ts7hX2TH/LT+
E/xl5kFz/eWHcJjy+HPKp1X1CVmPb10kc9M1faIbKk0y9Vb1NL/s3Htct+8B
N3BPNoaV1qOY1fuZf6UMVdO+nl21D1invsPn8nv4B48whYdYgoUVETP6TpM3
p153q5d9oX/uOGCd9QZjOIlnsil+nl/Bn3gpW+PX+E1M2/vDmWVYThXU6Vsb
1EV37tlAXXq+YrO577EFB/2jb3pmzNKevC92YK36O+kBU80=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0b1L1WEYh/HbBiHHY5opCKfSArHAoMF8QRc1Qc30HxDEFg1szXQ1pfBl
0EGF0kPTiXzJQUQJyjMoCOKgULSkp6Clpabqc4aL63vfz/28/Pgl+x53D+VF
xCI2ExE9JRG9eFcc8exyxAhG5cGiiDVuvhoxJM9eiZjGDI7sy7sUsZWM+CJf
lLOc4B29X3KZ/Jcr+INeQWHEP3nDWYH3uOGuduff5Iw6Hy/c+VGdcM8nPtab
4HFvHDT7XH5pZo8LzWT4a+591t/k3sdT1vf1S9QHnLW+pF9lf1pvUa5HA0rV
jfzTzD2zr+VaXuYTLrN+yr+td9jfLM+hCX/0WnL3oxUX3Huf27Ard3OnPQ+5
QL3mzG3nrfKS+pt+Un3GxeoN/S2sowWt6Le/0kybXG5mlw/VO3wN1fJt3MIr
6w9K3YsuzNp73UyN/jLuYMx/qOMVNFqv50m9Gf9mnhf41P9KySl5ldP8WW9b
HjCfxiNk1MN81zlvOeU7VvBE/u7eH3iay95W5D1ZPsd/9GxhBQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0TtMVFEUheEtSmh4hQEUmhEaaBUEWwqxQ4cKGk0ssIBABWgsMSHYACEx
GmJihwwNFY68bWyQEqEWQoAoD4kYzQB+U/z5117n3HPPnal50tfeeyUixrFQ
FrGfiFjkU87URKzJWXmT88sjlnTf5SL5B1fyqu5MTsp59v40f6iI+Hg9YpqH
K50tp+WBGxEz3M+v9HdrI1as/TZn9Gv4hCHzHTShyLyFYoya+zxTyM2oqIoo
07+REzzlrEZMOPuv7h+29QfYwRd3G7U+b/3Y/JZP+LVuWc7KkzziHefyrPPT
zriq+4xruGduRZ31KvuScr18yed4b88Fh2cL5dJq38AlXK974Zlb8m0k9Q/4
JrdxAt/sKedNXnff537TE/drMP/il+YzbjL/4Q17xnStzpjCfbwzP+RptHhf
itO6Dp5BJ+bMj7jR+uPc95m7uQdf5RL9oDyLZ9j1vj3fdYSu3H9hfsoF7nqo
S+E/rzxbfg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j9IlWEUx/Ej5iKhZaZejfAaRH8kNQ3SIhsN1ETTdKi0yUWjhqzFIK6g
YUOLEmkggoipoIZKZIOrV1oNoqUxdEihtc8dvnzP7zznPe8D75t8/KR9MCsi
prBVENFdEtGDT8URT09HfNN7zktyV0XEkDqtN8zLeq94T05x0vkI/5bH+XVR
xFvelyf4nPOU3qT6n940j8gfOftUxCKfNzOqd+QOfxIRhzwmf/Wu4/IWfzH3
Qn9GHuJcPPTcVc7Xq+W0mUtmU+qLvCtf4Sps2lfD1Wj23A9nhbhutgH1eI8b
uIkT6DOXMHNSXcYFfIb/ohwr3vvGzBqv4jOa7W9Bjvfd5VZ8wD20me3kPGcb
dq1n7q6+r9eNEvVlexNcxaXmk+pj9j5ANnKwb7aGD/iC87Q9e/IOP/PMrN6h
szq9I74md5a6AzpwS57DbbON/M53aOJ53Ml8G3mmMOJn0j+hXlBv8Cr/0ttW
d7nfTubuPMCP+Kx9u+pe9Uvu5+/c4V7tqMR/gcpWuw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVz70vnWEch/GfaKI2b6UkBp1LSB1KQuK1TTkGNVRrOppIqzmNd/8DfwCV
pgkrqzIQVJMOHUxFu9WgJBIGhkrwOcOV63v/Xu7nfipSH3vTWRExi52CiLPC
iG/8pCyiFusVEQmuQ1tpRAfaMYJR/C2KyHkYccSbZu/L4+onzmN8yrlq51z0
KGJC7UKe50nMPYj4xAu4VJ/iK/7M0/ii/97+MN7Z/69XLV9zDa/oZyMt3+OZ
4ogGcxvyJvLcsVUSsY1d73vs/zrtJjjJP9Sa5V/6+zjAVzs3dld51l238pr8
Gq/Qn8HOtd0P7kjJx/b+4QRv7FTbeeFNNdzF370rIVdyHe/ZrZJT5huc6+VG
fspDak1yi9zM+2Zb5bR6q3O33Japuzcpj2XeLT9T+80Tvv9c/iMfos/MpJlF
JNWXuIeneEBvmnudy+2lnF/KyzyIt9jzf/l6u/71UP7JR3wHqKxU+g==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0jtIlXEYx/HHqbmbmWZ2vNSgYuhQ6piVBhZEF5cSysEUPNoFtMCty+ji
ZIUGNQTpFIRFRXoCqxNqtaSiQ65OKZKKfd7hy+/yPP/3fc973tS19PmunIh4
hsldESu7IzJ0jY6nIqb5bX6eHsuPGCiOOE5rUYd6NO6POI1ivgSl6Ld3RteE
PtzFPQzvjTiwL+IRCjAiH6Rv0OJMER3VpWg6L+IQHZNL6HuU4oN8mPaZl9GP
8hFnP/E73WOCTusq6H075XRGfsA/xBxfo6tGs3MDuX6fbgGD/DIdsvcE3eaP
6Vt9of4vXsjPscqfdI1FnELY6bW/abaRnJdzkMtvea4y72WTPtXtQKXdV2Zj
GMWE7ov5V0whi2+Y1DfY/cn/SrLdz8gkanbVvVtRxX/XZXHL/lH5un4VbaiV
f5jNu8YsrZPb9eu4gRNyJx3GBec7aIMuTf+hG2flm8n/hh6ck2/TO7jI1zjX
5L285C/hCi5j3Df0eo935ZvK8O/4meRbo0u633yW/0P/A94fZxU=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0TtI1XEcBfCv0pBedOj6jBwUvCiCOphwdSmHIJxUGgSFUAgH0XCRhqSg
yQeoOEUFLgoRNIigg9pSKIig3DlBBDHB56SB+rnD4ZzvOd/H/95fZd9w51BO
REzD32TEZlHEYHlEXVlEC05Dhr/Br+XVQMXjiP6qiCd4S7Yiuy2NWKd/0g9l
S/QivYi/4Qe8z/QcPYUncC7vI/2JPjd/BqPq7cqIMV6qJKKXdwI9MCwb5f+j
52V7vq3Vjl38RvZW9of+DaXyr/qq6C+4Vz4gX1efyhLwi24wv4G75K/lH+j/
cAPtvG7edXafvqTf/hyeQZusQ5axe82uWTwDaf5L/jTdZeZIdlwc0azegafQ
qKdNT6E9BTAJE5Di15pplY2rm2AMzt2/hAuo0NOUnaUL4L18BPLpPHhnvlhP
vZ5Vt5bdz3E/wUvxquUL6rtH3k99hZP40H9+TOfT+zgXH/Ay9LXZF956k76g
X9nxw+4V9ZH6e/bt3L4HH4RVug==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0b1L1WEUB/BzIxTyZbB8SdIwQiUwigSFnER0cAsStKkGk4brYPUPhFvX
hroK4nAXB8cGEUShTXxBCyIHA7UsjQwhMQgh+zzDl/N9Oec8z/P7NTwavpfN
RMQkbF+MGL4ckYX1qojnUIRnaiLa1eJqGtb4z6D8WsS+bNXckPwxDMIT2Tf1
Hf/tpYg9/ILeWXqGnlG3GiIK+BQ+rr5SP/JyeKv5F/Qovoy3VUYcOveWPcd0
t12/1SW4I/vHb6yNOJfuClX4Tf6ZfU30A1h0zwWokN2Q9dl3lV/Pq4Mr0Mj/
a6YLv+/8h87vxK/z61IvfDY34Pwt9ZR/BL/4ebrLzA93OoA3dK3stdoBH+A9
FOzrN7+BT+ir0TOGt8Ht9C3kE5CHL7LN9Hb7/9DN8jE1az6nTvNL5TmzLek9
8j07X+Jf1RVZMTzVe+xd8/wSM7uyEd6OOpegp8AvM9/szb34of4MXU93+GYn
FRGV+Hf+T7wU31UX6PP4J/xUf4/eFTyf/lF6j13z9AF+N31D+X928F5l
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D1I1HEYB/BHkiPSjujFUxfPy6DTIgnFIe+WqyVQfAGJW0qnWkybRBJ1
SJwERbgGQWsKDBpaskXUwRpsSAwait5IMOjVoSXw0/Dl+b49v//v968fuN0z
WBYRS/DhRMTLkxFDNRG/qyPGqiJ+mT/hjWxNdjgVMcpvy0T0n4rY4j/nD/Ku
0Rv0U/oG3arTxXvGW+YVeY/xh3hCtoiX8DlzxjzEu4dP4Y26o3ieN05n6RZn
DfFG6G13/MHLQCPeBHd1s+ZNnWGdF/gm1Oo0mGfgNFyX35Kv42twTP7Zu5rt
p+lPeJ/OgM4K/ZFO6HSbXdAhK8q+y97T1fYW5Jfxd1CAKzq9OiV8T/bH3fP4
DuTgkvyq/Ikzpu0/8I+/6WzLanivzYs6BZ1H+FdnzENKVgVZWbts3G4P3Q1j
//8BpGWtsrOyV85M0RfoTlkSz+KzslxtRDmdpv8e1zN3670LT+Izdr/gCTyj
P+n7U7y3vH/2Juj7zizBFm+fV6c3ojPpzhOwyt/jV/jWUaiEO/Im8xwcgaK3
n4cDTZ5Zjg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D0sXXEcxvGfIk0X0nrpVZarm8RbJKaqO2gHEoO0MSApJgbCInIRUw0G
g6UxSUyojUEsIibDjaUkXUpCImnC4qUk1OcMT57n+f5+/3P+56QHRrtG8iJi
mk5LIg5KIxreRcyUR0y9jcjSMb6Hv0o6HqmI/3JvdUTObMcsXx81Ozc7o318
Ew+8H5+we4L/oW2zn2aPeA91lEVsYCvYg15lt4t/wpfxH3i7ntEX9aN0xAL2
XZ7jWZ7DZuUxeZK/T+7pOUP6uF6pf5OH5Ub8td6tD+qdvIfP41sVEZ/1L/pH
/yFDrfQB68D+mdfY+8rv6JaazNrMlnzbur6W7CR3s9eCr+ppvVm+ds+U3CAX
8xp+iRXKafn+jTm/wK7kYvmcv0y+1/Nq3aWe6ug3/uRcUcK8e9b/yWF99m7w
Fu8twH85u4v/xfL1F3SI1fFnz4xHwA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D1Lm1EYxvE7RZ2laqsubbLGRZCmiKZJob5gQFQEBRfFyUIVBaHBDp3q
4uYXKHTuF6hLcejQIZuIUSEZBEFQ8F3jyy/DxfW/rnOfc57nJOcWx78kIqJI
1ZaI/60Ru3ybz7VFNKciSnLj64gGWnoVMa3/hb/SA72gantEglf4mPVV+w5x
TZfpiHiy70B+5Pu8YObe2m9n13TD5u/5BA1Y+6m/xTc0Qnndpu4aD5m94jnq
0//Qr/ved/J7eU0uJSO+67p0aVrWFeWEvQt4Bc/yz/zO7BSex6N8hl/pBvEk
7uf/5ALuwZ/4nnvSuNd5Wbkkp+QM3sKX5jvkbvlP/R1xGp/qm3Cqfu9LM/xY
d4ab8dtO/++9kvxId4k33HHBm7xbxUxZ/1HOU6OuXL9fl5O/mf3As7SjP+d/
rZ24sw+/ce4zABJKgA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j9I1HEYx/FHQ0jUwTo17Q/eiZyGLo2Bk2MnmUkhyAWRhEjq0NDmdWAQ
REMgWg4ODp6biARO+WfxrqUInZVoMRWDIHWxl8OHz/N9f57n+X1/97vk07G+
0bKImKZH1yIe01hdxHJ9xDf6TqtXIiYaIsbxFefLTRGVNJmKKMpuq6caI9r5
2dWIbexnMuJSImJXXcX3+S8sof6rvslD729swd439qaxaizlWW+pHP+MZ+zu
oXrZiGdOuGNRluc5mpe95rfkO3iV+j7WS0/0p/Fa/INdRXv/yUs8If/KT5z3
5Kvyh1jOTD+/a+4In8H73K3b+QZ+ip1Rh74Fs4tUoIz8nn0fqUX+iR+YPaR+
WbeeVvyZuUZ1E12nrKwdb1YnKUXPsQf6BuzolG1i67RBg+6Q4XfwEj+2f1Hf
H95l5pXZtHqLzvWG75LH2njWOc3feZ8ffvv3+JR6lleYnVMX1AW+wiuxJfUX
9bB9pYv/g3PJuUaWdYeX2Bq2ffE93WcI2/ecA/UhvVD/B+EiWdI=
       "],
       VertexColors->None]}, {}, {}}},
   VertexColors->{
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649999976909684, 1, 0.10000003197120676`], 
     Hue[0.6499993874496071, 1, 0.10000084814669796`], 
     Hue[0.6499937580362951, 1, 0.10000864271897605`], 
     Hue[0.6499715118660402, 1, 0.10003944510855985`], 
     Hue[0.6499335773748115, 1, 0.1000919697887226], 
     Hue[0.6498887914451422, 1, 0.10015398107595691`], 
     Hue[0.6498352660712459, 1, 0.10022809313212122`], 
     Hue[0.6498258057805197, 1, 0.10024119199620345`], 
     Hue[0.6498563321740463, 1, 0.10019892468208984`], 
     Hue[0.64985984558704, 1, 0.10019405995640612`], 
     Hue[0.6498335684013049, 1, 0.10023044375203936`], 
     Hue[0.6498005195536725, 1, 0.10027620369491513`], 
     Hue[0.6497734757652518, 1, 0.10031364894042064`], 
     Hue[0.6497291636752569, 1, 0.10037500414195208`], 
     Hue[0.6497077641299924, 1, 0.10040463428154903`], 
     Hue[0.649791515911589, 1, 0.10028867027626141`], 
     Hue[0.6498964456976118, 1, 0.1001433828802298], 
     Hue[0.6499606142780169, 1, 0.10005453407659201`], 
     Hue[0.6499904685365034, 1, 0.10001319741099535`], 
     Hue[0.649998651387875, 1, 0.10000186730909617`], 
     Hue[0.649999878100839, 1, 0.10000016878345375`], 
     Hue[0.6499999935928835, 1, 0.10000000887139203`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999945743066, 1, 0.10000000751249856`], 
     Hue[0.6499996969994325, 1, 0.1000004195392474], 
     Hue[0.6499937978811454, 1, 0.10000858754918338`], 
     Hue[0.6499408674556676, 1, 0.10008187583061406`], 
     Hue[0.6497352051569412, 1, 0.10036663901346618`], 
     Hue[0.6493936833798046, 1, 0.10083951532027051`], 
     Hue[0.6490667140461939, 1, 0.10129224208988548`], 
     Hue[0.6487635006949054, 1, 0.1017120759609002], 
     Hue[0.6487270889084671, 1, 0.101762492280584], 
     Hue[0.6488822352657346, 1, 0.10154767424744432`], 
     Hue[0.6488681210674755, 1, 0.10156721698349556`], 
     Hue[0.6487132008037324, 1, 0.10178172196406285`], 
     Hue[0.6485450308469991, 1, 0.10201457267338589`], 
     Hue[0.6483622398548194, 1, 0.10226766789332692`], 
     Hue[0.6479746652778023, 1, 0.10280430961535068`], 
     Hue[0.6477295059698063, 1, 0.10314376096488369`], 
     Hue[0.648274358786365, 1, 0.10238934937272541`], 
     Hue[0.6490682198954721, 1, 0.10129015706780782`], 
     Hue[0.6496232284995248, 1, 0.10052168361604262`], 
     Hue[0.6499024634529762, 1, 0.10013505060357142`], 
     Hue[0.6499840877683455, 1, 0.10002203232075248`], 
     Hue[0.6499981816619654, 1, 0.10000251769881713`], 
     Hue[0.6499998627295812, 1, 0.1000001900667338], 
     Hue[0.6499999942012185, 1, 0.10000000802908218`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999913709361, 1, 0.10000001194793465`], 
     Hue[0.6499998235705214, 1, 0.10000024428697034`], 
     Hue[0.6499970307590142, 1, 0.10000411125674966`], 
     Hue[0.6499558443227186, 1, 0.10006113863008197`], 
     Hue[0.6496240934804294, 1, 0.10052048595017475`], 
     Hue[0.6483889103657552, 1, 0.10223073949356976`], 
     Hue[0.6463795382364937, 1, 0.10501294705716253`], 
     Hue[0.6447364702310827, 1, 0.10728796429542398`], 
     Hue[0.6436899364256725, 1, 0.10873701110291498`], 
     Hue[0.643640646966921, 1, 0.10880525804580171`], 
     Hue[0.6439076660189531, 1, 0.10843553935837272`], 
     Hue[0.6435076264453965, 1, 0.10898944030637409`], 
     Hue[0.6429253389220522, 1, 0.10979568456946628`], 
     Hue[0.6425262199385269, 1, 0.11034831085434736`], 
     Hue[0.641816598885637, 1, 0.11133086308142567`], 
     Hue[0.6398006904797765, 1, 0.11412212087415566`], 
     Hue[0.638337632316587, 1, 0.11614789371549492`], 
     Hue[0.6406623339116113, 1, 0.11292907612238444`], 
     Hue[0.6445942350840018, 1, 0.10748490526830516`], 
     Hue[0.6476814237377192, 1, 0.10321033636315809`], 
     Hue[0.649342564394087, 1, 0.10091029545434113`], 
     Hue[0.6498730913181395, 1, 0.10017571971334535`], 
     Hue[0.6499820779325163, 1, 0.10002481517036217`], 
     Hue[0.6499981522395682, 1, 0.10000255843752087`], 
     Hue[0.64999985601774, 1, 0.10000019936005225`], 
     Hue[0.6499999942221562, 1, 0.10000000800009151`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999682913116, 1, 0.10000004390433788`], 
     Hue[0.6499996906832073, 1, 0.10000042828478993`], 
     Hue[0.6499973828890299, 1, 0.10000362369211252`], 
     Hue[0.6499748432360111, 1, 0.10003483244244621`], 
     Hue[0.6497533292284228, 1, 0.10034154414526088`], 
     Hue[0.6482950873594109, 1, 0.10236064827158503`], 
     Hue[0.6433276343511776, 1, 0.10923866012913884`], 
     Hue[0.6354431725647137, 1, 0.12015560721808866`], 
     Hue[0.6294009649343322, 1, 0.12852174086015547`], 
     Hue[0.6267281408682941, 1, 0.13222257418236213`], 
     Hue[0.6264372454106848, 1, 0.1326253525082826], 
     Hue[0.6251434888693679, 1, 0.13441670771933675`], 
     Hue[0.6224293998492977, 1, 0.13817467713174178`], 
     Hue[0.6212807100340211, 1, 0.13976517072212472`], 
     Hue[0.6217037866484854, 1, 0.13917937233286645`], 
     Hue[0.6202921775347399, 1, 0.1411339080288218], 
     Hue[0.6138354353714721, 1, 0.15007401256257719`], 
     Hue[0.6088882535819361, 1, 0.1569239565788578], 
     Hue[0.6158034287568741, 1, 0.14734909864432819`], 
     Hue[0.6289117753350029, 1, 0.12919908030538071`], 
     Hue[0.6402680541739076, 1, 0.113475001913051], 
     Hue[0.6468734242956043, 1, 0.10432910482147097`], 
     Hue[0.649269915807132, 1, 0.10101088580550954`], 
     Hue[0.6498669531156333, 1, 0.10018421876296944`], 
     Hue[0.649979959526278, 1, 0.1000277483482306], 
     Hue[0.6499977905153569, 1, 0.10000305928642889`], 
     Hue[0.6499998676105108, 1, 0.10000018330852356`], 
     Hue[0.6499999966472064, 1, 0.10000000464232967`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999561247779, 1, 0.10000006075030762`], 
     Hue[0.6499994270555906, 1, 0.10000079330764389`], 
     Hue[0.6499955216431317, 1, 0.10000620080181775`], 
     Hue[0.6499712489871483, 1, 0.10003980909471773`], 
     Hue[0.6498150288390254, 1, 0.10025611391519568`], 
     Hue[0.648819706143527, 1, 0.10163425303203952`], 
     Hue[0.643962933637772, 1, 0.10835901496308493`], 
     Hue[0.6298575511972674, 1, 0.12788954449609138`], 
     Hue[0.6085040468753101, 1, 0.1574559350957245], 
     Hue[0.5916456046912346, 1, 0.1807983935044445], 
     Hue[0.5843928068991314, 1, 0.19084072890889495`], 
     Hue[0.5809425729137753, 1, 0.19561797596554198`], 
     Hue[0.5713710886340267, 1, 0.20887080035288602`], 
     Hue[0.5616686760727363, 1, 0.2223049100531343], 
     Hue[0.5620528128727018, 1, 0.2217730283301052], 
     Hue[0.5683112155664811, 1, 0.21310754767718001`], 
     Hue[0.5678645879974967, 1, 0.21372595508038922`], 
     Hue[0.5545069521967535, 1, 0.23222114311218756`], 
     Hue[0.5447537255550116, 1, 0.245725610769984], 
     Hue[0.5602631691137158, 1, 0.22425099661177825`], 
     Hue[0.5907217620998423, 1, 0.1820775601694492], 
     Hue[0.6196682300002044, 1, 0.1419978353843324], 
     Hue[0.6386486248185335, 1, 0.11571728871279988`], 
     Hue[0.6467595975037354, 1, 0.10448671114867417`], 
     Hue[0.6492019067582832, 1, 0.1011050521808388], 
     Hue[0.6498311086529901, 1, 0.1002338495573983], 
     Hue[0.6499772714518389, 1, 0.10003147029745388`], 
     Hue[0.6499984829171128, 1, 0.1000021005763054], 
     Hue[0.6499999539083409, 1, 0.10000006381922037`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499994887542428, 1, 0.10000070787874078`], 
     Hue[0.6499937093953752, 1, 0.10000871006794215`], 
     Hue[0.6499568450798264, 1, 0.10005975296639417`], 
     Hue[0.6497774045887782, 1, 0.10030820903092255`], 
     Hue[0.6489295512637334, 1, 0.10148215978867683`], 
     Hue[0.6451366511111966, 1, 0.1067338676921894], 
     Hue[0.6318053259527835, 1, 0.1251926256038383], 
     Hue[0.6011633718055592, 1, 0.1676199467307642], 
     Hue[0.5590269376811419, 1, 0.22596270167226512`], 
     Hue[0.5231534421252756, 1, 0.2756336955188492], 
     Hue[0.503188593946499, 1, 0.30327733145869384`], 
     Hue[0.4877033405261671, 1, 0.32471845157915324`], 
     Hue[0.45863119184573675`, 1, 0.3649721959059029], 
     Hue[0.4373968721360797, 1, 0.39437356165773585`], 
     Hue[0.44535368731799385`, 1, 0.3833564329443162], 
     Hue[0.46583448848123865`, 1, 0.3549984005644389], 
     Hue[0.46999446989002297`, 1, 0.3492384263061221], 
     Hue[0.4504712701361676, 1, 0.37627054904222945`], 
     Hue[0.4395007921892894, 1, 0.3914604415840609], 
     Hue[0.46809454656664096`, 1, 0.3518690893692664], 
     Hue[0.5199699317478563, 1, 0.28004163296450674`], 
     Hue[0.5743828378154652, 1, 0.20470068610166364`], 
     Hue[0.6169125078236533, 1, 0.1458134507057109], 
     Hue[0.638423361460079, 1, 0.11602919182450598`], 
     Hue[0.6461852863132764, 1, 0.1052819112585404], 
     Hue[0.6489840057003123, 1, 0.10140676133802914`], 
     Hue[0.6498454239186365, 1, 0.10021402842034947`], 
     Hue[0.6499885928257225, 1, 0.10001579454899961`], 
     Hue[0.6499996022826809, 1, 0.1000005506855188], 
     Hue[0.6499999949561814, 1, 0.10000000698374883`], 
     Hue[0.6499962524797729, 1, 0.10000518887416067`], 
     Hue[0.6499560166179489, 1, 0.1000609000674554], 
     Hue[0.6497179659922457, 1, 0.10039050862612126`], 
     Hue[0.6487809691211849, 1, 0.10168788890912873`], 
     Hue[0.645406076523703, 1, 0.10636081712102663`], 
     Hue[0.6337492412196136, 1, 0.12250105061899663`], 
     Hue[0.6023446506040745, 1, 0.16598432993281995`], 
     Hue[0.5467225537744493, 1, 0.24299954092768555`], 
     Hue[0.48185601724943794`, 1, 0.3328147453469321], 
     Hue[0.42402616274144844`, 1, 0.4128868515887637], 
     Hue[0.3834486096299525, 1, 0.4690711558969889], 
     Hue[0.34808779529892875`, 1, 0.5180322834322525], 
     Hue[0.2969800849761256, 1, 0.5887968054176722], 
     Hue[0.2673952532094017, 1, 0.6297604186331361], 
     Hue[0.28530885919220683`, 1, 0.6049569641954059], 
     Hue[0.3188581746832802, 1, 0.5585040658231505], 
     Hue[0.32806855642084687`, 1, 0.5457512295711352], 
     Hue[0.30505353640156957`, 1, 0.5776181803670576], 
     Hue[0.29955064359308275`, 1, 0.5852375704095777], 
     Hue[0.3458315877787482, 1, 0.5211562630755795], 
     Hue[0.41590133598123846`, 1, 0.4241366117182853], 
     Hue[0.49589695769718367`, 1, 0.3133734431885149], 
     Hue[0.5720947165688519, 1, 0.2078688539815896], 
     Hue[0.6168651054265433, 1, 0.14587908479401707`], 
     Hue[0.6363652985273125, 1, 0.11887881742372122`], 
     Hue[0.6458139892474757, 1, 0.10579601488811063`], 
     Hue[0.6492949820101491, 1, 0.1009761787551781], 
     Hue[0.6499410412389569, 1, 0.10008163520759811`], 
     Hue[0.6499974855494974, 1, 0.10000348154684978`], 
     Hue[0.649999941365086, 1, 0.1000000811868041], 
     Hue[0.6499823140150783, 1, 0.10002448828681462`], 
     Hue[0.6497933263540053, 1, 0.1002861635098388], 
     Hue[0.6487204876825116, 1, 0.10177163243959945`], 
     Hue[0.6451615729383572, 1, 0.1066993605468901], 
     Hue[0.6353965215708487, 1, 0.12022020090190189`], 
     Hue[0.6079093131695241, 1, 0.15827941253450506`], 
     Hue[0.5457040109646117, 1, 0.24440983097207608`], 
     Hue[0.4571862801070082, 1, 0.366972842928758], 
     Hue[0.37474096909526033`, 1, 0.48112788894502423`], 
     Hue[0.30517744645263445`, 1, 0.5774466126040446], 
     Hue[0.2516152566984813, 1, 0.6516096445713336], 
     Hue[0.20447299494579108`, 1, 0.7168835454596739], 
     Hue[0.14905746590234448`, 1, 0.7936127395198307], 
     Hue[0.12384608620675475`, 1, 0.8285208037137242], 
     Hue[0.14011977627844052`, 1, 0.8059880020760054], 
     Hue[0.16664883218622994`, 1, 0.7692554631267585], 
     Hue[0.17515093068978166`, 1, 0.7574833267372254], 
     Hue[0.15079901637608079`, 1, 0.7912013619408113], 
     Hue[0.1524941610279375, 1, 0.7888542385767019], 
     Hue[0.21715522649739866`, 1, 0.6993235325420634], 
     Hue[0.2992607586820293, 1, 0.5856389495171902], 
     Hue[0.3948151482519245, 1, 0.4533328716511815], 
     Hue[0.502632228837416, 1, 0.3040476831481933], 
     Hue[0.5758377154930199, 1, 0.20268624008658792`], 
     Hue[0.6147040713782683, 1, 0.14887128578393616`], 
     Hue[0.6380018987547281, 1, 0.11661275557037644`], 
     Hue[0.6477292623908059, 1, 0.10314409822811502`], 
     Hue[0.6497724245175954, 1, 0.10031510451409864`], 
     Hue[0.6499870297360454, 1, 0.10001795882701409`], 
     Hue[0.6499995358185351, 1, 0.10000064271279765`], 
     Hue[0.6499423364993376, 1, 0.10007984177014792`], 
     Hue[0.6493253660446596, 1, 0.10093410855354819`], 
     Hue[0.6458767104867272, 1, 0.10570917009530076`], 
     Hue[0.6356763867284073, 1, 0.11983269529912834`], 
     Hue[0.6142637986531444, 1, 0.14948089417256938`], 
     Hue[0.565049278844471, 1, 0.21762407544611712`], 
     Hue[0.4649433153217069, 1, 0.3562323326314828], 
     Hue[0.342440007214464, 1, 0.5258522977030499], 
     Hue[0.25334229788590523`, 1, 0.6492183567733619], 
     Hue[0.19242945590916272`, 1, 0.7335592148950055], 
     Hue[0.14897402123421521`, 1, 0.7937282782910866], 
     Hue[0.10934489341469278`, 1, 0.8485993783488869], 
     Hue[0.06970512355860736, 1, 0.9034852135342359], 
     Hue[0.058982259464863684`, 1, 0.9183322561255733], 
     Hue[0.0610341021734625, 1, 0.9154912431444366], 
     Hue[0.06564134210546824, 1, 0.909111987853967], 
     Hue[0.0702572678615796, 1, 0.9027207060378128], 
     Hue[0.045950603364913856`, 1, 0.9363760876485808], 
     Hue[0.0473784072038923, 1, 0.9343991284869184], 
     Hue[0.11768845756893442`, 1, 0.8370467510583984], 
     Hue[0.20306658299876756`, 1, 0.7188308850786295], 
     Hue[0.29941327672599893`, 1, 0.5854277706870784], 
     Hue[0.42198399789160224`, 1, 0.4157144644577816], 
     Hue[0.5195997031500921, 1, 0.2805542571767957], 
     Hue[0.581948527337701, 1, 0.19422511599395248`], 
     Hue[0.624553578860998, 1, 0.13523350619246424`], 
     Hue[0.6443876833879528, 1, 0.10777089992437298`], 
     Hue[0.6492775343310644, 1, 0.10100033708006476`], 
     Hue[0.6499415635452619, 1, 0.10008091201425287`], 
     Hue[0.6499969949663125, 1, 0.1000041608158751], 
     Hue[0.6498645736962303, 1, 0.1001875133436812], 
     Hue[0.6484179080575208, 1, 0.10219058884343286`], 
     Hue[0.6403861247641137, 1, 0.11331151955738102`], 
     Hue[0.6180343759081722, 1, 0.14426009489637692`], 
     Hue[0.5800298680118476, 1, 0.19688172121436487`], 
     Hue[0.5101927903012211, 1, 0.2935792134290785], 
     Hue[0.3794168446052978, 1, 0.47465359977728006`], 
     Hue[0.2347347197607772, 1, 0.674982695715847], 
     Hue[0.15062796295930658`, 1, 0.7914382051332678], 
     Hue[0.11201951423759138`, 1, 0.8448960572094888], 
     Hue[0.0938871255942485, 1, 0.8700024414848867], 
     Hue[0.07106375508400609, 1, 0.9016040314221454], 
     Hue[0.047255886507096, 1, 0.9345687725286362], 
     Hue[0.04827864267135906, 1, 0.9331526486088875], 
     Hue[0.041508957377678124`, 1, 0.9425260590155226], 
     Hue[0.03830235204129018, 1, 0.9469659740966752], 
     Hue[0.04662971043855524, 1, 0.9354357855466159], 
     Hue[0.023870550168631377`, 1, 0.9669484689972796], 
     Hue[0.01462423152533654, 1, 0.9797510640418418], 
     Hue[0.06490399281841275, 1, 0.9101329330206593], 
     Hue[0.13673413857472794`, 1, 0.8106758081272998], 
     Hue[0.2241312045240771, 1, 0.6896644860435855], 
     Hue[0.3456117173383327, 1, 0.5214606990700009], 
     Hue[0.4603083004587689, 1, 0.3626500455186277], 
     Hue[0.5450245458144268, 1, 0.24535062887233217`], 
     Hue[0.6066806917895115, 1, 0.159980580599138], 
     Hue[0.638482501405487, 1, 0.11594730574624885`], 
     Hue[0.6480238412522031, 1, 0.10273621980464184`], 
     Hue[0.6497792171818407, 1, 0.10030569928668213`], 
     Hue[0.6499852436630134, 1, 0.10002043185121233`], 
     Hue[0.6497623188264602, 1, 0.10032909700951674`], 
     Hue[0.6472623270305151, 1, 0.10379062411159448`], 
     Hue[0.6335961509332226, 1, 0.12271302178476863`], 
     Hue[0.5966224091750055, 1, 0.17390743344999232`], 
     Hue[0.53984581791543, 1, 0.2525211751940202], 
     Hue[0.45298669799299757`, 1, 0.3727876489327726], 
     Hue[0.3063755473720729, 1, 0.5757877036386683], 
     Hue[0.15894950811984976`, 1, 0.779916065680208], 
     Hue[0.08732672994548085, 1, 0.8790860662293342], 
     Hue[0.06937952497508793, 1, 0.903936042342186], 
     Hue[0.07275828596392431, 1, 0.8992577578961048], 
     Hue[0.060448136655732454`, 1, 0.9163025800151398], 
     Hue[0.03956007649182591, 1, 0.9452245094728564], 
     Hue[0.04259435510151832, 1, 0.941023200628667], 
     Hue[0.040316862612792215`, 1, 0.9441766517669031], 
     Hue[0.05100157990277232, 1, 0.9293824278269306], 
     Hue[0.07429993050400907, 1, 0.8971231731482951], 
     Hue[0.057969425220906534`, 1, 0.9197346420018218], 
     Hue[0.03504451597357283, 1, 0.9514768240365914], 
     Hue[0.046183508841908805`, 1, 0.9360536031419724], 
     Hue[0.08451587306372488, 1, 0.8829780219117656], 
     Hue[0.15761569399396747`, 1, 0.781762885239122], 
     Hue[0.2745643112848683, 1, 0.6198340305286438], 
     Hue[0.4054066441576427, 1, 0.43866772347403316`], 
     Hue[0.511431414272498, 1, 0.291864195622695], 
     Hue[0.5876166230864777, 1, 0.18637698341872327`], 
     Hue[0.6298753021056092, 1, 0.12786496631531047`], 
     Hue[0.6455091274501612, 1, 0.10621813122285378`], 
     Hue[0.6493611908910836, 1, 0.10088450492003816`], 
     Hue[0.6499490182279156, 1, 0.10007059014596298`], 
     Hue[0.6496805683138812, 1, 0.10044229002693379`], 
     Hue[0.6464365595685904, 1, 0.10493399444349023`], 
     Hue[0.62925917558985, 1, 0.12871806456790003`], 
     Hue[0.5833337356473046, 1, 0.19230713525757825`], 
     Hue[0.5117222880185224, 1, 0.29146144735896906`], 
     Hue[0.4065117180659912, 1, 0.4371376211393969], 
     Hue[0.2502542267414538, 1, 0.6534941475887562], 
     Hue[0.11455858010707798`, 1, 0.8413804275440459], 
     Hue[0.05895728161389313, 1, 0.9183668408423018], 
     Hue[0.052481479686253385`, 1, 0.9273333358190338], 
     Hue[0.06667810556214326, 1, 0.9076764692216477], 
     Hue[0.05657398821983628, 1, 0.9216667855417652], 
     Hue[0.029047919541252742`, 1, 0.9597798037121116], 
     Hue[0.027648859049933416`, 1, 0.9617169643923998], 
     Hue[0.03340102705525594, 1, 0.953752424077338], 
     Hue[0.05696544655707858, 1, 0.9211247663055835], 
     Hue[0.09661415438787602, 1, 0.8662265554629408], 
     Hue[0.09535959614201828, 1, 0.8679636361110517], 
     Hue[0.06621191529590109, 1, 0.9083219634364447], 
     Hue[0.0425894125850006, 1, 0.9410300441130761], 
     Hue[0.04139533307002896, 1, 0.94268338497996], 
     Hue[0.09444857421779462, 1, 0.8692250510830537], 
     Hue[0.2087434675490915, 1, 0.7109705833935657], 
     Hue[0.35990354748392217`, 1, 0.5016720111761078], 
     Hue[0.48838600807168686`, 1, 0.32377321959304894`], 
     Hue[0.5728457884432645, 1, 0.20682890830932618`], 
     Hue[0.6206870751125984, 1, 0.1405871267671715], 
     Hue[0.6420931426485745, 1, 0.11094795633274303`], 
     Hue[0.6486859647516193, 1, 0.10181943342083485`], 
     Hue[0.6498819914263866, 1, 0.10016339648654175`], 
     Hue[0.6496684289018466, 1, 0.10045909844359704`], 
     Hue[0.6464671285678256, 1, 0.10489166813685682`], 
     Hue[0.6301501130674866, 1, 0.12748445882963405`], 
     Hue[0.5858640206060137, 1, 0.18880366377628865`], 
     Hue[0.5078713876285805, 1, 0.296793463283504], 
     Hue[0.3815207559686509, 1, 0.4717404917357142], 
     Hue[0.2123574832899508, 1, 0.7059665615985297], 
     Hue[0.09155462455172725, 1, 0.8732320583129931], 
     Hue[0.0508055502965028, 1, 0.9296538534356116], 
     Hue[0.04380454819379409, 1, 0.9393475486547467], 
     Hue[0.058694716468774555`, 1, 0.9187303925816968], 
     Hue[0.053731671045678664`, 1, 0.9256023016290602], 
     Hue[0.02487936037450922, 1, 0.9655516548660641], 
     Hue[0.019024186395598996`, 1, 0.973658818836863], 
     Hue[0.024130125204393504`, 1, 0.9665890574093013], 
     Hue[0.040942080244115386`, 1, 0.9433109658158402], 
     Hue[0.08623952918085531, 1, 0.8805914211342004], 
     Hue[0.10374496621720608`, 1, 0.8563531236992531], 
     Hue[0.07856807878854488, 1, 0.891213429369707], 
     Hue[0.04189205550835773, 1, 0.9419956154499661], 
     Hue[0.01802736195714949, 1, 0.9750390372901008], 
     Hue[0.05296687005171874, 1, 0.9266612568514664], 
     Hue[0.16409633641214172`, 1, 0.7727896880447269], 
     Hue[0.3313660397498419, 1, 0.5411854834232959], 
     Hue[0.4780190812489016, 1, 0.3381274259630594], 
     Hue[0.566075408141189, 1, 0.2162032810352769], 
     Hue[0.6152399146779433, 1, 0.14812934890746315`], 
     Hue[0.6397795787888649, 1, 0.11415135244618707`], 
     Hue[0.6481652649740527, 1, 0.10254040234361939`], 
     Hue[0.6498228385542861, 1, 0.10024530046329619`], 
     Hue[0.6497396473328048, 1, 0.10036048830842427`], 
     Hue[0.6473354918645235, 1, 0.10368931895681358`], 
     Hue[0.6352032073434439, 1, 0.1204878667552315], 
     Hue[0.59920518796155, 1, 0.1703312782070847], 
     Hue[0.5205152935252375, 1, 0.27928651665736354`], 
     Hue[0.375298096903057, 1, 0.48035648121115193`], 
     Hue[0.1941191491313306, 1, 0.7312196396643115], 
     Hue[0.08397393087335725, 1, 0.8837284034061207], 
     Hue[0.05070416198681715, 1, 0.9297942372490224], 
     Hue[0.03521629627786549, 1, 0.9512389743844939], 
     Hue[0.042917970505802816`, 1, 0.9405751177611961], 
     Hue[0.0485211381990448, 1, 0.9328168855705533], 
     Hue[0.0340069777275509, 1, 0.9529134154541603], 
     Hue[0.028549351842905635`, 1, 0.9604701282175153], 
     Hue[0.02267133307841873, 1, 0.9686089234298817], 
     Hue[0.01995352039602749, 1, 0.9723720486824236], 
     Hue[0.057430822316269836`, 1, 0.9204803998697803], 
     Hue[0.0837498856578891, 1, 0.8840386198583073], 
     Hue[0.06545724113349394, 1, 0.9093668968920854], 
     Hue[0.03484537937969179, 1, 0.951752551628119], 
     Hue[0.013225973102829691`, 1, 0.9816871141653127], 
     Hue[0.043139929955085754`, 1, 0.9402677892929583], 
     Hue[0.15139736314315005`, 1, 0.7903728818017922], 
     Hue[0.3210001666244018, 1, 0.5555382308277514], 
     Hue[0.4747558901623309, 1, 0.34264569054446503`], 
     Hue[0.5665720730892265, 1, 0.21551559110722476`], 
     Hue[0.6165213868692023, 1, 0.1463550027964891], 
     Hue[0.6404786658571751, 1, 0.11318338573621918`], 
     Hue[0.6482964431107908, 1, 0.10235877107736652`], 
     Hue[0.6498308075724633, 1, 0.10023426643812786`], 
     Hue[0.6498473287870612, 1, 0.10021139091022302`], 
     Hue[0.648436055881696, 1, 0.10216546108688258`], 
     Hue[0.640800609817345, 1, 0.11273761717598384`], 
     Hue[0.6129991057239735, 1, 0.15123200745911355`], 
     Hue[0.5346793103021789, 1, 0.2596748011200601], 
     Hue[0.37686185607342076`, 1, 0.47819127620603274`], 
     Hue[0.19120398709631375`, 1, 0.7352560178666425], 
     Hue[0.08555978295482425, 1, 0.8815326082163972], 
     Hue[0.05069744515291641, 1, 0.9298035374805773], 
     Hue[0.0321430267292423, 1, 0.9554942706825875], 
     Hue[0.03293642716341516, 1, 0.9543957162352714], 
     Hue[0.0425845223688609, 1, 0.9410368151815772], 
     Hue[0.04796026810859533, 1, 0.9335934749265604], 
     Hue[0.04905945561393876, 1, 0.9320715229960848], 
     Hue[0.03304004808935124, 1, 0.9542522411070522], 
     Hue[0.013376417288328057`, 1, 0.9814788068315459], 
     Hue[0.033232102709860545`, 1, 0.9539863193248085], 
     Hue[0.05333756609240958, 1, 0.9261479854105099], 
     Hue[0.038793977265069834`, 1, 0.9462852622483648], 
     Hue[0.019326758426456814`, 1, 0.973239872947983], 
     Hue[0.011635837830835105`, 1, 0.9838888399265361], 
     Hue[0.04695625108745716, 1, 0.934983652340444], 
     Hue[0.1545731991893059, 1, 0.7859755703532688], 
     Hue[0.3186061675430974, 1, 0.5588529987864805], 
     Hue[0.4735705905319132, 1, 0.34428687464812024`], 
     Hue[0.5720943013732938, 1, 0.2078694288677472], 
     Hue[0.6228469231504629, 1, 0.13759656794551295`], 
     Hue[0.6433556939264036, 1, 0.10919980840959516`], 
     Hue[0.6489263470154355, 1, 0.1014865964401663], 
     Hue[0.6498968337860509, 1, 0.1001428455270065], 
     Hue[0.6499171851770337, 1, 0.10011466667795345`], 
     Hue[0.6490757082332906, 1, 0.10127978860005911`], 
     Hue[0.6438971149984241, 1, 0.10845014846372064`], 
     Hue[0.6208799103253224, 1, 0.14032012416493825`], 
     Hue[0.5440854805784332, 1, 0.24665087304524647`], 
     Hue[0.3826732070444076, 1, 0.4701447902462049], 
     Hue[0.19823919535457762`, 1, 0.7255149602782771], 
     Hue[0.0885655290650812, 1, 0.8773708059098876], 
     Hue[0.0461775846780037, 1, 0.9360618058304564], 
     Hue[0.0367348717365249, 1, 0.9491363314417348], 
     Hue[0.04094340742064595, 1, 0.943309128186798], 
     Hue[0.04681404864652006, 1, 0.9351805480278954], 
     Hue[0.05926086628516425, 1, 0.9179464928359264], 
     Hue[0.0625100600307067, 1, 0.9134476091882523], 
     Hue[0.044668343013581135`, 1, 0.9381515250581185], 
     Hue[0.018415492002113898`, 1, 0.9745016264586116], 
     Hue[0.01837383768460943, 1, 0.9745593016674639], 
     Hue[0.027498710381205216`, 1, 0.9619248625491005], 
     Hue[0.016917680159650894`, 1, 0.9765755197789449], 
     Hue[0.00542977103498099, 1, 0.9924818554900263], 
     Hue[0.008999127121843697, 1, 0.9875396701389856], 
     Hue[0.049878075771403685`, 1, 0.9309380489319026], 
     Hue[0.15577794460154437`, 1, 0.7843074613209385], 
     Hue[0.31349398084954316`, 1, 0.5659314111314018], 
     Hue[0.4708409301825858, 1, 0.3480664043625735], 
     Hue[0.5779553539116832, 1, 0.19975412535305415`], 
     Hue[0.6290090641486396, 1, 0.12906437271726828`], 
     Hue[0.6458316291602609, 1, 0.1057715903934849], 
     Hue[0.6494516927293791, 1, 0.10075919468239816`], 
     Hue[0.6499547375568101, 1, 0.10006267107518607`], 
     Hue[0.649930466062368, 1, 0.10009627775979811`], 
     Hue[0.6491390382842157, 1, 0.10119210083723977`], 
     Hue[0.6441579221208853, 1, 0.1080890309095434], 
     Hue[0.622427338316893, 1, 0.13817753156122511`], 
     Hue[0.549614754598433, 1, 0.23899495517140049`], 
     Hue[0.39485142135387763`, 1, 0.4532826473561694], 
     Hue[0.21306793754222597`, 1, 0.704982855710764], 
     Hue[0.09134093611885497, 1, 0.8735279346046624], 
     Hue[0.03842913213266608, 1, 0.9467904324316931], 
     Hue[0.03937257729987864, 1, 0.9454841237386296], 
     Hue[0.05677635119889779, 1, 0.9213865906476799], 
     Hue[0.06450147383679228, 1, 0.9106902669952107], 
     Hue[0.06870816696985471, 1, 0.9048656149648165], 
     Hue[0.05798457964175885, 1, 0.9197136589575647], 
     Hue[0.040730231185646004`, 1, 0.9436042952814132], 
     Hue[0.020223819840564095`, 1, 0.9719977879130651], 
     Hue[0.007738076325403465, 1, 0.9892857404725184], 
     Hue[0.009803726276587321, 1, 0.9864256097708791], 
     Hue[0.009040116131149856, 1, 0.9874829161261002], 
     Hue[0.005909601337574788, 1, 0.9918174750710503], 
     Hue[0.01502276063894814, 1, 0.979199254499918], 
     Hue[0.05922444560429663, 1, 0.9179969214709739], 
     Hue[0.16170201367860204`, 1, 0.7761049041373203], 
     Hue[0.3097734695600573, 1, 0.5710828883014591], 
     Hue[0.4652375521962418, 1, 0.35582492772828056`], 
     Hue[0.5780725622654689, 1, 0.19959183686319693`], 
     Hue[0.6305046120346524, 1, 0.12699361410586604`], 
     Hue[0.6463812430646457, 1, 0.10501058652587525`], 
     Hue[0.6495765566875406, 1, 0.10058630612494388`], 
     Hue[0.6499722824617045, 1, 0.10003837812994767`], 
     Hue[0.6499289294080627, 1, 0.10009840543499024`], 
     Hue[0.6490585942883179, 1, 0.10130348483155978`], 
     Hue[0.6435402965078705, 1, 0.10894420483525627`], 
     Hue[0.6214943370610082, 1, 0.1394693794539887], 
     Hue[0.55449095816355, 1, 0.23224328869662322`], 
     Hue[0.4135667449580124, 1, 0.427369122365829], 
     Hue[0.2351661809024284, 1, 0.674385287981253], 
     Hue[0.10005977349240647`, 1, 0.8614556982412834], 
     Hue[0.035475222323244404`, 1, 0.9508804613985847], 
     Hue[0.03204217605358273, 1, 0.9556339100796547], 
     Hue[0.057285665002259734`, 1, 0.920681386919948], 
     Hue[0.07601724418635392, 1, 0.8947453542035099], 
     Hue[0.07386085207905835, 1, 0.8977311278905346], 
     Hue[0.04803585511619457, 1, 0.9334888159929613], 
     Hue[0.03186620609994861, 1, 0.9558775607846866], 
     Hue[0.02360840396202113, 1, 0.9673114406679708], 
     Hue[0.006237939711511875, 1, 0.9913628527071373], 
     Hue[0.0008745682263716636, 1, 0.9987890593788701], 
     Hue[0.011980825103776516`, 1, 0.9834111652409248], 
     Hue[0.021632827887377637`, 1, 0.9700468536944001], 
     Hue[0.03404676834565212, 1, 0.952858320752174], 
     Hue[0.08390096788032897, 1, 0.8838294290887753], 
     Hue[0.1877096057867319, 1, 0.740094391987602], 
     Hue[0.32381982828791267`, 1, 0.551634083909044], 
     Hue[0.4662144987385175, 1, 0.3544722325158989], 
     Hue[0.5745866855196075, 1, 0.20441843543438976`], 
     Hue[0.6278514831036263, 1, 0.1306671772411329], 
     Hue[0.6454547078042697, 1, 0.10629348150178049`], 
     Hue[0.6494374776566451, 1, 0.10077887709079918`], 
     Hue[0.649964718535355, 1, 0.10004885125873923`], 
     Hue[0.6499435003037034, 1, 0.10007823034871836`], 
     Hue[0.6491822067736996, 1, 0.10113232908256976`], 
     Hue[0.6439572351415185, 1, 0.1083669051886668], 
     Hue[0.6230661978808063, 1, 0.1372929567804221], 
     Hue[0.5641469798348232, 1, 0.2188734125363987], 
     Hue[0.4417542112244809, 1, 0.3883403229199496], 
     Hue[0.27174566177386184`, 1, 0.6237367760054221], 
     Hue[0.1267468975606708, 1, 0.8245042956852251], 
     Hue[0.048701217899378535`, 1, 0.9325675444470144], 
     Hue[0.025403864348801153`, 1, 0.9648254185939676], 
     Hue[0.040307472731702654`, 1, 0.9441896531407193], 
     Hue[0.06298548955996575, 1, 0.9127893221477397], 
     Hue[0.06539791836747422, 1, 0.9094490361065742], 
     Hue[0.04690260576581862, 1, 0.9350579304780974], 
     Hue[0.03933219768478524, 1, 0.9455400339749128], 
     Hue[0.04111572515814499, 1, 0.9430705343964146], 
     Hue[0.021152258337921448`, 1, 0.9707122576859549], 
     Hue[0.003656722610345331, 1, 0.9949368456164449], 
     Hue[0.017780834452122196`, 1, 0.9753803830662924], 
     Hue[0.03998214266020639, 1, 0.9446401101627911], 
     Hue[0.05947992444465655, 1, 0.9176431815381678], 
     Hue[0.12052021545429314`, 1, 0.8331258555248249], 
     Hue[0.23206752917386064`, 1, 0.678675728836193], 
     Hue[0.3605456094632415, 1, 0.5007830022816656], 
     Hue[0.4844829393382577, 1, 0.32917746860856634`], 
     Hue[0.5772051861525473, 1, 0.20079281917339598`], 
     Hue[0.6261544874596762, 1, 0.13301686351737152`], 
     Hue[0.6446849725839858, 1, 0.10735926872986576`], 
     Hue[0.6493241654500368, 1, 0.10093577091533369`], 
     Hue[0.6499579069206303, 1, 0.10005828272528121`], 
     Hue[0.6499675069681489, 1, 0.1000449903517939], 
     Hue[0.6494731076924755, 1, 0.10072954319503409`], 
     Hue[0.6456485879679781, 1, 0.10602503204433802`], 
     Hue[0.629082557828833, 1, 0.12896261223700048`], 
     Hue[0.5817793127489398, 1, 0.19445941311685266`], 
     Hue[0.4820487549788015, 1, 0.3325478777216595], 
     Hue[0.33012927763265965`, 1, 0.5428979232778559], 
     Hue[0.1808792466532107, 1, 0.7495518123263236], 
     Hue[0.0866977596673636, 1, 0.8799569481528812], 
     Hue[0.04001141617346671, 1, 0.9445995776059692], 
     Hue[0.033176989469076545`, 1, 0.9540626299658941], 
     Hue[0.042751603158124096`, 1, 0.9408054725502898], 
     Hue[0.04588895041897034, 1, 0.9364614532660411], 
     Hue[0.04514959894559145, 1, 0.9374851706907195], 
     Hue[0.050591630763069384`, 1, 0.9299500497126731], 
     Hue[0.061044418591131855`, 1, 0.9154769588738174], 
     Hue[0.04784729261078946, 1, 0.9337499025389069], 
     Hue[0.02389193277465107, 1, 0.9669188623120216], 
     Hue[0.028216459700999175`, 1, 0.9609310557986166], 
     Hue[0.05579618224621952, 1, 0.9227437476590807], 
     Hue[0.09059868149711292, 1, 0.8745556717732282], 
     Hue[0.1665431658838218, 1, 0.7694017703147084], 
     Hue[0.28408857603786003`, 1, 0.6066465870245015], 
     Hue[0.4080802285572287, 1, 0.43496583738229877`], 
     Hue[0.5161002967395522, 1, 0.285399589129851], 
     Hue[0.5895575288250847, 1, 0.1836895754729596], 
     Hue[0.6288806999875622, 1, 0.1292421077095293], 
     Hue[0.6451518541354205, 1, 0.10671281735095615`], 
     Hue[0.6493944506951734, 1, 0.10083845288360602`], 
     Hue[0.6499636878790861, 1, 0.10005027832126548`], 
     Hue[0.6499862887732498, 1, 0.1000189847755003], 
     Hue[0.6497493433511243, 1, 0.10034706305228946`], 
     Hue[0.6476431436909588, 1, 0.10326333950482638`], 
     Hue[0.6370931948435861, 1, 0.11787096098580394`], 
     Hue[0.6034793546269759, 1, 0.16441320128572567`], 
     Hue[0.5285979396496221, 1, 0.2680951604851387], 
     Hue[0.4048910312903138, 1, 0.43938164898264254`], 
     Hue[0.2632010648282367, 1, 0.6355677563916723], 
     Hue[0.15523949503520018`, 1, 0.7850530068743382], 
     Hue[0.08903707933307159, 1, 0.8767178901542086], 
     Hue[0.06628805666558879, 1, 0.9082165369245693], 
     Hue[0.05933713397278784, 1, 0.9178408914222937], 
     Hue[0.046438582960784625`, 1, 0.9357004235927597], 
     Hue[0.04265210600463121, 1, 0.9409432378397414], 
     Hue[0.0524475142937183, 1, 0.9273803648240824], 
     Hue[0.07620379340321026, 1, 0.8944870552878627], 
     Hue[0.08804181050643511, 1, 0.8780959546833975], 
     Hue[0.07410794736713189, 1, 0.897388995953202], 
     Hue[0.06337003047187284, 1, 0.9122568808850992], 
     Hue[0.09011366840413704, 1, 0.8752272283635025], 
     Hue[0.14644545807624387`, 1, 0.7972293657405853], 
     Hue[0.23580726081536652`, 1, 0.673497638871031], 
     Hue[0.349389072159645, 1, 0.5162305154712609], 
     Hue[0.4621382488111426, 1, 0.3601162708768795], 
     Hue[0.5528903895856362, 1, 0.2344594605737346], 
     Hue[0.6076556223449107, 1, 0.15863067675320064`], 
     Hue[0.6351993511890847, 1, 0.12049320604588276`], 
     Hue[0.646644681443802, 1, 0.10464582569319719`], 
     Hue[0.6495969224912248, 1, 0.10055810731984266`], 
     Hue[0.6499771149098671, 1, 0.10003168704787631`], 
     Hue[0.6499958310074129, 1, 0.10000577245127446`], 
     Hue[0.6499135913390339, 1, 0.10011964276133767`], 
     Hue[0.6490405721811161, 1, 0.10132843851845466`], 
     Hue[0.6436029545146564, 1, 0.10885744759509113`], 
     Hue[0.6229356840924041, 1, 0.13747366817974832`], 
     Hue[0.5728758389313529, 1, 0.20678729994120382`], 
     Hue[0.48334768987603993`, 1, 0.33074935247932935`], 
     Hue[0.36394899237349043`, 1, 0.4960706259443979], 
     Hue[0.2542488845618081, 1, 0.6479630829144195], 
     Hue[0.17879094572403942`, 1, 0.7524433059205607], 
     Hue[0.15248224395922688`, 1, 0.7888707391333781], 
     Hue[0.13753788230526398`, 1, 0.8095629321927115], 
     Hue[0.10335222951175616`, 1, 0.8568969129837223], 
     Hue[0.07730245138697356, 1, 0.8929658365411136], 
     Hue[0.0804122103179905, 1, 0.8886600164827824], 
     Hue[0.11943161605855024`, 1, 0.8346331469958536], 
     Hue[0.1616399418426182, 1, 0.7761908497563748], 
     Hue[0.16278542567900117`, 1, 0.7746047952136907], 
     Hue[0.14200389780850975`, 1, 0.8033792184189865], 
     Hue[0.16893242405363124`, 1, 0.7660935666949722], 
     Hue[0.24238747079719347`, 1, 0.6643865788961937], 
     Hue[0.33567476904290405`, 1, 0.535219550555979], 
     Hue[0.4335242779912632, 1, 0.3997356150890202], 
     Hue[0.5232678813975795, 1, 0.27547524114181293`], 
     Hue[0.5901332724166605, 1, 0.1828923920384701], 
     Hue[0.6260920574358144, 1, 0.13310330508887236`], 
     Hue[0.6421463297745397, 1, 0.11087431261986816`], 
     Hue[0.6482997598970935, 1, 0.10235417860402436`], 
     Hue[0.6498046705066846, 1, 0.10027045622151376`], 
     Hue[0.6499894797529542, 1, 0.10001456649590969`], 
     Hue[0.6499991169575482, 1, 0.1000012226741641], 
     Hue[0.6499785086935765, 1, 0.1000297571935095], 
     Hue[0.6496984326028048, 1, 0.10041755485765497`], 
     Hue[0.6474304602180798, 1, 0.10355782431342805`], 
     Hue[0.637081922996974, 1, 0.117886568158036], 
     Hue[0.609175580580095, 1, 0.1565261191967916], 
     Hue[0.5529412882549132, 1, 0.23438898549319717`], 
     Hue[0.46536944712670825`, 1, 0.355642303978404], 
     Hue[0.3724148532325075, 1, 0.4843486647549896], 
     Hue[0.3043285885301989, 1, 0.5786219543428015], 
     Hue[0.2787825445875384, 1, 0.61399339980187], 
     Hue[0.2601929998250374, 1, 0.6397327694730252], 
     Hue[0.22162865708438106`, 1, 0.6931295517293186], 
     Hue[0.1853838360314657, 1, 0.7433146885718167], 
     Hue[0.1818149491634548, 1, 0.7482562242352164], 
     Hue[0.2269275229895506, 1, 0.6857926604760068], 
     Hue[0.27964867168504576`, 1, 0.612794146897629], 
     Hue[0.28215984997205146`, 1, 0.6093171308079288], 
     Hue[0.26047963270485897`, 1, 0.6393358931778875], 
     Hue[0.2887567864471958, 1, 0.6001829110731135], 
     Hue[0.361131115582228, 1, 0.4999723015015305], 
     Hue[0.443000457730172, 1, 0.3866147508351465], 
     Hue[0.5183869096757747, 1, 0.2822335096796966], 
     Hue[0.5799461644525845, 1, 0.19699761845026764`], 
     Hue[0.6206690532051, 1, 0.1406120801775539], 
     Hue[0.639772418514095, 1, 0.11416126667279153`], 
     Hue[0.6470054150028277, 1, 0.10414634845762327`], 
     Hue[0.6493991855026726, 1, 0.1008318969962995], 
     Hue[0.6499342458671938, 1, 0.10009104418388552`], 
     Hue[0.6499965869678032, 1, 0.10000472573688801`], 
     Hue[0.6499998732630221, 1, 0.10000017548196938`], 
     Hue[0.6499960081084486, 1, 0.10000552723445576`], 
     Hue[0.6499251510684619, 1, 0.1001036369821297], 
     Hue[0.6491964089084648, 1, 0.10111266458827957`], 
     Hue[0.6453075303332527, 1, 0.10649726569241934`], 
     Hue[0.6331539878019834, 1, 0.12332524765879233`], 
     Hue[0.6036796020314713, 1, 0.16413593564873208`], 
     Hue[0.5502994558067207, 1, 0.2380469073445407], 
     Hue[0.4874505251790095, 1, 0.32506850359829453`], 
     Hue[0.43753127150469145`, 1, 0.39418747022427336`], 
     Hue[0.41113987839999583`, 1, 0.4307293991384673], 
     Hue[0.3909619240522747, 1, 0.45866810515838885`], 
     Hue[0.368925582576998, 1, 0.4891799625856952], 
     Hue[0.34773251897178636`, 1, 0.5185242045006035], 
     Hue[0.3451780703375053, 1, 0.5220611333788389], 
     Hue[0.38028479044577007`, 1, 0.4734518286135492], 
     Hue[0.41570492066015197`, 1, 0.42440857139363575`], 
     Hue[0.4069138502398968, 1, 0.4365808227447583], 
     Hue[0.3913395904191222, 1, 0.4581451824966001], 
     Hue[0.41776954988842374`, 1, 0.42154985400064415`], 
     Hue[0.4716739217518352, 1, 0.346913031420536], 
     Hue[0.5307862173715633, 1, 0.2650652374855278], 
     Hue[0.5824364589166949, 1, 0.19354951842303778`], 
     Hue[0.6189957044882809, 1, 0.142929024554688], 
     Hue[0.6390393407832956, 1, 0.11517629737697534`], 
     Hue[0.6468202564798128, 1, 0.10440272179718234`], 
     Hue[0.649207282669579, 1, 0.10109760861135206`], 
     Hue[0.6498570260637708, 1, 0.10019796391170191`], 
     Hue[0.6499852560005129, 1, 0.10002041476852061`], 
     Hue[0.6499992635889119, 1, 0.10000101964612196`], 
     Hue[0.6499999876696264, 1, 0.10000001707282496`], 
     Hue[0.6499994231210573, 1, 0.1000007987554591], 
     Hue[0.6499857232523235, 1, 0.1000197678044752], 
     Hue[0.649817085613139, 1, 0.10025326607411526`], 
     Hue[0.6487779419004893, 1, 0.10169208044547638`], 
     Hue[0.6447926016794149, 1, 0.10721024382850251`], 
     Hue[0.6326722498751234, 1, 0.12399226940367539`], 
     Hue[0.6074667187386592, 1, 0.15889223559262572`], 
     Hue[0.5741454538519732, 1, 0.2050293715895755], 
     Hue[0.5427647059583359, 1, 0.24847963790384256`], 
     Hue[0.5185670517359251, 1, 0.28198408221179594`], 
     Hue[0.5014902688826319, 1, 0.30562885847020194`], 
     Hue[0.4980295854953551, 1, 0.3104205739295084], 
     Hue[0.49836815836351356`, 1, 0.3099517807274428], 
     Hue[0.5015755509759485, 1, 0.30551077557176365`], 
     Hue[0.5187656242363552, 1, 0.28170913567273903`], 
     Hue[0.527132306817473, 1, 0.27012449825272966`], 
     Hue[0.5088315525354231, 1, 0.2954640041817219], 
     Hue[0.5011128687947184, 1, 0.3061514124380822], 
     Hue[0.5229008848234633, 1, 0.27598339024443547`], 
     Hue[0.5558173393294349, 1, 0.23040676092847487`], 
     Hue[0.5911230822001549, 1, 0.18152188618440107`], 
     Hue[0.6209762289784778, 1, 0.14018675987595378`], 
     Hue[0.6390739773746428, 1, 0.11512833901972545`], 
     Hue[0.6469151579024053, 1, 0.10427131982743887`], 
     Hue[0.6492924762091768, 1, 0.10097964832575516`], 
     Hue[0.6498559656387828, 1, 0.1001994321924546], 
     Hue[0.6499774103278382, 1, 0.10003127800760865`], 
     Hue[0.6499978417947263, 1, 0.10000298828422514`], 
     Hue[0.6499998979018545, 1, 0.10000014136666303`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999357005815, 1, 0.10000008902996423`], 
     Hue[0.6499980285908314, 1, 0.10000272964346424`], 
     Hue[0.64997112626772, 1, 0.10003997901392615`], 
     Hue[0.6497765468372962, 1, 0.10030939668682066`], 
     Hue[0.6488105795123204, 1, 0.101646889906018], 
     Hue[0.6451451008988048, 1, 0.10672216798627031`], 
     Hue[0.6363996121150224, 1, 0.11883130630227677`], 
     Hue[0.6225844035357797, 1, 0.13796005664276667`], 
     Hue[0.606096681840978, 1, 0.16078920975864588`], 
     Hue[0.5900003425991084, 1, 0.18307644870892686`], 
     Hue[0.5791163442951389, 1, 0.1981466002067308], 
     Hue[0.582179024556632, 1, 0.19390596599850968`], 
     Hue[0.5913095918218003, 1, 0.1812636420928919], 
     Hue[0.5976148253139884, 1, 0.17253331879601613`], 
     Hue[0.6023144943232429, 1, 0.16602608478320216`], 
     Hue[0.5959064233713482, 1, 0.1748987984089025], 
     Hue[0.5783919650546149, 1, 0.19914958684745632`], 
     Hue[0.5759025067214927, 1, 0.20259652915485624`], 
     Hue[0.5913437051248417, 1, 0.18121640828868077`], 
     Hue[0.6091836222595428, 1, 0.15651498456371002`], 
     Hue[0.62648401954311, 1, 0.13256058832492476`], 
     Hue[0.6400171999696501, 1, 0.11382233850356144`], 
     Hue[0.6469779810210704, 1, 0.10418433397082567`], 
     Hue[0.6493437255586528, 1, 0.10090868768801918`], 
     Hue[0.6498868101661912, 1, 0.10015672438527375`], 
     Hue[0.6499819607544464, 1, 0.10002497741692046`], 
     Hue[0.6499976141970967, 1, 0.10000330341940465`], 
     Hue[0.6499997956685558, 1, 0.10000028292046115`], 
     Hue[0.6499999914894199, 1, 0.1000000117838802], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999955819602, 1, 0.10000000611728592`], 
     Hue[0.6499998135366489, 1, 0.10000025818002467`], 
     Hue[0.6499968969850997, 1, 0.1000042964821697], 
     Hue[0.6499711547434761, 1, 0.10003993958595626`], 
     Hue[0.6498021486465595, 1, 0.10027394802784076`], 
     Hue[0.64902623416854, 1, 0.10134829115125239`], 
     Hue[0.64684763036038, 1, 0.10436481950101245`], 
     Hue[0.6424675728891299, 1, 0.11042951446120472`], 
     Hue[0.6359559266375608, 1, 0.11944564004030048`], 
     Hue[0.6287494142163745, 1, 0.1294238880080969], 
     Hue[0.6235212043250125, 1, 0.13666294785767502`], 
     Hue[0.6253229323423583, 1, 0.13416824752596548`], 
     Hue[0.6318954357855218, 1, 0.12506785814312377`], 
     Hue[0.6365777890601756, 1, 0.11858459976283385`], 
     Hue[0.6370525884441484, 1, 0.11792718523117927`], 
     Hue[0.6304490043653282, 1, 0.1270706093403148], 
     Hue[0.6203542180416428, 1, 0.14104800578849463`], 
     Hue[0.6198049529606637, 1, 0.14180852666985025`], 
     Hue[0.628103610620858, 1, 0.13031807760188902`], 
     Hue[0.6362674641449452, 1, 0.11901428041469136`], 
     Hue[0.6428864769589929, 1, 0.1098494934413944], 
     Hue[0.6474051025579688, 1, 0.10359293491973554`], 
     Hue[0.6493655121447789, 1, 0.10087852164569076`], 
     Hue[0.6498945069046956, 1, 0.10014606736272923`], 
     Hue[0.6499867675663353, 1, 0.10001832183122804`], 
     Hue[0.6499984253785815, 1, 0.10000218024504093`], 
     Hue[0.6499998299933235, 1, 0.10000023539385977`], 
     Hue[0.6499999911548267, 1, 0.10000001224716314`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999892751397, 1, 0.10000001484980654`], 
     Hue[0.6499997754662288, 1, 0.10000031089291399`], 
     Hue[0.6499973539157804, 1, 0.10000366380891944`], 
     Hue[0.6499767672229376, 1, 0.10003216846054797`], 
     Hue[0.6498650665011521, 1, 0.10018683099840481`], 
     Hue[0.6494789342968051, 1, 0.10072147558903906`], 
     Hue[0.6484750974666168, 1, 0.10211140350776145`], 
     Hue[0.6467216510809705, 1, 0.10453925234942558`], 
     Hue[0.6446046831445763, 1, 0.10747043872289433`], 
     Hue[0.6427943973773967, 1, 0.10997698824668149`], 
     Hue[0.6430790489983114, 1, 0.10958285523310743`], 
     Hue[0.6454868776150838, 1, 0.1062489386868071], 
     Hue[0.6474140437258555, 1, 0.1035805548411231], 
     Hue[0.6473544399483011, 1, 0.10366308314850617`], 
     Hue[0.6446337357779107, 1, 0.10743021199981591`], 
     Hue[0.6409665330793982, 1, 0.1125078772746795], 
     Hue[0.640815270379684, 1, 0.1127173179358222], 
     Hue[0.6438401966908248, 1, 0.10852895842808875`], 
     Hue[0.646611250047981, 1, 0.10469211531818015`], 
     Hue[0.6484564916120658, 1, 0.10213716546021669`], 
     Hue[0.6495144411551925, 1, 0.10067231224665661`], 
     Hue[0.6499027540111557, 1, 0.10013464829224594`], 
     Hue[0.6499874336314637, 1, 0.1000173995872042], 
     Hue[0.6499988652121094, 1, 0.10000157124477162`], 
     Hue[0.6499999051736008, 1, 0.10000013129809114`], 
     Hue[0.6499999965614092, 1, 0.10000000476112582`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999906329164, 1, 0.10000001296980818`], 
     Hue[0.6499998330121323, 1, 0.1000002312139707], 
     Hue[0.6499981506805673, 1, 0.10000256059613752`], 
     Hue[0.649987329336018, 1, 0.1000175439962828], 
     Hue[0.64993939103377, 1, 0.10008392010708776`], 
     Hue[0.6497836313840751, 1, 0.10029958731435758`], 
     Hue[0.6494792143044831, 1, 0.10072108788610035`], 
     Hue[0.6490770654192832, 1, 0.10127790941945408`], 
     Hue[0.6486554555700654, 1, 0.1018616769029864], 
     Hue[0.6486176146323193, 1, 0.10191407204755801`], 
     Hue[0.6491379074291289, 1, 0.10119366663659078`], 
     Hue[0.6496122957074744, 1, 0.10053682132811238`], 
     Hue[0.6495995812371504, 1, 0.10055442597933026`], 
     Hue[0.6489758122132936, 1, 0.10141810616620897`], 
     Hue[0.6481337631542463, 1, 0.10258402024796674`], 
     Hue[0.6480764344519863, 1, 0.10266339845109604`], 
     Hue[0.6487826629630273, 1, 0.10168554358965444`], 
     Hue[0.6494159862246167, 1, 0.10080863445822301`], 
     Hue[0.6497696255132579, 1, 0.10031898005856599`], 
     Hue[0.6499370212478398, 1, 0.10008720134914487`], 
     Hue[0.6499894627045795, 1, 0.10001459010135147`], 
     Hue[0.6499989259054363, 1, 0.10000148720785743`], 
     Hue[0.6499999346671307, 1, 0.10000009046089606`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999951176217, 1, 0.10000000676021609`], 
     Hue[0.6499999061825072, 1, 0.10000012990114379`], 
     Hue[0.6499992040627566, 1, 0.10000110206695244`], 
     Hue[0.649995163144138, 1, 0.10000669718503977`], 
     Hue[0.6499795954833999, 1, 0.10002825240760015`], 
     Hue[0.6499464358965762, 1, 0.10007416568166376`], 
     Hue[0.649897652583137, 1, 0.10014171180796415`], 
     Hue[0.6498351049041282, 1, 0.1002283162865917], 
     Hue[0.6498160036634709, 1, 0.10025476415827111`], 
     Hue[0.6498846296945715, 1, 0.10015974349982408`], 
     Hue[0.649955802053807, 1, 0.10006119715626728`], 
     Hue[0.649957169473705, 1, 0.10005930380563927`], 
     Hue[0.6498721609403103, 1, 0.10017700792880116`], 
     Hue[0.6497508419757096, 1, 0.10034498803363284`], 
     Hue[0.6497365099481575, 1, 0.10036483237947436`], 
     Hue[0.649839465236729, 1, 0.10022227890299075`], 
     Hue[0.6499322573296988, 1, 0.100093797543494], 
     Hue[0.6499770749005384, 1, 0.1000317424454084], 
     Hue[0.6499945135254511, 1, 0.10000759665706765`], 
     Hue[0.6499992251797292, 1, 0.10000107282806733`], 
     Hue[0.6499999405878827, 1, 0.10000008226293167`], 
     Hue[0.6499999989770763, 1, 0.10000000141635602`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499526402205567, 1, 0.10006557507922935`], 
     Hue[0.6498504249822287, 1, 0.10020710387076033`], 
     Hue[0.6497263245796807, 1, 0.10037893519736513`], 
     Hue[0.6495285121992007, 1, 0.10065282926264515`], 
     Hue[0.649784924404843, 1, 0.10029779697790969`], 
     Hue[0.649931082454768, 1, 0.10009542429339813`], 
     Hue[0.6499867458103449, 1, 0.10001835195490712`], 
     Hue[0.6499433316037029, 1, 0.10007846393333457`], 
     Hue[0.6496414165123657, 1, 0.10049650021364742`], 
     Hue[0.648886647949194, 1, 0.1015415643780391], 
     Hue[0.6480351202363256, 1, 0.10272060274970299`], 
     Hue[0.6484028479050594, 1, 0.10221144136222547`], 
     Hue[0.6494571340705553, 1, 0.10075166051769271`], 
     Hue[0.6498831365721641, 1, 0.10016181090008054`], 
     Hue[0.6499825353819552, 1, 0.1000241817788314], 
     Hue[0.6499683453811985, 1, 0.10004382947218678`], 
     Hue[0.6496792945415393, 1, 0.10044405371171489`], 
     Hue[0.6481677974731709, 1, 0.10253689580637884`], 
     Hue[0.6445214923553753, 1, 0.10758562596948039`], 
     Hue[0.6405501084637386, 1, 0.11308446520405428`], 
     Hue[0.6492881137391465, 1, 0.10098568866887413`], 
     Hue[0.6498695045742886, 1, 0.100180685974062], 
     Hue[0.6499817918932295, 1, 0.10002521122475931`], 
     Hue[0.6499751358502095, 1, 0.1000344272843254], 
     Hue[0.6498016047825689, 1, 0.10027470107028934`], 
     Hue[0.6485847479787559, 1, 0.10195957972172263`], 
     Hue[0.6432720593310828, 1, 0.10931561015696241`], 
     Hue[0.6313624537425536, 1, 0.12580583327954112`], 
     Hue[0.6184660050886543, 1, 0.14366245449263254`], 
     Hue[0.6492589568068923, 1, 0.1010260598058415], 
     Hue[0.6498541274025343, 1, 0.10020197744264474`], 
     Hue[0.649977260618031, 1, 0.10003148529811107`], 
     Hue[0.6499646389935646, 1, 0.10004896139352598`], 
     Hue[0.6498036295719553, 1, 0.10027189751575434`], 
     Hue[0.6489247582501114, 1, 0.10148879626907649`], 
     Hue[0.644695046919595, 1, 0.1073453196497916], 
     Hue[0.6305182330351189, 1, 0.12697475425906612`], 
     Hue[0.6027245775752668, 1, 0.16545827720347675`], 
     Hue[0.5726579325301511, 1, 0.207089016496714], 
     Hue[0.6498213694005998, 1, 0.10024733467609265`], 
     Hue[0.6499818197369783, 1, 0.10002517267187616`], 
     Hue[0.6499521729617384, 1, 0.10006622205297773`], 
     Hue[0.6497432504274335, 1, 0.10035549940816904`], 
     Hue[0.6488748693450612, 1, 0.10155787321453072`], 
     Hue[0.6453403329197034, 1, 0.10645184672656453`], 
     Hue[0.6328439897900153, 1, 0.1237544756753635], 
     Hue[0.6014905114148632, 1, 0.16716698419480486`], 
     Hue[0.5513276290676964, 1, 0.2366232828293435], 
     Hue[0.6490571112767588, 1, 0.10130553823218018`], 
     Hue[0.6498939340505188, 1, 0.10014686054543566`], 
     Hue[0.6499682495963772, 1, 0.10004396209732382`], 
     Hue[0.6497311511792768, 1, 0.10037225221330903`], 
     Hue[0.6486912692523092, 1, 0.1018120887275719], 
     Hue[0.6453343394936855, 1, 0.10646014531643558`], 
     Hue[0.6346959450401553, 1, 0.12119022994440043`], 
     Hue[0.6043266101331188, 1, 0.16324007827722015`], 
     Hue[0.5440586084204604, 1, 0.24668808064859338`], 
     Hue[0.6466105184332703, 1, 0.10469312832316424`], 
     Hue[0.6495693662019543, 1, 0.1005962621819095], 
     Hue[0.6499716984321321, 1, 0.10003918678627872`], 
     Hue[0.6498760636216188, 1, 0.10017160421622018`], 
     Hue[0.6489568580128253, 1, 0.1014443504437804], 
     Hue[0.6452039381529711, 1, 0.10664070101896317`], 
     Hue[0.6355388412548055, 1, 0.12002314287796167`], 
     Hue[0.6118430576320381, 1, 0.15283268943256276`], 
     Hue[0.5535710719491292, 1, 0.23351697730120574`], 
     Hue[0.4542205625498602, 1, 0.37107922108480895`], 
     Hue[0.6412227361047911, 1, 0.11215313462413552`], 
     Hue[0.6486789324967017, 1, 0.1018291703891823], 
     Hue[0.6498860418018505, 1, 0.10015778827436095`], 
     Hue[0.649658824652883, 1, 0.1004723966344697], 
     Hue[0.6471265069337676, 1, 0.10397868270709104`], 
     Hue[0.6371382682408416, 1, 0.11780855166652697`], 
     Hue[0.6153410596299196, 1, 0.14798930205088065`], 
     Hue[0.5746480881031568, 1, 0.20433341647255218`], 
     Hue[0.486935416451847, 1, 0.3257817310666734], 
     Hue[0.12966010901488478`, 1, 0.8204706182870827], 
     Hue[0.10191922355826988`, 1, 0.8588810750731648], 
     Hue[0.06671150091092626, 1, 0.9076302295079482], 
     Hue[0.04982473508133456, 1, 0.9310119052719983], 
     Hue[0.04992144844921409, 1, 0.9308779944549342], 
     Hue[0.015293892254526043`, 1, 0.9788238414937332], 
     Hue[0.6322038181205127, 1, 0.12464086721775164`], 
     Hue[0.6466541534535873, 1, 0.10463271060272532`], 
     Hue[0.6496017464371375, 1, 0.1005514280101173], 
     Hue[0.6499695901490652, 1, 0.10004210594744818`], 
     Hue[0.6493124046287972, 1, 0.10095205512935768`], 
     Hue[0.6442467894662265, 1, 0.10796598381599413`], 
     Hue[0.6246325669428242, 1, 0.13512413807916648`], 
     Hue[0.5854465812727223, 1, 0.18938165669930757`], 
     Hue[0.5269117229161162, 1, 0.2704299221161468], 
     Hue[0.09638717335159941, 1, 0.8665408368977855], 
     Hue[0.08215870968636618, 1, 0.8862417865881084], 
     Hue[0.0753255913031664, 1, 0.8957030274263851], 
     Hue[0.04579198716486599, 1, 0.9365957100794163], 
     Hue[0.03827518130522878, 1, 0.947003595115837], 
     Hue[0.05243399702446183, 1, 0.9273990810430529], 
     Hue[0.03158579533612704, 1, 0.9562658218422857], 
     Hue[0.642748252040215, 1, 0.11004088179047154`], 
     Hue[0.6488384534082097, 1, 0.10160829528094048`], 
     Hue[0.649885631292545, 1, 0.10015835667186093`], 
     Hue[0.648957922922127, 1, 0.10144287595397805`], 
     Hue[0.6414815426213831, 1, 0.11179478713962335`], 
     Hue[0.6131326796141648, 1, 0.1510470589957718], 
     Hue[0.5578078685210066, 1, 0.22765064358629852`], 
     Hue[0.48157296662888227`, 1, 0.3332066615907784], 
     Hue[0.0920558626665795, 1, 0.872538036307813], 
     Hue[0.060010301103005315`, 1, 0.9169088138573773], 
     Hue[0.06818090254019205, 1, 0.905595673405888], 
     Hue[0.04403332737386845, 1, 0.939030777482336], 
     Hue[0.03713921835702716, 1, 0.9485764668902701], 
     Hue[0.04305999072090727, 1, 0.9403784743864361], 
     Hue[0.0752377503810564, 1, 0.8958246533185372], 
     Hue[0.09006496215885129, 1, 0.8752946677800522], 
     Hue[0.04506433136870891, 1, 0.9376032334894799], 
     Hue[0.047704450707045765`, 1, 0.9339476836363981], 
     Hue[0.6473959979574577, 1, 0.10360554128967389`], 
     Hue[0.6496959663821051, 1, 0.10042096962477746`], 
     Hue[0.45582252288552855`, 1, 0.368861122158499], 
     Hue[0.06921061941669915, 1, 0.9041699115768782], 
     Hue[0.06500035122851278, 1, 0.9099995136835978], 
     Hue[0.019964360501590783`, 1, 0.9723570393054897], 
     Hue[0.10655817288624181`, 1, 0.8524579144652036], 
     Hue[0.05914074427211846, 1, 0.9181128156232207], 
     Hue[0.02948054374805975, 1, 0.9591807855796096], 
     Hue[0.6494562843072095, 1, 0.10075283711309457`], 
     Hue[0.6489306149873504, 1, 0.10148068694059174`], 
     Hue[0.6419441654706588, 1, 0.11115423242524175`], 
     Hue[0.06277317100824187, 1, 0.9130833016808959], 
     Hue[0.04230534914879014, 1, 0.9414233627170598], 
     Hue[0.05579379691654507, 1, 0.9227470504232452], 
     Hue[0.04001878174075024, 1, 0.9445893791281921], 
     Hue[0.02270435213383859, 1, 0.968563204737762], 
     Hue[0.021954692203700055`, 1, 0.9696011954102615], 
     Hue[0.08894658393597898, 1, 0.8768431914732598], 
     Hue[0.05788251122854904, 1, 0.9198549844527784], 
     Hue[0.6492881418714764, 1, 0.10098564971641733`], 
     Hue[0.6446912938155632, 1, 0.10735051625537406`], 
     Hue[0.03138458610402295, 1, 0.9565444192405836], 
     Hue[0.04394664514658153, 1, 0.9391507990278102], 
     Hue[0.017011821701268914`, 1, 0.9764451699520893], 
     Hue[0.024563788082055726`, 1, 0.9659886011171537], 
     Hue[0.04000006782983878, 1, 0.9446152906971463], 
     Hue[0.017296135589333295`, 1, 0.9760515045686154], 
     Hue[0.6463826925043435, 1, 0.10500857960937049`], 
     Hue[0.649519618401336, 1, 0.1006651437519964], 
     Hue[0.6496143344699881, 1, 0.10053399842617047`], 
     Hue[0.6469387669233665, 1, 0.10423863041380026`], 
     Hue[0.06374719256486516, 1, 0.9117346564486483], 
     Hue[0.03917513357652602, 1, 0.9457575073555794], 
     Hue[0.03291204507315115, 1, 0.9544294760525599], 
     Hue[0.03806628505559817, 1, 0.9472928360768641], 
     Hue[0.04839548955308959, 1, 0.932990860618799], 
     Hue[0.01575384386688128, 1, 0.9781869854150874], 
     Hue[0.01766771840371817, 1, 0.9755370052871594], 
     Hue[0.007937127358919605, 1, 0.9890101313491881], 
     Hue[0.6383251619286705, 1, 0.1161651604064562], 
     Hue[0.6478918916989861, 1, 0.10291891918601936`], 
     Hue[0.6497521689561618, 1, 0.10034315067608361`], 
     Hue[0.059579385507860794`, 1, 0.9175054662198852], 
     Hue[0.03639684477779204, 1, 0.9496043687692111], 
     Hue[0.04506719026812067, 1, 0.9375992750133714], 
     Hue[0.05962097947602851, 1, 0.9174478745716529], 
     Hue[0.06537149239740703, 1, 0.9094856259112827], 
     Hue[0.03209592920180482, 1, 0.9555594826436549], 
     Hue[0.013060582436783763`, 1, 0.9819161166259917], 
     Hue[0.01591414692144444, 1, 0.9779650273395385], 
     Hue[0.006231782427331911, 1, 0.9913713781775405], 
     Hue[0.004207989628574826, 1, 0.9941735528219734], 
     Hue[0.649873955654964, 1, 0.10017452293928064`], 
     Hue[0.03008855100473662, 1, 0.958338929378057], 
     Hue[0.04890138613554795, 1, 0.9322903884277028], 
     Hue[0.06759620053962478, 1, 0.9064052607912888], 
     Hue[0.0750634875863796, 1, 0.8960659402650129], 
     Hue[0.06379603857425031, 1, 0.9116670235125766], 
     Hue[0.02860812938543411, 1, 0.9603887439278604], 
     Hue[0.01176339484414013, 1, 0.9837122225234983], 
     Hue[0.0027185433606783382`, 1, 0.9962358630390608], 
     Hue[0.007080911083604202, 1, 0.9901956615765479], 
     Hue[0.011200771466911452`, 1, 0.9844912395073534], 
     Hue[0.6498689206860896, 1, 0.10018149443464522`], 
     Hue[0.027054100374850343`, 1, 0.9625404764040534], 
     Hue[0.07616475457170335, 1, 0.8945411090545646], 
     Hue[0.06025697319642764, 1, 0.9165672678818694], 
     Hue[0.03675062453942479, 1, 0.9491145198684887], 
     Hue[0.03341036005911768, 1, 0.9537395014566062], 
     Hue[0.0055160507853831975`, 1, 0.9923623912202387], 
     Hue[0.024357725617199955`, 1, 0.9662739183761847], 
     Hue[0.03693402455313788, 1, 0.9488605813879629], 
     Hue[0.06648084013307609, 1, 0.907949605969587], 
     Hue[0.6498090651319971, 1, 0.1002643713556963], 
     Hue[0.6479472674875802, 1, 0.10284224501719659`], 
     Hue[0.02718557828698054, 1, 0.9623584300641808], 
     Hue[0.05202922686153977, 1, 0.9279595320378681], 
     Hue[0.0442648248452312, 1, 0.9387102425219876], 
     Hue[0.05062406090060767, 1, 0.9299051464453124], 
     Hue[0.011864235991189576`, 1, 0.9835725963198914], 
     Hue[0.03501034690640481, 1, 0.9515241350526703], 
     Hue[0.05849152831696158, 1, 0.9190117300226686], 
     Hue[0.10014432569341958`, 1, 0.8613386259629575], 
     Hue[0.5458605576617012, 1, 0.24419307400687537`], 
     Hue[0.6088832844347836, 1, 0.1569308369364535], 
     Hue[0.6499003286002993, 1, 0.10013800655343165`], 
     Hue[0.6487901994270908, 1, 0.10167510848556657`], 
     Hue[0.6420497033491818, 1, 0.11100810305497909`], 
     Hue[0.04396788426607934, 1, 0.9391213910161978], 
     Hue[0.04229696581210751, 1, 0.9414349704140049], 
     Hue[0.04105723283376772, 1, 0.9431515237686292], 
     Hue[0.04543132522137905, 1, 0.9370950881550136], 
     Hue[0.06041538696646587, 1, 0.9163479257387396], 
     Hue[0.07023939527505385, 1, 0.9027454526960793], 
     Hue[0.08838890630987561, 1, 0.8776153604940184], 
     Hue[0.570775115281247, 1, 0.20969599422596577`], 
     Hue[0.6180198306568319, 1, 0.14428023447515584`], 
     Hue[0.6406548812508711, 1, 0.11293939519110165`], 
     Hue[0.6484020008892469, 1, 0.10221261415335046`], 
     Hue[0.6498633823894528, 1, 0.10018916284537306`], 
     Hue[0.6499619845489004, 1, 0.10005263677844557`], 
     Hue[0.6494740801880717, 1, 0.10072819666266995`], 
     Hue[0.6459589966189624, 1, 0.10559523545066753`], 
     Hue[0.07337923378810374, 1, 0.8983979839857025], 
     Hue[0.10821201323840013`, 1, 0.8501679816699075], 
     Hue[0.44253098798701795`, 1, 0.38726478586412894`], 
     Hue[0.5361910618110318, 1, 0.25758160672318675`], 
     Hue[0.5984225570659726, 1, 0.17141492098557654`], 
     Hue[0.6300938480432797, 1, 0.12756236424776654`], 
     Hue[0.6443408033198974, 1, 0.10783581078783434`], 
     Hue[0.6490665928338413, 1, 0.10129240992237362`], 
     Hue[0.6499240230913889, 1, 0.10010519879653851`], 
     Hue[0.6498316314415247, 1, 0.10023312569635048`], 
     Hue[0.6483854795500424, 1, 0.1022354898537874], 
     Hue[0.6404839771620894, 1, 0.11317603162172249`], 
     Hue[0.5172832085434217, 1, 0.28376171124757], 
     Hue[0.5834721630044652, 1, 0.19211546660920206`], 
     Hue[0.6230341544228463, 1, 0.1373373246452898], 
     Hue[0.640617770192625, 1, 0.11299077973328846`], 
     Hue[0.6475239389709543, 1, 0.10342839219406337`], 
     Hue[0.6496121812004986, 1, 0.10053697987623277`], 
     Hue[0.6499698174471147, 1, 0.10004179122707206`], 
     Hue[0.6499590662019183, 1, 0.1000566775665746], 
     Hue[0.6494853465236767, 1, 0.10071259712106306`], 
     Hue[0.6462748287316159, 1, 0.10515792944853185`], 
     Hue[0.5235747550980449, 1, 0.27505033909501486`], 
     Hue[0.5800384458876828, 1, 0.1968698441555162], 
     Hue[0.6192317834496185, 1, 0.14260214599283605`], 
     Hue[0.6393095228850015, 1, 0.11480219908230557`], 
     Hue[0.6468131363467482, 1, 0.10441258044296405`], 
     Hue[0.6492508064929488, 1, 0.10103734485591723`], 
     Hue[0.6498905049244696, 1, 0.100151608566119], 
     Hue[0.6498735936909054, 1, 0.10017502412028499`], 
     Hue[0.6489218162074085, 1, 0.10149286986666523`], 
     Hue[0.5410494544591591, 1, 0.25085460151808736`], 
     Hue[0.5859491081550583, 1, 0.18868585024684245`], 
     Hue[0.6196994673404707, 1, 0.14195458368242536`], 
     Hue[0.6389587347783106, 1, 0.11528790569156996`], 
     Hue[0.6468773681599463, 1, 0.10432364408622824`], 
     Hue[0.6492391577640024, 1, 0.10105347386522737`], 
     Hue[0.6498466378491974, 1, 0.1002123475934191], 
     Hue[0.6499795881943548, 1, 0.10002826250012427`], 
     Hue[0.6499775299978761, 1, 0.10003111231063326`], 
     Hue[0.6497811118329528, 1, 0.10030307592360387`], 
     Hue[0.5990222123873178, 1, 0.17058462900217541`], 
     Hue[0.6230598329454274, 1, 0.13730176976786973`], 
     Hue[0.6393843792112138, 1, 0.11469855186139631`], 
     Hue[0.6469348235764133, 1, 0.10424409043265863`], 
     Hue[0.6493302996040397, 1, 0.10092727747132971`], 
     Hue[0.6498728461315512, 1, 0.10017605920246762`], 
     Hue[0.6499788128410681, 1, 0.1000293360662135], 
     Hue[0.6499693786132754, 1, 0.10004239884315722`], 
     Hue[0.6497880266116084, 1, 0.10029350161469609`], 
     Hue[0.6194746765096588, 1, 0.14226583252508782`], 
     Hue[0.6312000362686843, 1, 0.12603071901259105`], 
     Hue[0.6411738544580793, 1, 0.1122208169041979], 
     Hue[0.6471125290281452, 1, 0.1039980367302606], 
     Hue[0.6493471882105425, 1, 0.10090389324694123`], 
     Hue[0.6498933512603884, 1, 0.10014766748561608`], 
     Hue[0.6499849754673326, 1, 0.10002080319907804`], 
     Hue[0.649973665157842, 1, 0.10003646362760334`], 
     Hue[0.6498261109263888, 1, 0.10024076948653866`], 
     Hue[0.6492545906914331, 1, 0.10103210519647733`], 
     Hue[0.6350240381532365, 1, 0.12073594717244189`], 
     Hue[0.6405936591312379, 1, 0.11302416427982456`], 
     Hue[0.6448541455514909, 1, 0.1071250292363973], 
     Hue[0.6478761457647362, 1, 0.10294072124882683`], 
     Hue[0.6494188117981682, 1, 0.10080472212561335`], 
     Hue[0.649895997834715, 1, 0.10014400299808708`], 
     Hue[0.6499873136549017, 1, 0.10001756570859764`], 
     Hue[0.6499816329227096, 1, 0.1000254313377867], 
     Hue[0.6499068198203933, 1, 0.10012901871022463`], 
     Hue[0.6496522182449306, 1, 0.10048154396855762`], 
     Hue[0.6490470432927504, 1, 0.1013194785177302], 
     Hue[0.6472779012856564, 1, 0.10376905975832196`], 
     Hue[0.6485607311149593, 1, 0.10199283384082568`], 
     Hue[0.6462769751265228, 1, 0.1051549575171223], 
     Hue[0.647903512271989, 1, 0.10290282916186148`], 
     Hue[0.6490055423732982, 1, 0.1013769413292794], 
     Hue[0.6496413907946905, 1, 0.1004965358227363], 
     Hue[0.6499167750000682, 1, 0.10011523461529029`], 
     Hue[0.6499880081842594, 1, 0.10001660405256396`], 
     Hue[0.6499626287427561, 1, 0.1000517448177223], 
     Hue[0.6498825939106834, 1, 0.10016256227751533`], 
     Hue[0.6497543080371967, 1, 0.1003401888715739], 
     Hue[0.6495487884917747, 1, 0.10062475439600432`], 
     Hue[0.6497844249546617, 1, 0.10029848852431462`], 
     Hue[0.649769824837636, 1, 0.1003187040709655], 
     Hue[0.6494347938362267, 1, 0.10078259314984003`], 
     Hue[0.6493743349853968, 1, 0.10086630540483534`], 
     Hue[0.6496792784296321, 1, 0.10044407602050942`], 
     Hue[0.6498693750218989, 1, 0.10018086535429382`], 
     Hue[0.6499590052975042, 1, 0.10005676189576354`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499928840699785, 1, 0.1000098528261837], 
     Hue[0.6499797451129904, 1, 0.10002804522816723`], 
     Hue[0.6499789368106524, 1, 0.10002916441601976`], 
     Hue[0.6499082777069607, 1, 0.10012700009805447`], 
     Hue[0.6498627459429446, 1, 0.10019004407899984`], 
     Hue[0.6497881497582787, 1, 0.10029333110392183`], 
     Hue[0.6495694663384647, 1, 0.10059612353135658`], 
     Hue[0.6492278023219837, 1, 0.10106919678494558`], 
     Hue[0.6495890202445054, 1, 0.10056904889222339`], 
     Hue[0.6473429681190734, 1, 0.10367896721974454`], 
     Hue[0.6495937109571688, 1, 0.10056255405930485`], 
     Hue[0.6472801906410751, 1, 0.1037658898815883], 
     Hue[0.649554256636937, 1, 0.1006171831180872], 
     Hue[0.6470252444037521, 1, 0.10411889236403554`], 
     Hue[0.6492207955611302, 1, 0.10107889845381966`], 
     Hue[0.649366509390603, 1, 0.10087714084378052`], 
     Hue[0.649671301081743, 1, 0.1004551215791251], 
     Hue[0.6467304534364349, 1, 0.10452706447262865`], 
     Hue[0.649870960492025, 1, 0.10017867008796541`], 
     Hue[0.6493804147650767, 1, 0.10085788724835536`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499956129402918, 1, 0.1000060743903652], 
     Hue[0.6499828272543736, 1, 0.1000237776477904], 
     Hue[0.6499879392993507, 1, 0.10001669943166822`], 
     Hue[0.6498437724014271, 1, 0.10021631513648556`], 
     Hue[0.6498600560391217, 1, 0.10019376856121626`], 
     Hue[0.649312641862217, 1, 0.10095172665231492`], 
     Hue[0.6491513121232934, 1, 0.10117510629082457`], 
     Hue[0.6484398729059102, 1, 0.10216017597643207`], 
     Hue[0.6474048212850052, 1, 0.10359332437460828`], 
     Hue[0.6454776827991869, 1, 0.10626166997035653`], 
     Hue[0.6449727686467337, 1, 0.10696078187375345`], 
     Hue[0.6457740500749252, 1, 0.10585131528087283`], 
     Hue[0.6476338634890185, 1, 0.10327618901520519`], 
     Hue[0.6490152340201105, 1, 0.10136352212600083`], 
     Hue[0.649997599245131, 1, 0.10000332412212636`], 
     Hue[0.649991244927906, 1, 0.10001212240751478`], 
     Hue[0.6499920290182936, 1, 0.10001103674390126`], 
     Hue[0.6498931280637097, 1, 0.10014797652717118`], 
     Hue[0.6499195775730673, 1, 0.1001113541295992], 
     Hue[0.6491691377858241, 1, 0.10115042460424367`], 
     Hue[0.6493093710736547, 1, 0.10095625543647814`], 
     Hue[0.6465717433783684, 1, 0.10474681686072071`], 
     Hue[0.6463601697878312, 1, 0.10503976490915688`], 
     Hue[0.6394594847193459, 1, 0.11459455961936725`], 
     Hue[0.6319842354501293, 1, 0.1249449047613595], 
     Hue[0.6283468590312618, 1, 0.12998127211056068`], 
     Hue[0.6350464544765527, 1, 0.12070490918631158`], 
     Hue[0.6422209146361111, 1, 0.11077104127307695`], 
     Hue[0.6471424220889351, 1, 0.10395664633839752`], 
     Hue[0.6499966473422293, 1, 0.10000464214152867`], 
     Hue[0.6499909483777528, 1, 0.10001253301541921`], 
     Hue[0.6499885759658932, 1, 0.10001581789337864`], 
     Hue[0.6499301426217967, 1, 0.10009672560058923`], 
     Hue[0.6499274152816604, 1, 0.10010050191770094`], 
     Hue[0.6494513870615394, 1, 0.10075961791479165`], 
     Hue[0.6495275168211437, 1, 0.10065420747841648`], 
     Hue[0.6467116019025025, 1, 0.10455316659653496`], 
     Hue[0.6472121893604954, 1, 0.10386004550085261`], 
     Hue[0.6380072752919099, 1, 0.11660531113427859`], 
     Hue[0.6382810357554235, 1, 0.1162262581847983], 
     Hue[0.6193915907133171, 1, 0.1423808743969456], 
     Hue[0.5848840835822561, 1, 0.19016049965533782`], 
     Hue[0.602641337125589, 1, 0.16557353321072305`], 
     Hue[0.6234840571884415, 1, 0.13671438235446573`], 
     Hue[0.6499942780486521, 1, 0.10000792270186647`], 
     Hue[0.6499853846860142, 1, 0.1000202365885957], 
     Hue[0.6499826010262422, 1, 0.10002409088674169`], 
     Hue[0.6499163940884041, 1, 0.10011576203144049`], 
     Hue[0.6499002777678503, 1, 0.10013807693682272`], 
     Hue[0.6495391224809343, 1, 0.10063813810332183`], 
     Hue[0.6495101058483288, 1, 0.10067831497923709`], 
     Hue[0.6475510535646866, 1, 0.10339084891043396`], 
     Hue[0.6476875257993613, 1, 0.10320188735473049`], 
     Hue[0.6393416521912709, 1, 0.11475771235054798`], 
     Hue[0.6402598188247917, 1, 0.11348640470413471`], 
     Hue[0.6179689233782857, 1, 0.14435072147621986`], 
     Hue[0.6187736611947413, 1, 0.1432364691149736], 
     Hue[0.580426232016515, 1, 0.19633290951559468`], 
     Hue[0.49966505636732805`, 1, 0.30815607579908433`], 
     Hue[0.5038460737454232, 1, 0.3023669748140294], 
     Hue[0.5383670555168497, 1, 0.25456869236128504`], 
     Hue[0.6499944847498004, 1, 0.10000763650027647`], 
     Hue[0.649982501337945, 1, 0.10002422891669158`], 
     Hue[0.6499860653119417, 1, 0.1000192941834654], 
     Hue[0.6498843617788137, 1, 0.10016011446010407`], 
     Hue[0.6498810291935211, 1, 0.10016472880897088`], 
     Hue[0.6494566650720704, 1, 0.10075230990021022`], 
     Hue[0.6493950223233501, 1, 0.1008376613984383], 
     Hue[0.6476949432721703, 1, 0.1031916170077643], 
     Hue[0.6476179193734379, 1, 0.10329826548293208`], 
     Hue[0.6408384149433723, 1, 0.11268527161686914`], 
     Hue[0.6412474754586565, 1, 0.11211888013416794`], 
     Hue[0.6199778069941677, 1, 0.1415691903157678], 
     Hue[0.6212242362015308, 1, 0.13984336525941898`], 
     Hue[0.5779461301664864, 1, 0.1997668966925572], 
     Hue[0.5769979038911797, 1, 0.2010798253814436], 
     Hue[0.4682089153833877, 1, 0.35171073254607854`], 
     Hue[0.3722922278609938, 1, 0.4845184537309317], 
     Hue[0.3860242434037821, 1, 0.4655048937486095], 
     Hue[0.6481292031830281, 1, 0.10259033405426883`], 
     Hue[0.6497773667885814, 1, 0.10030826136965652`], 
     Hue[0.6499000001060277, 1, 0.10013846139165404`], 
     Hue[0.6499342923611466, 1, 0.10009097980764309`], 
     Hue[0.6493721442868894, 1, 0.10086933867969165`], 
     Hue[0.6494463007386948, 1, 0.10076666051565333`], 
     Hue[0.6474767076737922, 1, 0.10349378937474928`], 
     Hue[0.6473927741963041, 1, 0.10361000495896354`], 
     Hue[0.6415118300522674, 1, 0.1117528506968606], 
     Hue[0.6415033131276426, 1, 0.1117646433617256], 
     Hue[0.6229763610226948, 1, 0.13741734627626873`], 
     Hue[0.6250392311289827, 1, 0.1345610645906393], 
     Hue[0.577695198416236, 1, 0.2001143406544425], 
     Hue[0.5816458388041322, 1, 0.19464422319427843`], 
     Hue[0.5025952420877479, 1, 0.3040988955708107], 
     Hue[0.217619563643146, 1, 0.6986806041864132], 
     Hue[0.24658280636075358`, 1, 0.6585776527312643], 
     Hue[0.6443453088116917, 1, 0.1078295724145807], 
     Hue[0.6498806122569879, 1, 0.10016530610570903`], 
     Hue[0.6492235588107339, 1, 0.10107507241590698`], 
     Hue[0.649942117266885, 1, 0.10008014532277466`], 
     Hue[0.6496100549902669, 1, 0.10053992385963044`], 
     Hue[0.649785752312044, 1, 0.10029665064486219`], 
     Hue[0.6476059905622544, 1, 0.10331478229841698`], 
     Hue[0.6481959136024488, 1, 0.10249796578122483`], 
     Hue[0.6413751945276387, 1, 0.11194203834634639`], 
     Hue[0.6418380965188583, 1, 0.11130109712773478`], 
     Hue[0.6264664147260715, 1, 0.13258496422543958`], 
     Hue[0.6269070246570778, 1, 0.13197488893635387`], 
     Hue[0.588447203439426, 1, 0.18522694908387166`], 
     Hue[0.5949737275877074, 1, 0.17619022334009746`], 
     Hue[0.5073630121889461, 1, 0.2974973677383823], 
     Hue[0.5213930746768564, 1, 0.27807112737050654`], 
     Hue[0.17284165485828984`, 1, 0.7606807855808295], 
     Hue[0.13036858469505552`, 1, 0.8194896519606923], 
     Hue[0.12297979907968837`, 1, 0.8297202781973546], 
     Hue[0.0855918314341575, 1, 0.8814882333988588], 
     Hue[0.08730870868306961, 1, 0.879111018746519], 
     Hue[0.0848002886451843, 1, 0.8825842157220526], 
     Hue[0.06060876582216401, 1, 0.9160801704000805], 
     Hue[0.10332802650425132`, 1, 0.8569304248402674], 
     Hue[0.03996560834963936, 1, 0.9446630038235764], 
     Hue[0.08145620965289024, 1, 0.887214478942152], 
     Hue[0.12098782995798008`, 1, 0.8324783892889507], 
     Hue[0.047741321288895966`, 1, 0.9338966320615287], 
     Hue[0.6178462534805712, 1, 0.1445205721038245], 
     Hue[0.5927504250997091, 1, 0.17926864216963362`], 
     Hue[0.6463310316397703, 1, 0.10508011003724108`], 
     Hue[0.6371808487791979, 1, 0.11774959399803368`], 
     Hue[0.6495865343791329, 1, 0.10057249085966219`], 
     Hue[0.6478554251443158, 1, 0.10296941133863968`], 
     Hue[0.6499938256402342, 1, 0.1000085491135218], 
     Hue[0.649783059231158, 1, 0.10030037952608907`], 
     Hue[0.6489253221048855, 1, 0.10148801554708164`], 
     Hue[0.6494973664720706, 1, 0.1006959541155947], 
     Hue[0.6434493770285653, 1, 0.10907009334506353`], 
     Hue[0.645773577941884, 1, 0.10585196900354535`], 
     Hue[0.6278269201892357, 1, 0.13070118743028908`], 
     Hue[0.631229499130892, 1, 0.12598992428030348`], 
     Hue[0.5986418110213797, 1, 0.17111133858578195`], 
     Hue[0.6011427853432639, 1, 0.16764845106317305`], 
     Hue[0.5385936731070533, 1, 0.25425491415946466`], 
     Hue[0.23464488380786952`, 1, 0.6751070839583345], 
     Hue[0.16983150080673853`, 1, 0.7648486911906698], 
     Hue[0.14728440467478776`, 1, 0.7960677473733708], 
     Hue[0.12804502917863403`, 1, 0.8227068826757374], 
     Hue[0.10132651150661054`, 1, 0.8597017532985393], 
     Hue[0.08478700872578648, 1, 0.8826026033027572], 
     Hue[0.054152927725869326`, 1, 0.9250190231487962], 
     Hue[0.05103759459161428, 1, 0.929332561334688], 
     Hue[0.04706382127373221, 1, 0.9348347090056016], 
     Hue[0.04284246034685857, 1, 0.940679670288965], 
     Hue[0.03685526688188134, 1, 0.9489696304712413], 
     Hue[0.04815766535589194, 1, 0.9333201556610726], 
     Hue[0.04878621243296999, 1, 0.9324498597081954], 
     Hue[0.04423999507366272, 1, 0.9387446222056979], 
     Hue[0.024944102982891847`, 1, 0.9654620112544575], 
     Hue[0.051954510763432604`, 1, 0.9280629850967856], 
     Hue[0.02207241681949068, 1, 0.9694381920960898], 
     Hue[0.02367750510809019, 1, 0.9672157621580291], 
     Hue[0.529515987313607, 1, 0.2668240175657749], 
     Hue[0.48298561427219616`, 1, 0.33125068793080537`], 
     Hue[0.5657302897820702, 1, 0.21668113722482596`], 
     Hue[0.6417967388879883, 1, 0.11135836153970859`], 
     Hue[0.6198059617493407, 1, 0.14180712988552835`], 
     Hue[0.6487818729791549, 1, 0.10168663741347785`], 
     Hue[0.6449732271074773, 1, 0.1069601470819546], 
     Hue[0.6498832343034661, 1, 0.10016167557981633`], 
     Hue[0.6493007735785594, 1, 0.10096815966045625`], 
     Hue[0.6499386614486314, 1, 0.10008493030189503`], 
     Hue[0.6478410961136738, 1, 0.10298925153491324`], 
     Hue[0.6491239428051558, 1, 0.10121300226978432`], 
     Hue[0.6369501748401805, 1, 0.11806898868282709`], 
     Hue[0.642737568395344, 1, 0.11005567452952371`], 
     Hue[0.6071453432796277, 1, 0.15933721699743872`], 
     Hue[0.5597071970700245, 1, 0.2250208040568893], 
     Hue[0.41809850004166293`, 1, 0.42109438455769754`], 
     Hue[0.2608593717966918, 1, 0.6388101005891961], 
     Hue[0.14373981935516944`, 1, 0.8009756347389961], 
     Hue[0.11385760191224459`, 1, 0.8423510127368922], 
     Hue[0.11340586755479654`, 1, 0.842976491077974], 
     Hue[0.0864673351448505, 1, 0.8802759974917456], 
     Hue[0.07424878161524928, 1, 0.8971939946865779], 
     Hue[0.06346351039982301, 1, 0.9121274471387066], 
     Hue[0.07048247693635856, 1, 0.902408878088119], 
     Hue[0.04384938853840026, 1, 0.9392854620237535], 
     Hue[0.04673950701240759, 1, 0.9352837595212818], 
     Hue[0.040914070490966625`, 1, 0.9433497485509693], 
     Hue[0.04297164654140717, 1, 0.9405007970965131], 
     Hue[0.041606744592537104`, 1, 0.9423906613334102], 
     Hue[0.057742674284490425`, 1, 0.9200486048368594], 
     Hue[0.06506422932165223, 1, 0.9099110670930969], 
     Hue[0.020835859070153506`, 1, 0.9711503489797875], 
     Hue[0.03668872889877006, 1, 0.9492002215247799], 
     Hue[0.07932867636779195, 1, 0.8901602942599804], 
     Hue[0.061955588798035865`, 1, 0.9142153385873351], 
     Hue[0.4441471648046818, 1, 0.38502700257813294`], 
     Hue[0.5432776808772282, 1, 0.24776936493922264`], 
     Hue[0.6344540014127219, 1, 0.12152522881315427`], 
     Hue[0.6469377990993272, 1, 0.10423997047785463`], 
     Hue[0.6369645683713758, 1, 0.11804905917809505`], 
     Hue[0.6496096261274799, 1, 0.10054051766964324`], 
     Hue[0.6481939225872458, 1, 0.1025007225715058], 
     Hue[0.6498045535736218, 1, 0.10027061812883147`], 
     Hue[0.6467667304978932, 1, 0.10447683469522485`], 
     Hue[0.6308718972569096, 1, 0.12648506533658666`], 
     Hue[0.1969173040702228, 1, 0.7273452712873838], 
     Hue[0.13349793587134184`, 1, 0.8151567041781421], 
     Hue[0.15449209515222717`, 1, 0.7860878682507624], 
     Hue[0.06966928016292162, 1, 0.9035348428513392], 
     Hue[0.07790514759531786, 1, 0.8921313340987906], 
     Hue[0.05882818130195988, 1, 0.9185455951203633], 
     Hue[0.046839570392211316`, 1, 0.9351452102261689], 
     Hue[0.06893345561113229, 1, 0.9045536768461244], 
     Hue[0.05546128842092035, 1, 0.9232074468018026], 
     Hue[0.06684605185253967, 1, 0.9074439282041759], 
     Hue[0.03292638791936153, 1, 0.9544096167270378], 
     Hue[0.03778947236264629, 1, 0.947676115190182], 
     Hue[0.05675030755190069, 1, 0.9214226510819837], 
     Hue[0.03570489153880074, 1, 0.9505624578693528], 
     Hue[0.08895651376524671, 1, 0.8768294424788892], 
     Hue[0.07364562388007911, 1, 0.8980291361660443], 
     Hue[0.06378227688246352, 1, 0.9116860781627427], 
     Hue[0.09142800104740412, 1, 0.8734073831651328], 
     Hue[0.04337834946898811, 1, 0.9399376699660165], 
     Hue[0.053360288434190384`, 1, 0.9261165237065057], 
     Hue[0.31103908957087173`, 1, 0.5693304913634084], 
     Hue[0.2608761125329217, 1, 0.6387869211082623], 
     Hue[0.4189347361986594, 1, 0.41993651910954866`], 
     Hue[0.6438229987528055, 1, 0.108552770957654], 
     Hue[0.6315340516083862, 1, 0.12556823623454222`], 
     Hue[0.6490405401899926, 1, 0.10132848281385642`], 
     Hue[0.6458046755498129, 1, 0.10580891077718221`], 
     Hue[0.649571792185221, 1, 0.10059290312815555`], 
     Hue[0.6487924363820959, 1, 0.10167201116325188`], 
     Hue[0.6488235490858598, 1, 0.10162893203496329`], 
     Hue[0.6405162376921787, 1, 0.11313136319544495`], 
     Hue[0.6409643814275047, 1, 0.11251085648499357`], 
     Hue[0.6098977700362115, 1, 0.15552616456524565`], 
     Hue[0.6161409734588983, 1, 0.14688172905691005`], 
     Hue[0.10085367132225931`, 1, 0.8603564550922564], 
     Hue[0.13077428104049005`, 1, 0.8189279185593215], 
     Hue[0.05323544766854349, 1, 0.9262893801512475], 
     Hue[0.06454562849689671, 1, 0.9106291297735276], 
     Hue[0.04802552800189974, 1, 0.9335031150742926], 
     Hue[0.06378728993283145, 1, 0.9116791370160795], 
     Hue[0.04331824258096162, 1, 0.9400208948878993], 
     Hue[0.03899639751993289, 1, 0.9460049880493236], 
     Hue[0.025340143115403557`, 1, 0.9649136479940565], 
     Hue[0.03874590377099185, 1, 0.9463518255478575], 
     Hue[0.024736856504633864`, 1, 0.9657489679166609], 
     Hue[0.021831555326996432`, 1, 0.9697716926241587], 
     Hue[0.02835836757554444, 1, 0.960734567972323], 
     Hue[0.021850322737412053`, 1, 0.9697457069789679], 
     Hue[0.05111216905145455, 1, 0.9292293043902936], 
     Hue[0.02866081862370662, 1, 0.9603157895979446], 
     Hue[0.09533754624060164, 1, 0.8679941667437824], 
     Hue[0.10380377797397022`, 1, 0.8562716920360413], 
     Hue[0.09110199110752693, 1, 0.8738587815434243], 
     Hue[0.09394741357973357, 1, 0.8699189658126766], 
     Hue[0.06086389365568445, 1, 0.9157269164767445], 
     Hue[0.03959073322495832, 1, 0.9451820616885191], 
     Hue[0.1174068325190113, 1, 0.8374366934352152], 
     Hue[0.020270591689855677`, 1, 0.9719330268909692], 
     Hue[0.08935638548149105, 1, 0.8762757739487047], 
     Hue[0.6300236387284205, 1, 0.12765957714526402`], 
     Hue[0.648367114770052, 1, 0.10226091801069716`], 
     Hue[0.6453198371265559, 1, 0.10648022551707637`], 
     Hue[0.6493649650646504, 1, 0.10087927914125343`], 
     Hue[0.6468238797601883, 1, 0.10439770494743159`], 
     Hue[0.6490957200063673, 1, 0.1012520799911838], 
     Hue[0.6432669261033601, 1, 0.10932271770303982`], 
     Hue[0.6263558930870176, 1, 0.1327379941872065], 
     Hue[0.063702918837506, 1, 0.911795958532684], 
     Hue[0.03932782850740746, 1, 0.945546083605128], 
     Hue[0.051256636811168765`, 1, 0.9290292721076125], 
     Hue[0.05155810882666456, 1, 0.928611849316926], 
     Hue[0.04211336564291279, 1, 0.94168918603289], 
     Hue[0.028071927888881465`, 1, 0.961131176769241], 
     Hue[0.042007767928972206`, 1, 0.9418353982521923], 
     Hue[0.021950163922795585`, 1, 0.9696074653376677], 
     Hue[0.04812933735018965, 1, 0.9333593790535835], 
     Hue[0.017618916820366315`, 1, 0.9756045767102621], 
     Hue[0.07241906560978828, 1, 0.8997274476172161], 
     Hue[0.09631631241168948, 1, 0.866638952045353], 
     Hue[0.02287603739019972, 1, 0.9683254866904927], 
     Hue[0.014224747598486465`, 1, 0.980304195632865], 
     Hue[0.020622314266075636`, 1, 0.9714460264008185], 
     Hue[0.020286550418896154`, 1, 0.9719109301892208], 
     Hue[0.6479072288091489, 1, 0.10289768318733242`], 
     Hue[0.6494714228699296, 1, 0.10073187602625133`], 
     Hue[0.6381726880864029, 1, 0.11637627803421129`], 
     Hue[0.6459762467132516, 1, 0.1055713507047286], 
     Hue[0.04020902413034955, 1, 0.9443259665887468], 
     Hue[0.032565472331178236`, 1, 0.954909346002984], 
     Hue[0.03968611312065595, 1, 0.9450499972175533], 
     Hue[0.0300974469101446, 1, 0.958326611970569], 
     Hue[0.037947340906303806`, 1, 0.9474575279758871], 
     Hue[0.03937204369670555, 1, 0.9454848625737924], 
     Hue[0.045799032241573334`, 1, 0.9365859553578215], 
     Hue[0.034926678663978916`, 1, 0.9516399833883369], 
     Hue[0.02659468896281969, 1, 0.9631765845130189], 
     Hue[0.05197282591632124, 1, 0.9280376256543245], 
     Hue[0.014422701188508302`, 1, 0.9800301060466808], 
     Hue[0.025491634684400077`, 1, 0.9647038904369846], 
     Hue[0.06173693681063297, 1, 0.9145180874929698], 
     Hue[0.018555457171142264`, 1, 0.9743078285322645], 
     Hue[0.06382580496732082, 1, 0.9116258085067865], 
     Hue[0.027758202936372767`, 1, 0.9615655651650223], 
     Hue[0.02832450389030905, 1, 0.9607814561518797], 
     Hue[0.012783702065627178`, 1, 0.982299489447593], 
     Hue[0.012742323705093428`, 1, 0.9823567825621784], 
     Hue[0.633340314134012, 1, 0.1230672573529064], 
     Hue[0.6418035027130007, 1, 0.1113489962435376], 
     Hue[0.6485867105400551, 1, 0.10195686232915442`], 
     Hue[0.6471746299602236, 1, 0.10391205082430587`], 
     Hue[0.6496414126047206, 1, 0.10049650562423307`], 
     Hue[0.6488387891085793, 1, 0.1016078304650441], 
     Hue[0.6342202833321612, 1, 0.12184883846316147`], 
     Hue[0.04908649437740542, 1, 0.9320340847082078], 
     Hue[0.06203599014832939, 1, 0.9141040136407748], 
     Hue[0.03386942937047288, 1, 0.953103867025499], 
     Hue[0.038226547820264134`, 1, 0.9470709337873267], 
     Hue[0.03472413692703513, 1, 0.9519204257933359], 
     Hue[0.03870074613812324, 1, 0.9464143515010601], 
     Hue[0.05285158354595809, 1, 0.9268208843209811], 
     Hue[0.05780686512530042, 1, 0.9199597252111225], 
     Hue[0.057805446899979906`, 1, 0.9199616889077202], 
     Hue[0.06317244893635121, 1, 0.9125304553188984], 
     Hue[0.05523839826900456, 1, 0.9235160639352245], 
     Hue[0.015500707356173038`, 1, 0.9785374821222219], 
     Hue[0.03023901383841665, 1, 0.9581305962237309], 
     Hue[0.03546306232424323, 1, 0.9508972983202786], 
     Hue[0.014395614917667054`, 1, 0.9800676101139996], 
     Hue[0.035104062319544216`, 1, 0.9513943752498619], 
     Hue[0.02405128884439378, 1, 0.966698215446224], 
     Hue[0.011250381962026212`, 1, 0.9844225480525791], 
     Hue[0.009910132685224782, 1, 0.986278277820458], 
     Hue[0.02177802835173781, 1, 0.9698458068975938], 
     Hue[0.004543249671876803, 1, 0.9937093466081706], 
     Hue[0.025107756785021418`, 1, 0.9652354136822779], 
     Hue[0.6061907515330937, 1, 0.16065895941571648`], 
     Hue[0.6263033779322905, 1, 0.13281070747836696`], 
     Hue[0.6447852320084005, 1, 0.10722044798836847`], 
     Hue[0.6411254416378414, 1, 0.11228785003991207`], 
     Hue[0.6492329501649864, 1, 0.10106206900232663`], 
     Hue[0.648663555923987, 1, 0.10185046102832576`], 
     Hue[0.6498318460733453, 1, 0.10023282851382961`], 
     Hue[0.6497345839418999, 1, 0.1003674991573695], 
     Hue[0.6476827084334378, 1, 0.10320855755370151`], 
     Hue[0.04235233865242527, 1, 0.9413583003274112], 
     Hue[0.03910622726320212, 1, 0.9458529160971048], 
     Hue[0.06414575702915948, 1, 0.9111827979596253], 
     Hue[0.06778780339163404, 1, 0.9061399645346605], 
     Hue[0.06224339489413622, 1, 0.9138168378388883], 
     Hue[0.0651657017368743, 1, 0.9097705668258663], 
     Hue[0.04226676012846009, 1, 0.9414767936682861], 
     Hue[0.030808129440789145`, 1, 0.9573425900050612], 
     Hue[0.01170176215431551, 1, 0.9837975600940247], 
     Hue[0.01565870931337987, 1, 0.9783187101814741], 
     Hue[0.01766461000182884, 1, 0.975541309228237], 
     Hue[0.011200458930441526`, 1, 0.9844916722501579], 
     Hue[0.010407720312972546`, 1, 0.9855893103358842], 
     Hue[0.0034138151309827114`, 1, 0.9952731790494086], 
     Hue[0.006897189694763606, 1, 0.9904500450380196], 
     Hue[0.010335324634626275`, 1, 0.985689550505902], 
     Hue[0.015446904534346051`, 1, 0.9786119783370594], 
     Hue[0.0398940342976547, 1, 0.9447621063570935], 
     Hue[0.6495629543271926, 1, 0.10060514016234881`], 
     Hue[0.648516512791204, 1, 0.10205405921217907`], 
     Hue[0.6498827827309209, 1, 0.10016230083410951`], 
     Hue[0.6497203665201945, 1, 0.10038718481819231`], 
     Hue[0.6474576970268802, 1, 0.10352011180893522`], 
     Hue[0.05674124962376981, 1, 0.9214351928286264], 
     Hue[0.035635770454682913`, 1, 0.9506581639858237], 
     Hue[0.036779308210869055`, 1, 0.9490748040157198], 
     Hue[0.027328594169229725`, 1, 0.9621604080733742], 
     Hue[0.036472832788678744`, 1, 0.949499154600291], 
     Hue[0.07273015397217786, 1, 0.8992967098846769], 
     Hue[0.06276979263287419, 1, 0.9130879794314051], 
     Hue[0.07236131028131065, 1, 0.8998074165335698], 
     Hue[0.07857626794534867, 1, 0.8912020905372094], 
     Hue[0.062175982845062094`, 1, 0.9139101775991447], 
     Hue[0.03510070900271234, 1, 0.9513990183039368], 
     Hue[0.03724283613257506, 1, 0.9484329961241269], 
     Hue[0.028798522432975315`, 1, 0.9601251227851111], 
     Hue[0.022763360938319654`, 1, 0.9684815002392496], 
     Hue[0.004078417893809028, 1, 0.9943529598393414], 
     Hue[0.002908058206684494, 1, 0.9959734578676677], 
     Hue[0.00967239290046773, 1, 0.9866074559839678], 
     Hue[0.005529653108682253, 1, 0.9923435572341323], 
     Hue[0.012484215973968316`, 1, 0.9827141624975824], 
     Hue[0.017629013650984904`, 1, 0.9755905964832517], 
     Hue[0.02318367396042942, 1, 0.9678995283624823], 
     Hue[0.11405287495366134`, 1, 0.8420806346795459], 
     Hue[0.05209843862902197, 1, 0.9278637003598158], 
     Hue[0.6495217561177691, 1, 0.10066218383693515`], 
     Hue[0.6497311521323709, 1, 0.10037225089364041`], 
     Hue[0.6473952423061683, 1, 0.10360658757607465`], 
     Hue[0.6497643515251672, 1, 0.10032628250361468`], 
     Hue[0.6476038143816514, 1, 0.1033177954715597], 
     Hue[0.6358751867983506, 1, 0.11955743366382224`], 
     Hue[0.6379716059336993, 1, 0.11665469947641649`], 
     Hue[0.5973971640182597, 1, 0.1728346959747174], 
     Hue[0.6047209206133498, 1, 0.16269410991997724`], 
     Hue[0.5011956880741875, 1, 0.30603673958958666`], 
     Hue[0.5244614932811363, 1, 0.2738225477645805], 
     Hue[0.06658553862345051, 1, 0.9078046388290685], 
     Hue[0.03943111213434636, 1, 0.9454030755062897], 
     Hue[0.02730191728939424, 1, 0.962197345291608], 
     Hue[0.07249966521881224, 1, 0.8996158481585677], 
     Hue[0.07177912136293307, 1, 0.9006135242667082], 
     Hue[0.05713167313258127, 1, 0.9208946064318106], 
     Hue[0.03348569841109739, 1, 0.9536351868154036], 
     Hue[0.040103115136827516`, 1, 0.9444726098105466], 
     Hue[0.030765838506016552`, 1, 0.957401146683977], 
     Hue[0.0005871844906407686, 1, 0.9991869753206513], 
     Hue[0.014855475239958005`, 1, 0.9794308804369811], 
     Hue[0.007260088903489836, 1, 0.9899475692105526], 
     Hue[0.03132866983503346, 1, 0.9566218417668767], 
     Hue[0.03009674037298249, 1, 0.9583275902527935], 
     Hue[0.04642487245442661, 1, 0.935719407370794], 
     Hue[0.14987274174283238`, 1, 0.7924838960483859], 
     Hue[0.08238001756527602, 1, 0.8859353602942331], 
     Hue[0.6480585484955923, 1, 0.10268816362148765`], 
     Hue[0.6498243689177996, 1, 0.10024318149843137`], 
     Hue[0.6493185912905913, 1, 0.10094348898225812`], 
     Hue[0.6498567041650429, 1, 0.10019840961763293`], 
     Hue[0.6446913352474132, 1, 0.1073504588881972], 
     Hue[0.6483645651703301, 1, 0.1022644482256968], 
     Hue[0.6398915737942011, 1, 0.11399628243879846`], 
     Hue[0.6174750778177862, 1, 0.14503450763691145`], 
     Hue[0.5557489410953519, 1, 0.23050146617566664`], 
     Hue[0.04114736505943639, 1, 0.9430267253023189], 
     Hue[0.028995626443264477`, 1, 0.9598522095400953], 
     Hue[0.04287206517898379, 1, 0.9406386789829455], 
     Hue[0.05564037309045844, 1, 0.9229594834132114], 
     Hue[0.03821511511737008, 1, 0.9470867636836415], 
     Hue[0.04512312488394288, 1, 0.9375218270837713], 
     Hue[0.046980244805912674`, 1, 0.9349504302687363], 
     Hue[0.046182796307279284`, 1, 0.9360545897283825], 
     Hue[0.04619322686986671, 1, 0.9360401474109538], 
     Hue[0.04604454281532411, 1, 0.9362460176403204], 
     Hue[0.019461172291428963`, 1, 0.9730537614426368], 
     Hue[0.010927148611725057`, 1, 0.9848701019222269], 
     Hue[0.021491831017871443`, 1, 0.9702420801291012], 
     Hue[0.052216808283995775`, 1, 0.9276998039144675], 
     Hue[0.073546483612427, 1, 0.8981664073058703], 
     Hue[0.07082412611096944, 1, 0.9019358253848115], 
     Hue[0.1960728982836375, 1, 0.7285144485303481], 
     Hue[0.14955674022584597`, 1, 0.7929214366103671], 
     Hue[0.6479700144213345, 1, 0.10281074926276763`], 
     Hue[0.6498189065050572, 1, 0.10025074483915158`], 
     Hue[0.6496221737513989, 1, 0.10052314403652472`], 
     Hue[0.649935871708054, 1, 0.1000887930196176], 
     Hue[0.6466792087735233, 1, 0.1045980186212755], 
     Hue[0.6491707727534062, 1, 0.10114816080297602`], 
     Hue[0.6330896828089344, 1, 0.12341428534147542`], 
     Hue[0.644147797331992, 1, 0.10810304984801113`], 
     Hue[0.6306772769191878, 1, 0.12675453965035532`], 
     Hue[0.5878838126852955, 1, 0.18600702858959084`], 
     Hue[0.08331044335212145, 1, 0.8846470784355241], 
     Hue[0.046917387134525534`, 1, 0.93503746396758], 
     Hue[0.04390991163468083, 1, 0.9392016608135189], 
     Hue[0.040980195123120455`, 1, 0.9432581913679872], 
     Hue[0.07897957699311564, 1, 0.8906436626249168], 
     Hue[0.04234901044964512, 1, 0.9413629086081837], 
     Hue[0.05722195695522958, 1, 0.9207695980619898], 
     Hue[0.051646060313505715`, 1, 0.928490070335146], 
     Hue[0.05251349719599674, 1, 0.9272890038824662], 
     Hue[0.06374640815574029, 1, 0.9117357425535904], 
     Hue[0.08537548656032357, 1, 0.881787787839552], 
     Hue[0.0385175879758185, 1, 0.9466679551104051], 
     Hue[0.04114861662600333, 1, 0.9430249923639954], 
     Hue[0.06862005929191517, 1, 0.9049876102111943], 
     Hue[0.10347457421568385`, 1, 0.8567275126244377], 
     Hue[0.11385937245644162`, 1, 0.8423485612141577], 
     Hue[0.15292311430085864`, 1, 0.7882603032757342], 
     Hue[0.23323942635673817`, 1, 0.6770531019675933], 
     Hue[0.48801219794735573`, 1, 0.3242908028421228], 
     Hue[0.5341435059359803, 1, 0.2604166840886427], 
     Hue[0.5982220603813023, 1, 0.17169253177973526`], 
     Hue[0.5845883516301834, 1, 0.19056997466589995`], 
     Hue[0.6317548984875883, 1, 0.12526244824795474`], 
     Hue[0.6239743082146333, 1, 0.136035573241277], 
     Hue[0.6458185997401262, 1, 0.1057896311290561], 
     Hue[0.6424510944726874, 1, 0.11045233073012517`], 
     Hue[0.6494871121063018, 1, 0.10071015246819745`], 
     Hue[0.6487295762190795, 1, 0.10175904831204388`], 
     Hue[0.6498940522334328, 1, 0.10014669690755466`], 
     Hue[0.6498466142821047, 1, 0.10021238022477813`], 
     Hue[0.6484433935716636, 1, 0.10215530120846578`], 
     Hue[0.6496912017207931, 1, 0.10042756684813268`], 
     Hue[0.640674020104104, 1, 0.11291289524047132`], 
     Hue[0.6473724607374948, 1, 0.10363813128654573`], 
     Hue[0.6361000256953032, 1, 0.11924611826804174`], 
     Hue[0.6151320522154582, 1, 0.14827869693244256`], 
     Hue[0.1596290617659139, 1, 0.7789751452471961], 
     Hue[0.11049739432170946`, 1, 0.8470036078622484], 
     Hue[0.05951057796403525, 1, 0.9176007382036434], 
     Hue[0.1382321091586478, 1, 0.808601695011103], 
     Hue[0.1933652782816741, 1, 0.732263460840759], 
     Hue[0.10260640413962985`, 1, 0.8579295942682048], 
     Hue[0.0968589290088846, 1, 0.8658876367569289], 
     Hue[0.1232954230039437, 1, 0.829283260456078], 
     Hue[0.5718304307809572, 1, 0.20823478814944402`], 
     Hue[0.5606098595318073, 1, 0.22377096372518987`], 
     Hue[0.6171800509417378, 1, 0.1454430063883631], 
     Hue[0.6115081992411145, 1, 0.15329633951230298`], 
     Hue[0.6387983294092281, 1, 0.11551000543337656`], 
     Hue[0.6357993080374023, 1, 0.11966249656359686`], 
     Hue[0.647508835048726, 1, 0.10344930531714862`], 
     Hue[0.6460890626091076, 1, 0.10541514407969726`], 
     Hue[0.6497072613450633, 1, 0.10040533044529704`], 
     Hue[0.6493701828632253, 1, 0.10087205449707268`], 
     Hue[0.6499498970190645, 1, 0.1000693733582184], 
     Hue[0.6499896950543148, 1, 0.10001426838633333`], 
     Hue[0.6499551701358096, 1, 0.10006207211964821`], 
     Hue[0.6494456622274193, 1, 0.10076754460818878`], 
     Hue[0.6499143109726556, 1, 0.10011864634555381`], 
     Hue[0.6458326060671404, 1, 0.10577023775319017`], 
     Hue[0.6490614852743954, 1, 0.10129948192776017`], 
     Hue[0.6438452036828677, 1, 0.10852202566987551`], 
     Hue[0.26974375768505293`, 1, 0.6265086432053113], 
     Hue[0.2202116703539247, 1, 0.6950915333561043], 
     Hue[0.11554778122661113`, 1, 0.8400107644554615], 
     Hue[0.12077383989361423`, 1, 0.8327746832242264], 
     Hue[0.20654611374663495`, 1, 0.7140130732738901], 
     Hue[0.20302378292331336`, 1, 0.7188901467215661], 
     Hue[0.5531910975010145, 1, 0.23404309576782611`], 
     Hue[0.5512511604070232, 1, 0.2367291625133526], 
     Hue[0.6067316298318661, 1, 0.15991005100203148`], 
     Hue[0.6033274165863522, 1, 0.16462357703428146`], 
     Hue[0.6337578235466775, 1, 0.12248916739690813`], 
     Hue[0.6323801483147224, 1, 0.12439671771807657`], 
     Hue[0.6449320495038608, 1, 0.10701716222542348`], 
     Hue[0.6442911299742498, 1, 0.10790458926642348`], 
     Hue[0.6489398590923566, 1, 0.10146788741058314`], 
     Hue[0.6485710056789802, 1, 0.10197860752141213`], 
     Hue[0.649881029445154, 1, 0.10016472846055606`], 
     Hue[0.6497832518124702, 1, 0.10030011287504136`], 
     Hue[0.6499918225336475, 1, 0.10001132264571887`], 
     Hue[0.6498452007250434, 1, 0.10021433745763235`], 
     Hue[0.649735457201385, 1, 0.10036629002885156`], 
     Hue[0.6479101686794568, 1, 0.10289361259767515`], 
     Hue[0.32875492464829176`, 1, 0.5448008735639037], 
     Hue[0.3537205581728769, 1, 0.5102330732990935], 
     Hue[0.333133861503319, 1, 0.5387377302261738], 
     Hue[0.3337410944829357, 1, 0.5378969461005506], 
     Hue[0.5537084199814506, 1, 0.23332680310260698`], 
     Hue[0.5582063345886067, 1, 0.22709892133885234`], 
     Hue[0.6020616416292124, 1, 0.16637618851339822`], 
     Hue[0.6027978226852437, 1, 0.16535686089735485`], 
     Hue[0.63142728496753, 1, 0.12571606696803544`], 
     Hue[0.6309683481219115, 1, 0.1263515179850456], 
     Hue[0.6440561742973234, 1, 0.10822991251139841`], 
     Hue[0.6439930780875056, 1, 0.10831727649422306`], 
     Hue[0.6483854291209886, 1, 0.10223555967863114`], 
     Hue[0.6483716270070116, 1, 0.1022546702979841], 
     Hue[0.64969166042028, 1, 0.1004269317257661], 
     Hue[0.6496438862486836, 1, 0.10049308057874576`], 
     Hue[0.6499672163735649, 1, 0.1000453927135256], 
     Hue[0.6499501601459003, 1, 0.10006900902875335`], 
     Hue[0.46967072215803674`, 1, 0.34968669239656447`], 
     Hue[0.47264194566560447`, 1, 0.34557269061685536`], 
     Hue[0.564331452498748, 1, 0.2186179888478873], 
     Hue[0.5735306705356845, 1, 0.20588061002751384`], 
     Hue[0.6046278616122931, 1, 0.16282296084451736`], 
     Hue[0.6073197872702389, 1, 0.1590956791642846], 
     Hue[0.6310548183915224, 1, 0.12623178991943051`], 
     Hue[0.6315445968142752, 1, 0.1255536351802343], 
     Hue[0.6439758086627911, 1, 0.10834118800536614`], 
     Hue[0.643991942151482, 1, 0.10831884932871719`], 
     Hue[0.6484358826825427, 1, 0.10216570090109477`], 
     Hue[0.6484977919336846, 1, 0.1020799803995137], 
     Hue[0.6496458300863586, 1, 0.10049038911119593`], 
     Hue[0.6496749069882731, 1, 0.10045012878546807`], 
     Hue[0.6499401762947263, 1, 0.10008283282268662`], 
     Hue[0.6499401407462699, 1, 0.10008288204362627`], 
     Hue[0.6499985448044754, 1, 0.10000201488611099`], 
     Hue[0.6499974993088754, 1, 0.10000346249540334`], 
     Hue[0.5701711350095648, 1, 0.21053227460214102`], 
     Hue[0.5577170757836172, 1, 0.2277763566072994], 
     Hue[0.5737642510157568, 1, 0.2055571909012599], 
     Hue[0.6003465848589445, 1, 0.1687508825029999], 
     Hue[0.6116257420746372, 1, 0.1531335878966563], 
     Hue[0.6179811658048272, 1, 0.14433377042408546`], 
     Hue[0.6324341983167951, 1, 0.12432187925366832`], 
     Hue[0.6340270983949128, 1, 0.12211632529935157`], 
     Hue[0.644066898230662, 1, 0.10821506398831415`], 
     Hue[0.6442677396062926, 1, 0.10793697592974871`], 
     Hue[0.6485269424052195, 1, 0.1020396182081577], 
     Hue[0.6485359654684775, 1, 0.10202712473595432`], 
     Hue[0.6497053544187258, 1, 0.10040797080484122`], 
     Hue[0.649722832880679, 1, 0.10038376985752137`], 
     Hue[0.6499466377345717, 1, 0.10007388621366997`], 
     Hue[0.6499543998457624, 1, 0.10006313867509821`], 
     Hue[0.6499922839703353, 1, 0.100010683733382], 
     Hue[0.6499979998900263, 1, 0.10000276938304065`], 
     Hue[0.6090958982558502, 1, 0.1566364485688228], 
     Hue[0.5994620676246191, 1, 0.16997559867360446`], 
     Hue[0.6254744127533969, 1, 0.13395850541837362`], 
     Hue[0.6324216621653719, 1, 0.12433923700179281`], 
     Hue[0.6365593174232859, 1, 0.11861017587545042`], 
     Hue[0.6397560644317252, 1, 0.1141839107868421], 
     Hue[0.6447113402595225, 1, 0.10732275964066115`], 
     Hue[0.6454860230659113, 1, 0.10625012190873817`], 
     Hue[0.6485631153977498, 1, 0.10198953252619256`], 
     Hue[0.6486512431710065, 1, 0.10186750945552941`], 
     Hue[0.6497272868430781, 1, 0.1003776028326611], 
     Hue[0.649729245179856, 1, 0.1003748912894302], 
     Hue[0.649959795601362, 1, 0.1000556676288835], 
     Hue[0.6499618245100471, 1, 0.10005285837070392`], 
     Hue[0.6499987289203185, 1, 0.10000175995648206`], 
     Hue[0.6496197556902774, 1, 0.10052649212115435`], 
     Hue[0.64775670917018, 1, 0.10310609499513543`], 
     Hue[0.6497239754316693, 1, 0.10038218786384263`], 
     Hue[0.6448156264660667, 1, 0.10717836335467683`], 
     Hue[0.6408682757931777, 1, 0.11264392582483083`], 
     Hue[0.6384319393660486, 1, 0.11601731472393284`], 
     Hue[0.6441687784852134, 1, 0.10807399902047378`], 
     Hue[0.6426350077760178, 1, 0.11019768154089855`], 
     Hue[0.6444041113611124, 1, 0.10774815349999815`], 
     Hue[0.6466485070056949, 1, 0.10464052876134554`], 
     Hue[0.6358158736104513, 1, 0.11963955961629825`], 
     Hue[0.6317154942047327, 1, 0.1253170080242163], 
     Hue[0.6421858675795608, 1, 0.11081956796676201`], 
     Hue[0.6428851275863636, 1, 0.10985136180349653`], 
     Hue[0.6453589787161614, 1, 0.10642602946993036`], 
     Hue[0.6465358791983307, 1, 0.10479647495615756`], 
     Hue[0.6476309591945539, 1, 0.10328021034600224`], 
     Hue[0.648827440139892, 1, 0.101623544421688], 
     Hue[0.6490855674893812, 1, 0.10126613732239526`], 
     Hue[0.6497410574906399, 1, 0.10035853578219085`], 
     Hue[0.6497700296486953, 1, 0.1003184204864218], 
     Hue[0.6499621235485527, 1, 0.1000524443173887], 
     Hue[0.6499631535111297, 1, 0.10005101821535896`], 
     Hue[0.6499988889067965, 1, 0.10000153843674342`], 
     Hue[0.6498140933002458, 1, 0.10025740927658276`], 
     Hue[0.6493974162897445, 1, 0.10083434667573848`], 
     Hue[0.6498803207664913, 1, 0.10016570970793527`], 
     Hue[0.6481536790762313, 1, 0.10255644435598744`], 
     Hue[0.6496472070081551, 1, 0.10048848260409299`], 
     Hue[0.6471402612431302, 1, 0.10395963827874292`], 
     Hue[0.6492885444887708, 1, 0.10098509224631728`], 
     Hue[0.6495864562717184, 1, 0.10057259900838997`], 
     Hue[0.6479494343434392, 1, 0.102839244755238], 
     Hue[0.6488362751137784, 1, 0.10161131138092219`], 
     Hue[0.6491038099745627, 1, 0.10124087849675933`], 
     Hue[0.64942119336182, 1, 0.10080142457594148`], 
     Hue[0.6498922784884097, 1, 0.10014915286220206`], 
     Hue[0.6483990009017261, 1, 0.10221676798222545`], 
     Hue[0.6465172063969351, 1, 0.10482232960424369`], 
     Hue[0.6493621458190904, 1, 0.10088318271202883`], 
     Hue[0.6453245988710898, 1, 0.10647363233233725`], 
     Hue[0.6471274489297509, 1, 0.10397737840496027`], 
     Hue[0.6483922400221149, 1, 0.10222612920014854`], 
     Hue[0.6485247894626657, 1, 0.10204259920553989`], 
     Hue[0.6491381987922908, 1, 0.1011932632106742], 
     Hue[0.6493737669753471, 1, 0.1008670918802887], 
     Hue[0.6496210357465021, 1, 0.10052471973561257`], 
     Hue[0.6498165479192314, 1, 0.10025401057337194`], 
     Hue[0.6498724443053411, 1, 0.10017661557722003`], 
     Hue[0.6499665094088094, 1, 0.1000463715878024], 
     Hue[0.6499917892175143, 1, 0.10001136877574947`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6498232605412784, 1, 0.10024471617361465`], 
     Hue[0.6496750025787413, 1, 0.10044999642943513`], 
     Hue[0.6496685385612269, 1, 0.10045894660753209`], 
     Hue[0.6498639723089052, 1, 0.10018834603382355`], 
     Hue[0.6496174240702354, 1, 0.1005297205181357], 
     Hue[0.64920755138824, 1, 0.1010972365393599], 
     Hue[0.6495338656167161, 1, 0.10064541683839315`], 
     Hue[0.649790607585968, 1, 0.10028992795789053`], 
     Hue[0.6499234272808985, 1, 0.10010602376490985`], 
     Hue[0.6499804327968308, 1, 0.10002709305054201`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6489031585682026, 1, 0.10151870352095033`], 
     Hue[0.6489021498075503, 1, 0.10152010026646877`], 
     Hue[0.6487985500631467, 1, 0.10166354606641229`], 
     Hue[0.6486893853114188, 1, 0.10181469726111247`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6312929681675595, 1, 0.1259020440756868], 
     Hue[0.6388215745991802, 1, 0.11547781978575059`], 
     Hue[0.6450415036889765, 1, 0.10686561027680175`], 
     Hue[0.5925059906482243, 1, 0.1796070898716895], 
     Hue[0.6133551637627203, 1, 0.15073900402084897`], 
     Hue[0.49720615583473643`, 1, 0.3115607073057496], 
     Hue[0.518673796877603, 1, 0.2818362812463959], 
     Hue[0.514174748201409, 1, 0.2880657332595876], 
     Hue[0.3727969551563195, 1, 0.4838196005527884], 
     Hue[0.22406757847405856`, 1, 0.6897525836513035], 
     Hue[0.0999772227273199, 1, 0.8615699993006339], 
     Hue[0.08150531552272133, 1, 0.887146486199309], 
     Hue[0.06074291864519299, 1, 0.9158944203374251], 
     Hue[0.09171365842224366, 1, 0.8730118575692011], 
     Hue[0.07647016774973092, 1, 0.8941182292696033], 
     Hue[0.6058741458816524, 1, 0.16109733647155822`], 
     Hue[0.6499719914032148, 1, 0.10003878113401034`], 
     Hue[0.19771813442239816`, 1, 0.7262364292612948], 
     Hue[0.05629683515735684, 1, 0.9220505359359674], 
     Hue[0.03896035828188038, 1, 0.9460548885327811], 
     Hue[0.01223751047181798, 1, 0.9830557547313289], 
     Hue[0.5056867473081215, 1, 0.29981834988106265`], 
     Hue[0.5791214103201123, 1, 0.19813958571061374`], 
     Hue[0.6263477647945219, 1, 0.13274924874604654`], 
     Hue[0.48114062591951323`, 1, 0.3338052871883664], 
     Hue[0.19237814000115439`, 1, 0.7336302676907094], 
     Hue[0.07025484756343459, 1, 0.9027240572198598], 
     Hue[0.043522036810525355`, 1, 0.9397387182623494], 
     Hue[0.4621876916878501, 1, 0.3600478115091307], 
     Hue[0.5534733309710608, 1, 0.23365231096314662`], 
     Hue[0.6400140073581523, 1, 0.11382675904255843`], 
     Hue[0.17332602197044716`, 1, 0.7600101234255348], 
     Hue[0.05157567726564849, 1, 0.9285875237860253], 
     Hue[0.05934590376755089, 1, 0.9178287486295449], 
     Hue[0.03441322125765478, 1, 0.9523509244124779], 
     Hue[0.041007174555774184`, 1, 0.9432208352304665], 
     Hue[0.07851052272455972, 1, 0.8912931223813789], 
     Hue[0.08096769342528565, 1, 0.8878908860265275], 
     Hue[0.28349540774141, 1, 0.6074678969734323], 
     Hue[0.4296229773224755, 1, 0.40513741601503395`], 
     Hue[0.633973057570626, 1, 0.12219115105605634`], 
     Hue[0.6465448294361723, 1, 0.10478408231914609`], 
     Hue[0.6120826227550745, 1, 0.15250098387758912`], 
     Hue[0.14029944794360927`, 1, 0.8057392259242333], 
     Hue[0.05015886484347187, 1, 0.9305492640628851], 
     Hue[0.021377244255039063`, 1, 0.9704007387237921], 
     Hue[0.018440214431860724`, 1, 0.974467395402039], 
     Hue[0.10200316378373075`, 1, 0.8587648501456036], 
     Hue[0.026773968856712016`, 1, 0.9629283508137834], 
     Hue[0.06965804873711978, 1, 0.9035503940562957], 
     Hue[0.02634361787811268, 1, 0.9635242213995362], 
     Hue[0.09886951825964918, 1, 0.8631037439481781], 
     Hue[0.6301232096367435, 1, 0.12752170973373975`], 
     Hue[0.6453557200851419, 1, 0.1064305414205729], 
     Hue[0.6493795460161914, 1, 0.10085909013142728`], 
     Hue[0.6211988333618537, 1, 0.13987853842204878`], 
     Hue[0.06285578478657339, 1, 0.9129689133724369], 
     Hue[0.048777122183848, 1, 0.9324624462069796], 
     Hue[0.02950865934742497, 1, 0.9591418562881807], 
     Hue[0.019215653570866187`, 1, 0.9733937104403391], 
     Hue[0.04109485386478218, 1, 0.9430994331103015], 
     Hue[0.03846166552309738, 1, 0.9467453861987882], 
     Hue[0.043955904839393156`, 1, 0.9391379779146863], 
     Hue[0.020173287216063485`, 1, 0.9720677561623736], 
     Hue[0.04396969397004502, 1, 0.9391188852722453], 
     Hue[0.06864751202554253, 1, 0.9049495987338642], 
     Hue[0.6427550742491973, 1, 0.1100314356549576], 
     Hue[0.05627972328014752, 1, 0.9220742293044112], 
     Hue[0.025015242436588148`, 1, 0.9653635104724164], 
     Hue[0.03939831657384085, 1, 0.9454484847439127], 
     Hue[0.009952681936556296, 1, 0.9862193634724604], 
     Hue[0.022529780101107733`, 1, 0.9688049198600046], 
     Hue[0.6401614917431198, 1, 0.11362254989414192`], 
     Hue[0.648406074601997, 1, 0.1022069736280042], 
     Hue[0.6491584547328567, 1, 0.10116521652373689`], 
     Hue[0.049544359463614795`, 1, 0.931400117665764], 
     Hue[0.007888468849291175, 1, 0.9890775046702122], 
     Hue[0.03075470792259083, 1, 0.9574165582610281], 
     Hue[0.6486783555911915, 1, 0.10182996918142723`], 
     Hue[0.649085992567519, 1, 0.10126554875266608`], 
     Hue[0.04403248245167102, 1, 0.9390319473746094], 
     Hue[0.06836756150050194, 1, 0.9053372225377666], 
     Hue[0.01515199070980977, 1, 0.9790203205556479], 
     Hue[0.0008005344307854267, 1, 0.9988915677112201], 
     Hue[0.06960507160291374, 1, 0.9036237470113503], 
     Hue[0.6490896268755713, 1, 0.10126051663382446`], 
     Hue[0.6365740258619116, 1, 0.11858981034504554`], 
     Hue[0.600205956487583, 1, 0.1689455987095005], 
     Hue[0.5115573095702308, 1, 0.29168987905660343`], 
     Hue[0.10119031714750437`, 1, 0.8598903301034555], 
     Hue[0.6493621883737429, 1, 0.10088312379020219`], 
     Hue[0.6106844538896145, 1, 0.15443690999899543`], 
     Hue[0.5394968084983891, 1, 0.25300441900223053`], 
     Hue[0.05115927600928871, 1, 0.9291640793717542], 
     Hue[0.052019159881682264`, 1, 0.9279734709330553], 
     Hue[0.04118522183161666, 1, 0.9429743082331461], 
     Hue[0.1418329182783541, 1, 0.8036159593068943], 
     Hue[0.12158443529348772`, 1, 0.8316523203628632], 
     Hue[0.6493358548685807, 1, 0.10091958556658064`], 
     Hue[0.6243465718813018, 1, 0.1355201312412745], 
     Hue[0.5721639775577578, 1, 0.20777295415079694`], 
     Hue[0.059718121862663676`, 1, 0.9173133697286194], 
     Hue[0.05257835329346261, 1, 0.9271992031321287], 
     Hue[0.04309560328308748, 1, 0.9403291646849558], 
     Hue[0.04537123025151746, 1, 0.937178296574822], 
     Hue[0.07201825940379614, 1, 0.9002824100562823], 
     Hue[0.11497219616397492`, 1, 0.8408077283883424], 
     Hue[0.18658253843213912`, 1, 0.741654946786269], 
     Hue[0.6023388574683647, 1, 0.165992351197649], 
     Hue[0.1286766762487056, 1, 0.8218322944248693], 
     Hue[0.09649699163117442, 1, 0.8663887808183738], 
     Hue[0.14340436175566262`, 1, 0.8014401144921594], 
     Hue[0.23829302564437177`, 1, 0.6700558106462544], 
     Hue[0.1975137344115977, 1, 0.7265194446608647], 
     Hue[0.6499834865183284, 1, 0.10002286482077606`], 
     Hue[0.3482887017030422, 1, 0.5177541053342493], 
     Hue[0.32667440993817226`, 1, 0.5476815862394538], 
     Hue[0.4764623303542645, 1, 0.34028292720178765`], 
     Hue[0.6499940432100225, 1, 0.10000824786304582`], 
     Hue[0.6499924692967158, 1, 0.1000104271276242], 
     Hue[0.566678074337803, 1, 0.21536882014765743`], 
     Hue[0.6499931775476575, 1, 0.10000944647247424`], 
     Hue[0.6024343251531767, 1, 0.1658601651725246], 
     Hue[0.6499954479276492, 1, 0.10000630286940893`], 
     Hue[0.6486621126272644, 1, 0.10185245943917241`], 
     Hue[0.6464690834258365, 1, 0.10488896141038029`], 
     Hue[0.642908761068509, 1, 0.10981863852052595`], 
     Hue[0.6439124597930012, 1, 0.10842890182507542`], 
     Hue[0.6328937597428063, 1, 0.12368556343303748`], 
     Hue[0.6499960952170183, 1, 0.10000540662259003`], 
     Hue[0.6486239269984553, 1, 0.10190533184829267`], 
     Hue[0.6476487991869694, 1, 0.1032555088180424], 
     Hue[0.6488528390937288, 1, 0.1015883766394525], 
     Hue[0.6489671636049841, 1, 0.1014300811623298], 
     Hue[0.6496776182866274, 1, 0.10044637468005445`], 
     Hue[0.6475354194523827, 1, 0.1034124961428548], 
     Hue[0.6456737960179432, 1, 0.10599012859054027`], 
     Hue[0.6499725602192108, 1, 0.1000379935426313], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6492784555506013, 1, 0.1009990615453214], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6496608293197141, 1, 0.1004696209419343], 
     Hue[0.6495830622355592, 1, 0.10057729844307191`], 
     Hue[0.6497957894817981, 1, 0.10028275302520279`], 
     Hue[0.6476750039258382, 1, 0.1032192253334549], 
     Hue[0.6471790082517929, 1, 0.10390598857444062`], 
     Hue[0.6423919354363395, 1, 0.1105342432419914], 
     Hue[0.6244555938503461, 1, 0.1353691777456746], 
     Hue[0.6486846461092286, 1, 0.10182125923337586`], 
     Hue[0.11590414688096395`, 1, 0.839517335087896], 
     Hue[0.08465087931166326, 1, 0.8827910901838509], 
     Hue[0.05036231500383248, 1, 0.9302675638408474], 
     Hue[0.04630079102044693, 1, 0.9358912124332274], 
     Hue[0.04383150895497456, 1, 0.9393102183700353], 
     Hue[0.6182444918525216, 1, 0.14396916512727775`], 
     Hue[0.5027788936376796, 1, 0.3038446088093668], 
     Hue[0.08034487967990156, 1, 0.8887532435201364], 
     Hue[0.047437473287300524`, 1, 0.9343173446791223], 
     Hue[0.6488406035833214, 1, 0.10160531811540124`], 
     Hue[0.6406955949857572, 1, 0.11288302232741314`], 
     Hue[0.61020263563344, 1, 0.15510404296908314`], 
     Hue[0.4655159753256748, 1, 0.355439418779835], 
     Hue[0.05166835670513348, 1, 0.9284591984082766], 
     Hue[0.044097616768992265`, 1, 0.93894176139678], 
     Hue[0.061446978925637996`, 1, 0.9149195676414243], 
     Hue[0.025273624901279157`, 1, 0.9650057501366904], 
     Hue[0.04104260717687647, 1, 0.943171774678171], 
     Hue[0.02155960042567162, 1, 0.9701482455644548], 
     Hue[0.027315581411363032`, 1, 0.9621784257381126], 
     Hue[0.07678723350047512, 1, 0.8936792151531883], 
     Hue[0.631207539161065, 1, 0.12602033039237162`], 
     Hue[0.645701522810773, 1, 0.10595173764662211`], 
     Hue[0.6494172952967342, 1, 0.10080682189682963`], 
     Hue[0.6308611799338162, 1, 0.1264999047070238], 
     Hue[0.06424877550155206, 1, 0.911040156997851], 
     Hue[0.04509795675473749, 1, 0.9375566752626712], 
     Hue[0.04772644179303487, 1, 0.9339172344404132], 
     Hue[0.02132823102596182, 1, 0.9704686031948222], 
     Hue[0.6358981390757297, 1, 0.11952565358745118`], 
     Hue[0.6497010367710574, 1, 0.10041394908622828`], 
     Hue[0.6474971417396094, 1, 0.10346549605284865`], 
     Hue[0.6497330798737283, 1, 0.1003695817132993], 
     Hue[0.6476159562768067, 1, 0.10330098361672932`], 
     Hue[0.05735744919248609, 1, 0.9205819934257884], 
     Hue[0.033528244451502265`, 1, 0.9535762769133045], 
     Hue[0.049164342703324815`, 1, 0.9319262947184734], 
     Hue[0.012551156651339657`, 1, 0.9826214754058374], 
     Hue[0.6497163830940513, 1, 0.10039270033131359`], 
     Hue[0.6473539488435031, 1, 0.103663763139765], 
     Hue[0.05931606770023412, 1, 0.917870060107368], 
     Hue[0.6482757363140179, 1, 0.1023874420267445], 
     Hue[0.6498453905638506, 1, 0.10021407460389928`], 
     Hue[0.031139878665732756`, 1, 0.95688324492437], 
     Hue[0.0337335044995003, 1, 0.9532920706929995], 
     Hue[0.647944007622239, 1, 0.10284675867689988`], 
     Hue[0.6498143848477675, 1, 0.10025700559539878`], 
     Hue[0.055698433556729876`, 1, 0.9228790919983739], 
     Hue[0.5576370857649897, 1, 0.22788711201770653`], 
     Hue[0.6128128587071412, 1, 0.15148988794395843`], 
     Hue[0.6481333460601899, 1, 0.10258459776281405`], 
     Hue[0.6498366505084129, 1, 0.10022617621912072`], 
     Hue[0.04336140725545823, 1, 0.9399611284155194], 
     Hue[0.06805304034756054, 1, 0.9057727133649162], 
     Hue[0.06656412997909311, 1, 0.9078342815674096], 
     Hue[0.05223966558902993, 1, 0.9276681553382663], 
     Hue[0.09125986063964109, 1, 0.873640192960497], 
     Hue[0.6485110647902746, 1, 0.10206160259808131`], 
     Hue[0.6407009549174503, 1, 0.11287560088353048`], 
     Hue[0.6326273619528644, 1, 0.12405442191141858`], 
     Hue[0.6379112257101143, 1, 0.11673830286291878`], 
     Hue[0.6489288435691029, 1, 0.10148313967354995`], 
     Hue[0.6455789723141596, 1, 0.10612142294962511`], 
     Hue[0.6499298741728831, 1, 0.10009709729908503`], 
     Hue[0.6498627396334172, 1, 0.10019005281526851`], 
     Hue[0.6492476056026731, 1, 0.10104177685783719`], 
     Hue[0.6498837970720727, 1, 0.10016089636174559`], 
     Hue[0.6496896116197495, 1, 0.10042976852650079`], 
     Hue[0.6493190986445261, 1, 0.10094278649219465`], 
     Hue[0.6497085042989013, 1, 0.10040360943229054`], 
     Hue[0.649848197401381, 1, 0.10021018821347248`], 
     Hue[0.6492117987755095, 1, 0.10109135554160233`], 
     Hue[0.6479312352008514, 1, 0.10286444356805188`], 
     Hue[0.6499081608323997, 1, 0.10012716192436977`], 
     Hue[0.6492317052592907, 1, 0.10106379271790521`], 
     Hue[0.6463788228695017, 1, 0.10501393756530537`], 
     Hue[0.6499301033956554, 1, 0.10009677991370804`], 
     Hue[0.6494987161710277, 1, 0.10069408530165393`], 
     Hue[0.6469693955377902, 1, 0.10419622156305977`], 
     Hue[0.6379710995016905, 1, 0.11665540068996708`], 
     Hue[0.6499087807694133, 1, 0.10012630355004322`], 
     Hue[0.6495283920737677, 1, 0.10065299559016788`], 
     Hue[0.6476403124089203, 1, 0.10326725974149499`], 
     Hue[0.6398474435366743, 1, 0.11405738587229705`], 
     Hue[0.6182310082083972, 1, 0.14398783478837318`], 
     Hue[0.6498802358039856, 1, 0.10016582734832771`], 
     Hue[0.6494249011475627, 1, 0.10079629071875934`], 
     Hue[0.6476662399784014, 1, 0.10323136002990574`], 
     Hue[0.641056432071552, 1, 0.11238340174708189`], 
     Hue[0.6205651418201429, 1, 0.14075595747980213`], 
     Hue[0.6499162951454762, 1, 0.10011589902934058`], 
     Hue[0.6493953046639684, 1, 0.1008372704652745], 
     Hue[0.6474131555311542, 1, 0.1035817846491712], 
     Hue[0.6415454114509769, 1, 0.11170635337557053`], 
     Hue[0.6240214306377297, 1, 0.13597032680929735`], 
     Hue[0.5792106840076037, 1, 0.19801597598947196`], 
     Hue[0.6496828657135563, 1, 0.10043910901199907`], 
     Hue[0.6497017398079356, 1, 0.10041297565055086`], 
     Hue[0.6478627814807547, 1, 0.10295922564203198`], 
     Hue[0.6414800216223766, 1, 0.11179689313824788`], 
     Hue[0.626762327681144, 1, 0.13217523859533906`], 
     Hue[0.5919738436585651, 1, 0.1803439087804483], 
     Hue[0.6499187963510086, 1, 0.10011243582168051`], 
     Hue[0.6492426772471285, 1, 0.10104860073474521`], 
     Hue[0.6445839917289551, 1, 0.10749908837529297`], 
     Hue[0.6291576418639486, 1, 0.12885864972684033`], 
     Hue[0.05426374574167925, 1, 0.9248655828192134], 
     Hue[0.045830499674065606`, 1, 0.9365423850666784], 
     Hue[0.03817996926681966, 1, 0.947135427169019], 
     Hue[0.6497026037600987, 1, 0.10041177940909417`], 
     Hue[0.6485852902744793, 1, 0.10195882885072098`], 
     Hue[0.6399864700646524, 1, 0.11386488760278902`], 
     Hue[0.044395566815380594`, 1, 0.9385292151787037], 
     Hue[0.04248487770896736, 1, 0.9411747847106605], 
     Hue[0.06342468276915769, 1, 0.912181208473474], 
     Hue[0.6480115671840383, 1, 0.10275321466825467`], 
     Hue[0.6363006394441317, 1, 0.11896834538504844`], 
     Hue[0.0870536101615228, 1, 0.8794642320840453], 
     Hue[0.04562630015449742, 1, 0.9368251228630036], 
     Hue[0.04471815103292531, 1, 0.9380825601082573], 
     Hue[0.10672312753951407`, 1, 0.8522295157145189], 
     Hue[0.022685685517722542`, 1, 0.968589050821615], 
     Hue[0.03861390484046645, 1, 0.9465345932978158], 
     Hue[0.05232052825842781, 1, 0.9275561916421768], 
     Hue[0.035580856819405704`, 1, 0.9507341982500537], 
     Hue[0.04478203039910311, 1, 0.937994111755088], 
     Hue[0.014434335707593005`, 1, 0.9800139967125635], 
     Hue[0.028736149686440893`, 1, 0.9602114850495433], 
     Hue[0.0126820331481452, 1, 0.982440261794876], 
     Hue[0.6391705939011751, 1, 0.1149945622906806], 
     Hue[0.6479661711975621, 1, 0.10281607064952947`], 
     Hue[0.6494043673301488, 1, 0.10082472215825544`], 
     Hue[0.645714853183222, 1, 0.10593328020784651`], 
     Hue[0.03639777473064332, 1, 0.9496030811421863], 
     Hue[0.017537021360291893`, 1, 0.9757179704242113], 
     Hue[0.01026854921362741, 1, 0.9857820087811313], 
     Hue[0.6489018917654912, 1, 0.10152045755547387`], 
     Hue[0.6495194889914516, 1, 0.10066532293491312`], 
     Hue[0.04767944912492528, 1, 0.9339823012116419], 
     Hue[0.03645043439698803, 1, 0.9495301677580166], 
     Hue[0.06542156476001881, 1, 0.9094162949476663], 
     Hue[0.06340770906122262, 1, 0.9122047105306149], 
     Hue[0.01045564886668493, 1, 0.9855229477230516], 
     Hue[0.0115026421157165, 1, 0.9840732647628541], 
     Hue[0.6494740211625747, 1, 0.10072827839028119`], 
     Hue[0.04427931754145742, 1, 0.9386901757118282], 
     Hue[0.07237968389785021, 1, 0.8997819761414381], 
     Hue[0.035676149987182715`, 1, 0.9506022538639008], 
     Hue[0.0011745891806254072`, 1, 0.9983736457499033], 
     Hue[0.008458142127868107, 1, 0.9882887262844903], 
     Hue[0.015611937728588487`, 1, 0.9783834708373391], 
     Hue[0.6490701383635099, 1, 0.10128750072744781`], 
     Hue[0.02573221429495287, 1, 0.9643707802069884], 
     Hue[0.03201392055373109, 1, 0.9556730330794493], 
     Hue[0.6488196245601551, 1, 0.1016343659936315], 
     Hue[0.046735633750972116`, 1, 0.935289122498654], 
     Hue[0.07186744590474292, 1, 0.900491228747279], 
     Hue[0.6488536876660301, 1, 0.10158720169318916`], 
     Hue[0.6498380839295351, 1, 0.1002241914821821], 
     Hue[0.041086093456200956`, 1, 0.9431115629067987], 
     Hue[0.06700162153799438, 1, 0.9072285240243155], 
     Hue[0.6277990966084912, 1, 0.13073971238824297`], 
     Hue[0.6442331489963262, 1, 0.1079848706204714], 
     Hue[0.6491686723250383, 1, 0.10115106908840855`], 
     Hue[0.6492798072378851, 1, 0.10099718997831286`], 
     Hue[0.6142271833414661, 1, 0.1495315922964316], 
     Hue[0.6371781596642759, 1, 0.1177533173879257], 
     Hue[0.6467950798667544, 1, 0.10443758172295539`], 
     Hue[0.6495569536587888, 1, 0.1006134487801386], 
     Hue[0.6497731865249076, 1, 0.10031404942705112`], 
     Hue[0.60480151707667, 1, 0.16258251481691854`], 
     Hue[0.6330089263482277, 1, 0.1235261019793771], 
     Hue[0.6445471187438859, 1, 0.10755014327769646`], 
     Hue[0.6487374731646326, 1, 0.10174811407973952`], 
     Hue[0.64983412117599, 1, 0.10022967837170621`], 
     Hue[0.6493468333278533, 1, 0.10090438462297247`], 
     Hue[0.6022342832428614, 1, 0.1661371462791149], 
     Hue[0.631127473038135, 1, 0.12613119117796695`], 
     Hue[0.6440146223473466, 1, 0.10828744598059696`], 
     Hue[0.6483622997530706, 1, 0.10226758495728698`], 
     Hue[0.6496610044193197, 1, 0.10046937849632655`], 
     Hue[0.6499582441416699, 1, 0.10005781580384165`], 
     Hue[0.6058308015380279, 1, 0.1611573517165767], 
     Hue[0.6312576796062362, 1, 0.12595090516059607`], 
     Hue[0.6439786098328303, 1, 0.10833730946223502`], 
     Hue[0.6484702177317255, 1, 0.10211816006376469`], 
     Hue[0.6496587688293561, 1, 0.10047247392858388`], 
     Hue[0.649939020772773, 1, 0.10008443277616058`], 
     Hue[0.633119930420021, 1, 0.1233724040338171], 
     Hue[0.6441449544800693, 1, 0.10810698610451949`], 
     Hue[0.6485319477877951, 1, 0.10203268767843751`], 
     Hue[0.6497160473663807, 1, 0.10039316518501146`], 
     Hue[0.6499506411361033, 1, 0.10006834304231854`], 
     Hue[0.6381152164858033, 1, 0.11645585409658013`], 
     Hue[0.6450562435002993, 1, 0.10684520130727782`], 
     Hue[0.6485972961121185, 1, 0.10194220538322062`], 
     Hue[0.6497277328598755, 1, 0.1003769852709416], 
     Hue[0.6499611735006391, 1, 0.10005375976834585`], 
     Hue[0.647095632440894, 1, 0.10402143200491609`], 
     Hue[0.6489484724765117, 1, 0.10145596118636857`], 
     Hue[0.649753196132293, 1, 0.10034172843220977`], 
     Hue[0.649962415941268, 1, 0.10005203946593658`], 
     Hue[0.6497221043628657, 1, 0.1003847785744936], 
     Hue[0.6492421130206842, 1, 0.10104938197136026`], 
     Hue[0.6494266876001642, 1, 0.1007938171690034], 
     Hue[0.6488642335376651, 1, 0.10157259971707916`], 
     Hue[0.6495060949834135, 1, 0.10068386848450449`], 
     Hue[0.6498441776198002, 1, 0.10021575406489204`], 
     Hue[0.6499451921613975, 1, 0.10007588777652665`], 
     Hue[0.6497943481566071, 1, 0.10028474870623633`], 
     Hue[0.6495399526181233, 1, 0.10063698868259865`], 
     Hue[0.6498333637037117, 1, 0.10023072717947615`], 
     Hue[0.6499403135233126, 1, 0.1000826428138749], 
     Hue[0.6499489655298978, 1, 0.10007066311244919`], 
     Hue[0.6498486702778828, 1, 0.10020953346139301`], 
     Hue[0.64968134772499, 1, 0.10044121084232155`], 
     Hue[0.6496217170975961, 1, 0.10052377632640538`], 
     Hue[0.6494382216208568, 1, 0.10077784698650598`], 
     Hue[0.648629594398281, 1, 0.10189748467930317`], 
     Hue[0.6492006791954266, 1, 0.1011067518832556], 
     Hue[0.6495366050144639, 1, 0.10064162382612694`], 
     Hue[0.649962635914433, 1, 0.10005173488770819`], 
     Hue[0.6498761822222077, 1, 0.10017144000002023`], 
     Hue[0.649645498595113, 1, 0.10049084809907435`], 
     Hue[0.6497175651972956, 1, 0.10039106357297535`], 
     Hue[0.6491382494289228, 1, 0.10119319309841453`], 
     Hue[0.6469290670520219, 1, 0.10425206100489272`], 
     Hue[0.6499268294659234, 1, 0.10010131304718298`], 
     Hue[0.6497819979845432, 1, 0.10030184894447865`], 
     Hue[0.649812205531135, 1, 0.10026002311073624`], 
     Hue[0.6493863855032584, 1, 0.10084962007241141`], 
     Hue[0.6464886430440556, 1, 0.10486187886207685`], 
     Hue[0.6384967560196013, 1, 0.11592756858824439`], 
     Hue[0.6499227125648132, 1, 0.10010701337179721`], 
     Hue[0.649811687615808, 1, 0.10026074022426584`], 
     Hue[0.649791955522241, 1, 0.10028806158458939`], 
     Hue[0.6495398903668558, 1, 0.10063707487666126`], 
     Hue[0.6474095595589028, 1, 0.10358676368767307`], 
     Hue[0.6387860509065049, 1, 0.11552700643714708`], 
     Hue[0.6182689374550846, 1, 0.14393531736988285`], 
     Hue[0.6499537332125152, 1, 0.1000640617057483], 
     Hue[0.6499528462510007, 1, 0.10006528980630683`], 
     Hue[0.6498916663365855, 1, 0.1001500004570356], 
     Hue[0.6497606997170576, 1, 0.10033133885330482`], 
     Hue[0.649727715184891, 1, 0.10037700974399709`], 
     Hue[0.6494857788885866, 1, 0.10071199846195698`], 
     Hue[0.6477032283992118, 1, 0.10318014529339903`], 
     Hue[0.6405815482443582, 1, 0.11304093320011938`], 
     Hue[0.6193865373203343, 1, 0.1423878714026141], 
     Hue[0.6499614046249048, 1, 0.1000534397501318], 
     Hue[0.6498877201255143, 1, 0.10015546444159566`], 
     Hue[0.6497181581343889, 1, 0.10039024258315386`], 
     Hue[0.6497571483281035, 1, 0.1003362561610875], 
     Hue[0.6493744818306854, 1, 0.10086610208058946`], 
     Hue[0.6475518426751616, 1, 0.10338975629593011`], 
     Hue[0.6414056844791381, 1, 0.11189982149042418`], 
     Hue[0.6220237349834802, 1, 0.13873636694595054`], 
     Hue[0.5770318831104885, 1, 0.20103277723163138`], 
     Hue[0.6483917651250946, 1, 0.10222678674986906`], 
     Hue[0.6494363724814153, 1, 0.10078040733342496`], 
     Hue[0.6498339143383031, 1, 0.10022996476234962`], 
     Hue[0.6489708616820986, 1, 0.10142496074786356`], 
     Hue[0.6499163528366462, 1, 0.10011581914925916`], 
     Hue[0.6498347791615197, 1, 0.10022876731481897`], 
     Hue[0.6495210274721027, 1, 0.10066319273093466`], 
     Hue[0.6474494919311958, 1, 0.10353147271065197`], 
     Hue[0.6414199202556341, 1, 0.11188011041527594`], 
     Hue[0.6258892655925671, 1, 0.1333840937949072], 
     Hue[0.5848453321548063, 1, 0.19021415547796056`], 
     Hue[0.6453645324718147, 1, 0.10641833965441046`], 
     Hue[0.649429316022528, 1, 0.10079017781496127`], 
     Hue[0.6471717532286848, 1, 0.10391603399105188`], 
     Hue[0.6498388592579648, 1, 0.10022311795051031`], 
     Hue[0.6499599255320806, 1, 0.10005548772481156`], 
     Hue[0.6497013189626538, 1, 0.10041355835940248`], 
     Hue[0.6495052641009864, 1, 0.10068501893709571`], 
     Hue[0.6485647345074125, 1, 0.10198729068204432`], 
     Hue[0.6425024717752289, 1, 0.11038119292660624`], 
     Hue[0.6271585120205934, 1, 0.13162667566379377`], 
     Hue[0.05613592543851087, 1, 0.9222733340082158], 
     Hue[0.05320544049059184, 1, 0.9263309285514882], 
     Hue[0.6396497160431217, 1, 0.11433116240183148`], 
     Hue[0.6483845387196311, 1, 0.10223679254204927`], 
     Hue[0.6435663250389826, 1, 0.10890816533063957`], 
     Hue[0.6494652406292689, 1, 0.10074043605178148`], 
     Hue[0.6498411544004004, 1, 0.10021994006098413`], 
     Hue[0.6490777405788634, 1, 0.10127697458311223`], 
     Hue[0.6499146394524903, 1, 0.10011819152732113`], 
     Hue[0.6468897881509198, 1, 0.10430644717564953`], 
     Hue[0.6339196311461559, 1, 0.1222651261053226], 
     Hue[0.6034688635735971, 1, 0.1644277273596349], 
     Hue[0.09379582832302935, 1, 0.8701288530911901], 
     Hue[0.08840720728195872, 1, 0.8775900206865186], 
     Hue[0.0383698728866082, 1, 0.9468724836954655], 
     Hue[0.03957827983252593, 1, 0.9451993048472718], 
     Hue[0.04341303729019841, 1, 0.9398896406751098], 
     Hue[0.029025486185974336`, 1, 0.9598108652809586], 
     Hue[0.6460736933064093, 1, 0.10543642465266405`], 
     Hue[0.6375116258018224, 1, 0.11729159504363047`], 
     Hue[0.6494731702548533, 1, 0.10072945657020321`], 
     Hue[0.6476290999024182, 1, 0.10328278475049787`], 
     Hue[0.6498388431558231, 1, 0.10022314024578349`], 
     Hue[0.6497185889591506, 1, 0.10038964605656084`], 
     Hue[0.6443418270901986, 1, 0.10783439325972506`], 
     Hue[0.07086421195903003, 1, 0.9018803219028815], 
     Hue[0.06884490298650148, 1, 0.9046762881725363], 
     Hue[0.040098283823609915`, 1, 0.9444792993211555], 
     Hue[0.047559177390334884`, 1, 0.9341488313056902], 
     Hue[0.03818567881746371, 1, 0.9471275216373579], 
     Hue[0.0625725558785798, 1, 0.9133610764758125], 
     Hue[0.04113916201267309, 1, 0.943038083367068], 
     Hue[0.04183503209137307, 1, 0.9420745709504065], 
     Hue[0.05397925564253003, 1, 0.9252594921872661], 
     Hue[0.6486598690453643, 1, 0.10185556593718795`], 
     Hue[0.6453002092079927, 1, 0.10650740263508703`], 
     Hue[0.6495493492903867, 1, 0.10062397790561856`], 
     Hue[0.6493426000465646, 1, 0.10091024608937216`], 
     Hue[0.06379106828292325, 1, 0.9116739054544141], 
     Hue[0.10009042474573482`, 1, 0.8614132580443672], 
     Hue[0.6452444535897003, 1, 0.10658460272195354`], 
     Hue[0.058087459910583505`, 1, 0.9195712093545767], 
     Hue[0.05706725519961531, 1, 0.9209838004928403], 
     Hue[0.046490376976558, 1, 0.9356287088016889], 
     Hue[0.046129430478278555`, 1, 0.9361284808762297], 
     Hue[0.020797086972966783`, 1, 0.971204033422046], 
     Hue[0.02238108259365723, 1, 0.9690108087164746], 
     Hue[0.024803607571393438`, 1, 0.965656543362686], 
     Hue[0.023364358729570434`, 1, 0.967649349451364], 
     Hue[0.02886671961059184, 1, 0.960030695923796], 
     Hue[0.02020775897943161, 1, 0.9720200260284794], 
     Hue[0.0977309711612957, 1, 0.8646801937766675], 
     Hue[0.6485847288450334, 1, 0.1019596062145692], 
     Hue[0.6409130522463226, 1, 0.11258192765893811`], 
     Hue[0.6470486014333279, 1, 0.10408655186154604`], 
     Hue[0.030316080315814564`, 1, 0.9580238887934874], 
     Hue[0.04540878179201646, 1, 0.937126302134131], 
     Hue[0.04017224023901311, 1, 0.9443768981305973], 
     Hue[0.044543342071723946`, 1, 0.9383246032853053], 
     Hue[0.02017491172489161, 1, 0.9720655068424577], 
     Hue[0.015295437351768304`, 1, 0.9788217021283209], 
     Hue[0.023623330761102346`, 1, 0.9672907727923199], 
     Hue[0.015612297083320681`, 1, 0.9783829732692484], 
     Hue[0.02492427734273628, 1, 0.9654894621408268], 
     Hue[0.014895022279636239`, 1, 0.9793761229974268], 
     Hue[0.6474563192896581, 1, 0.10352201944508879`], 
     Hue[0.6490648854847869, 1, 0.10129477394414124`], 
     Hue[0.6492076314576706, 1, 0.10109712567399465`], 
     Hue[0.6446048324100935, 1, 0.107470232047563], 
     Hue[0.6483046830138488, 1, 0.10234736198082475`], 
     Hue[0.03552609285265251, 1, 0.9508100252809427], 
     Hue[0.03508571978387598, 1, 0.951419772606941], 
     Hue[0.03515458722153164, 1, 0.9513244176932638], 
     Hue[0.014017878836782627`, 1, 0.9805906293029163], 
     Hue[0.02215245783908304, 1, 0.969327366068962], 
     Hue[0.014726378753304292`, 1, 0.9796096294185017], 
     Hue[0.012255628931993612`, 1, 0.9830306676326243], 
     Hue[0.009596543815271086, 1, 0.9867124777942401], 
     Hue[0.6411918108434772, 1, 0.11219595421672393`], 
     Hue[0.6461521695321715, 1, 0.10532776526314724`], 
     Hue[0.6494679186762458, 1, 0.10073672798673663`], 
     Hue[0.6496322538285559, 1, 0.10050918700661496`], 
     Hue[0.039772431544265574`, 1, 0.9449304794002477], 
     Hue[0.03704701452495118, 1, 0.948704133734683], 
     Hue[0.03621524110841434, 1, 0.949855820003734], 
     Hue[0.039950349948065456`, 1, 0.9446841308411401], 
     Hue[0.043570153016859625`, 1, 0.9396720958228097], 
     Hue[0.06369410089346128, 1, 0.911808167993669], 
     Hue[0.06442166540394156, 1, 0.9108007709791578], 
     Hue[0.06654611040788083, 1, 0.9078592317429343], 
     Hue[0.013825766652924454`, 1, 0.9808566307882585], 
     Hue[0.01036743266189899, 1, 0.9856450932373706], 
     Hue[0.007789975766972379, 1, 0.989213879707269], 
     Hue[0.003362857653289697, 1, 0.9953437355569835], 
     Hue[0.005763682843181073, 1, 0.9920195160632878], 
     Hue[0.032552067009237184`, 1, 0.9549279072179793], 
     Hue[0.03405365838945318, 1, 0.9528487806915263], 
     Hue[0.029962858050932684`, 1, 0.9585129657756316], 
     Hue[0.043944502807630514`, 1, 0.9391537653432808], 
     Hue[0.07183569669891043, 1, 0.9005351891861241], 
     Hue[0.06823796808394378, 1, 0.9055166595760777], 
     Hue[0.06889253603611212, 1, 0.9046103347192294], 
     Hue[0.03388122758552514, 1, 0.9530875310354268], 
     Hue[0.030659955598500543`, 1, 0.9575477537866915], 
     Hue[0.008964787151429676, 1, 0.9875872177903281], 
     Hue[0.0038891755274935713`, 1, 0.9946149877311627], 
     Hue[0.008918370380308627, 1, 0.9876514871657266], 
     Hue[0.008545801999559788, 1, 0.9881673510775326], 
     Hue[0.6497219801449867, 1, 0.10038495056847997`], 
     Hue[0.030000960117784192`, 1, 0.9584602090676834], 
     Hue[0.0267680052020981, 1, 0.9629366081817103], 
     Hue[0.03353981145958407, 1, 0.9535602610559606], 
     Hue[0.031270844855063706`, 1, 0.9567019071237579], 
     Hue[0.029138996373125226`, 1, 0.9596536973295189], 
     Hue[0.009216168449887041, 1, 0.9872391513770795], 
     Hue[0.01745658852397125, 1, 0.975829338966809], 
     Hue[0.6489208247310737, 1, 0.10149424268005183`], 
     Hue[0.058300099465873, 1, 0.9192767853549451], 
     Hue[0.05090357438814097, 1, 0.9295181277702663], 
     Hue[0.04409702847575725, 1, 0.9389425759566438], 
     Hue[0.041951474853775816`, 1, 0.9419133425101566], 
     Hue[0.0455519472915723, 1, 0.9369280729808999], 
     Hue[0.006686567289488576, 1, 0.9907416760607081], 
     Hue[0.6497616870676434, 1, 0.1003299717524938], 
     Hue[0.6476232802908426, 1, 0.103290842674218], 
     Hue[0.6494279365376326, 1, 0.10079208787097028`], 
     Hue[0.6367361253262844, 1, 0.11836536493283698`], 
     Hue[0.6455230398651721, 1, 0.10619886787899249`], 
     Hue[0.037981906194124115`, 1, 0.9474096683465973], 
     Hue[0.0408778679269004, 1, 0.943399875178138], 
     Hue[0.042232392037163, 1, 0.9415243802562359], 
     Hue[0.04240031316203241, 1, 0.9412918740833397], 
     Hue[0.04768721512653551, 1, 0.9339715482863354], 
     Hue[0.041211659028783654`, 1, 0.9429377028832227], 
     Hue[0.04831920608566098, 1, 0.9330964838813925], 
     Hue[0.07518952524216371, 1, 0.8958914265877733], 
     Hue[0.06971371467075616, 1, 0.9034733181481838], 
     Hue[0.6234930275813372, 1, 0.1367019618104563], 
     Hue[0.6471277506330485, 1, 0.10397696066193285`], 
     Hue[0.6489874068451905, 1, 0.10140205206050554`], 
     Hue[0.6497017527841852, 1, 0.10041295768343597`], 
     Hue[0.6498984166922149, 1, 0.10014065381077944`], 
     Hue[0.6496292924113466, 1, 0.10051328743044319`], 
     Hue[0.6488445556109727, 1, 0.10159984607711484`], 
     Hue[0.649778283550153, 1, 0.10030699200748054`], 
     Hue[0.6425396511588635, 1, 0.11032971378003531`], 
     Hue[0.6479578649379257, 1, 0.1028275716244106], 
     Hue[0.6204195752199382, 1, 0.14095751123393183`], 
     Hue[0.6405941830744628, 1, 0.11302343881997468`], 
     Hue[0.6481689247123931, 1, 0.10253533501360967`], 
     Hue[0.6498183202723641, 1, 0.10025155654595748`], 
     Hue[0.6498741802587673, 1, 0.10017421194939921`], 
     Hue[0.6498775578741091, 1, 0.10016953525123372`], 
     Hue[0.6495821136025571, 1, 0.100578611934921], 
     Hue[0.6499373590833081, 1, 0.10008673357695809`], 
     Hue[0.6466681261653241, 1, 0.1046133637710898], 
     Hue[0.649274493099335, 1, 0.10100454801630541`], 
     Hue[0.6448762409008205, 1, 0.10709443567578708`], 
     Hue[0.6089981714862794, 1, 0.15677176255745925`], 
     Hue[0.6346706446900287, 1, 0.12122526119842195`], 
     Hue[0.6454526759413621, 1, 0.10629629485042164`], 
     Hue[0.6491582145923612, 1, 0.10116554902596137`], 
     Hue[0.6497157983237045, 1, 0.10039351001333228`], 
     Hue[0.6495027893128164, 1, 0.10068844556686975`], 
     Hue[0.6499201610256953, 1, 0.10011054627211431`], 
     Hue[0.6499538788065777, 1, 0.10006386011396938`], 
     Hue[0.6498842789713233, 1, 0.10016022911662933`], 
     Hue[0.6496032645143989, 1, 0.10054932605698623`], 
     Hue[0.6488043759781962, 1, 0.10165547941480539`], 
     Hue[0.649795530813851, 1, 0.10028311118082167`], 
     Hue[0.6482024974049992, 1, 0.10248884974692411`], 
     Hue[0.6024053962159769, 1, 0.1659002206240321], 
     Hue[0.6318512766193006, 1, 0.1251290016040453], 
     Hue[0.6441384496108, 1, 0.10811599284658469`], 
     Hue[0.6484528469605408, 1, 0.10214221190078972`], 
     Hue[0.6497338680913757, 1, 0.10036849033501834`], 
     Hue[0.649912342586056, 1, 0.10012137180392251`], 
     Hue[0.649871333393051, 1, 0.10017815376346778`], 
     Hue[0.6036209569850148, 1, 0.16421713648228714`], 
     Hue[0.630950105099937, 1, 0.12637677755393345`], 
     Hue[0.6439810457117625, 1, 0.10833393670679037`], 
     Hue[0.648400102794294, 1, 0.10221524228482369`], 
     Hue[0.6496396869352193, 1, 0.10049889501277325`], 
     Hue[0.6498487977251083, 1, 0.10020935699600393`], 
     Hue[0.6498495443345171, 1, 0.10020832322913023`], 
     Hue[0.6499439285594746, 1, 0.10007763737918901`], 
     Hue[0.6092181129633748, 1, 0.156467228204558], 
     Hue[0.6319252584694832, 1, 0.12502656519610023`], 
     Hue[0.6440193419512215, 1, 0.1082809111444627], 
     Hue[0.6485164685013147, 1, 0.1020541205366412], 
     Hue[0.6496911881982969, 1, 0.10042758557158907`], 
     Hue[0.6498642363226074, 1, 0.10018798047638988`], 
     Hue[0.6498806262290605, 1, 0.10016528675976236`], 
     Hue[0.6499429120483161, 1, 0.10007904485617779`], 
     Hue[0.6351781727980892, 1, 0.12052252997187649`], 
     Hue[0.6444516059643979, 1, 0.1076823917416029], 
     Hue[0.6485444303759181, 1, 0.10201540409488259`], 
     Hue[0.6497261945124423, 1, 0.10037911529046462`], 
     Hue[0.6498910295039884, 1, 0.10015088222524691`], 
     Hue[0.6498942824670726, 1, 0.10014637812251488`], 
     Hue[0.6499575206265278, 1, 0.10005881759403848`], 
     Hue[0.6496716913072046, 1, 0.10045458126694752`], 
     Hue[0.6459877899196629, 1, 0.10555536780354377`], 
     Hue[0.6487276915235816, 1, 0.10176165789042557`], 
     Hue[0.649733317193595, 1, 0.10036925311656093`], 
     Hue[0.6498948395498347, 1, 0.10014560677715195`], 
     Hue[0.6498985190517773, 1, 0.1001405120821545], 
     Hue[0.6499620346194697, 1, 0.10005256744996509`], 
     Hue[0.6497721636962438, 1, 0.10031546565135482`], 
     Hue[0.6498497708133715, 1, 0.10020800964302418`], 
     Hue[0.6495307520491639, 1, 0.10064972793192703`], 
     Hue[0.648112770234713, 1, 0.10261308736732044`], 
     Hue[0.6492305659527149, 1, 0.1010653702193179], 
     Hue[0.649707550244395, 1, 0.10040493043083777`], 
     Hue[0.6497913837319287, 1, 0.1002888532942526], 
     Hue[0.6499088359058091, 1, 0.10012622720734127`], 
     Hue[0.6499263293586904, 1, 0.1001020055033518], 
     Hue[0.6499644944814522, 1, 0.10004916148722011`], 
     Hue[0.6498373028218771, 1, 0.10022527301586241`], 
     Hue[0.6497451025149057, 1, 0.10035293497936143`], 
     Hue[0.6495560123779659, 1, 0.10061475209204732`], 
     Hue[0.6497004428501939, 1, 0.10041477143819313`], 
     Hue[0.6494987703008099, 1, 0.1006940103527248], 
     Hue[0.6493579234777965, 1, 0.1008890290307433], 
     Hue[0.649715698014699, 1, 0.1003936489027245], 
     Hue[0.6498241758497791, 1, 0.10024344882338278`], 
     Hue[0.6498994107425927, 1, 0.10013927743333322`], 
     Hue[0.6499481817937316, 1, 0.10007174828560249`], 
     Hue[0.6499077513311474, 1, 0.10012772892610364`], 
     Hue[0.6496555240543804, 1, 0.10047696669393485`], 
     Hue[0.6493754082800219, 1, 0.100864819304585], 
     Hue[0.6482319468429034, 1, 0.10244807360213375`], 
     Hue[0.6492851521797726, 1, 0.10098978928954574`], 
     Hue[0.6481459299418838, 1, 0.10256717392662248`], 
     Hue[0.6482091378047817, 1, 0.10247965534722532`], 
     Hue[0.6499037411265587, 1, 0.10013328151707268`], 
     Hue[0.6497578390940847, 1, 0.10033529971588273`], 
     Hue[0.6499198198959212, 1, 0.10011101860564758`], 
     Hue[0.6499100505259799, 1, 0.10012454542556626`], 
     Hue[0.6497863218632153, 1, 0.10029586203554806`], 
     Hue[0.6494924838801659, 1, 0.10070271462746269`], 
     Hue[0.6494226704725989, 1, 0.10079937934563227`], 
     Hue[0.6498367955394584, 1, 0.10022597540690377`], 
     Hue[0.649941134156729, 1, 0.10008150655222134`], 
     Hue[0.6498116968261762, 1, 0.10026072747144835`], 
     Hue[0.649873191405741, 1, 0.10017558113051256`], 
     Hue[0.6494736087448549, 1, 0.10072884943020093`], 
     Hue[0.6495814525498127, 1, 0.1005795272387209], 
     Hue[0.6495260890372909, 1, 0.10065618440990488`], 
     Hue[0.6498855311799355, 1, 0.10015849528932008`], 
     Hue[0.6498821923987246, 1, 0.10016311821715063`], 
     Hue[0.6496680766227215, 1, 0.10045958621469327`], 
     Hue[0.6497041036807453, 1, 0.10040970259589123`], 
     Hue[0.6496923087830277, 1, 0.10042603399273087`], 
     Hue[0.6498718367735986, 1, 0.1001774567750173], 
     Hue[0.6496991172124669, 1, 0.10041660693658441`], 
     Hue[0.6496694176127454, 1, 0.10045772945927564`], 
     Hue[0.6496866101630119, 1, 0.10043392438967595`], 
     Hue[0.6499246563043265, 1, 0.10010432204016331`], 
     Hue[0.649826283980032, 1, 0.10024052987380193`], 
     Hue[0.649926338848644, 1, 0.10010199236341603`], 
     Hue[0.6499236388569277, 1, 0.10010573081348478`], 
     Hue[0.649625007992174, 1, 0.10051921970314366`], 
     Hue[0.6495827119562023, 1, 0.10057778344525833`], 
     Hue[0.6496015750104206, 1, 0.10055166537018698`], 
     Hue[0.6496873992133034, 1, 0.100432831858503], 
     Hue[0.6498545524404962, 1, 0.10020138892854381`], 
     Hue[0.6495824574818436, 1, 0.10057813579437044`], 
     Hue[0.6496550646169922, 1, 0.1004776028380108], 
     Hue[0.6496097608075474, 1, 0.10054033118954982`], 
     Hue[0.6498340535847857, 1, 0.10022977195952754`], 
     Hue[0.6494171045795625, 1, 0.1008070859667597], 
     Hue[0.6499184304393719, 1, 0.10011294246856195`], 
     Hue[0.05388308384032814, 1, 0.925392653144161], 
     Hue[0.649842102923036, 1, 0.10021862672195017`], 
     Hue[0.6497046025949196, 1, 0.10040901179164986`], 
     Hue[0.041683232136209836`, 1, 0.9422847555037095], 
     Hue[0.04113066060974424, 1, 0.9430498545403542], 
     Hue[0.014510345657857804`, 1, 0.9799087521660431], 
     Hue[0.6307416254095305, 1, 0.12666544174065006`], 
     Hue[0.6498382023628717, 1, 0.10022402749756232`], 
     Hue[0.6494690054117913, 1, 0.10073522327598122`], 
     Hue[0.06870808515626081, 1, 0.9048657282451774], 
     Hue[0.05776000655548441, 1, 0.9200246063077908], 
     Hue[0.04008294401782553, 1, 0.9445005390522415], 
     Hue[0.03998859509233932, 1, 0.9446311760259917], 
     Hue[0.0427200132446901, 1, 0.9408492124304291], 
     Hue[0.04069811831524772, 1, 0.9436487592558108], 
     Hue[0.6420830868502572, 1, 0.11096187974579773`], 
     Hue[0.047632726235142586`, 1, 0.9340469944436487], 
     Hue[0.03947622452824728, 1, 0.9453406121916575], 
     Hue[0.028449903518679598`, 1, 0.9606078258972128], 
     Hue[0.0880097764959673, 1, 0.8781403094671222], 
     Hue[0.10016800353925992`, 1, 0.8613058412533323], 
     Hue[0.04360938675827708, 1, 0.9396177721808471], 
     Hue[0.6475654987077457, 1, 0.10337084794312129`], 
     Hue[0.0251303414341284, 1, 0.9652041426296685], 
     Hue[0.10081068642169677`, 1, 0.8604159726468814], 
     Hue[0.07580013055125123, 1, 0.8950459730828829], 
     Hue[0.09990425219514576, 1, 0.8616710354221059], 
     Hue[0.024675421714856927`, 1, 0.9658340314717366], 
     Hue[0.050137261437109726`, 1, 0.9305791764716942], 
     Hue[0.046776019301721705`, 1, 0.93523320404377], 
     Hue[0.021457424653446577`, 1, 0.9702897197106124], 
     Hue[0.019751799353723398`, 1, 0.9726513547409984], 
     Hue[0.01680908711127571, 1, 0.9767258793843874], 
     Hue[0.01440144142209454, 1, 0.9800595426463307], 
     Hue[0.01481669601868385, 1, 0.9794845747433608], 
     Hue[0.0280118425257051, 1, 0.9612143718874853], 
     Hue[0.013383580297995468`, 1, 0.9814688888181601], 
     Hue[0.014320509417825478`, 1, 0.9801716023445494], 
     Hue[0.0172839294216669, 1, 0.9760684054161536], 
     Hue[0.07450109818912687, 1, 0.8968446332765936], 
     Hue[0.047210284387175006`, 1, 0.93463191392545], 
     Hue[0.014393278961707945`, 1, 0.9800708445145582], 
     Hue[0.016856950863738063`, 1, 0.9766596064963627], 
     Hue[0.012320324951581085`, 1, 0.98294108852858], 
     Hue[0.010275615890435241`, 1, 0.985772224151705], 
     Hue[0.637232539105323, 1, 0.11767802277724519`], 
     Hue[0.638031138360988, 1, 0.11657226996170895`], 
     Hue[0.03525326968422382, 1, 0.9511877804372285], 
     Hue[0.03744251748693428, 1, 0.9481565142488602], 
     Hue[0.06463940691108683, 1, 0.9104992827384952], 
     Hue[0.04499698807232322, 1, 0.9376964780537064], 
     Hue[0.015005951520566163`, 1, 0.9792225286638315], 
     Hue[0.01456794680493112, 1, 0.9798289967316338], 
     Hue[0.003910694285865213, 1, 0.9945851925272635], 
     Hue[0.6493553325147267, 1, 0.10089261651807085`], 
     Hue[0.6495015036065516, 1, 0.10069022577554403`], 
     Hue[0.6485453343422101, 1, 0.10201415244924761`], 
     Hue[0.6485756135970349, 1, 0.10197222732718254`], 
     Hue[0.040335138052103425`, 1, 0.9441513473124721], 
     Hue[0.03695733080109609, 1, 0.9488283111984823], 
     Hue[0.04206153553072589, 1, 0.9417609508036103], 
     Hue[0.06648636779091333, 1, 0.9079419522895046], 
     Hue[0.06433607271994823, 1, 0.9109192839262255], 
     Hue[0.06751618253739122, 1, 0.9065160549482275], 
     Hue[0.008571980347397035, 1, 0.9881311041343734], 
     Hue[0.007945912571656999, 1, 0.9889979672084749], 
     Hue[0.6494969499909599, 1, 0.10069653078174795`], 
     Hue[0.6484950112057156, 1, 0.10208383063823999`], 
     Hue[0.6484094532214162, 1, 0.10220229553957769`], 
     Hue[0.031031257782994204`, 1, 0.9570336430697004], 
     Hue[0.029551160991942882`, 1, 0.9590830078573098], 
     Hue[0.0267592676916385, 1, 0.9629487062731159], 
     Hue[0.07127931863619696, 1, 0.9013055588114195], 
     Hue[0.068711351833875, 1, 0.9048612051530961], 
     Hue[0.03196273120236359, 1, 0.9557439106428811], 
     Hue[0.03035596942629648, 1, 0.9579686577174357], 
     Hue[0.0021351943041774124`, 1, 0.9970435771172929], 
     Hue[0., 1, 1.], 
     Hue[0.0085078320274381, 1, 0.9882199248850857], 
     Hue[0.6494807639290264, 1, 0.10071894225211725`], 
     Hue[0.6494782922251136, 1, 0.1007223646113812], 
     Hue[0.6483966076720857, 1, 0.10222008168480443`], 
     Hue[0.04230641207477759, 1, 0.9414218909733849], 
     Hue[0.6489238442822333, 1, 0.10149006176306159`], 
     Hue[0.6496761313230504, 1, 0.10044843355269961`], 
     Hue[0.6496442228054237, 1, 0.10049261457710565`], 
     Hue[0.6289603631802385, 1, 0.12913180482736206`], 
     Hue[0.04236932139734617, 1, 0.9413347857575207], 
     Hue[0.0451080983176152, 1, 0.9375426330986867], 
     Hue[0.0456215913740462, 1, 0.9368316427128591], 
     Hue[0.648793329312517, 1, 0.1016707747980534], 
     Hue[0.6496377155865927, 1, 0.10050162457241017`], 
     Hue[0.6496586351861857, 1, 0.10047265897297361`], 
     Hue[0.6496891893492678, 1, 0.10043035320870626`], 
     Hue[0.6493331594956382, 1, 0.10092331762142415`], 
     Hue[0.638526376747741, 1, 0.11588655527235855`], 
     Hue[0.043200916199857775`, 1, 0.9401833468001969], 
     Hue[0.05095047877511394, 1, 0.9294531832344577], 
     Hue[0.046124686800754766`, 1, 0.9361350490451088], 
     Hue[0.6487676460996885, 1, 0.1017063361696621], 
     Hue[0.6495931612172297, 1, 0.10056331523768201`], 
     Hue[0.6497699262830143, 1, 0.10031856360813403`], 
     Hue[0.6497582275526447, 1, 0.1003347618501844], 
     Hue[0.6494999123698229, 1, 0.10069242902639917`], 
     Hue[0.6495881296151054, 1, 0.10057028207139264`], 
     Hue[0.6498788878154025, 1, 0.10016769379405806`], 
     Hue[0.6492996971798762, 1, 0.10096965005863295`], 
     Hue[0.6491921147809965, 1, 0.10111861030323575`], 
     Hue[0.6499104370570542, 1, 0.10012401022869415`], 
     Hue[0.6497064553061999, 1, 0.10040644649910797`], 
     Hue[0.6498439596910156, 1, 0.10021605581243993`], 
     Hue[0.6496278364041627, 1, 0.10051530344039017`], 
     Hue[0.6497873339466844, 1, 0.10029446068920625`], 
     Hue[0.6498125567188874, 1, 0.10025953685077138`], 
     Hue[0.6497633975904421, 1, 0.10032760333631092`], 
     Hue[0.6497714789468696, 1, 0.10031641376587287`], 
     Hue[0.6497643444331866, 1, 0.10032629232328001`], 
     Hue[0.6497944526431005, 1, 0.10028460403263002`], 
     Hue[0.6499062171090211, 1, 0.10012985323366322`], 
     Hue[0.6498155493111194, 1, 0.10025539326152699`], 
     Hue[0.6498059825593456, 1, 0.10026863953321379`], 
     Hue[0.6498265133828732, 1, 0.10024021223909867`], 
     Hue[0.6499172197842323, 1, 0.10011461876029369`], 
     Hue[0.6499280689567947, 1, 0.10009959682905364`], 
     Hue[0.6498288368569385, 1, 0.10023699512116213`], 
     Hue[0.6498283347909065, 1, 0.10023769028951413`], 
     Hue[0.6498305382467162, 1, 0.10023463935070065`], 
     Hue[0.6498396130644998, 1, 0.1002220742183849], 
     Hue[0.6498337992580293, 1, 0.10023012410426721`], 
     Hue[0.649860063873632, 1, 0.10019375771343253`], 
     Hue[0.6489938634795805, 1, 0.10139311210519623`], 
     Hue[0.6497200489332474, 1, 0.1003876245539651], 
     Hue[0.6495197810162897, 1, 0.10066491859282964`], 
     Hue[0.6498745493074837, 1, 0.10017370095886875`], 
     Hue[0.6498262933309421, 1, 0.10024051692638793`], 
     Hue[0.10524004743398285`, 1, 0.8542830112452544], 
     Hue[0.021686710453826752`, 1, 0.9699722470639323], 
     Hue[0.6493373442597588, 1, 0.10091752333264169`], 
     Hue[0.6493599425072097, 1, 0.10088623345155585`], 
     Hue[0.04438280403097139, 1, 0.9385468867263473], 
     Hue[0.04089771395265862, 1, 0.9433723960655497], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6498050267652953, 1, 0.10026996294036038`], 
     Hue[0.6491552252272876, 1, 0.10116968814683262`], 
     Hue[0.6494926067996083, 1, 0.10070254443131167`], 
     Hue[0.6495426725698557, 1, 0.10063322259558456`], 
     Hue[0.6495792595415016, 1, 0.10058256371176694`], 
     Hue[0.6491493760411046, 1, 0.10117778702000914`], 
     Hue[0.649140666859852, 1, 0.10118984588635893`], 
     Hue[0.6495105397562887, 1, 0.10067771418360034`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499027092115623, 1, 0.10013471032245223`], 
     Hue[0.6497656720679338, 1, 0.10032445405978407`], 
     Hue[0.6482320464325191, 1, 0.10244793570881974`], 
     Hue[0.6469681627817382, 1, 0.10419792845605484`], 
     Hue[0.6447371269763458, 1, 0.10728705495582902`], 
     Hue[0.6445916137583816, 1, 0.107488534796087], 
     Hue[0.6499308470146784, 1, 0.10009575028736846`], 
     Hue[0.6498579497275571, 1, 0.10019668499261335`], 
     Hue[0.6494355199252905, 1, 0.10078158779575173`], 
     Hue[0.6484356149041893, 1, 0.10216607167112247`], 
     Hue[0.6431642258851614, 1, 0.10946491800516117`], 
     Hue[0.6279016310349287, 1, 0.13059774164394494`], 
     Hue[0.6271177861956798, 1, 0.13168306526752033`], 
     Hue[0.6499756472067431, 1, 0.10003371925220193`], 
     Hue[0.6499578633554144, 1, 0.10005834304634931`], 
     Hue[0.6498842701302959, 1, 0.10016024135805185`], 
     Hue[0.6496305707832019, 1, 0.10051151737710518`], 
     Hue[0.648887778417325, 1, 0.10153999911447302`], 
     Hue[0.6476157228781064, 1, 0.1033013067841603], 
     Hue[0.6443569476344165, 1, 0.10781345712157714`], 
     Hue[0.6498506020154098, 1, 0.10020685874789412`], 
     Hue[0.649705603999756, 1, 0.10040762523110722`], 
     Hue[0.6489080330420466, 1, 0.101511954249474], 
     Hue[0.6482914517880466, 1, 0.10236568213962782`], 
     Hue[0.6452598947464396, 1, 0.10656322265877595`], 
     Hue[0.6498140968869448, 1, 0.10025740431038414`], 
     Hue[0.6496484810073236, 1, 0.1004867186052442], 
     Hue[0.648729862202491, 1, 0.10175865233501258`], 
     Hue[0.648413941336544, 1, 0.10219608122632381`], 
     Hue[0.6453892731162477, 1, 0.10638408337750321`], 
     Hue[0.6432772977581112, 1, 0.10930835695030773`], 
     Hue[0.6499328696710126, 1, 0.10009294968629032`], 
     Hue[0.6495744376755279, 1, 0.10058924014157672`], 
     Hue[0.6482288623353962, 1, 0.10245234445868218`], 
     Hue[0.643697515395808, 1, 0.1087265171442659], 
     Hue[0.6497129391888993, 1, 0.10039746881537023`], 
     Hue[0.6488132697315385, 1, 0.10164316498710055`], 
     Hue[0.6482313331258844, 1, 0.10244892336416005`], 
     Hue[0.11344731373009043`, 1, 0.8429191040660285], 
     Hue[0.11323760400852934`, 1, 0.8432094713728054], 
     Hue[0.6482450777562206, 1, 0.10242989233754063`], 
     Hue[0.6496916149164867, 1, 0.10042699473101833`], 
     Hue[0.6491399050955516, 1, 0.10119090063692852`], 
     Hue[0.08490701344686591, 1, 0.8824364429197242], 
     Hue[0.06697061246667879, 1, 0.9072714596615217], 
     Hue[0.060454915254167685`, 1, 0.9162931942634602], 
     Hue[0.048235149611946526`, 1, 0.933212869768074], 
     Hue[0.04401893718494998, 1, 0.9390507023593001], 
     Hue[0.03747806273773269, 1, 0.9481072977477548], 
     Hue[0.05344987084838437, 1, 0.9259924865176217], 
     Hue[0.04589112452042998, 1, 0.9364584429717123], 
     Hue[0.050202523117609754`, 1, 0.9304888141448481], 
     Hue[0.02999720289964891, 1, 0.958465411369717], 
     Hue[0.04408650581603957, 1, 0.938957145793176], 
     Hue[0.01162781131325663, 1, 0.98389995356626], 
     Hue[0.01127991425751218, 1, 0.9843816571819063], 
     Hue[0.6456481227242467, 1, 0.10602567622796626`], 
     Hue[0.6490576458893617, 1, 0.10130479799934543`], 
     Hue[0.6489261671161527, 1, 0.10148684553148091`], 
     Hue[0.6481345738244674, 1, 0.10258289778150673`], 
     Hue[0.04780632435686771, 1, 0.9338066278135677], 
     Hue[0.03979761145305827, 1, 0.9448956149111502], 
     Hue[0.04900292513571736, 1, 0.9321497959659298], 
     Hue[0.6064053233776273, 1, 0.16036185993866994`], 
     Hue[0.6484798238208168, 1, 0.10210485932502288`], 
     Hue[0.6497037437293651, 1, 0.10041020099010993`], 
     Hue[0.5482258922483598, 1, 0.24091799534842484`], 
     Hue[0.087578484352689, 1, 0.878737483203969], 
     Hue[0.07062958497702931, 1, 0.9022051900318055], 
     Hue[0.06396322804944421, 1, 0.9114355303930772], 
     Hue[0.06437520813494868, 1, 0.9108650964285326], 
     Hue[0.07050909879970724, 1, 0.9023720170465592], 
     Hue[0.040415001543837814`, 1, 0.9440407670931475], 
     Hue[0.07777304312433986, 1, 0.8923142479816832], 
     Hue[0.08864390342290596, 1, 0.8772622875682841], 
     Hue[0.048569275228382947`, 1, 0.932750234299162], 
     Hue[0.5310126054835547, 1, 0.26475177702277053`], 
     Hue[0.6492083231828757, 1, 0.10109616790063372`], 
     Hue[0.06263185835624807, 1, 0.9132789653528873], 
     Hue[0.05113739543382401, 1, 0.9291943755531668], 
     Hue[0.04857748919151783, 1, 0.9327388611194368], 
     Hue[0.0533018037796823, 1, 0.9261975024589014], 
     Hue[0.06190396781924434, 1, 0.9142868137887387], 
     Hue[0.0670711663972483, 1, 0.9071322311422715], 
     Hue[0.018515587275054424`, 1, 0.9743630330037707], 
     Hue[0.019020406684673863`, 1, 0.9736640522827592], 
     Hue[0.0339148047156862, 1, 0.9530410396244345], 
     Hue[0.024385212843262227`, 1, 0.9662358591400984], 
     Hue[0.023012856428964557`, 1, 0.9681360449445106], 
     Hue[0.09448765999984665, 1, 0.8691709323079047], 
     Hue[0.043824738143059316`, 1, 0.9393195933403794], 
     Hue[0.04149848791629829, 1, 0.9425405551928178], 
     Hue[0.043463218263920966`, 1, 0.9398201593268787], 
     Hue[0.05275206941907329, 1, 0.9269586731120523], 
     Hue[0.020474470177885062`, 1, 0.9716507335998514], 
     Hue[0.017377860076169704`, 1, 0.975938347586842], 
     Hue[0.10082929014588538`, 1, 0.8603902136441587], 
     Hue[0.018229040834663368`, 1, 0.9747597896135429], 
     Hue[0.016885198480094843`, 1, 0.9766204944121764], 
     Hue[0.6461472466818617, 1, 0.10533458151742223`], 
     Hue[0.03642065901913116, 1, 0.9495713952042799], 
     Hue[0.031745497461815875`, 1, 0.9560446958221012], 
     Hue[0.041952273727451916`, 1, 0.9419122363773742], 
     Hue[0.013046603456955186`, 1, 0.9819354721365237], 
     Hue[0.5983454978326734, 1, 0.17152161838552915`], 
     Hue[0.6022248607370287, 1, 0.16615019282565263`], 
     Hue[0.6477995107573841, 1, 0.10304683125900674`], 
     Hue[0.6370199234798274, 1, 0.1179724136433159], 
     Hue[0.031305298589567654`, 1, 0.9566542019529063], 
     Hue[0.0368179443013541, 1, 0.9490213078904328], 
     Hue[0.03320397002422837, 1, 0.9540252722741454], 
     Hue[0.051840587257630966`, 1, 0.928220725335588], 
     Hue[0.014180199871491883`, 1, 0.9803658771010113], 
     Hue[0.021680161781822527`, 1, 0.9699813144559379], 
     Hue[0.005304254725042923, 1, 0.9926556473037867], 
     Hue[0.010799498153694076`, 1, 0.9850468487102698], 
     Hue[0.006742393769193722, 1, 0.9906643778580394], 
     Hue[0.005916955565143711, 1, 0.9918072922944163], 
     Hue[0.6441048583532912, 1, 0.10816250381851981`], 
     Hue[0.6484843896243547, 1, 0.10209853744320116`], 
     Hue[0.6490880331529807, 1, 0.10126272332664214`], 
     Hue[0.05130778638787692, 1, 0.9289584496167859], 
     Hue[0.0443384547808221, 1, 0.9386082933804002], 
     Hue[0.03809309828289398, 1, 0.9472557100698391], 
     Hue[0.059034045015249115`, 1, 0.9182605530558089], 
     Hue[0.06173550976469999, 1, 0.9145200634027231], 
     Hue[0.021575318439249758`, 1, 0.9701264821610388], 
     Hue[0.0038774459490926727`, 1, 0.9946312286858716], 
     Hue[0.004740489441371509, 1, 0.9934362453888703], 
     Hue[0.006142541847195426, 1, 0.9914949420577294], 
     Hue[0.008052121545263136, 1, 0.9888509086296358], 
     Hue[0.014137081572457855`, 1, 0.9804255793612122], 
     Hue[0.6404737964873864, 1, 0.11319012794054185`], 
     Hue[0.6491595840461881, 1, 0.10116365285912417`], 
     Hue[0.6497346109013015, 1, 0.10036746182896716`], 
     Hue[0.6363446516713699, 1, 0.11890740537810321`], 
     Hue[0.6358707836490146, 1, 0.11956353033213359`], 
     Hue[0.5956837699629056, 1, 0.17520708774366922`], 
     Hue[0.5960880233808034, 1, 0.1746473522419647], 
     Hue[0.4868542147016809, 1, 0.32589416425921114`], 
     Hue[0.4931669175684789, 1, 0.3171534987513369], 
     Hue[0.04483601470773302, 1, 0.9379193642508311], 
     Hue[0.03680086493713308, 1, 0.9490449562408927], 
     Hue[0.030301293032106713`, 1, 0.9580443634940061], 
     Hue[0.028373301458268996`, 1, 0.9607138902885507], 
     Hue[0.07269328395621188, 1, 0.8993477606760143], 
     Hue[0.07071387824703623, 1, 0.9020884762733345], 
     Hue[0.07635655967417443, 1, 0.8942755327588354], 
     Hue[0.07680437074410107, 1, 0.8936554866620139], 
     Hue[0.03397582858368453, 1, 0.9529565450379752], 
     Hue[0.0001415299609048848, 1, 0.9998040354387472], 
     Hue[0.008720244702119961, 1, 0.9879258150278339], 
     Hue[0.025438136246693666`, 1, 0.9647779651968856], 
     Hue[0.6492004060506914, 1, 0.10110713008365806`], 
     Hue[0.6497622076056531, 1, 0.1003292510075574], 
     Hue[0.03428630623978335, 1, 0.9525266528987616], 
     Hue[0.07753773203379744, 1, 0.892640063337819], 
     Hue[0.06800160355927398, 1, 0.9058439335333129], 
     Hue[0.03203022936535738, 1, 0.9556504516479667], 
     Hue[0.02303512129737706, 1, 0.9681052166651702], 
     Hue[0.0022283590375400397`, 1, 0.9969145797941753], 
     Hue[0.0107849642607315, 1, 0.9850669725620641], 
     Hue[0.01354576119673001, 1, 0.9812443306506815], 
     Hue[0.04798980310469714, 1, 0.9335525803165732], 
     Hue[0.6062599321494685, 1, 0.1605631708699668], 
     Hue[0.6066472815410087, 1, 0.16002684094321884`], 
     Hue[0.6493966101779612, 1, 0.10083546283051517`], 
     Hue[0.6495892775004837, 1, 0.100568692691638], 
     Hue[0.648675008883066, 1, 0.10183460308498565`], 
     Hue[0.029478685863724596`, 1, 0.9591833580348429], 
     Hue[0.04313241811288426, 1, 0.9402781903052371], 
     Hue[0.04072860742243256, 1, 0.9436065435689395], 
     Hue[0.047953795725585446`, 1, 0.9336024366876509], 
     Hue[0.04423171761199618, 1, 0.9387560833064668], 
     Hue[0.05339315721285798, 1, 0.9260710130898889], 
     Hue[0.0768120588568344, 1, 0.8936448415828447], 
     Hue[0.6382928104275187, 1, 0.11620995479266638`], 
     Hue[0.6391986505449277, 1, 0.11495571463010004`], 
     Hue[0.6493236646477679, 1, 0.10093646433385989`], 
     Hue[0.6491838513604048, 1, 0.10113005196251654`], 
     Hue[0.6440172145378913, 1, 0.108283856793689], 
     Hue[0.04178716078778333, 1, 0.9421408542938384], 
     Hue[0.044547269629119146`, 1, 0.9383191651289119], 
     Hue[0.047848959839330796`, 1, 0.933747594068619], 
     Hue[0.05039860553704345, 1, 0.9302173154102475], 
     Hue[0.07484637077999845, 1, 0.8963665635353868], 
     Hue[0.039095132612616545`, 1, 0.9458682779209924], 
     Hue[0.6494375371226361, 1, 0.10077879475327309`], 
     Hue[0.6498018962883816, 1, 0.10027429744685626`], 
     Hue[0.646873959809805, 1, 0.1043283633402701], 
     Hue[0.6340756447216094, 1, 0.12204910730854096`], 
     Hue[0.09863551983085261, 1, 0.8634277417726656], 
     Hue[0.09094333562801071, 1, 0.8740784583612159], 
     Hue[0.06044416243704642, 1, 0.9163080827794742], 
     Hue[0.12105034653104152`, 1, 0.8323918278800964], 
     Hue[0.08085280909794812, 1, 0.8880499566336103], 
     Hue[0.645526051888763, 1, 0.10619469738478966`], 
     Hue[0.6470795014910338, 1, 0.104043767166261], 
     Hue[0.6493677287341193, 1, 0.1008754525219887], 
     Hue[0.6496529647960042, 1, 0.1004805102824557], 
     Hue[0.648746689960784, 1, 0.1017353523619915], 
     Hue[0.6421285070983408, 1, 0.11089899017152824`], 
     Hue[0.2251775469929308, 1, 0.6882157041636343], 
     Hue[0.647893846873708, 1, 0.10291621202101972`], 
     Hue[0.6486416945972464, 1, 0.10188073055765892`], 
     Hue[0.6498457538132246, 1, 0.10021357164322749`], 
     Hue[0.6497823612786566, 1, 0.10030134592186017`], 
     Hue[0.646873736164624, 1, 0.10432867300282844`], 
     Hue[0.6477754652998367, 1, 0.10308012496945697`], 
     Hue[0.6493125837684354, 1, 0.10095180708985878`], 
     Hue[0.6495641426211453, 1, 0.1006034948322605], 
     Hue[0.6497707274456652, 1, 0.10031745430600209`], 
     Hue[0.6468490019880697, 1, 0.10436292032421114`], 
     Hue[0.6477463076194151, 1, 0.10312049714234843`], 
     Hue[0.6493145234102441, 1, 0.10094912143196978`], 
     Hue[0.6492172470399903, 1, 0.10108381179078267`], 
     Hue[0.6494638514093759, 1, 0.10074235958701809`], 
     Hue[0.6497823074769308, 1, 0.1003014204165574], 
     Hue[0.6499777611528732, 1, 0.10003079224986793`], 
     Hue[0.5414866068622726, 1, 0.2502493135753149], 
     Hue[0.6469254182880692, 1, 0.1042571131395966], 
     Hue[0.6478497007253369, 1, 0.10297733745722591`], 
     Hue[0.649345189409999, 1, 0.10090666081692455`], 
     Hue[0.6495387197635338, 1, 0.10063869571203012`], 
     Hue[0.6498224213399206, 1, 0.10024587814472524`], 
     Hue[0.649386979251001, 1, 0.10084879796015261`], 
     Hue[0.6495732086634157, 1, 0.10059094185065523`], 
     Hue[0.6498291937048549, 1, 0.10023650102404713`], 
     Hue[0.6493720261409178, 1, 0.1008695022664215], 
     Hue[0.6496174756457836, 1, 0.10052964910583807`], 
     Hue[0.6368741919269602, 1, 0.11817419579343975`], 
     Hue[0.635364466631856, 1, 0.12026458466358414`], 
     Hue[0.6364325407452603, 1, 0.11878571281425494`], 
     Hue[0.6495755553290814, 1, 0.10058769262127198`], 
     Hue[0.6498483402268316, 1, 0.1002099904551563], 
     Hue[0.6499068461607078, 1, 0.10012898223901996`], 
     Hue[0.6492822716382364, 1, 0.1009937777316727], 
     Hue[0.6495664564521784, 1, 0.10060029106621457`], 
     Hue[0.6465629702050969, 1, 0.1047589643314043], 
     Hue[0.6467576313120595, 1, 0.1044894335679176], 
     Hue[0.6497149791640484, 1, 0.10039464423439459`], 
     Hue[0.6497996198782567, 1, 0.10027744939933689`], 
     Hue[0.6487076096740543, 1, 0.10178946352823263`], 
     Hue[0.6491846426415534, 1, 0.10112895634246459`], 
     Hue[0.6497015533887277, 1, 0.10041323376945399`], 
     Hue[0.6499090025975782, 1, 0.10012599640335326`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6494536148352175, 1, 0.1007565333050835], 
     Hue[0.6494676933247115, 1, 0.10073704001193792`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499677682062704, 1, 0.10004462863747177`], 
     Hue[0.6499159567668522, 1, 0.10011636755358931`], 
     Hue[0.6499586156125281, 1, 0.10005730145957653`], 
     Hue[0.6497342083386085, 1, 0.10036801922346522`], 
     Hue[0.6486958382052802, 1, 0.10180576248499675`], 
     Hue[0.64995298925716, 1, 0.10006509179777849`], 
     Hue[0.649699212390262, 1, 0.10041647515194506`], 
     Hue[0.6499503496575255, 1, 0.10006874662804163`], 
     Hue[0.6496842930705824, 1, 0.10043713267150137`], 
     Hue[0.6499497055555192, 1, 0.10006963846158885`], 
     Hue[0.6496796918465149, 1, 0.10044350359713328`], 
     Hue[0.6499471466004823, 1, 0.10007318163010147`], 
     Hue[0.6496657807990255, 1, 0.10046276504750323`], 
     Hue[0.6499396133068425, 1, 0.10008361234437207`], 
     Hue[0.6499330917990747, 1, 0.1000926421243582], 
     Hue[0.6499375851866971, 1, 0.10008642051072714`], 
     Hue[0.649568580993897, 1, 0.10059734939306575`], 
     Hue[0.6499538739845886, 1, 0.10006386679056971`], 
     Hue[0.6496537896202406, 1, 0.10047936821812845`], 
     Hue[0.6491621541128009, 1, 0.10116009430535275`], 
     Hue[0.06024007906432027, 1, 0.9165906597570951], 
     Hue[0.046190855663939656`, 1, 0.9360434306191605], 
     Hue[0.033857950941987625`, 1, 0.953119760234171], 
     Hue[0.04270455282316932, 1, 0.9408706191679195], 
     Hue[0.052622079354547546`, 1, 0.9271386593552418], 
     Hue[0.0402389850840712, 1, 0.9442844821912861], 
     Hue[0.6499712377283842, 1, 0.10003982468377576`], 
     Hue[0.64992186070424, 1, 0.10010819287105233`], 
     Hue[0.04095054705673207, 1, 0.9432992425368325], 
     Hue[0.03561220493535888, 1, 0.9506907931664262], 
     Hue[0.025530936670433824`, 1, 0.9646494723024762], 
     Hue[0.07909078423314264, 1, 0.8904896833694947], 
     Hue[0.10263677497082568`, 1, 0.8578875423480875], 
     Hue[0.03680304106912968, 1, 0.9490419431350512], 
     Hue[0.6499182622719397, 1, 0.10011317531577589`], 
     Hue[0.6498051364487069, 1, 0.10026981107102134`], 
     Hue[0.055241142827705536`, 1, 0.923512263777023], 
     Hue[0.06031890396534545, 1, 0.9164815175864447], 
     Hue[0.08612859086040703, 1, 0.8807450280394364], 
     Hue[0.029422001712560597`, 1, 0.9592618437826084], 
     Hue[0.0747922906558649, 1, 0.8964414437072641], 
     Hue[0.07809189434944763, 1, 0.8918727616699956], 
     Hue[0.0395810345321056, 1, 0.9451954906478537], 
     Hue[0.05050760632296236, 1, 0.930066391245129], 
     Hue[0.6481393464082207, 1, 0.10257628958861761`], 
     Hue[0.6470887827991273, 1, 0.10403091612428539`], 
     Hue[0.6498166902002593, 1, 0.10025381356887168`], 
     Hue[0.6496608377984208, 1, 0.10046960920218662`], 
     Hue[0.051078590390588374`, 1, 0.9292757979207238], 
     Hue[0.05714056591662575, 1, 0.9208822933462105], 
     Hue[0.05261679886351933, 1, 0.9271459708043578], 
     Hue[0.048775746205941606`, 1, 0.9324643514071578], 
     Hue[0.6498605662491577, 1, 0.10019306211655093`], 
     Hue[0.6497695098277386, 1, 0.10031914023851578`], 
     Hue[0.6362402722765276, 1, 0.11905193069403877`], 
     Hue[0.04272235928098833, 1, 0.9408459640724777], 
     Hue[0.6499302812990246, 1, 0.10009653358596594`], 
     Hue[0.6498911876640104, 1, 0.1001506632344472], 
     Hue[0.6442899150039886, 1, 0.10790627153293891`], 
     Hue[0.6463016243471624, 1, 0.1051208278270059], 
     Hue[0.044856700495144786`, 1, 0.937890722391338], 
     Hue[0.04826789235036122, 1, 0.9331675336687306], 
     Hue[0.6463630362357854, 1, 0.10503579598122019`], 
     Hue[0.6411650887681268, 1, 0.11223295401336293`], 
     Hue[0.6438087981846533, 1, 0.10857243328278783`], 
     Hue[0.6458676144975295, 1, 0.10572176454188234`], 
     Hue[0.0599273079456738, 1, 0.9170237274598362], 
     Hue[0.05343456474638697, 1, 0.9260136795819257], 
     Hue[0.05231397035764451, 1, 0.9275652718124922], 
     Hue[0.05640804776209041, 1, 0.9218965492524902], 
     Hue[0.02055474339991714, 1, 0.9715395860616532], 
     Hue[0.025255770720847837`, 1, 0.9650304713095954], 
     Hue[0.005143255281773396, 1, 0.9928785696098523], 
     Hue[0.00871911321308605, 1, 0.9879273817049578], 
     Hue[0.6499698891411724, 1, 0.1000416919583768], 
     Hue[0.6499302703385912, 1, 0.10009654876195068`], 
     Hue[0.06766522469085445, 1, 0.9063096888895862], 
     Hue[0.04651327332353694, 1, 0.9355970061674104], 
     Hue[0.052626683731600066`, 1, 0.9271322840639383], 
     Hue[0.04169642954516195, 1, 0.9422664821682373], 
     Hue[0.6499599955346981, 1, 0.10005539079811039`], 
     Hue[0.64991089561585, 1, 0.10012337530113083`], 
     Hue[0.03334874487427886, 1, 0.95382481478946], 
     Hue[0.03222677404335783, 1, 0.955378312863043], 
     Hue[0.04567016513503952, 1, 0.9367643867360992], 
     Hue[0.057083734909899264`, 1, 0.9209609824324472], 
     Hue[0.021427727483556813`, 1, 0.9703308388689214], 
     Hue[0.6499592761095564, 1, 0.10005638692522968`], 
     Hue[0.6499158290298568, 1, 0.10011654442019828`], 
     Hue[0.07271980853696347, 1, 0.8993110343334352], 
     Hue[0.6499793161789261, 1, 0.10002863913687161`], 
     Hue[0.6495995667178095, 1, 0.10055444608303304`], 
     Hue[0.6499443099739375, 1, 0.10007710926685578`], 
     Hue[0.6499237901870234, 1, 0.10010552127950609`], 
     Hue[0.649914229016793, 1, 0.10011875982290214`], 
     Hue[0.649916203279379, 1, 0.10011602622855209`], 
     Hue[0.6499220911583287, 1, 0.10010787378077574`], 
     Hue[0.6499290085020225, 1, 0.10009829592027653`], 
     Hue[0.6499406095057795, 1, 0.10008223299199766`], 
     Hue[0.6476792963742027, 1, 0.10321328194341162`], 
     Hue[0.6499565644198273, 1, 0.10006014157254686`], 
     Hue[0.6467271128367327, 1, 0.10453168991837022`], 
     Hue[0.648007222510079, 1, 0.10275923037065988`], 
     Hue[0.6499894776122711, 1, 0.1000145694599324], 
     Hue[0.64950277206805, 1, 0.10068846944423851`], 
     Hue[0.6498664477940284, 1, 0.10018491843903764`], 
     Hue[0.6498425699776529, 1, 0.10021798003094218`], 
     Hue[0.6499667631516982, 1, 0.10004602025149481`], 
     Hue[0.6499252658734632, 1, 0.10010347802135859`], 
     Hue[0.6497237279477236, 1, 0.10038253053392121`], 
     Hue[0.6497815470579313, 1, 0.1003024733044028], 
     Hue[0.6498923802619718, 1, 0.1001490119449622], 
     Hue[0.6499127497103961, 1, 0.10012080809329775`], 
     Hue[0.649848204703063, 1, 0.10021017810345119`], 
     Hue[0.6499334386213353, 1, 0.10009216190892034`], 
     Hue[0.6498479608919063, 1, 0.10021051568812976`], 
     Hue[0.6499050899734422, 1, 0.10013141388292626`], 
     Hue[0.6499792482395723, 1, 0.10002873320674609`], 
     Hue[0.6499464523331187, 1, 0.10007414292337416`], 
     Hue[0.649996188489335, 1, 0.10000527747630542`], 
     Hue[0.6499884985066602, 1, 0.10001592514462447`], 
     Hue[0.6462966855822057, 1, 0.10512766611694602`], 
     Hue[0.6488418101600686, 1, 0.10160364747067431`], 
     Hue[0.6498914689956915, 1, 0.10015027369827331`], 
     Hue[0.6485099986840415, 1, 0.1020630787451734], 
     Hue[0.6498706676206161, 1, 0.10017907560222389`], 
     Hue[0.6498623971469067, 1, 0.10019052702735994`], 
     Hue[0.6498682363596605, 1, 0.100182441963547], 
     Hue[0.6497150069205663, 1, 0.10039460580229288`], 
     Hue[0.6499666570178849, 1, 0.10004616720600554`], 
     Hue[0.6499127652365365, 1, 0.1001207865955649], 
     Hue[0.6319499160690127, 1, 0.12499242390444398`], 
     Hue[0.6345361190848053, 1, 0.12141152742103876`], 
     Hue[0.649908169646232, 1, 0.10012714972060192`], 
     Hue[0.6497785550261536, 1, 0.10030661611763363`], 
     Hue[0.04788834486376681, 1, 0.9336930609578613], 
     Hue[0.05374761624385649, 1, 0.9255802236623526], 
     Hue[0.037839013053604376`, 1, 0.947607520387317], 
     Hue[0.026736588440281706`, 1, 0.962980108313456], 
     Hue[0.6499859139002138, 1, 0.10001950383047337`], 
     Hue[0.6499577357503808, 1, 0.1000585197302419], 
     Hue[0.6498142629379849, 1, 0.10025717439355937`], 
     Hue[0.02217120486741264, 1, 0.9693014086451209], 
     Hue[0.6497154324783988, 1, 0.10039401656837094`], 
     Hue[0.6494073667314323, 1, 0.10082056914109375`], 
     Hue[0.058179531136253626`, 1, 0.9194437261190335], 
     Hue[0.04019540142111244, 1, 0.9443448288015366], 
     Hue[0.039651798830714347`, 1, 0.9450975093113186], 
     Hue[0.07139996894324296, 1, 0.9011385045401252], 
     Hue[0.08345814579525113, 1, 0.8844425673604216], 
     Hue[0.04135713562066756, 1, 0.9427362737559987], 
     Hue[0.649870280269064, 1, 0.10017961193514213`], 
     Hue[0.02354419528874674, 1, 0.9674003449848122], 
     Hue[0.10319057337364468`, 1, 0.8571207445595689], 
     Hue[0.0425100912798525, 1, 0.941139873612512], 
     Hue[0.04938890963888931, 1, 0.9316153558846149], 
     Hue[0.07567395866927762, 1, 0.8952206726117695], 
     Hue[0.06944722531893788, 1, 0.9038423034045475], 
     Hue[0.036711901642478395`, 1, 0.9491681361873376], 
     Hue[0.6498471333249413, 1, 0.10021166155008132`], 
     Hue[0.6497362870499251, 1, 0.10036514100779606`], 
     Hue[0.050316172480653676`, 1, 0.9303314534883257], 
     Hue[0.06896806385427046, 1, 0.9045057577402409], 
     Hue[0.6497939549693635, 1, 0.10028529311934285`], 
     Hue[0.6496611332398203, 1, 0.10046920012947962`], 
     Hue[0.03635391922171782, 1, 0.9496638041545447], 
     Hue[0.03264539696911373, 1, 0.9547986811196887], 
     Hue[0.036059555970493595`, 1, 0.950071384040855], 
     Hue[0.035869149617264506`, 1, 0.9503350236068645], 
     Hue[0.6497048688318849, 1, 0.10040864315585159`], 
     Hue[0.6498901466536714, 1, 0.10015210463337815`], 
     Hue[0.6498186381065174, 1, 0.10025111646789898`], 
     Hue[0.03978598399930999, 1, 0.9449117144624939], 
     Hue[0.6498365552980848, 1, 0.10022630804880564`], 
     Hue[0.038614673654424836`, 1, 0.946533528786181], 
     Hue[0.020088516878873475`, 1, 0.9721851304754059], 
     Hue[0.015653825082680095`, 1, 0.978325472962443], 
     Hue[0.060023975321159106`, 1, 0.916889880324549], 
     Hue[0.025001347038836386`, 1, 0.965382750253919], 
     Hue[0.01739294560071014, 1, 0.9759174599374782], 
     Hue[0.008012496150157644, 1, 0.9889057745613202], 
     Hue[0.005050177531512157, 1, 0.9930074464948293], 
     Hue[0.04157789698552705, 1, 0.9424306041738857], 
     Hue[0.029623712922861367`, 1, 0.9589825513375766], 
     Hue[0.025855616238894208`, 1, 0.9641999159769157], 
     Hue[0.03129007252212457, 1, 0.9566752842001351], 
     Hue[0.04457819062810153, 1, 0.9382763514380132], 
     Hue[0.62693511264123, 1, 0.13193599788137383`], 
     Hue[0.6179909146733846, 1, 0.1443202719906982], 
     Hue[0.5823312809395349, 1, 0.19369514946833638`], 
     Hue[0.5992668951906599, 1, 0.17024583742831714`], 
     Hue[0.043191299276561734`, 1, 0.9401966625401453], 
     Hue[0.055169971961415154`, 1, 0.9236108080534252], 
     Hue[0.058095846742392765`, 1, 0.9195595968182254], 
     Hue[0.06531013810271558, 1, 0.9095705780116246], 
     Hue[0.6430924327938393, 1, 0.10956432382391486`], 
     Hue[0.6499700647005079, 1, 0.10004144887621992`], 
     Hue[0.6499273629201392, 1, 0.10010057441826889`], 
     Hue[0.6307482107411515, 1, 0.12665632358917492`], 
     Hue[0.6334596003745704, 1, 0.12290209178905637`], 
     Hue[0.6496680746326979, 1, 0.10045958897011062`], 
     Hue[0.6494912339037838, 1, 0.10070444536399166`], 
     Hue[0.6497951582535709, 1, 0.10028362703351723`], 
     Hue[0.6498866199565994, 1, 0.10015698775240091`], 
     Hue[0.6490777568353736, 1, 0.10127695207409819`], 
     Hue[0.6495720203421957, 1, 0.1005925872184983], 
     Hue[0.6492473421041892, 1, 0.10104214170189191`], 
     Hue[0.6476715861915104, 1, 0.10322395758098561`], 
     Hue[0.6480046067052972, 1, 0.10276285225420388`], 
     Hue[0.6497016837349963, 1, 0.10041305329000517`], 
     Hue[0.6499265332508286, 1, 0.10010172319116037`], 
     Hue[0.6498074952532037, 1, 0.10026654503402575`], 
     Hue[0.6495819733523926, 1, 0.10057880612745639`], 
     Hue[0.6499593879656662, 1, 0.1000562320475391], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6495850589546076, 1, 0.10057453375515878`], 
     Hue[0.6498617680362934, 1, 0.10019139810359387`], 
     Hue[0.6498609885143221, 1, 0.10019247744170792`], 
     Hue[0.6497809043843384, 1, 0.10030336316014682`], 
     Hue[0.6495247053655197, 1, 0.10065810026312673`], 
     Hue[0.6497356018476623, 1, 0.10036608974939062`], 
     Hue[0.6498631232252404, 1, 0.1001895216881286], 
     Hue[0.6497582535865756, 1, 0.10033472580320309`], 
     Hue[0.6497601805994563, 1, 0.10033205763152211`], 
     Hue[0.6493203773838575, 1, 0.10094101593004344`], 
     Hue[0.6498489287214888, 1, 0.10020917561640022`], 
     Hue[0.649747588430293, 1, 0.10034949294267126`], 
     Hue[0.6497387443460223, 1, 0.10036173859781529`], 
     Hue[0.649510936764516, 1, 0.10067716447990095`], 
     Hue[0.6490724421537889, 1, 0.10128431086398472`], 
     Hue[0.6496808121430375, 1, 0.10044195241733275`], 
     Hue[0.6497730421487639, 1, 0.10031424933248079`], 
     Hue[0.6493261797832832, 1, 0.100932981838531], 
     Hue[0.6497317263057001, 1, 0.10037145588441537`], 
     Hue[0.6498312563867796, 1, 0.1002336450029206], 
     Hue[0.6499041713848823, 1, 0.10013268577477841`], 
     Hue[0.64875615486882, 1, 0.10172224710471087`], 
     Hue[0.6486185620563141, 1, 0.10191276022971903`], 
     Hue[0.649107591163377, 1, 0.10123564300455491`], 
     Hue[0.6480335517513598, 1, 0.10272277449811731`], 
     Hue[0.6492578940310508, 1, 0.10102753134162193`], 
     Hue[0.649972456880578, 1, 0.10003813662689198`], 
     Hue[0.6499549361248194, 1, 0.10006239613486548`], 
     Hue[0.6499493595519019, 1, 0.10007011754352053`], 
     Hue[0.6481954122050712, 1, 0.10249866002374763`], 
     Hue[0.6487405611096866, 1, 0.10174383846351087`], 
     Hue[0.6490059371930739, 1, 0.10137639465574386`], 
     Hue[0.6426522449640729, 1, 0.11017381466512988`], 
     Hue[0.6456305903146068, 1, 0.10604995187208299`], 
     Hue[0.6499584473486927, 1, 0.10005753444027171`], 
     Hue[0.6499736013898804, 1, 0.10003655192170419`], 
     Hue[0.6499543602001118, 1, 0.10006319356907603`], 
     Hue[0.6499571420447671, 1, 0.10005934178416864`], 
     Hue[0.6487174560654293, 1, 0.10177583006325175`], 
     Hue[0.6491089660446444, 1, 0.10123373932280014`], 
     Hue[0.649282654856523, 1, 0.10099324712173732`], 
     Hue[0.6435715543526157, 1, 0.1089009247425321], 
     Hue[0.6452164892372619, 1, 0.10662332259456038`], 
     Hue[0.6481694863337752, 1, 0.10253455738400351`], 
     Hue[0.648004756298844, 1, 0.10276264512467753`], 
     Hue[0.6461379122313186, 1, 0.10534750614125132`], 
     Hue[0.6499682298283389, 1, 0.10004398946845386`], 
     Hue[0.6499455342692761, 1, 0.10007541408869461`], 
     Hue[0.6499607017392703, 1, 0.10005441297639495`], 
     Hue[0.6499339928806762, 1, 0.10009139447290992`], 
     Hue[0.6489366532260923, 1, 0.10147232630233373`], 
     Hue[0.6492949437724033, 1, 0.10097623169974936`], 
     Hue[0.6492498691631101, 1, 0.10103864269723213`], 
     Hue[0.6449538012438458, 1, 0.10698704443159805`], 
     Hue[0.6483698440427336, 1, 0.10225713901775353`], 
     Hue[0.6463668838287727, 1, 0.10503046854477624`], 
     Hue[0.6484232917630881, 1, 0.10218313448187798`], 
     Hue[0.6484110006585035, 1, 0.10220015293437971`], 
     Hue[0.6466892324480217, 1, 0.10458413968735455`], 
     Hue[0.6427774484741788, 1, 0.1100004559588293], 
     Hue[0.6488316005130143, 1, 0.1016177839050572], 
     Hue[0.6492168014952406, 1, 0.10108442869889767`], 
     Hue[0.6453883916577562, 1, 0.10638530385849147`], 
     Hue[0.6467150589085305, 1, 0.10454837997280386`], 
     Hue[0.6483464600806986, 1, 0.10228951681134045`], 
     Hue[0.6466346435751965, 1, 0.10465972428049722`], 
     Hue[0.6435563338884175, 1, 0.10892199923142196`], 
     Hue[0.6342254998448534, 1, 0.1218416155994338], 
     Hue[0.6499516518407451, 1, 0.10006694360512226`], 
     Hue[0.6499087375413788, 1, 0.10012636340424477`], 
     Hue[0.6486826571897675, 1, 0.10182401312186046`], 
     Hue[0.6490824891108271, 1, 0.1012703996927009], 
     Hue[0.6492316670456285, 1, 0.10106384562912982`], 
     Hue[0.6452487761118194, 1, 0.10657861769132707`], 
     Hue[0.6465576305080638, 1, 0.10476635775806555`], 
     Hue[0.6471651878231728, 1, 0.10392512455253008`], 
     Hue[0.639531197914759, 1, 0.1144952644257184], 
     Hue[0.642896126188708, 1, 0.10983613296948133`], 
     Hue[0.6489806141061978, 1, 0.10141145739141845`], 
     Hue[0.6491351553669877, 1, 0.1011974771841709], 
     Hue[0.6498353163059316, 1, 0.10022802357640236`], 
     Hue[0.649855376152732, 1, 0.1002002484039095], 
     Hue[0.6497269259539095, 1, 0.10037810252535623`], 
     Hue[0.6454490219864928, 1, 0.10630135417254846`], 
     Hue[0.6486137072549414, 1, 0.10191948226238887`], 
     Hue[0.6464577460926881, 1, 0.10490465925627795`], 
     Hue[0.0755660491217589, 1, 0.8953700858314106], 
     Hue[0.064030522216457, 1, 0.9113423538541365], 
     Hue[0.6160261133838477, 1, 0.1470407660839032], 
     Hue[0.6107083782138782, 1, 0.15440378401155316`], 
     Hue[0.6428879355530601, 1, 0.10984747384960908`], 
     Hue[0.645434060944562, 1, 0.10632206946137575`], 
     Hue[0.6490207432728116, 1, 0.10135589392995326`], 
     Hue[0.6494509749883405, 1, 0.10076018847768248`], 
     Hue[0.6483078564804852, 1, 0.10234296795009745`], 
     Hue[0.6473086521841515, 1, 0.10372648159117492`], 
     Hue[0.6478031905742327, 1, 0.1030417361279854], 
     Hue[0.6495819496113384, 1, 0.10057883899968535`], 
     Hue[0.6496854879980031, 1, 0.1004354781566111], 
     Hue[0.6494067618235331, 1, 0.1008214067058773], 
     Hue[0.6385829129121574, 1, 0.11580827442932048`], 
     Hue[0.6464807432000838, 1, 0.10487281710757633`], 
     Hue[0.6423462072442531, 1, 0.11059755920026496`], 
     Hue[0.050003420073607474`, 1, 0.9307644952826974], 
     Hue[0.059436544565959926`, 1, 0.917703245985594], 
     Hue[0.06413016841551689, 1, 0.9112043821938997], 
     Hue[0.05538351355310178, 1, 0.9233151350803206], 
     Hue[0.04901347769479614, 1, 0.9321351847302822], 
     Hue[0.048328688375398166`, 1, 0.933083354557141], 
     Hue[0.04797342466300469, 1, 0.9335752581589165], 
     Hue[0.04650932665789387, 1, 0.9356024707813777], 
     Hue[0.04035056779816304, 1, 0.9441299830486973], 
     Hue[0.03864366255109697, 1, 0.9464933903138657], 
     Hue[0.03854454940579133, 1, 0.9466306238996735], 
     Hue[0.03701109274635406, 1, 0.9487538715819713], 
     Hue[0.07037948798101712, 1, 0.9025514781801302], 
     Hue[0.05459852344573901, 1, 0.924402044459746], 
     Hue[0.04272996237734361, 1, 0.9408354367082935], 
     Hue[0.04561097569227557, 1, 0.9368463413491569], 
     Hue[0.04423481966231124, 1, 0.9387517881598767], 
     Hue[0.04729627943210246, 1, 0.9345128438632428], 
     Hue[0.04027706469340553, 1, 0.9442317565783616], 
     Hue[0.03262057058349921, 1, 0.954833056115155], 
     Hue[0.015518147992949927`, 1, 0.9785133335482231], 
     Hue[0.018621053909051333`, 1, 0.974217002279775], 
     Hue[0.037262558687354064`, 1, 0.9484056879713559], 
     Hue[0.03714761055532634, 1, 0.9485648469233944], 
     Hue[0.02567665446213263, 1, 0.9644477092062779], 
     Hue[0.025590034981223475`, 1, 0.9645676438721521], 
     Hue[0.01622622705224186, 1, 0.9775329163892036], 
     Hue[0.03279659142060909, 1, 0.9545893349560798], 
     Hue[0.04300380655044578, 1, 0.940456267853229], 
     Hue[0.6355938905863523, 1, 0.11994692072658916`], 
     Hue[0.6402323027383038, 1, 0.11352450390081024`], 
     Hue[0.6474310993506772, 1, 0.10355693936060079`], 
     Hue[0.6484403881708681, 1, 0.10215946253264421`], 
     Hue[0.6458792054570779, 1, 0.10570571552096913`], 
     Hue[0.6408491184985583, 1, 0.11267045130968861`], 
     Hue[0.6439296941013801, 1, 0.1084050389365506], 
     Hue[0.6490918980080681, 1, 0.10125737198882888`], 
     Hue[0.6499571782628429, 1, 0.10005929163606371`], 
     Hue[0.645917001011082, 1, 0.10565338321542496`], 
     Hue[0.6495841989918155, 1, 0.10057572447287083`], 
     Hue[0.6494868151005919, 1, 0.10071056370687281`], 
     Hue[0.6482640021464762, 1, 0.10240368933564836`], 
     Hue[0.11133179594380227`, 1, 0.8458482825393507], 
     Hue[0.14826934081387355`, 1, 0.7947039896423289], 
     Hue[0.12076334004688594`, 1, 0.8327892214735425], 
     Hue[0.10171461656660186`, 1, 0.8591643770616282], 
     Hue[0.06626762766538952, 1, 0.9082448232325375], 
     Hue[0.07505579172519872, 1, 0.8960765960728019], 
     Hue[0.07256972238267712, 1, 0.8995188459316779], 
     Hue[0.06801340411587098, 1, 0.9058275943011017], 
     Hue[0.07247584247820105, 1, 0.8996488334917216], 
     Hue[0.06509228937817846, 1, 0.9098722147071375], 
     Hue[0.04655999542432765, 1, 0.9355323140278541], 
     Hue[0.03957773101089579, 1, 0.9452000647541443], 
     Hue[0.04369632752578356, 1, 0.9394973926566074], 
     Hue[0.045442807008135966`, 1, 0.9370791902964272], 
     Hue[0.04545680645085992, 1, 0.9370598064526555], 
     Hue[0.046946301744385854`, 1, 0.9349974283539272], 
     Hue[0.052739821517888696`, 1, 0.9269756317444617], 
     Hue[0.04759434059041734, 1, 0.9341001437978838], 
     Hue[0.06517195896023997, 1, 0.9097619029781292], 
     Hue[0.02858891040060796, 1, 0.9604153548299275], 
     Hue[0.027306320585482213`, 1, 0.9621912484201016], 
     Hue[0.02462504955162237, 1, 0.9659037775439075], 
     Hue[0.03348486831510589, 1, 0.953636336179084], 
     Hue[0.0588901821137926, 1, 0.918459747842441], 
     Hue[0.6442706692389585, 1, 0.10793291951528822`], 
     Hue[0.6462638309364479, 1, 0.10517315716491828`], 
     Hue[0.6491269451476702, 1, 0.10120884518014896`], 
     Hue[0.6494954847620504, 1, 0.10069855956023784`], 
     Hue[0.6485386714401999, 1, 0.10202337800587705`], 
     Hue[0.6465360989821843, 1, 0.1047961706400525], 
     Hue[0.6478096530539398, 1, 0.10303278807916026`], 
     Hue[0.6498487820026938, 1, 0.10020937876550093`], 
     Hue[0.6497532622750568, 1, 0.10034163684992135`], 
     Hue[0.07198542433866106, 1, 0.9003278739926232], 
     Hue[0.05816798737922846, 1, 0.9194597097826067], 
     Hue[0.10106436155238674`, 1, 0.8600647301582338], 
     Hue[0.05432461090446228, 1, 0.9247813079784368], 
     Hue[0.055281198573898904`, 1, 0.9234568019746014], 
     Hue[0.0648909933460079, 1, 0.910150932290143], 
     Hue[0.06775203232807225, 1, 0.9061894936995922], 
     Hue[0.06350240658921247, 1, 0.9120735908764751], 
     Hue[0.06748646715493833, 1, 0.9065571993239315], 
     Hue[0.06222272202387191, 1, 0.9138454618131004], 
     Hue[0.035943487138394015`, 1, 0.9502320947314544], 
     Hue[0.04903191800087181, 1, 0.9321096519987929], 
     Hue[0.06764055330291541, 1, 0.9063438492728864], 
     Hue[0.06592584328626161, 1, 0.9087180631420992], 
     Hue[0.09740144779360238, 1, 0.8651364569011659], 
     Hue[0.08332860479136328, 1, 0.8846219318273432], 
     Hue[0.07941985846062494, 1, 0.8900340421314424], 
     Hue[0.04281683289072202, 1, 0.9407151544590003], 
     Hue[0.044610575704509436`, 1, 0.9382315105629869], 
     Hue[0.6481098274072621, 1, 0.10261716205148325`], 
     Hue[0.6488637451557483, 1, 0.10157327593819462`], 
     Hue[0.6496345627212257, 1, 0.10050599007830303`], 
     Hue[0.6491309928427883, 1, 0.10120324067921627`], 
     Hue[0.6495110846987906, 1, 0.10067695964782845`], 
     Hue[0.6496636920362295, 1, 0.10046565718060532`], 
     Hue[0.6463301018025237, 1, 0.10508139750419795`], 
     Hue[0.647870683943726, 1, 0.10294828377022552`], 
     Hue[0.6440030309761958, 1, 0.10830349557142113`], 
     Hue[0.6290246026926585, 1, 0.12904285781016522`], 
     Hue[0.6356095365486487, 1, 0.11992525708648644`], 
     Hue[0.05776311269601064, 1, 0.9200203054978314], 
     Hue[0.05170152149366558, 1, 0.9284132779318477], 
     Hue[0.04904923900031388, 1, 0.9320856690764885], 
     Hue[0.04887040719787472, 1, 0.9323332823414043], 
     Hue[0.05762154585497925, 1, 0.9202163211238749], 
     Hue[0.06156482700126309, 1, 0.9147563933828665], 
     Hue[0.03242527937652939, 1, 0.9551034593248054], 
     Hue[0.030882819268045036`, 1, 0.9572391733211684], 
     Hue[0.020524247197141077`, 1, 0.9715818115731892], 
     Hue[0.02155423932916678, 1, 0.9701556686211537], 
     Hue[0.02724629812460988, 1, 0.9622743564428479], 
     Hue[0.026057138405182534`, 1, 0.9639208852851319], 
     Hue[0.021226004092164463`, 1, 0.97061014818008], 
     Hue[0.02044913341612342, 1, 0.971685815269983], 
     Hue[0.038157945903427914`, 1, 0.9471659210567921], 
     Hue[0.03227651539827281, 1, 0.9553094402177761], 
     Hue[0.10268596978189448`, 1, 0.8578194264558383], 
     Hue[0.1046959297352611, 1, 0.8550364049819462], 
     Hue[0.10679475018236773`, 1, 0.852130345901337], 
     Hue[0.0983792616071466, 1, 0.8637825608516432], 
     Hue[0.06994536603819579, 1, 0.9031525701009596], 
     Hue[0.18252848984138847`, 1, 0.7472682448350005], 
     Hue[0.04478137703589258, 1, 0.937995016411841], 
     Hue[0.6397295265473467, 1, 0.11422065554982769`], 
     Hue[0.6431626710751982, 1, 0.10946707081895644`], 
     Hue[0.6489244792002459, 1, 0.10148918264581351`], 
     Hue[0.6482588362609076, 1, 0.10241084210028183`], 
     Hue[0.6495558193019607, 1, 0.10061501942805445`], 
     Hue[0.6491907738775962, 1, 0.1011204669387131], 
     Hue[0.03755253553373672, 1, 0.9480041815686722], 
     Hue[0.030791018605599074`, 1, 0.9573662819307089], 
     Hue[0.021793014519940312`, 1, 0.9698250568185443], 
     Hue[0.023563116164161735`, 1, 0.9673741468496222], 
     Hue[0.02191247370731042, 1, 0.9696596517898778], 
     Hue[0.022554831431917832`, 1, 0.96877023340196], 
     Hue[0.019382017501405002`, 1, 0.97316336038267], 
     Hue[0.08916749316972639, 1, 0.8765373171496096], 
     Hue[0.08858365380384825, 1, 0.8773457101177486], 
     Hue[0.031868012427307524`, 1, 0.9558750597160357], 
     Hue[0.0163004466603468, 1, 0.9774301507779813], 
     Hue[0.014320217925261058`, 1, 0.9801720059496386], 
     Hue[0.017078768913471043`, 1, 0.9763524738121171], 
     Hue[0.01510057494717465, 1, 0.9790915116116042], 
     Hue[0.6489209313432037, 1, 0.10149409506325639`], 
     Hue[0.6481830029663782, 1, 0.10251584204655334`], 
     Hue[0.6493831313235778, 1, 0.10085412585966154`], 
     Hue[0.6497534717813827, 1, 0.10034134676423939`], 
     Hue[0.6495493456568323, 1, 0.10062398293669368`], 
     Hue[0.6429425066011294, 1, 0.10977191393689786`], 
     Hue[0.645364622702828, 1, 0.1064182147191613], 
     Hue[0.045562314771301016`, 1, 0.9369137180089678], 
     Hue[0.03536932920354585, 1, 0.9510270826412441], 
     Hue[0.03205775285907486, 1, 0.9556123421951271], 
     Hue[0.03573544726896427, 1, 0.9505201499352802], 
     Hue[0.031084904009253567`, 1, 0.956959363679495], 
     Hue[0.03039775121758692, 1, 0.9579108060064181], 
     Hue[0.031561733637955225`, 1, 0.9562991380397543], 
     Hue[0.030218723438457107`, 1, 0.9581586906236748], 
     Hue[0.03102684827896318, 1, 0.9570397485368203], 
     Hue[0.03677292170179258, 1, 0.949083646874441], 
     Hue[0.03535626369950884, 1, 0.9510451733391416], 
     Hue[0.029033027153124613`, 1, 0.9598004239418275], 
     Hue[0.02106998885107092, 1, 0.9708261692831325], 
     Hue[0.07503803891746474, 1, 0.8961011768835104], 
     Hue[0.018965691049731892`, 1, 0.9737398123926789], 
     Hue[0.6193397342257524, 1, 0.14245267568741976`], 
     Hue[0.6286364425958294, 1, 0.12958031025192848`], 
     Hue[0.6492641393924392, 1, 0.1010188839181612], 
     Hue[0.6450403224686413, 1, 0.10686724581265053`], 
     Hue[0.6495801476295168, 1, 0.10058133405143829`], 
     Hue[0.6496997489466949, 1, 0.10041573222765326`], 
     Hue[0.6401186297951248, 1, 0.11368189720675036`], 
     Hue[0.04256279271599228, 1, 0.9410669023932415], 
     Hue[0.03638349114745065, 1, 0.9496228584112222], 
     Hue[0.04947508894639108, 1, 0.9314960306896124], 
     Hue[0.053984077668564945`, 1, 0.925252815535833], 
     Hue[0.061488897271427145`, 1, 0.9148615268549469], 
     Hue[0.058540266040311484`, 1, 0.9189442470211071], 
     Hue[0.0557053515561603, 1, 0.9228695132299318], 
     Hue[0.05921265030819167, 1, 0.9180132534194269], 
     Hue[0.061686921144494034`, 1, 0.9145873399537775], 
     Hue[0.060897846490670426`, 1, 0.9156799048590717], 
     Hue[0.017013543490446703`, 1, 0.9764427859363046], 
     Hue[0.024863639153844486`, 1, 0.9655734227100615], 
     Hue[0.015631071753729797`, 1, 0.9783569775717588], 
     Hue[0.013767651810629888`, 1, 0.980937097492974], 
     Hue[0.016820061873037195`, 1, 0.97671068356041], 
     Hue[0.006453677412856296, 1, 0.9910641389668143], 
     Hue[0.004468860753837678, 1, 0.9938123466485325], 
     Hue[0.005951767477189285, 1, 0.9917590911854303], 
     Hue[0.649796600528712, 1, 0.10028163003716803`], 
     Hue[0.6499289039363815, 1, 0.10009844070347187`], 
     Hue[0.6498617342407582, 1, 0.1001914448974118], 
     Hue[0.6462424706496872, 1, 0.10520273294658695`], 
     Hue[0.056905864376537885`, 1, 0.9212072647094091], 
     Hue[0.06032007547870766, 1, 0.9164798954910203], 
     Hue[0.050322931947465066`, 1, 0.9303220942265867], 
     Hue[0.021782399085011894`, 1, 0.9698397551130604], 
     Hue[0.012742495527810371`, 1, 0.982356544653801], 
     Hue[0.013552739675201542`, 1, 0.9812346681420285], 
     Hue[0.013773707512444111`, 1, 0.9809287126750774], 
     Hue[0.012860006230179466`, 1, 0.9821938375274437], 
     Hue[0.007684248493825874, 1, 0.9893602713162412], 
     Hue[0.00849934311854661, 1, 0.9882316787589355], 
     Hue[0.004294375440589304, 1, 0.9940539416976456], 
     Hue[0.004448289738923306, 1, 0.99384082959226], 
     Hue[0.0032786548893642964`, 1, 0.9954603239993418], 
     Hue[0.006043445340893072, 1, 0.9916321526049172], 
     Hue[0.018527860216095315`, 1, 0.974346039700791], 
     Hue[0.006441521158108476, 1, 0.9910809707041576], 
     Hue[0.015010129373017045`, 1, 0.9792167439450533], 
     Hue[0.6492488740040859, 1, 0.10104002060972728`], 
     Hue[0.6497735116761223, 1, 0.10031359921767684`], 
     Hue[0.6497614299181659, 1, 0.10033032780561646`], 
     Hue[0.6460089257649584, 1, 0.1055261027869807], 
     Hue[0.6473441564928454, 1, 0.10367732177913722`], 
     Hue[0.6499398935284747, 1, 0.10008322434518885`], 
     Hue[0.649928624763933, 1, 0.10009882724993903`], 
     Hue[0.6498539383327498, 1, 0.10020223923157723`], 
     Hue[0.6461001154090655, 1, 0.1053998402028323], 
     Hue[0.040431494339919105`, 1, 0.9440179309139581], 
     Hue[0.03227248733051824, 1, 0.9553150175423594], 
     Hue[0.028518488143855603`, 1, 0.9605128625700461], 
     Hue[0.02831369911299164, 1, 0.9607964166127808], 
     Hue[0.07695566318965663, 1, 0.8934460048143216], 
     Hue[0.07066325272287277, 1, 0.9021585731529455], 
     Hue[0.07347407378685233, 1, 0.8982666670643582], 
     Hue[0.07447470581545845, 1, 0.8968811765632113], 
     Hue[0.07808497629999578, 1, 0.8918823405076982], 
     Hue[0.07745849728065701, 1, 0.8927497729960133], 
     Hue[0.078180648851923, 1, 0.8917498708204143], 
     Hue[0.041757016881401765`, 1, 0.9421825920103667], 
     Hue[0.03840569859469045, 1, 0.9468228788688902], 
     Hue[0.04401884806996592, 1, 0.9390508257492779], 
     Hue[0.04090229903438214, 1, 0.9433660474908555], 
     Hue[0.03926924586058522, 1, 0.9456271980391896], 
     Hue[0.01173247527745891, 1, 0.9837550342312108], 
     Hue[0.012644971016653406`, 1, 0.982491578592326], 
     Hue[0.010547311326926767`, 1, 0.985396030470409], 
     Hue[0.002783784509136633, 1, 0.9961455291411955], 
     Hue[0.035547032357981845`, 1, 0.9507810321197174], 
     Hue[0.07378134716390505, 1, 0.8978412116192085], 
     Hue[0.6499339869616807, 1, 0.10009140266844221`], 
     Hue[0.6435619501222906, 1, 0.10891422290759772`], 
     Hue[0.6457866607263631, 1, 0.10583385437888179`], 
     Hue[0.6495188840022943, 1, 0.10066616061220791`], 
     Hue[0.6498717325601041, 1, 0.10017760107062505`], 
     Hue[0.6402755217379462, 1, 0.11346466220899754`], 
     Hue[0.6217337124969, 1, 0.1391379365427538], 
     Hue[0.6296892898798067, 1, 0.12812252170488317`], 
     Hue[0.610666733280488, 1, 0.15446144622701655`], 
     Hue[0.034240719893309124`, 1, 0.9525897724554182], 
     Hue[0.03150590945438114, 1, 0.9563764330631646], 
     Hue[0.025818577807962817`, 1, 0.9642511999582054], 
     Hue[0.031068584403085242`, 1, 0.9569819600572667], 
     Hue[0.07135072151156163, 1, 0.9012066932916838], 
     Hue[0.07525259937979667, 1, 0.8958040931664353], 
     Hue[0.07183801964170988, 1, 0.9005319728037863], 
     Hue[0.06464329887458053, 1, 0.9104938938659654], 
     Hue[0.07501689180249604, 1, 0.8961304575042361], 
     Hue[0.06668559816285413, 1, 0.9076660948514327], 
     Hue[0.036338935107117054`, 1, 0.9496845513901455], 
     Hue[0.03661432067245585, 1, 0.9493032482996765], 
     Hue[0.03439110656469391, 1, 0.9523815447565778], 
     Hue[0.03810276083952602, 1, 0.9472423311452717], 
     Hue[0.03714471196492253, 1, 0.9485688603562611], 
     Hue[0.03258610246900384, 1, 0.9548807811967639], 
     Hue[0.0029304466573317756`, 1, 0.9959424584744637], 
     Hue[0.002256591495968019, 1, 0.9968754886978904], 
     Hue[0.004354508717300587, 1, 0.9939706802375838], 
     Hue[0.006124305259761931, 1, 0.9915201927172527], 
     Hue[0.009093837025002549, 1, 0.9874085333499965], 
     Hue[0.06182413232175599, 1, 0.9143973552467994], 
     Hue[0.6499187572606038, 1, 0.1001124899468564], 
     Hue[0.6496751202160722, 1, 0.10044983354697702`], 
     Hue[0.6493951891473593, 1, 0.1008374304113488], 
     Hue[0.64695115154358, 1, 0.10422148247812016`], 
     Hue[0.6481509063221403, 1, 0.10256028355395957`], 
     Hue[0.6485801021793048, 1, 0.10196601236711642`], 
     Hue[0.029800931201089065`, 1, 0.9587371721831074], 
     Hue[0.05284684419351693, 1, 0.9268274465012842], 
     Hue[0.035703293451310736`, 1, 0.9505646706058775], 
     Hue[0.035521130093860376`, 1, 0.9508168967931164], 
     Hue[0.04836720484908963, 1, 0.9330300240551066], 
     Hue[0.04419520294628965, 1, 0.9388066420743681], 
     Hue[0.047559161398734506`, 1, 0.9341488534479061], 
     Hue[0.04631960670792323, 1, 0.9358651599428756], 
     Hue[0.04945652161743286, 1, 0.9315217392989391], 
     Hue[0.05155812905766821, 1, 0.928611821304767], 
     Hue[0.045325563611229414`, 1, 0.9372415273075285], 
     Hue[0.046027827253624976`, 1, 0.9362691622642115], 
     Hue[0.014972555042922497`, 1, 0.9792687699405689], 
     Hue[0.01911865051254713, 1, 0.9735280223672423], 
     Hue[0.09409839216485139, 1, 0.869709918540975], 
     Hue[0.6447514169265784, 1, 0.10726726887089141`], 
     Hue[0.6467748961798084, 1, 0.10446552836641908`], 
     Hue[0.6499097928190916, 1, 0.10012490225048869`], 
     Hue[0.648279389066667, 1, 0.1023823843692303], 
     Hue[0.6471768627220092, 1, 0.1039089593079873], 
     Hue[0.6489886889727547, 1, 0.10140027680695501`], 
     Hue[0.6397445596636103, 1, 0.11419984046577035`], 
     Hue[0.6431228898692026, 1, 0.10952215248879636`], 
     Hue[0.645099054763858, 1, 0.10678592417311969`], 
     Hue[0.6137637429933227, 1, 0.15017327893232246`], 
     Hue[0.6080317900380768, 1, 0.15810982917804756`], 
     Hue[0.03665234702087128, 1, 0.9492505964326399], 
     Hue[0.043584002569695524`, 1, 0.9396529195188831], 
     Hue[0.042631985892674695`, 1, 0.9409710964562966], 
     Hue[0.041552250105474475`, 1, 0.9424661152385737], 
     Hue[0.04298677791736105, 1, 0.940479845960577], 
     Hue[0.043574096913637894`, 1, 0.9396666350426552], 
     Hue[0.07415626089419625, 1, 0.8973221003003437], 
     Hue[0.056476579765261437`, 1, 0.9218016587865611], 
     Hue[0.057696038950466266`, 1, 0.920113176837816], 
     Hue[0.054752873071091, 1, 0.924188329593874], 
     Hue[0.6497581450692562, 1, 0.10033487605795298`], 
     Hue[0.6476182914904347, 1, 0.10329775024401348`], 
     Hue[0.6488998348077983, 1, 0.10152330565074087`], 
     Hue[0.6499419099647096, 1, 0.10008043235655607`], 
     Hue[0.6498785343536069, 1, 0.10016818320269816`], 
     Hue[0.6499413558036876, 1, 0.10008119965643263`], 
     Hue[0.6498836742197627, 1, 0.10016106646494395`], 
     Hue[0.64487675995091, 1, 0.10709371699104768`], 
     Hue[0.6422265448290051, 1, 0.11076324562137753`], 
     Hue[0.646717744017108, 1, 0.10454466213015809`], 
     Hue[0.6479260270323114, 1, 0.10287165487833815`], 
     Hue[0.6269265205646809, 1, 0.13194789460274953`], 
     Hue[0.6335148983635394, 1, 0.12282552534279173`], 
     Hue[0.0633644631380188, 1, 0.9122645895012048], 
     Hue[0.07438285089735319, 1, 0.8970083602959725], 
     Hue[0.06569258886889817, 1, 0.9090410307969101], 
     Hue[0.6487025826768295, 1, 0.10179642398592847`], 
     Hue[0.6431846726034752, 1, 0.10943660716441889`], 
     Hue[0.6492247496918222, 1, 0.1010734235036309], 
     Hue[0.6479464775082973, 1, 0.10284333883466538`], 
     Hue[0.6467038336222727, 1, 0.10456392267685322`], 
     Hue[0.6487603782979934, 1, 0.10171639927970157`], 
     Hue[0.6387562509282643, 1, 0.11556826794548027`], 
     Hue[0.6422879845941496, 1, 0.1106781751773313], 
     Hue[0.6468585039422808, 1, 0.1043497637722266], 
     Hue[0.6472220976386766, 1, 0.10384632634644789`], 
     Hue[0.6489526506295077, 1, 0.10145017605145097`], 
     Hue[0.6490489052261195, 1, 0.10131690045614232`], 
     Hue[0.6468024899316948, 1, 0.10442732163303811`], 
     Hue[0.6456266501735372, 1, 0.10605540745202546`], 
     Hue[0.6492165092510298, 1, 0.10108483334472805`], 
     Hue[0.6477135139744667, 1, 0.10316590372766139`], 
     Hue[0.6488743758589024, 1, 0.1015585565030582], 
     Hue[0.6494622226127257, 1, 0.10074461484391825`], 
     Hue[0.6494770706993216, 1, 0.10072405595478552`], 
     Hue[0.6468998028787286, 1, 0.10429258062945271`], 
     Hue[0.6389935304010697, 1, 0.11523972713698051`], 
     Hue[0.6418234646271941, 1, 0.11132135667003895`], 
     Hue[0.6492660828990564, 1, 0.1010161929089989], 
     Hue[0.6477821957498783, 1, 0.10307080588478393`], 
     Hue[0.648904579497495, 1, 0.10151673608039151`], 
     Hue[0.6478357769321603, 1, 0.10299661655547036`], 
     Hue[0.6478132213228475, 1, 0.10302784739913425`], 
     Hue[0.64898750788055, 1, 0.10140191216539228`], 
     Hue[0.6494772180453221, 1, 0.1007238519372463], 
     Hue[0.6495188020012523, 1, 0.10066627415211216`], 
     Hue[0.6494971022653871, 1, 0.10069631994023329`], 
     Hue[0.6392006260079067, 1, 0.11495297937366758`], 
     Hue[0.6419848888918036, 1, 0.1110978461498105], 
     Hue[0.6396471273634698, 1, 0.11433474672750327`], 
     Hue[0.6423544298648308, 1, 0.1105861740333112], 
     Hue[0.6493395857869937, 1, 0.1009144196795473], 
     Hue[0.6478575134462948, 1, 0.10296651984359188`], 
     Hue[0.6490013072310329, 1, 0.10138280537241598`], 
     Hue[0.6469496433063704, 1, 0.10422357080656415`], 
     Hue[0.6478747152858508, 1, 0.10294270191189896`], 
     Hue[0.6478637811424055, 1, 0.10295784149513093`], 
     Hue[0.6490137210959837, 1, 0.10136561694402266`], 
     Hue[0.6495545267883425, 1, 0.10061680906229509`], 
     Hue[0.6495709774902239, 1, 0.10059403116738233`], 
     Hue[0.6495651936551425, 1, 0.10060203955441799`], 
     Hue[0.6499802984840596, 1, 0.10002727902207142`], 
     Hue[0.6499660615569638, 1, 0.10004699169035791`], 
     Hue[0.6405210148027639, 1, 0.11312474873463456`], 
     Hue[0.6430880530556518, 1, 0.10957038807678984`], 
     Hue[0.649352976382181, 1, 0.10089587885544171`], 
     Hue[0.6470291655017886, 1, 0.10411346315136967`], 
     Hue[0.647939478799539, 1, 0.10285302935448465`], 
     Hue[0.6490206320604894, 1, 0.10135604791624538`], 
     Hue[0.6472361180563594, 1, 0.10382691346042552`], 
     Hue[0.6481055256321482, 1, 0.10262311835548713`], 
     Hue[0.649105378839976, 1, 0.10123870622157176`], 
     Hue[0.649573963734973, 1, 0.10058989636696043`], 
     Hue[0.6495805460063098, 1, 0.10058078245280183`], 
     Hue[0.6495756553138287, 1, 0.10058755418085259`], 
     Hue[0.6498441808156323, 1, 0.10021574963989366`], 
     Hue[0.6497707323824213, 1, 0.10031744747049355`], 
     Hue[0.648883744939926, 1, 0.10154558392933336`], 
     Hue[0.6498047512778485, 1, 0.1002703443845175], 
     Hue[0.6471014987442669, 1, 0.10401330943101504`], 
     Hue[0.6476202126696591, 1, 0.1032950901497029], 
     Hue[0.6484005855363204, 1, 0.10221457387278723`], 
     Hue[0.6494615070488619, 1, 0.1007456056246528], 
     Hue[0.6491633037212793, 1, 0.1011585025397671], 
     Hue[0.6481607607600677, 1, 0.10254663894759866`], 
     Hue[0.6487963694526842, 1, 0.10166656537320655`], 
     Hue[0.6496069168225992, 1, 0.10054426901486277`], 
     Hue[0.6496610154561011, 1, 0.10046936321462933`], 
     Hue[0.649743555965862, 1, 0.10035507635496044`], 
     Hue[0.6495372825876065, 1, 0.10064068564792952`], 
     Hue[0.6487772894669718, 1, 0.10169298381496221`], 
     Hue[0.6484820534946345, 1, 0.10210177208435224`], 
     Hue[0.6488802533948681, 1, 0.10155041837633656`], 
     Hue[0.6492875162378543, 1, 0.10098651597835556`], 
     Hue[0.648518117759945, 1, 0.10205183694776858`], 
     Hue[0.6491888435515394, 1, 0.10112313969786862`], 
     Hue[0.6495012768885314, 1, 0.10069053969280273`], 
     Hue[0.6483856221051956, 1, 0.1022352924697292], 
     Hue[0.6489690407448532, 1, 0.10142748204558791`], 
     Hue[0.6487437550749572, 1, 0.10173941605005939`], 
     Hue[0.6492026642949891, 1, 0.10110400328386132`], 
     Hue[0.6492308188856877, 1, 0.10106502000443249`], 
     Hue[0.6495265066697994, 1, 0.10065560614950862`], 
     Hue[0.6497396958068138, 1, 0.10036042119056554`], 
     Hue[0.649635981221561, 1, 0.10050402600091565`], 
     Hue[0.6495123254644481, 1, 0.10067524166461034`], 
     Hue[0.6497889624633891, 1, 0.10029220581992276`], 
     Hue[0.6493738601243053, 1, 0.10086696290480811`], 
     Hue[0.6493595603190053, 1, 0.1008867626352235], 
     Hue[0.6497643638545932, 1, 0.10032626543210166`], 
     Hue[0.6498389750367888, 1, 0.10022295764136936`], 
     Hue[0.6497294347477206, 1, 0.1003746288108484], 
     Hue[0.6499006879981659, 1, 0.10013750892561647`], 
     Hue[0.6499347718763797, 1, 0.10009031586347424`], 
     Hue[0.6498010047587366, 1, 0.10027553187251854`], 
     Hue[0.6498252539821568, 1, 0.1002419560247059], 
     Hue[0.6497210953751235, 1, 0.10038617563444449`], 
     Hue[0.6492195675657059, 1, 0.10108059875517658`], 
     Hue[0.6491094047673516, 1, 0.10123313186059024`], 
     Hue[0.6496734903539132, 1, 0.10045209027919712`], 
     Hue[0.649769532827646, 1, 0.10031910839249007`], 
     Hue[0.6496102523155612, 1, 0.10053965063999215`], 
     Hue[0.6495635339976475, 1, 0.10060433754171888`], 
     Hue[0.6498483913224488, 1, 0.10020991970737862`], 
     Hue[0.6499050542344526, 1, 0.10013146336768118`], 
     Hue[0.6498335960433566, 1, 0.10023040547842946`], 
     Hue[0.6499435020167722, 1, 0.10007822797677693`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.059579490631567755`, 1, 0.917505320663983], 
     Hue[0.07991536854907277, 1, 0.8893479512397454], 
     Hue[0.6499801979499172, 1, 0.10002741822319161`], 
     Hue[0.06835008551879307, 1, 0.9053614200509019], 
     Hue[0.059859085857839056`, 1, 0.9171181888122228], 
     Hue[0.044143419887211155`, 1, 0.9388783416946307], 
     Hue[0.04416349555757948, 1, 0.9388505446125822], 
     Hue[0.021823794159580467`, 1, 0.9697824388559655], 
     Hue[0.011580605128459487`, 1, 0.9839653159759792], 
     Hue[0.016543659263464017`, 1, 0.9770933948659728], 
     Hue[0.041073345351872126`, 1, 0.9431292141281771], 
     Hue[0.054100303467128574`, 1, 0.9250918875070528], 
     Hue[0.055204035692738795`, 1, 0.923563642886977], 
     Hue[0.04886542001602534, 1, 0.9323401876701188], 
     Hue[0.03605780861198271, 1, 0.9500738034603317], 
     Hue[0.029444839658297806`, 1, 0.9592302220115877], 
     Hue[0.03628870663934147, 1, 0.9497540984993734], 
     Hue[0.0456221645194429, 1, 0.9368308491269252], 
     Hue[0.06552882025387119, 1, 0.9092677873407937], 
     Hue[0.019615928730785548`, 1, 0.9728394832958355], 
     Hue[0.020591929400534337`, 1, 0.9714880977531063], 
     Hue[0.018603951798201845`, 1, 0.9742406821255667], 
     Hue[0.019531735361918323`, 1, 0.9729560587296515], 
     Hue[0.08991391816625294, 1, 0.8755038056159575], 
     Hue[0.09716744199989646, 1, 0.8654604649232203], 
     Hue[0.019994236480676997`, 1, 0.9723156725652164], 
     Hue[0.03200310512431892, 1, 0.9556880082894045], 
     Hue[0.0327869530174032, 1, 0.9546026804374418], 
     Hue[0.649679594467542, 1, 0.10044363842955735`], 
     Hue[0.6489631645726089, 1, 0.10143561828407999`], 
     Hue[0.648886387076701, 1, 0.10154192558610639`], 
     Hue[0.6496513958889447, 1, 0.10048268261530731`], 
     Hue[0.05042065659901018, 1, 0.9301867831706013], 
     Hue[0.0425353931905641, 1, 0.9411048401976805], 
     Hue[0.045268657461306816`, 1, 0.9373203204381905], 
     Hue[0.014196562385874523`, 1, 0.980343221311866], 
     Hue[0.035082716257188395`, 1, 0.9514239313362006], 
     Hue[0.042277060143964484`, 1, 0.9414625321083568], 
     Hue[0.05923196659415042, 1, 0.9179865077927147], 
     Hue[0.05970354397820676, 1, 0.9173335544917137], 
     Hue[0.06011599258817235, 1, 0.9167624718009921], 
     Hue[0.03250321453015437, 1, 0.9549955491120939], 
     Hue[0.03197948264339456, 1, 0.9557207163399152], 
     Hue[0.014161872424076738`, 1, 0.980391253566663], 
     Hue[0.008041040835682911, 1, 0.9888662511505929], 
     Hue[0.6470590415077843, 1, 0.10407209637383717`], 
     Hue[0.005527247627587273, 1, 0.9923468879002637], 
     Hue[0.009561766672235517, 1, 0.98676063076152], 
     Hue[0.011236584533758087`, 1, 0.9844416521840272], 
     Hue[0.0644638106120069, 1, 0.9107424160756827], 
     Hue[0.01968158577020529, 1, 0.9727485735489465], 
     Hue[0.0026142669520616835`, 1, 0.9963802457586838], 
     Hue[0.004255523836018571, 1, 0.9941077362270513], 
     Hue[0.0012827322183663892`, 1, 0.9982239092361082], 
     Hue[0.001334871515964564, 1, 0.9981517163625105], 
     Hue[0.05627833916928371, 1, 0.9220761457656071], 
     Hue[0.0555203731793269, 1, 0.9231256371363167], 
     Hue[0.03073202843046341, 1, 0.9574479606347429], 
     Hue[0.03423277225244492, 1, 0.9526007768812301], 
     Hue[0.06863953885658214, 1, 0.9049606385062708], 
     Hue[0.04354582869684365, 1, 0.9397057756505242], 
     Hue[0.04757107024400009, 1, 0.9341323642775383], 
     Hue[0.0687036647584458, 1, 0.9048718487959981], 
     Hue[0.0608033037490352, 1, 0.9158108101936436], 
     Hue[0.6494350140329945, 1, 0.1007822882620076], 
     Hue[0.6481132194741939, 1, 0.10261246534342383`], 
     Hue[0.6487949442628547, 1, 0.10166853871297048`], 
     Hue[0.6496618088915397, 1, 0.10046826461171432`], 
     Hue[0.6498118503627555, 1, 0.1002605148823387], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6494810203440681, 1, 0.1007185872159058], 
     Hue[0.65, 1, 0.1], 
     Hue[0.648805466653725, 1, 0.10165396924868857`], 
     Hue[0.6470795325284311, 1, 0.10404372419140316`], 
     Hue[0.648895988112801, 1, 0.10152863184381401`], 
     Hue[0.6449769906791938, 1, 0.10695493598265479`], 
     Hue[0.6492496081090583, 1, 0.10103900415668851`], 
     Hue[0.6458459663797931, 1, 0.1057517388587481], 
     Hue[0.6492751776280958, 1, 0.10100360020725196`], 
     Hue[0.6466307483646522, 1, 0.1046651176489432], 
     Hue[0.6491364383900751, 1, 0.10119570069066529`], 
     Hue[0.6466879954421647, 1, 0.10458585246469508`], 
     Hue[0.6470917771528514, 1, 0.10402677009605199`], 
     Hue[0.07375320339045754, 1, 0.897880179920905], 
     Hue[0.0784373552565909, 1, 0.8913944311831817], 
     Hue[0.050740040412396215`, 1, 0.9297445594289898], 
     Hue[0.04459897843538074, 1, 0.938247568320242], 
     Hue[0.0367150598966941, 1, 0.949163763219962], 
     Hue[0.05777540031472894, 1, 0.9200032918719139], 
     Hue[0.056861250676672026`, 1, 0.9212690375246079], 
     Hue[0.04643807040643644, 1, 0.9357011332833958], 
     Hue[0.031775424927830254`, 1, 0.9560032577922349], 
     Hue[0.023934561540597032`, 1, 0.9668598378668657], 
     Hue[0.032334315482239084`, 1, 0.9552294093322843], 
     Hue[0.6431790587027628, 1, 0.10944438025771311`], 
     Hue[0.6499168881801375, 1, 0.10011507790442499`], 
     Hue[0.062031813798055446`, 1, 0.9141097962796156], 
     Hue[0.06631219708045799, 1, 0.9081831117347504], 
     Hue[0.06419863949136984, 1, 0.9111095760888724], 
     Hue[0.06911697246307369, 1, 0.9042995765895903], 
     Hue[0.06429581960137787, 1, 0.9109750190134768], 
     Hue[0.04440019207439572, 1, 0.9385228109739137], 
     Hue[0.04526382935698381, 1, 0.9373270055057148], 
     Hue[0.047711170633804256`, 1, 0.9339383791224249], 
     Hue[0.05100253624017459, 1, 0.9293811036674505], 
     Hue[0.016362192392428532`, 1, 0.9773446566874066], 
     Hue[0.61296819705229, 1, 0.15127480408144464`], 
     Hue[0.6475245130660026, 1, 0.10342759729322729`], 
     Hue[0.5501894332251758, 1, 0.2381992463036028], 
     Hue[0.07750373986523107, 1, 0.8926871294173724], 
     Hue[0.0634266254423097, 1, 0.9121785186183404], 
     Hue[0.037109347332046294`, 1, 0.9486178267710128], 
     Hue[0.03932832294888189, 1, 0.9455453989938558], 
     Hue[0.08225260521931466, 1, 0.8861117773886412], 
     Hue[0.044439191137106704`, 1, 0.9384688122716983], 
     Hue[0.5357742446310274, 1, 0.2581587382031929], 
     Hue[0.05558665496840243, 1, 0.9230338623514427], 
     Hue[0.05014393239658754, 1, 0.930569939758571], 
     Hue[0.0654356344907332, 1, 0.9093968137820618], 
     Hue[0.03132660246899954, 1, 0.956624704273693], 
     Hue[0.02686741759309219, 1, 0.9627989602557185], 
     Hue[0.018121970975972568`, 1, 0.974908040187115], 
     Hue[0.030438474470317, 1, 0.9578544199641764], 
     Hue[0.02889030182105179, 1, 0.9599980436323898], 
     Hue[0.030867689416017252`, 1, 0.9572601223470529], 
     Hue[0.10572585158838455`, 1, 0.85361035933916], 
     Hue[0.10065202190466727`, 1, 0.860635661978153], 
     Hue[0.0861270321617017, 1, 0.8807471862376437], 
     Hue[0.08535571406913256, 1, 0.8818151651350472], 
     Hue[0.0866546854157999, 1, 0.8800165894242771], 
     Hue[0.05143403454843276, 1, 0.9287836444714008], 
     Hue[0.050557058991333226`, 1, 0.9299979183196924], 
     Hue[0.051414691146338676`, 1, 0.9288104276435312], 
     Hue[0.03134888224562593, 1, 0.9565938553522103], 
     Hue[0.022510051565530653`, 1, 0.9688322362938806], 
     Hue[0.037294778274239215`, 1, 0.9483610762356687], 
     Hue[0.04158007353321547, 1, 0.9424275904924709], 
     Hue[0.062352884289116006`, 1, 0.9136652371381471], 
     Hue[0.04417157646806369, 1, 0.9388393556596041], 
     Hue[0.035174895733136036`, 1, 0.9512962982156579], 
     Hue[0.015624443506459085`, 1, 0.9783661551449028], 
     Hue[0.6476204233118503, 1, 0.10329479849128413`], 
     Hue[0.033644412431132475`, 1, 0.9534154289415089], 
     Hue[0.03392337783639643, 1, 0.953029169149605], 
     Hue[0.031054160874945058`, 1, 0.95700193109623], 
     Hue[0.0321229434659025, 1, 0.9555220782779812], 
     Hue[0.03199557741053727, 1, 0.9556984312777176], 
     Hue[0.04041895045955868, 1, 0.944035299363688], 
     Hue[0.03467807894189745, 1, 0.951984198388142], 
     Hue[0.021270155849435257`, 1, 0.970549014977705], 
     Hue[0.016612298763743816`, 1, 0.9769983555578932], 
     Hue[0.07635709029586335, 1, 0.8942747980518816], 
     Hue[0.6486568734066076, 1, 0.10185971374469724`], 
     Hue[0.03278078908342108, 1, 0.9546112151152631], 
     Hue[0.0544185541052864, 1, 0.9246512327772958], 
     Hue[0.05381903638105001, 1, 0.925481334241623], 
     Hue[0.0400094529739522, 1, 0.9446022958822201], 
     Hue[0.04940100927541702, 1, 0.9315986025417302], 
     Hue[0.0514207679110803, 1, 0.9288020136615811], 
     Hue[0.051060381112942865`, 1, 0.9293010107666945], 
     Hue[0.024996948746884184`, 1, 0.9653888401966219], 
     Hue[0.023609648823418317`, 1, 0.9673097170137286], 
     Hue[0.04486300323179693, 1, 0.9378819955252042], 
     Hue[0.046134536065497, 1, 0.9361214116016194], 
     Hue[0.00727662961112252, 1, 0.989924666692292], 
     Hue[0.0081990129163243, 1, 0.9886475205773971], 
     Hue[0.009092937083550634, 1, 0.9874097794227761], 
     Hue[0.02233264598644147, 1, 0.9690778747880041], 
     Hue[0.010629391266623212`, 1, 0.9852823813231371], 
     Hue[0.6443382606131893, 1, 0.10783933145866098`], 
     Hue[0.6440621124237487, 1, 0.10822169049019417`], 
     Hue[0.6495207196094057, 1, 0.10066361900236129`], 
     Hue[0.07720710320134672, 1, 0.8930978571058276], 
     Hue[0.026649166275201086`, 1, 0.9631011543881831], 
     Hue[0.013374163276568707`, 1, 0.9814819277709049], 
     Hue[0.01049063366258518, 1, 0.9854745072364205], 
     Hue[0.018700077655620206`, 1, 0.974107584784526], 
     Hue[0.6495553832057549, 1, 0.10061562325357012`], 
     Hue[0.029499804175961097`, 1, 0.959154117294823], 
     Hue[0.07512868826975927, 1, 0.8959756623957179], 
     Hue[0.0733414966200786, 1, 0.8984502354491218], 
     Hue[0.026675118528509234`, 1, 0.9630652204989872], 
     Hue[0.0003431685737003143, 1, 0.9995248435133379], 
     Hue[0.011945692581946443`, 1, 0.983459810271151], 
     Hue[0.025695616118400988`, 1, 0.9644214546052909], 
     Hue[0.034811351694747916`, 1, 0.9517996668841953], 
     Hue[0.04011714917408804, 1, 0.9444531780666473], 
     Hue[0.6492464852129024, 1, 0.10104332816675056`], 
     Hue[0.026374019796105985`, 1, 0.9634821264361609], 
     Hue[0.04723741358707256, 1, 0.9345943504178995], 
     Hue[0.04668223985461695, 1, 0.9353630525089919], 
     Hue[0.009135114776081199, 1, 0.9873513795408106], 
     Hue[0.009146228164818249, 1, 0.9873359917717901], 
     Hue[0.006688394503995609, 1, 0.9907391460713908], 
     Hue[0.047483390164286154`, 1, 0.9342537674648345], 
     Hue[0.044713929961099796`, 1, 0.9380884046692465], 
     Hue[0.048491229835744276`, 1, 0.9328582971505078], 
     Hue[0.04785035766481083, 1, 0.9337456586179542], 
     Hue[0.05872955173322958, 1, 0.9186821591386052], 
     Hue[0.06630241977394802, 1, 0.9081966495437642], 
     Hue[0.6495495459296265, 1, 0.1006237056359018], 
     Hue[0.646164169880077, 1, 0.10531114939681657`], 
     Hue[0.05824484133233132, 1, 0.919353296616772], 
     Hue[0.042178704615433715`, 1, 0.9415987166863224], 
     Hue[0.05793378814589589, 1, 0.9197839856441442], 
     Hue[0.04871626051852862, 1, 0.9325467162051142], 
     Hue[0.043684630492171306`, 1, 0.9395135885493012], 
     Hue[0.048308576182292895`, 1, 0.933111202209133], 
     Hue[0.07010999087383551, 1, 0.9029246280208432], 
     Hue[0.030172352293026283`, 1, 0.9582228968250405], 
     Hue[0.033697724834832576`, 1, 0.9533416117671549], 
     Hue[0.648067552394353, 1, 0.10267569668474205`], 
     Hue[0.638955558086547, 1, 0.11529230418785798`], 
     Hue[0.054712431566668385`, 1, 0.9242443255230745], 
     Hue[0.11927171151066163`, 1, 0.8348545532929301], 
     Hue[0.06525200032365575, 1, 0.9096510764749383], 
     Hue[0.0794022182623646, 1, 0.8900584670213413], 
     Hue[0.07864231335424166, 1, 0.891110643047973], 
     Hue[0.6499689182748085, 1, 0.10004303623488058`], 
     Hue[0.6499371254476073, 1, 0.10008705707254383`], 
     Hue[0.6492650272110092, 1, 0.10101765463091035`], 
     Hue[0.6448027571463951, 1, 0.10719618241268374`], 
     Hue[0.21582917949940678`, 1, 0.7011595976162059], 
     Hue[0.6489657557679257, 1, 0.10143203047517983`], 
     Hue[0.6499626995896192, 1, 0.10005164672206576`], 
     Hue[0.5474728442722577, 1, 0.24196067716148936`], 
     Hue[0.6490110423907637, 1, 0.10136932592048105`], 
     Hue[0.6499944308396645, 1, 0.10000771114508], 
     Hue[0.6499835761401124, 1, 0.10002274072907517`], 
     Hue[0.6499712098828667, 1, 0.10003986323910773`], 
     Hue[0.6490634073725924, 1, 0.10129682056102592`], 
     Hue[0.6387875046297276, 1, 0.11552499358960805`], 
     Hue[0.6493241434031858, 1, 0.10093580144174275`], 
     Hue[0.649837087938245, 1, 0.10022557054704546`], 
     Hue[0.6495311088193251, 1, 0.10064923394247301`], 
     Hue[0.6496576456724601, 1, 0.10047402906890147`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6492324471003426, 1, 0.10106276555337193`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6494744179209362, 1, 0.10072772903254985`], 
     Hue[0.6495157415619276, 1, 0.10067051168348493`], 
     Hue[0.6492319225377491, 1, 0.10106349187080896`], 
     Hue[0.6499983576164775, 1, 0.10000227406949275`], 
     Hue[0.6499951145522576, 1, 0.10000676446610489`], 
     Hue[0.6499852733484728, 1, 0.10002039074826856`], 
     Hue[0.6493915076499502, 1, 0.1008425278692997], 
     Hue[0.6498771498255334, 1, 0.10017010024156929`], 
     Hue[0.6499981588583915, 1, 0.10000254927299634`], 
     Hue[0.6499940486503908, 1, 0.10000824033022811`], 
     Hue[0.6499821845563837, 1, 0.10002466753731493`], 
     Hue[0.6467849599430608, 1, 0.10445159392499268`], 
     Hue[0.648436374078501, 1, 0.10216502050669107`], 
     Hue[0.6498687607024498, 1, 0.10018171595045412`], 
     Hue[0.6499979793996546, 1, 0.10000279775432443`], 
     Hue[0.6499937478811818, 1, 0.10000865677990223`], 
     Hue[0.6499811204975277, 1, 0.10002614084957712`], 
     Hue[0.64661169582597, 1, 0.10469149808711846`], 
     Hue[0.6483740055944929, 1, 0.10225137686916377`], 
     Hue[0.6490770635417232, 1, 0.10127791201915247`], 
     Hue[0.6496201813435399, 1, 0.10052590275509855`], 
     Hue[0.6499979358625592, 1, 0.10000285803645664`], 
     Hue[0.6499925437739636, 1, 0.10001032400528108`], 
     Hue[0.6499767127306578, 1, 0.1000322439113969], 
     Hue[0.6498290153849048, 1, 0.10023674792859341`], 
     Hue[0.649999130900196, 1, 0.10000120336895937`], 
     Hue[0.6499956203092773, 1, 0.10000606418715466`], 
     Hue[0.6499851658503346, 1, 0.1000205395918444], 
     Hue[0.649994232474425, 1, 0.10000798580464228`], 
     Hue[0.6499729417531572, 1, 0.10003746526485924`], 
     Hue[0.6499190526510759, 1, 0.10011208094466428`], 
     Hue[0.09877508489427256, 1, 0.8632344978386995], 
     Hue[0.09126055660193944, 1, 0.8736392293203916], 
     Hue[0.07210591494029839, 1, 0.9001610408518945], 
     Hue[0.04818075755504958, 1, 0.9332881818468544], 
     Hue[0.12691957480525362`, 1, 0.8242652041158026], 
     Hue[0.08575204409787285, 1, 0.8812664004798684], 
     Hue[0.05562672164688942, 1, 0.9229783854119993], 
     Hue[0.042774601531233136`, 1, 0.9407736286490618], 
     Hue[0.03164783887468159, 1, 0.9561799154042869], 
     Hue[0.03405874906703321, 1, 0.9528417320610308], 
     Hue[0.030144827115665795`, 1, 0.958261008609078], 
     Hue[0.09396364741331231, 1, 0.8698964881969522], 
     Hue[0.08652712395144346, 1, 0.8801932129903091], 
     Hue[0.061214049624003786`, 1, 0.9152420851359947], 
     Hue[0.044776166094338654`, 1, 0.9380022315616849], 
     Hue[0.12417068049173496`, 1, 0.8280713654729823], 
     Hue[0.12565152524385292`, 1, 0.826020965046973], 
     Hue[0.024479295730701955`, 1, 0.9661055905267204], 
     Hue[0.07792226939801372, 1, 0.8921076269873657], 
     Hue[0.04616903522250149, 1, 0.9360736435380748], 
     Hue[0.2357298120721792, 1, 0.6736048755923673], 
     Hue[0.08889129383143379, 1, 0.8769197470026301], 
     Hue[0.15421048826467976`, 1, 0.7864777854796742], 
     Hue[0.08714012989437792, 1, 0.8793444355308614], 
     Hue[0.5752974624665456, 1, 0.20343428273862924`], 
     Hue[0.6065914183080049, 1, 0.16010419003507015`], 
     Hue[0.6205648774984954, 1, 0.1407563234636217], 
     Hue[0.05131693633698631, 1, 0.9289457804564806], 
     Hue[0.04480344596790242, 1, 0.9379644594290583], 
     Hue[0.031118335229574634`, 1, 0.956913074297512], 
     Hue[0.5883867835153163, 1, 0.1853106074403314], 
     Hue[0.6178304300221001, 1, 0.14454248150786134`], 
     Hue[0.6287607232657988, 1, 0.12940822932427856`], 
     Hue[0.051707736971505214`, 1, 0.9284046718856083], 
     Hue[0.043056295145973644`, 1, 0.9403835913363442], 
     Hue[0.6109655437967231, 1, 0.15404770858915268`], 
     Hue[0.6093453287086855, 1, 0.15629108332643543`], 
     Hue[0.04939680894504084, 1, 0.9316044183837896], 
     Hue[0.05093701857667321, 1, 0.9294718204322986], 
     Hue[0.6442695509851231, 1, 0.10793446786675277`], 
     Hue[0.06911443317412203, 1, 0.9043030925281387], 
     Hue[0.0356846500797503, 1, 0.9505904845049612], 
     Hue[0.04212737250435472, 1, 0.9416697919170472], 
     Hue[0.029585083989926653`, 1, 0.9590360375524092], 
     Hue[0.04536085424235259, 1, 0.9371926633567426], 
     Hue[0.05684838761303368, 1, 0.9212868479204149], 
     Hue[0.024289085186181336`, 1, 0.9663689589729796], 
     Hue[0.0237731284470154, 1, 0.9670833606118249], 
     Hue[0.05483847049596635, 1, 0.9240698100825081], 
     Hue[0.6499568451768565, 1, 0.10005975283204487`], 
     Hue[0.1363381392299282, 1, 0.8112241149124071], 
     Hue[0.08772543993991222, 1, 0.8785340062370447], 
     Hue[0.6499921958935919, 1, 0.1000108056857958], 
     Hue[0.6499815826907896, 1, 0.1000255008896759], 
     Hue[0.6498444107546016, 1, 0.10021543126285924`], 
     Hue[0.6499972430972302, 1, 0.100003817249989], 
     Hue[0.649991738534553, 1, 0.10001143895215739`], 
     Hue[0.6487705039500171, 1, 0.10170237914613013`], 
     Hue[0.6494538081178016, 1, 0.10075626568304397`], 
     Hue[0.6497754438766126, 1, 0.10031092386315178`], 
     Hue[0.6499970364609213, 1, 0.10000410336180125`], 
     Hue[0.6499900303665672, 1, 0.1000138041078301], 
     Hue[0.6488764101426018, 1, 0.10155573980255143`], 
     Hue[0.6494944920013717, 1, 0.1006999341519469], 
     Hue[0.6497946645707691, 1, 0.10028431059431978`], 
     Hue[0.6499976902030482, 1, 0.10000319818039483`], 
     Hue[0.6499918345586811, 1, 0.10001130599567229`], 
     Hue[0.6422490695270423, 1, 0.11073205757794152`], 
     Hue[0.6439347182575961, 1, 0.10839808241255937`], 
     Hue[0.6462677940825908, 1, 0.10516766973179734`], 
     Hue[0.6499987146874728, 1, 0.10000177966349917`], 
     Hue[0.6499948721580225, 1, 0.10000710008889192`], 
     Hue[0.6499919871931541, 1, 0.10001109465563283`], 
     Hue[0.6499713454318636, 1, 0.10003967555588111`], 
     Hue[0.6499718278287638, 1, 0.10003900762171163`], 
     Hue[0.6497345611795992, 1, 0.10036753067440123`], 
     Hue[0.6498018925098331, 1, 0.10027430267869263`], 
     Hue[0.6498626192094604, 1, 0.10019021955613172`], 
     Hue[0.6499355607562259, 1, 0.10008922356830251`], 
     Hue[0.6497756875709593, 1, 0.10031058644021032`], 
     Hue[0.6499010158522833, 1, 0.10013705497376155`], 
     Hue[0.6495286701235261, 1, 0.10065261059819466`], 
     Hue[0.6497227255582314, 1, 0.10038391845783354`], 
     Hue[0.6498101922800572, 1, 0.10026281068915155`], 
     Hue[0.6498793549635762, 1, 0.10016704697350987`], 
     Hue[0.6499140775511517, 1, 0.10011896954455923`], 
     Hue[0.6498240476769204, 1, 0.1002436262934949], 
     Hue[0.6496034200215915, 1, 0.10054911073933477`], 
     Hue[0.6497286976236282, 1, 0.10037564944420725`], 
     Hue[0.6469830084704469, 1, 0.10417737288707352`], 
     Hue[0.6499943753176628, 1, 0.10000778802169773`], 
     Hue[0.6499831692600134, 1, 0.10002330410151988`], 
     Hue[0.6493091928249018, 1, 0.1009565022424437], 
     Hue[0.6499940334340683, 1, 0.10000826139898249`], 
     Hue[0.6499820302250641, 1, 0.10002488122683444`], 
     Hue[0.6484170359375229, 1, 0.10219179639419922`], 
     Hue[0.6492662755870917, 1, 0.10101592611018075`], 
     Hue[0.6499929453047922, 1, 0.1000097680395185], 
     Hue[0.6499785213522411, 1, 0.10002973966612777`], 
     Hue[0.6495661971830554, 1, 0.10060065005423105`], 
     Hue[0.6498227478492569, 1, 0.10024542605487519`], 
     Hue[0.6499935357840586, 1, 0.1000089504528419], 
     Hue[0.6499790435681867, 1, 0.1000290165978954], 
     Hue[0.6457346189709852, 1, 0.10590591219402055`], 
     Hue[0.6478372678614377, 1, 0.1029945521918556], 
     Hue[0.6479352451115096, 1, 0.10285889138406365`], 
     Hue[0.6361629517392285, 1, 0.11915898989952975`], 
     Hue[0.6426060373172346, 1, 0.11023779448382903`], 
     Hue[0.6433837635085882, 1, 0.10916094283426252`], 
     Hue[0.6499868209653984, 1, 0.10001824789406386`], 
     Hue[0.6499586304141812, 1, 0.10005728096497984`], 
     Hue[0.6499343411964055, 1, 0.10009091218959242`], 
     Hue[0.6498193104351556, 1, 0.10025018555132306`], 
     Hue[0.6496351891654721, 1, 0.10050512269396177`], 
     Hue[0.052356192627825426`, 1, 0.9275068102076263], 
     Hue[0.06232968961202978, 1, 0.9136973528448818], 
     Hue[0.046157553002425855`, 1, 0.9360895419966412], 
     Hue[0.6497899760668525, 1, 0.10029080236897342`], 
     Hue[0.12808116331743558`, 1, 0.8226568507912431], 
     Hue[0.0871847617928091, 1, 0.879282637517649], 
     Hue[0.07370672850149418, 1, 0.8979445297671619], 
     Hue[0.0547391379729677, 1, 0.9242073474220448], 
     Hue[0.05296101370270223, 1, 0.9266693656424123], 
     Hue[0.015749925564766842`, 1, 0.9781924107564767], 
     Hue[0.061102234844841785`, 1, 0.9153969055994499], 
     Hue[0.06232914547868751, 1, 0.9136981062602788], 
     Hue[0.6344594739747509, 1, 0.12151765141957578`], 
     Hue[0.641906698618319, 1, 0.11120610960540464`], 
     Hue[0.6428219458256503, 1, 0.10993884424140725`], 
     Hue[0.6499660998753157, 1, 0.1000469386341783], 
     Hue[0.6499012701443765, 1, 0.10013670287701723`], 
     Hue[0.6448549115485948, 1, 0.1071239686250227], 
     Hue[0.6474981839893832, 1, 0.10346405293777722`], 
     Hue[0.6476675081491792, 1, 0.1032296041011365], 
     Hue[0.6499988552337818, 1, 0.10000158506091766`], 
     Hue[0.6499944554086007, 1, 0.10000767712655288`], 
     Hue[0.6499816628274131, 1, 0.10002538993127426`], 
     Hue[0.6499900650935815, 1, 0.10001375602427179`], 
     Hue[0.6499696401582413, 1, 0.10004203670397364`], 
     Hue[0.6494683817249716, 1, 0.10073608684234706`], 
     Hue[0.6497816019775468, 1, 0.10030239726185837`], 
     Hue[0.6499908786944303, 1, 0.10001262950001963`], 
     Hue[0.6499724054302531, 1, 0.1000382078658034], 
     Hue[0.6495373427578125, 1, 0.10064060233533664`], 
     Hue[0.6498121543365734, 1, 0.10026009399551378`], 
     Hue[0.6495735994608536, 1, 0.1005904007465105], 
     Hue[0.6458640286731668, 1, 0.1057267295294614], 
     Hue[0.6481632013431321, 1, 0.10254325967874019`], 
     Hue[0.6484169294684935, 1, 0.10219194381285517`], 
     Hue[0.6499930956036425, 1, 0.10000955993341809`], 
     Hue[0.6499789780864972, 1, 0.10002910726485005`], 
     Hue[0.6481809414244274, 1, 0.10251869648925446`], 
     Hue[0.6499820088708554, 1, 0.10002491079420026`], 
     Hue[0.649951928607446, 1, 0.10006656038969021`], 
     Hue[0.6498726435811897, 1, 0.10017633965681431`], 
     Hue[0.6495268294385302, 1, 0.10065515923895813`], 
     Hue[0.6499262060984181, 1, 0.10010217617142107`], 
     Hue[0.6499853226778649, 1, 0.10002032244603327`], 
     Hue[0.6499619200761516, 1, 0.10005272604840555`], 
     Hue[0.64993257150324, 1, 0.1000933625339754], 
     Hue[0.6499534329371166, 1, 0.10006447747168479`], 
     Hue[0.6499324527590057, 1, 0.10009352694906906`], 
     Hue[0.6498805022972121, 1, 0.10016545835770649`], 
     Hue[0.649897647721092, 1, 0.10014171854002644`], 
     Hue[0.6498193090375265, 1, 0.10025018748650186`], 
     Hue[0.6497572528766662, 1, 0.10033611140153914`], 
     Hue[0.6380802606040145, 1, 0.11650425454828774`], 
     Hue[0.6441258644660639, 1, 0.10813341843160391`], 
     Hue[0.6471783848968902, 1, 0.10390685168122897`], 
     Hue[0.6472837152496111, 1, 0.10376100965438464`], 
     Hue[0.6367727623764567, 1, 0.11831463670952139`], 
     Hue[0.6437779004305053, 1, 0.10861521478853113`], 
     Hue[0.6497256563756506, 1, 0.10037986040294537`], 
     Hue[0.6467055444258307, 1, 0.10456155387192675`], 
     Hue[0.6468596733897962, 1, 0.10434814453720526`], 
     Hue[0.6480300591612538, 1, 0.10272761039211016`], 
     Hue[0.6355800602668357, 1, 0.1199660703997661], 
     Hue[0.6431989834370649, 1, 0.10941679216406403`], 
     Hue[0.6494483465051228, 1, 0.10076382791598378`], 
     Hue[0.6492329934935951, 1, 0.10106200900886837`], 
     Hue[0.6487296255360026, 1, 0.10175898002707338`], 
     Hue[0.6487995970278788, 1, 0.10166209642293714`], 
     Hue[0.6407885398068301, 1, 0.11275432949823529`], 
     Hue[0.6391229507819325, 1, 0.11506052968655511`], 
     Hue[0.6442267727472464, 1, 0.1079936992730435], 
     Hue[0.6491919410820355, 1, 0.10111885080948943`], 
     Hue[0.6455200946749557, 1, 0.10620294583467675`], 
     Hue[0.6492911092393578, 1, 0.10098154105319682`], 
     Hue[0.6465279546916489, 1, 0.10480744735002454`], 
     Hue[0.6491777108101718, 1, 0.101138554262839], 
     Hue[0.6467143550007588, 1, 0.10454935461433398`], 
     Hue[0.6383228871128208, 1, 0.11616831015147888`], 
     Hue[0.6486561139070236, 1, 0.1018607653595058], 
     Hue[0.646137504600712, 1, 0.1053480705528604], 
     Hue[0.6474542829314643, 1, 0.10352483901797246`], 
     Hue[0.649844653836598, 1, 0.1002150946877875], 
     Hue[0.6499914508239111, 1, 0.1000118373207385], 
     Hue[0.6499755212375811, 1, 0.10003389367104164`], 
     Hue[0.6499537620148891, 1, 0.10006402182553824`], 
     Hue[0.6490939257495898, 1, 0.10125456434672189`], 
     Hue[0.6455793655528038, 1, 0.10612087846534854`], 
     Hue[0.6494816406482039, 1, 0.10071772833325618`], 
     Hue[0.6468259055741598, 1, 0.10439489997424038`], 
     Hue[0.6477000178659472, 1, 0.10318459064715], 
     Hue[0.6486834249166266, 1, 0.10182295011544017`], 
     Hue[0.6419858110464992, 1, 0.11109656932023194`], 
     Hue[0.6450215943703861, 1, 0.10689317702561925`], 
     Hue[0.06207432696715964, 1, 0.914050931891625], 
     Hue[0.050992562517808926`, 1, 0.9293949134368799], 
     Hue[0.05092039552033345, 1, 0.9294948369718461], 
     Hue[0.04560230798720555, 1, 0.9368583427869461], 
     Hue[0.016323968703749192`, 1, 0.9773975817948088], 
     Hue[0.03931198655078383, 1, 0.9455680186219916], 
     Hue[0.649993070256032, 1, 0.10000959503010948`], 
     Hue[0.64997850354992, 1, 0.10002976431549539`], 
     Hue[0.649956412075368, 1, 0.1000603525110289], 
     Hue[0.6499153667338397, 1, 0.10011718452237588`], 
     Hue[0.6475468365907283, 1, 0.10339668779745319`], 
     Hue[0.6492170655122174, 1, 0.1010840631369299], 
     Hue[0.649036411873795, 1, 0.1013341989439762], 
     Hue[0.12735195655975606`, 1, 0.8236665216864917], 
     Hue[0.07095879139435235, 1, 0.901749365761666], 
     Hue[0.06795459612742838, 1, 0.9059090207466377], 
     Hue[0.0429022520687633, 1, 0.940596881750943], 
     Hue[0.04204277396934619, 1, 0.9417869283501361], 
     Hue[0.04506896570308505, 1, 0.9375968167188053], 
     Hue[0.046965490716977976`, 1, 0.9349708590072613], 
     Hue[0.06583530477381705, 1, 0.9088434241593302], 
     Hue[0.06357108278528767, 1, 0.9119785007588324], 
     Hue[0.08419549407552807, 1, 0.8834216235877304], 
     Hue[0.06607430809810899, 1, 0.9085124964795414], 
     Hue[0.0345622025072474, 1, 0.9521446426822728], 
     Hue[0.035767592234322576`, 1, 0.9504756415217072], 
     Hue[0.04888123447080894, 1, 0.932318290732726], 
     Hue[0.0938591734949511, 1, 0.8700411443916062], 
     Hue[0.6493588109490479, 1, 0.10088780022439532`], 
     Hue[0.28823557445349274`, 1, 0.6009045892182409], 
     Hue[0.20090324072823595`, 1, 0.7218262820685963], 
     Hue[0.1592129302023353, 1, 0.7795513274121512], 
     Hue[0.04594641706013736, 1, 0.936381884070579], 
     Hue[0.028644150948217928`, 1, 0.9603388679178521], 
     Hue[0.08067642003119846, 1, 0.8882941876491098], 
     Hue[0.09160174623068462, 1, 0.8731668129113598], 
     Hue[0.08526111437163175, 1, 0.8819461493315868], 
     Hue[0.17654403595039975`, 1, 0.755554411760985], 
     Hue[0.14420758431908232`, 1, 0.8003279601735784], 
     Hue[0.160482513840219, 1, 0.7777934423750814], 
     Hue[0.06284677599261046, 1, 0.9129813870871548], 
     Hue[0.6496950824240438, 1, 0.10042219356670862`], 
     Hue[0.649457309782455, 1, 0.10075141722429308`], 
     Hue[0.6490075876645662, 1, 0.10137410938752375`], 
     Hue[0.0841655055898558, 1, 0.8834631461063536], 
     Hue[0.07281066895396893, 1, 0.8991852276021969], 
     Hue[0.03715915984143059, 1, 0.948548855604173], 
     Hue[0.024061943309682254`, 1, 0.9666834631096708], 
     Hue[0.09051325443792058, 1, 0.8746739553936483], 
     Hue[0.013527640835015342`, 1, 0.9812694203822865], 
     Hue[0.017871235057461687`, 1, 0.9752552129973607], 
     Hue[0.015134948317259922`, 1, 0.9790439177145632], 
     Hue[0.6487559364419047, 1, 0.10172254954197814`], 
     Hue[0.6467772863617347, 1, 0.10446221888375203`], 
     Hue[0.6254270652456169, 1, 0.1340240635060689], 
     Hue[0.03878605281080172, 1, 0.9462962345696592], 
     Hue[0.03357773444218792, 1, 0.9535077523108167], 
     Hue[0.03854235466945888, 1, 0.9466336627653646], 
     Hue[0.03623230957301016, 1, 0.9498321867450628], 
     Hue[0.05276005316699983, 1, 0.9269476186918464], 
     Hue[0.06076138056174474, 1, 0.9158688576837382], 
     Hue[0.0260536268840742, 1, 0.9639257473912818], 
     Hue[0.01962800228977002, 1, 0.9728227660603184], 
     Hue[0.007946743440065629, 1, 0.9889968167752937], 
     Hue[0.026346987648856346`, 1, 0.963519555563122], 
     Hue[0.01704075784299175, 1, 0.9764051045250883], 
     Hue[0.013200644397284744`, 1, 0.9817221846806826], 
     Hue[0.09307224102515876, 1, 0.871130743195934], 
     Hue[0.04843689360942616, 1, 0.9329335319254098], 
     Hue[0.03250841319888753, 1, 0.9549883509553865], 
     Hue[0.5315189606144243, 1, 0.26405066991848947`], 
     Hue[0.5754262393411327, 1, 0.2032559762968933], 
     Hue[0.5904309884160934, 1, 0.18248016988540922`], 
     Hue[0.5939622345161822, 1, 0.17759075220836315`], 
     Hue[0.6304604884179906, 1, 0.1270547083443207], 
     Hue[0.6368306691194965, 1, 0.11823445814223563`], 
     Hue[0.649968277199286, 1, 0.10004392387791179`], 
     Hue[0.6499259825003436, 1, 0.10010248576875501`], 
     Hue[0.6498575313506219, 1, 0.10019726428375447`], 
     Hue[0.6498526822456124, 1, 0.10020397842915202`], 
     Hue[0.060477346241165963`, 1, 0.9162621359737703], 
     Hue[0.059186618982938755`, 1, 0.9180492967928541], 
     Hue[0.013484933907003116`, 1, 0.9813285530518417], 
     Hue[0.004096652524860578, 1, 0.9943277118886545], 
     Hue[0.012228653015817104`, 1, 0.9830680189011763], 
     Hue[0.016368740618419864`, 1, 0.9773355899129572], 
     Hue[0.6495804740765165, 1, 0.10058088204790024`], 
     Hue[0.6499407058989871, 1, 0.1000820995244794], 
     Hue[0.6498819683756317, 1, 0.10016342840297142`], 
     Hue[0.649877894596993, 1, 0.10016906901954829`], 
     Hue[0.6498579908001729, 1, 0.1001966281228375], 
     Hue[0.14945676108720896`, 1, 0.7930598692638646], 
     Hue[0.09427842950140553, 1, 0.8694606360749769], 
     Hue[0.07261005730015602, 1, 0.8994629975843994], 
     Hue[0.07496422988755302, 1, 0.8962033740018497], 
     Hue[0.03457235775045886, 1, 0.9521305815762877], 
     Hue[0.0751609814158739, 1, 0.89593094880879], 
     Hue[0.06710783261252007, 1, 0.9070814625365107], 
     Hue[0.07043302640414995, 1, 0.9024773480557924], 
     Hue[0.07436874416714412, 1, 0.8970278926916466], 
     Hue[0.04195775174810057, 1, 0.9419046514257069], 
     Hue[0.02348923479181464, 1, 0.9674764441344105], 
     Hue[0.028349870127783228`, 1, 0.9607463336692231], 
     Hue[0.05907345746978676, 1, 0.9182059819649107], 
     Hue[0.6498577759491584, 1, 0.10019692560885764`], 
     Hue[0.6497457903882365, 1, 0.10035198253936482`], 
     Hue[0.6499554316058366, 1, 0.10006171008422632`], 
     Hue[0.6498933215703696, 1, 0.10014770859487288`], 
     Hue[0.6497858170863429, 1, 0.10029656095737151`], 
     Hue[0.172357007071749, 1, 0.7613518363621937], 
     Hue[0.11038532780047605`, 1, 0.8471587768916486], 
     Hue[0.08121293919221018, 1, 0.8875513149646321], 
     Hue[0.06379628953306882, 1, 0.9116666760311355], 
     Hue[0.06832439748146335, 1, 0.9053969881025893], 
     Hue[0.06822362903491919, 1, 0.9055365136439582], 
     Hue[0.07233801941360696, 1, 0.8998396654273134], 
     Hue[0.06837306326009807, 1, 0.9053296047167873], 
     Hue[0.03604259907689744, 1, 0.9500948628166036], 
     Hue[0.002546920706362976, 1, 0.9964734944065744], 
     Hue[0.0016639070438763115`, 1, 0.997696128708479], 
     Hue[0.0007909078474683806, 1, 0.9989048968265823], 
     Hue[0.04673538297575486, 1, 0.9352894697258778], 
     Hue[0.0528828759846427, 1, 0.9267775563289563], 
     Hue[0.6385124853534148, 1, 0.11590578951065651`], 
     Hue[0.6449512096220037, 1, 0.10699063283107184`], 
     Hue[0.6469680405622861, 1, 0.10419809768298857`], 
     Hue[0.6466956681133744, 1, 0.104575228766097], 
     Hue[0.6499179992919234, 1, 0.10011353944195223`], 
     Hue[0.6498330217966197, 1, 0.10023120058929585`], 
     Hue[0.6499780591100208, 1, 0.10003037969381738`], 
     Hue[0.6499416185021615, 1, 0.10008083592008415`], 
     Hue[0.6498793386899799, 1, 0.10016706950618169`], 
     Hue[0.09950090802563483, 1, 0.8622295119645056], 
     Hue[0.06419266388205969, 1, 0.9111178500094559], 
     Hue[0.04399537318811686, 1, 0.9390833294318383], 
     Hue[0.03980201832467678, 1, 0.944889513088909], 
     Hue[0.03348426783988456, 1, 0.9536371676063138], 
     Hue[0.03372985728958966, 1, 0.9532971206759527], 
     Hue[0.05273873887936531, 1, 0.9269771307824173], 
     Hue[0.048835655861444005`, 1, 0.9323813995764622], 
     Hue[0.015830965123667218`, 1, 0.9780802021364607], 
     Hue[0.08151528447352718, 1, 0.8871326830366546], 
     Hue[0.6466217648822217, 1, 0.10467755631692388`], 
     Hue[0.6499615076887281, 1, 0.10005329704637654`], 
     Hue[0.6499192513822374, 1, 0.10011180577844064`], 
     Hue[0.6499921029649034, 1, 0.10001093435628766`], 
     Hue[0.6499765605679644, 1, 0.10003245459820317`], 
     Hue[0.6499501028226999, 1, 0.10006908839933855`], 
     Hue[0.041487173614574435`, 1, 0.9425562211490508], 
     Hue[0.04084836252105106, 1, 0.9434407288170062], 
     Hue[0.06090910456628851, 1, 0.9156643167543697], 
     Hue[0.05515008285780454, 1, 0.9236383468122706], 
     Hue[0.04442237481907063, 1, 0.9384920964043637], 
     Hue[0.029915635075127955`, 1, 0.9585783514344381], 
     Hue[0.04957507265679617, 1, 0.9313575917059745], 
     Hue[0.05094028454276911, 1, 0.9294672983253967], 
     Hue[0.6495409582143993, 1, 0.10063559631852417`], 
     Hue[0.6485615614524635, 1, 0.10199168414274291`], 
     Hue[0.649983815202874, 1, 0.10002240971909757`], 
     Hue[0.6499569726346928, 1, 0.10005957635196386`], 
     Hue[0.6499093739654164, 1, 0.10012548220173127`], 
     Hue[0.5609812181877171, 1, 0.22325677481700723`], 
     Hue[0.592337211042654, 1, 0.17984078471017143`], 
     Hue[0.5970134258552375, 1, 0.17336602573890192`], 
     Hue[0.055100347735577704`, 1, 0.9237072108276617], 
     Hue[0.6479193260551558, 1, 0.10288093315439976`], 
     Hue[0.6452453873223507, 1, 0.10658330986136066`], 
     Hue[0.6499705861219492, 1, 0.10004072690807031`], 
     Hue[0.6499376208343695, 1, 0.10008637115241159`], 
     Hue[0.6499937186344199, 1, 0.10000869727541867`], 
     Hue[0.6499815417717242, 1, 0.1000255575468435], 
     Hue[0.6499606406888642, 1, 0.10005449750772656`], 
     Hue[0.6451688263253699, 1, 0.1066893173956417], 
     Hue[0.6480965999890487, 1, 0.10263547693824032`], 
     Hue[0.6499443427410518, 1, 0.1000770638970052], 
     Hue[0.6498915223823863, 1, 0.1001501997782343], 
     Hue[0.6499191555242062, 1, 0.10011193850494536`], 
     Hue[0.6498566868064087, 1, 0.10019843365266484`], 
     Hue[0.6498153611487943, 1, 0.10025565379397706`], 
     Hue[0.64573893449775, 1, 0.1058999368492692], 
     Hue[0.6471817103079827, 1, 0.10390224726587022`], 
     Hue[0.648482516300193, 1, 0.10210113127665589`], 
     Hue[0.645606934555609, 1, 0.10608270599992604`], 
     Hue[0.6488552636988794, 1, 0.10158501949385938`], 
     Hue[0.645651061915866, 1, 0.10602160657803174`], 
     Hue[0.6489370003174816, 1, 0.10147184571425631`], 
     Hue[0.6490081979815369, 1, 0.10137326433325665`], 
     Hue[0.6490360077114343, 1, 0.10133475855339873`], 
     Hue[0.6497391152442346, 1, 0.10036122504644447`], 
     Hue[0.649135279281409, 1, 0.10119730561035684`], 
     Hue[0.6494608790928093, 1, 0.10074647510226419`], 
     Hue[0.6240461007928988, 1, 0.13593616813290946`], 
     Hue[0.6374704864405576, 1, 0.11734855723615109`], 
     Hue[0.6414707166144704, 1, 0.11180977699534868`], 
     Hue[0.6499244849848164, 1, 0.10010455925179274`], 
     Hue[0.649233176750437, 1, 0.10106175526862575`], 
     Hue[0.6499140056316395, 1, 0.10011906912542227`], 
     Hue[0.6463305154629292, 1, 0.1050808247436366], 
     Hue[0.6479908720361923, 1, 0.10278186948834912`], 
     Hue[0.6480450524764418, 1, 0.10270685041723439`], 
     Hue[0.6499650551555786, 1, 0.10004838516919888`], 
     Hue[0.6499189443796413, 1, 0.1001122308589583], 
     Hue[0.6499242251169189, 1, 0.10010491906888146`], 
     Hue[0.6498821989371071, 1, 0.10016310916400568`], 
     Hue[0.649789963751755, 1, 0.10029081942064691`], 
     Hue[0.6498392636470757, 1, 0.10022255802712608`], 
     Hue[0.6497160506085209, 1, 0.10039316069589418`], 
     Hue[0.6496314216769604, 1, 0.10051033921651636`], 
     Hue[0.6496064862608281, 1, 0.10054486517731495`], 
     Hue[0.6498300143289476, 1, 0.10023536477530341`], 
     Hue[0.6498849948937723, 1, 0.10015923783939225`], 
     Hue[0.6496999635415956, 1, 0.10041543509625224`], 
     Hue[0.6496712375414129, 1, 0.10045520955804377`], 
     Hue[0.6494534680059582, 1, 0.10075673660713488`], 
     Hue[0.6497394229389668, 1, 0.10036079900758452`], 
     Hue[0.6498990325343295, 1, 0.1001398011063131], 
     Hue[0.6499881327343695, 1, 0.1000164315985653], 
     Hue[0.649968799305462, 1, 0.10004320096166794`], 
     Hue[0.6499432361816326, 1, 0.10007859605620101`], 
     Hue[0.06724157579807222, 1, 0.9068962796642076], 
     Hue[0.6499593522394259, 1, 0.10005628151464112`], 
     Hue[0.06336863287824301, 1, 0.9122588160147403], 
     Hue[0.016838269818239215`, 1, 0.9766854725593611], 
     Hue[0.04168357589978977, 1, 0.9422842795233679], 
     Hue[0.0386890660930832, 1, 0.9464305238711156], 
     Hue[0.06751225042609976, 1, 0.9065214994100157], 
     Hue[0.02576666129646632, 1, 0.9643230843587389], 
     Hue[0.0230508304957715, 1, 0.9680834654673932], 
     Hue[0.09570480909613677, 1, 0.8674856489438105], 
     Hue[0.020666196792623825`, 1, 0.971385265979444], 
     Hue[0.028914646752637996`, 1, 0.9599643352655781], 
     Hue[0.6494112836702908, 1, 0.10081514568728978`], 
     Hue[0.6493636566720733, 1, 0.10088109076174467`], 
     Hue[0.05236666239317256, 1, 0.9274923136094534], 
     Hue[0.03130553128311864, 1, 0.9566538797618358], 
     Hue[0.024328334612227276`, 1, 0.9663146136138392], 
     Hue[0.03939859521543887, 1, 0.9454480989324693], 
     Hue[0.04309381893701303, 1, 0.9403316353179819], 
     Hue[0.048266130808177654`, 1, 0.9331699727271385], 
     Hue[0.029526658690814833`, 1, 0.9591169341204102], 
     Hue[0.02272121346256517, 1, 0.968539858282602], 
     Hue[0.06089840404598401, 1, 0.9156791328594068], 
     Hue[0.05473552704263829, 1, 0.9242123471717315], 
     Hue[0.03318267205759917, 1, 0.9540547617664011], 
     Hue[0.00928372142193079, 1, 0.9871456164927112], 
     Hue[0.6481794574431041, 1, 0.10252075123262509`], 
     Hue[0.04971702902549335, 1, 0.9311610367339322], 
     Hue[0.06044810249079424, 1, 0.9163026273204388], 
     Hue[0.0028885166606616997`, 1, 0.9960005153929299], 
     Hue[0.05609869367844089, 1, 0.9223248856760049], 
     Hue[0.6489918183611147, 1, 0.10139594380768736`], 
     Hue[0.6493621307454646, 1, 0.10088320358320298`], 
     Hue[0.6498218768371575, 1, 0.10024663207162811`], 
     Hue[0.6497024436682362, 1, 0.10041200107474992`], 
     Hue[0.6499989449454294, 1, 0.10000146084479014`], 
     Hue[0.6499974065711196, 1, 0.10000359090152677`], 
     Hue[0.6499911089724155, 1, 0.10001231065357848`], 
     Hue[0.019027112185320827`, 1, 0.9736547677434019], 
     Hue[0.06689408621798898, 1, 0.9073774190827845], 
     Hue[0.05920040917609204, 1, 0.9180302026792573], 
     Hue[0.06289730437374064, 1, 0.9129114247132822], 
     Hue[0.048012535980808346`, 1, 0.933521104026573], 
     Hue[0.03978206301117937, 1, 0.9449171435229824], 
     Hue[0.03540027779638899, 1, 0.9509842307434615], 
     Hue[0.026393570210791584`, 1, 0.9634550566312117], 
     Hue[0.027331873484537472`, 1, 0.962155867482948], 
     Hue[0.1066536603002386, 1, 0.8523257011227465], 
     Hue[0.06024692782625385, 1, 0.9165811768559562], 
     Hue[0.039189162532340394`, 1, 0.9457380826475288], 
     Hue[0.028879197350603847`, 1, 0.9600134190530101], 
     Hue[0.030090616365315292`, 1, 0.958336069648025], 
     Hue[0.025623958738075103`, 1, 0.9645206725165114], 
     Hue[0.031903553186861, 1, 0.9558258494335771], 
     Hue[0.04076178560992283, 1, 0.9435606045401068], 
     Hue[0.06501571005059514, 1, 0.9099782476222529], 
     Hue[0.6435670855750815, 1, 0.10890711228065647`], 
     Hue[0.6425785679063328, 1, 0.11027582905276992`], 
     Hue[0.6449271467185937, 1, 0.1070239506973317], 
     Hue[0.6485566314450245, 1, 0.10199851030688924`], 
     Hue[0.649125049079192, 1, 0.10121147050573426`], 
     Hue[0.6499956090677688, 1, 0.10000607975232013`], 
     Hue[0.6499941546049821, 1, 0.10000809362387095`], 
     Hue[0.6492759692761771, 1, 0.10100250407913945`], 
     Hue[0.6484234996865119, 1, 0.10218284658790666`], 
     Hue[0.6499939661219417, 1, 0.10000835460038837`], 
     Hue[0.6492397830943111, 1, 0.10105260802326163`], 
     Hue[0.6498428339067502, 1, 0.1002176145906535], 
     Hue[0.6495903564389404, 1, 0.1005671987768519], 
     Hue[0.6499926088211632, 1, 0.10001023393992794`], 
     Hue[0.6499945114586985, 1, 0.10000759951872526`], 
     Hue[0.6499637047775865, 1, 0.10005025492334191`], 
     Hue[0.07928017381901586, 1, 0.8902274516352088], 
     Hue[0.10297819585678447`, 1, 0.85741480573676], 
     Hue[0.10098939285085995`, 1, 0.8601685329757324], 
     Hue[0.12318661616118176`, 1, 0.8294339160845177], 
     Hue[0.11735580154287428`, 1, 0.8375073517098665], 
     Hue[0.6145560947636765, 1, 0.14907617648106342`], 
     Hue[0.04185067072369486, 1, 0.9420529174594995], 
     Hue[0.04842544457951281, 1, 0.9329493844283668], 
     Hue[0.6190771234024015, 1, 0.14281629067359802`], 
     Hue[0.6214511531800638, 1, 0.1395291725199117], 
     Hue[0.6478125563933088, 1, 0.10302876807080319`], 
     Hue[0.06204588308983361, 1, 0.9140903157217689], 
     Hue[0.062419858914684156`, 1, 0.9135725030412066], 
     Hue[0.06569055941279622, 1, 0.9090438408130515], 
     Hue[0.6499747936386155, 1, 0.10003490111576314`], 
     Hue[0.6499738517652197, 1, 0.10003620524815732`], 
     Hue[0.6499907001267992, 1, 0.10001287674750885`], 
     Hue[0.6494633437276633, 1, 0.10074306253092778`], 
     Hue[0.6499700291156463, 1, 0.10004149814756678`], 
     Hue[0.6499904142473003, 1, 0.10001327258066119`], 
     Hue[0.6494809595337075, 1, 0.10071867141486651`], 
     Hue[0.6499750452927184, 1, 0.10003455267162066`], 
     Hue[0.6499923978279482, 1, 0.10001052608437945`], 
     Hue[0.6499483599759286, 1, 0.10007150157179119`], 
     Hue[0.649984513443093, 1, 0.10002144292494813`], 
     Hue[0.6499771770283137, 1, 0.1000316010377195], 
     Hue[0.6496133169116165, 1, 0.10053540735314641`], 
     Hue[0.6496653824879784, 1, 0.10046331655510682`], 
     Hue[0.6458131632704711, 1, 0.10579715854857849`], 
     Hue[0.6457739397279738, 1, 0.10585146806895941`], 
     Hue[0.6453467615726858, 1, 0.10644294551474276`], 
     Hue[0.6498128522325368, 1, 0.10025912767802594`], 
     Hue[0.6494387936872403, 1, 0.1007770548945903], 
     Hue[0.6495262753424667, 1, 0.10065592644889229`], 
     Hue[0.6469777954465857, 1, 0.10418459092011212`], 
     Hue[0.6499941816160543, 1, 0.10000805622392492`], 
     Hue[0.6499808614506251, 1, 0.10002649952990374`], 
     Hue[0.024644746484107305`, 1, 0.9658765048681591], 
     Hue[0.027701109294989812`, 1, 0.9616446178992449], 
     Hue[0.01020504596535643, 1, 0.9858699363556602], 
     Hue[0.006712165553525273, 1, 0.9907062323105035], 
     Hue[0.6499055604766235, 1, 0.10013076241698286`], 
     Hue[0.07971038260671659, 1, 0.8896317779291617], 
     Hue[0.05595929078931117, 1, 0.9225179050609538], 
     Hue[0.032703118268389786`, 1, 0.9547187593206911], 
     Hue[0.027399264521969502`, 1, 0.9620625568157346], 
     Hue[0.031715691604689455`, 1, 0.95608596547043], 
     Hue[0.6499521309691656, 1, 0.10006628019654003`], 
     Hue[0.03438002735091661, 1, 0.9523968852064232], 
     Hue[0.020514922410266534`, 1, 0.971594722816554], 
     Hue[0.06528849448301188, 1, 0.909600546100445], 
     Hue[0.07737418074836278, 1, 0.8928665189638054], 
     Hue[0.6499980270047907, 1, 0.10000273183952066`], 
     Hue[0.6499952983369286, 1, 0.10000650999502203`], 
     Hue[0.6499904245332631, 1, 0.1000132583385589], 
     Hue[0.649970150236542, 1, 0.10004133044171104`], 
     Hue[0.649901294396797, 1, 0.10013666929674264`], 
     Hue[0.6499562007867138, 1, 0.10006064506455023`], 
     Hue[0.6498615884783321, 1, 0.10019164672230946`], 
     Hue[0.6493654278090476, 1, 0.10087863841824188`], 
     Hue[0.6494486702901593, 1, 0.10076337959824103`], 
     Hue[0.03823403582071727, 1, 0.9470605657866991], 
     Hue[0.03276506178544192, 1, 0.9546329913740035], 
     Hue[0.031800291994456775`, 1, 0.9559688264692137], 
     Hue[0.06629906735821245, 1, 0.9082012913501674], 
     Hue[0.05206319808671478, 1, 0.9279124949568565], 
     Hue[0.050044621814262946`, 1, 0.9307074467187129], 
     Hue[0.05392831805410758, 1, 0.9253300211558511], 
     Hue[0.6395910766738113, 1, 0.11441235537472284`], 
     Hue[0.6449732524630962, 1, 0.10696011197417452`], 
     Hue[0.6473255099465282, 1, 0.10370314007403797`], 
     Hue[0.034562635241955464`, 1, 0.9521440435111386], 
     Hue[0.5944544553903148, 1, 0.17690921561341033`], 
     Hue[0.6222774023714821, 1, 0.13838513517794784`], 
     Hue[0.6305252313997606, 1, 0.1269650642157161], 
     Hue[0.028769685209166118`, 1, 0.960165051248847], 
     Hue[0.03129422539224458, 1, 0.9566695340722768], 
     Hue[0.04845642689533347, 1, 0.9329064858372307], 
     Hue[0.05312870153483251, 1, 0.9264371824902319], 
     Hue[0.6453367455430371, 1, 0.10645681386348714`], 
     Hue[0.649816574752118, 1, 0.10025397342014435`], 
     Hue[0.6496993259919096, 1, 0.10041631785735594`], 
     Hue[0.6499995667510081, 1, 0.10000059988321958`], 
     Hue[0.6499984908239054, 1, 0.10000208962843872`], 
     Hue[0.6481978371418453, 1, 0.1024953024189834], 
     Hue[0.6483064192084629, 1, 0.10234495801905143`], 
     Hue[0.649997660195584, 1, 0.10000323972919145`], 
     Hue[0.6499916925989468, 1, 0.10001150255530437`], 
     Hue[0.24481799553637257`, 1, 0.661021236949638], 
     Hue[0.1972296574954786, 1, 0.7269127819293373], 
     Hue[0.5826937465593647, 1, 0.19319327399472586`], 
     Hue[0.6026562991617161, 1, 0.16555281654531612`], 
     Hue[0.6464311899189246, 1, 0.10494142934302764`], 
     Hue[0.06741170473094293, 1, 0.9066607165263867], 
     Hue[0.05971540233596195, 1, 0.9173171352271295], 
     Hue[0.12173483457993106`, 1, 0.8314440751970186], 
     Hue[0.10256507949644855`, 1, 0.8579868130049174], 
     Hue[0.64737927389886, 1, 0.10362869767850155`], 
     Hue[0.648762372431618, 1, 0.10171363817160575`], 
     Hue[0.6499091790390005, 1, 0.10012575209984549`], 
     Hue[0.6499966582137314, 1, 0.10000462708867955`], 
     Hue[0.6499958047666861, 1, 0.10000580878458858`], 
     Hue[0.6259234724469327, 1, 0.13333673045809322`], 
     Hue[0.6356119366717504, 1, 0.11992193383911486`], 
     Hue[0.6406941031633825, 1, 0.11288508792762433`], 
     Hue[0.6450137908372324, 1, 0.10690398191767822`], 
     Hue[0.6499821126294347, 1, 0.10002476712847501`], 
     Hue[0.6499732691260091, 1, 0.10003701197937206`], 
     Hue[0.636134417462731, 1, 0.11919849889775701`], 
     Hue[0.640644777976962, 1, 0.11295338433959123`], 
     Hue[0.6486262422763239, 1, 0.10190212607893616`], 
     Hue[0.6479086123052448, 1, 0.10289576757735343`], 
     Hue[0.6497257549304509, 1, 0.10037972394245258`], 
     Hue[0.6438644427880955, 1, 0.10849538690879083`], 
     Hue[0.644000176463968, 1, 0.10830744797296749`], 
     Hue[0.09140442556035089, 1, 0.8734400261472064], 
     Hue[0.06769753949521418, 1, 0.9062649453143189], 
     Hue[0.034171885481253716`, 1, 0.9526850816413409], 
     Hue[0.6499868804077649, 1, 0.10001816558924866`], 
     Hue[0.6499822744758911, 1, 0.10002454303338171`], 
     Hue[0.6499848703981542, 1, 0.10002094867947885`], 
     Hue[0.6499932097296881, 1, 0.10000940191273955`], 
     Hue[0.6499844425789807, 1, 0.10002154104448831`], 
     Hue[0.6499776435768708, 1, 0.10003095504740965`], 
     Hue[0.03480716581978749, 1, 0.9518054627110635], 
     Hue[0.05170481052142162, 1, 0.9284087238934162], 
     Hue[0.056482049080313956`, 1, 0.9217940858887961], 
     Hue[0.05460418409469159, 1, 0.9243942066381194], 
     Hue[0.05377728086245359, 1, 0.9255391495750643], 
     Hue[0.057893628426539445`, 1, 0.9198395914094069], 
     Hue[0.04333483034112273, 1, 0.9399979272199839], 
     Hue[0.0359773736708352, 1, 0.9501851749173051], 
     Hue[0.03327729236755406, 1, 0.9539237490295405], 
     Hue[0.03339477752606779, 1, 0.9537610772715984], 
     Hue[0.019983783674175637`, 1, 0.9723301456819107], 
     Hue[0.013772699320083404`, 1, 0.9809301086337306], 
     Hue[0.11699497248514101`, 1, 0.8380069611744202], 
     Hue[0.08474610454741405, 1, 0.8826592398574268], 
     Hue[0.1502334076162652, 1, 0.7919845125313252], 
     Hue[0.12036882817240302`, 1, 0.833335468684365], 
     Hue[0.11368423371105785`, 1, 0.8425910610154583], 
     Hue[0.08735312117451777, 1, 0.8790495245275909], 
     Hue[0.08259314476896751, 1, 0.885640261089122], 
     Hue[0.6499998620018042, 1, 0.10000019107442507`], 
     Hue[0.64999947191828, 1, 0.1000007311900738], 
     Hue[0.6499981522735166, 1, 0.10000255839051542`], 
     Hue[0.6499998654847237, 1, 0.10000018625192106`], 
     Hue[0.6499994595394545, 1, 0.10000074832998614`], 
     Hue[0.6499980882217745, 1, 0.10000264707754297`], 
     Hue[0.6499998480160923, 1, 0.10000021043925679`], 
     Hue[0.6499994079907874, 1, 0.10000081970506373`], 
     Hue[0.6499978062790251, 1, 0.10000303745981139`], 
     Hue[0.6499999122786961, 1, 0.1000001214602669], 
     Hue[0.649999708572939, 1, 0.10000040351439221`], 
     Hue[0.6499988156872871, 1, 0.10000163981760254`], 
     Hue[0.1925054703814415, 1, 0.7334539640872348], 
     Hue[0.128656638045059, 1, 0.8218600396299184], 
     Hue[0.1083693858050534, 1, 0.849950081193003], 
     Hue[0.22401789640152026`, 1, 0.6898213742132797], 
     Hue[0.15381064934865035`, 1, 0.7870314085941764], 
     Hue[0.11863295658723982`, 1, 0.8357389831868988], 
     Hue[0.20506026475655426`, 1, 0.7160704026447711], 
     Hue[0.16123618234780135`, 1, 0.7767499013645828], 
     Hue[0.12171889698257321`, 1, 0.831466142639514], 
     Hue[0.14569183601310132`, 1, 0.7982728424433982], 
     Hue[0.11570125087322847`, 1, 0.8397982680216836], 
     Hue[0.08533815164190861, 1, 0.8818394823419726], 
     Hue[0.23229739595871113`, 1, 0.6783574517494769], 
     Hue[0.15257785664537293`, 1, 0.7887383523371759], 
     Hue[0.11733481341988994`, 1, 0.8375364121878447], 
     Hue[0.5582406898841066, 1, 0.22705135246816022`], 
     Hue[0.5667647255163811, 1, 0.21524884159270302`], 
     Hue[0.588643773321283, 1, 0.1849547754013005], 
     Hue[0.644856606301431, 1, 0.10712162204417247`], 
     Hue[0.6474966188650284, 1, 0.10346622003303764`], 
     Hue[0.6488368685778474, 1, 0.10161048966144204`], 
     Hue[0.621949368908096, 1, 0.1388393353580209], 
     Hue[0.634771469823243, 1, 0.12108565716781751`], 
     Hue[0.6402617139205808, 1, 0.1134837807253497], 
     Hue[0.6372287375822705, 1, 0.11768328642454866`], 
     Hue[0.6374284181878698, 1, 0.11740680558602648`], 
     Hue[0.6412362704221211, 1, 0.1121343948001401], 
     Hue[0.6350472444831297, 1, 0.12070381533105126`], 
     Hue[0.6352215027167397, 1, 0.12046253469989893`], 
     Hue[0.6398283041756684, 1, 0.11408388652599762`], 
     Hue[0.503403283302293, 1, 0.30298006927374815`], 
     Hue[0.5333361405897064, 1, 0.2615345745680989], 
     Hue[0.5664424562616147, 1, 0.21569506056084126`], 
     Hue[0.0679353813013912, 1, 0.9059356258903813], 
     Hue[0.047885200597176825`, 1, 0.9336974145577551], 
     Hue[0.5922504909487819, 1, 0.17996085868630196`], 
     Hue[0.6097172841793851, 1, 0.15577606805931293`], 
     Hue[0.16131522595825165`, 1, 0.7766404563654977], 
     Hue[0.11692358087249966`, 1, 0.8381058110996159], 
     Hue[0.08401810264688037, 1, 0.8836672424889349], 
     Hue[0.04187618502252188, 1, 0.9420175899688158], 
     Hue[0.03317441528444964, 1, 0.9540661942215312], 
     Hue[0.026151771356869302`, 1, 0.9637898550443348], 
     Hue[0.0643420093383773, 1, 0.910911063993016], 
     Hue[0.12091445235595144`, 1, 0.8325799890456056], 
     Hue[0.1717364928725038, 1, 0.7622110098688409], 
     Hue[0.1312536364389647, 1, 0.8182641956998951], 
     Hue[0.1080738381522185, 1, 0.8503593010200052], 
     Hue[0.23237998123217846`, 1, 0.6782431029092914], 
     Hue[0.19027485079418066`, 1, 0.7365425142849806], 
     Hue[0.6435309830082894, 1, 0.10895710045006093`], 
     Hue[0.6408701494623426, 1, 0.11264133151367961`], 
     Hue[0.6427108274897545, 1, 0.11009270039880154`], 
     Hue[0.639560692645466, 1, 0.11445442556781632`], 
     Hue[0.057324297183525386`, 1, 0.9206278962074264], 
     Hue[0.05966002006234772, 1, 0.9173938183752108], 
     Hue[0.05872437101704897, 1, 0.9186893324379322], 
     Hue[0.0491675076406447, 1, 0.931921912497569], 
     Hue[0.051304144553236175`, 1, 0.9289634921570575], 
     Hue[0.05455027928724032, 1, 0.9244688440638211], 
     Hue[0.0731253124557737, 1, 0.8987495673689286], 
     Hue[0.10162724457427885`, 1, 0.8592853536663831], 
     Hue[0.14755270180601643`, 1, 0.7956962590378235], 
     Hue[0.11907076634196867`, 1, 0.8351327850649665], 
     Hue[0.14485382826965654`, 1, 0.7994331608573986], 
     Hue[0.08124944942950574, 1, 0.8875007623283766], 
     Hue[0.07346248252796428, 1, 0.8982827164997417], 
     Hue[0.05967451279589753, 1, 0.9173737515133726], 
     Hue[0.09841469583734641, 1, 0.8637334980713666], 
     Hue[0.05305814868978609, 1, 0.9265348710449115], 
     Hue[0.05215215873072743, 1, 0.9277893186805313], 
     Hue[0.1326198593494079, 1, 0.8163725024392813], 
     Hue[0.12396154447899, 1, 0.8283609384137062], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999855685525, 1, 0.10000001998200422`], 
     Hue[0.6499998085900103, 1, 0.10000026502921659`], 
     Hue[0.6499969245812831, 1, 0.10000425827206963`], 
     Hue[0.6499624724015783, 1, 0.10005196129012232`], 
     Hue[0.6498853160787897, 1, 0.10015879312167579`], 
     Hue[0.6487316403817719, 1, 0.10175619024062352`], 
     Hue[0.6488893890300222, 1, 0.10153776903535382`], 
     Hue[0.6486262422763239, 1, 0.10190212607893616`], 
     Hue[0.6497596282371284, 1, 0.10033282244089921`], 
     Hue[0.6482411227995016, 1, 0.10243536843145935`], 
     Hue[0.6497155091839999, 1, 0.1003939103606156], 
     Hue[0.6477976125718761, 1, 0.1030494595158639], 
     Hue[0.6490208655724655, 1, 0.1013557245919709], 
     Hue[0.6498491264673871, 1, 0.1002089018143871], 
     Hue[0.6499948511107007, 1, 0.10000712923133766`], 
     Hue[0.6499999959955522, 1, 0.10000000554462002`], 
     Hue[0.6499999120314451, 1, 0.10000012180261444`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999929888856, 1, 0.1000000097076969], 
     Hue[0.6499980780633294, 1, 0.10000266114308241`], 
     Hue[0.6436132309772631, 1, 0.10884321864686651`], 
     Hue[0.6436765476860895, 1, 0.10875554935772223`], 
     Hue[0.6427108274897545, 1, 0.11009270039880154`], 
     Hue[0.6411866275088056, 1, 0.1122031311416538], 
     Hue[0.6386282200159651, 1, 0.1157455415163561], 
     Hue[0.6443514863190107, 1, 0.10782101894290824`], 
     Hue[0.6490192012996836, 1, 0.10135802896966893`], 
     Hue[0.6499543156918993, 1, 0.1000632551958317], 
     Hue[0.6499999953055019, 1, 0.10000000650007436`], 
     Hue[0.6499997427347268, 1, 0.10000035621345517`], 
     Hue[0.6499877325727229, 1, 0.10001698566853749`], 
     Hue[0.6292339134302047, 1, 0.1287530429427934], 
     Hue[0.6264736073428859, 1, 0.13257500521754254`], 
     Hue[0.6232775526680696, 1, 0.1370003116903652], 
     Hue[0.6214922483412532, 1, 0.13947227152749558`], 
     Hue[0.6182744456087187, 1, 0.14392769069562036`], 
     Hue[0.6097526504788033, 1, 0.1557270993370416], 
     Hue[0.6280925036738698, 1, 0.1303334564515649], 
     Hue[0.6455500985214253, 1, 0.10616140204725723`], 
     Hue[0.6497030995051547, 1, 0.10041109299286279`], 
     Hue[0.6499998918048913, 1, 0.10000014980861222`], 
     Hue[0.6499962539079677, 1, 0.10000518689666016`], 
     Hue[0.5911923048292281, 1, 0.18142603946722266`], 
     Hue[0.5813738521619448, 1, 0.1950208200834611], 
     Hue[0.5647006799981396, 1, 0.21810675077180675`], 
     Hue[0.5651820142195915, 1, 0.21744028800364257`], 
     Hue[0.5636903268097644, 1, 0.2195057013403262], 
     Hue[0.5466924059998496, 1, 0.24304128400020825`], 
     Hue[0.5888181000382094, 1, 0.18471339994709474`], 
     Hue[0.6339035261139512, 1, 0.12228742538068296`], 
     Hue[0.6484774932399666, 1, 0.10210808628312315`], 
     Hue[0.6499665035597323, 1, 0.1000463796865245], 
     Hue[0.5219056391141019, 1, 0.27736142276508957`], 
     Hue[0.4896389972037085, 1, 0.3220383115640959], 
     Hue[0.4440325970453475, 1, 0.3851856348602881], 
     Hue[0.45559408789961625`, 1, 0.36917741675437754`], 
     Hue[0.46389346996694314`, 1, 0.35768596466115576`], 
     Hue[0.4430750114864584, 1, 0.38651152255721155`], 
     Hue[0.5167277201740303, 1, 0.2845308489898041], 
     Hue[0.6062800903216063, 1, 0.160535259554699], 
     Hue[0.6427894441900026, 1, 0.10998384650615033`], 
     Hue[0.64979006416327, 1, 0.10029068038931842`], 
     Hue[0.4214900656719799, 1, 0.41639837060802787`], 
     Hue[0.35250789709030667`, 1, 0.5119121424903447], 
     Hue[0.27664051313650284`, 1, 0.6169592895033037], 
     Hue[0.30208351693774366`, 1, 0.5817305150092781], 
     Hue[0.32087636266482267`, 1, 0.555709651694861], 
     Hue[0.305335761616291, 1, 0.5772274069928278], 
     Hue[0.4115219767185829, 1, 0.430200339928116], 
     Hue[0.553045276850935, 1, 0.2342450012833208], 
     Hue[0.627833964045726, 1, 0.13069143439822561`], 
     Hue[0.6489926675785803, 1, 0.10139476796811966`], 
     Hue[0.6399766152384442, 1, 0.11387853274676969`], 
     Hue[0.43657495235407107`, 1, 0.39551160443282474`], 
     Hue[0.30182980959299976`, 1, 0.5820818021020003], 
     Hue[0.2103657776648773, 1, 0.7087243078486315], 
     Hue[0.1317246423616265, 1, 0.8176120336531325], 
     Hue[0.15381064934865035`, 1, 0.7870314085941764], 
     Hue[0.16754095746675013`, 1, 0.768020212738346], 
     Hue[0.1605767942116203, 1, 0.777662900322372], 
     Hue[0.29412916292048996`, 1, 0.5927442359562447], 
     Hue[0.47567795869104323`, 1, 0.3413689802739402], 
     Hue[0.5977000406784722, 1, 0.17241532829134626`], 
     Hue[0.6467464116551228, 1, 0.10450496847752229`], 
     Hue[0.6237462181560944, 1, 0.13635139024540777`], 
     Hue[0.32016557988232414`, 1, 0.5566938124706282], 
     Hue[0.18971349124197845`, 1, 0.7373197813572606], 
     Hue[0.11460081623478346`, 1, 0.8413219467518384], 
     Hue[0.059998825938176514`, 1, 0.9169247025471403], 
     Hue[0.06207432696715964, 1, 0.914050931891625], 
     Hue[0.1978377829173969, 1, 0.7260707621143735], 
     Hue[0.3913413176002015, 1, 0.4581427910151056], 
     Hue[0.5546709167556221, 1, 0.2319941152614463], 
     Hue[0.6424064197057776, 1, 0.11051418809969264`], 
     Hue[0.5958645560104098, 1, 0.17495676860097106`], 
     Hue[0.45297831405925437`, 1, 0.37279925745641707`], 
     Hue[0.21370803056040938`, 1, 0.7040965730702025], 
     Hue[0.07475055517029838, 1, 0.8964992313026637], 
     Hue[0.046973775791721906`, 1, 0.9349593873653081], 
     Hue[0.13224475446495831`, 1, 0.8168918784331346], 
     Hue[0.31524158913476896`, 1, 0.5635116458133969], 
     Hue[0.5106039721214096, 1, 0.29300988475497125`], 
     Hue[0.6370241824815182, 1, 0.1179665165640518], 
     Hue[0.5611370396377706, 1, 0.22304102204000986`], 
     Hue[0.38884431959634264`, 1, 0.4616001728666025], 
     Hue[0.06338016686809522, 1, 0.9122428458749451], 
     Hue[0.0407089650448792, 1, 0.9436337407070904], 
     Hue[0.041606744592537104`, 1, 0.9423906613334102], 
     Hue[0.08169583753051379, 1, 0.8868826864962116], 
     Hue[0.24532715696214324`, 1, 0.6603162442062632], 
     Hue[0.46834315701093115`, 1, 0.3515248595233261], 
     Hue[0.6335478328633152, 1, 0.12277992372771745`], 
     Hue[0.5405726469235124, 1, 0.25151479656744447`], 
     Hue[0.3381490656115057, 1, 0.5317936014609921], 
     Hue[0.05914200412801207, 1, 0.9181110712073679], 
     Hue[0.026325157562746226`, 1, 0.9635497818361975], 
     Hue[0.041007174555774295`, 1, 0.9432208352304664], 
     Hue[0.04082129656991662, 1, 0.9434782047493462], 
     Hue[0.17647552593408705`, 1, 0.7556492717835718], 
     Hue[0.43696835616612695`, 1, 0.3949668914622858], 
     Hue[0.5907862709442647, 1, 0.18198824023101817`], 
     Hue[0.6342054637024933, 1, 0.12186935795039389`], 
     Hue[0.5371186249951179, 1, 0.25629728846829847`], 
     Hue[0.3075118241717192, 1, 0.5742143973006966], 
     Hue[0.055660498015668414`, 1, 0.9229316181321514], 
     Hue[0.02866081862370662, 1, 0.9603157895979446], 
     Hue[0.018933144825165615`, 1, 0.9737848763959246], 
     Hue[0.13148292733589562`, 1, 0.8179467159964523], 
     Hue[0.41385837559306315`, 1, 0.4269653261019125], 
     Hue[0.5845120980924718, 1, 0.19067555648734671`], 
     Hue[0.6382271018784125, 1, 0.11630093586065963`], 
     Hue[0.5552023675185952, 1, 0.23125826035886826`], 
     Hue[0.2960323072529263, 1, 0.5901091130344098], 
     Hue[0.04858513419524557, 1, 0.9327282757296599], 
     Hue[0.029094758011440014`, 1, 0.9597149504456985], 
     Hue[0.014150515748235448`, 1, 0.980406978194751], 
     Hue[0.11926874651876407`, 1, 0.8348586586663266], 
     Hue[0.40748776111448703`, 1, 0.4357861769184026], 
     Hue[0.5853030657567175, 1, 0.18958037049069887`], 
     Hue[0.64274147365331, 1, 0.11005026724926313`], 
     Hue[0.5706901374950681, 1, 0.20981365577605954`], 
     Hue[0.29563653839593607`, 1, 0.5906571006825501], 
     Hue[0.041501736414209844`, 1, 0.9425360572726326], 
     Hue[0.04931922644672149, 1, 0.9317118403045395], 
     Hue[0.020173287216063485`, 1, 0.9720677561623736], 
     Hue[0.011774148565117382`, 1, 0.9836973327559914], 
     Hue[0.1229888123748285, 1, 0.8297077982502374], 
     Hue[0.40577365547430644`, 1, 0.4381595539586526], 
     Hue[0.6452471250263685, 1, 0.10658090380964365`], 
     Hue[0.5802092383561946, 1, 0.1966333622760382], 
     Hue[0.30198332693010654`, 1, 0.5818692396352371], 
     Hue[0.04587461027138351, 1, 0.9364813088550075], 
     Hue[0.06292405309673454, 1, 0.9128743880199061], 
     Hue[0.008228584232668701, 1, 0.9886065756778433], 
     Hue[0.1293029773940093, 1, 0.8209651082236794], 
     Hue[0.40200163984937987`, 1, 0.44338234482393557`], 
     Hue[0.6454546849293559, 1, 0.10629351317473812`], 
     Hue[0.5769194734928553, 1, 0.20118842131758488`], 
     Hue[0.3153211471862796, 1, 0.5634014885113052], 
     Hue[0.06365166408880463, 1, 0.9118669266462704], 
     Hue[0.0624727809512059, 1, 0.9134992263752533], 
     Hue[0.030808129440789145`, 1, 0.9573425900050612], 
     Hue[0.01392441829586688, 1, 0.9807200362057227], 
     Hue[0.13608262166002583`, 1, 0.8115779084707334], 
     Hue[0.3972220160429113, 1, 0.4500002854790459], 
     Hue[0.5977345809289127, 1, 0.1723675033291978], 
     Hue[0.6449704161337327, 1, 0.10696403919944704`], 
     Hue[0.5856887570764899, 1, 0.18904633635562945`], 
     Hue[0.335516498183694, 1, 0.5354386948225776], 
     Hue[0.07435526407128301, 1, 0.897046557439762], 
     Hue[0.05687343494673669, 1, 0.9212521669968261], 
     Hue[0.03300287431724569, 1, 0.9543037124838136], 
     Hue[0.16175744631013134`, 1, 0.776028151262895], 
     Hue[0.40391683041637805`, 1, 0.44073054250039967`], 
     Hue[0.5945609846136145, 1, 0.17676171361191842`], 
     Hue[0.6453247023565682, 1, 0.10647348904475165`], 
     Hue[0.591191212324393, 1, 0.1814275521662251], 
     Hue[0.3673754708398347, 1, 0.4913262711448443], 
     Hue[0.06045082821835357, 1, 0.9162988532361258], 
     Hue[0.053295772870045166`, 1, 0.9262058529491682], 
     Hue[0.058026228597175766`, 1, 0.9196559911731412], 
     Hue[0.20418070074396893`, 1, 0.7172882605083507], 
     Hue[0.43026035751793823`, 1, 0.4042548895905471], 
     Hue[0.6466670794188601, 1, 0.10461481311234758`], 
     Hue[0.6034581686044457, 1, 0.1644425357784598], 
     Hue[0.41558398363986415`, 1, 0.42457602265249583`], 
     Hue[0.15733387490674872`, 1, 0.7821530962829633], 
     Hue[0.04174010529027827, 1, 0.9422060080596146], 
     Hue[0.08812686207384501, 1, 0.8779781909746761], 
     Hue[0.2547022234993506, 1, 0.647335382847053], 
     Hue[0.46884151690978576`, 1, 0.35083482274029665`], 
     Hue[0.6482160045893766, 1, 0.1024701474916325], 
     Hue[0.6191297675677203, 1, 0.14274339875238734`], 
     Hue[0.4744761672424244, 1, 0.34303299920279695`], 
     Hue[0.23621067237997728`, 1, 0.6729390690123391], 
     Hue[0.06020599930938797, 1, 0.9166378471100782], 
     Hue[0.04292929180366645, 1, 0.9405594421180002], 
     Hue[0.0836874782754028, 1, 0.8841250300802115], 
     Hue[0.14251130033721027`, 1, 0.802676661071555], 
     Hue[0.3209936193235755, 1, 0.5555472963212031], 
     Hue[0.5131863279967954, 1, 0.28943431508136025`], 
     Hue[0.649284558258495, 1, 0.10099061164208392`], 
     Hue[0.6328089402945783, 1, 0.12380300574596842`], 
     Hue[0.3365239654205696, 1, 0.5340437401869036], 
     Hue[0.1771466518637385, 1, 0.754720020496362], 
     Hue[0.1394059275120093, 1, 0.8069764080602948], 
     Hue[0.08381681923256001, 1, 0.8839459426010707], 
     Hue[0.09649699163117453, 1, 0.8663887808183738], 
     Hue[0.16199790554148785`, 1, 0.775695207711786], 
     Hue[0.23779653037572096`, 1, 0.6707432656336172], 
     Hue[0.4090619007541736, 1, 0.4336065989557597], 
     Hue[0.564300286142414, 1, 0.21866114226434988`], 
     Hue[0.6497793869914988, 1, 0.10030546416561703`], 
     Hue[0.6421543835113943, 1, 0.11086316129191565`], 
     Hue[0.5845730776878278, 1, 0.1905911232014692], 
     Hue[0.4421307986531579, 1, 0.38781889417255067`], 
     Hue[0.30273196078378256`, 1, 0.5808326696839934], 
     Hue[0.26251669292035, 1, 0.6365153482641308], 
     Hue[0.19671034261050163`, 1, 0.7276318333085362], 
     Hue[0.20437123607650282`, 1, 0.7170244423556115], 
     Hue[0.2804334148997351, 1, 0.6117075793695975], 
     Hue[0.26401427692265117`, 1, 0.6344417704147907], 
     Hue[0.3566077200112886, 1, 0.5062354645997543], 
     Hue[0.49954029668937405`, 1, 0.308328819968559], 
     Hue[0.6054951211636957, 1, 0.1616221399271905], 
     Hue[0.6499463129268348, 1, 0.10007433594745953`], 
     Hue[0.6472595090929059, 1, 0.1037945258713612], 
     Hue[0.6202589440273842, 1, 0.14117992365439108`], 
     Hue[0.5345872231497928, 1, 0.2598023064079793], 
     Hue[0.4358818094356479, 1, 0.39647134078141055`], 
     Hue[0.3934841683457398, 1, 0.4551757669058988], 
     Hue[0.35435535134841495`, 1, 0.5093541289021948], 
     Hue[0.36273143039163774`, 1, 0.49775648099619396`], 
     Hue[0.4129577111538222, 1, 0.4282123999408616], 
     Hue[0.3946433353527849, 1, 0.4535707664346056], 
     Hue[0.46830489851037205`, 1, 0.35157783283179256`], 
     Hue[0.5703213967526508, 1, 0.210324219880945], 
     Hue[0.6319772222045845, 1, 0.12495461540903681`], 
     Hue[0.6499882919777111, 1, 0.10001621110778469`], 
     Hue[0.6493129109029602, 1, 0.10095135413436285`], 
     Hue[0.6394899477650373, 1, 0.11455238001764068`], 
     Hue[0.5991364025169876, 1, 0.17042651959186325`], 
     Hue[0.5412523525694353, 1, 0.2505736656730897], 
     Hue[0.5036248667392936, 1, 0.3026732614379012], 
     Hue[0.49826235434221405`, 1, 0.31009827860308825`], 
     Hue[0.5101705876061519, 1, 0.2936099556222513], 
     Hue[0.5214133211043324, 1, 0.2780430938555398], 
     Hue[0.5038363707983116, 1, 0.30238040966387636`], 
     Hue[0.5537600609228117, 1, 0.23325530026072233`], 
     Hue[0.6141480081243584, 1, 0.14964121952011913`], 
     Hue[0.6443573441203475, 1, 0.10781290814105739`], 
     Hue[0.6499983861739096, 1, 0.10000223452843299`], 
     Hue[0.6498798084719187, 1, 0.10016641903888178`], 
     Hue[0.6329458099702117, 1, 0.12361349388739928`], 
     Hue[0.6050906606383611, 1, 0.1621821621930385], 
     Hue[0.580476844083135, 1, 0.19626283126950536`], 
     Hue[0.5884562895514353, 1, 0.18521436831339744`], 
     Hue[0.5999646598186157, 1, 0.16927970178960916`], 
     Hue[0.590433155147369, 1, 0.18247716979595058`], 
     Hue[0.5778326565219114, 1, 0.19992401404658428`], 
     Hue[0.6080789925844681, 1, 0.15804447180612125`], 
     Hue[0.6370221491822815, 1, 0.11796933190145648`], 
     Hue[0.6499980232229953, 1, 0.10000273707585275`], 
     Hue[0.6499998476701447, 1, 0.10000021091826115`], 
     Hue[0.6499853114607944, 1, 0.10002033797736164`], 
     Hue[0.6355055196112366, 1, 0.12006928053828778`], 
     Hue[0.6241747305614327, 1, 0.13575806537647778`], 
     Hue[0.6298415284595332, 1, 0.12791172982526178`], 
     Hue[0.6374704864405576, 1, 0.11734855723615109`], 
     Hue[0.6272943836391766, 1, 0.13143854573037103`], 
     Hue[0.6208422851681881, 1, 0.1403722205363551], 
     Hue[0.6357867388974985, 1, 0.11967989998807904`], 
     Hue[0.6464455628119401, 1, 0.10492152841423685`], 
     Hue[0.6499998602111053, 1, 0.10000019355385414`], 
     Hue[0.649999991286051, 1, 0.10000001206546782`], 
     Hue[0.6499982619971986, 1, 0.1000024064654174], 
     Hue[0.6465893405849458, 1, 0.10472245149776738`], 
     Hue[0.6429875694268179, 1, 0.10970951925517525`], 
     Hue[0.6446630656589148, 1, 0.10738960139534877`], 
     Hue[0.6476792963742027, 1, 0.10321328194341162`], 
     Hue[0.6434877349346255, 1, 0.10901698239821078`], 
     Hue[0.6464547161315036, 1, 0.10490885458714892`], 
     Hue[0.6493241434031858, 1, 0.10093580144174275`], 
     Hue[0.6499661885261714, 1, 0.10004681588683961`], 
     Hue[0.6499992551976687, 1, 0.10000103126476644`], 
     Hue[0.649999997206145, 1, 0.10000000386841473`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499998921199264, 1, 0.10000014937240975`], 
     Hue[0.6487048014509812, 1, 0.10179335183710293`], 
     Hue[0.6489493872320349, 1, 0.10145469460179792`], 
     Hue[0.6493812627955761, 1, 0.1008567130522794], 
     Hue[0.6499090025975782, 1, 0.10012599640335326`], 
     Hue[0.6499947857550614, 1, 0.10000721972376107`], 
     Hue[0.6499999591669566, 1, 0.10000005653806004`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999969485136, 1, 0.10000000422513507`], 
     Hue[0.6499995990051164, 1, 0.10000055522368508`], 
     Hue[0.6498429406266033, 1, 0.10021746682470319`], 
     Hue[0.6499667631516982, 1, 0.10004602025149481`], 
     Hue[0.649927712385062, 1, 0.1001000905437603], 
     Hue[0.6499913231299104, 1, 0.10001201412781648`], 
     Hue[0.6499996275968155, 1, 0.10000051563517853`], 
     Hue[0.6499999993606727, 1, 0.10000000088522253`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499998106246453, 1, 0.10000026221202964`], 
     Hue[0.6489184683812524, 1, 0.10149750531826592`], 
     Hue[0.6494744179209362, 1, 0.10072772903254987`], 
     Hue[0.6492113474879239, 1, 0.10109198040133628`], 
     Hue[0.6491327098674249, 1, 0.10120086326048862`], 
     Hue[0.6499159567668522, 1, 0.10011636755358931`], 
     Hue[0.6499983356221635, 1, 0.1000023045231583], 
     Hue[0.6499999938210091, 1, 0.10000000855552584`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999929888856, 1, 0.1000000097076969], 
     Hue[0.6499981421897488, 1, 0.1000025723526555], 
     Hue[0.6444725259206253, 1, 0.10765342564836501`], 
     Hue[0.6467055444258307, 1, 0.10456155387192677`], 
     Hue[0.6456867556751186, 1, 0.10597218444983592`], 
     Hue[0.644861262378056, 1, 0.10711517516884561`], 
     Hue[0.6493915076499502, 1, 0.1008425278692997], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499997486801059, 1, 0.10000034798139182`], 
     Hue[0.649991910242851, 1, 0.10001120120220632`], 
     Hue[0.6291351184535812, 1, 0.12888983598734916`], 
     Hue[0.6313940014287721, 1, 0.1257621518678541], 
     Hue[0.6350472444831297, 1, 0.12070381533105133`], 
     Hue[0.6330724852874604, 1, 0.12343809729428559`], 
     Hue[0.6296786102276966, 1, 0.1281373089154971], 
     Hue[0.6469777954465857, 1, 0.10418459092011212`], 
     Hue[0.6499999946768531, 1, 0.10000000737051117`], 
     Hue[0.6499963553896654, 1, 0.10000504638354027`], 
     Hue[0.626587955057132, 1, 0.13241667761320183`], 
     Hue[0.58666576890809, 1, 0.18769355074264465`], 
     Hue[0.5815045550716836, 1, 0.19483984682382274`], 
     Hue[0.594795962800251, 1, 0.1764363591996525], 
     Hue[0.599734294616619, 1, 0.16959866899237375`], 
     Hue[0.5922117089780605, 1, 0.18001455679960848`], 
     Hue[0.638885787800233, 1, 0.1153889091996775], 
     Hue[0.649970882443136, 1, 0.10004031661719628`], 
     Hue[0.5861170415196884, 1, 0.1884533271265853], 
     Hue[0.49978952382278746`, 1, 0.30798373624537123`], 
     Hue[0.4792638147916879, 1, 0.3364039487499706], 
     Hue[0.5139436506769701, 1, 0.28838571444727223`], 
     Hue[0.5311791761658312, 1, 0.26452114069346455`], 
     Hue[0.5222695722189804, 1, 0.2768575153891041], 
     Hue[0.617601438367791, 1, 0.14485954687536626`], 
     Hue[0.6465583946368834, 1, 0.1047652997335462], 
     Hue[0.6498396683510507, 1, 0.10022199766777609`], 
     Hue[0.5144218900943176, 1, 0.28772353679248336`], 
     Hue[0.36747539512987476`, 1, 0.4911879144355581], 
     Hue[0.3271564840332561, 1, 0.5470140990308763], 
     Hue[0.3821059310006368, 1, 0.47093024938373373`], 
     Hue[0.418450428174881, 1, 0.42060709945016483`], 
     Hue[0.419163411642826, 1, 0.4196198915714717], 
     Hue[0.5726667468805052, 1, 0.20707681201160813`], 
     Hue[0.6372657010603978, 1, 0.11763210622406456`], 
     Hue[0.6492266004186042, 1, 0.10107086095885574`], 
     Hue[0.4132504811137626, 1, 0.42780702615017485`], 
     Hue[0.22684494678131095`, 1, 0.6859069967643387], 
     Hue[0.17795046082218285`, 1, 0.7536070542462083], 
     Hue[0.22401789640152003`, 1, 0.6898213742132799], 
     Hue[0.2726718251568572, 1, 0.6224543959366593], 
     Hue[0.3021714355005741, 1, 0.5816087816145897], 
     Hue[0.5009484110523579, 1, 0.3063791231582737], 
     Hue[0.6156495237743886, 1, 0.14756219785084657`], 
     Hue[0.6473662637322478, 1, 0.10364671175534917`], 
     Hue[0.406225284551732, 1, 0.4375342213899095], 
     Hue[0.2954147323764829, 1, 0.5909642167094853], 
     Hue[0.12521908377559188`, 1, 0.8266197301568728], 
     Hue[0.0756132419456722, 1, 0.8953047419213769], 
     Hue[0.09877508489427245, 1, 0.8632344978386998], 
     Hue[0.20331579321849097`, 1, 0.7184858247743972], 
     Hue[0.4151917854816828, 1, 0.4251190662561315], 
     Hue[0.579275047155653, 1, 0.1979268577844805], 
     Hue[0.6435345249877448, 1, 0.108952196170815], 
     Hue[0.6065132617254015, 1, 0.16021240684175178`], 
     Hue[0.07798538426543589, 1, 0.8920202371709349], 
     Hue[0.13550731810354366`, 1, 0.8123744826258626], 
     Hue[0.3340621071852493, 1, 0.5374524669742703], 
     Hue[0.5314545571262095, 1, 0.2641398439790945], 
     Hue[0.6383888902817949, 1, 0.11607692114828394`], 
     Hue[0.5740463904333991, 1, 0.20516653632298582`], 
     Hue[0.06429581960137776, 1, 0.9109750190134769], 
     Hue[0.08386747347673329, 1, 0.8838758059552924], 
     Hue[0.2619560345946706, 1, 0.6372916444073792], 
     Hue[0.4865413392722339, 1, 0.32632737639229153`], 
     Hue[0.6345402734805613, 1, 0.12140577518076136`], 
     Hue[0.5462864733953855, 1, 0.24360334452946628`], 
     Hue[0.3642912418204467, 1, 0.4955967420947661], 
     Hue[0.06003819740452432, 1, 0.9168701882091203], 
     Hue[0.04224054132610633, 1, 0.9415130966253912], 
     Hue[0.19264375174974568`, 1, 0.7332624975772752], 
     Hue[0.44967702021305744`, 1, 0.37737027970499737`], 
     Hue[0.634037409801746, 1, 0.12210204796681315`], 
     Hue[0.538137266093415, 1, 0.2548868623321947], 
     Hue[0.3215692403514731, 1, 0.554750282590268], 
     Hue[0.05702528750551206, 1, 0.9210419096077526], 
     Hue[0.019191942847292642`, 1, 0.9734265406729794], 
     Hue[0.14075158446557656`, 1, 0.8051131907399709], 
     Hue[0.42632027932993966`, 1, 0.40971038246623737`], 
     Hue[0.5887435857812691, 1, 0.18481657353362754`], 
     Hue[0.6377310666411495, 1, 0.11698775388148536`], 
     Hue[0.5488093407943893, 1, 0.24011014351546114`], 
     Hue[0.05042083322873636, 1, 0.930186538606365], 
     Hue[0.013994591492208941`, 1, 0.98062287331848], 
     Hue[0.1173558015428744, 1, 0.8375073517098662], 
     Hue[0.4120228306068672, 1, 0.42950684992895327`], 
     Hue[0.584992650164194, 1, 0.19001017669573145`], 
     Hue[0.6424070324051833, 1, 0.11051333974666937`], 
     Hue[0.5651429244254538, 1, 0.21749441233398706`], 
     Hue[0.29475692386260643`, 1, 0.5918750284979296], 
     Hue[0.04226839804815652, 1, 0.9414745257794757], 
     Hue[0.043004823165668005`, 1, 0.940454860232152], 
     Hue[0.011897386660162601`, 1, 0.9835266953936209], 
     Hue[0.12173224651036996`, 1, 0.8314476586779492], 
     Hue[0.40682103007237713`, 1, 0.4367093429767086], 
     Hue[0.6452604186370224, 1, 0.10656249727181505`], 
     Hue[0.5773114577810954, 1, 0.20064567384156026`], 
     Hue[0.2987144420089265, 1, 0.5863953879876402], 
     Hue[0.044332359685107514`, 1, 0.9386167327436974], 
     Hue[0.008434943783681259, 1, 0.988320847068749], 
     Hue[0.12442509281335168`, 1, 0.827719102258436], 
     Hue[0.4042382215278098, 1, 0.4402855394230326], 
     Hue[0.6457656987905932, 1, 0.10586287859764028`], 
     Hue[0.5832445301923442, 1, 0.19243065050290797`], 
     Hue[0.30847090163720275`, 1, 0.5728864438869501], 
     Hue[0.06130303962047057, 1, 0.91511886821781], 
     Hue[0.03209592920180482, 1, 0.9555594826436549], 
     Hue[0.013280100865527, 1, 0.9816121680323473], 
     Hue[0.13374602920180256`, 1, 0.8148131903359657], 
     Hue[0.39884973973206134`, 1, 0.44774651421714584`], 
     Hue[0.6452857850001147, 1, 0.10652737461522582`], 
     Hue[0.5853855670130665, 1, 0.1894661379819078], 
     Hue[0.32498912865636825`, 1, 0.550015052629644], 
     Hue[0.07419846404210206, 1, 0.897263665172474], 
     Hue[0.03140738495719286, 1, 0.956512851597733], 
     Hue[0.1508812403701969, 1, 0.7910875133335735], 
     Hue[0.3977715484729414, 1, 0.44923939442208116`], 
     Hue[0.596739657579778, 1, 0.1737450895049229], 
     Hue[0.6452464878282621, 1, 0.10658178608394475`], 
     Hue[0.5890846179724005, 1, 0.1843443751151378], 
     Hue[0.3515200210649462, 1, 0.5132799708331515], 
     Hue[0.06339088954651728, 1, 0.9122279990894376], 
     Hue[0.05629378907743121, 1, 0.9220547535850953], 
     Hue[0.19097013545834673`, 1, 0.7355798124422892], 
     Hue[0.41419282825373194`, 1, 0.42650223780252505`], 
     Hue[0.6466255106496794, 1, 0.10467236986967463`], 
     Hue[0.5989855186472473, 1, 0.17063543571919615`], 
     Hue[0.3929183027780588, 1, 0.45595927307653406`], 
     Hue[0.04294201063550407, 1, 0.9405418314277636], 
     Hue[0.08591587259902056, 1, 0.8810395610167407], 
     Hue[0.24008073716074896`, 1, 0.6675805177774246], 
     Hue[0.44804512105616645`, 1, 0.37962983238376957`], 
     Hue[0.64812032772274, 1, 0.10260262315312933`], 
     Hue[0.6139761470200836, 1, 0.14987918104911505`], 
     Hue[0.44829225086508795`, 1, 0.37928765264833986`], 
     Hue[0.05549482154611085, 1, 0.9231610163207696], 
     Hue[0.13918838910544806`, 1, 0.8072776150847643], 
     Hue[0.30367759559068946`, 1, 0.5795233291821223], 
     Hue[0.4961219719021409, 1, 0.31306188505857424`], 
     Hue[0.6492199984736929, 1, 0.10108000211334832`], 
     Hue[0.2609630197616295, 1, 0.6386665880223591], 
     Hue[0.1278122916866613, 1, 0.8230291345876997], 
     Hue[0.07337923378810396, 1, 0.8983979839857023], 
     Hue[0.23120442623515186`, 1, 0.6798707944436359], 
     Hue[0.3840950236972893, 1, 0.46817612103452255`], 
     Hue[0.5429338381367355, 1, 0.2482454548875971], 
     Hue[0.6497544980443819, 1, 0.10033992578470208`], 
     Hue[0.3660654575882447, 1, 0.49314013564704584`], 
     Hue[0.24672915534181133`, 1, 0.6583750156805689], 
     Hue[0.1547302755305049, 1, 0.7857580800346855], 
     Hue[0.13823210915864803`, 1, 0.8086016950111027], 
     Hue[0.349118697361691, 1, 0.5166048805761202], 
     Hue[0.4727088745175573, 1, 0.3454800198987669], 
     Hue[0.6499395448229044, 1, 0.10008370716828632`], 
     Hue[0.6067710899650721, 1, 0.15985541389451557`], 
     Hue[0.47088971663978363`, 1, 0.3479988538833766], 
     Hue[0.3110042941470614, 1, 0.5693786696425304], 
     Hue[0.3769395016191829, 1, 0.4780837669888237], 
     Hue[0.30832506213197247`, 1, 0.5730883755095766], 
     Hue[0.2810498698046127, 1, 0.6108540264243824], 
     Hue[0.46024160079529547`, 1, 0.36274239889882165`], 
     Hue[0.55300560700737, 1, 0.2342999287590261], 
     Hue[0.6499881504927991, 1, 0.10001640700997043`], 
     Hue[0.6488858476306787, 1, 0.10154267251136802`], 
     Hue[0.6329432274589821, 1, 0.12361706967217867`], 
     Hue[0.5562609553180339, 1, 0.2297925234057993], 
     Hue[0.44259600776914376`, 1, 0.38717475847349336`], 
     Hue[0.49019647007230266`, 1, 0.3212664260537348], 
     Hue[0.45791735343022777`, 1, 0.3659605875581462], 
     Hue[0.4319718472869306, 1, 0.40188513452578845`], 
     Hue[0.40778475221966504`, 1, 0.43537495846507923`], 
     Hue[0.5471893524893718, 1, 0.24235320424548518`], 
     Hue[0.605830801538028, 1, 0.1611573517165766], 
     Hue[0.6499983385819378, 1, 0.10000230042500927`], 
     Hue[0.6112461399379394, 1, 0.1536591908551609], 
     Hue[0.5457169332483843, 1, 0.24439193857916017`], 
     Hue[0.5715476827252373, 1, 0.20862628545736378`], 
     Hue[0.5621595898447864, 1, 0.22162518329183428`], 
     Hue[0.5519450226495959, 1, 0.23576843017748264`], 
     Hue[0.5123917233359839, 1, 0.2905345369194069], 
     Hue[0.6047562008540697, 1, 0.1626452603559036], 
     Hue[0.633119930420021, 1, 0.12337240403381708`], 
     Hue[0.6499998364423862, 1, 0.10000022646438833`], 
     Hue[0.6075124776144403, 1, 0.15882887714923652`], 
     Hue[0.6193310966092745, 1, 0.14246463546408142`], 
     Hue[0.6163590572764938, 1, 0.14657976684793173`], 
     Hue[0.6240461007928988, 1, 0.1359361681329094], 
     Hue[0.5824276447089135, 1, 0.19356172271073524`], 
     Hue[0.6341683656905344, 1, 0.12192072442849086`], 
     Hue[0.6450562435002994, 1, 0.1068452013072778], 
     Hue[0.649998059876671, 1, 0.10000268632460936`], 
     Hue[0.6499999904576685, 1, 0.10000001321245894`], 
     Hue[0.6499971158246362, 1, 0.1000039934735808], 
     Hue[0.6413143460147877, 1, 0.11202629013337102`], 
     Hue[0.6410775412094368, 1, 0.11235417371001065`], 
     Hue[0.6458590511833882, 1, 0.10573362143838569`], 
     Hue[0.6489484724765117, 1, 0.10145596118636857`], 
     Hue[0.6499998618695754, 1, 0.10000019125751106`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499998114324185, 1, 0.10000026109357443`], 
     Hue[0.6483313390400722, 1, 0.10231045363682315`], 
     Hue[0.6479754035894586, 1, 0.10280328733767276`], 
     Hue[0.6492780480528788, 1, 0.10099962577293704`], 
     Hue[0.6498441776198002, 1, 0.10021575406489204`], 
     Hue[0.6499893728994065, 1, 0.10001471444697566`], 
     Hue[0.6499992907575683, 1, 0.10000098202798226`], 
     Hue[0.649999997206145, 1, 0.10000000386841473`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999934358572, 1, 0.10000000908881312`], 
     Hue[0.6497848330418637, 1, 0.10029792348049646`], 
     Hue[0.6499112908278863, 1, 0.10012282808446515`], 
     Hue[0.6499844425789807, 1, 0.10002154104448831`], 
     Hue[0.6499953565139376, 1, 0.10000642944224034`], 
     Hue[0.6499999591669566, 1, 0.10000005653806004`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499324527590057, 1, 0.10009352694906906`], 
     Hue[0.6497943481566071, 1, 0.10028474870623633`], 
     Hue[0.6499607754956357, 1, 0.10005431085219674`], 
     Hue[0.6499496398883832, 1, 0.10006972938531568`], 
     Hue[0.6499447400852516, 1, 0.10007651372811323`], 
     Hue[0.6494382216208568, 1, 0.10077784698650598`], 
     Hue[0.6486185620563141, 1, 0.10191276022971901`], 
     Hue[0.6496797987617657, 1, 0.10044335556063207`], 
     Hue[0.6499854401877119, 1, 0.10002015974009129`], 
     Hue[0.6497285164617064, 1, 0.10037590028379123`], 
     Hue[0.6496888622054784, 1, 0.10043080617703001`], 
     Hue[0.6469290670520219, 1, 0.10425206100489275`], 
     Hue[0.6439245633532764, 1, 0.10841214304930961`], 
     Hue[0.649883576244067, 1, 0.10016120212359952`], 
     Hue[0.6499753915284763, 1, 0.10003407326826368`], 
     Hue[0.6487851573598815, 1, 0.10168208980939483`], 
     Hue[0.6486179250004243, 1, 0.10191364230710491`], 
     Hue[0.6384967560196012, 1, 0.1159275685882445], 
     Hue[0.6306100024699105, 1, 0.12684768888781625`], 
     Hue[0.6493349563454849, 1, 0.10092082967548249`], 
     Hue[0.649977890985136, 1, 0.10003061248211942`], 
     Hue[0.6499407226267707, 1, 0.10008207636293287`], 
     Hue[0.6498076585938817, 1, 0.1002663188700101], 
     Hue[0.6453736750794219, 1, 0.106405680659262], 
     Hue[0.6447597355006577, 1, 0.10725575084524322`], 
     Hue[0.6182689374550845, 1, 0.14393531736988308`], 
     Hue[0.601943974690413, 1, 0.16653911196712046`], 
     Hue[0.6498220586249283, 1, 0.10024638036548392`], 
     Hue[0.6496120284755279, 1, 0.10053719134157678`], 
     Hue[0.6488914511935538, 1, 0.10153491373200235`], 
     Hue[0.6347783794036009, 1, 0.12107609005655254`], 
     Hue[0.632957146218715, 1, 0.12359779754331765`], 
     Hue[0.5762455004366276, 1, 0.20212161478005414`], 
     Hue[0.5490250914210729, 1, 0.23981141187851449`], 
     Hue[0.6490388348826471, 1, 0.10133084400864242`], 
     Hue[0.6484961781941342, 1, 0.10208221480812192`], 
     Hue[0.6453618063049665, 1, 0.1064221143469694], 
     Hue[0.608750891345709, 1, 0.1571141504444029], 
     Hue[0.6047744480126694, 1, 0.16261999505938074`], 
     Hue[0.6463740115169911, 1, 0.10502059943801231`], 
     Hue[0.6449971409709293, 1, 0.10692703557871337`], 
     Hue[0.6355032613338163, 1, 0.12007240738394673`], 
     Hue[0.5613896370005482, 1, 0.22269127184539475`], 
     Hue[0.5550058478110469, 1, 0.23153036456931972`], 
     Hue[0.640376967009775, 1, 0.11332419952492696`], 
     Hue[0.6378794275947982, 1, 0.11678233102258714`], 
     Hue[0.6150717443857258, 1, 0.14836220008130283`], 
     Hue[0.4966996492509248, 1, 0.3122620241141042], 
     Hue[0.48984258818301873`, 1, 0.32175641636197416`], 
     Hue[0.18458328754737768`, 1, 0.7444231403190156], 
     Hue[0.11422458858475326`, 1, 0.8418428773441878], 
     Hue[0.10748847595058708`, 1, 0.8511698025299563], 
     Hue[0.052360264138277546`, 1, 0.9275011727316157], 
     Hue[0.630291258305634, 1, 0.1272890269614298], 
     Hue[0.6258230365377624, 1, 0.13347579556309824`], 
     Hue[0.5840924029575036, 1, 0.1912566728280719], 
     Hue[0.07097692306399772, 1, 0.9017242603729262], 
     Hue[0.03827518130522878, 1, 0.947003595115837], 
     Hue[0.6365531728162829, 1, 0.11861868379283916`], 
     Hue[0.5533173558696124, 1, 0.23386827648822897`], 
     Hue[0.12076334004688571`, 1, 0.8327892214735428], 
     Hue[0.10106436155238663`, 1, 0.8600647301582339], 
     Hue[0.04305999072090727, 1, 0.9403784743864361], 
     Hue[0.08510984988615111, 1, 0.8821555924653293], 
     Hue[0.0955673263849145, 1, 0.8676760096208876], 
     Hue[0.09188459976188834, 1, 0.8727751695604623], 
     Hue[0.08038262198421309, 1, 0.8887009849449358], 
     Hue[0.0228460474572193, 1, 0.968367011213081], 
     Hue[0.10403247325179388`, 1, 0.8559550370359776], 
     Hue[0.1017073617808616, 1, 0.8591744221495763], 
     Hue[0.06444412253995546, 1, 0.9107696764831386], 
     Hue[0.6345728827186761, 1, 0.12136062392798697`], 
     Hue[0.07716389777998445, 1, 0.8931576799969446], 
     Hue[0.07337355094079945, 1, 0.8984058525435084], 
     Hue[0.021954692203700166`, 1, 0.9696011954102614], 
     Hue[0.0635635586572576, 1, 0.9119889187822587], 
     Hue[0.017011821701268914`, 1, 0.9764451699520893], 
     Hue[0.05909294780758001, 1, 0.9181789953433508], 
     Hue[0.039095499906262154`, 1, 0.9458677693605602], 
     Hue[0.6426926758498632, 1, 0.1101178334386509], 
     Hue[0.07370672850149407, 1, 0.8979445297671621], 
     Hue[0.07615636081497301, 1, 0.894552731179268], 
     Hue[0.03351241254973192, 1, 0.9535981980080636], 
     Hue[0.07407245728647083, 1, 0.8974381360648866], 
     Hue[0.07546016081335771, 1, 0.8955167004122739], 
     Hue[0.06465912215230796, 1, 0.910471984712189], 
     Hue[0.03209592920180471, 1, 0.955559482643655], 
     Hue[0.060966991134431936`, 1, 0.9155841661215558], 
     Hue[0.02860812938543411, 1, 0.9603887439278604], 
     Hue[0.004467268988803674, 1, 0.9938145506308872], 
     Hue[0.002640336054215986, 1, 0.996344150078778], 
     Hue[0.05567405391634028, 1, 0.9229128484235289], 
     Hue[0.03341036005911768, 1, 0.9537395014566062], 
     Hue[0.019425057243391608`, 1, 0.9731037668937655], 
     Hue[0.6454534972712916, 1, 0.10629515762436548`], 
     Hue[0.0511849875064907, 1, 0.9291284788371668], 
     Hue[0.05062406090060767, 1, 0.9299051464453124], 
     Hue[0.022088212565692822`, 1, 0.9694163210628869], 
     Hue[0.6009637598642246, 1, 0.16789633249568914`], 
     Hue[0.6040750898127217, 1, 0.1635883371823853], 
     Hue[0.042657782665863175`, 1, 0.9409353778472664], 
     Hue[0.06041538696646587, 1, 0.9163479257387396], 
     Hue[0.09032245959870833, 1, 0.874938132863327], 
     Hue[0.6109042551988951, 1, 0.15413256972460682`], 
     Hue[0.6154287785788516, 1, 0.14786784504466705`], 
     Hue[0.07337923378810374, 1, 0.8983979839857025], 
     Hue[0.5382784777828574, 1, 0.2546913384545052], 
     Hue[0.625256711631609, 1, 0.13425993774084918`], 
     Hue[0.6290934003914134, 1, 0.128947599458043], 
     Hue[0.6369717887683298, 1, 0.11803906170538947`], 
     Hue[0.5843048016809896, 1, 0.19096258228786056`], 
     Hue[0.6376442074413268, 1, 0.1171080204658552], 
     Hue[0.6404064322729925, 1, 0.11328340146816422`], 
     Hue[0.6445483872786331, 1, 0.10754838684496956`], 
     Hue[0.5209808323869097, 1, 0.2786419243873558], 
     Hue[0.6194114421690536, 1, 0.14235338776592577`], 
     Hue[0.6454757929787741, 1, 0.10626428664477437`], 
     Hue[0.6468078131392214, 1, 0.10441995103800109`], 
     Hue[0.6482946621782938, 1, 0.10236123698390087`], 
     Hue[0.5841927835358766, 1, 0.19111768433494014`], 
     Hue[0.6389688105289337, 1, 0.11527395465224563`], 
     Hue[0.6488196302791482, 1, 0.10163435807502554`], 
     Hue[0.6492526203315294, 1, 0.10103483338711314`], 
     Hue[0.649978227027782, 1, 0.10003014719230201`], 
     Hue[0.6496222277803081, 1, 0.10052306922726582`], 
     Hue[0.6220180309619526, 1, 0.13874426482191177`], 
     Hue[0.6469324722543273, 1, 0.10424734610939311`], 
     Hue[0.649782017164924, 1, 0.10030182238702834`], 
     Hue[0.6498767361803058, 1, 0.10017067298111498`], 
     Hue[0.6499211706692806, 1, 0.10010914830407308`], 
     Hue[0.6104700040408073, 1, 0.15473384055888229`], 
     Hue[0.6493466885104066, 1, 0.10090458513943705`], 
     Hue[0.6499712480469302, 1, 0.10003981039655825`], 
     Hue[0.6499854234920832, 1, 0.10002018285711553`], 
     Hue[0.6498226217789349, 1, 0.10024560061378245`], 
     Hue[0.6498449429634574, 1, 0.10021469435828984`], 
     Hue[0.623609724258807, 1, 0.1365403817954981], 
     Hue[0.6393674623230721, 1, 0.11472197524497714`], 
     Hue[0.6368082385182318, 1, 0.11826551589783305`], 
     Hue[0.6498957082634949, 1, 0.1001444039428533], 
     Hue[0.6499809692136566, 1, 0.10002635031955254`], 
     Hue[0.6499836976424419, 1, 0.10002257249508055`], 
     Hue[0.6495720203421957, 1, 0.1005925872184983], 
     Hue[0.6498497708133715, 1, 0.10020800964302418`], 
     Hue[0.6466062674091917, 1, 0.1046990143565039], 
     Hue[0.6421806965663938, 1, 0.11082672783114719`], 
     Hue[0.6476265696206204, 1, 0.1032862882176026], 
     Hue[0.646772782825982, 1, 0.10446845454864033`], 
     Hue[0.64998793636516, 1, 0.100016703494394], 
     Hue[0.649951928607446, 1, 0.10006656038969021`], 
     Hue[0.649978895943447, 1, 0.10002922100138104`], 
     Hue[0.6494068673621977, 1, 0.10082126057541871`], 
     Hue[0.6492733741333361, 1, 0.10100609735384244`], 
     Hue[0.6496495199903992, 1, 0.10048528001329338`], 
     Hue[0.6484009095853388, 1, 0.10221412518953085`], 
     Hue[0.649993696992432, 1, 0.10000872724124799`], 
     Hue[0.6499929982963744, 1, 0.10000969466655867`], 
     Hue[0.649980794444464, 1, 0.10002659230766522`], 
     Hue[0.6496555240543804, 1, 0.10047696669393485`], 
     Hue[0.6488512458053037, 1, 0.10159058273111787`], 
     Hue[0.6450622824670815, 1, 0.10683683966096404`], 
     Hue[0.6497185631888844, 1, 0.1003896817384678], 
     Hue[0.6479940077924463, 1, 0.10277752767199737`], 
     Hue[0.6481023283676373, 1, 0.10262754533711768`], 
     Hue[0.6496543308167051, 1, 0.10047861886917753`], 
     Hue[0.6499482685600367, 1, 0.10007162814764155`], 
     Hue[0.6498749970033215, 1, 0.10017308107232409`], 
     Hue[0.6478968658253802, 1, 0.10291203193408902`], 
     Hue[0.6470403216390381, 1, 0.10409801619210114`], 
     Hue[0.6399964163991237, 1, 0.11385111575505952`], 
     Hue[0.6475209372324455, 1, 0.10343254844738312`], 
     Hue[0.6499974571236018, 1, 0.10000352090578218`], 
     Hue[0.6499960106658248, 1, 0.10000552369347346`], 
     Hue[0.6493773914426942, 1, 0.10086207338703884`], 
     Hue[0.6455466178668718, 1, 0.10616622141510057`], 
     Hue[0.6413935595352617, 1, 0.11191660987425307`], 
     Hue[0.6358399389952557, 1, 0.1196062383142614], 
     Hue[0.6137529049442676, 1, 0.15018828546178342`], 
     Hue[0.6482424932415111, 1, 0.10243347089636931`], 
     Hue[0.6474515136038154, 1, 0.10352867347164034`], 
     Hue[0.6346848645172317, 1, 0.12120557220690989`], 
     Hue[0.6246245709552922, 1, 0.13513520944651855`], 
     Hue[0.602887211082016, 1, 0.1652330923479779], 
     Hue[0.5547863150618229, 1, 0.23183433299132228`], 
     Hue[0.6256279705588261, 1, 0.1337458869185484], 
     Hue[0.6499950552952017, 1, 0.10000684651433601`], 
     Hue[0.6499887196970034, 1, 0.10001561888107224`], 
     Hue[0.6408694228605922, 1, 0.11264233757764155`], 
     Hue[0.6103467504767762, 1, 0.1549044993398484], 
     Hue[0.5907948019110371, 1, 0.18197642812317955`], 
     Hue[0.5345268126026144, 1, 0.2598859517809955], 
     Hue[0.4555871125783231, 1, 0.3691870748915528], 
     Hue[0.5841774237769684, 1, 0.19113895169342848`], 
     Hue[0.6499145826729483, 1, 0.10011827014514851`], 
     Hue[0.6485798878268384, 1, 0.10196630916283911`], 
     Hue[0.6338432929341848, 1, 0.12237082516805174`], 
     Hue[0.622789861828791, 1, 0.13767557592936625`], 
     Hue[0.5646368796170913, 1, 0.21819508976095053`], 
     Hue[0.5074657345789182, 1, 0.2973551367368825], 
     Hue[0.46269759774519803`, 1, 0.3593417877374182], 
     Hue[0.4261316549929124, 1, 0.4099715546251982], 
     Hue[0.32116904354575787`, 1, 0.5553044012443352], 
     Hue[0.64755039969914, 1, 0.10339175426272929`], 
     Hue[0.649529879183105, 1, 0.10065093651570074`], 
     Hue[0.6443787121333309, 1, 0.10778332166154184`], 
     Hue[0.6066578289943158, 1, 0.1600122367771013], 
     Hue[0.5849287730998062, 1, 0.19009862186180687`], 
     Hue[0.28630868428500034`, 1, 0.6035725909899996], 
     Hue[0.17601632236114179`, 1, 0.7562850921153421], 
     Hue[0.6427594562974508, 1, 0.11002536820352965`], 
     Hue[0.649914769572667, 1, 0.10011801136092266`], 
     Hue[0.649836059298579, 1, 0.10022699481735214`], 
     Hue[0.6481125658562185, 1, 0.10261337035292827`], 
     Hue[0.633270734622622, 1, 0.12316359821483118`], 
     Hue[0.5579305883854162, 1, 0.2274807237740391], 
     Hue[0.5268501001978081, 1, 0.270515245879958], 
     Hue[0.19656515992391588`, 1, 0.7278328554899626], 
     Hue[0.0999371769738816, 1, 0.8616254472669331], 
     Hue[0.13026161557382498`, 1, 0.8196377630516269], 
     Hue[0.09092649201324943, 1, 0.8741017802893469], 
     Hue[0.05007880522369801, 1, 0.9306601158441103], 
     Hue[0.04203887387041749, 1, 0.9417923284871141], 
     Hue[0.14461757826044808`, 1, 0.7997602762547642], 
     Hue[0.6340240312996479, 1, 0.12212057204664134`], 
     Hue[0.649698849662652, 1, 0.10041697739017423`], 
     Hue[0.6494671061685995, 1, 0.10073785299732388`], 
     Hue[0.6448283007430161, 1, 0.10716081435582385`], 
     Hue[0.6111662474777846, 1, 0.15376981118460603`], 
     Hue[0.4933926985337477, 1, 0.3168408789532725], 
     Hue[0.2885424455111663, 1, 0.6004796908306929], 
     Hue[0.23468980178432336`, 1, 0.6750448898370908], 
     Hue[0.14508136771729985`, 1, 0.7991181062375848], 
     Hue[0.1106828888962188, 1, 0.8467467692206202], 
     Hue[0.04284246034685857, 1, 0.940679670288965], 
     Hue[0.04974082154264614, 1, 0.9311280932486439], 
     Hue[0.06186759691103805, 1, 0.9143371735077935], 
     Hue[0.027434504120049996`, 1, 0.9620137635260847], 
     Hue[0.5360700548166188, 1, 0.25774915486929706`], 
     Hue[0.490740480714975, 1, 0.32051318054849615`], 
     Hue[0.6165246442593834, 1, 0.1463504925639308], 
     Hue[0.6117586270836248, 1, 0.15294959326882712`], 
     Hue[0.6490893255258984, 1, 0.10126093388721763`], 
     Hue[0.6485026908745868, 1, 0.10207319725057223`], 
     Hue[0.6396864053249477, 1, 0.11428036185776475`], 
     Hue[0.5790117352220479, 1, 0.19829144353870304`], 
     Hue[0.42961028632410747`, 1, 0.40515498816662043`], 
     Hue[0.4224595247855797, 1, 0.41505604260458207`], 
     Hue[0.189237269557973, 1, 0.737979165227422], 
     Hue[0.14826934081387355`, 1, 0.7947039896423289], 
     Hue[0.13617768783732298`, 1, 0.8114462783790913], 
     Hue[0.08592875696253988, 1, 0.881021721128791], 
     Hue[0.04588234370284583, 1, 0.9364706010268289], 
     Hue[0.03827518130522878, 1, 0.947003595115837], 
     Hue[0.05412507208382933, 1, 0.9250575924993133], 
     Hue[0.022730454310887938`, 1, 0.9685270632618475], 
     Hue[0.03545556920487225, 1, 0.9509076734086385], 
     Hue[0.12955845579886116`, 1, 0.8206113688938845], 
     Hue[0.45255769598815887`, 1, 0.3733816517087031], 
     Hue[0.6476505444651581, 1, 0.10325309227901182`], 
     Hue[0.6465159256265679, 1, 0.10482410297859829`], 
     Hue[0.6348505142685872, 1, 0.12097621101272543`], 
     Hue[0.1127768992689604, 1, 0.8438473702429778], 
     Hue[0.09623186385119775, 1, 0.8667558808214185], 
     Hue[0.05940759743919277, 1, 0.9177433266226562], 
     Hue[0.03655187561267037, 1, 0.9493897106901487], 
     Hue[0.035704891538800854`, 1, 0.9505624578693527], 
     Hue[0.08964929401124955, 1, 0.875870208292116], 
     Hue[0.06299900858047336, 1, 0.91277060350396], 
     Hue[0.42761614518278784`, 1, 0.4079161066699861], 
     Hue[0.64516287345455, 1, 0.10669755983216145`], 
     Hue[0.6434849674865389, 1, 0.10902081424940772`], 
     Hue[0.6420389900742204, 1, 0.11102293682031025`], 
     Hue[0.085032145369479, 1, 0.8822631833345674], 
     Hue[0.07805012652431187, 1, 0.8919305940432605], 
     Hue[0.04895499805427739, 1, 0.9322161565402314], 
     Hue[0.01972319384525456, 1, 0.9726909623681091], 
     Hue[0.035704891538800854`, 1, 0.9505624578693527], 
     Hue[0.0902109364015714, 1, 0.8750925495978242], 
     Hue[0.07962559569032024, 1, 0.8897491751980181], 
     Hue[0.641857175665499, 1, 0.11127467984777055`], 
     Hue[0.07383842485543157, 1, 0.8977621809694024], 
     Hue[0.07281066895396882, 1, 0.899185227602197], 
     Hue[0.039826630266601715`, 1, 0.9448554350154745], 
     Hue[0.052617030849134716`, 1, 0.9271456495935058], 
     Hue[0.08409589404587503, 1, 0.8835595313210962], 
     Hue[0.01493825292723261, 1, 0.979316265177678], 
     Hue[0.640617165234838, 1, 0.11299161736714734`], 
     Hue[0.032195330250696985`, 1, 0.9554218504221118], 
     Hue[0.0353135342515305, 1, 0.9511043371901885], 
     Hue[0.025491634684399966`, 1, 0.9647038904369846], 
     Hue[0.060122143875246725`, 1, 0.9167539546342737], 
     Hue[0.0508419474930395, 1, 0.92960345731733], 
     Hue[0.03617660892137964, 1, 0.9499093107242436], 
     Hue[0.013347756256090415`, 1, 0.9815184913377211], 
     Hue[0.6435206988847543, 1, 0.10897134000572492`], 
     Hue[0.644787794939086, 1, 0.10721689931511168`], 
     Hue[0.07530075960670524, 1, 0.8957374097753312], 
     Hue[0.03374975633330779, 1, 0.9532695681538815], 
     Hue[0.03698060603672482, 1, 0.9487960839491503], 
     Hue[0.05526563186028988, 1, 0.9234783558857526], 
     Hue[0.05780633329080531, 1, 0.9199604615973466], 
     Hue[0.025491634684400077`, 1, 0.9647038904369846], 
     Hue[0.03462645246884977, 1, 0.9520556811969773], 
     Hue[0.028405985744116458`, 1, 0.960668635123531], 
     Hue[0.5983108699745935, 1, 0.17156956465056283`], 
     Hue[0.600076493024638, 1, 0.16912485581203984`], 
     Hue[0.6459502293923701, 1, 0.10560737468748754`], 
     Hue[0.6468936016966582, 1, 0.10430116688155022`], 
     Hue[0.03984505433008301, 1, 0.9448299247737312], 
     Hue[0.016676882452590913`, 1, 0.9769089319887203], 
     Hue[0.01268847194288869, 1, 0.9824313465406156], 
     Hue[0.009886219638919225, 1, 0.9863113881922657], 
     Hue[0.009361873765496798, 1, 0.9870374055554659], 
     Hue[0.647181969212105, 1, 0.10390188878323918`], 
     Hue[0.0726100573001558, 1, 0.8994629975843997], 
     Hue[0.0749642298875528, 1, 0.8962033740018499], 
     Hue[0.03829456795145403, 1, 0.9469767520672175], 
     Hue[0.0715815901881639, 1, 0.9008870289702345], 
     Hue[0.003918657428684913, 1, 0.9945741666372054], 
     Hue[0.008380799025688446, 1, 0.9883958167336621], 
     Hue[0.010109852113697304`, 1, 0.9860017432271884], 
     Hue[0.013392872240578613`, 1, 0.9814560230515065], 
     Hue[0.02221657778216901, 1, 0.9692385846093045], 
     Hue[0.1378774443161318, 1, 0.8090927694084329], 
     Hue[0.5866706125545822, 1, 0.18768684415519393`], 
     Hue[0.5945774354187181, 1, 0.1767389355740827], 
     Hue[0.08121293919220995, 1, 0.8875513149646324], 
     Hue[0.09666621809206044, 1, 0.8661544672571471], 
     Hue[0.028243584067817018`, 1, 0.9608934989830226], 
     Hue[0.07036164712686577, 1, 0.9025761809012628], 
     Hue[0.017231037834268492`, 1, 0.976141639921782], 
     Hue[0.02085981093233724, 1, 0.9711171848629176], 
     Hue[0.04500910074330067, 1, 0.9376797066631221], 
     Hue[0.16879117376478225`, 1, 0.7662891440179939], 
     Hue[0.6459123098374758, 1, 0.10565987868657198`], 
     Hue[0.6085511365505746, 1, 0.15739073400689685`], 
     Hue[0.028769370423728957`, 1, 0.9601654871056061], 
     Hue[0.01985313082848894, 1, 0.9725110496220923], 
     Hue[0.029746104536194418`, 1, 0.9588130860268077], 
     Hue[0.02487145999000473, 1, 0.9655625938599934], 
     Hue[0.07141379022196914, 1, 0.9011193673849658], 
     Hue[0.21407021372874913`, 1, 0.7035950886832705], 
     Hue[0.6474708302686111, 1, 0.10350192732038466`], 
     Hue[0.6238777963461348, 1, 0.13616920505919797`], 
     Hue[0.04392440479253046, 1, 0.9391815933641886], 
     Hue[0.05175826284875518, 1, 0.9283347129786467], 
     Hue[0.04391566454050155, 1, 0.9391936952516133], 
     Hue[0.11067556418812097`, 1, 0.8467569111241402], 
     Hue[0.1472551651043208, 1, 0.7961082329324789], 
     Hue[0.49152321029638035`, 1, 0.3194294011280888], 
     Hue[0.4937786114459339, 1, 0.31630653799793773`], 
     Hue[0.6130703880879496, 1, 0.15113330880130071`], 
     Hue[0.6198946367472027, 1, 0.14168434911925792`], 
     Hue[0.6467873751710465, 1, 0.10444824976316648`], 
     Hue[0.6474265169845311, 1, 0.1035632841752647], 
     Hue[0.6488299010528167, 1, 0.10162013700379235`], 
     Hue[0.09171961870665135, 1, 0.8730036048677136], 
     Hue[0.17025425179874792`, 1, 0.7642633436632721], 
     Hue[0.1382321091586476, 1, 0.8086016950111032], 
     Hue[0.0976368124231155, 1, 0.8648105674141477], 
     Hue[0.5406459829322725, 1, 0.2514132544014689], 
     Hue[0.6268653987678943, 1, 0.1320325247829157], 
     Hue[0.6333724953870054, 1, 0.12302269869491575`], 
     Hue[0.6480929942181443, 1, 0.10264046954410799`], 
     Hue[0.648701168509393, 1, 0.10179838206391748`], 
     Hue[0.6495904006827088, 1, 0.10056713751624942`], 
     Hue[0.18396853630277527`, 1, 0.7452743343500035], 
     Hue[0.29381397375816426`, 1, 0.5931806517194649], 
     Hue[0.15725886908721082`, 1, 0.7822569504946312], 
     Hue[0.2461156702594724, 1, 0.6592244565638075], 
     Hue[0.5863795963578904, 1, 0.1880897896583057], 
     Hue[0.6389027835311382, 1, 0.11536537664919339`], 
     Hue[0.643161452109211, 1, 0.1094687586180155], 
     Hue[0.6491919798829099, 1, 0.10111879708520176`], 
     Hue[0.6495432103688467, 1, 0.1006324779508277], 
     Hue[0.6499006668244155, 1, 0.10013753824311711`], 
     Hue[0.32594360073994044`, 1, 0.548693475898544], 
     Hue[0.37696469410560485`, 1, 0.4780488850845471], 
     Hue[0.27879499814937836`, 1, 0.6139761564085531], 
     Hue[0.3769399664350754, 1, 0.47808312339758796`], 
     Hue[0.5386415875397478, 1, 0.2541885710988108], 
     Hue[0.6207562211393574, 1, 0.14049138611473594`], 
     Hue[0.646123895834392, 1, 0.10536691346007264`], 
     Hue[0.6480425704907392, 1, 0.10271028701282274`], 
     Hue[0.6497823326442356, 1, 0.10030138556952006`], 
     Hue[0.6498919513445695, 1, 0.10014960583059619`], 
     Hue[0.45129056128855993`, 1, 0.3751361459081478], 
     Hue[0.493075831097555, 1, 0.3172796184803085], 
     Hue[0.5952884848836757, 1, 0.17575440554567984`], 
     Hue[0.6395858690138707, 1, 0.11441956598079447`], 
     Hue[0.6495968544947627, 1, 0.1005582014687901], 
     Hue[0.649954955757087, 1, 0.10006236895172574`], 
     Hue[0.6499849436957271, 1, 0.10002084719053166`], 
     Hue[0.6499975711140137, 1, 0.10000336307290417`], 
     Hue[0.5462477874213132, 1, 0.24365690972433562`], 
     Hue[0.5720380811290162, 1, 0.20794727228290072`], 
     Hue[0.5580607032902251, 1, 0.22730056467507306`], 
     Hue[0.6277470156311113, 1, 0.130811824510769], 
     Hue[0.6499412344012785, 1, 0.10008136775207593`], 
     Hue[0.6499942397222878, 1, 0.10000797576914], 
     Hue[0.604149845174162, 1, 0.16348482975885262`], 
     Hue[0.6171033130469044, 1, 0.1455492588581324], 
     Hue[0.6247244457229296, 1, 0.13499692130671287`], 
     Hue[0.6430880530556519, 1, 0.10957038807678983`], 
     Hue[0.64997868050084, 1, 0.1000295193065294], 
     Hue[0.6499957385818227, 1, 0.10000590042516855`], 
     Hue[0.6499987629932663, 1, 0.10000171277855444`], 
     Hue[0.6473255099465282, 1, 0.10370314007403797`], 
     Hue[0.648883744939926, 1, 0.10154558392933337`], 
     Hue[0.6365699702820129, 1, 0.11859542576336675`], 
     Hue[0.6459899791699963, 1, 0.10555233653385127`], 
     Hue[0.635980750523351, 1, 0.11941126850612946`], 
     Hue[0.6444041113611124, 1, 0.10774815349999818`], 
     Hue[0.6338032976435302, 1, 0.12242620326280443`], 
     Hue[0.6391225719232485, 1, 0.11506105426011741`], 
     Hue[0.6411579196796532, 1, 0.11224288044355714`], 
     Hue[0.6425986940294729, 1, 0.11024796211303753`], 
     Hue[0.6484005855363204, 1, 0.10221457387278723`], 
     Hue[0.6499042635489446, 1, 0.10013255816299979`], 
     Hue[0.6499140056316395, 1, 0.10011906912542227`], 
     Hue[0.646900654580378, 1, 0.10429140135024581`], 
     Hue[0.6494553805775191, 1, 0.10075408843112746`], 
     Hue[0.647529726182325, 1, 0.10342037913216547`], 
     Hue[0.6491038099745627, 1, 0.10124087849675935`], 
     Hue[0.6498922784884097, 1, 0.10014915286220206`], 
     Hue[0.645810904914801, 1, 0.10580028550258326`], 
     Hue[0.6476630909565652, 1, 0.10323572021398672`], 
     Hue[0.6481553858445184, 1, 0.10255408113835916`], 
     Hue[0.6484471298138311, 1, 0.10215012795008008`], 
     Hue[0.6497396958068138, 1, 0.10036042119056554`], 
     Hue[0.6498149363438975, 1, 0.10025624198537271`], 
     Hue[0.6497778114242176, 1, 0.10030764572031403`], 
     Hue[0.6499697190471675, 1, 0.10004192747315277`], 
     Hue[0.649046269611445, 1, 0.10132054976876859`], 
     Hue[0.6383496845838518, 1, 0.11613120596082069`], 
     Hue[0.6120159354330789, 1, 0.15259332016958319`], 
     Hue[0.49886613531240814`, 1, 0.3092622741828195], 
     Hue[0.530448650987929, 1, 0.2655326370936368], 
     Hue[0.3761037772181852, 1, 0.47924092385174355`], 
     Hue[0.2296963854457324, 1, 0.6819588509212936], 
     Hue[0.08405938796736889, 1, 0.8836100781990276], 
     Hue[0.06431079960133801, 1, 0.9109542774750705], 
     Hue[0.09903220130617785, 1, 0.8628784904991383], 
     Hue[0.05465134734035204, 1, 0.9243289036825895], 
     Hue[0.04284765448587835, 1, 0.9406724784041683], 
     Hue[0.6214309965432693, 1, 0.13955708170931944`], 
     Hue[0.425978765776394, 1, 0.41018324738653145`], 
     Hue[0.16805897967816164`, 1, 0.7673029512148531], 
     Hue[0.06948894029863117, 1, 0.9037845442018954], 
     Hue[0.05333953269641556, 1, 0.9261452624203477], 
     Hue[0.6437625251939236, 1, 0.10863650357764416`], 
     Hue[0.04459883777500373, 1, 0.938247763080764], 
     Hue[0.02049419190913393, 1, 0.9716234265873531], 
     Hue[0.0972793977680354, 1, 0.8653054492442587], 
     Hue[0.027112290718130483`, 1, 0.9624599051595116], 
     Hue[0.6418706317749687, 1, 0.11125604831158176`], 
     Hue[0.07341485782996526, 1, 0.8983486583892789], 
     Hue[0.021954692203700055`, 1, 0.9696011954102615], 
     Hue[0.039030651881602485`, 1, 0.9459575589331658], 
     Hue[0.05507422074541246, 1, 0.9237433866601981], 
     Hue[0.6443239590020108, 1, 0.1078591336895236], 
     Hue[0.0315451298663727, 1, 0.9563221278773302], 
     Hue[0.009474771661338033, 1, 0.9868810853919936], 
     Hue[0.6467970462009119, 1, 0.10443485910642963`], 
     Hue[0.6472426602621003, 1, 0.10381785502170723`], 
     Hue[0.03354096435334386, 1, 0.953558664741524], 
     Hue[0.002366521103192687, 1, 0.9967232784725024], 
     Hue[0.04908747330171248, 1, 0.932032729274552], 
     Hue[0.058118030021646394`, 1, 0.9195288815084895], 
     Hue[0.06553208770485364, 1, 0.909263263177895], 
     Hue[0.12640426600783095`, 1, 0.8249787086045417], 
     Hue[0.23603285623306586`, 1, 0.6731852759849857], 
     Hue[0.19889124653952656`, 1, 0.7246121201760402], 
     Hue[0.3516836119966889, 1, 0.5130534603122769], 
     Hue[0.32844108107436315`, 1, 0.545235426204728], 
     Hue[0.47407458992385193`, 1, 0.34358902933620505`], 
     Hue[0.6499830574411674, 1, 0.10002345892761448`], 
     Hue[0.5610774502414368, 1, 0.2231235304349337], 
     Hue[0.6499932778373206, 1, 0.1000093076098637], 
     Hue[0.6482094108987222, 1, 0.10247927721715393`], 
     Hue[0.6426537004090926, 1, 0.11017179943356407`], 
     Hue[0.6485651460081773, 1, 0.10198672091175452`], 
     Hue[0.6468990362927279, 1, 0.10429364205622287`], 
     Hue[0.649651853185313, 1, 0.10048204943572045`], 
     Hue[0.6495897176865651, 1, 0.1005680832032175], 
     Hue[0.6476334994499926, 1, 0.1032766930692411], 
     Hue[0.6472422472450943, 1, 0.10381842689140793`], 
     Hue[0.08896796537331486, 1, 0.8768135864061795], 
     Hue[0.05002632755227121, 1, 0.9307327772353168], 
     Hue[0.04284246034685857, 1, 0.940679670288965], 
     Hue[0.05001735037102739, 1, 0.9307452071785776], 
     Hue[0.021729572238999517`, 1, 0.9699128999767699], 
     Hue[0.06952857930639822, 1, 0.9037296594219102], 
     Hue[0.6424372372147743, 1, 0.11047151770262027`], 
     Hue[0.07490427922818799, 1, 0.8962863826071242], 
     Hue[0.04435180897678137, 1, 0.9385898029552259], 
     Hue[0.04229106463684451, 1, 0.9414431412720614], 
     Hue[0.0743491926556703, 1, 0.8970549640152257], 
     Hue[0.04059654797530943, 1, 0.9437893951111099], 
     Hue[0.014493377065114776`, 1, 0.9799322471406103], 
     Hue[0.07968792059632013, 1, 0.889662879174326], 
     Hue[0.6465125934954252, 1, 0.104828716698642], 
     Hue[0.6459071107233308, 1, 0.10566707746000355`], 
     Hue[0.606999026236627, 1, 0.15953980982620877`], 
     Hue[0.6462699136072091, 1, 0.10516473500540287`], 
     Hue[0.06041538696646587, 1, 0.9163479257387396], 
     Hue[0.05535359769290471, 1, 0.9233565570405935], 
     Hue[0.07337923378810385, 1, 0.8983979839857024], 
     Hue[0.6392828201978242, 1, 0.11483917203378194`], 
     Hue[0.6332265310029574, 1, 0.1232248032266744], 
     Hue[0.6491038099745627, 1, 0.10124087849675933`], 
     Hue[0.6457534730172505, 1, 0.1058798065914994], 
     Hue[0.6498922784884097, 1, 0.10014915286220206`], 
     Hue[0.6492792879483541, 1, 0.10099790899458673`], 
     Hue[0.6493877517226868, 1, 0.1008477283839722], 
     Hue[0.6492148614352822, 1, 0.10108711493576317`], 
     Hue[0.6499526196229324, 1, 0.10006560359901673`], 
     Hue[0.6499287593386579, 1, 0.10009864091570449`], 
     Hue[0.6496660108228615, 1, 0.10046244655296112`], 
     Hue[0.6495192489610482, 1, 0.10066565528470248`], 
     Hue[0.6498812672976926, 1, 0.1001643991262718], 
     Hue[0.6482705546617313, 1, 0.10239461662221823`], 
     Hue[0.6476420796759197, 1, 0.10326481275641891`], 
     Hue[0.6493895145696986, 1, 0.10084528751887879`], 
     Hue[0.6434398754723312, 1, 0.10908324934600307`], 
     Hue[0.6415243622893098, 1, 0.11173549836864806`], 
     Hue[0.6477985837511296, 1, 0.10304811480612823`], 
     Hue[0.6311505844679748, 1, 0.1260991907366504], 
     Hue[0.6268346761691109, 1, 0.13207506376584646`], 
     Hue[0.6443003380538577, 1, 0.10789183961773562`], 
     Hue[0.04284246034685857, 1, 0.940679670288965], 
     Hue[0.03685526688188134, 1, 0.9489696304712413], 
     Hue[0.6392273962585344, 1, 0.11491591287279855`], 
     Hue[0.03827518130522878, 1, 0.947003595115837], 
     Hue[0.041606744592537104`, 1, 0.9423906613334102], 
     Hue[0.6349434538973262, 1, 0.12084752537293302`], 
     Hue[0.025751898021964648`, 1, 0.9643435258157412], 
     Hue[0.05193931854254619, 1, 0.9280840204795514], 
     Hue[0.017011821701268914`, 1, 0.9764451699520893], 
     Hue[0.020173287216063485`, 1, 0.9720677561623736], 
     Hue[0.012758284836256628`, 1, 0.9823346825344138], 
     Hue[0.6449749084497158, 1, 0.10695781906962429`], 
     Hue[0.06389865489526858, 1, 0.9115249393757819], 
     Hue[0.06384720723013537, 1, 0.9115961746044279], 
     Hue[0.07255491893501409, 1, 0.8995393430130575], 
     Hue[0.07312672418550603, 1, 0.8987476126662225], 
     Hue[0.04107887830059265, 1, 0.9431215531222563], 
     Hue[0.041588470912922615`, 1, 0.9424159633513378], 
     Hue[0.06041538696646587, 1, 0.9163479257387396], 
     Hue[0.06374640815574029, 1, 0.9117357425535904], 
     Hue[0.6490707038213298, 1, 0.10128671778585109`], 
     Hue[0.6496913054505354, 1, 0.10042742322233554`], 
     Hue[0.5888045015225164, 1, 0.18473222866113115`], 
     Hue[0.6036959417089317, 1, 0.16411331147994074`], 
     Hue[0.6222057058467476, 1, 0.13848440728911873`], 
     Hue[0.6310081293509674, 1, 0.12629643628327594`], 
     Hue[0.6058308015380279, 1, 0.1611573517165767], 
     Hue[0.6402137035419405, 1, 0.11355025663423622`], 
     Hue[0.6439886090718191, 1, 0.10832346436209665`], 
     Hue[0.633119930420021, 1, 0.12337240403381712`], 
     Hue[0.6473341046292588, 1, 0.10369123974410334`], 
     Hue[0.6485349610483069, 1, 0.10202851547157513`], 
     Hue[0.6450562435002993, 1, 0.10684520130727782`], 
     Hue[0.6494423243728757, 1, 0.10077216625294132`], 
     Hue[0.6497288670998609, 1, 0.10037541478480805`], 
     Hue[0.6489484724765117, 1, 0.10145596118636857`], 
     Hue[0.6499126023613532, 1, 0.10012101211504945`], 
     Hue[0.6499629691186642, 1, 0.10005127352800336`], 
     Hue[0.6491038099745627, 1, 0.10124087849675933`], 
     Hue[0.6496776182866274, 1, 0.10044637468005445`], 
     Hue[0.6486096504814155, 1, 0.10192509933342471`], 
     Hue[0.6498441776198002, 1, 0.10021575406489204`], 
     Hue[0.6497943481566071, 1, 0.10028474870623633`], 
     Hue[0.6498822834118156, 1, 0.10016299219902448`], 
     Hue[0.6494382216208568, 1, 0.10077784698650598`], 
     Hue[0.6498640875848931, 1, 0.10018818642091724`], 
     Hue[0.6494114196045649, 1, 0.10081495747060246`], 
     Hue[0.6469290670520219, 1, 0.1042520610048927], 
     Hue[0.6493286246810557, 1, 0.10092959659546147`], 
     Hue[0.6384967560196013, 1, 0.11592756858824438`], 
     Hue[0.6498695514487343, 1, 0.1001806210709834], 
     Hue[0.6472615319100973, 1, 0.10379172504755772`], 
     Hue[0.6182689374550846, 1, 0.14393531736988283`], 
     Hue[0.649954511179343, 1, 0.10006298452090977`], 
     Hue[0.6499363903540898, 1, 0.10008807489433724`], 
     Hue[0.6403402511796833, 1, 0.11337503682813087`], 
     Hue[0.6497181100988532, 1, 0.10039030909389571`], 
     Hue[0.649631654672514, 1, 0.10051001660728831`], 
     Hue[0.6214241108970181, 1, 0.1395666156810519], 
     Hue[0.6498803707568835, 1, 0.10016564049046903`], 
     Hue[0.6499074176917317, 1, 0.10012819088837162`], 
     Hue[0.5824457121418007, 1, 0.19353670626519898`], 
     Hue[0.6498222505728725, 1, 0.10024611459140739`], 
     Hue[0.6497757780382568, 1, 0.10031046117779828`], 
     Hue[0.6495953728047564, 1, 0.10056025303956805`], 
     Hue[0.6496726228167735, 1, 0.10045329148446741`], 
     Hue[0.055056271823484826`, 1, 0.9237682390136364], 
     Hue[0.6494183140547178, 1, 0.1008054113088523], 
     Hue[0.6492943987167404, 1, 0.10097698639220556`], 
     Hue[0.6488142657471984, 1, 0.10164178588849462`], 
     Hue[0.6490037736789362, 1, 0.10137939029070364`], 
     Hue[0.10746359275895068`, 1, 0.8512042561799144], 
     Hue[0.08829945843939524, 1, 0.8777392113916066], 
     Hue[0.03203500107977364, 1, 0.9556438446587749], 
     Hue[0.024930672628064032`, 1, 0.965480607130373], 
     Hue[0.647099106789354, 1, 0.10401662136858685`], 
     Hue[0.6474562747016455, 1, 0.10352208118233706`], 
     Hue[0.041606744592537104`, 1, 0.9423906613334102], 
     Hue[0.03809183899312307, 1, 0.9472574537018296], 
     Hue[0.046403759358903174`, 1, 0.9357486408876725], 
     Hue[0.06009558546921556, 1, 0.9167907278118554], 
     Hue[0.052823806173831866`, 1, 0.9268593452977714], 
     Hue[0.6444984425681382, 1, 0.107617541059501], 
     Hue[0.6449309065941959, 1, 0.10701874471572875`], 
     Hue[0.10056860950523383`, 1, 0.8607511560696763], 
     Hue[0.055399463122646986`, 1, 0.9232930510609504], 
     Hue[0.05431268201313999, 1, 0.9247978249048832], 
     Hue[0.02866081862370662, 1, 0.9603157895979446], 
     Hue[0.6394855910206029, 1, 0.11455841243301147`], 
     Hue[0.6402279612063426, 1, 0.11353051525275641`], 
     Hue[0.03168629012588531, 1, 0.9561266752103126], 
     Hue[0.03200312432733732, 1, 0.9556879817006099], 
     Hue[0.017618916820366315`, 1, 0.9756045767102621], 
     Hue[0.013643235397031273`, 1, 0.9811093663733413], 
     Hue[0.013311532119129388`, 1, 0.9815686478350516], 
     Hue[0.6436537767619063, 1, 0.1087870783296682], 
     Hue[0.6441423928698694, 1, 0.10811053294941164`], 
     Hue[0.036322583748362725`, 1, 0.9497071917330363], 
     Hue[0.03417350197382374, 1, 0.9526828434208595], 
     Hue[0.011126014326944045`, 1, 0.984594749393462], 
     Hue[0.009863647406235021, 1, 0.9863426420529053], 
     Hue[0.6454530506307294, 1, 0.1062957760497592], 
     Hue[0.6458104351512287, 1, 0.10580093594445254`], 
     Hue[0.03753874128941004, 1, 0.9480232812915861], 
     Hue[0.03931725793441798, 1, 0.9455607197831136], 
     Hue[0.04042197122912394, 1, 0.9440311167596745], 
     Hue[0.040222208701616524`, 1, 0.944307711028531], 
     Hue[0.06410936128704403, 1, 0.9112331920640929], 
     Hue[0.013642556410774942`, 1, 0.9811103065081578], 
     Hue[0.010783945796170258`, 1, 0.9850683827437643], 
     Hue[0.008415045949061062, 1, 0.9883483979166847], 
     Hue[0.009495217348706952, 1, 0.9868527759787135], 
     Hue[0.008190266052178097, 1, 0.9886596316200611], 
     Hue[0.009192414186764974, 1, 0.9872720418952485], 
     Hue[0.040515558676816665`, 1, 0.9439015341397924], 
     Hue[0.03857060686005942, 1, 0.94659454434761], 
     Hue[0.008979243255729075, 1, 0.9875672016459135], 
     Hue[0.009295381640388123, 1, 0.9871294715748472], 
     Hue[0.028798522432975315`, 1, 0.9601251227851111], 
     Hue[0.014718706813873883`, 1, 0.9796202521038668], 
     Hue[0.016156031881964683`, 1, 0.9776301097018951], 
     Hue[0.052460599074250935`, 1, 0.9273622474356525], 
     Hue[0.6471296072101265, 1, 0.10397439001674802`], 
     Hue[0.6473872624115128, 1, 0.10361763666098238`], 
     Hue[0.04181473554251214, 1, 0.9421026738642139], 
     Hue[0.04239388978079062, 1, 0.9413007679958284], 
     Hue[0.6466337765086415, 1, 0.10466092483418866`], 
     Hue[0.646800462909818, 1, 0.10443012827871366`], 
     Hue[0.6485442026309691, 1, 0.10201571943404272`], 
     Hue[0.6487442651011454, 1, 0.10173870985995258`], 
     Hue[0.6221969417172857, 1, 0.1384965422376044], 
     Hue[0.6477878638952453, 1, 0.10306295768350654`], 
     Hue[0.6480039022964763, 1, 0.1027638275894944], 
     Hue[0.6494467282471968, 1, 0.10076606858080442`], 
     Hue[0.6495480007587726, 1, 0.10062584510323795`], 
     Hue[0.6352349763637155, 1, 0.1204438788810094], 
     Hue[0.6489436009185443, 1, 0.10146270642047711`], 
     Hue[0.6491036257173601, 1, 0.10124113362211681`], 
     Hue[0.6494768883602804, 1, 0.10072430842422718`], 
     Hue[0.6493620567577014, 1, 0.10088330602779809`], 
     Hue[0.6498378173791937, 1, 0.10022456055188575`], 
     Hue[0.6498745094097533, 1, 0.1001737562018801], 
     Hue[0.6442147897925249, 1, 0.10801029105650409`], 
     Hue[0.6496501974441999, 1, 0.10048434200033862`], 
     Hue[0.6497233161736018, 1, 0.10038310068270527`], 
     Hue[0.649867756560731, 1, 0.1001831063005263], 
     Hue[0.6498264151498583, 1, 0.10024034825404236`], 
     Hue[0.6483858649006528, 1, 0.10223495629140389`], 
     Hue[0.6499222029355487, 1, 0.10010771901231724`], 
     Hue[0.6499429904932875, 1, 0.10007893624006342`], 
     Hue[0.649683047593285, 1, 0.10043885717852857`], 
     Hue[0.6499175130374115, 1, 0.10011421271743029`], 
     Hue[0.6499559602361451, 1, 0.10006097813456835`], 
     Hue[0.6497706437723507, 1, 0.10031757016136063`], 
     Hue[0.6498497708133715, 1, 0.10020800964302418`], 
     Hue[0.6499481817937316, 1, 0.10007174828560249`], 
     Hue[0.6499481817937316, 1, 0.10007174828560249`], 
     Hue[0.6491438876046509, 1, 0.10118538639356035`], 
     Hue[0.6495894740597911, 1, 0.10056842053259699`], 
     Hue[0.6483994975840651, 1, 0.1022160802682175], 
     Hue[0.6488534493727995, 1, 0.1015875316376622], 
     Hue[0.6477776820679593, 1, 0.10307705559821023`], 
     Hue[0.6499197792769594, 1, 0.10011107484728698`], 
     Hue[0.6498087869529634, 1, 0.10026475652666611`], 
     Hue[0.6497123951126985, 1, 0.10039822215164826`], 
     Hue[0.6495739580772921, 1, 0.1005899042006725], 
     Hue[0.649751373392211, 1, 0.10034425222616937`], 
     Hue[0.6496075011183897, 1, 0.10054345998992192`], 
     Hue[0.649895778023681, 1, 0.10014430735182625`], 
     Hue[0.053374851328025885`, 1, 0.9260963596996565], 
     Hue[0.05380111140356125, 1, 0.9255061534412229], 
     Hue[0.058561137615340986`, 1, 0.9189153479172201], 
     Hue[0.03998859509233932, 1, 0.9446311760259917], 
     Hue[0.0427200132446901, 1, 0.9408492124304291], 
     Hue[0.0251303414341284, 1, 0.9652041426296685], 
     Hue[0.07604690628855726, 1, 0.8947042836004593], 
     Hue[0.051228894847768824`, 1, 0.9290676840569355], 
     Hue[0.04764857875038331, 1, 0.9340250448071616], 
     Hue[0.04593698802822965, 1, 0.9363949396532205], 
     Hue[0.01680908711127571, 1, 0.9767258793843874], 
     Hue[0.017011821701268914`, 1, 0.9764451699520893], 
     Hue[0.020173287216063485`, 1, 0.9720677561623736], 
     Hue[0.04733932373864003, 1, 0.9344532440541908], 
     Hue[0.012410752000722058`, 1, 0.982815881845154], 
     Hue[0.03521138220913689, 1, 0.9512457784796565], 
     Hue[0.06447610078072796, 1, 0.9107253989189921], 
     Hue[0.06459492763931285, 1, 0.9105608694224899], 
     Hue[0.008493014351403372, 1, 0.9882404416672876], 
     Hue[0.07364828141127544, 1, 0.8980254565074647], 
     Hue[0.07188949192750471, 1, 0.9004607034849935], 
     Hue[0.649151766953336, 1, 0.10117447652615018`], 
     Hue[0.649726922297457, 1, 0.1003781075881365], 
     Hue[0.6494251206798614, 1, 0.10079598675096124`], 
     Hue[0.6498503335314594, 1, 0.10020723049490239`], 
     Hue[0.6497428204206986, 1, 0.10035609480210955`], 
     Hue[0.6498394143454485, 1, 0.1002223493678407], 
     Hue[0.6498466135724958, 1, 0.10021238120731348`], 
     Hue[0.6493578765982575, 1, 0.10088909394087432`], 
     Hue[0.6487164111187367, 1, 0.10177727691251856`], 
     Hue[0.1013778304177968, 1, 0.8596306963445891], 
     Hue[0.021936454219800727`, 1, 0.9696264480033528], 
     Hue[0.041038998580315345`, 1, 0.9431767711964864], 
     Hue[0.6497425060352919, 1, 0.1003565301049805], 
     Hue[0.6491606990351715, 1, 0.10116210902822412`], 
     Hue[0.6482873573767849, 1, 0.1023713513244517], 
     Hue[0.6446869024804697, 1, 0.10735659656550361`], 
     Hue[0.6274250544045753, 1, 0.13125761697828042`], 
     Hue[0.6499838381125184, 1, 0.1000223779980516], 
     Hue[0.6499058427059782, 1, 0.1001303716378764], 
     Hue[0.6492090694451876, 1, 0.10109513461435554`], 
     Hue[0.6465035962448429, 1, 0.10484117443021766`], 
     Hue[0.6496822280196737, 1, 0.10043999197275957`], 
     Hue[0.6487900742192818, 1, 0.10167528185022527`], 
     Hue[0.6485114499392175, 1, 0.10206106931492966`], 
     Hue[0.648667785580125, 1, 0.10184460458136542`], 
     Hue[0.10704411806835556`, 1, 0.8517850672899693], 
     Hue[0.6498020481725953, 1, 0.10027408714563732`], 
     Hue[0.08477894637926453, 1, 0.8826137665517876], 
     Hue[0.03685526688188134, 1, 0.9489696304712413], 
     Hue[0.05527313279758661, 1, 0.9234679699725724], 
     Hue[0.045732456509965935`, 1, 0.9366781371400471], 
     Hue[0.03307946131776529, 1, 0.9541976689446326], 
     Hue[0.6493633419442921, 1, 0.10088152653867247`], 
     Hue[0.046492283422257974`, 1, 0.9356260691076428], 
     Hue[0.6017081483048399, 1, 0.1668656408086833], 
     Hue[0.5980154396440366, 1, 0.17197862203133404`], 
     Hue[0.6483658281786634, 1, 0.10226269944492762`], 
     Hue[0.6480943176404445, 1, 0.1026386371132308], 
     Hue[0.5390999911909005, 1, 0.253553858351061], 
     Hue[0.06812844576505306, 1, 0.9056683058637727], 
     Hue[0.060214938010207164`, 1, 0.9166254704474055], 
     Hue[0.05268656070961064, 1, 0.9270493774790006], 
     Hue[0.04934459694634541, 1, 0.9316767119204449], 
     Hue[0.01887778058168854, 1, 0.9738615345792005], 
     Hue[0.018496744064256054`, 1, 0.9743891236033377], 
     Hue[0.018875358621470606`, 1, 0.9738648880625792], 
     Hue[0.043719215711325754`, 1, 0.9394657013227797], 
     Hue[0.040361675946535835`, 1, 0.9441146025355657], 
     Hue[0.054909662309344354`, 1, 0.9239712368024463], 
     Hue[0.021954692203700055`, 1, 0.9696011954102615], 
     Hue[0.017618916820366315`, 1, 0.9756045767102621], 
     Hue[0.017618916820366315`, 1, 0.9756045767102621], 
     Hue[0.01807778167652796, 1, 0.9749692253709613], 
     Hue[0.015225820907530663`, 1, 0.9789180941280345], 
     Hue[0.043525115241094814`, 1, 0.9397344558200226], 
     Hue[0.013508708162625505`, 1, 0.9812956348517493], 
     Hue[0.5904021416468117, 1, 0.1825201115659531], 
     Hue[0.5917826987178284, 1, 0.1806085710060837], 
     Hue[0.594692220896095, 1, 0.17658000183617628`], 
     Hue[0.031933594694323664`, 1, 0.9557842535001673], 
     Hue[0.033228396675246685`, 1, 0.9539914507573508], 
     Hue[0.025491634684400077`, 1, 0.9647038904369846], 
     Hue[0.03023901383841643, 1, 0.9581305962237311], 
     Hue[0.0104987595690883, 1, 0.9854632559812624], 
     Hue[0.009150109894715652, 1, 0.9873306170688553], 
     Hue[0.6456403417374514, 1, 0.10603644990199038`], 
     Hue[0.038557411199186986`, 1, 0.9466128152626643], 
     Hue[0.009764523862285435, 1, 0.9864798900368354], 
     Hue[0.014801340872325541`, 1, 0.9795058357152415], 
     Hue[0.02092202586343661, 1, 0.9710310411121648], 
     Hue[0.5841665161217874, 1, 0.19115405460060217`], 
     Hue[0.03260320860013288, 1, 0.9548570957844315], 
     Hue[0.029048014526991572`, 1, 0.9597796721933963], 
     Hue[0.5983416204920031, 1, 0.1715269870110726], 
     Hue[0.5989962456502381, 1, 0.17062058294582413`], 
     Hue[0.5992867576938933, 1, 0.17021833550076315`], 
     Hue[0.04714584706108649, 1, 0.9347211348384956], 
     Hue[0.041332514357341865`, 1, 0.9427703647359882], 
     Hue[0.0637464081557404, 1, 0.9117357425535902], 
     Hue[0.03365579615680803, 1, 0.9533996668598044], 
     Hue[0.04012187461930994, 1, 0.9444466351424938], 
     Hue[0.06916173043730389, 1, 0.904237604009887], 
     Hue[0.09286638167872119, 1, 0.8714157792140784], 
     Hue[0.10867214552181426`, 1, 0.8495308754313341], 
     Hue[0.13627144477288267`, 1, 0.8113164610837009], 
     Hue[0.07211141978491054, 1, 0.9001534187593546], 
     Hue[0.08885586905341625, 1, 0.8769687966952698], 
     Hue[0.6478965689070533, 1, 0.1029124430517725], 
     Hue[0.2013509450615638, 1, 0.7212063837609116], 
     Hue[0.24560421875247374`, 1, 0.6599326201888825], 
     Hue[0.6490290845935826, 1, 0.10134434440888575`], 
     Hue[0.6498587995481566, 1, 0.10019550831793704`], 
     Hue[0.649691436723818, 1, 0.10042724145932888`], 
     Hue[0.6447253111856288, 1, 0.10730341528143703`], 
     Hue[0.6487382714538579, 1, 0.10174700875619688`], 
     Hue[0.6497542323111057, 1, 0.10034029372308442`], 
     Hue[0.6268594512254994, 1, 0.13204075984161628`], 
     Hue[0.6495755553290814, 1, 0.10058769262127198`], 
     Hue[0.6495755553290814, 1, 0.10058769262127197`], 
     Hue[0.6496776182866274, 1, 0.10044637468005445`], 
     Hue[0.6499494253305192, 1, 0.10007002646543495`], 
     Hue[0.6499159567668522, 1, 0.10011636755358931`], 
     Hue[0.6495956712045818, 1, 0.10055983987057897`], 
     Hue[0.6498795296969424, 1, 0.10016680503500286`], 
     Hue[0.6493098098059089, 1, 0.10095564796104922`], 
     Hue[0.6499678487902338, 1, 0.10004451705967632`], 
     Hue[0.6499075960125535, 1, 0.10012794398261823`], 
     Hue[0.6494224371705009, 1, 0.10079970237930659`], 
     Hue[0.019432661379499394`, 1, 0.973093238089924], 
     Hue[0.03393356930036051, 1, 0.9530150578918085], 
     Hue[0.10037829225221961`, 1, 0.8610146722661575], 
     Hue[0.05768094492790732, 1, 0.9201340762536667], 
     Hue[0.05778002339652555, 1, 0.9199968906817338], 
     Hue[0.07445088093432428, 1, 0.8969141648601663], 
     Hue[0.07056484579903577, 1, 0.9022948288936428], 
     Hue[0.06171983243086099, 1, 0.9145417704803463], 
     Hue[0.049462616105099166`, 1, 0.9315133007775549], 
     Hue[0.04155834072464082, 1, 0.9424576820735743], 
     Hue[0.6455622125400321, 1, 0.1061446287907249], 
     Hue[0.6457986970113689, 1, 0.10581718875348915`], 
     Hue[0.6472257311188611, 1, 0.10384129537388478`], 
     Hue[0.6451771352504884, 1, 0.10667781273009311`], 
     Hue[0.6453529104193104, 1, 0.10643443172710872`], 
     Hue[0.05949026299302307, 1, 0.917628866625045], 
     Hue[0.058255045465130384`, 1, 0.9193391678175118], 
     Hue[0.05785003153283341, 1, 0.9198999563391538], 
     Hue[0.02860812938543411, 1, 0.9603887439278604], 
     Hue[0.02860812938543411, 1, 0.9603887439278604], 
     Hue[0.028798522432975315`, 1, 0.9601251227851111], 
     Hue[0.003627810331088943, 1, 0.9949768780031075], 
     Hue[0.055103085744093616`, 1, 0.9237034197389472], 
     Hue[0.05453425609780693, 1, 0.9244910300184211], 
     Hue[0.05375293108184542, 1, 0.9255728646559064], 
     Hue[0.03903833590720307, 1, 0.9459469195131035], 
     Hue[0.08699742048355796, 1, 0.8795420331766121], 
     Hue[0.6499560847798013, 1, 0.10006080568950593`], 
     Hue[0.6498389731233429, 1, 0.1002229602907559], 
     Hue[0.6499451292204242, 1, 0.10007597492556644`], 
     Hue[0.646830399938332, 1, 0.1043886770084634], 
     Hue[0.6473671676734059, 1, 0.10364546014451508`], 
     Hue[0.6499923203782045, 1, 0.10001063332248608`], 
     Hue[0.6495236931189671, 1, 0.10065950183527637`], 
     Hue[0.649747769225601, 1, 0.10034924261070646`], 
     Hue[0.6498904155732932, 1, 0.10015173228313247`], 
     Hue[0.6499848583880379, 1, 0.10002096530887072`], 
     Hue[0.6478262103864884, 1, 0.10300986254178546`], 
     Hue[0.6389045310958464, 1, 0.11536295694421266`], 
     Hue[0.6358584839320016, 1, 0.11958056070953622`], 
     Hue[0.01839771819637459, 1, 0.9745262363434812], 
     Hue[0.021503531968782963`, 1, 0.9702258788124543], 
     Hue[0.06118908531381173, 1, 0.915276651103953], 
     Hue[0.07248745452853023, 1, 0.899632755268189], 
     Hue[0.08044360158224884, 1, 0.8886165516553477], 
     Hue[0.10305212377293982`, 1, 0.8573124440066987], 
     Hue[0.07154065506998775, 1, 0.9009437083646323], 
     Hue[0.07400765205374138, 1, 0.8975278663871273], 
     Hue[0.07256059199410769, 1, 0.8995314880081585], 
     Hue[0.07376807132140772, 1, 0.897859593554974], 
     Hue[0.07188017725506768, 1, 0.9004736007237525], 
     Hue[0.0353584991458471, 1, 0.9510420781057501], 
     Hue[0.03457357145067752, 1, 0.9521289010682926], 
     Hue[0.03258545349066211, 1, 0.9548816797821601], 
     Hue[0.0411852531840855, 1, 0.9429742648220355], 
     Hue[0.04125417164014911, 1, 0.9428788392674858], 
     Hue[0.03209592920180482, 1, 0.9555594826436549], 
     Hue[0.061309406925087906`, 1, 0.9151100519498783], 
     Hue[0.030808129440789145`, 1, 0.9573425900050612], 
     Hue[0.007909588715874771, 1, 0.9890482617780195], 
     Hue[0.005790757186173501, 1, 0.991982028511452], 
     Hue[0.02593134542055875, 1, 0.9640950601869186], 
     Hue[0.025516802321324472`, 1, 0.9646690429397047], 
     Hue[0.028210623892171882`, 1, 0.9609391361493004], 
     Hue[0.6022452835609714, 1, 0.16612191506942425`], 
     Hue[0.6060398769489005, 1, 0.16086786268613779`], 
     Hue[0.04381101574118107, 1, 0.939338593589134], 
     Hue[0.6380500355568548, 1, 0.11654610461358562`], 
     Hue[0.6347798130349368, 1, 0.12107410502854907`], 
     Hue[0.6492783455660893, 1, 0.10099921383156862`], 
     Hue[0.6495720203421957, 1, 0.10059258721849831`], 
     Hue[0.6498317448858686, 1, 0.10023296861956653`], 
     Hue[0.649659241650275, 1, 0.10047181925346538`], 
     Hue[0.649414789477533, 1, 0.10081029149264678`], 
     Hue[0.6498618196799413, 1, 0.1001913265970044], 
     Hue[0.6496908480858702, 1, 0.10042805649648744`], 
     Hue[0.6498618941109153, 1, 0.10019122353873268`], 
     Hue[0.6497859162559023, 1, 0.10029642364567375`], 
     Hue[0.6496093504472542, 1, 0.100540899380725], 
     Hue[0.6493258018121839, 1, 0.10093350518312995`], 
     Hue[0.6498655948103998, 1, 0.10018609949329255`], 
     Hue[0.6486185620563141, 1, 0.10191276022971904`], 
     Hue[0.649107591163377, 1, 0.10123564300455491`], 
     Hue[0.6491010492706201, 1, 0.10124470100991076`], 
     Hue[0.649966791599451, 1, 0.10004598086229856`], 
     Hue[0.6499436227202112, 1, 0.10007806084893833`], 
     Hue[0.6475885060367288, 1, 0.10333899164145241`], 
     Hue[0.648715802495228, 1, 0.10177811962199201`], 
     Hue[0.6481829312404903, 1, 0.10251594135932109`], 
     Hue[0.6464558240632146, 1, 0.10490732052785678`], 
     Hue[0.6490789511025784, 1, 0.10127529847335306`], 
     Hue[0.6414333144295552, 1, 0.11186156463600058`], 
     Hue[0.6451130061468894, 1, 0.10676660687353778`], 
     Hue[0.6433215366665956, 1, 0.10924710307702151`], 
     Hue[0.64800635002955, 1, 0.1027604384206231], 
     Hue[0.6460119583457221, 1, 0.10552190382900023`], 
     Hue[0.6419382533632253, 1, 0.11116241842014957`], 
     Hue[0.6412136620517335, 1, 0.11216569869759987`], 
     Hue[0.6463124871911979, 1, 0.10510578696603366`], 
     Hue[0.6457056538266575, 1, 0.10594601777847436`], 
     Hue[0.6281593919363465, 1, 0.13024084193428956`], 
     Hue[0.6496387329690755, 1, 0.10050021588897247`], 
     Hue[0.6418561866242183, 1, 0.11127604928954397`], 
     Hue[0.6409971991432349, 1, 0.1124654165709055], 
     Hue[0.06692902413742918, 1, 0.907329043502021], 
     Hue[0.03854454940579133, 1, 0.9466306238996735], 
     Hue[0.03701109274635406, 1, 0.9487538715819713], 
     Hue[0.04178756135347772, 1, 0.9421402996644154], 
     Hue[0.044199633856616516`, 1, 0.9388005069677617], 
     Hue[0.020150442993734585`, 1, 0.9720993866240597], 
     Hue[0.023874535640811656`, 1, 0.9669429506511839], 
     Hue[0.6489184024768646, 1, 0.10149759657049523`], 
     Hue[0.14826934081387322`, 1, 0.7947039896423295], 
     Hue[0.12076334004688594`, 1, 0.8327892214735426], 
     Hue[0.12076334004688571`, 1, 0.8327892214735428], 
     Hue[0.06607178626569388, 1, 0.9085159882475007], 
     Hue[0.06163591025721604, 1, 0.9146579704130855], 
     Hue[0.046467710484230706`, 1, 0.9356600931756807], 
     Hue[0.043734592778937764`, 1, 0.9394444099983938], 
     Hue[0.04266667839706162, 1, 0.9409230606809916], 
     Hue[0.045054951972745116`, 1, 0.9376162203454299], 
     Hue[0.06672896145599083, 1, 0.9076060533686281], 
     Hue[0.02816590338572822, 1, 0.96100105685053], 
     Hue[0.6472877826609257, 1, 0.10375537785410296`], 
     Hue[0.6462793560991785, 1, 0.10515166078575282`], 
     Hue[0.6458578239248396, 1, 0.10573532071945287`], 
     Hue[0.1010643615523864, 1, 0.8600647301582341], 
     Hue[0.05590090056929531, 1, 0.9225987530578988], 
     Hue[0.06084096886273305, 1, 0.9157586584977543], 
     Hue[0.059398355121854096`, 1, 0.9177561236774329], 
     Hue[0.05873193242578867, 1, 0.918678862795062], 
     Hue[0.04305999072090727, 1, 0.9403784743864361], 
     Hue[0.041007174555774295`, 1, 0.9432208352304664], 
     Hue[0.09871027958790823, 1, 0.8633242282628962], 
     Hue[0.6333339658174786, 1, 0.12307604732964514`], 
     Hue[0.634021946308949, 1, 0.12212345895683985`], 
     Hue[0.6339633030846511, 1, 0.12220465726740615`], 
     Hue[0.045071012944814304`, 1, 0.937593982076411], 
     Hue[0.0482367478008936, 1, 0.9332106568910704], 
     Hue[0.03570489153880074, 1, 0.9505624578693528], 
     Hue[0.02866081862370684, 1, 0.9603157895979444], 
     Hue[0.03227651539827281, 1, 0.9553094402177761], 
     Hue[0.10365402055798145`, 1, 0.8564790484581796], 
     Hue[0.07425672241337034, 1, 0.8971829997353334], 
     Hue[0.1499676611802, 1, 0.7923524691351076], 
     Hue[0.6418258930145502, 1, 0.11131799428754593`], 
     Hue[0.6424916697706924, 1, 0.11039614954827212`], 
     Hue[0.6423043849432353, 1, 0.11065546700167424`], 
     Hue[0.035800356091833296`, 1, 0.9504302761805385], 
     Hue[0.03888400526398983, 1, 0.9461606080960141], 
     Hue[0.019382017501405002`, 1, 0.97316336038267], 
     Hue[0.014743672363951466`, 1, 0.9795856844191441], 
     Hue[0.6417500519724477, 1, 0.11142300496122623`], 
     Hue[0.031622334723259815`, 1, 0.9562152288447172], 
     Hue[0.031706707851328564`, 1, 0.9560984045135451], 
     Hue[0.6446191653330818, 1, 0.10745038646188668`], 
     Hue[0.6442311175297312, 1, 0.10798768342037228`], 
     Hue[0.06056838923489549, 1, 0.9161360764439908], 
     Hue[0.061909785187658106`, 1, 0.9142787589709349], 
     Hue[0.06134113457623802, 1, 0.9150661213559782], 
     Hue[0.02242996360288141, 1, 0.9689431273190874], 
     Hue[0.6456561317368714, 1, 0.10601458682587038`], 
     Hue[0.6457543317382626, 1, 0.10587861759317495`], 
     Hue[0.6469492708998005, 1, 0.10422408644643008`], 
     Hue[0.6468717943207014, 1, 0.10433136170979801`], 
     Hue[0.6470103488108736, 1, 0.10413951703109807`], 
     Hue[0.6456145670870205, 1, 0.10607213787951009`], 
     Hue[0.6455272861029625, 1, 0.10619298847282119`], 
     Hue[0.034139505625166766`, 1, 0.9527299152882306], 
     Hue[0.037692354743131595`, 1, 0.9478105857402794], 
     Hue[0.026131323039848775`, 1, 0.9638181680986708], 
     Hue[0.027554862745293618`, 1, 0.9618471131219012], 
     Hue[0.012312898060215072`, 1, 0.9829513719166253], 
     Hue[0.011158681958560623`, 1, 0.9845495172881468], 
     Hue[0.6449994346912448, 1, 0.10692385965827658`], 
     Hue[0.64522506967174, 1, 0.10661144199297541`], 
     Hue[0.645230483075345, 1, 0.10660394651106078`], 
     Hue[0.026442358134220023`, 1, 0.9633875041218493], 
     Hue[0.03341036005911768, 1, 0.9537395014566062], 
     Hue[0.04169642954516195, 1, 0.9422664821682373], 
     Hue[0.6463861974695382, 1, 0.10500372658063943`], 
     Hue[0.037458794930372186`, 1, 0.948133976250254], 
     Hue[0.029196952632720596`, 1, 0.9595734502008484], 
     Hue[0.04867667776443574, 1, 0.9326015230953967], 
     Hue[0.047086912332810815`, 1, 0.9348027367699543], 
     Hue[0.050099697928459586`, 1, 0.9306311874836714], 
     Hue[0.6459583909871119, 1, 0.10559607401784499`], 
     Hue[0.6463691356687115, 1, 0.10502735061255333`], 
     Hue[0.646269026366501, 1, 0.10516596349253715`], 
     Hue[0.6478793439933811, 1, 0.10293629293224162`], 
     Hue[0.6480037574805025, 1, 0.10276402810391956`], 
     Hue[0.6264488934377215, 1, 0.13260922447084714`], 
     Hue[0.041428495787547814`, 1, 0.9426374673710877], 
     Hue[0.05906145177148192, 1, 0.9182226052394865], 
     Hue[0.04795074484854722, 1, 0.9336066609789345], 
     Hue[0.6473748889787766, 1, 0.10363476910630941`], 
     Hue[0.6471683685528576, 1, 0.10392072046527413`], 
     Hue[0.6288018987419344, 1, 0.12935121712655243`], 
     Hue[0.6315132731299921, 1, 0.12559700643539567`], 
     Hue[0.6302207094641101, 1, 0.12738670997277066`], 
     Hue[0.6486018769818955, 1, 0.10193586264045244`], 
     Hue[0.6484041457698037, 1, 0.1022096443187335], 
     Hue[0.6396201140451768, 1, 0.11437214978360138`], 
     Hue[0.641300727305566, 1, 0.11204514680767791`], 
     Hue[0.6405221177612069, 1, 0.1131232215614058], 
     Hue[0.6475870584693532, 1, 0.1033409959655111], 
     Hue[0.6486372393265982, 1, 0.10188689939394094`], 
     Hue[0.6494704949436647, 1, 0.10073316084723348`], 
     Hue[0.6490718686307487, 1, 0.10128510497280944`], 
     Hue[0.6493815925822217, 1, 0.10085625642461608`], 
     Hue[0.6471654960438836, 1, 0.10392469778539193`], 
     Hue[0.6480308228037529, 1, 0.10272655304095757`], 
     Hue[0.6490965881744875, 1, 0.10125087791224813`], 
     Hue[0.6405210148027639, 1, 0.11312474873463457`], 
     Hue[0.640521014802764, 1, 0.11312474873463454`], 
     Hue[0.6494038820916501, 1, 0.10082539402694603`], 
     Hue[0.6496136747003404, 1, 0.10053491195337484`], 
     Hue[0.648883744939926, 1, 0.10154558392933336`], 
     Hue[0.6476202126696591, 1, 0.1032950901497029], 
     Hue[0.6476202126696591, 1, 0.10329509014970288`], 
     Hue[0.649743555965862, 1, 0.10035507635496044`], 
     Hue[0.6476792963742027, 1, 0.1032132819434116], 
     Hue[0.6486897531799507, 1, 0.10181418790468372`], 
     Hue[0.6495184060337525, 1, 0.10066682241480417`], 
     Hue[0.649776440711349, 1, 0.1003095436304399], 
     Hue[0.6492287390176986, 1, 0.10106789982164817`], 
     Hue[0.6497104700138886, 1, 0.10040088767307732`], 
     Hue[0.6497839153853582, 1, 0.10029919408181179`], 
     Hue[0.6497426953446435, 1, 0.1003562679843398], 
     Hue[0.6490442051142656, 1, 0.10132340830332459`], 
     Hue[0.6494528731678745, 1, 0.10075756022909697`], 
     Hue[0.6497338391888878, 1, 0.10036853035384762`], 
     Hue[0.6498050535200882, 1, 0.10026992589526255`], 
     Hue[0.06364688787648276, 1, 0.9118735398633316], 
     Hue[0.08581451348565816, 1, 0.8811799044044732], 
     Hue[0.04779306774118286, 1, 0.933824983127593], 
     Hue[0.041007174555774184`, 1, 0.9432208352304665], 
     Hue[0.018537678405841307`, 1, 0.9743324452842197], 
     Hue[0.019148238853984978`, 1, 0.9734870538944823], 
     Hue[0.09293622957062242, 1, 0.8713190667483689], 
     Hue[0.09172729912466382, 1, 0.8729929704427731], 
     Hue[0.6467521884209034, 1, 0.1044969698787491], 
     Hue[0.6464905891329383, 1, 0.10485918427746997`], 
     Hue[0.0021608338217425915`, 1, 0.997008076246818], 
     Hue[0.0033917764847102294`, 1, 0.9953036940980935], 
     Hue[0.0022813832686379154`, 1, 0.9968411616280398], 
     Hue[0.0035253607560050693`, 1, 0.9951187312609161], 
     Hue[0.05062406090060767, 1, 0.9299051464453124], 
     Hue[0.057083734909899264`, 1, 0.9209609824324472], 
     Hue[0.029474244065731403`, 1, 0.9591895082166797], 
     Hue[0.026111929724167537`, 1, 0.9638450203819219], 
     Hue[0.031224615976722103`, 1, 0.9567659163399233], 
     Hue[0.6498118503627555, 1, 0.1002605148823387], 
     Hue[0.6493926417382123, 1, 0.10084095759324452`], 
     Hue[0.6471529574078013, 1, 0.10394205897381359`], 
     Hue[0.07240847923723182, 1, 0.8997421056715252], 
     Hue[0.06894168590298722, 1, 0.9045422810574024], 
     Hue[0.03685526688188134, 1, 0.9489696304712413], 
     Hue[0.03821041064913944, 1, 0.94709327756273], 
     Hue[0.06502260895696321, 1, 0.9099686952903586], 
     Hue[0.06429581960137787, 1, 0.9109750190134768], 
     Hue[0.019266698629920587`, 1, 0.9733230326662637], 
     Hue[0.6066303035608369, 1, 0.1600503489157643], 
     Hue[0.6482409961321133, 1, 0.10243554381707398`], 
     Hue[0.0636637711154695, 1, 0.9118501630708884], 
     Hue[0.05093340024236137, 1, 0.9294768304336536], 
     Hue[0.018201531839944662`, 1, 0.9747978789908459], 
     Hue[0.10382439292732959`, 1, 0.8562431482544667], 
     Hue[0.03888372036392829, 1, 0.9461610025730224], 
     Hue[0.02791769720394044, 1, 0.9613447269483901], 
     Hue[0.04205085971589184, 1, 0.9417757327010728], 
     Hue[0.0162755928385101, 1, 0.9774645637620629], 
     Hue[0.033394658565627844`, 1, 0.9537612419860538], 
     Hue[0.03241191645995778, 1, 0.9551219618246739], 
     Hue[0.05318268781556246, 1, 0.926362432255375], 
     Hue[0.03023901383841665, 1, 0.9581305962237309], 
     Hue[0.03023901383841665, 1, 0.9581305962237309], 
     Hue[0.028798522432975315`, 1, 0.9601251227851111], 
     Hue[0.017559328634829674`, 1, 0.9756870834286975], 
     Hue[0.03069642969191666, 1, 0.9574972511958076], 
     Hue[0.07320400345297817, 1, 0.8986406106035687], 
     Hue[0.03423791418292599, 1, 0.9525936572851793], 
     Hue[0.04352149226450697, 1, 0.9397394722491442], 
     Hue[0.03879069980425298, 1, 0.9462898002710343], 
     Hue[0.026244418906802958`, 1, 0.9636615738213496], 
     Hue[0.04169642954516195, 1, 0.9422664821682373], 
     Hue[0.013641543611771167`, 1, 0.9811117088452399], 
     Hue[0.05929233126679978, 1, 0.9179029259382772], 
     Hue[0.06984225064262772, 1, 0.9032953452640539], 
     Hue[0.06440920276376849, 1, 0.9108180269424744], 
     Hue[0.6472585026881512, 1, 0.10379591935486765`], 
     Hue[0.040553238283958515`, 1, 0.9438493623760575], 
     Hue[0.0553332675508561, 1, 0.9233847064680454], 
     Hue[0.047081871542754894`, 1, 0.9348097163254163], 
     Hue[0.06374640815574029, 1, 0.9117357425535904], 
     Hue[0.036396428723724616`, 1, 0.9496049448440735], 
     Hue[0.6486503048068177, 1, 0.10186880872902164`], 
     Hue[0.12038335839839909`, 1, 0.833315349909909], 
     Hue[0.07974756122609494, 1, 0.8895802998407917], 
     Hue[0.6495028420046701, 1, 0.10068837260891834`], 
     Hue[0.2216719091828594, 1, 0.6930696642083486], 
     Hue[0.648654734699049, 1, 0.10186267503208601`], 
     Hue[0.6496776182866274, 1, 0.10044637468005445`], 
     Hue[0.648943951335204, 1, 0.10146222122817918`], 
     Hue[0.6493676095841963, 1, 0.10087561749880522`], 
     Hue[0.6494744179209362, 1, 0.10072772903254985`], 
     Hue[0.6499985476770227, 1, 0.10000201090873787`], 
     Hue[0.6493915076499502, 1, 0.1008425278692997], 
     Hue[0.6499839745405096, 1, 0.100022189097756], 
     Hue[0.6499824476755622, 1, 0.10002430321845229`], 
     Hue[0.6499583083822401, 1, 0.10005772685535995`], 
     Hue[0.6498693186063289, 1, 0.10018094346816003`], 
     Hue[0.6497269590604986, 1, 0.10037805668546348`], 
     Hue[0.6499980338107145, 1, 0.1000027224159337], 
     Hue[0.6499934744313104, 1, 0.10000903540280097`], 
     Hue[0.6499969215200364, 1, 0.10000426251071888`], 
     Hue[0.6470353766715933, 1, 0.1041048630701017], 
     Hue[0.6499925446036501, 1, 0.10001032285648452`], 
     Hue[0.6499969367808718, 1, 0.10000424138033143`], 
     Hue[0.6499609879522575, 1, 0.10005401668148967`], 
     Hue[0.6499809257736326, 1, 0.10002641046727788`], 
     Hue[0.09877508489427267, 1, 0.8632344978386993], 
     Hue[0.04859175193662091, 1, 0.9327191127031403], 
     Hue[0.04768328208227213, 1, 0.9339769940399308], 
     Hue[0.19354820697457858`, 1, 0.7320101749582758], 
     Hue[0.030840217316589813`, 1, 0.957298160638568], 
     Hue[0.02899135450435797, 1, 0.9598581245324275], 
     Hue[0.05952534975938406, 1, 0.9175802849485452], 
     Hue[0.057104578741587586`, 1, 0.9209321217424172], 
     Hue[0.023817360629775575`, 1, 0.96702211605108], 
     Hue[0.025714972226166477`, 1, 0.9643946538406926], 
     Hue[0.12178343687308557`, 1, 0.8313767797141892], 
     Hue[0.5616019202312185, 1, 0.22239734121831292`], 
     Hue[0.5749599152120318, 1, 0.2039016558602637], 
     Hue[0.602712996325463, 1, 0.16547431278012809`], 
     Hue[0.6027422984139095, 1, 0.1654337406576638], 
     Hue[0.6014978350094349, 1, 0.16715684383309015`], 
     Hue[0.04169642954516195, 1, 0.9422664821682373], 
     Hue[0.045438181965524294`, 1, 0.9370855942015818], 
     Hue[0.027510556808322484`, 1, 0.9619084598038612], 
     Hue[0.11100834442981822`, 1, 0.8462961384817902], 
     Hue[0.649699285904165, 1, 0.10041637336346389`], 
     Hue[0.6497782778547827, 1, 0.10030699989337782`], 
     Hue[0.6498448364467028, 1, 0.10021484184302697`], 
     Hue[0.6499937253541108, 1, 0.10000868797123122`], 
     Hue[0.6488665247514132, 1, 0.10156942726727408`], 
     Hue[0.6489921274555965, 1, 0.1013955158307126], 
     Hue[0.648953670374948, 1, 0.10144876409622587`], 
     Hue[0.6444041113611124, 1, 0.10774815349999815`], 
     Hue[0.6444041113611125, 1, 0.10774815349999814`], 
     Hue[0.6476792963742027, 1, 0.10321328194341163`], 
     Hue[0.6499986441866097, 1, 0.10000187728007896`], 
     Hue[0.6499988636243521, 1, 0.10000157344320475`], 
     Hue[0.6499952819733407, 1, 0.10000653265229763`], 
     Hue[0.6496186666238246, 1, 0.10052800005931987`], 
     Hue[0.6498576069015085, 1, 0.10019715967483434`], 
     Hue[0.6498922784884097, 1, 0.10014915286220206`], 
     Hue[0.6499667631516982, 1, 0.10004602025149481`], 
     Hue[0.6498716140532944, 1, 0.10017776515697706`], 
     Hue[0.6499896988601637, 1, 0.10001426311669652`], 
     Hue[0.6499857333285166, 1, 0.10001975385282313`], 
     Hue[0.6497575763462137, 1, 0.10033566352062726`], 
     Hue[0.6498779198241658, 1, 0.1001690340896167], 
     Hue[0.6487521504229286, 1, 0.10172779172209905`], 
     Hue[0.6480322241472688, 1, 0.10272461271916623`], 
     Hue[0.6456093981542613, 1, 0.10607929486333044`], 
     Hue[0.6438645361601399, 1, 0.10849525762442161`], 
     Hue[0.6499582086363724, 1, 0.10005786496502277`], 
     Hue[0.6499542331203751, 1, 0.10006336952563441`], 
     Hue[0.6499391258748829, 1, 0.10008428725016214`], 
     Hue[0.0789693272008013, 1, 0.8906578546450444], 
     Hue[0.0614929596210102, 1, 0.9148559020632165], 
     Hue[0.07546597717883696, 1, 0.8955086469831488], 
     Hue[0.07370672850149407, 1, 0.8979445297671621], 
     Hue[0.053981287722602134`, 1, 0.9252566785379356], 
     Hue[0.6451827962032917, 1, 0.10666997448775006`], 
     Hue[0.643333574754259, 1, 0.10923043495564139`], 
     Hue[0.6499758858821693, 1, 0.10003338877853486`], 
     Hue[0.6485659081529022, 1, 0.10198566563444322`], 
     Hue[0.647788838414318, 1, 0.10306160834940584`], 
     Hue[0.6499906477453703, 1, 0.10001294927564114`], 
     Hue[0.6499961053430436, 1, 0.10000539260193968`], 
     Hue[0.6499954970192986, 1, 0.10000623489635585`], 
     Hue[0.6495704434939058, 1, 0.10059477054689965`], 
     Hue[0.6496060456525027, 1, 0.10054547525038092`], 
     Hue[0.6499830657578263, 1, 0.10002344741224062`], 
     Hue[0.649950201650959, 1, 0.10006895156021076`], 
     Hue[0.6499723188068057, 1, 0.10003832780596128`], 
     Hue[0.649951928607446, 1, 0.10006656038969021`], 
     Hue[0.6495038205379544, 1, 0.10068701771667861`], 
     Hue[0.6499324527590057, 1, 0.10009352694906906`], 
     Hue[0.6498805022972121, 1, 0.10016545835770649`], 
     Hue[0.6439044440276992, 1, 0.10844000057703199`], 
     Hue[0.6304858768930425, 1, 0.12701955507117196`], 
     Hue[0.6446601445104554, 1, 0.10739364606244647`], 
     Hue[0.6396767740768357, 1, 0.11429369743207374`], 
     Hue[0.6467055444258307, 1, 0.10456155387192674`], 
     Hue[0.6436428112647089, 1, 0.10880226132578767`], 
     Hue[0.6393133159010926, 1, 0.11479694721387178`], 
     Hue[0.6482956795092666, 1, 0.10235982837178473`], 
     Hue[0.64713335389187, 1, 0.10396920230356461`], 
     Hue[0.6467958937660881, 1, 0.10443645478541642`], 
     Hue[0.6493199599353737, 1, 0.10094159393563636`], 
     Hue[0.644481564530696, 1, 0.10764091064980552`], 
     Hue[0.647603562504106, 1, 0.10331814422508409`], 
     Hue[0.6439344465583411, 1, 0.10839845861152772`], 
     Hue[0.06207432696715964, 1, 0.9140509318916251], 
     Hue[0.021000311582941023`, 1, 0.9709226455005433], 
     Hue[0.14826934081387333`, 1, 0.7947039896423291], 
     Hue[0.04328293913667425, 1, 0.9400697765799895], 
     Hue[0.10106436155238652`, 1, 0.860064730158234], 
     Hue[0.04305999072090727, 1, 0.9403784743864361], 
     Hue[0.2998962221428872, 1, 0.5847590770329254], 
     Hue[0.29911838975968796`, 1, 0.5858360757173552], 
     Hue[0.04667741459457175, 1, 0.9353697336382852], 
     Hue[0.2255541736176343, 1, 0.687694221144814], 
     Hue[0.16048251384021922`, 1, 0.7777934423750811], 
     Hue[0.16048251384021917`, 1, 0.7777934423750812], 
     Hue[0.0739342122136808, 1, 0.8976295523195188], 
     Hue[0.07281066895396882, 1, 0.899185227602197], 
     Hue[0.037257503764507094`, 1, 0.9484126870952978], 
     Hue[0.014220842291348235`, 1, 0.9803096029812102], 
     Hue[0.02575612995151666, 1, 0.9643376662209768], 
     Hue[0.02417717033757172, 1, 0.9665239179941314], 
     Hue[0.016979219001321266`, 1, 0.9764903121520166], 
     Hue[0.021693872745923937`, 1, 0.9699623300441053], 
     Hue[0.01505916227846793, 1, 0.9791488522298137], 
     Hue[0.1238227201072325, 1, 0.8285531567746011], 
     Hue[0.5984996234851034, 1, 0.17130821363601073`], 
     Hue[0.596327924576561, 1, 0.17431518135553092`], 
     Hue[0.6016537816124339, 1, 0.16694091776739928`], 
     Hue[0.011184520148178612`, 1, 0.9845137413332912], 
     Hue[0.0755098395625875, 1, 0.8954479144518018], 
     Hue[0.0726100573001558, 1, 0.8994629975843997], 
     Hue[0.0749642298875528, 1, 0.8962033740018499], 
     Hue[0.03603714189782403, 1, 0.9501024189107051], 
     Hue[0.07377033265686206, 1, 0.897856462475114], 
     Hue[0.06580465322465623, 1, 0.9088858647658606], 
     Hue[0.06991899329234896, 1, 0.9031890862105937], 
     Hue[0.02326006416827575, 1, 0.9677937573054644], 
     Hue[0.02713471129379119, 1, 0.96242886128552], 
     Hue[0.08848543321196312, 1, 0.8774817078603587], 
     Hue[0.08121293919220995, 1, 0.8875513149646324], 
     Hue[0.06814797737594058, 1, 0.9056412620948514], 
     Hue[0.06606034350726608, 1, 0.9085318320668624], 
     Hue[0.04650250008475876, 1, 0.9356119229595649], 
     Hue[0.05134600273242074, 1, 0.9289055346781867], 
     Hue[0.6461164616995995, 1, 0.10537720687747776`], 
     Hue[0.646589707372782, 1, 0.10472194363768654`], 
     Hue[0.6464638328272155, 1, 0.10489623147000937`], 
     Hue[0.6461929942310273, 1, 0.10527123875703917`], 
     Hue[0.6462595534905318, 1, 0.1051790797823407], 
     Hue[0.11312390279315265`, 1, 0.8433669038248655], 
     Hue[0.14019007733942246`, 1, 0.8058906621454152], 
     Hue[0.03256343368018555, 1, 0.9549121687505122], 
     Hue[0.057862114219665695`, 1, 0.9198832264650783], 
     Hue[0.051949007444326956`, 1, 0.9280706050770858], 
     Hue[0.0791033248313312, 1, 0.8904723194643106], 
     Hue[0.6461375668076628, 1, 0.10534798442015933`], 
     Hue[0.6461541778933109, 1, 0.10532498445541574`], 
     Hue[0.05241153651517394, 1, 0.9274301802097591], 
     Hue[0.06748448072604096, 1, 0.9065599497639434], 
     Hue[0.05284657880693011, 1, 0.9268278139596352], 
     Hue[0.5623465277061914, 1, 0.2213663462529658], 
     Hue[0.5670055134867641, 1, 0.2149154428644805], 
     Hue[0.564900717294584, 1, 0.2178297760536529], 
     Hue[0.6485067685214111, 1, 0.10206755127804629`], 
     Hue[0.6439953860755101, 1, 0.10831408081852449`], 
     Hue[0.6499195572370497, 1, 0.10011138228716199`], 
     Hue[0.6499311376513854, 1, 0.10009534786731247`], 
     Hue[0.646006881614683, 1, 0.10552893314890052`], 
     Hue[0.6468245515886034, 1, 0.10439677472347218`], 
     Hue[0.6464603224028663, 1, 0.10490109205756971`], 
     Hue[0.6480750122246861, 1, 0.1026653676888962], 
     Hue[0.6240461007928987, 1, 0.13593616813290957`], 
     Hue[0.6374704864405576, 1, 0.11734855723615105`], 
     Hue[0.6481633187973176, 1, 0.10254309704986793`], 
     Hue[0.649943659549119, 1, 0.10007800985506597`], 
     Hue[0.6499303766567089, 1, 0.10009640155224925`], 
     Hue[0.6498379951402355, 1, 0.10022431442121241`], 
     Hue[0.6495920618185648, 1, 0.10056483748198729`], 
     Hue[0.0735784721735726, 1, 0.8981221154519764], 
     Hue[0.03868906609308331, 1, 0.9464305238711155], 
     Hue[0.02272121346256517, 1, 0.968539858282602], 
     Hue[0.008648389508746579, 1, 0.9880253068340432], 
     Hue[0.6498248235446792, 1, 0.1002425520150596], 
     Hue[0.06214634927713514, 1, 0.9139512086931975], 
     Hue[0.06289730437374064, 1, 0.9129114247132822], 
     Hue[0.06289730437374053, 1, 0.9129114247132823], 
     Hue[0.6499943201394927, 1, 0.10000786442224104`], 
     Hue[0.649254163378747, 1, 0.10103269686019653`], 
     Hue[0.6485904499694474, 1, 0.10195168465768824`], 
     Hue[0.12318661616118176`, 1, 0.8294339160845176], 
     Hue[0.12318661616118176`, 1, 0.8294339160845176], 
     Hue[0.1173558015428744, 1, 0.8375073517098662], 
     Hue[0.042286515002341596`, 1, 0.9414494407659885], 
     Hue[0.04761974661301638, 1, 0.9340649662281311], 
     Hue[0.051582291276240366`, 1, 0.9285783659252057], 
     Hue[0.647454728061143, 1, 0.10352422268457119`], 
     Hue[0.647450176353928, 1, 0.10353052504840743`], 
     Hue[0.057083734909899264`, 1, 0.9209609824324472], 
     Hue[0.06357340879840456, 1, 0.911975280125286], 
     Hue[0.07119927954457517, 1, 0.9014163821690498], 
     Hue[0.6499623829960771, 1, 0.10005208508235479`], 
     Hue[0.6499726201977906, 1, 0.10003791049536694`], 
     Hue[0.6494772888157235, 1, 0.10072375394745972`], 
     Hue[0.6499697038644608, 1, 0.10004194849536201`], 
     Hue[0.6499800297411067, 1, 0.10002765112769844`], 
     Hue[0.6499902223069337, 1, 0.10001353834424564`], 
     Hue[0.6497071671533372, 1, 0.10040546086461008`], 
     Hue[0.6461505024562492, 1, 0.10533007352211665`], 
     Hue[0.6452749299036067, 1, 0.10654240474885232`], 
     Hue[0.6498028997115937, 1, 0.10027290809163965`], 
     Hue[0.6494106402112511, 1, 0.10081603663057546`], 
     Hue[0.6495987882121048, 1, 0.10055552401400869`], 
     Hue[0.6494825345148535, 1, 0.1007164906717413], 
     Hue[0.6469777954465857, 1, 0.10418459092011212`], 
     Hue[0.009937563168037733, 1, 0.9862402971519478], 
     Hue[0.005761138716815051, 1, 0.9920230386997946], 
     Hue[0.10322864008369348`, 1, 0.8570680368071937], 
     Hue[0.03341036005911768, 1, 0.9537395014566062], 
     Hue[0.0394302518233689, 1, 0.9454042667061047], 
     Hue[0.05895198721725725, 1, 0.9183741715453361], 
     Hue[0.6498965205318745, 1, 0.10014327926355841`], 
     Hue[0.05062406090060767, 1, 0.9299051464453124], 
     Hue[0.6379953443944169, 1, 0.11662183083849978`], 
     Hue[0.6432193535170956, 1, 0.1093885874378677], 
     Hue[0.645910441411738, 1, 0.1056624657375935], 
     Hue[0.6473255099465282, 1, 0.10370314007403801`], 
     Hue[0.5818622116873443, 1, 0.19434462997136948`], 
     Hue[0.6440655714602169, 1, 0.10821690105508434`], 
     Hue[0.6460319291898848, 1, 0.10549425189092866`], 
     Hue[0.649816574752118, 1, 0.10025397342014435`], 
     Hue[0.649999605669737, 1, 0.10000054599574884`], 
     Hue[0.6468099634904545, 1, 0.10441697362860157`], 
     Hue[0.6483571089979854, 1, 0.10227477215663569`], 
     Hue[0.6499919930894206, 1, 0.10001108649157156`], 
     Hue[0.6499909176556408, 1, 0.10001257555372818`], 
     Hue[0.6499870048874995, 1, 0.10001799323269309`], 
     Hue[0.6474672147747128, 1, 0.10350693338885929`], 
     Hue[0.057083734909899264`, 1, 0.9209609824324472], 
     Hue[0.13086189998617925`, 1, 0.8188066000191365], 
     Hue[0.09885516960731455, 1, 0.863123611312949], 
     Hue[0.6365333830338097, 1, 0.11864608503010975`], 
     Hue[0.6414280585903478, 1, 0.11186884195182624`], 
     Hue[0.649698528006097, 1, 0.10041742276078884`], 
     Hue[0.6497693035814939, 1, 0.10031942581023925`], 
     Hue[0.641493696785014, 1, 0.11177795829767295`], 
     Hue[0.644000176463968, 1, 0.10830744797296747`], 
     Hue[0.644000176463968, 1, 0.10830744797296749`], 
     Hue[0.6499844425789807, 1, 0.10002154104448831`], 
     Hue[0.017271616449651805`, 1, 0.976085454146636], 
     Hue[0.018431012585652495`, 1, 0.9744801364198658], 
     Hue[0.6499998647959381, 1, 0.10000018720562424`], 
     Hue[0.6499994371734349, 1, 0.100000779298321], 
     Hue[0.649999132714483, 1, 0.10000120085686982`], 
     Hue[0.6499987738806146, 1, 0.10000169770376455`], 
     Hue[0.6499998843610802, 1, 0.10000016011542733`], 
     Hue[0.6499990189277065, 1, 0.10000135840779097`], 
     Hue[0.6499989425380476, 1, 0.10000146417808796`], 
     Hue[0.6499987324947435, 1, 0.10000175500727826`], 
     Hue[0.6499980168427846, 1, 0.10000274590999057`], 
     Hue[0.2240178964015206, 1, 0.6898213742132792], 
     Hue[0.28748569694134524`, 1, 0.6019428811581374], 
     Hue[0.12073457523840347`, 1, 0.8328290496699028], 
     Hue[0.11733481341989016`, 1, 0.8375364121878445], 
     Hue[0.11733481341989016`, 1, 0.8375364121878445], 
     Hue[0.5456483643202249, 1, 0.2444868801719963], 
     Hue[0.644848605723679, 1, 0.10713269976721373`], 
     Hue[0.6453508529527922, 1, 0.10643728052690318`], 
     Hue[0.6476608639459399, 1, 0.10323880376716019`], 
     Hue[0.6478316812932331, 1, 0.10300228744013876`], 
     Hue[0.6420376696207584, 1, 0.11102476514048841`], 
     Hue[0.6350472444831297, 1, 0.12070381533105123`], 
     Hue[0.5065526153457091, 1, 0.29861945567517206`], 
     Hue[0.5120873527559253, 1, 0.29095597310718035`], 
     Hue[0.538278602882412, 1, 0.2546911652397372], 
     Hue[0.5416127195076832, 1, 0.25007469606628485`], 
     Hue[0.17109723630573104`, 1, 0.7630961343459108], 
     Hue[0.21225814539324372`, 1, 0.7061041063785857], 
     Hue[0.033475818301066385`, 1, 0.9536488669677542], 
     Hue[0.024479121590509245`, 1, 0.9661058316439103], 
     Hue[0.08286331183439777, 1, 0.8852661836139109], 
     Hue[0.06087409373159214, 1, 0.9157127932947186], 
     Hue[0.07092948667642462, 1, 0.9017899415249506], 
     Hue[0.14339109880788636`, 1, 0.8014584785736958], 
     Hue[0.130537332075239, 1, 0.8192560017419768], 
     Hue[0.1079648476754268, 1, 0.8505102109109475], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999929888856, 1, 0.1000000097076969], 
     Hue[0.6499998556337312, 1, 0.10000019989175687`], 
     Hue[0.6499975306790926, 1, 0.10000341905971798`], 
     Hue[0.644594354830961, 1, 0.1074847394648234], 
     Hue[0.6436547469838655, 1, 0.1087857349454171], 
     Hue[0.6430439065673588, 1, 0.10963151398365718`], 
     Hue[0.6413333107544064, 1, 0.11200003126312974`], 
     Hue[0.6499984729564457, 1, 0.1000021143679983], 
     Hue[0.6499998819271423, 1, 0.10000016348549536`], 
     Hue[0.6499999953055019, 1, 0.10000000650007436`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649999630018986, 1, 0.10000051228140414`], 
     Hue[0.6499999725779861, 1, 0.10000003796894227`], 
     Hue[0.64999708503316, 1, 0.10000403610793232`], 
     Hue[0.605803864782396, 1, 0.16119464876283632`], 
     Hue[0.6002685571375672, 1, 0.16885892088644539`], 
     Hue[0.5980030751001162, 1, 0.17199574216907], 
     Hue[0.5915357387222795, 1, 0.1809505156153054], 
     Hue[0.5844539474889465, 1, 0.19075607270761247`], 
     Hue[0.5842632743081962, 1, 0.19102008172711288`], 
     Hue[0.5883334297222325, 1, 0.18538448192306278`], 
     Hue[0.5875249340739627, 1, 0.18650393743605176`], 
     Hue[0.5767551333872727, 1, 0.201415969156084], 
     Hue[0.5688041735651079, 1, 0.2124249904483121], 
     Hue[0.6273931640653431, 1, 0.13130177283260197`], 
     Hue[0.649999002177137, 1, 0.10000138160088722`], 
     Hue[0.6499999699354154, 1, 0.10000004162788635`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499839023451237, 1, 0.1000222890605979], 
     Hue[0.6499980728841622, 1, 0.10000266831423697`], 
     Hue[0.6498934221914403, 1, 0.10014756927339034`], 
     Hue[0.6214562468639946, 1, 0.1395221197267768], 
     Hue[0.5808482853713703, 1, 0.19574852794733344`], 
     Hue[0.525264659992271, 1, 0.2727104707799325], 
     Hue[0.4797852573948507, 1, 0.3356819512994375], 
     Hue[0.45080235080800923`, 1, 0.37581212965044875`], 
     Hue[0.42662153948924963`, 1, 0.40929325301488517`], 
     Hue[0.38790883259028114`, 1, 0.4628954625673031], 
     Hue[0.36302116385565725`, 1, 0.49735531158447466`], 
     Hue[0.3753340750129613, 1, 0.480306665366669], 
     Hue[0.40153235119463115`, 1, 0.44403212911512613`], 
     Hue[0.4079018827472577, 1, 0.43521277773456624`], 
     Hue[0.3868510116272803, 1, 0.4643601377468427], 
     Hue[0.38113493478544, 1, 0.4722747056816985], 
     Hue[0.4146045020969372, 1, 0.4259322278657792], 
     Hue[0.47443992109996047`, 1, 0.3430831861692855], 
     Hue[0.5400452652637167, 1, 0.25224501732716154`], 
     Hue[0.5973047241496775, 1, 0.17296268963890812`], 
     Hue[0.628991624445407, 1, 0.12908851999866722`], 
     Hue[0.6418890416569172, 1, 0.11123055770580707`], 
     Hue[0.6479806100912969, 1, 0.10279607833512731`], 
     Hue[0.6496777439075401, 1, 0.10044620074340607`], 
     Hue[0.6499748981372279, 1, 0.10003475642537678`], 
     Hue[0.6499986762119131, 1, 0.10000183293735111`], 
     Hue[0.6499999715100772, 1, 0.10000003944758551`], 
     Hue[0.6432683837329979, 1, 0.10932069944661829`], 
     Hue[0.6309314681484599, 1, 0.12640258256367087`], 
     Hue[0.5981782583044749, 1, 0.17175318080918864`], 
     Hue[0.5265335115767785, 1, 0.2709535993552297], 
     Hue[0.4284997118838716, 1, 0.4066927066223317], 
     Hue[0.344391301292921, 1, 0.5231505059021094], 
     Hue[0.276990448816766, 1, 0.6164747631767856], 
     Hue[0.22595494783241432`, 1, 0.6871393030012725], 
     Hue[0.18069096956301606`, 1, 0.7498125036819778], 
     Hue[0.12451734431483175`, 1, 0.827591369410233], 
     Hue[0.10267570086473754`, 1, 0.8578336449565171], 
     Hue[0.11569016644018937`, 1, 0.8398136156981992], 
     Hue[0.14139695966603893`, 1, 0.8042195943085614], 
     Hue[0.14419426734915486`, 1, 0.8003463990550164], 
     Hue[0.12458691312328851`, 1, 0.8274950433677544], 
     Hue[0.12210390972508989`, 1, 0.8309330480729524], 
     Hue[0.19228853426528209`, 1, 0.7337543371711479], 
     Hue[0.2752122147612134, 1, 0.6189369334075507], 
     Hue[0.37096468037044267`, 1, 0.4863565964101564], 
     Hue[0.48247017110096213`, 1, 0.3319643784755909], 
     Hue[0.5617782124072876, 1, 0.22215324435914025`], 
     Hue[0.6065151853681263, 1, 0.16020974333644047`], 
     Hue[0.6349759074118704, 1, 0.12080258973741029`], 
     Hue[0.6499795105696301, 1, 0.10002836998051222`], 
     Hue[0.6499989006054794, 1, 0.10000152223856701`], 
     Hue[0.6483470744992574, 1, 0.10228866607795134`], 
     Hue[0.639956631023622, 1, 0.11390620319806181`], 
     Hue[0.616673246829604, 1, 0.1461447351590098], 
     Hue[0.5774895341441195, 1, 0.2003991065696807], 
     Hue[0.5065612697535073, 1, 0.2986074726489899], 
     Hue[0.37485176352822086`, 1, 0.4809744812686173], 
     Hue[0.22944014729082396`, 1, 0.6823136422127053], 
     Hue[0.14603166782842336`, 1, 0.7978023060837215], 
     Hue[0.10882549185099855`, 1, 0.8493185497447713], 
     Hue[0.09219434485495492, 1, 0.8723462917392931], 
     Hue[0.07019705675044485, 1, 0.9028040752686148], 
     Hue[0.04675787221956795, 1, 0.935258330772906], 
     Hue[0.048136774661970305`, 1, 0.9333490812372718], 
     Hue[0.04143459651683923, 1, 0.9426290202074533], 
     Hue[0.038676166894232256`, 1, 0.9464483843002939], 
     Hue[0.04772291688896013, 1, 0.9339221150768244], 
     Hue[0.02554455123347188, 1, 0.9646306213690389], 
     Hue[0.015058721742109538`, 1, 0.979149462203233], 
     Hue[0.06336875363542949, 1, 0.9122586488124823], 
     Hue[0.1334704969802899, 1, 0.8151946964888294], 
     Hue[0.2199739851159449, 1, 0.6954206359933071], 
     Hue[0.3411712544599908, 1, 0.5276090322861666], 
     Hue[0.4568769469399483, 1, 0.36740115039084087`], 
     Hue[0.542924975093056, 1, 0.24825772679423008`], 
     Hue[0.6054891874955718, 1, 0.16163035577536222`], 
     Hue[0.6379789389063913, 1, 0.11664454612961209`], 
     Hue[0.647899009205653, 1, 0.10290906417678822`], 
     Hue[0.6497603488187218, 1, 0.10033182471253908`], 
     Hue[0.6499834929211847, 1, 0.10002285595528276`], 
     Hue[0.6496892843550106, 1, 0.10043022166229308`], 
     Hue[0.5849948198382672, 1, 0.19000717253163008`], 
     Hue[0.5152377292556356, 1, 0.28659391333835066`], 
     Hue[0.4123210905568667, 1, 0.4290938746135692], 
     Hue[0.2572693918202809, 1, 0.6437808420949956], 
     Hue[0.10234446418981591`, 1, 0.8582922803525627], 
     Hue[0.21697107301606328`, 1, 0.6995785142854508], 
     Hue[0.365591434568137, 1, 0.4937964752133488], 
     Hue[0.4912666838467882, 1, 0.3197845915967549], 
     Hue[0.574692142773666, 1, 0.20427241769800092`], 
     Hue[0.6218356034867247, 1, 0.13899685671068893`], 
     Hue[0.6497117942648292, 1, 0.10039905409485199`], 
     Hue[0.6336241153822073, 1, 0.12267430177848226`], 
     Hue[0.5950360731629449, 1, 0.17610389869746085`], 
     Hue[0.5165640729325323, 1, 0.2847574374780324], 
     Hue[0.37724267786105503`, 1, 0.47766398450007763`], 
     Hue[0.3242395019761018, 1, 0.5510529972638591], 
     Hue[0.4757756373768842, 1, 0.34123373286277575`], 
     Hue[0.5664168652929649, 1, 0.21573049420974105`], 
     Hue[0.6161209268094339, 1, 0.1469094859561685], 
     Hue[0.6498901466536714, 1, 0.10015210463337815`], 
     Hue[0.5393823954403061, 1, 0.2531628370826532], 
     Hue[0.3797675315589142, 1, 0.4741680332261188], 
     Hue[0.1947215912254457, 1, 0.7303854890724598], 
     Hue[0.1551755718954252, 1, 0.7851415158371036], 
     Hue[0.3160500741963202, 1, 0.5623922049589413], 
     Hue[0.4722057603572495, 1, 0.3461766395053469], 
     Hue[0.6491058847112803, 1, 0.1012380057843812], 
     Hue[0.6439397196607403, 1, 0.10839115739282117`], 
     Hue[0.622135775424429, 1, 0.13858123402771375`], 
     Hue[0.551138568212532, 1, 0.23688505939803256`], 
     Hue[0.40069995998016983`, 1, 0.4451846707966879], 
     Hue[0.21997363859228936`, 1, 0.6954211157952916], 
     Hue[0.09317686948294912, 1, 0.870985873023609], 
     Hue[0.03775178411924762, 1, 0.947728298911811], 
     Hue[0.05874569916563288, 1, 0.9186598011552775], 
     Hue[0.06964439892140839, 1, 0.9035692938011268], 
     Hue[0.054440448839187305`, 1, 0.9246209169918945], 
     Hue[0.03721177982131241, 1, 0.9484759971704906], 
     Hue[0.020430647065159846`, 1, 0.9717114117559326], 
     Hue[0.006116313173134547, 1, 0.9915312586833521], 
     Hue[0.006225408537350763, 1, 0.9913802035636681], 
     Hue[0.009435289111973555, 1, 0.9869357535372674], 
     Hue[0.01001873548532084, 1, 0.9861279047126328], 
     Hue[0.06571233685343236, 1, 0.909013687433709], 
     Hue[0.16982938621239269`, 1, 0.7648516190905332], 
     Hue[0.3141629566625122, 1, 0.5650051369288293], 
     Hue[0.465542847990703, 1, 0.35540221047441134`], 
     Hue[0.5769832257823871, 1, 0.2011001489166947], 
     Hue[0.6296755092437066, 1, 0.12814160258563695`], 
     Hue[0.6461485447523412, 1, 0.10533278418906616`], 
     Hue[0.6499707866363719, 1, 0.10004044927271588`], 
     Hue[0.6492143459933011, 1, 0.10108782862466016`], 
     Hue[0.6441407601679922, 1, 0.10811279361354939`], 
     Hue[0.6238182428743096, 1, 0.13625166371249436`], 
     Hue[0.5663510214490879, 1, 0.2158216626089553], 
     Hue[0.4467910291937711, 1, 0.3813662672701631], 
     Hue[0.27904361375621184`, 1, 0.6136319194144759], 
     Hue[0.13351344119723862`, 1, 0.8151352352653619], 
     Hue[0.05257407939504899, 1, 0.9272051208376245], 
     Hue[0.025888942072453625`, 1, 0.9641537725150642], 
     Hue[0.03856779076734662, 1, 0.9465984435529047], 
     Hue[0.06002893617229632, 1, 0.9168830114537435], 
     Hue[0.06297304716478802, 1, 0.9128065500795244], 
     Hue[0.04692201552584219, 1, 0.935031055425757], 
     Hue[0.04104484734040881, 1, 0.9431686729132802], 
     Hue[0.043898982506381135`, 1, 0.9392167934527031], 
     Hue[0.024212888134958144`, 1, 0.9664744625823656], 
     Hue[0.00517255855717047, 1, 0.9928379958439177], 
     Hue[0.018708583593559425`, 1, 0.9740958073319946], 
     Hue[0.04185745453622647, 1, 0.9420435244883018], 
     Hue[0.0628911721093025, 1, 0.9129199155409657], 
     Hue[0.12584839116030855`, 1, 0.8257483814703419], 
     Hue[0.23857016003186077`, 1, 0.6696720861097313], 
     Hue[0.36648743684999013`, 1, 0.4925558566692445], 
     Hue[0.4884351090134196, 1, 0.3237052336737267], 
     Hue[0.5784867098492943, 1, 0.199018401747131], 
     Hue[0.6263496437550646, 1, 0.13274664710837208`], 
     Hue[0.644701583669634, 1, 0.10733626876512217`], 
     Hue[0.6493239150489023, 1, 0.1009361176245968], 
     Hue[0.6499582492178618, 1, 0.10005780877526832`], 
     Hue[0.6499852600653462, 1, 0.10002040914028992`], 
     Hue[0.6021231020095987, 1, 0.16629108952517094`], 
     Hue[0.525688615607696, 1, 0.27212345531242094`], 
     Hue[0.4002184216867108, 1, 0.4458514161260928], 
     Hue[0.258055951192298, 1, 0.6426917598875874], 
     Hue[0.23147825488214535`, 1, 0.6794916470862603], 
     Hue[0.34530779115203375`, 1, 0.521881519943338], 
     Hue[0.45875962254527336`, 1, 0.3647943687834677], 
     Hue[0.6499982954700144, 1, 0.10000236011844169`], 
     Hue[0.5355428886601953, 1, 0.25847907723972974`], 
     Hue[0.44001433343840435`, 1, 0.3907493844699017], 
     Hue[0.34287336106483335`, 1, 0.5252522692948461], 
     Hue[0.24720746943046112`, 1, 0.6577127346347461], 
     Hue[0.22952922044509477`, 1, 0.6821903101529457], 
     Hue[0.1920595501912255, 1, 0.7340713920429186], 
     Hue[0.20005354625680116`, 1, 0.7230027821059677], 
     Hue[0.25231624389878954`, 1, 0.6506390469093684], 
     Hue[0.25880069584880533`, 1, 0.6416605749785772], 
     Hue[0.33144520438597, 1, 0.5410758708501954], 
     Hue[0.4161690355583556, 1, 0.42376595076535384`], 
     Hue[0.49717125175464727`, 1, 0.31160903603202694`], 
     Hue[0.649997929053041, 1, 0.10000286746502014`], 
     Hue[0.649999937616737, 1, 0.10000008637682566`], 
     Hue[0.6397007081080387, 1, 0.11426055800425422`], 
     Hue[0.6199879664435257, 1, 0.14155512338588747`], 
     Hue[0.5824560412059364, 1, 0.19352240448408808`], 
     Hue[0.5362164225575521, 1, 0.2575464918433894], 
     Hue[0.49672507838486707`, 1, 0.31222681454403023`], 
     Hue[0.47156766340145667`, 1, 0.3470601583672139], 
     Hue[0.45313411801935133`, 1, 0.3725835288962829], 
     Hue[0.44154658421857457`, 1, 0.3886278064665891], 
     Hue[0.43246506612963376`, 1, 0.4012022161281995], 
     Hue[0.4331516531966305, 1, 0.4002515571123578], 
     Hue[0.4581802594529749, 1, 0.36559656383434247`], 
     Hue[0.4642425577811309, 1, 0.3572026123030495], 
     Hue[0.4530870595053957, 1, 0.3726486868386829], 
     Hue[0.47690592578938407`, 1, 0.339668718137776], 
     Hue[0.5190045941392355, 1, 0.28137825426875096`], 
     Hue[0.6499996203899421, 1, 0.10000052561392632`], 
     Hue[0.6499999581560985, 1, 0.10000005793770987`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649998697945513, 1, 0.1000018028446744], 
     Hue[0.6499853303871161, 1, 0.10002031177168538`], 
     Hue[0.6498812891688583, 1, 0.10016436884311923`], 
     Hue[0.6493235138791089, 1, 0.10093667309046467`], 
     Hue[0.6466005258749555, 1, 0.10470696417313856`], 
     Hue[0.6403176189570315, 1, 0.11340637375180258`], 
     Hue[0.6300405920432861, 1, 0.12763610332468078`], 
     Hue[0.6172938986396966, 1, 0.14528537111426615`], 
     Hue[0.6045312444555834, 1, 0.16295673844611536`], 
     Hue[0.5957681668063417, 1, 0.17509023057583462`], 
     Hue[0.5983579899762795, 1, 0.1715043215713053], 
     Hue[0.6065292833081961, 1, 0.16019022311172856`], 
     Hue[0.6122259367188088, 1, 0.15230254915857253`], 
     Hue[0.6153412796185826, 1, 0.14798899745119334`], 
     Hue[0.6088598912440909, 1, 0.15696322750818187`], 
     Hue[0.5964237351285364, 1, 0.17418252059125727`], 
     Hue[0.592365924061182, 1, 0.1798010282229787], 
     Hue[0.605128669685848, 1, 0.1621295342811336], 
     Hue[0.6214017151299335, 1, 0.13959762520470753`], 
     Hue[0.6340404929532419, 1, 0.12209777898781889`], 
     Hue[0.6435378051870545, 1, 0.10894765435638618`], 
     Hue[0.64816683180358, 1, 0.10253823288735082`], 
     Hue[0.6499415492425693, 1, 0.10008093181798106`], 
     Hue[0.6499913133183599, 1, 0.10001202771304012`], 
     Hue[0.6499984451206817, 1, 0.10000215290982532`], 
     Hue[0.6499998689759074, 1, 0.1000001814179744], 
     Hue[0.6499999946808874, 1, 0.10000000736492512`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649999991286051, 1, 0.10000001206546782`], 
     Hue[0.6499998158099827, 1, 0.10000025503233165`], 
     Hue[0.6499978187463464, 1, 0.10000302019736655`], 
     Hue[0.649982890365702, 1, 0.10002369026287426`], 
     Hue[0.6498993782206554, 1, 0.10013932246370807`], 
     Hue[0.6496046189230954, 1, 0.10054745072186794`], 
     Hue[0.6488209670252897, 1, 0.10163250719575281`], 
     Hue[0.6474350045500273, 1, 0.1035515321615007], 
     Hue[0.6457462266604738, 1, 0.10588984000857479`], 
     Hue[0.6442691656746478, 1, 0.1079350013735647], 
     Hue[0.6444585173659669, 1, 0.10767282210866116`], 
     Hue[0.6464103363882171, 1, 0.10497030346246863`], 
     Hue[0.6479964636805288, 1, 0.10277412721157558`], 
     Hue[0.6479448413061017, 1, 0.10284560434539755`], 
     Hue[0.6457218671558378, 1, 0.10592356855345544`], 
     Hue[0.6427317566813526, 1, 0.1100637215181272], 
     Hue[0.6426016586051124, 1, 0.1102438573159982], 
     Hue[0.6450729162804222, 1, 0.10682211591941551`], 
     Hue[0.6473288273284878, 1, 0.10369854677594002`], 
     Hue[0.6488004698732963, 1, 0.10166088786774367`], 
     Hue[0.649627731191707, 1, 0.10051544911917484`], 
     Hue[0.6499266622852758, 1, 0.10010154452807961`], 
     Hue[0.6499895884328335, 1, 0.10001441601607668`], 
     Hue[0.6499990657349259, 1, 0.10000129359779494`], 
     Hue[0.6499999229535507, 1, 0.10000010667969905`], 
     Hue[0.649999997206145, 1, 0.10000000386841473`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999929888856, 1, 0.1000000097076969], 
     Hue[0.6499998566510486, 1, 0.1000001984831634], 
     Hue[0.6499975864743816, 1, 0.10000334180470258`], 
     Hue[0.6499707575543086, 1, 0.10004048954018818`], 
     Hue[0.6497921714211431, 1, 0.10028776264764805`], 
     Hue[0.6490060766730709, 1, 0.10137620152959419`], 
     Hue[0.647543310959762, 1, 0.10340156944032956`], 
     Hue[0.6459734639830488, 1, 0.10557520371577862`], 
     Hue[0.6452823565592715, 1, 0.10653212168716264`], 
     Hue[0.6451341855981795, 1, 0.10673728147944382`], 
     Hue[0.6452073614073295, 1, 0.10663596112831311`], 
     Hue[0.6447414059100274, 1, 0.10728113027842366`], 
     Hue[0.6440934666212659, 1, 0.10817827698593965`], 
     Hue[0.6430781798783924, 1, 0.10958405862991824`], 
     Hue[0.641405980987597, 1, 0.1118994109402503], 
     Hue[0.6407374428139965, 1, 0.11282507918062024`], 
     Hue[0.6422787469372822, 1, 0.11069096577914783`], 
     Hue[0.6479455197479496, 1, 0.10284466496437751`], 
     Hue[0.6493792718359844, 1, 0.10085946976556005`], 
     Hue[0.6498761351986848, 1, 0.10017150510951331`], 
     Hue[0.6499821579004168, 1, 0.10002470444557673`], 
     Hue[0.649998154721627, 1, 0.10000255500082418`], 
     Hue[0.6499998595678589, 1, 0.10000019444450305`], 
     Hue[0.6499999942182303, 1, 0.10000000800552726`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499996419097441, 1, 0.10000049581727743`], 
     Hue[0.6499902977534591, 1, 0.10001343387982593`], 
     Hue[0.6256478520257426, 1, 0.13371835873358717`], 
     Hue[0.6117609049892991, 1, 0.15294643924558576`], 
     Hue[0.6012708661623315, 1, 0.1674711083906179], 
     Hue[0.5920208974252733, 1, 0.18027875741116006`], 
     Hue[0.584694032988925, 1, 0.19042364663071926`], 
     Hue[0.5881747759918083, 1, 0.18560415631903465`], 
     Hue[0.5880542874916173, 1, 0.1857709865500685], 
     Hue[0.5791764116984981, 1, 0.1980634299559258], 
     Hue[0.5706593667361839, 1, 0.20985626144220687`], 
     Hue[0.5787288549651208, 1, 0.19868312389444814`], 
     Hue[0.6225301003913821, 1, 0.13803524561193242`], 
     Hue[0.6467786193332294, 1, 0.10446037323091305`], 
     Hue[0.6499980726261976, 1, 0.10000266867141883`], 
     Hue[0.6499999226861073, 1, 0.10000010705000528`], 
     Hue[0.6499999987427024, 1, 0.10000000174087363`], 
     Hue[0.49996409864502533`, 1, 0.30774201726073414`], 
     Hue[0.462032577908571, 1, 0.36026258443428627`], 
     Hue[0.404261916223023, 1, 0.4402527313835066], 
     Hue[0.3708583664731346, 1, 0.4865038002679676], 
     Hue[0.40556189320481656`, 1, 0.43845276325486937`], 
     Hue[0.3978328114888238, 1, 0.4491545687077825], 
     Hue[0.5094380056006869, 1, 0.2946242999375105], 
     Hue[0.6168917692749176, 1, 0.14584216561934482`], 
     Hue[0.649999750631233, 1, 0.10000034527983112`], 
     Hue[0.40622528455173157`, 1, 0.43753422138991016`], 
     Hue[0.329163090798735, 1, 0.5442357204325208], 
     Hue[0.26612659014802875`, 1, 0.6315170290258063], 
     Hue[0.2992988881930217, 1, 0.5855861548096624], 
     Hue[0.506874097415585, 1, 0.2981743266553438], 
     Hue[0.34934890026453985`, 1, 0.5162861380952526], 
     Hue[0.6472240633763143, 1, 0.10384360455587249`], 
     Hue[0.6327799075169908, 1, 0.12384320497647444`], 
     Hue[0.5907834716390193, 1, 0.18199211619212705`], 
     Hue[0.5232436831441429, 1, 0.2755087464158021], 
     Hue[0.42527703020671315`, 1, 0.4111548812522433], 
     Hue[0.27559578564789583`, 1, 0.6184058352567596], 
     Hue[0.13514826109786338`, 1, 0.8128716384798814], 
     Hue[0.06547135297627693, 1, 0.9093473574174628], 
     Hue[0.053403045295357776`, 1, 0.9260573218987354], 
     Hue[0.06578454945407564, 1, 0.9089137007558953], 
     Hue[0.06003819740452421, 1, 0.9168701882091204], 
     Hue[0.032552864076617616`, 1, 0.9549268035862217], 
     Hue[0.028896843082799606`, 1, 0.959988986500739], 
     Hue[0.03398161478125161, 1, 0.9529485333798055], 
     Hue[0.052998682278975306`, 1, 0.926617209152188], 
     Hue[0.09183388227469957, 1, 0.8728453937734928], 
     Hue[0.09466162177766535, 1, 0.8689300621540019], 
     Hue[0.06560450569254184, 1, 0.9091629921180191], 
     Hue[0.0441078563697489, 1, 0.93892758348804], 
     Hue[0.09246821165120689, 1, 0.8719670915598673], 
     Hue[0.20069360964941885`, 1, 0.7221165404854201], 
     Hue[0.34768743300566, 1, 0.5185866312229324], 
     Hue[0.477326297254936, 1, 0.33908666533931936`], 
     Hue[0.5654537615517556, 1, 0.21706402246679987`], 
     Hue[0.6171166371788558, 1, 0.14553081006004592`], 
     Hue[0.6408109990792749, 1, 0.11272323204408097`], 
     Hue[0.6483978960794408, 1, 0.10221829773615904`], 
     Hue[0.6498435639375467, 1, 0.10021660377878154`], 
     Hue[0.6097900538973925, 1, 0.15567530998822576`], 
     Hue[0.5440936662495303, 1, 0.24663953903911198`], 
     Hue[0.4167272502547824, 1, 0.42299303810876276`], 
     Hue[0.252941914957681, 1, 0.6497727331355186], 
     Hue[0.05824729262520745, 1, 0.9193499025189434], 
     Hue[0.04316814055277696, 1, 0.9402287284653857], 
     Hue[0.0516173942124698, 1, 0.9285297618596572], 
     Hue[0.2677061950292634, 1, 0.6293298838056353], 
     Hue[0.4299465619084288, 1, 0.4046893758190986], 
     Hue[0.5388992631391254, 1, 0.2538317894996725], 
     Hue[0.6007570185166984, 1, 0.16818258974610995`], 
     Hue[0.6339442739017035, 1, 0.12223100536687206`], 
     Hue[0.4586762586732925, 1, 0.36490979568313353`], 
     Hue[0.28755052571399836`, 1, 0.6018531182421561], 
     Hue[0.12808116331743513`, 1, 0.8226568507912436], 
     Hue[0.06374719256486494, 1, 0.9117346564486485], 
     Hue[0.04839548955308981, 1, 0.9329908606187988], 
     Hue[0.035104062319543994`, 1, 0.9513943752498621], 
     Hue[0.021778028351738032`, 1, 0.9698458068975935], 
     Hue[0.2340335900194253, 1, 0.6759534907423341], 
     Hue[0.5315189606144247, 1, 0.2640506699184888], 
     Hue[0.6383251619286706, 1, 0.11616516040645611`], 
     Hue[0.21236383074401233`, 1, 0.7059577728159829], 
     Hue[0.4994091563597941, 1, 0.30851039888643894`], 
     Hue[0.26038735988378, 1, 0.6394636555455354], 
     Hue[0.2540691165967825, 1, 0.648211992404455], 
     Hue[0.6497715284957271, 1, 0.10031634515976262`], 
     Hue[0.6478022050348858, 1, 0.10304310072092739`], 
     Hue[0.6377560360485921, 1, 0.11695318085579562`], 
     Hue[0.6052288200258271, 1, 0.16199086457962408`], 
     Hue[0.531991814830338, 1, 0.2633959486964551], 
     Hue[0.4097133890208438, 1, 0.4327045382788317], 
     Hue[0.2673840781285128, 1, 0.6297758918220593], 
     Hue[0.1559989614005815, 1, 0.7840014380607333], 
     Hue[0.08796433563665718, 1, 0.8782032275800131], 
     Hue[0.0634256601231834, 1, 0.9121798552140538], 
     Hue[0.05741597775944951, 1, 0.9205009538715315], 
     Hue[0.04572493786301246, 1, 0.9366885475742905], 
     Hue[0.042260602867523644`, 1, 0.9414853191065057], 
     Hue[0.05129787568012145, 1, 0.9289721721352164], 
     Hue[0.07390325043690649, 1, 0.8976724224719755], 
     Hue[0.08537490306691731, 1, 0.8817885957534992], 
     Hue[0.07173821430346616, 1, 0.9006701648105854], 
     Hue[0.05992129101810395, 1, 0.9170320585903177], 
     Hue[0.08476116749271467, 1, 0.8826383834716258], 
     Hue[0.1391883891054484, 1, 0.8072776150847637], 
     Hue[0.22502594574167745`, 1, 0.6884256135884467], 
     Hue[0.33796120301740695`, 1, 0.532053718898975], 
     Hue[0.45101014426281344`, 1, 0.3755244156361045], 
     Hue[0.5447806156308518, 1, 0.24568837835728213`], 
     Hue[0.6030455589619531, 1, 0.16501384143729575`], 
     Hue[0.6333492875439365, 1, 0.1230548326314726], 
     Hue[0.6460417983319332, 1, 0.10548058692501568`], 
     Hue[0.6494898599496781, 1, 0.10070634776198412`], 
     Hue[0.6499683136735778, 1, 0.10004387337504625`], 
     Hue[0.6499848703981542, 1, 0.10002094867947885`], 
     Hue[0.6479464775082973, 1, 0.10284333883466541`], 
     Hue[0.6387562509282643, 1, 0.11556826794548032`], 
     Hue[0.6121538163977766, 1, 0.15240240806461716`], 
     Hue[0.5569612532213151, 1, 0.22882288015510233`], 
     Hue[0.46986400781404103`, 1, 0.3494190661036355], 
     Hue[0.3702983880177533, 1, 0.48727915505234165`], 
     Hue[0.2870361731076263, 1, 0.602565298774056], 
     Hue[0.24949710747073217`, 1, 0.6545424665789863], 
     Hue[0.20060596338960218`, 1, 0.7222378968451661], 
     Hue[0.16086098763069734`, 1, 0.7772694017421113], 
     Hue[0.1486813651950336, 1, 0.794133494345338], 
     Hue[0.18257981607410007`, 1, 0.7471971777435538], 
     Hue[0.23650697498336087`, 1, 0.6725288038691927], 
     Hue[0.25366869848249174`, 1, 0.6487664174857807], 
     Hue[0.23351287322574749`, 1, 0.6766744832258881], 
     Hue[0.24589028468525548`, 1, 0.6595365288973386], 
     Hue[0.39284721099692843`, 1, 0.4560577078504068], 
     Hue[0.47270887451755805`, 1, 0.34548001989876576`], 
     Hue[0.5486146864980037, 1, 0.24037966484891793`], 
     Hue[0.6048015170766703, 1, 0.16258251481691802`], 
     Hue[0.6330089263482278, 1, 0.1235261019793769], 
     Hue[0.6445471187438859, 1, 0.10755014327769638`], 
     Hue[0.6487374731646326, 1, 0.10174811407973951`], 
     Hue[0.64983412117599, 1, 0.1002296783717062], 
     Hue[0.6499832022074589, 1, 0.10002325848198003`], 
     Hue[0.6499996200581669, 1, 0.10000052607330735`], 
     Hue[0.6448471228149473, 1, 0.10713475302545768`], 
     Hue[0.6328830102181247, 1, 0.12370044739028904`], 
     Hue[0.6058098551792646, 1, 0.1611863543671722], 
     Hue[0.5637128297071754, 1, 0.2194745434823726], 
     Hue[0.5185647518673809, 1, 0.28198726664516494`], 
     Hue[0.4831138978847609, 1, 0.33107306446725415`], 
     Hue[0.451187483614008, 1, 0.3752788688421428], 
     Hue[0.4342692244741284, 1, 0.3987041507281299], 
     Hue[0.44282106940560934`, 1, 0.38686313466915634`], 
     Hue[0.47685342024046684`, 1, 0.3397414181285844], 
     Hue[0.47716564652433213`, 1, 0.33930910481246324`], 
     Hue[0.4599007981769845, 1, 0.36321427944725226`], 
     Hue[0.4653428185215648, 1, 0.3556791743547565], 
     Hue[0.5473086579267841, 1, 0.24218801210137592`], 
     Hue[0.6499818698944012, 1, 0.10002510322313687`], 
     Hue[0.6499987139416478, 1, 0.10000178069618], 
     Hue[0.6499999983432351, 1, 0.10000000229398222`], 
     Hue[0.6275987246989476, 1, 0.13101715041684175`], 
     Hue[0.6145914564817518, 1, 0.14902721410218986`], 
     Hue[0.5964438148128464, 1, 0.17415471795144352`], 
     Hue[0.6082851657861913, 1, 0.15775900121911982`], 
     Hue[0.5954779206837549, 1, 0.17549210982249314`], 
     Hue[0.6499985055562454, 1, 0.10000206922981408`], 
     Hue[0.6499998722928474, 1, 0.10000017682528822`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999895297228, 1, 0.10000001449730686`], 
     Hue[0.6499999229535507, 1, 0.10000010667969905`], 
     Hue[0.649999997206145, 1, 0.10000000386841473`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6470003814864307, 1, 0.10415331794186522`], 
     Hue[0.6495452789608659, 1, 0.10062961374649342`], 
     Hue[0.6499141328420703, 1, 0.10011889298790262`], 
     Hue[0.6499743686200449, 1, 0.1000354896030148], 
     Hue[0.6498069051568519, 1, 0.10026736209051279`], 
     Hue[0.6434218068418492, 1, 0.10910826744974725`], 
     Hue[0.6309862281062321, 1, 0.1263267610836787], 
     Hue[0.6159755155353182, 1, 0.14711082464340564`], 
     Hue[0.6486341169811031, 1, 0.10189122264154969`], 
     Hue[0.6496910722414716, 1, 0.10042774612719325`], 
     Hue[0.6499573650159429, 1, 0.10005903305484828`], 
     Hue[0.6499525630244325, 1, 0.10006568196617037`], 
     Hue[0.6497803544047215, 1, 0.10030412467038569`], 
     Hue[0.6497476127498395, 1, 0.10034945926945299`], 
     Hue[0.6490275967309426, 1, 0.1013464045263873], 
     Hue[0.6488831602693075, 1, 0.10154639347326654`], 
     Hue[0.6459310567895805, 1, 0.10563392136827322`], 
     Hue[0.6453202233763875, 1, 0.10647969070961738`], 
     Hue[0.6347783794036008, 1, 0.12107609005655269`], 
     Hue[0.6327141568103614, 1, 0.12393424441642284`], 
     Hue[0.6059645178912306, 1, 0.16097220599675768`], 
     Hue[0.6014496189637002, 1, 0.16722360451179977`], 
     Hue[0.5575570969099287, 1, 0.22799786581702183`], 
     Hue[0.552290042644377, 1, 0.23529071018470882`], 
     Hue[0.649047973079703, 1, 0.1013181911204113], 
     Hue[0.6491556503569935, 1, 0.10116909950570135`], 
     Hue[0.6498875096278042, 1, 0.10015575589996349`], 
     Hue[0.6499113767322856, 1, 0.10012270913991222`], 
     Hue[0.6499516518407451, 1, 0.10006694360512226`], 
     Hue[0.6498347791615197, 1, 0.10022876731481897`], 
     Hue[0.6495210274721027, 1, 0.10066319273093467`], 
     Hue[0.6488132697315385, 1, 0.10164316498710055`], 
     Hue[0.6474494919311958, 1, 0.10353147271065202`], 
     Hue[0.6451827555456642, 1, 0.10667003078292663`], 
     Hue[0.641419920255634, 1, 0.1118801104152761], 
     Hue[0.6258892655925667, 1, 0.13338409379490757`], 
     Hue[0.6098761854007811, 1, 0.15555605098353384`], 
     Hue[0.5496375414568706, 1, 0.2389634041366408], 
     Hue[0.49996228675723503`, 1, 0.3077445260284438], 
     Hue[0.45570342132843417`, 1, 0.3690260320067835], 
     Hue[0.6453645324718146, 1, 0.10641833965441057`], 
     Hue[0.6482450777562206, 1, 0.10242989233754062`], 
     Hue[0.649429316022528, 1, 0.10079017781496129`], 
     Hue[0.6498388592579648, 1, 0.10022311795051031`], 
     Hue[0.6499599255320806, 1, 0.10005548772481156`], 
     Hue[0.6188591497875038, 1, 0.14311810029422553`], 
     Hue[0.5733900998748807, 1, 0.20607524632708835`], 
     Hue[0.5122826568780832, 1, 0.2906855520149618], 
     Hue[0.14384786425834262`, 1, 0.8008260341038332], 
     Hue[0.11006547162684222`, 1, 0.8476016546705261], 
     Hue[0.09156693380786296, 1, 0.8732150147275743], 
     Hue[0.06073921813312666, 1, 0.915899544123363], 
     Hue[0.6252275515959289, 1, 0.13430031317486774`], 
     Hue[0.5769522688657304, 1, 0.20114301233975795`], 
     Hue[0.5041849576711126, 1, 0.30189775091692095`], 
     Hue[0.05343882300834446, 1, 0.9260077835269077], 
     Hue[0.03002144887670688, 1, 0.9584318400168674], 
     Hue[0.6493256360836789, 1, 0.10093373465336773`], 
     Hue[0.6444193815599399, 1, 0.1077270101477755], 
     Hue[0.07072345595766039, 1, 0.9020752148278549], 
     Hue[0.0454549039630503, 1, 0.9370624406665456], 
     Hue[0.05176394167839382, 1, 0.9283268499837625], 
     Hue[0.044601768293896615`, 1, 0.9382437054392201], 
     Hue[0.024278793712004698`, 1, 0.966383208706455], 
     Hue[0.020644492285498695`, 1, 0.9714153183739249], 
     Hue[0.08867438633688085, 1, 0.8772200804566266], 
     Hue[0.06072303494290343, 1, 0.9159219516175183], 
     Hue[0.6496143344699881, 1, 0.10053399842617047`], 
     Hue[0.6469387669233665, 1, 0.10423863041380022`], 
     Hue[0.06374719256486538, 1, 0.9117346564486479], 
     Hue[0.03917513357652602, 1, 0.9457575073555793], 
     Hue[0.03291204507315115, 1, 0.9544294760525599], 
     Hue[0.03806628505559817, 1, 0.9472928360768641], 
     Hue[0.04839548955308959, 1, 0.932990860618799], 
     Hue[0.01575384386688128, 1, 0.9781869854150874], 
     Hue[0.01766771840371817, 1, 0.9755370052871594], 
     Hue[0.007937127358919605, 1, 0.9890101313491881], 
     Hue[0.6383251619286705, 1, 0.11616516040645633`], 
     Hue[0.647891891698986, 1, 0.10291891918601938`], 
     Hue[0.6497521689561618, 1, 0.10034315067608361`], 
     Hue[0.03193618800811204, 1, 0.9557806627579988], 
     Hue[0.03306238154327401, 1, 0.954221317863159], 
     Hue[0.045183723639609985`, 1, 0.9374379211143862], 
     Hue[0.051854498034304086`, 1, 0.9282014642601943], 
     Hue[0.06364590924392188, 1, 0.9118748948930312], 
     Hue[0.06722992459429633, 1, 0.9069124121002051], 
     Hue[0.07176331143874948, 1, 0.9006354149309622], 
     Hue[0.07264264442077772, 1, 0.8994178769558462], 
     Hue[0.06712748570652038, 1, 0.9070542505602026], 
     Hue[0.06096699113443205, 1, 0.9155841661215557], 
     Hue[0.032562953035502384`, 1, 0.9549128342585352], 
     Hue[0.014936054217799088`, 1, 0.9793193095445859], 
     Hue[0.009090108398278396, 1, 0.9874136960639223], 
     Hue[0.004467268988803674, 1, 0.9938145506308872], 
     Hue[0.0053754869541441375`, 1, 0.9925570180634927], 
     Hue[0.0075334141412704, 1, 0.9895691188813179], 
     Hue[0.008493818134473363, 1, 0.9882393287368831], 
     Hue[0.009488970651959416, 1, 0.9868614252511332], 
     Hue[0.00920954436639776, 1, 0.9872483231849877], 
     Hue[0.6497888858757621, 1, 0.10029231186432934`], 
     Hue[0.6499221503178785, 1, 0.10010779186755295`], 
     Hue[0.022088212565692933`, 1, 0.9694163210628867], 
     Hue[0.03873919372175594, 1, 0.946361116385261], 
     Hue[0.11542624301407456`, 1, 0.8401790481343583], 
     Hue[0.4998273439191191, 1, 0.3079313699581428], 
     Hue[0.5693690290298355, 1, 0.21164288288176625`], 
     Hue[0.06349803511565044, 1, 0.9120796436860226], 
     Hue[0.08989807314235443, 1, 0.8755257448798169], 
     Hue[0.5551259802975873, 1, 0.23136402728026373`], 
     Hue[0.6358812924468079, 1, 0.1195489796890352], 
     Hue[0.5178350591095982, 1, 0.2829976104636333], 
     Hue[0.5817091637285248, 1, 0.19455654252973492`], 
     Hue[0.6218516038139731, 1, 0.13897470241142187`], 
     Hue[0.6498876098860826, 1, 0.10015561708080876`], 
     Hue[0.6490337248831248, 1, 0.10133791939259647`], 
     Hue[0.5428954400679438, 1, 0.24829862144438564`], 
     Hue[0.5865958549106953, 1, 0.1877903547390372], 
     Hue[0.6198590625452215, 1, 0.1417336057066164], 
     Hue[0.6389674336840003, 1, 0.1152758610529226], 
     Hue[0.6468829768396419, 1, 0.10431587822203436`], 
     Hue[0.6492458890477659, 1, 0.10104415362617025`], 
     Hue[0.6498473644705273, 1, 0.10021134150234688`], 
     Hue[0.6499793159610402, 1, 0.10002863943855982`], 
     Hue[0.6499695093857584, 1, 0.10004221777356542`], 
     Hue[0.6499211706692806, 1, 0.10010914830407307`], 
     Hue[0.6497848142945776, 1, 0.10029794943827723`], 
     Hue[0.649634493072658, 1, 0.1005060865147813], 
     Hue[0.6124419336634548, 1, 0.15200347646598572`], 
     Hue[0.6169019129471299, 1, 0.14582812053474326`], 
     Hue[0.6256959327663991, 1, 0.13365178540037057`], 
     Hue[0.6300210320872908, 1, 0.12766318634067444`], 
     Hue[0.6381760136280844, 1, 0.11637167343803705`], 
     Hue[0.6408474346304216, 1, 0.11267278281941621`], 
     Hue[0.6457820674962715, 1, 0.10584021423593168`], 
     Hue[0.6470708472649669, 1, 0.10405574994081514`], 
     Hue[0.6489458092932303, 1, 0.10145964867091188`], 
     Hue[0.6498097728864153, 1, 0.10026339138804034`], 
     Hue[0.6498921903821884, 1, 0.1001492748554315], 
     Hue[0.6499712480469302, 1, 0.10003981039655825`], 
     Hue[0.6499842758037225, 1, 0.1000217719640766], 
     Hue[0.6446536186060657, 1, 0.1074026819300628], 
     Hue[0.6466395726775371, 1, 0.10465289936956401`], 
     Hue[0.6428634096597486, 1, 0.10988143277880962`], 
     Hue[0.6447539886042116, 1, 0.10726370808647628`], 
     Hue[0.6453639400337614, 1, 0.10641915995325345`], 
     Hue[0.647095848381984, 1, 0.10402113300956063`], 
     Hue[0.6457139069390793, 1, 0.1059345903920442], 
     Hue[0.6451723627522489, 1, 0.10668442080457857`], 
     Hue[0.6448267331797799, 1, 0.10716298482799716`], 
     Hue[0.6429378787334201, 1, 0.10977832175372604`], 
     Hue[0.6499964990769933, 1, 0.10000484743185549`], 
     Hue[0.6499659629220892, 1, 0.10004712826172263`], 
     Hue[0.6499908169147036, 1, 0.10001271504117959`], 
     Hue[0.6497064730758035, 1, 0.1004064218950413], 
     Hue[0.6498975519042653, 1, 0.10014185120947876`], 
     Hue[0.6487353096769284, 1, 0.1017511096780992], 
     Hue[0.6493351012691956, 1, 0.10092062901188315`], 
     Hue[0.6471521637375249, 1, 0.10394315790188863`], 
     Hue[0.647960506284076, 1, 0.10282391437589485`], 
     Hue[0.646436721838114, 1, 0.10493376976261147`], 
     Hue[0.6408258084403919, 1, 0.11270272677484189`], 
     Hue[0.642579227472854, 1, 0.1102749158068176], 
     Hue[0.645734095735883, 1, 0.10590663667339269`], 
     Hue[0.6481816025936159, 1, 0.10251778102422412`], 
     Hue[0.6499963659174549, 1, 0.10000503180660095`], 
     Hue[0.6499860235301017, 1, 0.10001935203524384`], 
     Hue[0.6499946294981453, 1, 0.10000743607949117`], 
     Hue[0.6499078369008661, 1, 0.10012761044495465`], 
     Hue[0.6493216640717874, 1, 0.10093923436214054`], 
     Hue[0.6461158482887291, 1, 0.10537805621560588`], 
     Hue[0.6359698442682492, 1, 0.11942636947473187`], 
     Hue[0.6420243034371679, 1, 0.11104327216392143`], 
     Hue[0.6283697379852444, 1, 0.12994959355889235`], 
     Hue[0.5748514940754447, 1, 0.20405177743399971`], 
     Hue[0.5920467951226204, 1, 0.18024289906098723`], 
     Hue[0.6152934834162914, 1, 0.14805517680821192`], 
     Hue[0.6499559764698013, 1, 0.10006095565719822`], 
     Hue[0.6497628788449856, 1, 0.10032832159925076`], 
     Hue[0.6337709684193622, 1, 0.12247096680396001`], 
     Hue[0.6036509051373478, 1, 0.1641756698098262], 
     Hue[0.5549649544362985, 1, 0.23158698616512532`], 
     Hue[0.6499951102503556, 1, 0.1000067704225845], 
     Hue[0.6499943878304972, 1, 0.10000777069623468`], 
     Hue[0.3820646081453897, 1, 0.47098746564484506`], 
     Hue[0.38069329840203003`, 1, 0.4728862022125738], 
     Hue[0.39270881200196994`, 1, 0.4562493372280416], 
     Hue[0.39628303129913856`, 1, 0.4513004182011928], 
     Hue[0.6462983561746376, 1, 0.10512535298896339`], 
     Hue[0.638521077191224, 1, 0.11589389311984373`], 
     Hue[0.6184411443805102, 1, 0.1436968770116012], 
     Hue[0.5676084553766305, 1, 0.21408060024774248`], 
     Hue[0.4784079023188036, 1, 0.3375890583278105], 
     Hue[0.21222845577838473`, 1, 0.7061452150760827], 
     Hue[0.18865732490204018`, 1, 0.738782165520252], 
     Hue[0.16372639701273894`, 1, 0.7733019118285154], 
     Hue[0.1360186324910161, 1, 0.811666508858593], 
     Hue[0.11732464866825043`, 1, 0.8375504864593456], 
     Hue[0.10432318742596902`, 1, 0.855552509717889], 
     Hue[0.10836938580505284`, 1, 0.8499500811930037], 
     Hue[0.12706352144016553`, 1, 0.82406589339054], 
     Hue[0.11612761301448482`, 1, 0.8392079204414826], 
     Hue[0.11697518534041318`, 1, 0.8380343587594279], 
     Hue[0.13674099549295848`, 1, 0.8106663139328266], 
     Hue[0.1690715282276884, 1, 0.7659009609155084], 
     Hue[0.6162751624294198, 1, 0.14669592894388028`], 
     Hue[0.6279240761176494, 1, 0.13056666383710075`], 
     Hue[0.6499911089724155, 1, 0.10001231065357848`], 
     Hue[0.6499966807293847, 1, 0.10000459591315973`], 
     Hue[0.6494747153099362, 1, 0.10072731726316536`], 
     Hue[0.6455855820490095, 1, 0.10611227100906385`], 
     Hue[0.6304048826073834, 1, 0.12713170100516144`], 
     Hue[0.5991807598344461, 1, 0.1703651017676901], 
     Hue[0.12408779720025442`, 1, 0.8281861269534939], 
     Hue[0.09893053627907977, 1, 0.8630192574597357], 
     Hue[0.08360433154795888, 1, 0.8842401563182108], 
     Hue[0.04692519761977265, 1, 0.9350266494495455], 
     Hue[0.03689422334799952, 1, 0.9489156907489237], 
     Hue[0.04500406616327257, 1, 0.9376866776200841], 
     Hue[0.4631429646854476, 1, 0.3587251258201496], 
     Hue[0.5476127638103824, 1, 0.24176694241639363`], 
     Hue[0.6015618915385809, 1, 0.16706815017734955`], 
     Hue[0.644712343855953, 1, 0.10732137004560363`], 
     Hue[0.6492485546859366, 1, 0.10104046274254941`], 
     Hue[0.6499328377699335, 1, 0.10009299385701523`], 
     Hue[0.3842520515348438, 1, 0.4679586978748317], 
     Hue[0.36459716050422086`, 1, 0.4951731623787712], 
     Hue[0.23800030126526678`, 1, 0.6704611213250152], 
     Hue[0.1497669450087893, 1, 0.7926303838339841], 
     Hue[0.06670707826208533, 1, 0.9076363531755742], 
     Hue[0.12955845579886038`, 1, 0.8206113688938856], 
     Hue[0.3809644518141112, 1, 0.4725107590266152], 
     Hue[0.5021089262730716, 1, 0.30477225592959317`], 
     Hue[0.6247564484272926, 1, 0.13495260986990262`], 
     Hue[0.6465191023009161, 1, 0.10481970450642389`], 
     Hue[0.6296623560066149, 1, 0.1281598147600717], 
     Hue[0.23691999607364667`, 1, 0.6719569285134124], 
     Hue[0.11929341904814372`, 1, 0.8348244967025702], 
     Hue[0.08105032083542285, 1, 0.8877764788432606], 
     Hue[0.06716625950373889, 1, 0.9070005637640538], 
     Hue[0.05691166180578411, 1, 0.9211992374996836], 
     Hue[0.08746526632712992, 1, 0.878894246623974], 
     Hue[0.051286299167820015`, 1, 0.9289882011522491], 
     Hue[0.23431737305453548`, 1, 0.6755605603860279], 
     Hue[0.6425256066746322, 1, 0.1103491599889708], 
     Hue[0.6496031774532233, 1, 0.1005494466032293], 
     Hue[0.6232893111656032, 1, 0.13698403069378035`], 
     Hue[0.1521032679118745, 1, 0.7893954751989429], 
     Hue[0.03899396229554286, 1, 0.9460083598984791], 
     Hue[0.025892612425206574`, 1, 0.9641486904881754], 
     Hue[0.01580781136640963, 1, 0.9781122611849713], 
     Hue[0.06947417836483016, 1, 0.9038049838025429], 
     Hue[0.6249602942812136, 1, 0.1346703617644736], 
     Hue[0.6437019625880376, 1, 0.10872035949348649`], 
     Hue[0.649034600666347, 1, 0.1013367067696735], 
     Hue[0.647015734299314, 1, 0.10413206020094982`], 
     Hue[0.6424402007079218, 1, 0.11046741440441601`], 
     Hue[0.03770132700792472, 1, 0.9477981626044119], 
     Hue[0.048129636946656396`, 1, 0.9333589642277066], 
     Hue[0.05049247328449835, 1, 0.9300873446830022], 
     Hue[0.030111245926419783`, 1, 0.9583075056403418], 
     Hue[0.040764651561333465`, 1, 0.9435566362996921], 
     Hue[0.021921896261181684`, 1, 0.9696466051768253], 
     Hue[0.03551148279988614, 1, 0.9508302545847731], 
     Hue[0.06679847437471864, 1, 0.907509804711928], 
     Hue[0.09196401893136263, 1, 0.8726652045565748], 
     Hue[0.02736454063625937, 1, 0.9621106360421025], 
     Hue[0.013701917525883123`, 1, 0.981028114194931], 
     Hue[0.022030891218653093`, 1, 0.969495689081865], 
     Hue[0.05197282591632135, 1, 0.9280376256543243], 
     Hue[0.0254916346844003, 1, 0.9647038904369842], 
     Hue[0.6488387891085793, 1, 0.1016078304650441], 
     Hue[0.6342202833321613, 1, 0.1218488384631613], 
     Hue[0.04908649437740542, 1, 0.9320340847082078], 
     Hue[0.06374719256486516, 1, 0.9117346564486483], 
     Hue[0.03386942937047288, 1, 0.953103867025499], 
     Hue[0.03472413692703524, 1, 0.9519204257933358], 
     Hue[0.032912045073151264`, 1, 0.9544294760525598], 
     Hue[0.04839548955308959, 1, 0.932990860618799], 
     Hue[0.05780686512530042, 1, 0.9199597252111225], 
     Hue[0.057805446899979906`, 1, 0.9199616889077201], 
     Hue[0.015500707356173038`, 1, 0.9785374821222219], 
     Hue[0.025491634684400077`, 1, 0.9647038904369846], 
     Hue[0.03546306232424301, 1, 0.9508972983202788], 
     Hue[0.035104062319543994`, 1, 0.9513943752498621], 
     Hue[0.035104062319543994`, 1, 0.9513943752498621], 
     Hue[0.011250381962026101`, 1, 0.9844225480525792], 
     Hue[0.01766771840371817, 1, 0.9755370052871595], 
     Hue[0.02177802835173759, 1, 0.9698458068975941], 
     Hue[0.6061907515330934, 1, 0.1606589594157168], 
     Hue[0.6263033779322906, 1, 0.13281070747836693`], 
     Hue[0.6447852320084005, 1, 0.10722044798836845`], 
     Hue[0.6492329501649864, 1, 0.10106206900232663`], 
     Hue[0.07233510601335014, 1, 0.8998436993661305], 
     Hue[0.06430966226023427, 1, 0.9109558522550602], 
     Hue[0.04830888899271368, 1, 0.9331107690870118], 
     Hue[0.04188445269316632, 1, 0.9420061424248466], 
     Hue[0.02943312940619225, 1, 0.9592464362068107], 
     Hue[0.011740282585455897`, 1, 0.9837442241124457], 
     Hue[0.00958692830235608, 1, 0.9867257915813531], 
     Hue[0.011033051137763317`, 1, 0.9847234676554046], 
     Hue[0.01446453731292996, 1, 0.979972179105174], 
     Hue[0.029052110759434258`, 1, 0.9597740004869373], 
     Hue[0.047142938537645285`, 1, 0.9347251620247988], 
     Hue[0.6477157866437446, 1, 0.10316275695481511`], 
     Hue[0.6490294327358196, 1, 0.10134386236578832`], 
     Hue[0.6498235847301783, 1, 0.10024426729667621`], 
     Hue[0.6495528041232685, 1, 0.10061919429085904`], 
     Hue[0.6482356826610067, 1, 0.10244290093091384`], 
     Hue[0.6464395108135192, 1, 0.104929908104358], 
     Hue[0.06864285538105919, 1, 0.9049560463954566], 
     Hue[0.047812323436742465`, 1, 0.9337983213952796], 
     Hue[0.09349221394765017, 1, 0.8705492422263306], 
     Hue[0.13192130197551366`, 1, 0.8173397357262119], 
     Hue[0.649775084305755, 1, 0.1003114217304931], 
     Hue[0.6476896776581336, 1, 0.10319890785796892`], 
     Hue[0.6424608278395636, 1, 0.1104388537606043], 
     Hue[0.6267925498940297, 1, 0.13213339245442052`], 
     Hue[0.6184798785639419, 1, 0.14364324506531115`], 
     Hue[0.5542256081964011, 1, 0.23261069634344464`], 
     Hue[0.4624310317386455, 1, 0.3597108791311062], 
     Hue[0.055856061564820925`, 1, 0.922660837833325], 
     Hue[0.04120476360580261, 1, 0.9429472503919657], 
     Hue[0.008176962964246193, 1, 0.9886780512802745], 
     Hue[0.03132514200633807, 1, 0.9566267264527627], 
     Hue[0.08682109459731213, 1, 0.879786176711414], 
     Hue[0.5975130529355235, 1, 0.17267423439696758`], 
     Hue[0.04094862084352291, 1, 0.9433019096012759], 
     Hue[0.06114921044258892, 1, 0.9153318624641076], 
     Hue[0.02737532945727239, 1, 0.962095697674546], 
     Hue[0.13940838616162998`, 1, 0.8069730037762046], 
     Hue[0.14683436834494412`, 1, 0.7966908745993082], 
     Hue[0.6499317166265999, 1, 0.10009454620932336`], 
     Hue[0.6491252518082433, 1, 0.10121118980397077`], 
     Hue[0.6365927558392547, 1, 0.1185638765302628], 
     Hue[0.6438915704662946, 1, 0.1084578255082074], 
     Hue[0.1462483635748162, 1, 0.7975022658194854], 
     Hue[0.0574087311805247, 1, 0.9205109875961967], 
     Hue[0.0457562844810766, 1, 0.9366451445646632], 
     Hue[0.042614219060257974`, 1, 0.9409956966857966], 
     Hue[0.05234733254619173, 1, 0.9275190780129654], 
     Hue[0.06333003050708097, 1, 0.912312265451734], 
     Hue[0.08348347514966503, 1, 0.8844074959466177], 
     Hue[0.06965915244321808, 1, 0.9035488658478519], 
     Hue[0.08742696726510957, 1, 0.8789472760944637], 
     Hue[0.14237219737376905`, 1, 0.8028692651747813], 
     Hue[0.46537249245316903`, 1, 0.3556380873725352], 
     Hue[0.5505470291294294, 1, 0.2377041135130978], 
     Hue[0.6064764270994597, 1, 0.16026340863151733`], 
     Hue[0.5828616970865665, 1, 0.19296072711090798`], 
     Hue[0.6347687946013977, 1, 0.12108936132114172`], 
     Hue[0.6232299985199082, 1, 0.13706615589551174`], 
     Hue[0.6465414212308426, 1, 0.10478880137267954`], 
     Hue[0.6422265678199603, 1, 0.1107632137877472], 
     Hue[0.6486875725274255, 1, 0.10181720726971863`], 
     Hue[0.6498901727634763, 1, 0.10015206848134053`], 
     Hue[0.6261069876062163, 1, 0.13308263254523897`], 
     Hue[0.16002352916105178`, 1, 0.7784289596231591], 
     Hue[0.21014640063561274`, 1, 0.7090280606583824], 
     Hue[0.6499944060059315, 1, 0.10000774553024872`], 
     Hue[0.6499668394146931, 1, 0.10004591465657886`], 
     Hue[0.6498788878154026, 1, 0.10016769379405806`], 
     Hue[0.6487603782979934, 1, 0.10171639927970155`], 
     Hue[0.6422879845941497, 1, 0.11067817517733125`], 
     Hue[0.3210793054587813, 1, 0.5554286539801491], 
     Hue[0.2622701294420627, 1, 0.6368567438494517], 
     Hue[0.15046580862903913`, 1, 0.7916627265136381], 
     Hue[0.15129439452853516`, 1, 0.7905154537297205], 
     Hue[0.24435298185934395`, 1, 0.6616651020409083], 
     Hue[0.23175170781408677`, 1, 0.679113019949726], 
     Hue[0.5665686309767998, 1, 0.21552035710904652`], 
     Hue[0.5342671844752228, 1, 0.2602454368804608], 
     Hue[0.6137003415184832, 1, 0.15026106558979246`], 
     Hue[0.593399789795409, 1, 0.17836952182174148`], 
     Hue[0.6367651210303863, 1, 0.11832521703484974`], 
     Hue[0.6277071513687845, 1, 0.13086702118168306`], 
     Hue[0.6459687322533443, 1, 0.10558175534152335`], 
     Hue[0.6424544500834374, 1, 0.11044768449985591`], 
     Hue[0.6480965999890487, 1, 0.10263547693824031`], 
     Hue[0.6497064553061999, 1, 0.10040644649910797`], 
     Hue[0.47580758491782704`, 1, 0.34118949780608565`], 
     Hue[0.47945324080958857`, 1, 0.3361416665713389], 
     Hue[0.5676804062114242, 1, 0.21398097601495114`], 
     Hue[0.5451096064687251, 1, 0.24523285258176525`], 
     Hue[0.6066714075330664, 1, 0.15999343572344668`], 
     Hue[0.588620443044456, 1, 0.18498707886152244`], 
     Hue[0.6320572132644126, 1, 0.12484385855696727`], 
     Hue[0.6211801085246963, 1, 0.13990446511965132`], 
     Hue[0.6443946219760599, 1, 0.10776129264853249`], 
     Hue[0.6395878856999571, 1, 0.11441677364621329`], 
     Hue[0.6485611620912775, 1, 0.10199223710438514`], 
     Hue[0.6496772423014863, 1, 0.10044689527486517`], 
     Hue[0.6499448305488653, 1, 0.10007638847080187`], 
     Hue[0.6498583257113314, 1, 0.10019616439969499`], 
     Hue[0.6499984569282568, 1, 0.10000213656087527`], 
     Hue[0.6146926535969804, 1, 0.14888709501956562`], 
     Hue[0.6278953186527201, 1, 0.13060648186546453`], 
     Hue[0.6393871654422878, 1, 0.11469469400298624`], 
     Hue[0.646401331672682, 1, 0.1049827715301326], 
     Hue[0.64997733156194, 1, 0.10003138706808308`], 
     Hue[0.6499939901061312, 1, 0.1000083213915106], 
     Hue[0.6499979034667939, 1, 0.10000290289213164`], 
     Hue[0.6057985295347248, 1, 0.1612020360288426], 
     Hue[0.6014199149555417, 1, 0.16726473313848084`], 
     Hue[0.5941945419821182, 1, 0.17726909571706717`], 
     Hue[0.5935721773988376, 1, 0.17813083129391716`], 
     Hue[0.6497925420774407, 1, 0.10028724943123588`], 
     Hue[0.6453346995353796, 1, 0.1064596467971668], 
     Hue[0.647365591046669, 1, 0.10364764316615056`], 
     Hue[0.6437200329096716, 1, 0.10869533904814704`], 
     Hue[0.6463131787995968, 1, 0.10510482935440449`], 
     Hue[0.648146427886583, 1, 0.10256648446473114`], 
     Hue[0.6492940012288722, 1, 0.10097753676002313`], 
     Hue[0.649837555317398, 1, 0.10022492340667985`], 
     Hue[0.6499724740135533, 1, 0.10003811290431083`], 
     Hue[0.6499917293597135, 1, 0.1000114516557814], 
     Hue[0.649998874097617, 1, 0.10000155894176103`], 
     Hue[0.6472586615791933, 1, 0.10379569935188625`], 
     Hue[0.645935556618947, 1, 0.10562769083530418`], 
     Hue[0.645555524931534, 1, 0.1061538885563375], 
     Hue[0.6480477060691208, 1, 0.10270317621198666`], 
     Hue[0.6460457101993415, 1, 0.10547517049321942`], 
     Hue[0.6430480355734746, 1, 0.10962579689826596`], 
     Hue[0.6426008077512826, 1, 0.11024503542130107`], 
     Hue[0.6425062685639612, 1, 0.11037593583451526`], 
     Hue[0.5844452852645969, 1, 0.19076806655671197`], 
     Hue[0.6076968133470005, 1, 0.15857364305799926`], 
     Hue[0.055639430086638964`, 1, 0.9229607891108076], 
     Hue[0.040261142600805266`, 1, 0.9442538025527312], 
     Hue[0.013314047669729656`, 1, 0.9815651647649897], 
     Hue[0.5028491056786306, 1, 0.30374739213728075`], 
     Hue[0.577447520252857, 1, 0.20045727964989046`], 
     Hue[0.6255300394138742, 1, 0.13388148388848187`], 
     Hue[0.17922384249539086`, 1, 0.7518439103909973], 
     Hue[0.05338985647919359, 1, 0.9260755833365012], 
     Hue[0.060375305425618864`, 1, 0.9164034232568353], 
     Hue[0.04152037859705737, 1, 0.942510245019459], 
     Hue[0.07769232963868389, 1, 0.8924260051156685], 
     Hue[0.07667133928958036, 1, 0.893839684060581], 
     Hue[0.29038132819877516`, 1, 0.5979335455709267], 
     Hue[0.43325402419302694`, 1, 0.4001098126558088], 
     Hue[0.6347209352708134, 1, 0.12115562808656606`], 
     Hue[0.6467576215664936, 1, 0.10448944706177804`], 
     Hue[0.6180376709225066, 1, 0.144255532568837], 
     Hue[0.06280415117511617, 1, 0.9130404060652237], 
     Hue[0.025623415796026672`, 1, 0.9645214242824247], 
     Hue[0.019874989895234618`, 1, 0.9724807832219828], 
     Hue[0.6427550742491973, 1, 0.11003143565495759`], 
     Hue[0.025015242436588037`, 1, 0.9653635104724165], 
     Hue[0.03939831657384074, 1, 0.9454484847439129], 
     Hue[0.009952681936556296, 1, 0.9862193634724604], 
     Hue[0.02177802835173781, 1, 0.9698458068975938], 
     Hue[0.6383251619286706, 1, 0.11616516040645618`], 
     Hue[0.04499585987914301, 1, 0.9376980401673405], 
     Hue[0.03646678690700589, 1, 0.9495075258210688], 
     Hue[0.6485772038411993, 1, 0.10197002545064714`], 
     Hue[0.6369234208798585, 1, 0.11810603262788825`], 
     Hue[0.6013346975190248, 1, 0.1673827265121196], 
     Hue[0.5147833554979574, 1, 0.2872230462335975], 
     Hue[0.6234876351233624, 1, 0.13670942829072902`], 
     Hue[0.5701120979999572, 1, 0.2106140181539054], 
     Hue[0.05129317985829329, 1, 0.9289786740423631], 
     Hue[0.04254613095048032, 1, 0.9410899725301041], 
     Hue[0.04537874212275017, 1, 0.9371678955223459], 
     Hue[0.06921452049010612, 1, 0.9041645100906223], 
     Hue[0.11164928493221282`, 1, 0.8454086824015515], 
     Hue[0.1819543136563529, 1, 0.7480632580142806], 
     Hue[0.27131080708728605`, 1, 0.6243388824945271], 
     Hue[0.22899668355822894`, 1, 0.6829276689193753], 
     Hue[0.6499766519827216, 1, 0.10003232802392406`], 
     Hue[0.48279607741216607`, 1, 0.3315131235831547], 
     Hue[0.6499945180331105, 1, 0.10000759041569324`], 
     Hue[0.6499811983321498, 1, 0.10002603307856175`], 
     Hue[0.649996794304434, 1, 0.10000443865539904`], 
     Hue[0.6499971428506851, 1, 0.10000395605289755`], 
     Hue[0.645838420366616, 1, 0.10576218718468558`], 
     Hue[0.6448843946227951, 1, 0.10708314590689906`], 
     Hue[0.620467707106587, 1, 0.14089086708318724`], 
     Hue[0.6488699334180228, 1, 0.10156470757504545`], 
     Hue[0.6408920818946637, 1, 0.11261096353046571`], 
     Hue[0.6109351466286211, 1, 0.15408979697575534`], 
     Hue[0.4695302231514765, 1, 0.34988122948257105`], 
     Hue[0.0625760256482093, 1, 0.9133562721794024], 
     Hue[0.04183182090932258, 1, 0.9420790172024764], 
     Hue[0.024180757207134418`, 1, 0.9665189515593523], 
     Hue[0.02443356311291034, 1, 0.9661689126128934], 
     Hue[0.08573395700488229, 1, 0.881291444147086], 
     Hue[0.6304676013906622, 1, 0.12704485961292936`], 
     Hue[0.6454629692581374, 1, 0.10628204256565602`], 
     Hue[0.6493845889016818, 1, 0.1008521076745945], 
     Hue[0.6496143344699881, 1, 0.10053399842617047`], 
     Hue[0.6469387669233665, 1, 0.10423863041380026`], 
     Hue[0.6497251340277697, 1, 0.10038058365385742`], 
     Hue[0.6475170442456025, 1, 0.10343793873685801`], 
     Hue[0.05697232446203848, 1, 0.9211152430525622], 
     Hue[0.03137843604727375, 1, 0.9565529347037748], 
     Hue[0.04899999484846429, 1, 0.9321538532867418], 
     Hue[0.03364175026415872, 1, 0.9534191150188572], 
     Hue[0.036811264078456474`, 1, 0.9490305574298296], 
     Hue[0.6479505093220129, 1, 0.10283775632336682`], 
     Hue[0.64981551526209, 1, 0.10025544040633699`], 
     Hue[0.06342222548932275, 1, 0.9121846108609377], 
     Hue[0.07518494927125419, 1, 0.8958977625474942], 
     Hue[0.6498511620608162, 1, 0.10020608330040842`], 
     Hue[0.6491966771124554, 1, 0.10111229322890788`], 
     Hue[0.6477996317218898, 1, 0.10304666376969099`], 
     Hue[0.6499526196229324, 1, 0.10006560359901673`], 
     Hue[0.649930123008726, 1, 0.10009675275714863`], 
     Hue[0.6496501604767982, 1, 0.10048439318597165`], 
     Hue[0.6494750516162836, 1, 0.10072685160822278`], 
     Hue[0.647777071758273, 1, 0.10307790064239122`], 
     Hue[0.6468404987201464, 1, 0.10437469407979735`], 
     Hue[0.6406215794163865, 1, 0.11298550542346485`], 
     Hue[0.6379891873968002, 1, 0.11663035591212284`], 
     Hue[0.6484260853836799, 1, 0.10217926639182792`], 
     Hue[0.6384981172149445, 1, 0.11592568385623067`], 
     Hue[0.08278206644304109, 1, 0.8853786772327124], 
     Hue[0.049493294294344126`, 1, 0.9314708232847544], 
     Hue[0.03953676591754729, 1, 0.9452567856526268], 
     Hue[0.038792385757201675`, 1, 0.9462874658746437], 
     Hue[0.05318884542295699, 1, 0.9263539063374441], 
     Hue[0.052129923400487055`, 1, 0.9278201060608642], 
     Hue[0.036690338049741755`, 1, 0.9491979934695883], 
     Hue[0.03370362458677478, 1, 0.9533334428798503], 
     Hue[0.6496143344699881, 1, 0.10053399842617047`], 
     Hue[0.6488387891085793, 1, 0.10160783046504408`], 
     Hue[0.6469387669233665, 1, 0.10423863041380028`], 
     Hue[0.03917513357652591, 1, 0.9457575073555795], 
     Hue[0.03386942937047299, 1, 0.9531038670254989], 
     Hue[0.01575384386688128, 1, 0.9781869854150874], 
     Hue[0.025015242436588037`, 1, 0.9653635104724166], 
     Hue[0.01766771840371817, 1, 0.9755370052871595], 
     Hue[0.011250381962026212`, 1, 0.9844225480525791], 
     Hue[0.6478918916989861, 1, 0.10291891918601934`], 
     Hue[0.6492329501649864, 1, 0.10106206900232664`], 
     Hue[0.6499114247634243, 1, 0.10012264263525872`], 
     Hue[0.06456021150130375, 1, 0.9106089379212717], 
     Hue[0.6249305053130977, 1, 0.1347116080280186], 
     Hue[0.6428966081035971, 1, 0.10983546570271178`], 
     Hue[0.6488393502455692, 1, 0.10160705350613505`], 
     Hue[0.6497731865249076, 1, 0.10031404942705112`], 
     Hue[0.60480151707667, 1, 0.1625825148169186], 
     Hue[0.6330089263482277, 1, 0.12352610197937713`], 
     Hue[0.6445471187438859, 1, 0.10755014327769648`], 
     Hue[0.6487374731646326, 1, 0.10174811407973952`], 
     Hue[0.64983412117599, 1, 0.10022967837170621`], 
     Hue[0.5909195315008011, 1, 0.18180372561427544`], 
     Hue[0.6225890204069122, 1, 0.13795366405196768`], 
     Hue[0.6311055336952008, 1, 0.1261615687297219], 
     Hue[0.6402137035419406, 1, 0.11355025663423608`], 
     Hue[0.6439765089553009, 1, 0.10834021836958337`], 
     Hue[0.6472755805528911, 1, 0.1037722730806123], 
     Hue[0.6484444664448384, 1, 0.10215381569176224`], 
     Hue[0.6493440605303409, 1, 0.10090822388106649`], 
     Hue[0.6496490647721079, 1, 0.10048591031554292`], 
     Hue[0.6498697335800913, 1, 0.10018036888910446`], 
     Hue[0.649939887414238, 1, 0.1000832328110551], 
     Hue[0.6499506852281031, 1, 0.10006828199185738`], 
     Hue[0.6499267381572038, 1, 0.10010143947464095`], 
     Hue[0.6496223111933045, 1, 0.10052295373234772`], 
     Hue[0.6495041158540205, 1, 0.10068660881751018`], 
     Hue[0.6498711740764659, 1, 0.10017837435566274`], 
     Hue[0.6498861879182567, 1, 0.10015758595933696`], 
     Hue[0.6495326737333172, 1, 0.10064706713848388`], 
     Hue[0.6494639435261995, 1, 0.10074223204064692`], 
     Hue[0.6476970145539307, 1, 0.10318874907917298`], 
     Hue[0.6407741982686188, 1, 0.11277418701268169`], 
     Hue[0.6198299895757093, 1, 0.14177386058747937`], 
     Hue[0.6498347791615197, 1, 0.10022876731481899`], 
     Hue[0.6495210274721028, 1, 0.10066319273093466`], 
     Hue[0.6474494919311958, 1, 0.10353147271065197`], 
     Hue[0.6414199202556341, 1, 0.11188011041527594`], 
     Hue[0.6258892655925671, 1, 0.13338409379490718`], 
     Hue[0.5848453321548064, 1, 0.19021415547796047`], 
     Hue[0.6453645324718147, 1, 0.10641833965441043`], 
     Hue[0.649429316022528, 1, 0.10079017781496127`], 
     Hue[0.6498388592579648, 1, 0.10022311795051032`], 
     Hue[0.6499599255320806, 1, 0.10005548772481156`], 
     Hue[0.6480358780808705, 1, 0.10271955342648707`], 
     Hue[0.646052630494143, 1, 0.10546558854657137`], 
     Hue[0.6387695013596242, 1, 0.11554992119436659`], 
     Hue[0.631902032134708, 1, 0.12505872473655819`], 
     Hue[0.6143929978245282, 1, 0.14930200301219182`], 
     Hue[0.6017243049008473, 1, 0.16684327013728845`], 
     Hue[0.10746359275895045`, 1, 0.8512042561799147], 
     Hue[0.09944384071071499, 1, 0.8623085282467023], 
     Hue[0.092517146016176, 1, 0.8718993362852948], 
     Hue[0.09809668545044725, 1, 0.8641738201455346], 
     Hue[0.0407241862549107, 1, 0.9436126651855082], 
     Hue[0.037233918383063, 1, 0.9484453437772973], 
     Hue[0.03958002335351729, 1, 0.9451968907412837], 
     Hue[0.044033255627796586`, 1, 0.9390308768230509], 
     Hue[0.6475363042657547, 1, 0.10341127101664745`], 
     Hue[0.6452483436572103, 1, 0.10657921647463194`], 
     Hue[0.6497027054500938, 1, 0.10041163860756241`], 
     Hue[0.6493438727476328, 1, 0.10090848388789297`], 
     Hue[0.6497941236753363, 1, 0.10028505952645747`], 
     Hue[0.6499137068754293, 1, 0.10011948278786714`], 
     Hue[0.6453891933293946, 1, 0.10638419385160759`], 
     Hue[0.6425187110379779, 1, 0.11035870779356921`], 
     Hue[0.06776150427432237, 1, 0.9061763786970921], 
     Hue[0.06784547741952052, 1, 0.9060601081883561], 
     Hue[0.03579335293635966, 1, 0.9504399728573482], 
     Hue[0.039596426686619, 1, 0.945174178433912], 
     Hue[0.05366977203836021, 1, 0.9256880079468859], 
     Hue[0.6459225193220826, 1, 0.10564574247711651`], 
     Hue[0.649014282399092, 1, 0.10136483975510352`], 
     Hue[0.6494571961158928, 1, 0.10075157460876384`], 
     Hue[0.6456393101323222, 1, 0.10603787827832309`], 
     Hue[0.04748660006537497, 1, 0.934249322986404], 
     Hue[0.023992605784962984`, 1, 0.9667794689131282], 
     Hue[0.020643360215272466`, 1, 0.9714168858557766], 
     Hue[0.6488387891085793, 1, 0.10160783046504411`], 
     Hue[0.015500707356173038`, 1, 0.9785374821222219], 
     Hue[0.6492329501649864, 1, 0.10106206900232663`], 
     Hue[0.03332299287059859, 1, 0.9538604714099403], 
     Hue[0.03473507084480709, 1, 0.9519052865225748], 
     Hue[0.04215320415844004, 1, 0.9416340250113908], 
     Hue[0.07196710009451046, 1, 0.9003532460229855], 
     Hue[0.06926880363328558, 1, 0.9040893488154508], 
     Hue[0.03418609793982197, 1, 0.9526654028525543], 
     Hue[0.009141688588689245, 1, 0.987342277338738], 
     Hue[0.00910687601034832, 1, 0.9873904793702869], 
     Hue[0.009530405493161975, 1, 0.9868040539325449], 
     Hue[0.061849008916673553`, 1, 0.9143629107307597], 
     Hue[0.05771588629922719, 1, 0.9200856958933777], 
     Hue[0.048903090076979905`, 1, 0.9322880291241817], 
     Hue[0.04549981712078777, 1, 0.9370002532173707], 
     Hue[0.042100071806292494`, 1, 0.9417075928835951], 
     Hue[0.04064183626928053, 1, 0.9437266882425346], 
     Hue[0.041027294995301666`, 1, 0.9431929761603515], 
     Hue[0.005171644949916954, 1, 0.9928392608385764], 
     Hue[0.006973328096489095, 1, 0.9903446226356304], 
     Hue[0.6496689916477514, 1, 0.10045831925695965`], 
     Hue[0.6492350636994628, 1, 0.1010591425699746], 
     Hue[0.6471131177345122, 1, 0.10399722159836784`], 
     Hue[0.644491607965287, 1, 0.1076270043557565], 
     Hue[0.056424654261225005`, 1, 0.9218735556383039], 
     Hue[0.05135556875173097, 1, 0.9288922894206803], 
     Hue[0.045131851977784354`, 1, 0.9375097434153754], 
     Hue[0.04262461721951161, 1, 0.9409812992345225], 
     Hue[0.07595022636294868, 1, 0.8948381481128403], 
     Hue[0.08282899623078377, 1, 0.885313697526607], 
     Hue[0.6499373590833081, 1, 0.10008673357695809`], 
     Hue[0.6499373590833081, 1, 0.10008673357695809`], 
     Hue[0.649274493099335, 1, 0.1010045480163054], 
     Hue[0.649274493099335, 1, 0.10100454801630541`], 
     Hue[0.6448762409008205, 1, 0.107094435675787], 
     Hue[0.6448762409008204, 1, 0.10709443567578711`], 
     Hue[0.6495027893128164, 1, 0.10068844556686975`], 
     Hue[0.6495027893128164, 1, 0.10068844556686973`], 
     Hue[0.6499538788065777, 1, 0.10006386011396938`], 
     Hue[0.6499538788065777, 1, 0.10006386011396938`], 
     Hue[0.6496967586483982, 1, 0.1004198726406795], 
     Hue[0.6358687451106876, 1, 0.11956635292366341`], 
     Hue[0.6445814731119602, 1, 0.10750257569113203`], 
     Hue[0.648553772886834, 1, 0.10200246831053757`], 
     Hue[0.6497267406777602, 1, 0.10037835906156285`], 
     Hue[0.6499254125526751, 1, 0.10010327492706521`], 
     Hue[0.6499586581139448, 1, 0.10005724261146098`], 
     Hue[0.6496988563463841, 1, 0.10041696813577587`], 
     Hue[0.6497601166301001, 1, 0.10033214620447677`], 
     Hue[0.6477373901880301, 1, 0.10313284435503531`], 
     Hue[0.6479923174746732, 1, 0.10277986811199087`], 
     Hue[0.6490370473675526, 1, 0.10133331902954257`], 
     Hue[0.6491943163368815, 1, 0.10111556199508723`], 
     Hue[0.6497221480877446, 1, 0.1003847180323536], 
     Hue[0.6497860452111204, 1, 0.1002962450922949], 
     Hue[0.6499073154321457, 1, 0.10012833247856744`], 
     Hue[0.6498741343415306, 1, 0.1001742755271114], 
     Hue[0.649949059363878, 1, 0.10007053318847657`], 
     Hue[0.6499641592388715, 1, 0.10004962566925482`], 
     Hue[0.6499416791214037, 1, 0.10008075198574878`], 
     Hue[0.6495719554413468, 1, 0.10059267708121211`], 
     Hue[0.6498471989649298, 1, 0.10021157066394343`], 
     Hue[0.6495833963968747, 1, 0.1005768357581736], 
     Hue[0.6497469567827983, 1, 0.10035036753151011`], 
     Hue[0.6499319255313737, 1, 0.10009425695655956`], 
     Hue[0.6498426295691704, 1, 0.10021789751961035`], 
     Hue[0.649658930923395, 1, 0.10047224949068395`], 
     Hue[0.6499184304393719, 1, 0.10011294246856195`], 
     Hue[0.041701254779857866`, 1, 0.9422598010740431], 
     Hue[0.014595760058466745`, 1, 0.9797904860728921], 
     Hue[0.012805719268327964`, 1, 0.9822690040900074], 
     Hue[0.6365472824064977, 1, 0.11862683974484936`], 
     Hue[0.6274462299482741, 1, 0.1312282969946973], 
     Hue[0.0551207431208689, 1, 0.9236789710634122], 
     Hue[0.058552955161517706`, 1, 0.9189266774686679], 
     Hue[0.0749548643158855, 1, 0.8962163417164661], 
     Hue[0.02052017539793527, 1, 0.9715874494490128], 
     Hue[0.01575384386688128, 1, 0.9781869854150874], 
     Hue[0.6493942106350996, 1, 0.1008387852744775], 
     Hue[0.6486427565461664, 1, 0.1018792601668465], 
     Hue[0.03217186470267641, 1, 0.9554543411809097], 
     Hue[0.06835631402142672, 1, 0.9053527959703322], 
     Hue[0.033401603489734755`, 1, 0.9537516259372903], 
     Hue[0.008850548370431865, 1, 0.9877453945640174], 
     Hue[0.6350599869277493, 1, 0.12068617194619322`], 
     Hue[0.6255000197060359, 1, 0.13392304963779653`], 
     Hue[0.6490587473812769, 1, 0.10130327285669356`], 
     Hue[0.6483686684673781, 1, 0.10225876673747662`], 
     Hue[0.6494809405183147, 1, 0.10071869774387192`], 
     Hue[0.6497260502171801, 1, 0.10037931508390448`], 
     Hue[0.6497343048506602, 1, 0.10036788559139366`], 
     Hue[0.6495881296151054, 1, 0.10057028207139264`], 
     Hue[0.6491921147809965, 1, 0.10111861030323574`], 
     Hue[0.6499104370570542, 1, 0.10012401022869415`], 
     Hue[0.6497856444085193, 1, 0.10029680004974256`], 
     Hue[0.6498599323216309, 1, 0.10019393986235738`], 
     Hue[0.6497772646516744, 1, 0.10030840278998937`], 
     Hue[0.043590017780424484`, 1, 0.9396445907655662], 
     Hue[0.6498275660680192, 1, 0.10023875467505038`], 
     Hue[0.6449192713091971, 1, 0.10703485511034244`], 
     Hue[0.6416518541659899, 1, 0.11155897115478319`], 
     Hue[0.64068287535726, 1, 0.11290063412071698`], 
     Hue[0.6479982157146393, 1, 0.10277170131819176`], 
     Hue[0.6419437848941391, 1, 0.11115475937734598`], 
     Hue[0.6495046190558837, 1, 0.10068591207646872`], 
     Hue[0.6478746927882637, 1, 0.1029427330624042], 
     Hue[0.6414481356470569, 1, 0.11184104295022886`], 
     Hue[0.6497129391888993, 1, 0.10039746881537023`], 
     Hue[0.6488132697315385, 1, 0.10164316498710058`], 
     Hue[0.6482313331258844, 1, 0.10244892336416006`], 
     Hue[0.1400480729581597, 1, 0.8060872835963943], 
     Hue[0.14429912220993546`, 1, 0.8002012154016278], 
     Hue[0.6482450777562206, 1, 0.10242989233754067`], 
     Hue[0.6496916149164867, 1, 0.10042699473101835`], 
     Hue[0.047500702283308716`, 1, 0.9342297968384956], 
     Hue[0.05428141377100415, 1, 0.9248411193939942], 
     Hue[0.042136452329496143`, 1, 0.9416572198514668], 
     Hue[0.04630260025153665, 1, 0.9358887073440262], 
     Hue[0.03809627971540075, 1, 0.9472513050094451], 
     Hue[0.03701096584584418, 1, 0.9487540472903696], 
     Hue[0.04752291360831895, 1, 0.9341990426961738], 
     Hue[0.04573062708464948, 1, 0.9366806701904854], 
     Hue[0.012087522107598558`, 1, 0.9832634309279404], 
     Hue[0.6485449728221787, 1, 0.10201465301544485`], 
     Hue[0.6493545666330911, 1, 0.10089367696956628`], 
     Hue[0.0481605630927362, 1, 0.9333161434100576], 
     Hue[0.04724944704451617, 1, 0.9345776887075931], 
     Hue[0.047223014112845796`, 1, 0.9346142881514443], 
     Hue[0.6490955361391237, 1, 0.10125233457659792`], 
     Hue[0.08784875679221449, 1, 0.8783632598261646], 
     Hue[0.02084452568433881, 1, 0.971138349052454], 
     Hue[0.0227330174702699, 1, 0.9685235142719341], 
     Hue[0.025491634684400077`, 1, 0.9647038904369846], 
     Hue[0.015500707356173149`, 1, 0.9785374821222218], 
     Hue[0.007937127358919605, 1, 0.9890101313491881], 
     Hue[0.016398729669450995`, 1, 0.9772940666115294], 
     Hue[0.6367353523176112, 1, 0.11836643525253829`], 
     Hue[0.643165033439658, 1, 0.10946379985278118`], 
     Hue[0.6392746280899382, 1, 0.11485051495239339`], 
     Hue[0.6311256591634412, 1, 0.12613370269677374`], 
     Hue[0.6057126080956506, 1, 0.16132100417525305`], 
     Hue[0.5103894171629624, 1, 0.29330696085128294`], 
     Hue[0.4523531671962556, 1, 0.3736648454205692], 
     Hue[0.04253595364447027, 1, 0.9411040641845796], 
     Hue[0.03650959131652054, 1, 0.9494482581771254], 
     Hue[0.07112573625560481, 1, 0.9015182113383934], 
     Hue[0.02487452067512752, 1, 0.9655583559882849], 
     Hue[0.6492807435674608, 1, 0.10099589352197733`], 
     Hue[0.649702094733682, 1, 0.10041248421490184`], 
     Hue[0.015663297824426103`, 1, 0.9783123568584869], 
     Hue[0.010402925050109979`, 1, 0.9855959499306169], 
     Hue[0.6072062822644524, 1, 0.15925283994152745`], 
     Hue[0.6493857421370917, 1, 0.10085051088710387`], 
     Hue[0.6496768145128254, 1, 0.10044748759762635`], 
     Hue[0.6489286078283828, 1, 0.10148346608377772`], 
     Hue[0.6481394116323587, 1, 0.10257619927827265`], 
     Hue[0.02744127510626293, 1, 0.9620043883144052], 
     Hue[0.03030928226472862, 1, 0.9580333014796065], 
     Hue[0.04267372138507064, 1, 0.9409133088514408], 
     Hue[0.03898261105574852, 1, 0.9460240769997329], 
     Hue[0.06814599165074586, 1, 0.9056440115605057], 
     Hue[0.0795960382110551, 1, 0.8897901009385392], 
     Hue[0.6291890682016369, 1, 0.12881513633619507`], 
     Hue[0.643086932044869, 1, 0.10957194024556599`], 
     Hue[0.04599066264847074, 1, 0.9363206209482713], 
     Hue[0.6495362381265386, 1, 0.10064213182479281`], 
     Hue[0.6496502477532469, 1, 0.10048427234165816`], 
     Hue[0.6497334916836287, 1, 0.10036901151497563`], 
     Hue[0.6494530583691563, 1, 0.10075730379655277`], 
     Hue[0.6498937119860647, 1, 0.10014716801929503`], 
     Hue[0.644385519450856, 1, 0.1077738961449687], 
     Hue[0.6494894308732826, 1, 0.10070694186776266`], 
     Hue[0.6489813241547583, 1, 0.10141047424725774`], 
     Hue[0.6499030530452722, 1, 0.10013423424500778`], 
     Hue[0.6497681839584752, 1, 0.10032097605749586`], 
     Hue[0.6499624193041866, 1, 0.1000520348095878], 
     Hue[0.6495498122888399, 1, 0.10062333683083713`], 
     Hue[0.6499124871433793, 1, 0.10012117164762864`], 
     Hue[0.6499662184132918, 1, 0.10004677450467285`], 
     Hue[0.6491210449914011, 1, 0.10121701462729088`], 
     Hue[0.6499014265422774, 1, 0.10013648632607741`], 
     Hue[0.045898172273247106`, 1, 0.9364486845447347], 
     Hue[0.03357393149125498, 1, 0.9535130179351854], 
     Hue[0.041721242136016135`, 1, 0.9422321262732084], 
     Hue[0.029639695521289755`, 1, 0.9589604215859066], 
     Hue[0.027379799482665668`, 1, 0.9620895084086167], 
     Hue[0.09129239316479953, 1, 0.8735951479256623], 
     Hue[0.09949382176783228, 1, 0.8622393237060784], 
     Hue[0.03952839347860859, 1, 0.945268378260388], 
     Hue[0.6498910591377748, 1, 0.10015084119385029`], 
     Hue[0.6496884643169639, 1, 0.10043135709958845`], 
     Hue[0.08532059336526332, 1, 0.8818637938019431], 
     Hue[0.02467797272158312, 1, 0.9658304993085772], 
     Hue[0.0712916470849756, 1, 0.9012884886515722], 
     Hue[0.08487607534102959, 1, 0.8824792802970359], 
     Hue[0.03780516384995036, 1, 0.9476543885154532], 
     Hue[0.05511692188895401, 1, 0.9236842619999099], 
     Hue[0.6481982576716845, 1, 0.10249472014689845`], 
     Hue[0.6466465463809845, 1, 0.10464324347248309`], 
     Hue[0.6473514237014005, 1, 0.10366725949036848`], 
     Hue[0.6498219842148358, 1, 0.10024648339484275`], 
     Hue[0.6495868696149781, 1, 0.10057202668695331`], 
     Hue[0.6496998008988805, 1, 0.10041566029385789`], 
     Hue[0.6342202833321612, 1, 0.12184883846316144`], 
     Hue[0.04272235928098833, 1, 0.9408459640724777], 
     Hue[0.6499302812990246, 1, 0.10009653358596594`], 
     Hue[0.6497521689561618, 1, 0.10034315067608361`], 
     Hue[0.6499302812990246, 1, 0.10009653358596594`], 
     Hue[0.6407330310926641, 1, 0.11283118771784977`], 
     Hue[0.06465901179075528, 1, 0.9104721375204927], 
     Hue[0.043928337384023464`, 1, 0.939176148237506], 
     Hue[0.06949450586165895, 1, 0.9037768380377029], 
     Hue[0.6496267565797257, 1, 0.10051679858191831`], 
     Hue[0.6498824332262844, 1, 0.10016278476360634`], 
     Hue[0.6499555912141548, 1, 0.10006148908809344`], 
     Hue[0.6499559932871283, 1, 0.10006093237166855`], 
     Hue[0.6482134889743377, 1, 0.10247363065091698`], 
     Hue[0.6470864964532759, 1, 0.10403408183392583`], 
     Hue[0.6485517135544813, 1, 0.10200531969379527`], 
     Hue[0.6488053171713715, 1, 0.10165417622425492`], 
     Hue[0.6497074013050955, 1, 0.10040513665448308`], 
     Hue[0.6499744855164816, 1, 0.10003532774641008`], 
     Hue[0.6498582848514496, 1, 0.10019622097491597`], 
     Hue[0.03093626442334363, 1, 0.9571651723369089], 
     Hue[0.6495439675226568, 1, 0.10063142958401376`], 
     Hue[0.6491239851573768, 1, 0.10121294362824751`], 
     Hue[0.05697537394894059, 1, 0.9211110206860822], 
     Hue[0.041973274102834135`, 1, 0.9418831589345373], 
     Hue[0.03908008834489851, 1, 0.9458891084455251], 
     Hue[0.050461668545464966`, 1, 0.930129997398587], 
     Hue[0.04070662132124514, 1, 0.9436369858628914], 
     Hue[0.6498901466536714, 1, 0.10015210463337815`], 
     Hue[0.05809647408028029, 1, 0.9195587281965351], 
     Hue[0.02388969612910652, 1, 0.9669219592058526], 
     Hue[0.004703775656733078, 1, 0.993487079859908], 
     Hue[0.005073446969077411, 1, 0.9929752272735851], 
     Hue[0.02901417926389116, 1, 0.9598265210192276], 
     Hue[0.02562974029384768, 1, 0.9645126672854417], 
     Hue[0.027739664580877732`, 1, 0.9615912336572462], 
     Hue[0.035798772626913444`, 1, 0.9504324686704275], 
     Hue[0.03045689272249308, 1, 0.9578289177688558], 
     Hue[0.041955194156443554`, 1, 0.9419081927064628], 
     Hue[0.0431373100866318, 1, 0.9402714168031252], 
     Hue[0.6220727010665302, 1, 0.13866856775403508`], 
     Hue[0.6123190981071969, 1, 0.15217355646695818`], 
     Hue[0.6499762336336973, 1, 0.10003290727641927`], 
     Hue[0.6339150668690628, 1, 0.12227144587360537`], 
     Hue[0.6489929934194554, 1, 0.10139431680383103`], 
     Hue[0.6498812315927376, 1, 0.10016444856390189`], 
     Hue[0.6498459588253669, 1, 0.10021328778026134`], 
     Hue[0.6492931798639575, 1, 0.10097867403452046`], 
     Hue[0.649548748830848, 1, 0.10062480931113349`], 
     Hue[0.6490542809447961, 1, 0.10130945715335926`], 
     Hue[0.6492049457869853, 1, 0.10110084429494347`], 
     Hue[0.6481873826044754, 1, 0.1025097779322648], 
     Hue[0.6485611491336744, 1, 0.10199225504568171`], 
     Hue[0.6475993352090712, 1, 0.10332399740282451`], 
     Hue[0.6441815731412086, 1, 0.10805628334294194`], 
     Hue[0.649944275372174, 1, 0.10007715717698988`], 
     Hue[0.6499822748838165, 1, 0.1000245424685617], 
     Hue[0.6499661389474883, 1, 0.10004688453424702`], 
     Hue[0.6490844215634843, 1, 0.10126772398902172`], 
     Hue[0.6489132110550369, 1, 0.10150478469302596`], 
     Hue[0.6451415781275591, 1, 0.10672704566953359`], 
     Hue[0.6443940217949389, 1, 0.10776212366854628`], 
     Hue[0.6482947521388, 1, 0.10236111242320009`], 
     Hue[0.6489686192995734, 1, 0.10142806558520608`], 
     Hue[0.6456775578017829, 1, 0.10598491996676208`], 
     Hue[0.6492840458435771, 1, 0.1009913211396625], 
     Hue[0.6469621012812009, 1, 0.10420632130295268`], 
     Hue[0.6499516518407451, 1, 0.10006694360512226`], 
     Hue[0.6499087375413788, 1, 0.10012636340424477`], 
     Hue[0.6492316670456285, 1, 0.10106384562912982`], 
     Hue[0.6395311979147588, 1, 0.1144952644257186], 
     Hue[0.642896126188708, 1, 0.10983613296948137`], 
     Hue[0.6489806141061978, 1, 0.10141145739141846`], 
     Hue[0.6498198022716735, 1, 0.10024950454691368`], 
     Hue[0.6495443968535537, 1, 0.1006308351258488], 
     Hue[0.6449167352674762, 1, 0.10703836655272535`], 
     Hue[0.048198097370765525`, 1, 0.9332641728712477], 
     Hue[0.03857521513497475, 1, 0.9465881636592658], 
     Hue[0.027189815265305395`, 1, 0.9623525634788079], 
     Hue[0.03850717135024173, 1, 0.9466823781304344], 
     Hue[0.6390741556787548, 1, 0.11512809213710873`], 
     Hue[0.6439421999552474, 1, 0.10838772313888821`], 
     Hue[0.6499782273129707, 1, 0.10003014679742518`], 
     Hue[0.6499432906521843, 1, 0.1000785206354372], 
     Hue[0.0478489808596011, 1, 0.9337475649636292], 
     Hue[0.07494528596698957, 1, 0.8962296040457067], 
     Hue[0.05856263449656074, 1, 0.9189132753124543], 
     Hue[0.05487183232243831, 1, 0.9240236167843162], 
     Hue[0.10781147082973264`, 1, 0.8507225788511394], 
     Hue[0.05295014408505516, 1, 0.9266844158822313], 
     Hue[0.05388133913007598, 1, 0.9253950688968178], 
     Hue[0.06211844855677917, 1, 0.9139898404598442], 
     Hue[0.06721506894510776, 1, 0.9069329814606201], 
     Hue[0.06517422922087612, 1, 0.9097587595403254], 
     Hue[0.04501954627832283, 1, 0.9376652436146299], 
     Hue[0.06230299992999677, 1, 0.9137343077892353], 
     Hue[0.07307553801373778, 1, 0.8988184858271323], 
     Hue[0.09700780109073925, 1, 0.8656815061820534], 
     Hue[0.042703122737861254`, 1, 0.9408725992860382], 
     Hue[0.6473273284217171, 1, 0.10370062218531471`], 
     Hue[0.6487748549536838, 1, 0.10169635467951475`], 
     Hue[0.027452705565677693`, 1, 0.9619885615244462], 
     Hue[0.04369646701481511, 1, 0.9394971995179483], 
     Hue[0.6400104537885324, 1, 0.11383167936972449`], 
     Hue[0.6423043849432354, 1, 0.11065546700167417`], 
     Hue[0.6487281960022395, 1, 0.10176095938151451`], 
     Hue[0.6484267809425183, 1, 0.10217830331035932`], 
     Hue[0.6479000971357278, 1, 0.10290755781206923`], 
     Hue[0.03799635877715435, 1, 0.9473896570777862], 
     Hue[0.023348425156580976`, 1, 0.967671411321657], 
     Hue[0.023159878103820253`, 1, 0.9679324764716335], 
     Hue[0.023311044981100704`, 1, 0.9677231684877067], 
     Hue[0.020025186176978793`, 1, 0.9722728191395679], 
     Hue[0.08965111765417655, 1, 0.8758676832480633], 
     Hue[0.09095469798021705, 1, 0.8740627258735456], 
     Hue[0.09051681845580839, 1, 0.8746690205996499], 
     Hue[0.017944344342809893`, 1, 0.9751539847561095], 
     Hue[0.01578152189488169, 1, 0.9781486619917023], 
     Hue[0.014296350343567465`, 1, 0.9802050533704451], 
     Hue[0.016495027223627945`, 1, 0.9771607315365152], 
     Hue[0.014515307180739456`, 1, 0.97990188236513], 
     Hue[0.6427550742491973, 1, 0.11003143565495767`], 
     Hue[0.04908649437740542, 1, 0.9320340847082079], 
     Hue[0.032912045073151264`, 1, 0.9544294760525598], 
     Hue[0.03472413692703513, 1, 0.9519204257933359], 
     Hue[0.05398407766856517, 1, 0.9252528155358328], 
     Hue[0.057805446899979906`, 1, 0.9199616889077201], 
     Hue[0.057805446899979906`, 1, 0.9199616889077202], 
     Hue[0.05570535155616052, 1, 0.9228695132299316], 
     Hue[0.05398407766856517, 1, 0.9252528155358328], 
     Hue[0.05780686512530053, 1, 0.9199597252111222], 
     Hue[0.03546306232424323, 1, 0.9508972983202786], 
     Hue[0.011250381962026101`, 1, 0.9844225480525792], 
     Hue[0.007937127358919605, 1, 0.9890101313491881], 
     Hue[0.6497521689561618, 1, 0.10034315067608361`], 
     Hue[0.05082069155001001, 1, 0.929632888623063], 
     Hue[0.006782790843821607, 1, 0.9906084434470163], 
     Hue[0.008144735109810952, 1, 0.9887226744633386], 
     Hue[0.6499473924316491, 1, 0.10007284124848584`], 
     Hue[0.6499293152508461, 1, 0.10009787119113618`], 
     Hue[0.03360836562471947, 1, 0.9534653399042347], 
     Hue[0.07117997803519904, 1, 0.9014431073358782], 
     Hue[0.0724954489780475, 1, 0.8996216860303957], 
     Hue[0.04009293991172935, 1, 0.9444866985837593], 
     Hue[0.04091918730972388, 1, 0.9433426637249976], 
     Hue[0.009325605616963162, 1, 0.9870876229918972], 
     Hue[0.005520538003394582, 1, 0.9923561781491459], 
     Hue[0.05035314943988356, 1, 0.9302802546216997], 
     Hue[0.6499338498698609, 1, 0.10009159248788495`], 
     Hue[0.6498620888334296, 1, 0.10019095392294373`], 
     Hue[0.6489479268317214, 1, 0.10145671669453957`], 
     Hue[0.6475265734487213, 1, 0.1034247444556166], 
     Hue[0.6430469879148967, 1, 0.1096272475024508], 
     Hue[0.050329765612521005`, 1, 0.9303126322288171], 
     Hue[0.042735773982813696`, 1, 0.9408273898699503], 
     Hue[0.04477511716797844, 1, 0.9380036839212607], 
     Hue[0.05345478066160392, 1, 0.9259856883147023], 
     Hue[0.061928951058120796`, 1, 0.9142522216118327], 
     Hue[0.05739117415416506, 1, 0.9205352973250022], 
     Hue[0.06770191282062021, 1, 0.9062588899406797], 
     Hue[0.6496372281357327, 1, 0.10050229950437024`], 
     Hue[0.6498600754423887, 1, 0.10019374169515424`], 
     Hue[0.6484517550369183, 1, 0.10214372379503625`], 
     Hue[0.6499060166662519, 1, 0.10013013076980502`], 
     Hue[0.6479464775082973, 1, 0.10284333883466536`], 
     Hue[0.6467038336222727, 1, 0.10456392267685319`], 
     Hue[0.6387562509282644, 1, 0.1155682679454801], 
     Hue[0.6472220976386766, 1, 0.10384632634644789`], 
     Hue[0.6472220976386766, 1, 0.10384632634644785`], 
     Hue[0.6447068072167755, 1, 0.1073290361613877], 
     Hue[0.6330394963939094, 1, 0.12348377422381779`], 
     Hue[0.6486434327366711, 1, 0.10187832390307078`], 
     Hue[0.6479542012453401, 1, 0.10283264442952911`], 
     Hue[0.6489949553478854, 1, 0.10139160028754335`], 
     Hue[0.6471113314506716, 1, 0.10399969491445471`], 
     Hue[0.6495226057413306, 1, 0.10066100743508069`], 
     Hue[0.6493036438893487, 1, 0.10096418538397885`], 
     Hue[0.6491804546532631, 1, 0.10113475509548193`], 
     Hue[0.6418045339292079, 1, 0.11134756840571214`], 
     Hue[0.6477961404497693, 1, 0.10305149783878106`], 
     Hue[0.6474843221506638, 1, 0.10348324625292712`], 
     Hue[0.6487825312182038, 1, 0.10168572600556397`], 
     Hue[0.649459576572486, 1, 0.10074827859194249`], 
     Hue[0.6498661527869116, 1, 0.10018532691043006`], 
     Hue[0.6491220168277072, 1, 0.10121566900779004`], 
     Hue[0.6497587916629718, 1, 0.10033398077434678`], 
     Hue[0.648701741466883, 1, 0.10179758873816201`], 
     Hue[0.6485008636481064, 1, 0.10207572725646802`], 
     Hue[0.6482001501080512, 1, 0.10249209985039068`], 
     Hue[0.6482813642145266, 1, 0.10237964954911705`], 
     Hue[0.6486719392092343, 1, 0.1018388534025987], 
     Hue[0.6484655561048563, 1, 0.10212461462404505`], 
     Hue[0.06826258777746408, 1, 0.9054825707696651], 
     Hue[0.057187397832477505`, 1, 0.9208174491550312], 
     Hue[0.045358296199337844`, 1, 0.9371962052624554], 
     Hue[0.02335886116636865, 1, 0.9676569614619511], 
     Hue[0.014634081393758769`, 1, 0.9797374257624879], 
     Hue[0.056134145423178405`, 1, 0.9222757986448299], 
     Hue[0.038504177834357556`, 1, 0.9466865229985819], 
     Hue[0.029246379599775274`, 1, 0.9595050128618496], 
     Hue[0.02748788816436576, 1, 0.9619398471570321], 
     Hue[0.037237192728402646`, 1, 0.9484408100683657], 
     Hue[0.0506296516520498, 1, 0.9298974054048541], 
     Hue[0.03546306232424323, 1, 0.9508972983202786], 
     Hue[0.03939831657384074, 1, 0.9454484847439129], 
     Hue[0.03939831657384074, 1, 0.9454484847439129], 
     Hue[0.009952681936556407, 1, 0.9862193634724604], 
     Hue[0.008041040835682911, 1, 0.9888662511505929], 
     Hue[0.010292378997668883`, 1, 0.9857490136955355], 
     Hue[0.012289164533905161`, 1, 0.9829842337222852], 
     Hue[0.04340606600197294, 1, 0.9398992932280374], 
     Hue[0.07118961074245855, 1, 0.9014297697412113], 
     Hue[0.6479384255371093, 1, 0.10285448771784862`], 
     Hue[0.6477470413570692, 1, 0.1031194811979042], 
     Hue[0.6491102157450633, 1, 0.1012320089683739], 
     Hue[0.644961034964207, 1, 0.10697702851109805`], 
     Hue[0.6470917771528514, 1, 0.104026770096052], 
     Hue[0.08202855739195403, 1, 0.8864219974572944], 
     Hue[0.0772663172900574, 1, 0.8930158683676128], 
     Hue[0.05011381771228385, 1, 0.9306116370137609], 
     Hue[0.04445396812277291, 1, 0.9384483518300066], 
     Hue[0.03690581060695364, 1, 0.9488996468519103], 
     Hue[0.04737918358422988, 1, 0.9343980534987586], 
     Hue[0.03311847133470436, 1, 0.9541436550750246], 
     Hue[0.046541962898920874`, 1, 0.9355572821399557], 
     Hue[0.04574318976655356, 1, 0.9366632757078489], 
     Hue[0.5520940420491334, 1, 0.23556209562427685`], 
     Hue[0.5376501036925775, 1, 0.2555613948872005], 
     Hue[0.032113660441994485`, 1, 0.9555349316956999], 
     Hue[0.04308511544708005, 1, 0.9403436863040431], 
     Hue[0.0400094529739522, 1, 0.9446022958822201], 
     Hue[0.05197282591632113, 1, 0.9280376256543246], 
     Hue[0.04000945297395231, 1, 0.9446022958822198], 
     Hue[0.007435073507686463, 1, 0.9897052828355111], 
     Hue[0.6445488157590512, 1, 0.10754779356439075`], 
     Hue[0.019820976731822593`, 1, 0.9725555706790149], 
     Hue[0.6495469764337585, 1, 0.10062726339941139`], 
     Hue[0.012745726889338282`, 1, 0.9823520704609162], 
     Hue[0.04417656937260883, 1, 0.9388324424071569], 
     Hue[0.04446692156611742, 1, 0.9384304162930682], 
     Hue[0.011453907048082357`, 1, 0.9841407440872705], 
     Hue[0.006401475387581956, 1, 0.9911364186941174], 
     Hue[0.009140671470449724, 1, 0.9873436856563004], 
     Hue[0.05048952959982178, 1, 0.9300914205540929], 
     Hue[0.05910473808894301, 1, 0.9181626703383866], 
     Hue[0.053289954699020425`, 1, 0.9262139088782795], 
     Hue[0.04819367209655245, 1, 0.9332703001740044], 
     Hue[0.06933289853987523, 1, 0.9040006020217112], 
     Hue[0.06191019878017634, 1, 0.9142781863043712], 
     Hue[0.24773892559222693`, 1, 0.6569768722569166], 
     Hue[0.6499890034898884, 1, 0.1000152259370776], 
     Hue[0.6495127023476075, 1, 0.10067471982638966`], 
     Hue[0.6492175902887827, 1, 0.10108333652322396`], 
     Hue[0.6498326654667155, 1, 0.10023169396916323`], 
     Hue[0.6499881082797194, 1, 0.10001646545884998`], 
     Hue[0.6499865669517192, 1, 0.1000185996053119], 
     Hue[0.6499742258316692, 1, 0.1000356873099966], 
     Hue[0.6447508761619289, 1, 0.10726801762194454`], 
     Hue[0.6490377190037924, 1, 0.10133238907167208`], 
     Hue[0.6497956408877857, 1, 0.1002829587707582], 
     Hue[0.6499927697598791, 1, 0.10001001110170595`], 
     Hue[0.6499887256934325, 1, 0.10001561057832427`], 
     Hue[0.6499769866743443, 1, 0.10003186460475398`], 
     Hue[0.6499846282523107, 1, 0.10002128395833898`], 
     Hue[0.6499935975055555, 1, 0.1000088649923078], 
     Hue[0.649994903700457, 1, 0.10000705641475184`], 
     Hue[0.11863295658723949`, 1, 0.8357389831868992], 
     Hue[0.03034787920796722, 1, 0.9579798595581993], 
     Hue[0.03505827883950796, 1, 0.9514577677606814], 
     Hue[0.09830021119206922, 1, 0.8638920152725196], 
     Hue[0.05267828079038206, 1, 0.9270608419825479], 
     Hue[0.04635001220852253, 1, 0.9358230600189689], 
     Hue[0.040789603581734, 1, 0.9435220873483683], 
     Hue[0.1288532476167511, 1, 0.8215878109921908], 
     Hue[0.023817360629775575`, 1, 0.96702211605108], 
     Hue[0.023749371904444372`, 1, 0.9671162542861539], 
     Hue[0.08067834803250484, 1, 0.8882915181088396], 
     Hue[0.07713977471247657, 1, 0.8931910811673401], 
     Hue[0.04909740422401321, 1, 0.9320189787667509], 
     Hue[0.04452203504990271, 1, 0.9383541053155193], 
     Hue[0.20410514372379246`, 1, 0.7173928779209028], 
     Hue[0.15315556634410604`, 1, 0.7879384466004685], 
     Hue[0.08852528963632356, 1, 0.8774265220420134], 
     Hue[0.5883867835153166, 1, 0.18531060744033095`], 
     Hue[0.6178304300221003, 1, 0.1445424815078613], 
     Hue[0.6342202833321611, 1, 0.12184883846316161`], 
     Hue[0.6178304300221004, 1, 0.14454248150786106`], 
     Hue[0.03806628505559828, 1, 0.947292836076864], 
     Hue[0.6061907515330938, 1, 0.16065895941571645`], 
     Hue[0.04468239304571375, 1, 0.9381320711674733], 
     Hue[0.06824947402671455, 1, 0.9055007282707029], 
     Hue[0.17898339815715553`, 1, 0.7521768333208616], 
     Hue[0.6499930992970251, 1, 0.10000955481950372`], 
     Hue[0.6498662979568294, 1, 0.10018512590592855`], 
     Hue[0.6496607777270076, 1, 0.10046969237798958`], 
     Hue[0.6499974394706305, 1, 0.10000354534835781`], 
     Hue[0.6499939716120147, 1, 0.10000834699874893`], 
     Hue[0.6499958669565609, 1, 0.1000057226755311], 
     Hue[0.6479435828316525, 1, 0.10284734684848111`], 
     Hue[0.6499974800235059, 1, 0.10000348919822272`], 
     Hue[0.6499940304253188, 1, 0.10000826556494324`], 
     Hue[0.6463858151238356, 1, 0.10500425598238146`], 
     Hue[0.6468114277483866, 1, 0.10441494619454166`], 
     Hue[0.6499955804681895, 1, 0.10000611935173769`], 
     Hue[0.6480026763290759, 1, 0.10276552508281797`], 
     Hue[0.649996835842934, 1, 0.10000438114055295`], 
     Hue[0.6457909523887716, 1, 0.10582791207708554`], 
     Hue[0.646140792312151, 1, 0.10534351833702169`], 
     Hue[0.6499516518407451, 1, 0.10006694360512226`], 
     Hue[0.6497899760668525, 1, 0.10029080236897342`], 
     Hue[0.12808116331743624`, 1, 0.8226568507912421], 
     Hue[0.0871847617928091, 1, 0.879282637517649], 
     Hue[0.06516096340408128, 1, 0.909777127594349], 
     Hue[0.06172868609543414, 1, 0.9145295115601682], 
     Hue[0.6499685527974417, 1, 0.10004354228046541`], 
     Hue[0.6453452903425816, 1, 0.10644498260257935`], 
     Hue[0.6476581537282714, 1, 0.1032425563762396], 
     Hue[0.6499798526259114, 1, 0.10002789636412271`], 
     Hue[0.6497081153899492, 1, 0.10040414792160883`], 
     Hue[0.649848902628463, 1, 0.10020921174520522`], 
     Hue[0.6456842967295763, 1, 0.10597558914366362`], 
     Hue[0.6434979245336307, 1, 0.10900287372266512`], 
     Hue[0.6499784253706073, 1, 0.10002987256377453`], 
     Hue[0.6499693859413178, 1, 0.10004238869663695`], 
     Hue[0.6478161188385632, 1, 0.10302383545429718`], 
     Hue[0.6480536026161982, 1, 0.10269501176218723`], 
     Hue[0.6453322783359424, 1, 0.10646299922715666`], 
     Hue[0.6449672986906595, 1, 0.10696835565908695`], 
     Hue[0.6451736844804499, 1, 0.1066825907193772], 
     Hue[0.645091259259469, 1, 0.10679671794842759`], 
     Hue[0.644342915985969, 1, 0.10783288555788897`], 
     Hue[0.6444007143474562, 1, 0.10775285705736841`], 
     Hue[0.6446338312995726, 1, 0.10743007973905336`], 
     Hue[0.6342592705865003, 1, 0.12179485611099962`], 
     Hue[0.0612641821995904, 1, 0.9151726708005671], 
     Hue[0.03250033848878209, 1, 0.9549995313232248], 
     Hue[0.0345843096447892, 1, 0.9521140327995227], 
     Hue[0.09523666394141372, 1, 0.8681338499272734], 
     Hue[0.1983592063793964, 1, 0.7253487911669896], 
     Hue[0.16963550783380965`, 1, 0.7651200660762636], 
     Hue[0.11497243965094506`, 1, 0.8408073912525377], 
     Hue[0.15229169722691133`, 1, 0.7891345730704304], 
     Hue[0.05833042625343143, 1, 0.9192347944183258], 
     Hue[0.6495167529428522, 1, 0.10066911130989697`], 
     Hue[0.6489883444952622, 1, 0.10140075377579075`], 
     Hue[0.026450209420877946`, 1, 0.9633766331095536], 
     Hue[0.03917513357652602, 1, 0.9457575073555794], 
     Hue[0.033577734442188034`, 1, 0.9535077523108165], 
     Hue[0.03472413692703524, 1, 0.9519204257933358], 
     Hue[0.03623230957301016, 1, 0.9498321867450628], 
     Hue[0.025015242436588148`, 1, 0.9653635104724164], 
     Hue[0.026346987648856124`, 1, 0.9635195555631222], 
     Hue[0.09307224102515843, 1, 0.8711307431959344], 
     Hue[0.04843689360942616, 1, 0.9329335319254098], 
     Hue[0.5315189606144237, 1, 0.26405066991849024`], 
     Hue[0.5754262393411327, 1, 0.20325597629689324`], 
     Hue[0.575426239341133, 1, 0.2032559762968928], 
     Hue[0.649875651119267, 1, 0.10017217537332253`], 
     Hue[0.649875649291113, 1, 0.10017217790461287`], 
     Hue[0.17331095225783966`, 1, 0.7600309891814528], 
     Hue[0.12766332672407665`, 1, 0.823235393766663], 
     Hue[0.07802715035046881, 1, 0.8919624072070432], 
     Hue[0.06851341295243463, 1, 0.9051352743735521], 
     Hue[0.0679391310604277, 1, 0.9059304339163309], 
     Hue[0.07158962558394066, 1, 0.9008759030376206], 
     Hue[0.6499464831292368, 1, 0.10007410028259535`], 
     Hue[0.6499184109370365, 1, 0.10011296947179563`], 
     Hue[0.6498288365477685, 1, 0.10023699554924377`], 
     Hue[0.061401140430943135`, 1, 0.9149830363263864], 
     Hue[0.04634829554374764, 1, 0.9358254369394263], 
     Hue[0.037567625926924975`, 1, 0.9479832871781039], 
     Hue[0.05786211421966536, 1, 0.9198832264650787], 
     Hue[0.05279279153644112, 1, 0.9269022886418508], 
     Hue[0.6472828862522303, 1, 0.10376215749691192`], 
     Hue[0.6499800935021194, 1, 0.10002756284321936`], 
     Hue[0.6499422807032225, 1, 0.10007991902630733`], 
     Hue[0.07039725079862458, 1, 0.9025268835095966], 
     Hue[0.06133276840694113, 1, 0.9150777052826968], 
     Hue[0.06026259398959721, 1, 0.9165594852451731], 
     Hue[0.6495829314220184, 1, 0.10057747956951303`], 
     Hue[0.6007563958113746, 1, 0.16818345195348128`], 
     Hue[0.6499951528011115, 1, 0.10000671150615334`], 
     Hue[0.6174382819231714, 1, 0.14508545579868584`], 
     Hue[0.647106197502478, 1, 0.10400680345810738`], 
     Hue[0.6478317640142195, 1, 0.10300217290338837`], 
     Hue[0.6475757828928765, 1, 0.10335660830217093`], 
     Hue[0.06249124612314194, 1, 0.9134736592141111], 
     Hue[0.018084650903574584`, 1, 0.974959714133512], 
     Hue[0.06757640186450764, 1, 0.906432674341451], 
     Hue[0.05322344602401563, 1, 0.9263059978129015], 
     Hue[0.030856313299195248`, 1, 0.957275873893422], 
     Hue[0.05197282591632135, 1, 0.9280376256543243], 
     Hue[0.6478918916989861, 1, 0.10291891918601935`], 
     Hue[0.05399582404046466, 1, 0.9252365513285874], 
     Hue[0.6499956161056769, 1, 0.10000607000752429`], 
     Hue[0.6499911089724155, 1, 0.10001231065357848`], 
     Hue[0.06681697685755095, 1, 0.9074841858895448], 
     Hue[0.02672704593541697, 1, 0.9629933210124997], 
     Hue[0.03242828551071919, 1, 0.9550992969851579], 
     Hue[0.029182052104281708`, 1, 0.9595940817017639], 
     Hue[0.6449070264505997, 1, 0.10705180952993881`], 
     Hue[0.6440727187683695, 1, 0.10820700478225774`], 
     Hue[0.6443939593832946, 1, 0.10776221008466906`], 
     Hue[0.6443400020155287, 1, 0.10783692028619116`], 
     Hue[0.6492493699506017, 1, 0.10103933391455157`], 
     Hue[0.6494527819466682, 1, 0.10075768653538245`], 
     Hue[0.6498484806546423, 1, 0.10020979601664912`], 
     Hue[0.6498912236067963, 1, 0.10015061346751279`], 
     Hue[0.6499706325092646, 1, 0.1000406626794799], 
     Hue[0.10992721715271037`, 1, 0.847793083942401], 
     Hue[0.09876579460769042, 1, 0.8632473613124286], 
     Hue[0.11035594752752909`, 1, 0.8471994572695751], 
     Hue[0.03806628505559828, 1, 0.947292836076864], 
     Hue[0.6061907515330939, 1, 0.16065895941571615`], 
     Hue[0.6263033779322904, 1, 0.13281070747836715`], 
     Hue[0.06372190072865369, 1, 0.9117696759141718], 
     Hue[0.06485555389034381, 1, 0.9102000023056778], 
     Hue[0.6499903826101904, 1, 0.10001331638589032`], 
     Hue[0.6494877257675397, 1, 0.1007093027834067], 
     Hue[0.6499884901766956, 1, 0.10001593667842158`], 
     Hue[0.6499922570106315, 1, 0.10001072106220266`], 
     Hue[0.6499275366072345, 1, 0.10010033392844458`], 
     Hue[0.6499464223583913, 1, 0.10007418442684281`], 
     Hue[0.6453913385693693, 1, 0.10638122351933486`], 
     Hue[0.6448098170387806, 1, 0.10718640717707309`], 
     Hue[0.08465801396144634, 1, 0.8827812114379974], 
     Hue[0.08519764600350743, 1, 0.8820340286105282], 
     Hue[0.08337516010733359, 1, 0.8845574706206151], 
     Hue[0.6499924966956216, 1, 0.10001038919067769`], 
     Hue[0.6387932105341141, 1, 0.11551709310661128`], 
     Hue[0.6353394083893036, 1, 0.1202992806917336], 
     Hue[0.04421928477777015, 1, 0.9387732980000106], 
     Hue[0.048153392280072205`, 1, 0.9333260722275923], 
     Hue[0.6447011585016271, 1, 0.10733685745928563`], 
     Hue[0.6448943305510483, 1, 0.10706938846777939`], 
     Hue[0.6499946609395699, 1, 0.10000739254521092`], 
     Hue[0.0647287939103881, 1, 0.910375516124078], 
     Hue[0.15355933530569904`, 1, 0.7873793818844167], 
     Hue[0.645170456842378, 1, 0.10668705975670753`], 
     Hue[0.6499385647416965, 1, 0.10008506420380477`], 
     Hue[0.6205277623311956, 1, 0.14080771369526773`], 
     Hue[0.642560488295705, 1, 0.11030086235979314`], 
     Hue[0.6499848703981542, 1, 0.10002094867947885`], 
     Hue[0.039656102005979244`, 1, 0.9450915510686441], 
     Hue[0.020568021006048487`, 1, 0.971521201683933], 
     Hue[0.11278440634351394`, 1, 0.8438369758320575], 
     Hue[0.10893275550071002`, 1, 0.8491700308451707], 
     Hue[0.6499996117689304, 1, 0.10000053755071173`], 
     Hue[0.6499995549383003, 1, 0.10000061623927653`], 
     Hue[0.6499998613522568, 1, 0.10000019197379824`], 
     Hue[0.1067284633451212, 1, 0.852222127675986], 
     Hue[0.10836938580505306`, 1, 0.8499500811930034], 
     Hue[0.12629286712146093`, 1, 0.8251329532164388], 
     Hue[0.11863295658723927`, 1, 0.8357389831868994], 
     Hue[0.21110774562697637`, 1, 0.7076969675934173], 
     Hue[0.25216051171929077`, 1, 0.650854676080982], 
     Hue[0.1378538507545246, 1, 0.809125437416812], 
     Hue[0.21432628346020427`, 1, 0.7032405305935633], 
     Hue[0.5736023766631482, 1, 0.20578132462025636`], 
     Hue[0.5614372032462096, 1, 0.22262541088986365`], 
     Hue[0.6485314623232085, 1, 0.10203335986017296`], 
     Hue[0.6491656802896096, 1, 0.10115521190669445`], 
     Hue[0.6170406502618829, 1, 0.145636022714316], 
     Hue[0.6154386325239093, 1, 0.147854201120741], 
     Hue[0.5883867835153163, 1, 0.18531060744033134`], 
     Hue[0.15045000576486295`, 1, 0.7916846074024975], 
     Hue[0.07062535873731712, 1, 0.9022110417483301], 
     Hue[0.23447362550717887`, 1, 0.6753442108362139], 
     Hue[0.6448199254233327, 1, 0.10717241095230867`], 
     Hue[0.644208846340783, 1, 0.10801852045122351`], 
     Hue[0.0850591376137474, 1, 0.8822258094578882], 
     Hue[0.09740695956756307, 1, 0.8651288252141435], 
     Hue[0.6448884653974775, 1, 0.10707750944964665`], 
     Hue[0.6453953169661643, 1, 0.10637571496992648`], 
     Hue[0.6499971891361991, 1, 0.1000038919652628], 
     Hue[0.5981121608967196, 1, 0.17184470029684984`], 
     Hue[0.5854717308714729, 1, 0.18934683417796064`], 
     Hue[0.5996614433691522, 1, 0.1696995399504047], 
     Hue[0.6390043692910827, 1, 0.11522471944311631`], 
     Hue[0.4353319945381863, 1, 0.3972326229471268], 
     Hue[0.37496546869233927`, 1, 0.4808170433490687], 
     Hue[0.390011900540306, 1, 0.4599835223288071], 
     Hue[0.4452600169355271, 1, 0.38348613039696255`], 
     Hue[0.573381784770072, 1, 0.20608675954913125`], 
     Hue[0.6375229589269936, 1, 0.11727590302416266`], 
     Hue[0.40160736066184405`, 1, 0.4439282698528313], 
     Hue[0.5773654184541902, 1, 0.20057095906342903`], 
     Hue[0.22728327369662676`, 1, 0.6853000825739014], 
     Hue[0.04308574958218381, 1, 0.9403428082708224], 
     Hue[0.6394163061729531, 1, 0.11465434529898799`], 
     Hue[0.5883867835153158, 1, 0.185310607440332], 
     Hue[0.09307224102515943, 1, 0.8711307431959332], 
     Hue[0.39472354886284233`, 1, 0.453459701574526], 
     Hue[0.344949783712799, 1, 0.5223772225515091], 
     Hue[0.3586612911783269, 1, 0.5033920583684705], 
     Hue[0.5936284750273934, 1, 0.17805288073130157`], 
     Hue[0.4278010945255027, 1, 0.4076600229646886], 
     Hue[0.3799899453727811, 1, 0.4738600756376877], 
     Hue[0.6497731865249076, 1, 0.10031404942705112`], 
     Hue[0.23326531085858543`, 1, 0.6770172618881125], 
     Hue[0.3130814427000797, 1, 0.5665026177998896], 
     Hue[0.6499913868134334, 1, 0.10001192595063073`], 
     Hue[0.6489038319190435, 1, 0.10151777118901663`], 
     Hue[0.4619619730464792, 1, 0.3603603450125673], 
     Hue[0.4417370314569138, 1, 0.38836411029042717`], 
     Hue[0.4954214314489932, 1, 0.3140318641475479], 
     Hue[0.6499998898891067, 1, 0.10000015246123689`], 
     Hue[0.6025706657463226, 1, 0.1656713858897072], 
     Hue[0.6008226787674659, 1, 0.16809167555273957`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499997862560857, 1, 0.10000029595311212`], 
     Hue[0.6499990779848389, 1, 0.10000127663637694`], 
     Hue[0.6486511020220926, 1, 0.10186770489248718`], 
     Hue[0.6499407226267707, 1, 0.10008207636293287`], 
     Hue[0.6354676814128271, 1, 0.12012167188993178`], 
     Hue[0.5848453321548057, 1, 0.1902141554779614], 
     Hue[0.639531197914759, 1, 0.11449526442571836`], 
     Hue[0.580706957169457, 1, 0.19594421314998262`], 
     Hue[0.025903042625485817`, 1, 0.9641342486724042], 
     Hue[0.6449547432280339, 1, 0.1069857401457992], 
     Hue[0.5851247107231068, 1, 0.18982732361415994`], 
     Hue[0.6089511483839007, 1, 0.1568368714684452], 
     Hue[0.64019509435336, 1, 0.11357602320304], 
     Hue[0.6493461888102707, 1, 0.10090527703193289`], 
     Hue[0.6461585114915486, 1, 0.10531898408862514`], 
     Hue[0.649987649088762, 1, 0.1000171012617141], 
     Hue[0.10471895882045579`, 1, 0.855004518556292], 
     Hue[0.1392394785970158, 1, 0.8072068757887474], 
     Hue[0.5372696793716474, 1, 0.25608813625464216`], 
     Hue[0.6083213505344902, 1, 0.1577088992599366], 
     Hue[0.4986810040187754, 1, 0.3095186098201571], 
     Hue[0.22336035721007536`, 1, 0.6907318130937419], 
     Hue[0.0796255956903199, 1, 0.8897491751980187], 
     Hue[0.5742904650294552, 1, 0.20482858688229277`], 
     Hue[0.22306887145130444`, 1, 0.6911354087597323], 
     Hue[0.645340037260045, 1, 0.1064522561014763], 
     Hue[0.6427550742491974, 1, 0.11003143565495752`], 
     Hue[0.04259322582636593, 1, 0.9410247642404164], 
     Hue[0.6049285965937268, 1, 0.16240655856253214`], 
     Hue[0.6499017046372391, 1, 0.10013610127151513`], 
     Hue[0.060095585469215895`, 1, 0.9167907278118549], 
     Hue[0.6436966759282835, 1, 0.10872767948391512`], 
     Hue[0.03386942937047288, 1, 0.953103867025499], 
     Hue[0.0540176237603609, 1, 0.9252063671010387], 
     Hue[0.041470999995339874`, 1, 0.9425786153910679], 
     Hue[0.5812356721768548, 1, 0.1952121462166626], 
     Hue[0.6481378368943566, 1, 0.10257837968473708`], 
     Hue[0.009952681936556185, 1, 0.9862193634724606], 
     Hue[0.5784078892012288, 1, 0.19912753802906785`], 
     Hue[0.25241310933898886`, 1, 0.6505049255306308], 
     Hue[0.6495602767856091, 1, 0.10060884752761813`], 
     Hue[0.01651097486085562, 1, 0.9771386501926614], 
     Hue[0.6494484544654902, 1, 0.10076367843239825`], 
     Hue[0.6483151268634868, 1, 0.10233290126594134`], 
     Hue[0.6408761453841486, 1, 0.11263302946810194`], 
     Hue[0.0462831406040366, 1, 0.9359156514713339], 
     Hue[0.08948475457385185, 1, 0.8760980321285129], 
     Hue[0.10001911138221409`, 1, 0.8615119996246265], 
     Hue[0.05780686512530053, 1, 0.9199597252111222], 
     Hue[0.6455272861029625, 1, 0.10619298847282124`], 
     Hue[0.0612157411216776, 1, 0.9152397430622926], 
     Hue[0.6468880839554602, 1, 0.1043088068309013], 
     Hue[0.6426161775311433, 1, 0.11022375418764774`], 
     Hue[0.6447852320084007, 1, 0.10722044798836841`], 
     Hue[0.071736117160619, 1, 0.9006730685468352], 
     Hue[0.13271195854025042`, 1, 0.8162449804827301], 
     Hue[0.02783788189304981, 1, 0.9614552404557771], 
     Hue[0.6488566393602246, 1, 0.10158311473199673`], 
     Hue[0.32088402037208014`, 1, 0.5556990487155814], 
     Hue[0.026346987648856124`, 1, 0.9635195555631223], 
     Hue[0.11993540017691151`, 1, 0.8339355997550455], 
     Hue[0.6456533687331039, 1, 0.10601841252339476`], 
     Hue[0.08393034455035675, 1, 0.883788753699506], 
     Hue[0.5850783993839065, 1, 0.1898914470068987], 
     Hue[0.618613199175485, 1, 0.14345864729548236`], 
     Hue[0.1265694732233249, 1, 0.8247499601523194], 
     Hue[0.04272235928098833, 1, 0.9408459640724777], 
     Hue[0.6452749299036067, 1, 0.10654240474885238`], 
     Hue[0.6499776294646047, 1, 0.10003097458747053`], 
     Hue[0.014559449225128529`, 1, 0.9798407626113604], 
     Hue[0.6499987947065016, 1, 0.10000166886792095`], 
     Hue[0.25046533496948964`, 1, 0.653201843888399], 
     Hue[0.08286331183439855, 1, 0.8852661836139097], 
     Hue[0.6499999929888856, 1, 0.1000000097076969], 
     Hue[0.6499981101265391, 1, 0.10000261674786895`], 
     Hue[0.6499072806552448, 1, 0.10012838063119948`], 
     Hue[0.6424139351905273, 1, 0.1105037820438853], 
     Hue[0.6499992849439589, 1, 0.10000099007759541`], 
     Hue[0.6499999963888476, 1, 0.1000000050000572], 
     Hue[0.6053505649203895, 1, 0.16182229472561452`], 
     Hue[0.5873924756550859, 1, 0.1866873414006503], 
     Hue[0.5833506728862303, 1, 0.19228368369598875`], 
     Hue[0.6499407226267707, 1, 0.10008207636293287`], 
     Hue[0.4772491603253821, 1, 0.33919347031870173`], 
     Hue[0.4007096889912335, 1, 0.4451711998582921], 
     Hue[0.4062252845517318, 1, 0.43753422138990994`], 
     Hue[0.2742744841495816, 1, 0.6202353296390408], 
     Hue[0.34395843810238136`, 1, 0.5237498549351643], 
     Hue[0.5931959938441885, 1, 0.17865170083112358`], 
     Hue[0.2982366519006132, 1, 0.5870569435222279], 
     Hue[0.07962559569032013, 1, 0.8897491751980183], 
     Hue[0.4107270964661871, 1, 0.4313009433545102], 
     Hue[0.5851478579604558, 1, 0.18979527359321516`], 
     Hue[0.2990776514446132, 1, 0.585892482615151], 
     Hue[0.47156684320049835`, 1, 0.34706129403007924`], 
     Hue[0.23022254063329445`, 1, 0.6812303283539], 
     Hue[0.05785041042774952, 1, 0.9198994317154238], 
     Hue[0.0804468787655307, 1, 0.8886120140169574], 
     Hue[0.31666461339035434`, 1, 0.5615413045364325], 
     Hue[0.5107485628404164, 1, 0.292809682220962], 
     Hue[0.6191503270524775, 1, 0.1427149317734927], 
     Hue[0.5745344695729345, 1, 0.20449073443747529`], 
     Hue[0.41677568496485395`, 1, 0.42292597466404847`], 
     Hue[0.16312628894650472`, 1, 0.774132830689455], 
     Hue[0.171301672617576, 1, 0.7628130686833563], 
     Hue[0.2525700579819268, 1, 0.6502876120250245], 
     Hue[0.4727088745175577, 1, 0.3454800198987662], 
     Hue[0.6413247722183988, 1, 0.11201185385144793`], 
     Hue[0.6343980541936611, 1, 0.12160269419339238`], 
     Hue[0.5741257249842648, 1, 0.20505668848332564`], 
     Hue[0.49521272499596636`, 1, 0.3143208423132774], 
     Hue[0.44174668982683385`, 1, 0.3883507371628454], 
     Hue[0.4558105615089888, 1, 0.3688776840644771], 
     Hue[0.6168434916133725, 1, 0.14590901161225345`], 
     Hue[0.5934032562687064, 1, 0.1783647220894835], 
     Hue[0.6499984753384636, 1, 0.1000021110698197], 
     Hue[0.649999997206145, 1, 0.10000000386841473`], 
     Hue[0.6499971370846795, 1, 0.10000396403659756`], 
     Hue[0.5980394370323172, 1, 0.17194539487832997`], 
     Hue[0.5853021003077185, 1, 0.18958170726623597`], 
     Hue[0.4285571961667911, 1, 0.4066131129998277], 
     Hue[0.36965688876492503`, 1, 0.4881673847870269], 
     Hue[0.39129195061300875`, 1, 0.4582111453050648], 
     Hue[0.4711977095261346, 1, 0.34757240219458285`], 
     Hue[0.5866723066476305, 1, 0.18768449848789626`], 
     Hue[0.6384931995336433, 1, 0.11593249295341701`], 
     Hue[0.6369943793020255, 1, 0.1180077825048878], 
     Hue[0.10629467005142978`, 1, 0.852822764544174], 
     Hue[0.12629286712146082`, 1, 0.8251329532164389], 
     Hue[0.13771748395240957`, 1, 0.8093142529889713], 
     Hue[0.4555159009545894, 1, 0.36928567560133774`], 
     Hue[0.5895111546683302, 1, 0.18375378584385055`], 
     Hue[0.5939025305015919, 1, 0.17767341930548808`], 
     Hue[0.44964002438280454`, 1, 0.3774215047007322], 
     Hue[0.2075903403097999, 1, 0.7125672211095079], 
     Hue[0.03689422334799952, 1, 0.9489156907489237], 
     Hue[0.3108011262564271, 1, 0.5696599790295626], 
     Hue[0.5077663304919188, 1, 0.2969389270111894], 
     Hue[0.4044088252996428, 1, 0.4400493188158793], 
     Hue[0.5829586756836321, 1, 0.19282644905343246`], 
     Hue[0.322226848236343, 1, 0.5538397485958328], 
     Hue[0.02943312940619225, 1, 0.9592464362068107], 
     Hue[0.3975273118373725, 1, 0.4495775682251766], 
     Hue[0.596905478137967, 1, 0.17351549180896875`], 
     Hue[0.6454105656330505, 1, 0.10635460143116086`], 
     Hue[0.5923199533558348, 1, 0.17986467996884425`], 
     Hue[0.3746734228221847, 1, 0.4812214145538982], 
     Hue[0.043928337384023464`, 1, 0.939176148237506], 
     Hue[0.20912545723635922`, 1, 0.7104416745958103], 
     Hue[0.4342125271931002, 1, 0.3987826546557075], 
     Hue[0.2313972656518401, 1, 0.6796037860205291], 
     Hue[0.3268542639644974, 1, 0.547432557587619], 
     Hue[0.4556563623128164, 1, 0.3690911906437927], 
     Hue[0.4390878985062624, 1, 0.39203214052979063`], 
     Hue[0.5156355708977722, 1, 0.28604305568000765`], 
     Hue[0.649999055528591, 1, 0.10000130772964315`], 
     Hue[0.5971286665943378, 1, 0.17320646163860914`], 
     Hue[0.6036759810378309, 1, 0.16414094933223405`], 
     Hue[0.6180257405493282, 1, 0.14427205154708408`], 
     Hue[0.6499999932969623, 1, 0.10000000928112909`], 
     Hue[0.6499987268277645, 1, 0.1000017628538645], 
     Hue[0.645828986709081, 1, 0.10577524917204179`], 
     Hue[0.6482134889743377, 1, 0.10247363065091698`], 
     Hue[0.6448816369227308, 1, 0.10708696426083422`], 
     Hue[0.649975509028595, 1, 0.10003391057579149`], 
     Hue[0.6499992729776185, 1, 0.10000100664637435`], 
     Hue[0.6347783794036009, 1, 0.12107609005655262`], 
     Hue[0.5675390348219751, 1, 0.21417672101572674`], 
     Hue[0.6488954926527878, 1, 0.10152931786537074`], 
     Hue[0.6370994298566548, 1, 0.11786232789078564`], 
     Hue[0.6443239590020108, 1, 0.10785913368952357`], 
     Hue[0.04155834072464082, 1, 0.9424576820735743], 
     Hue[0.009474771661338033, 1, 0.9868810853919936], 
     Hue[0.004467268988803674, 1, 0.9938145506308872], 
     Hue[0.022088212565692822`, 1, 0.9694163210628869], 
     Hue[0.6487258778917904, 1, 0.10176416907290561`], 
     Hue[0.5979240640472641, 1, 0.17210514208840372`], 
     Hue[0.6499712480469302, 1, 0.10003981039655825`], 
     Hue[0.6427761593082032, 1, 0.11000224095787248`], 
     Hue[0.6456211694793101, 1, 0.10606299610557063`], 
     Hue[0.6326474334935711, 1, 0.12402663054736318`], 
     Hue[0.5708199470685535, 1, 0.20963391944354126`], 
     Hue[0.6063575850173591, 1, 0.16042795920673347`], 
     Hue[0.3844417568473057, 1, 0.46769602898065366`], 
     Hue[0.648667785580125, 1, 0.10184460458136543`], 
     Hue[0.184674147232528, 1, 0.7442973346011151], 
     Hue[0.12942245260902419`, 1, 0.8207996810028896], 
     Hue[0.6484570699759457, 1, 0.1021363646486907], 
     Hue[0.12955845579886072`, 1, 0.8206113688938852], 
     Hue[0.06003819740452432, 1, 0.9168701882091203], 
     Hue[0.118462710375427, 1, 0.8359747087109471], 
     Hue[0.03779967093100134, 1, 0.9476619940955366], 
     Hue[0.05780633329080531, 1, 0.9199604615973465], 
     Hue[0.6470888898871833, 1, 0.10403076784851555`], 
     Hue[0.07333500286576378, 1, 0.8984592268012501], 
     Hue[0.06889040827542581, 1, 0.9046132808494104], 
     Hue[0.01868022771103206, 1, 0.9741350693231864], 
     Hue[0.13950291882289012`, 1, 0.8068421123990752], 
     Hue[0.6481841123004977, 1, 0.10251430604546477`], 
     Hue[0.6499596100112259, 1, 0.10005592459984099`], 
     Hue[0.6063087564862858, 1, 0.16049556794206582`], 
     Hue[0.6206517480994662, 1, 0.1406360410930468], 
     Hue[0.6473762235597493, 1, 0.10363292122496255`], 
     Hue[0.6472511676796532, 1, 0.10380607552048021`], 
     Hue[0.04406253079800493, 1, 0.9389903419719932], 
     Hue[0.6206132711626215, 1, 0.14068931685175476`], 
     Hue[0.4405994030366784, 1, 0.3899392881030608], 
     Hue[0.05786211421966547, 1, 0.9198832264650786], 
     Hue[0.618270830809781, 1, 0.14393269580184184`], 
     Hue[0.042482351506751836`, 1, 0.9411782825291128], 
     Hue[0.13918838910544828`, 1, 0.8072776150847639], 
     Hue[0.26905063767598003`, 1, 0.6274683478332584], 
     Hue[0.2303741956861579, 1, 0.6810203444345506], 
     Hue[0.48040833698175356`, 1, 0.33481922571757206`], 
     Hue[0.6457969158907704, 1, 0.1058196549204718], 
     Hue[0.6342094599414793, 1, 0.12186382469641344`], 
     Hue[0.6460607481128854, 1, 0.10545434876677406`], 
     Hue[0.6499526196229324, 1, 0.10006560359901673`], 
     Hue[0.06333003050708108, 1, 0.9123122654517338], 
     Hue[0.649726922297457, 1, 0.10037810758813649`], 
     Hue[0.5962502216157243, 1, 0.17442277007053564`], 
     Hue[0.6402137035419406, 1, 0.11355025663423615`], 
     Hue[0.5719176745711743, 1, 0.20811398905529727`], 
     Hue[0.10746359275895068`, 1, 0.8512042561799145], 
     Hue[0.06009558546921567, 1, 0.9167907278118552], 
     Hue[0.6442531367767333, 1, 0.10795719523221542`], 
     Hue[0.03374975633330779, 1, 0.9532695681538815], 
     Hue[0.03921892413231187, 1, 0.9456968742783375], 
     Hue[0.009216347044223472, 1, 0.9872389040926137], 
     Hue[0.05273899033951568, 1, 0.9269767826068245], 
     Hue[0.6499218518999955, 1, 0.10010820506154475`], 
     Hue[0.05158410669515745, 1, 0.9285758522682436], 
     Hue[0.6494251206798614, 1, 0.10079598675096123`], 
     Hue[0.6447904285419719, 1, 0.1072132527880389], 
     Hue[0.640778164079348, 1, 0.11276869589013358`], 
     Hue[0.6487356695101961, 1, 0.10175061144742076`], 
     Hue[0.6498020481725953, 1, 0.10027408714563732`], 
     Hue[0.020025186176978793`, 1, 0.9722728191395679], 
     Hue[0.025491634684400077`, 1, 0.9647038904369846], 
     Hue[0.5998457584173371, 1, 0.16944433449907179`], 
     Hue[0.6495127023476075, 1, 0.10067471982638966`], 
     Hue[0.6492984310623836, 1, 0.10097140314439201`], 
     Hue[0.018915189787936937`, 1, 0.9738097372167026], 
     Hue[0.028102622190487203`, 1, 0.9610886769670177], 
     Hue[0.07364288343918068, 1, 0.898032930622673], 
     Hue[0.06706420222814657, 1, 0.9071418738379509], 
     Hue[0.6499211706692806, 1, 0.10010914830407308`], 
     Hue[0.6445571608926339, 1, 0.10753623876404535`], 
     Hue[0.060966991134431825`, 1, 0.9155841661215559], 
     Hue[0.025759341183150597`, 1, 0.964333219900253], 
     Hue[0.6494986016481691, 1, 0.10069424387176587`], 
     Hue[0.6484381379985806, 1, 0.10216257815581153`], 
     Hue[0.6484729270804462, 1, 0.10211440865784366`], 
     Hue[0.6412136620517335, 1, 0.11216569869759992`], 
     Hue[0.6422230086785912, 1, 0.11076814182964312`], 
     Hue[0.046805087355891395`, 1, 0.9351929559687657], 
     Hue[0.09864811270179208, 1, 0.8634103054898263], 
     Hue[0.054501041125472494`, 1, 0.924537019980115], 
     Hue[0.041520378597057594`, 1, 0.9425102450194588], 
     Hue[0.09926628380934543, 1, 0.8625543762639833], 
     Hue[0.6423043849432353, 1, 0.11065546700167422`], 
     Hue[0.6455272861029625, 1, 0.1061929884728212], 
     Hue[0.06229676973816811, 1, 0.9137429342086902], 
     Hue[0.6474093076492796, 1, 0.10358711248561293`], 
     Hue[0.6405221177612069, 1, 0.11312322156140575`], 
     Hue[0.6491622444811391, 1, 0.10115996917996127`], 
     Hue[0.6492633217317669, 1, 0.1010200160637074], 
     Hue[0.6418045339292079, 1, 0.11134756840571212`], 
     Hue[0.6459502293923701, 1, 0.10560737468748753`], 
     Hue[0.07357951720376499, 1, 0.8981206684870946], 
     Hue[0.54247725574747, 1, 0.2488776458881185], 
     Hue[0.016061592170358407`, 1, 0.9777608723795037], 
     Hue[0.06099795509912287, 1, 0.915541292939676], 
     Hue[0.6499663548133474, 1, 0.10004658564305739`], 
     Hue[0.6499829521449216, 1, 0.10002360472241628`], 
     Hue[0.044717880895353, 1, 0.9380829341448957], 
     Hue[0.023817360629775575`, 1, 0.96702211605108], 
     Hue[0.5761356864965637, 1, 0.20227366485091192`], 
     Hue[0.6499783388042952, 1, 0.10002999242482198`], 
     Hue[0.07546597717883696, 1, 0.8955086469831488], 
     Hue[0.6499604575051915, 1, 0.10005475114665802`], 
     Hue[0.6452749299036067, 1, 0.10654240474885238`], 
     Hue[0.6401897422926235, 1, 0.11358343374867526`], 
     Hue[0.18455963884191612`, 1, 0.7444558846804239], 
     Hue[0.014395118982216015`, 1, 0.9800682967938548], 
     Hue[0.03154512986637259, 1, 0.9563221278773303], 
     Hue[0.02417717033757172, 1, 0.9665239179941315], 
     Hue[0.12412390646029214`, 1, 0.8281361295165186], 
     Hue[0.5984996234851034, 1, 0.17130821363601065`], 
     Hue[0.649143544477197, 1, 0.10118586149311183`], 
     Hue[0.10817627143842334`, 1, 0.8502174703160292], 
     Hue[0.6393013466750865, 1, 0.1148135199883417], 
     Hue[0.6499992785577187, 1, 0.10000099892008188`], 
     Hue[0.26944928900073295`, 1, 0.6269163690759082], 
     Hue[0.5498748452484237, 1, 0.2386348296560289], 
     Hue[0.6486940508417165, 1, 0.10180823729608485`], 
     Hue[0.08286331183439832, 1, 0.8852661836139101], 
     Hue[0.644208846340783, 1, 0.10801852045122351`]},
   VertexNormals->CompressedData["
1:eJzEu2VQVW/Yt42kIiIlGIRBSKqICIKcoiiCiaKCiNIl3Q0iICUlLY0gUtIt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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Lighting->"Neutral",
  Method->{"RotationControl" -> "Globe"},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563404777812903*^9, 3.566101323509776*^9, 
  3.614727853041666*^9},
 CellTags->{"Solar Array Example", "PR7.3", "PR7."},
 CellLabel->"During evaluation of In[268]:="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 7 topics"]], "Text",
 CellTags->"PR7."]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.4 Cellular Array Example", "Section",
 CellTags->{"7.4", "Cellular Array Example", "PR7.4", "PR7."}],

Cell["\<\
positions = Flatten[Table[{x,y},{x,2,4*2,.5},{y,-2*2-1/2,2*2-1/2,.5}],1]//N;\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[269]:="],

Cell["\<\
gridpositions = Sort[Join[positions,Map[(#+{.25,.25})&,positions]]];\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[270]:="],

Cell[CellGroupData[{

Cell["Length[gridpositions]", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[271]:="],

Cell[BoxData["442"], "Output",
 CellChangeTimes->{3.563404810937457*^9, 3.566101371302011*^9, 
  3.614727853200574*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"Out[271]="]
}, Open  ]],

Cell["\<\
ListPlot[gridpositions,PlotRange->{{0,9},{-5,5}}, AspectRatio->1];\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[272]:="],

Cell["\<\
randomgridpositions = \
Map[(#+{Random[Real,{-.05,.05}],Random[Real,{-.05,.05}]})&,gridpositions];\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[273]:="],

Cell["\<\
ListPlot[randomgridpositions,PlotRange->{{0,9},{-5,5}}, AspectRatio->1];\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[274]:="],

Cell["\<\
randomclonedata = 
Map[
\tFunction[{pos},
\t{pos,1,Sort[Map[(Sqrt[Dot[#,#]]&[#-pos])&,randomgridpositions]][[2]]}
\t]
,
\trandomgridpositions
];\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[275]:="],

Cell[CellGroupData[{

Cell["\<\
rodlens = 
\tRemoveSurface[RodLens[1,1,FresnelReflections->True,ComponentMedium->1.48],
\t{1,5}]\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[276]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"RemoveSurface", "[", 
     RowBox[{
      RowBox[{"RodLens", "[", 
       RowBox[{"1", ",", "1", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FresnelReflections", "\[Rule]", "True"}], ",", 
          RowBox[{"ComponentMedium", "\[Rule]", "1.48`"}]}], "}"}]}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5634048118612003`*^9, 3.56610137374157*^9, 
  3.614727853982873*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"Out[276]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[
\t{rodlens,
\tMove[ClearBoundary[9,10],{.75,-.4}]},
\tPlotType->TopView, ShowLabels->False,
\tCreateClones -> randomclonedata];\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[277]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}], 
      LineBox[{{1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}], 
      LineBox[{{1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}], 
      LineBox[{{1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}], 
      LineBox[{{1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}], 
      LineBox[{{1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}], 
      LineBox[{{1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}], 
      LineBox[{{1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}], 
      LineBox[{{1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}], 
      LineBox[{{1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}], 
      LineBox[{{1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}], 
      LineBox[{{1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}], 
      LineBox[{{1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}], 
      LineBox[{{1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}], 
      LineBox[{{1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}], 
      LineBox[{{1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}], 
      LineBox[{{2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}], 
      LineBox[{{2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}], 
      LineBox[{{2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}], 
      LineBox[{{2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}], 
      LineBox[{{2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}], 
      LineBox[{{2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}], 
      LineBox[{{2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}], 
      LineBox[{{2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}], 
      LineBox[{{2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}], 
      LineBox[{{2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}], 
      LineBox[{{2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}], 
      LineBox[{{2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}], 
      LineBox[{{2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}], 
      LineBox[{{2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}], 
      LineBox[{{2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}], 
      LineBox[{{1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}], 
      LineBox[{{1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}], 
      LineBox[{{1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}], 
      LineBox[{{2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}], 
      LineBox[{{2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}], 
      LineBox[{{2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}], 
      LineBox[{{2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}], 
      LineBox[{{2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}], 
      LineBox[{{2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}], 
      LineBox[{{2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}], 
      LineBox[{{2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}], 
      LineBox[{{2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}], 
      LineBox[{{2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}], 
      LineBox[{{2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}], 
      LineBox[{{2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.939389508723094, -3.8456018485870693`}, {
       1.939389508723094, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145356}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}], 
      LineBox[{{1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}], 
      LineBox[{{1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}], 
      LineBox[{{1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}], 
      LineBox[{{1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}], 
      LineBox[{{1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}], 
      LineBox[{{1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}], 
      LineBox[{{1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}], 
      LineBox[{{1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}], 
      LineBox[{{1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}], 
      LineBox[{{1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}], 
      LineBox[{{1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}], 
      LineBox[{{1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}], 
      LineBox[{{1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}], 
      LineBox[{{1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}], 
      LineBox[{{1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}], 
      LineBox[{{2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}], 
      LineBox[{{2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}], 
      LineBox[{{2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}], 
      LineBox[{{2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}], 
      LineBox[{{2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}], 
      LineBox[{{2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}], 
      LineBox[{{2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}], 
      LineBox[{{2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}], 
      LineBox[{{2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}], 
      LineBox[{{2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}], 
      LineBox[{{2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}], 
      LineBox[{{2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}], 
      LineBox[{{2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}], 
      LineBox[{{2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}], 
      LineBox[{{2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}], 
      LineBox[{{1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}], 
      LineBox[{{1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}], 
      LineBox[{{1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}], 
      LineBox[{{2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}], 
      LineBox[{{2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}], 
      LineBox[{{2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}], 
      LineBox[{{2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}], 
      LineBox[{{2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}], 
      LineBox[{{2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}], 
      LineBox[{{2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}], 
      LineBox[{{2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}], 
      LineBox[{{2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}], 
      LineBox[{{2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}], 
      LineBox[{{2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}], 
      LineBox[{{2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}], 
      LineBox[{{1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}], 
      LineBox[{{1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}], 
      LineBox[{{1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}], 
      LineBox[{{1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}], 
      LineBox[{{1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}], 
      LineBox[{{1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}], 
      LineBox[{{1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}], 
      LineBox[{{1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}], 
      LineBox[{{1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}], 
      LineBox[{{1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}], 
      LineBox[{{1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}], 
      LineBox[{{1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}], 
      LineBox[{{1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}], 
      LineBox[{{1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}], 
      LineBox[{{1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}], 
      LineBox[{{2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}], 
      LineBox[{{2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}], 
      LineBox[{{2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}], 
      LineBox[{{2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}], 
      LineBox[{{2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}], 
      LineBox[{{2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}], 
      LineBox[{{2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}], 
      LineBox[{{2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}], 
      LineBox[{{2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}], 
      LineBox[{{2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}], 
      LineBox[{{2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}], 
      LineBox[{{1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}], 
      LineBox[{{1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}], 
      LineBox[{{1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}], 
      LineBox[{{1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}], 
      LineBox[{{1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}], 
      LineBox[{{1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}], 
      LineBox[{{1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}], 
      LineBox[{{1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}], 
      LineBox[{{1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}], 
      LineBox[{{1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}], 
      LineBox[{{1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}], 
      LineBox[{{2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}], 
      LineBox[{{2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}], 
      LineBox[{{2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}], 
      LineBox[{{2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}], 
      LineBox[{{2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}], 
      LineBox[{{2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}], 
      LineBox[{{2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}], 
      LineBox[{{2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}], 
      LineBox[{{1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}], 
      LineBox[{{1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}], 
      LineBox[{{1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}], 
      LineBox[{{1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}], 
      LineBox[{{1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}], 
      LineBox[{{1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}], 
      LineBox[{{1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}], 
      LineBox[{{1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}], 
      LineBox[{{1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}], 
      LineBox[{{1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}], 
      LineBox[{{1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}], 
      LineBox[{{1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}], 
      LineBox[{{1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}], 
      LineBox[{{1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}], 
      LineBox[{{1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}], 
      LineBox[{{2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}], 
      LineBox[{{2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}], 
      LineBox[{{2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}], 
      LineBox[{{2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}], 
      LineBox[{{2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}], 
      LineBox[{{2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}], 
      LineBox[{{2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}], 
      LineBox[{{2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}], 
      LineBox[{{2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}], 
      LineBox[{{2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}], 
      LineBox[{{2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}], 
      LineBox[{{2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}], 
      LineBox[{{2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}], 
      LineBox[{{2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}], 
      LineBox[{{2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}], 
      LineBox[{{1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}], 
      LineBox[{{1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}], 
      LineBox[{{1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}], 
      LineBox[{{2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}], 
      LineBox[{{2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}], 
      LineBox[{{2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}], 
      LineBox[{{2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}], 
      LineBox[{{2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}], 
      LineBox[{{2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}], 
      LineBox[{{2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}], 
      LineBox[{{2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}], 
      LineBox[{{2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}], 
      LineBox[{{2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}], 
      LineBox[{{2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}], 
      LineBox[{{2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}], 
      LineBox[{{1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}], 
      LineBox[{{1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}], 
      LineBox[{{1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}], 
      LineBox[{{1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}], 
      LineBox[{{1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}], 
      LineBox[{{1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}], 
      LineBox[{{1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}], 
      LineBox[{{1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}], 
      LineBox[{{1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}], 
      LineBox[{{1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}], 
      LineBox[{{1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}], 
      LineBox[{{1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}], 
      LineBox[{{1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}], 
      LineBox[{{1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}], 
      LineBox[{{1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}], 
      LineBox[{{2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}], 
      LineBox[{{2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}], 
      LineBox[{{2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}], 
      LineBox[{{2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}], 
      LineBox[{{2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}], 
      LineBox[{{2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}], 
      LineBox[{{2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}], 
      LineBox[{{2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}], 
      LineBox[{{2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}], 
      LineBox[{{2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}], 
      LineBox[{{2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}], 
      LineBox[{{2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}], 
      LineBox[{{2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}], 
      LineBox[{{2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}], 
      LineBox[{{2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}], 
      LineBox[{{1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}], 
      LineBox[{{1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}], 
      LineBox[{{1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}], 
      LineBox[{{2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}], 
      LineBox[{{2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}], 
      LineBox[{{2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}], 
      LineBox[{{2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}], 
      LineBox[{{2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}], 
      LineBox[{{2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}], 
      LineBox[{{2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}], 
      LineBox[{{2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}], 
      LineBox[{{2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}], 
      LineBox[{{2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}], 
      LineBox[{{2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}], 
      LineBox[{{2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.0236927843385946`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}], 
      LineBox[{{1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}], 
      LineBox[{{1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}], 
      LineBox[{{1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}], 
      LineBox[{{1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}], 
      LineBox[{{1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}], 
      LineBox[{{1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}], 
      LineBox[{{1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}], 
      LineBox[{{1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}], 
      LineBox[{{1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}], 
      LineBox[{{1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}], 
      LineBox[{{1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}], 
      LineBox[{{1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}], 
      LineBox[{{1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}], 
      LineBox[{{1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}], 
      LineBox[{{1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}], 
      LineBox[{{2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}], 
      LineBox[{{2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}], 
      LineBox[{{2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}], 
      LineBox[{{2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}], 
      LineBox[{{2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}], 
      LineBox[{{2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}], 
      LineBox[{{2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}], 
      LineBox[{{2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}], 
      LineBox[{{2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}], 
      LineBox[{{2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}], 
      LineBox[{{2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}], 
      LineBox[{{2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}], 
      LineBox[{{2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}], 
      LineBox[{{2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}], 
      LineBox[{{2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}], 
      LineBox[{{1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}], 
      LineBox[{{1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}], 
      LineBox[{{1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}], 
      LineBox[{{2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}], 
      LineBox[{{2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}], 
      LineBox[{{2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}], 
      LineBox[{{2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}], 
      LineBox[{{2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}], 
      LineBox[{{2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}], 
      LineBox[{{2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}], 
      LineBox[{{2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}], 
      LineBox[{{2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}], 
      LineBox[{{2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}], 
      LineBox[{{2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}], 
      LineBox[{{2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}], 
      LineBox[{{1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}], 
      LineBox[{{1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}], 
      LineBox[{{1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}], 
      LineBox[{{1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}], 
      LineBox[{{1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}], 
      LineBox[{{1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}], 
      LineBox[{{1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}], 
      LineBox[{{1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}], 
      LineBox[{{1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}], 
      LineBox[{{1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}], 
      LineBox[{{1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}], 
      LineBox[{{1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}], 
      LineBox[{{1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}], 
      LineBox[{{1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}], 
      LineBox[{{1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}], 
      LineBox[{{2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}], 
      LineBox[{{2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}], 
      LineBox[{{2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}], 
      LineBox[{{2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}], 
      LineBox[{{2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}], 
      LineBox[{{2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}], 
      LineBox[{{2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}], 
      LineBox[{{2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}], 
      LineBox[{{2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}], 
      LineBox[{{2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}], 
      LineBox[{{2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}], 
      LineBox[{{2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}], 
      LineBox[{{2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}], 
      LineBox[{{2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}], 
      LineBox[{{2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}], 
      LineBox[{{1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}], 
      LineBox[{{1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}], 
      LineBox[{{1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}], 
      LineBox[{{2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}], 
      LineBox[{{2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}], 
      LineBox[{{2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}], 
      LineBox[{{2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}], 
      LineBox[{{2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}], 
      LineBox[{{2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}], 
      LineBox[{{2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}], 
      LineBox[{{2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}], 
      LineBox[{{2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}], 
      LineBox[{{2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}], 
      LineBox[{{2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}], 
      LineBox[{{2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845168}, {
       1.8688159381993599`, -0.8505848171753346}, {
       1.8688159381993599`, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.86881593819936, -1.1832181088120635`}, {
       1.86881593819936, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}], 
      LineBox[{{1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}], 
      LineBox[{{1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}], 
      LineBox[{{1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}], 
      LineBox[{{1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}], 
      LineBox[{{1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}], 
      LineBox[{{1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}], 
      LineBox[{{1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}], 
      LineBox[{{1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}], 
      LineBox[{{1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}], 
      LineBox[{{1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}], 
      LineBox[{{1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}], 
      LineBox[{{1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}], 
      LineBox[{{1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}], 
      LineBox[{{1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}], 
      LineBox[{{1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}], 
      LineBox[{{2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}], 
      LineBox[{{2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}], 
      LineBox[{{2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}], 
      LineBox[{{2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}], 
      LineBox[{{2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}], 
      LineBox[{{2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}], 
      LineBox[{{2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}], 
      LineBox[{{2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}], 
      LineBox[{{2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}], 
      LineBox[{{2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}], 
      LineBox[{{2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}], 
      LineBox[{{1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}], 
      LineBox[{{1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}], 
      LineBox[{{1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}], 
      LineBox[{{1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}], 
      LineBox[{{1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}], 
      LineBox[{{1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}], 
      LineBox[{{1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}], 
      LineBox[{{1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}], 
      LineBox[{{1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}], 
      LineBox[{{1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}], 
      LineBox[{{1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}], 
      LineBox[{{2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}], 
      LineBox[{{2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}], 
      LineBox[{{2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}], 
      LineBox[{{2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}], 
      LineBox[{{2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}], 
      LineBox[{{2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}], 
      LineBox[{{2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}], 
      LineBox[{{2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667408}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}], 
      LineBox[{{1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}], 
      LineBox[{{1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}], 
      LineBox[{{1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}], 
      LineBox[{{1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}], 
      LineBox[{{1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}], 
      LineBox[{{1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}], 
      LineBox[{{1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}], 
      LineBox[{{1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}], 
      LineBox[{{1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}], 
      LineBox[{{1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}], 
      LineBox[{{1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}], 
      LineBox[{{1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}], 
      LineBox[{{1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}], 
      LineBox[{{1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}], 
      LineBox[{{1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}], 
      LineBox[{{2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}], 
      LineBox[{{2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}], 
      LineBox[{{2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}], 
      LineBox[{{2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}], 
      LineBox[{{2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}], 
      LineBox[{{2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}], 
      LineBox[{{2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}], 
      LineBox[{{2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}], 
      LineBox[{{2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}], 
      LineBox[{{2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}], 
      LineBox[{{2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}], 
      LineBox[{{2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}], 
      LineBox[{{2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}], 
      LineBox[{{2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}], 
      LineBox[{{2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}], 
      LineBox[{{1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}], 
      LineBox[{{1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}], 
      LineBox[{{1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}], 
      LineBox[{{2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}], 
      LineBox[{{2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}], 
      LineBox[{{2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}], 
      LineBox[{{2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}], 
      LineBox[{{2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}], 
      LineBox[{{2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}], 
      LineBox[{{2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}], 
      LineBox[{{2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}], 
      LineBox[{{2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}], 
      LineBox[{{2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}], 
      LineBox[{{2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}], 
      LineBox[{{2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {1.7845464039473522`, 
       0.0620762328448697}, {1.8620391706844055`, 0.1456745652424888}, {
       1.8620391706844055`, 0.1456745652424888}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036867`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844057`, -0.18871876434798784`}, {
       1.8620391706844057`, -0.18871876434798784`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8620391706844057`, 0.14567456524248884`}, {
       1.973183833623286, 0.17098610364750924`}, {2.0551012495386827`, 
       0.1456745652424888}, {2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.02152209955274947}, {
       2.1516322889658213`, -0.02152209955274947}, {2.117980392763994, 
       0.08738777124989006}, {2.0551012495386827`, 0.1456745652424888}, {
       1.973183833623286, 0.17098610364750924`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}], 
      LineBox[{{1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}], 
      LineBox[{{1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}], 
      LineBox[{{1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}], 
      LineBox[{{1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}], 
      LineBox[{{1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}], 
      LineBox[{{1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}], 
      LineBox[{{1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}], 
      LineBox[{{1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, 0.06207623284486967}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}], 
      LineBox[{{1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, 0.06207623284486967}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}], 
      LineBox[{{1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, 0.06207623284486967}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}], 
      LineBox[{{1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, 0.06207623284486967}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}], 
      LineBox[{{1.7845464039473522`, 0.0620762328448697}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.7845464039473522`, 0.0620762328448697}, {
       1.7845464039473522`, 0.0620762328448697}}], 
      LineBox[{{1.7845464039473522`, 0.0620762328448697}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.7845464039473522`, 0.0620762328448697}, {
       1.7845464039473522`, 0.0620762328448697}}], 
      LineBox[{{1.7845464039473522`, 0.0620762328448697}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.7845464039473522`, 0.0620762328448697}, {
       1.7845464039473522`, 0.0620762328448697}}], 
      LineBox[{{1.7845464039473522`, 0.0620762328448697}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.7845464039473522`, 0.0620762328448697}, {
       1.7845464039473522`, 0.0620762328448697}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}], 
      LineBox[{{2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}], 
      LineBox[{{2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}], 
      LineBox[{{2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}], 
      LineBox[{{2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}], 
      LineBox[{{2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}], 
      LineBox[{{2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}], 
      LineBox[{{2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}], 
      LineBox[{{2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}], 
      LineBox[{{2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}], 
      LineBox[{{2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}], 
      LineBox[{{2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}], 
      LineBox[{{1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}], 
      LineBox[{{1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}], 
      LineBox[{{1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}], 
      LineBox[{{1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8620391706844057`, 0.14567456524248884`}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}}], 
      LineBox[{{1.8620391706844057`, 0.14567456524248884`}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}}], 
      LineBox[{{1.8620391706844057`, 0.14567456524248884`}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}}], 
      LineBox[{{1.8620391706844057`, 0.14567456524248884`}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}}], 
      LineBox[{{1.973183833623286, 0.17098610364750924`}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}}], 
      LineBox[{{1.973183833623286, 0.17098610364750924`}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}}], 
      LineBox[{{1.973183833623286, 0.17098610364750924`}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}}], 
      LineBox[{{1.973183833623286, 0.17098610364750924`}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}}], 
      LineBox[{{2.0551012495386827`, 0.1456745652424888}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}}], 
      LineBox[{{2.0551012495386827`, 0.1456745652424888}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}}], 
      LineBox[{{2.0551012495386827`, 0.1456745652424888}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}}], 
      LineBox[{{2.0551012495386827`, 0.1456745652424888}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}}], 
      LineBox[{{2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}], 
      LineBox[{{2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}], 
      LineBox[{{2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}], 
      LineBox[{{2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.922378633863552, 
       0.4576864744029721}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.0518578650457386`, 0.3376636991690015}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}, {2.0518578650457386`, 0.3376636991690015}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.98256268345552, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1029307826394557`, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}], 
      LineBox[{{1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}], 
      LineBox[{{1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}], 
      LineBox[{{1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}], 
      LineBox[{{1.934248394663034, 0.40556555855370546`}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.40556555855370546`}, {1.934248394663034, 
       0.40556555855370546`}}], 
      LineBox[{{1.934248394663034, 0.40556555855370546`}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.40556555855370546`}, {1.934248394663034, 
       0.40556555855370546`}}], 
      LineBox[{{1.934248394663034, 0.40556555855370546`}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.40556555855370546`}, {1.934248394663034, 
       0.40556555855370546`}}], 
      LineBox[{{1.934248394663034, 0.40556555855370546`}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.40556555855370546`}, {1.934248394663034, 
       0.40556555855370546`}}], 
      LineBox[{{1.922378633863552, 0.4576864744029721}, {1.934248394663034, 
       0.5098073902522388}, {1.934248394663034, 0.5098073902522388}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}}], 
      LineBox[{{1.922378633863552, 0.4576864744029721}, {1.934248394663034, 
       0.5098073902522388}, {1.934248394663034, 0.5098073902522388}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}}], 
      LineBox[{{1.922378633863552, 0.4576864744029721}, {1.934248394663034, 
       0.5098073902522388}, {1.934248394663034, 0.5098073902522388}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}}], 
      LineBox[{{1.922378633863552, 0.4576864744029721}, {1.934248394663034, 
       0.5098073902522388}, {1.934248394663034, 0.5098073902522388}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}}], 
      LineBox[{{1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}}], 
      LineBox[{{1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}}], 
      LineBox[{{1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}}], 
      LineBox[{{1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}], 
      LineBox[{{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}], 
      LineBox[{{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}], 
      LineBox[{{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}], 
      LineBox[{{2.1421339394336907`, 0.38978461501826817`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1421339394336907`, 0.38978461501826817`}}], 
      LineBox[{{2.1421339394336907`, 0.38978461501826817`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1421339394336907`, 0.38978461501826817`}}], 
      LineBox[{{2.1421339394336907`, 0.38978461501826817`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1421339394336907`, 0.38978461501826817`}}], 
      LineBox[{{2.1421339394336907`, 0.38978461501826817`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1421339394336907`, 0.38978461501826817`}}], 
      LineBox[{{2.1029307826394557`, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}}], 
      LineBox[{{2.1029307826394557`, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}}], 
      LineBox[{{2.1029307826394557`, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}}], 
      LineBox[{{2.1029307826394557`, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}}], 
      LineBox[{{2.0518578650457386`, 0.3376636991690015}, {1.98256268345552, 
       0.35344464270443887`}, {1.98256268345552, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}}], 
      LineBox[{{2.0518578650457386`, 0.3376636991690015}, {1.98256268345552, 
       0.35344464270443887`}, {1.98256268345552, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}}], 
      LineBox[{{2.0518578650457386`, 0.3376636991690015}, {1.98256268345552, 
       0.35344464270443887`}, {1.98256268345552, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}}], 
      LineBox[{{2.0518578650457386`, 0.3376636991690015}, {1.98256268345552, 
       0.35344464270443887`}, {1.98256268345552, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.98256268345552, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.0518578650457386`, 0.5777092496369427}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}}], 
      LineBox[{{1.98256268345552, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.0518578650457386`, 0.5777092496369427}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}}], 
      LineBox[{{1.98256268345552, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.0518578650457386`, 0.5777092496369427}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}}], 
      LineBox[{{1.98256268345552, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.0518578650457386`, 0.5777092496369427}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}}], 
      LineBox[{{2.0518578650457386`, 0.5777092496369427}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}}], 
      LineBox[{{2.0518578650457386`, 0.5777092496369427}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}}], 
      LineBox[{{2.0518578650457386`, 0.5777092496369427}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}}], 
      LineBox[{{2.0518578650457386`, 0.5777092496369427}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}}], 
      LineBox[{{2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}], 
      LineBox[{{2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}], 
      LineBox[{{2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}], 
      LineBox[{{2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}], 
      LineBox[{{2.1421339394336907`, 0.5255883337876761}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1421339394336907`, 0.5255883337876761}}], 
      LineBox[{{2.1421339394336907`, 0.5255883337876761}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1421339394336907`, 0.5255883337876761}}], 
      LineBox[{{2.1421339394336907`, 0.5255883337876761}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1421339394336907`, 0.5255883337876761}}], 
      LineBox[{{2.1421339394336907`, 0.5255883337876761}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1421339394336907`, 0.5255883337876761}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.839375011674674, 0.927711313596769}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.076039862566275, 
       0.8545845993868387}, {2.004383511408823, 0.8324436118566818}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9071609500300508`, 1.1470914562265597`}, {2.004383511408823,
        1.1692324437567168`}, {2.076039862566275, 1.1470914562265597`}, {
       2.1310426958109914`, 1.0961057295467864`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 1.0961057295467864`}, {2.076039862566275, 
       1.1470914562265597`}, {2.004383511408823, 1.1692324437567168`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}], 
      LineBox[{{1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}], 
      LineBox[{{1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}], 
      LineBox[{{1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}], 
      LineBox[{{1.839375011674674, 0.9277113135967691}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 0.9277113135967691}, {1.839375011674674, 
       0.9277113135967691}}], 
      LineBox[{{1.839375011674674, 0.9277113135967691}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 0.9277113135967691}, {1.839375011674674, 
       0.9277113135967691}}], 
      LineBox[{{1.839375011674674, 0.9277113135967691}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 0.9277113135967691}, {1.839375011674674, 
       0.9277113135967691}}], 
      LineBox[{{1.839375011674674, 0.9277113135967691}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 0.9277113135967691}, {1.839375011674674, 
       0.9277113135967691}}], 
      LineBox[{{1.8227214937619387`, 1.0008380278066993`}, {1.839375011674674,
        1.0739647420166296`}, {1.839375011674674, 1.0739647420166296`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}}], 
      LineBox[{{1.8227214937619387`, 1.0008380278066993`}, {1.839375011674674,
        1.0739647420166296`}, {1.839375011674674, 1.0739647420166296`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}}], 
      LineBox[{{1.8227214937619387`, 1.0008380278066993`}, {1.839375011674674,
        1.0739647420166296`}, {1.839375011674674, 1.0739647420166296`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}}], 
      LineBox[{{1.8227214937619387`, 1.0008380278066993`}, {1.839375011674674,
        1.0739647420166296`}, {1.839375011674674, 1.0739647420166296`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}}], 
      LineBox[{{1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`,
        1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}}], 
      LineBox[{{1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`,
        1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}}], 
      LineBox[{{1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`,
        1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}}], 
      LineBox[{{1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`,
        1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}], 
      LineBox[{{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}], 
      LineBox[{{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}], 
      LineBox[{{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}], 
      LineBox[{{2.1310426958109914`, 0.9055703260666121}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}}], 
      LineBox[{{2.1310426958109914`, 0.9055703260666121}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}}], 
      LineBox[{{2.1310426958109914`, 0.9055703260666121}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}}], 
      LineBox[{{2.1310426958109914`, 0.9055703260666121}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}}], 
      LineBox[{{2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}], 
      LineBox[{{2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}], 
      LineBox[{{2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}], 
      LineBox[{{2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}], 
      LineBox[{{2.004383511408823, 0.8324436118566818}, {1.9071609500300508`, 
       0.8545845993868387}, {1.9071609500300508`, 0.8545845993868387}, {
       2.004383511408823, 0.8324436118566818}, {2.004383511408823, 
       0.8324436118566818}}], 
      LineBox[{{2.004383511408823, 0.8324436118566818}, {1.9071609500300508`, 
       0.8545845993868387}, {1.9071609500300508`, 0.8545845993868387}, {
       2.004383511408823, 0.8324436118566818}, {2.004383511408823, 
       0.8324436118566818}}], 
      LineBox[{{2.004383511408823, 0.8324436118566818}, {1.9071609500300508`, 
       0.8545845993868387}, {1.9071609500300508`, 0.8545845993868387}, {
       2.004383511408823, 0.8324436118566818}, {2.004383511408823, 
       0.8324436118566818}}], 
      LineBox[{{2.004383511408823, 0.8324436118566818}, {1.9071609500300508`, 
       0.8545845993868387}, {1.9071609500300508`, 0.8545845993868387}, {
       2.004383511408823, 0.8324436118566818}, {2.004383511408823, 
       0.8324436118566818}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9071609500300508`, 1.1470914562265597`}, {2.004383511408823,
        1.1692324437567168`}, {2.004383511408823, 1.1692324437567168`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}}], 
      LineBox[{{1.9071609500300508`, 1.1470914562265597`}, {2.004383511408823,
        1.1692324437567168`}, {2.004383511408823, 1.1692324437567168`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}}], 
      LineBox[{{1.9071609500300508`, 1.1470914562265597`}, {2.004383511408823,
        1.1692324437567168`}, {2.004383511408823, 1.1692324437567168`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}}], 
      LineBox[{{1.9071609500300508`, 1.1470914562265597`}, {2.004383511408823,
        1.1692324437567168`}, {2.004383511408823, 1.1692324437567168`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}}], 
      LineBox[{{2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}}], 
      LineBox[{{2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}}], 
      LineBox[{{2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}}], 
      LineBox[{{2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}}], 
      LineBox[{{2.076039862566275, 1.1470914562265597`}, {2.1310426958109914`,
        1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}}], 
      LineBox[{{2.076039862566275, 1.1470914562265597`}, {2.1310426958109914`,
        1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}}], 
      LineBox[{{2.076039862566275, 1.1470914562265597`}, {2.1310426958109914`,
        1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}}], 
      LineBox[{{2.076039862566275, 1.1470914562265597`}, {2.1310426958109914`,
        1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}}], 
      LineBox[{{2.1310426958109914`, 1.0961057295467864`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1310426958109914`, 1.0961057295467864`}}], 
      LineBox[{{2.1310426958109914`, 1.0961057295467864`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1310426958109914`, 1.0961057295467864`}}], 
      LineBox[{{2.1310426958109914`, 1.0961057295467864`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1310426958109914`, 1.0961057295467864`}}], 
      LineBox[{{2.1310426958109914`, 1.0961057295467864`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1310426958109914`, 1.0961057295467864`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9093839864924338`, 1.3763864165475082`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`,
        1.4322958648992508`}, {2.094571635134661, 1.3763864165475082`}, {
       2.0159953879179824`, 1.3521072608036129`}, {1.909383986492434, 
       1.3763864165475082`}, {1.909383986492434, 1.3763864165475082`}, {
       2.0159953879179824`, 1.3521072608036129`}, {2.094571635134661, 
       1.3763864165475082`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.909383986492434, 1.6971408329300592`}, {2.0159953879179824`,
        1.7214199886739545`}, {2.094571635134661, 1.6971408329300592`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.187165459455775, 
       1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.094571635134661, 
       1.6971408329300592`}, {2.0159953879179824`, 1.7214199886739545`}, {
       1.909383986492434, 1.6971408329300592`}, {1.909383986492434, 
       1.6971408329300592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9093839864924338`, 1.3763864165475082`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}}], 
      LineBox[{{1.9093839864924338`, 1.3763864165475082`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}}], 
      LineBox[{{1.9093839864924338`, 1.3763864165475082`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}}], 
      LineBox[{{1.9093839864924338`, 1.3763864165475082`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}}], 
      LineBox[{{1.8350519201230076`, 1.4565750206431458`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}}], 
      LineBox[{{1.8350519201230076`, 1.4565750206431458`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}}], 
      LineBox[{{1.8350519201230076`, 1.4565750206431458`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}}], 
      LineBox[{{1.8350519201230076`, 1.4565750206431458`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}}], 
      LineBox[{{1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}], 
      LineBox[{{1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}], 
      LineBox[{{1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}], 
      LineBox[{{1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}], 
      LineBox[{{1.8350519201230076`, 1.6169522288344216`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}}], 
      LineBox[{{1.8350519201230076`, 1.6169522288344216`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}}], 
      LineBox[{{1.8350519201230076`, 1.6169522288344216`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}}], 
      LineBox[{{1.8350519201230076`, 1.6169522288344216`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`,
        1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}}], 
      LineBox[{{2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`,
        1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}}], 
      LineBox[{{2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`,
        1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}}], 
      LineBox[{{2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`,
        1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}}], 
      LineBox[{{2.1548861243996527`, 1.4322958648992508`}, {2.094571635134661,
        1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}}], 
      LineBox[{{2.1548861243996527`, 1.4322958648992508`}, {2.094571635134661,
        1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}}], 
      LineBox[{{2.1548861243996527`, 1.4322958648992508`}, {2.094571635134661,
        1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}}], 
      LineBox[{{2.1548861243996527`, 1.4322958648992508`}, {2.094571635134661,
        1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}}], 
      LineBox[{{2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`,
        1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}], 
      LineBox[{{2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`,
        1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}], 
      LineBox[{{2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`,
        1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}], 
      LineBox[{{2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`,
        1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}], 
      LineBox[{{2.0159953879179824`, 1.3521072608036129`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}}], 
      LineBox[{{2.0159953879179824`, 1.3521072608036129`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}}], 
      LineBox[{{2.0159953879179824`, 1.3521072608036129`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}}], 
      LineBox[{{2.0159953879179824`, 1.3521072608036129`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.909383986492434, 1.6971408329300592`}, {2.0159953879179824`,
        1.7214199886739545`}, {2.0159953879179824`, 1.7214199886739545`}, {
       1.909383986492434, 1.6971408329300592`}, {1.909383986492434, 
       1.6971408329300592`}}], 
      LineBox[{{1.909383986492434, 1.6971408329300592`}, {2.0159953879179824`,
        1.7214199886739545`}, {2.0159953879179824`, 1.7214199886739545`}, {
       1.909383986492434, 1.6971408329300592`}, {1.909383986492434, 
       1.6971408329300592`}}], 
      LineBox[{{1.909383986492434, 1.6971408329300592`}, {2.0159953879179824`,
        1.7214199886739545`}, {2.0159953879179824`, 1.7214199886739545`}, {
       1.909383986492434, 1.6971408329300592`}, {1.909383986492434, 
       1.6971408329300592`}}], 
      LineBox[{{1.909383986492434, 1.6971408329300592`}, {2.0159953879179824`,
        1.7214199886739545`}, {2.0159953879179824`, 1.7214199886739545`}, {
       1.909383986492434, 1.6971408329300592`}, {1.909383986492434, 
       1.6971408329300592`}}], 
      LineBox[{{2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661,
        1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}}], 
      LineBox[{{2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661,
        1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}}], 
      LineBox[{{2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661,
        1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}}], 
      LineBox[{{2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661,
        1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}}], 
      LineBox[{{2.094571635134661, 1.6971408329300592`}, {2.1548861243996527`,
        1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}}], 
      LineBox[{{2.094571635134661, 1.6971408329300592`}, {2.1548861243996527`,
        1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}}], 
      LineBox[{{2.094571635134661, 1.6971408329300592`}, {2.1548861243996527`,
        1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}}], 
      LineBox[{{2.094571635134661, 1.6971408329300592`}, {2.1548861243996527`,
        1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}}], 
      LineBox[{{2.1548861243996527`, 1.6412313845783166`}, {2.187165459455775,
        1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}}], 
      LineBox[{{2.1548861243996527`, 1.6412313845783166`}, {2.187165459455775,
        1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}}], 
      LineBox[{{2.1548861243996527`, 1.6412313845783166`}, {2.187165459455775,
        1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}}], 
      LineBox[{{2.1548861243996527`, 1.6412313845783166`}, {2.187165459455775,
        1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`,
        1.9803982896703187`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.9472272080721864`, 
       2.164879500957241}, {1.9472272080721864`, 2.164879500957241}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.876220356740898, 
       2.0418920267659595`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994,
        1.9617794842046625`}, {2.089240910734764, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {1.9472272080721866`, 
       1.918904552574678}, {1.9472272080721866`, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.089240910734764, 
       1.918904552574678}, {2.135493908747994, 1.9617794842046625`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9472272080721866`, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.089240910734764, 2.164879500957241}, {
       2.135493908747994, 2.1220045693272565`}, {2.1602477620660525`, 
       2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 2.1220045693272565`}, {2.089240910734764, 
       2.164879500957241}, {2.028983631751061, 2.1834983064228974`}, {
       1.9472272080721866`, 2.164879500957241}, {1.9472272080721866`, 
       2.164879500957241}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`,
        1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}], 
      LineBox[{{1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`,
        1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}], 
      LineBox[{{1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`,
        1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}], 
      LineBox[{{1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`,
        1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}], 
      LineBox[{{1.8902246377113703`, 1.9803982896703187`}, {1.876220356740898,
        2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.8902246377113703`, 
       1.9803982896703187`}}], 
      LineBox[{{1.8902246377113703`, 1.9803982896703187`}, {1.876220356740898,
        2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.8902246377113703`, 
       1.9803982896703187`}}], 
      LineBox[{{1.8902246377113703`, 1.9803982896703187`}, {1.876220356740898,
        2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.8902246377113703`, 
       1.9803982896703187`}}], 
      LineBox[{{1.8902246377113703`, 1.9803982896703187`}, {1.876220356740898,
        2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.8902246377113703`, 
       1.9803982896703187`}}], 
      LineBox[{{1.876220356740898, 2.0418920267659595`}, {1.8902246377113703`,
        2.1033857638616005`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}}], 
      LineBox[{{1.876220356740898, 2.0418920267659595`}, {1.8902246377113703`,
        2.1033857638616005`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}}], 
      LineBox[{{1.876220356740898, 2.0418920267659595`}, {1.8902246377113703`,
        2.1033857638616005`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}}], 
      LineBox[{{1.876220356740898, 2.0418920267659595`}, {1.8902246377113703`,
        2.1033857638616005`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}}], 
      LineBox[{{1.8902246377113703`, 2.1033857638616005`}, {
       1.9472272080721864`, 2.164879500957241}, {1.9472272080721864`, 
       2.164879500957241}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}}], 
      LineBox[{{1.8902246377113703`, 2.1033857638616005`}, {
       1.9472272080721864`, 2.164879500957241}, {1.9472272080721864`, 
       2.164879500957241}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}}], 
      LineBox[{{1.8902246377113703`, 2.1033857638616005`}, {
       1.9472272080721864`, 2.164879500957241}, {1.9472272080721864`, 
       2.164879500957241}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}}], 
      LineBox[{{1.8902246377113703`, 2.1033857638616005`}, {
       1.9472272080721864`, 2.164879500957241}, {1.9472272080721864`, 
       2.164879500957241}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994,
        1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}}], 
      LineBox[{{2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994,
        1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}}], 
      LineBox[{{2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994,
        1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}}], 
      LineBox[{{2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994,
        1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}}], 
      LineBox[{{2.135493908747994, 1.9617794842046625`}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}}], 
      LineBox[{{2.135493908747994, 1.9617794842046625`}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}}], 
      LineBox[{{2.135493908747994, 1.9617794842046625`}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}}], 
      LineBox[{{2.135493908747994, 1.9617794842046625`}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}}], 
      LineBox[{{2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}], 
      LineBox[{{2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}], 
      LineBox[{{2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}], 
      LineBox[{{2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}], 
      LineBox[{{2.028983631751061, 1.9002857471090215`}, {1.9472272080721864`,
        1.918904552574678}, {1.9472272080721864`, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.028983631751061, 
       1.9002857471090215`}}], 
      LineBox[{{2.028983631751061, 1.9002857471090215`}, {1.9472272080721864`,
        1.918904552574678}, {1.9472272080721864`, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.028983631751061, 
       1.9002857471090215`}}], 
      LineBox[{{2.028983631751061, 1.9002857471090215`}, {1.9472272080721864`,
        1.918904552574678}, {1.9472272080721864`, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.028983631751061, 
       1.9002857471090215`}}], 
      LineBox[{{2.028983631751061, 1.9002857471090215`}, {1.9472272080721864`,
        1.918904552574678}, {1.9472272080721864`, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.028983631751061, 
       1.9002857471090215`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9472272080721866`, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.028983631751061, 2.1834983064228974`}, {
       1.9472272080721866`, 2.164879500957241}, {1.9472272080721866`, 
       2.164879500957241}}], 
      LineBox[{{1.9472272080721866`, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.028983631751061, 2.1834983064228974`}, {
       1.9472272080721866`, 2.164879500957241}, {1.9472272080721866`, 
       2.164879500957241}}], 
      LineBox[{{1.9472272080721866`, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.028983631751061, 2.1834983064228974`}, {
       1.9472272080721866`, 2.164879500957241}, {1.9472272080721866`, 
       2.164879500957241}}], 
      LineBox[{{1.9472272080721866`, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.028983631751061, 2.1834983064228974`}, {
       1.9472272080721866`, 2.164879500957241}, {1.9472272080721866`, 
       2.164879500957241}}], 
      LineBox[{{2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}}], 
      LineBox[{{2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}}], 
      LineBox[{{2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}}], 
      LineBox[{{2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}}], 
      LineBox[{{2.089240910734764, 2.164879500957241}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}}], 
      LineBox[{{2.089240910734764, 2.164879500957241}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}}], 
      LineBox[{{2.089240910734764, 2.164879500957241}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}}], 
      LineBox[{{2.089240910734764, 2.164879500957241}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}}], 
      LineBox[{{2.135493908747994, 2.1220045693272565`}, {2.1602477620660525`,
        2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}}], 
      LineBox[{{2.135493908747994, 2.1220045693272565`}, {2.1602477620660525`,
        2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}}], 
      LineBox[{{2.135493908747994, 2.1220045693272565`}, {2.1602477620660525`,
        2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}}], 
      LineBox[{{2.135493908747994, 2.1220045693272565`}, {2.1602477620660525`,
        2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`,
        2.3941263153558743`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`, 
       2.628267920438913}, {1.8760012596253415`, 2.628267920438913}, {
       1.8036541993202009`, 2.550220718744567}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`,
        2.370495524089671}, {2.0562435512562534`, 2.316079113661528}, {
       1.9797656491395037`, 2.2924483223953245`}, {1.8760012596253415`, 
       2.3160791136615275`}, {1.8760012596253415`, 2.3160791136615275`}, {
       1.9797656491395037`, 2.2924483223953245`}, {2.0562435512562534`, 
       2.316079113661528}, {2.1149473678626873`, 2.370495524089671}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`,
        2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {2.0562435512562534`, 
       2.628267920438913}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`,
        2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`,
        2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}], 
      LineBox[{{1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`,
        2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}], 
      LineBox[{{1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`,
        2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}], 
      LineBox[{{1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`,
        2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}], 
      LineBox[{{1.8036541993202009`, 2.3941263153558743`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}}], 
      LineBox[{{1.8036541993202009`, 2.3941263153558743`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}}], 
      LineBox[{{1.8036541993202009`, 2.3941263153558743`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}}], 
      LineBox[{{1.8036541993202009`, 2.3941263153558743`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}}], 
      LineBox[{{1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}], 
      LineBox[{{1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}], 
      LineBox[{{1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}], 
      LineBox[{{1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}], 
      LineBox[{{1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`,
        2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}}], 
      LineBox[{{1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`,
        2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}}], 
      LineBox[{{1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`,
        2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}}], 
      LineBox[{{1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`,
        2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`,
        2.370495524089671}, {2.1149473678626873`, 2.370495524089671}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}}], 
      LineBox[{{2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`,
        2.370495524089671}, {2.1149473678626873`, 2.370495524089671}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}}], 
      LineBox[{{2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`,
        2.370495524089671}, {2.1149473678626873`, 2.370495524089671}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}}], 
      LineBox[{{2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`,
        2.370495524089671}, {2.1149473678626873`, 2.370495524089671}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}}], 
      LineBox[{{2.1149473678626873`, 2.370495524089671}, {2.0562435512562534`,
        2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}}], 
      LineBox[{{2.1149473678626873`, 2.370495524089671}, {2.0562435512562534`,
        2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}}], 
      LineBox[{{2.1149473678626873`, 2.370495524089671}, {2.0562435512562534`,
        2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}}], 
      LineBox[{{2.1149473678626873`, 2.370495524089671}, {2.0562435512562534`,
        2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}}], 
      LineBox[{{2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`,
        2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}], 
      LineBox[{{2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`,
        2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}], 
      LineBox[{{2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`,
        2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}], 
      LineBox[{{2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`,
        2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}], 
      LineBox[{{1.9797656491395037`, 2.2924483223953245`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}}], 
      LineBox[{{1.9797656491395037`, 2.2924483223953245`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}}], 
      LineBox[{{1.9797656491395037`, 2.2924483223953245`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}}], 
      LineBox[{{1.9797656491395037`, 2.2924483223953245`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}], 
      LineBox[{{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}], 
      LineBox[{{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}], 
      LineBox[{{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}], 
      LineBox[{{1.9797656491395037`, 2.6518987117051167`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}}], 
      LineBox[{{1.9797656491395037`, 2.6518987117051167`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}}], 
      LineBox[{{1.9797656491395037`, 2.6518987117051167`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}}], 
      LineBox[{{1.9797656491395037`, 2.6518987117051167`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}}], 
      LineBox[{{2.0562435512562534`, 2.628267920438913}, {2.1149473678626873`,
        2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}}], 
      LineBox[{{2.0562435512562534`, 2.628267920438913}, {2.1149473678626873`,
        2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}}], 
      LineBox[{{2.0562435512562534`, 2.628267920438913}, {2.1149473678626873`,
        2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}}], 
      LineBox[{{2.0562435512562534`, 2.628267920438913}, {2.1149473678626873`,
        2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}}], 
      LineBox[{{2.1149473678626873`, 2.5738515100107704`}, {2.146364697071709,
        2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}}], 
      LineBox[{{2.1149473678626873`, 2.5738515100107704`}, {2.146364697071709,
        2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}}], 
      LineBox[{{2.1149473678626873`, 2.5738515100107704`}, {2.146364697071709,
        2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}}], 
      LineBox[{{2.1149473678626873`, 2.5738515100107704`}, {2.146364697071709,
        2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.0873594139807965`}, {1.962885544125747, 3.0873594139807965`}, {
       1.9105626923628816`, 3.030914105110803}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.093240401208077, 
       2.861578178500821}, {2.0379300414130537`, 2.844487914110729}, {
       1.962885544125747, 2.8615781785008205`}, {1.962885544125747, 
       2.8615781785008205`}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.962885544125747, 3.087359413980797}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.093240401208077, 3.0873594139807965`}, {
       2.1356961842248015`, 3.0480043695008945`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 3.0480043695008945`}, {2.093240401208077, 
       3.0873594139807965`}, {2.0379300414130537`, 3.1044496783708886`}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}], 
      LineBox[{{1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}], 
      LineBox[{{1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}], 
      LineBox[{{1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}], 
      LineBox[{{1.9105626923628816`, 2.9180234873708146`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}}], 
      LineBox[{{1.9105626923628816`, 2.9180234873708146`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}}], 
      LineBox[{{1.9105626923628816`, 2.9180234873708146`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}}], 
      LineBox[{{1.9105626923628816`, 2.9180234873708146`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}}], 
      LineBox[{{1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}], 
      LineBox[{{1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}], 
      LineBox[{{1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}], 
      LineBox[{{1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}], 
      LineBox[{{1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}}], 
      LineBox[{{1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}}], 
      LineBox[{{1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}}], 
      LineBox[{{1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}], 
      LineBox[{{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}], 
      LineBox[{{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}], 
      LineBox[{{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}], 
      LineBox[{{2.1356961842248015`, 2.900933222980723}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}}], 
      LineBox[{{2.1356961842248015`, 2.900933222980723}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}}], 
      LineBox[{{2.1356961842248015`, 2.900933222980723}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}}], 
      LineBox[{{2.1356961842248015`, 2.900933222980723}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}}], 
      LineBox[{{2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}], 
      LineBox[{{2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}], 
      LineBox[{{2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}], 
      LineBox[{{2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}], 
      LineBox[{{2.0379300414130537`, 2.844487914110729}, {1.962885544125747, 
       2.861578178500821}, {1.962885544125747, 2.861578178500821}, {
       2.0379300414130537`, 2.844487914110729}, {2.0379300414130537`, 
       2.844487914110729}}], 
      LineBox[{{2.0379300414130537`, 2.844487914110729}, {1.962885544125747, 
       2.861578178500821}, {1.962885544125747, 2.861578178500821}, {
       2.0379300414130537`, 2.844487914110729}, {2.0379300414130537`, 
       2.844487914110729}}], 
      LineBox[{{2.0379300414130537`, 2.844487914110729}, {1.962885544125747, 
       2.861578178500821}, {1.962885544125747, 2.861578178500821}, {
       2.0379300414130537`, 2.844487914110729}, {2.0379300414130537`, 
       2.844487914110729}}], 
      LineBox[{{2.0379300414130537`, 2.844487914110729}, {1.962885544125747, 
       2.861578178500821}, {1.962885544125747, 2.861578178500821}, {
       2.0379300414130537`, 2.844487914110729}, {2.0379300414130537`, 
       2.844487914110729}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.962885544125747, 3.087359413980797}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.0379300414130537`, 3.1044496783708886`}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}}], 
      LineBox[{{1.962885544125747, 3.087359413980797}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.0379300414130537`, 3.1044496783708886`}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}}], 
      LineBox[{{1.962885544125747, 3.087359413980797}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.0379300414130537`, 3.1044496783708886`}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}}], 
      LineBox[{{1.962885544125747, 3.087359413980797}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.0379300414130537`, 3.1044496783708886`}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}}], 
      LineBox[{{2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077,
        3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}}], 
      LineBox[{{2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077,
        3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}}], 
      LineBox[{{2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077,
        3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}}], 
      LineBox[{{2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077,
        3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}}], 
      LineBox[{{2.093240401208077, 3.0873594139807965`}, {2.1356961842248015`,
        3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}}], 
      LineBox[{{2.093240401208077, 3.0873594139807965`}, {2.1356961842248015`,
        3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}}], 
      LineBox[{{2.093240401208077, 3.0873594139807965`}, {2.1356961842248015`,
        3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}}], 
      LineBox[{{2.093240401208077, 3.0873594139807965`}, {2.1356961842248015`,
        3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}}], 
      LineBox[{{2.1356961842248015`, 3.0480043695008945`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1356961842248015`, 3.0480043695008945`}}], 
      LineBox[{{2.1356961842248015`, 3.0480043695008945`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1356961842248015`, 3.0480043695008945`}}], 
      LineBox[{{2.1356961842248015`, 3.0480043695008945`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1356961842248015`, 3.0480043695008945`}}], 
      LineBox[{{2.1356961842248015`, 3.0480043695008945`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1356961842248015`, 3.0480043695008945`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9302069051947932`, 3.3742196091609893`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.571043987737862}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}, {1.8693904382479098`, 3.571043987737862}, {
       1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`,
        3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.419963193105008}, {2.081722382467378, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.081722382467378, 
       3.3742196091609893`}, {2.1310700505998925`, 3.419963193105008}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9302069051947932`, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.081722382467378, 3.636652113930153}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.081722382467378, 
       3.636652113930153}, {2.017433442645454, 3.6565166561784253`}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9302069051947932`, 3.3742196091609893`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}}], 
      LineBox[{{1.9302069051947932`, 3.3742196091609893`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}}], 
      LineBox[{{1.9302069051947932`, 3.3742196091609893`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}}], 
      LineBox[{{1.9302069051947932`, 3.3742196091609893`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}}], 
      LineBox[{{1.8693904382479098`, 3.4398277353532802`}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}}], 
      LineBox[{{1.8693904382479098`, 3.4398277353532802`}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}}], 
      LineBox[{{1.8693904382479098`, 3.4398277353532802`}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}}], 
      LineBox[{{1.8693904382479098`, 3.4398277353532802`}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}}], 
      LineBox[{{1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`,
        3.571043987737862}, {1.8693904382479098`, 3.571043987737862}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}}], 
      LineBox[{{1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`,
        3.571043987737862}, {1.8693904382479098`, 3.571043987737862}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}}], 
      LineBox[{{1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`,
        3.571043987737862}, {1.8693904382479098`, 3.571043987737862}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}}], 
      LineBox[{{1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`,
        3.571043987737862}, {1.8693904382479098`, 3.571043987737862}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}}], 
      LineBox[{{1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`,
        3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}}], 
      LineBox[{{1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`,
        3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}}], 
      LineBox[{{1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`,
        3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}}], 
      LineBox[{{1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`,
        3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}}], 
      LineBox[{{2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}}], 
      LineBox[{{2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}}], 
      LineBox[{{2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}}], 
      LineBox[{{2.1310700505998925`, 3.419963193105008}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}}], 
      LineBox[{{2.1310700505998925`, 3.419963193105008}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}}], 
      LineBox[{{2.1310700505998925`, 3.419963193105008}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}}], 
      LineBox[{{2.1310700505998925`, 3.419963193105008}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}}], 
      LineBox[{{2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}], 
      LineBox[{{2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}], 
      LineBox[{{2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}], 
      LineBox[{{2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}], 
      LineBox[{{2.017433442645454, 3.354355066912717}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.017433442645454, 
       3.354355066912717}}], 
      LineBox[{{2.017433442645454, 3.354355066912717}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.017433442645454, 
       3.354355066912717}}], 
      LineBox[{{2.017433442645454, 3.354355066912717}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.017433442645454, 
       3.354355066912717}}], 
      LineBox[{{2.017433442645454, 3.354355066912717}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.017433442645454, 
       3.354355066912717}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{1.9302069051947932`, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.017433442645454, 3.6565166561784253`}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}}], 
      LineBox[{{1.9302069051947932`, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.017433442645454, 3.6565166561784253`}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}}], 
      LineBox[{{1.9302069051947932`, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.017433442645454, 3.6565166561784253`}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}}], 
      LineBox[{{1.9302069051947932`, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.017433442645454, 3.6565166561784253`}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}}], 
      LineBox[{{2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}}], 
      LineBox[{{2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}}], 
      LineBox[{{2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}}], 
      LineBox[{{2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}}], 
      LineBox[{{2.081722382467378, 3.636652113930153}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}}], 
      LineBox[{{2.081722382467378, 3.636652113930153}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}}], 
      LineBox[{{2.081722382467378, 3.636652113930153}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}}], 
      LineBox[{{2.081722382467378, 3.636652113930153}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}}], 
      LineBox[{{2.1310700505998925`, 3.5909085299861343`}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}}], 
      LineBox[{{2.1310700505998925`, 3.5909085299861343`}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}}], 
      LineBox[{{2.1310700505998925`, 3.5909085299861343`}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}}], 
      LineBox[{{2.1310700505998925`, 3.5909085299861343`}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.2144819406651965`, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}], 
      LineBox[{{2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}], 
      LineBox[{{2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}], 
      LineBox[{{2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}], 
      LineBox[{{2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}], 
      LineBox[{{2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}], 
      LineBox[{{2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}], 
      LineBox[{{2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}], 
      LineBox[{{2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}], 
      LineBox[{{2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}], 
      LineBox[{{2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}], 
      LineBox[{{2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}], 
      LineBox[{{2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}], 
      LineBox[{{2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}], 
      LineBox[{{2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}], 
      LineBox[{{2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}], 
      LineBox[{{2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}], 
      LineBox[{{2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}], 
      LineBox[{{2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}], 
      LineBox[{{2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}], 
      LineBox[{{2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}], 
      LineBox[{{2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}], 
      LineBox[{{2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}], 
      LineBox[{{2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}], 
      LineBox[{{2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}], 
      LineBox[{{2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}], 
      LineBox[{{2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}], 
      LineBox[{{2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}], 
      LineBox[{{2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}], 
      LineBox[{{2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}], 
      LineBox[{{2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}], 
      LineBox[{{2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}], 
      LineBox[{{2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}], 
      LineBox[{{2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}], 
      LineBox[{{2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}], 
      LineBox[{{2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}], 
      LineBox[{{2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}], 
      LineBox[{{2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}], 
      LineBox[{{2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}], 
      LineBox[{{2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}], 
      LineBox[{{2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}], 
      LineBox[{{2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}], 
      LineBox[{{2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}], 
      LineBox[{{2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}], 
      LineBox[{{2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}], 
      LineBox[{{2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}], 
      LineBox[{{2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}], 
      LineBox[{{2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}], 
      LineBox[{{2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}], 
      LineBox[{{2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}], 
      LineBox[{{2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}], 
      LineBox[{{2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}], 
      LineBox[{{2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}], 
      LineBox[{{2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}], 
      LineBox[{{2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}], 
      LineBox[{{2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}], 
      LineBox[{{2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}], 
      LineBox[{{2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}], 
      LineBox[{{2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}], 
      LineBox[{{2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}], 
      LineBox[{{2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}], 
      LineBox[{{2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}], 
      LineBox[{{2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}], 
      LineBox[{{2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}], 
      LineBox[{{2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}], 
      LineBox[{{2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}], 
      LineBox[{{2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}], 
      LineBox[{{2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}], 
      LineBox[{{2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}], 
      LineBox[{{2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}], 
      LineBox[{{2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}], 
      LineBox[{{2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}], 
      LineBox[{{2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}], 
      LineBox[{{2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}], 
      LineBox[{{2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}], 
      LineBox[{{2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}], 
      LineBox[{{2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}], 
      LineBox[{{2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}], 
      LineBox[{{2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}], 
      LineBox[{{2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}], 
      LineBox[{{2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}], 
      LineBox[{{2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}], 
      LineBox[{{2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}], 
      LineBox[{{2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}], 
      LineBox[{{2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}], 
      LineBox[{{2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}], 
      LineBox[{{2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}], 
      LineBox[{{2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}], 
      LineBox[{{2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}], 
      LineBox[{{2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}], 
      LineBox[{{2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}], 
      LineBox[{{2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}], 
      LineBox[{{2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}], 
      LineBox[{{2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}], 
      LineBox[{{2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}], 
      LineBox[{{2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}], 
      LineBox[{{2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}], 
      LineBox[{{2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}], 
      LineBox[{{2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}], 
      LineBox[{{2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}], 
      LineBox[{{2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}], 
      LineBox[{{2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}], 
      LineBox[{{2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}], 
      LineBox[{{2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}], 
      LineBox[{{2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}], 
      LineBox[{{2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}], 
      LineBox[{{2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}], 
      LineBox[{{2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}], 
      LineBox[{{2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}], 
      LineBox[{{2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}], 
      LineBox[{{2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}], 
      LineBox[{{2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}], 
      LineBox[{{2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}], 
      LineBox[{{2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}], 
      LineBox[{{2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}], 
      LineBox[{{2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}], 
      LineBox[{{2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}], 
      LineBox[{{2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}], 
      LineBox[{{2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}], 
      LineBox[{{2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}], 
      LineBox[{{2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}], 
      LineBox[{{2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}], 
      LineBox[{{2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}], 
      LineBox[{{2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}], 
      LineBox[{{2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}], 
      LineBox[{{2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}], 
      LineBox[{{2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}], 
      LineBox[{{2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}], 
      LineBox[{{2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}], 
      LineBox[{{2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}], 
      LineBox[{{2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}], 
      LineBox[{{2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}], 
      LineBox[{{2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}], 
      LineBox[{{2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}], 
      LineBox[{{2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}], 
      LineBox[{{2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}], 
      LineBox[{{2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}], 
      LineBox[{{2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}], 
      LineBox[{{2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}], 
      LineBox[{{2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}], 
      LineBox[{{2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}], 
      LineBox[{{2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}], 
      LineBox[{{2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}], 
      LineBox[{{2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}], 
      LineBox[{{2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}], 
      LineBox[{{2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}], 
      LineBox[{{2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}], 
      LineBox[{{2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}], 
      LineBox[{{2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}], 
      LineBox[{{2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}], 
      LineBox[{{2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}], 
      LineBox[{{2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}], 
      LineBox[{{2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}], 
      LineBox[{{2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}], 
      LineBox[{{2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}], 
      LineBox[{{2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}], 
      LineBox[{{2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}], 
      LineBox[{{2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}], 
      LineBox[{{2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}], 
      LineBox[{{2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}], 
      LineBox[{{2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}], 
      LineBox[{{2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}], 
      LineBox[{{2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}], 
      LineBox[{{2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}], 
      LineBox[{{2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}], 
      LineBox[{{2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}], 
      LineBox[{{2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}], 
      LineBox[{{2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}], 
      LineBox[{{2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}], 
      LineBox[{{2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}], 
      LineBox[{{2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}], 
      LineBox[{{2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}], 
      LineBox[{{2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}], 
      LineBox[{{2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}], 
      LineBox[{{2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}], 
      LineBox[{{2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}], 
      LineBox[{{2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}], 
      LineBox[{{2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}], 
      LineBox[{{2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}], 
      LineBox[{{2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}], 
      LineBox[{{2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}], 
      LineBox[{{2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}], 
      LineBox[{{2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}], 
      LineBox[{{2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}], 
      LineBox[{{2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}], 
      LineBox[{{2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}], 
      LineBox[{{2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}], 
      LineBox[{{2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}], 
      LineBox[{{2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}], 
      LineBox[{{2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}], 
      LineBox[{{2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}], 
      LineBox[{{2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}], 
      LineBox[{{2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}], 
      LineBox[{{2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}], 
      LineBox[{{2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}], 
      LineBox[{{2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}], 
      LineBox[{{2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}], 
      LineBox[{{2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}], 
      LineBox[{{2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}], 
      LineBox[{{2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}], 
      LineBox[{{2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}], 
      LineBox[{{2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}], 
      LineBox[{{2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}], 
      LineBox[{{2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}], 
      LineBox[{{2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}], 
      LineBox[{{2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}], 
      LineBox[{{2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}], 
      LineBox[{{2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}], 
      LineBox[{{2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}], 
      LineBox[{{2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}], 
      LineBox[{{2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}], 
      LineBox[{{2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}], 
      LineBox[{{2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}], 
      LineBox[{{2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}], 
      LineBox[{{2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}], 
      LineBox[{{2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}], 
      LineBox[{{2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}], 
      LineBox[{{2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}], 
      LineBox[{{2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}], 
      LineBox[{{2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}], 
      LineBox[{{2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}], 
      LineBox[{{2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}], 
      LineBox[{{2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}], 
      LineBox[{{2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}], 
      LineBox[{{2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}], 
      LineBox[{{2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}], 
      LineBox[{{2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}], 
      LineBox[{{2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}], 
      LineBox[{{2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}], 
      LineBox[{{2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}], 
      LineBox[{{2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}], 
      LineBox[{{2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}], 
      LineBox[{{2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}], 
      LineBox[{{2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}], 
      LineBox[{{2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}], 
      LineBox[{{2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}], 
      LineBox[{{2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}], 
      LineBox[{{2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}], 
      LineBox[{{2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}], 
      LineBox[{{2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}], 
      LineBox[{{2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}], 
      LineBox[{{2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}], 
      LineBox[{{2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}], 
      LineBox[{{2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}], 
      LineBox[{{2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}], 
      LineBox[{{2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}], 
      LineBox[{{2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}], 
      LineBox[{{2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}], 
      LineBox[{{2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}], 
      LineBox[{{2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}], 
      LineBox[{{2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}], 
      LineBox[{{2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}], 
      LineBox[{{2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}], 
      LineBox[{{2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}], 
      LineBox[{{2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}], 
      LineBox[{{2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}], 
      LineBox[{{2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}], 
      LineBox[{{2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}], 
      LineBox[{{2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}], 
      LineBox[{{2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}], 
      LineBox[{{2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}], 
      LineBox[{{2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}], 
      LineBox[{{2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}], 
      LineBox[{{2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}], 
      LineBox[{{2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}], 
      LineBox[{{2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}], 
      LineBox[{{2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}], 
      LineBox[{{2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}], 
      LineBox[{{2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}], 
      LineBox[{{2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}], 
      LineBox[{{2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}], 
      LineBox[{{2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}], 
      LineBox[{{2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}], 
      LineBox[{{2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}], 
      LineBox[{{2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}], 
      LineBox[{{2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}], 
      LineBox[{{2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}], 
      LineBox[{{2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}], 
      LineBox[{{2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}], 
      LineBox[{{2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}], 
      LineBox[{{2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}], 
      LineBox[{{2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}], 
      LineBox[{{2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}], 
      LineBox[{{2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}], 
      LineBox[{{2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}], 
      LineBox[{{2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}], 
      LineBox[{{2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}], 
      LineBox[{{2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}], 
      LineBox[{{2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}], 
      LineBox[{{2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}], 
      LineBox[{{2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}], 
      LineBox[{{2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}], 
      LineBox[{{2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}], 
      LineBox[{{2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}], 
      LineBox[{{2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}], 
      LineBox[{{2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}], 
      LineBox[{{2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}], 
      LineBox[{{2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}], 
      LineBox[{{2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}], 
      LineBox[{{2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}], 
      LineBox[{{2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}], 
      LineBox[{{2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}], 
      LineBox[{{2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}], 
      LineBox[{{2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}], 
      LineBox[{{2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}], 
      LineBox[{{2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}], 
      LineBox[{{2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}], 
      LineBox[{{2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}], 
      LineBox[{{2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}], 
      LineBox[{{2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}], 
      LineBox[{{2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}], 
      LineBox[{{2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}], 
      LineBox[{{2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}], 
      LineBox[{{2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}], 
      LineBox[{{2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}], 
      LineBox[{{2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.1360185284934627`, -0.5568514435778976}, {
       2.1360185284934627`, -0.5568514435778976}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.136018528493463, -0.8434037329586608}, {
       2.136018528493463, -0.8434037329586608}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}], 
      LineBox[{{2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}], 
      LineBox[{{2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}], 
      LineBox[{{2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}], 
      LineBox[{{2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}], 
      LineBox[{{2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}], 
      LineBox[{{2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}], 
      LineBox[{{2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}], 
      LineBox[{{2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}], 
      LineBox[{{2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}], 
      LineBox[{{2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}], 
      LineBox[{{2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}], 
      LineBox[{{2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}], 
      LineBox[{{2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}], 
      LineBox[{{2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}], 
      LineBox[{{2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}], 
      LineBox[{{2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}], 
      LineBox[{{2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}], 
      LineBox[{{2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}], 
      LineBox[{{2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}], 
      LineBox[{{2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}], 
      LineBox[{{2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}], 
      LineBox[{{2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}], 
      LineBox[{{2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}], 
      LineBox[{{2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}], 
      LineBox[{{2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}], 
      LineBox[{{2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}], 
      LineBox[{{2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}], 
      LineBox[{{2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}], 
      LineBox[{{2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}], 
      LineBox[{{2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}], 
      LineBox[{{2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}], 
      LineBox[{{2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}], 
      LineBox[{{2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}], 
      LineBox[{{2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}], 
      LineBox[{{2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}], 
      LineBox[{{2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}], 
      LineBox[{{2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}], 
      LineBox[{{2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}], 
      LineBox[{{2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}], 
      LineBox[{{2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}], 
      LineBox[{{2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}], 
      LineBox[{{2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}], 
      LineBox[{{2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}], 
      LineBox[{{2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}], 
      LineBox[{{2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}], 
      LineBox[{{2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}], 
      LineBox[{{2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}], 
      LineBox[{{2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}], 
      LineBox[{{2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}], 
      LineBox[{{2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}], 
      LineBox[{{2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}], 
      LineBox[{{2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}], 
      LineBox[{{2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}], 
      LineBox[{{2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}], 
      LineBox[{{2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}], 
      LineBox[{{2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}], 
      LineBox[{{2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}], 
      LineBox[{{2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}], 
      LineBox[{{2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}], 
      LineBox[{{2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}], 
      LineBox[{{2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}], 
      LineBox[{{2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}], 
      LineBox[{{2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}], 
      LineBox[{{2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}], 
      LineBox[{{2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}], 
      LineBox[{{2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}], 
      LineBox[{{2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}], 
      LineBox[{{2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}], 
      LineBox[{{2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}], 
      LineBox[{{2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}], 
      LineBox[{{2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}], 
      LineBox[{{2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}], 
      LineBox[{{2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}], 
      LineBox[{{2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}], 
      LineBox[{{2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}], 
      LineBox[{{2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}], 
      LineBox[{{2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}], 
      LineBox[{{2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}], 
      LineBox[{{2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}], 
      LineBox[{{2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}], 
      LineBox[{{2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}], 
      LineBox[{{2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}], 
      LineBox[{{2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}], 
      LineBox[{{2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}], 
      LineBox[{{2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}], 
      LineBox[{{2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}], 
      LineBox[{{2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}], 
      LineBox[{{2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}], 
      LineBox[{{2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}], 
      LineBox[{{2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.142432594166141, 0.1734570629829672}, {2.094118305373655, 
       0.22557797883223382`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.3298198105307671}, {2.142432594166141, 
       0.3819407263800337}, {2.142432594166141, 0.3819407263800337}, {
       2.094118305373655, 0.3298198105307671}, {2.082248544574173, 
       0.27769889468150044`}, {2.094118305373655, 0.2255779788322338}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.21172777575636, 0.15767611944752985`}, {
       2.142432594166141, 0.17345706298296718`}, {2.142432594166141, 
       0.17345706298296718`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.262800693350077, 0.3819407263800337}, {
       2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.262800693350077, 
       0.3819407263800337}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.142432594166141, 0.1734570629829672}, {2.094118305373655, 
       0.22557797883223382`}, {2.094118305373655, 0.22557797883223382`}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}}], 
      LineBox[{{2.142432594166141, 0.1734570629829672}, {2.094118305373655, 
       0.22557797883223382`}, {2.094118305373655, 0.22557797883223382`}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}}], 
      LineBox[{{2.142432594166141, 0.1734570629829672}, {2.094118305373655, 
       0.22557797883223382`}, {2.094118305373655, 0.22557797883223382`}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}}], 
      LineBox[{{2.142432594166141, 0.1734570629829672}, {2.094118305373655, 
       0.22557797883223382`}, {2.094118305373655, 0.22557797883223382`}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}}], 
      LineBox[{{2.094118305373655, 0.22557797883223382`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}}], 
      LineBox[{{2.094118305373655, 0.22557797883223382`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}}], 
      LineBox[{{2.094118305373655, 0.22557797883223382`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}}], 
      LineBox[{{2.094118305373655, 0.22557797883223382`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}}], 
      LineBox[{{2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}], 
      LineBox[{{2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}], 
      LineBox[{{2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}], 
      LineBox[{{2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}], 
      LineBox[{{2.094118305373655, 0.3298198105307671}, {2.142432594166141, 
       0.38194072638003373`}, {2.142432594166141, 0.38194072638003373`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}}], 
      LineBox[{{2.094118305373655, 0.3298198105307671}, {2.142432594166141, 
       0.38194072638003373`}, {2.142432594166141, 0.38194072638003373`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}}], 
      LineBox[{{2.094118305373655, 0.3298198105307671}, {2.142432594166141, 
       0.38194072638003373`}, {2.142432594166141, 0.38194072638003373`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}}], 
      LineBox[{{2.094118305373655, 0.3298198105307671}, {2.142432594166141, 
       0.38194072638003373`}, {2.142432594166141, 0.38194072638003373`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}], 
      LineBox[{{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}], 
      LineBox[{{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}], 
      LineBox[{{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}], 
      LineBox[{{2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}}], 
      LineBox[{{2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}}], 
      LineBox[{{2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}}], 
      LineBox[{{2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}}], 
      LineBox[{{2.262800693350077, 0.1734570629829672}, {2.21172777575636, 
       0.15767611944752985`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}}], 
      LineBox[{{2.262800693350077, 0.1734570629829672}, {2.21172777575636, 
       0.15767611944752985`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}}], 
      LineBox[{{2.262800693350077, 0.1734570629829672}, {2.21172777575636, 
       0.15767611944752985`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}}], 
      LineBox[{{2.262800693350077, 0.1734570629829672}, {2.21172777575636, 
       0.15767611944752985`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}}], 
      LineBox[{{2.21172777575636, 0.15767611944752985`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}}], 
      LineBox[{{2.21172777575636, 0.15767611944752985`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}}], 
      LineBox[{{2.21172777575636, 0.15767611944752985`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}}], 
      LineBox[{{2.21172777575636, 0.15767611944752985`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}], 
      LineBox[{{2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}], 
      LineBox[{{2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}], 
      LineBox[{{2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}], 
      LineBox[{{2.21172777575636, 0.39772166991547103`}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}}], 
      LineBox[{{2.21172777575636, 0.39772166991547103`}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}}], 
      LineBox[{{2.21172777575636, 0.39772166991547103`}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}}], 
      LineBox[{{2.21172777575636, 0.39772166991547103`}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}}], 
      LineBox[{{2.262800693350077, 0.3819407263800337}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}], 
      LineBox[{{2.262800693350077, 0.3819407263800337}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}], 
      LineBox[{{2.262800693350077, 0.3819407263800337}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}], 
      LineBox[{{2.262800693350077, 0.3819407263800337}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}], 
      LineBox[{{2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.302003850144312, 
       0.3456007540662044}}], 
      LineBox[{{2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.302003850144312, 
       0.3456007540662044}}], 
      LineBox[{{2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.302003850144312, 
       0.3456007540662044}}], 
      LineBox[{{2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.302003850144312, 
       0.3456007540662044}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2291699102503326`, 0.6891462206629825}, {
       2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.1797864462122365`, 0.848969211198768}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}, {2.1797864462122365`, 0.848969211198768}, {
       2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.7424205508415777}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.352201705728368, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.352201705728368, 
       0.6891462206629825}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.352201705728368, 0.9022435413773632}, {
       2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.352201705728368, 
       0.9022435413773632}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2291699102503326`, 0.6891462206629825}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}}], 
      LineBox[{{2.2291699102503326`, 0.6891462206629825}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}}], 
      LineBox[{{2.2291699102503326`, 0.6891462206629825}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}}], 
      LineBox[{{2.2291699102503326`, 0.6891462206629825}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}}], 
      LineBox[{{2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}}], 
      LineBox[{{2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}}], 
      LineBox[{{2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}}], 
      LineBox[{{2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}}], 
      LineBox[{{2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}], 
      LineBox[{{2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}], 
      LineBox[{{2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}], 
      LineBox[{{2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}], 
      LineBox[{{2.1797864462122365`, 0.848969211198768}, {2.2291699102503326`,
        0.9022435413773632}, {2.2291699102503326`, 0.9022435413773632}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}}], 
      LineBox[{{2.1797864462122365`, 0.848969211198768}, {2.2291699102503326`,
        0.9022435413773632}, {2.2291699102503326`, 0.9022435413773632}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}}], 
      LineBox[{{2.1797864462122365`, 0.848969211198768}, {2.2291699102503326`,
        0.9022435413773632}, {2.2291699102503326`, 0.9022435413773632}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}}], 
      LineBox[{{2.1797864462122365`, 0.848969211198768}, {2.2291699102503326`,
        0.9022435413773632}, {2.2291699102503326`, 0.9022435413773632}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}], 
      LineBox[{{2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}], 
      LineBox[{{2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}], 
      LineBox[{{2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}], 
      LineBox[{{2.392272412182171, 0.7262903815470088}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.392272412182171, 0.7262903815470088}, {2.392272412182171, 
       0.7262903815470088}}], 
      LineBox[{{2.392272412182171, 0.7262903815470088}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.392272412182171, 0.7262903815470088}, {2.392272412182171, 
       0.7262903815470088}}], 
      LineBox[{{2.392272412182171, 0.7262903815470088}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.392272412182171, 0.7262903815470088}, {2.392272412182171, 
       0.7262903815470088}}], 
      LineBox[{{2.392272412182171, 0.7262903815470088}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.392272412182171, 0.7262903815470088}, {2.392272412182171, 
       0.7262903815470088}}], 
      LineBox[{{2.352201705728368, 0.6891462206629825}, {2.299998565573644, 
       0.6730160513684136}, {2.299998565573644, 0.6730160513684136}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}}], 
      LineBox[{{2.352201705728368, 0.6891462206629825}, {2.299998565573644, 
       0.6730160513684136}, {2.299998565573644, 0.6730160513684136}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}}], 
      LineBox[{{2.352201705728368, 0.6891462206629825}, {2.299998565573644, 
       0.6730160513684136}, {2.299998565573644, 0.6730160513684136}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}}], 
      LineBox[{{2.352201705728368, 0.6891462206629825}, {2.299998565573644, 
       0.6730160513684136}, {2.299998565573644, 0.6730160513684136}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}}], 
      LineBox[{{2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}}], 
      LineBox[{{2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}}], 
      LineBox[{{2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}}], 
      LineBox[{{2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}], 
      LineBox[{{2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}], 
      LineBox[{{2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}], 
      LineBox[{{2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}], 
      LineBox[{{2.299998565573644, 0.9183737106719321}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}}], 
      LineBox[{{2.299998565573644, 0.9183737106719321}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}}], 
      LineBox[{{2.299998565573644, 0.9183737106719321}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}}], 
      LineBox[{{2.299998565573644, 0.9183737106719321}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}}], 
      LineBox[{{2.352201705728368, 0.9022435413773632}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}], 
      LineBox[{{2.352201705728368, 0.9022435413773632}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}], 
      LineBox[{{2.352201705728368, 0.9022435413773632}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}], 
      LineBox[{{2.352201705728368, 0.9022435413773632}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}], 
      LineBox[{{2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.392272412182171, 
       0.8650993804933369}}], 
      LineBox[{{2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.392272412182171, 
       0.8650993804933369}}], 
      LineBox[{{2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.392272412182171, 
       0.8650993804933369}}], 
      LineBox[{{2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.392272412182171, 
       0.8650993804933369}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.163703687295601, 1.078592341256198}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0807553746641787`, 1.222263033135929}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.163703687295601, 
       1.36593372501566}, {2.163703687295601, 1.36593372501566}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`,
        1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.329600312558446, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.329600312558446, 
       1.078592341256198}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.329600312558446, 1.36593372501566}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868, 
       1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.329600312558446, 
       1.36593372501566}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.163703687295601, 1.078592341256198}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}}], 
      LineBox[{{2.163703687295601, 1.078592341256198}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}}], 
      LineBox[{{2.163703687295601, 1.078592341256198}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}}], 
      LineBox[{{2.163703687295601, 1.078592341256198}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}}], 
      LineBox[{{2.0971148027241178`, 1.1504276871960635`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}}], 
      LineBox[{{2.0971148027241178`, 1.1504276871960635`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}}], 
      LineBox[{{2.0971148027241178`, 1.1504276871960635`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}}], 
      LineBox[{{2.0971148027241178`, 1.1504276871960635`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}}], 
      LineBox[{{2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`,
        1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}], 
      LineBox[{{2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`,
        1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}], 
      LineBox[{{2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`,
        1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}], 
      LineBox[{{2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`,
        1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}], 
      LineBox[{{2.0971148027241178`, 1.2940983790757945`}, {2.163703687295601,
        1.36593372501566}, {2.163703687295601, 1.36593372501566}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}}], 
      LineBox[{{2.0971148027241178`, 1.2940983790757945`}, {2.163703687295601,
        1.36593372501566}, {2.163703687295601, 1.36593372501566}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}}], 
      LineBox[{{2.0971148027241178`, 1.2940983790757945`}, {2.163703687295601,
        1.36593372501566}, {2.163703687295601, 1.36593372501566}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}}], 
      LineBox[{{2.0971148027241178`, 1.2940983790757945`}, {2.163703687295601,
        1.36593372501566}, {2.163703687295601, 1.36593372501566}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}], 
      LineBox[{{2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}], 
      LineBox[{{2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}], 
      LineBox[{{2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}], 
      LineBox[{{2.3836318330020427`, 1.1286776945174224`}, {2.329600312558446,
        1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.3836318330020427`, 
       1.1286776945174224`}}], 
      LineBox[{{2.3836318330020427`, 1.1286776945174224`}, {2.329600312558446,
        1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.3836318330020427`, 
       1.1286776945174224`}}], 
      LineBox[{{2.3836318330020427`, 1.1286776945174224`}, {2.329600312558446,
        1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.3836318330020427`, 
       1.1286776945174224`}}], 
      LineBox[{{2.3836318330020427`, 1.1286776945174224`}, {2.329600312558446,
        1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.3836318330020427`, 
       1.1286776945174224`}}], 
      LineBox[{{2.329600312558446, 1.078592341256198}, {2.259209364054909, 
       1.0568423485775569`}, {2.259209364054909, 1.0568423485775569`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}}], 
      LineBox[{{2.329600312558446, 1.078592341256198}, {2.259209364054909, 
       1.0568423485775569`}, {2.259209364054909, 1.0568423485775569`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}}], 
      LineBox[{{2.329600312558446, 1.078592341256198}, {2.259209364054909, 
       1.0568423485775569`}, {2.259209364054909, 1.0568423485775569`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}}], 
      LineBox[{{2.329600312558446, 1.078592341256198}, {2.259209364054909, 
       1.0568423485775569`}, {2.259209364054909, 1.0568423485775569`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}}], 
      LineBox[{{2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}}], 
      LineBox[{{2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}}], 
      LineBox[{{2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}}], 
      LineBox[{{2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}], 
      LineBox[{{2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}], 
      LineBox[{{2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}], 
      LineBox[{{2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}], 
      LineBox[{{2.259209364054909, 1.387683717694301}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}}], 
      LineBox[{{2.259209364054909, 1.387683717694301}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}}], 
      LineBox[{{2.259209364054909, 1.387683717694301}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}}], 
      LineBox[{{2.259209364054909, 1.387683717694301}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}}], 
      LineBox[{{2.329600312558446, 1.36593372501566}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}], 
      LineBox[{{2.329600312558446, 1.36593372501566}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}], 
      LineBox[{{2.329600312558446, 1.36593372501566}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}], 
      LineBox[{{2.329600312558446, 1.36593372501566}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}], 
      LineBox[{{2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868,
        1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.3836318330020427`, 
       1.3158483717544356`}}], 
      LineBox[{{2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868,
        1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.3836318330020427`, 
       1.3158483717544356`}}], 
      LineBox[{{2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868,
        1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.3836318330020427`, 
       1.3158483717544356`}}], 
      LineBox[{{2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868,
        1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.3836318330020427`, 
       1.3158483717544356`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.220879893889163, 1.653768181760945}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.829952976718999}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}, {
       2.1664408206575665`, 1.829952976718999}, {2.153066334691729, 
       1.7712247117329811`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.3565070122840317`, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.3565070122840317`, 
       1.653768181760945}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`,
        1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.220879893889163, 1.653768181760945}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}}], 
      LineBox[{{2.220879893889163, 1.653768181760945}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}}], 
      LineBox[{{2.220879893889163, 1.653768181760945}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}}], 
      LineBox[{{2.220879893889163, 1.653768181760945}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}}], 
      LineBox[{{2.1664408206575665`, 1.7124964467469632`}, {2.153066334691729,
        1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}}], 
      LineBox[{{2.1664408206575665`, 1.7124964467469632`}, {2.153066334691729,
        1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}}], 
      LineBox[{{2.1664408206575665`, 1.7124964467469632`}, {2.153066334691729,
        1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}}], 
      LineBox[{{2.1664408206575665`, 1.7124964467469632`}, {2.153066334691729,
        1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}}], 
      LineBox[{{2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`,
        1.829952976718999}, {2.1664408206575665`, 1.829952976718999}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}], 
      LineBox[{{2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`,
        1.829952976718999}, {2.1664408206575665`, 1.829952976718999}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}], 
      LineBox[{{2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`,
        1.829952976718999}, {2.1664408206575665`, 1.829952976718999}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}], 
      LineBox[{{2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`,
        1.829952976718999}, {2.1664408206575665`, 1.829952976718999}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}], 
      LineBox[{{2.1664408206575665`, 1.829952976718999}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}}], 
      LineBox[{{2.1664408206575665`, 1.829952976718999}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}}], 
      LineBox[{{2.1664408206575665`, 1.829952976718999}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}}], 
      LineBox[{{2.1664408206575665`, 1.829952976718999}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}], 
      LineBox[{{2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}], 
      LineBox[{{2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}], 
      LineBox[{{2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}], 
      LineBox[{{2.400679938699189, 1.694714958862928}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.400679938699189, 1.694714958862928}, {2.400679938699189, 
       1.694714958862928}}], 
      LineBox[{{2.400679938699189, 1.694714958862928}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.400679938699189, 1.694714958862928}, {2.400679938699189, 
       1.694714958862928}}], 
      LineBox[{{2.400679938699189, 1.694714958862928}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.400679938699189, 1.694714958862928}, {2.400679938699189, 
       1.694714958862928}}], 
      LineBox[{{2.400679938699189, 1.694714958862928}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.400679938699189, 1.694714958862928}, {2.400679938699189, 
       1.694714958862928}}], 
      LineBox[{{2.3565070122840317`, 1.653768181760945}, {2.298959599903037, 
       1.63598669387691}, {2.298959599903037, 1.63598669387691}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}}], 
      LineBox[{{2.3565070122840317`, 1.653768181760945}, {2.298959599903037, 
       1.63598669387691}, {2.298959599903037, 1.63598669387691}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}}], 
      LineBox[{{2.3565070122840317`, 1.653768181760945}, {2.298959599903037, 
       1.63598669387691}, {2.298959599903037, 1.63598669387691}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}}], 
      LineBox[{{2.3565070122840317`, 1.653768181760945}, {2.298959599903037, 
       1.63598669387691}, {2.298959599903037, 1.63598669387691}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}}], 
      LineBox[{{2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}}], 
      LineBox[{{2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}}], 
      LineBox[{{2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}}], 
      LineBox[{{2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}], 
      LineBox[{{2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}], 
      LineBox[{{2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}], 
      LineBox[{{2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}], 
      LineBox[{{2.298959599903037, 1.9064627295890522`}, {2.3565070122840317`,
        1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}}], 
      LineBox[{{2.298959599903037, 1.9064627295890522`}, {2.3565070122840317`,
        1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}}], 
      LineBox[{{2.298959599903037, 1.9064627295890522`}, {2.3565070122840317`,
        1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}}], 
      LineBox[{{2.298959599903037, 1.9064627295890522`}, {2.3565070122840317`,
        1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}}], 
      LineBox[{{2.3565070122840317`, 1.8886812417050172`}, {2.400679938699189,
        1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}}], 
      LineBox[{{2.3565070122840317`, 1.8886812417050172`}, {2.400679938699189,
        1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}}], 
      LineBox[{{2.3565070122840317`, 1.8886812417050172`}, {2.400679938699189,
        1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}}], 
      LineBox[{{2.3565070122840317`, 1.8886812417050172`}, {2.400679938699189,
        1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}}], 
      LineBox[{{2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.400679938699189, 
       1.8477344646030343`}}], 
      LineBox[{{2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.400679938699189, 
       1.8477344646030343`}}], 
      LineBox[{{2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.400679938699189, 
       1.8477344646030343`}}], 
      LineBox[{{2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.400679938699189, 
       1.8477344646030343`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1610676327125864`, 2.105837267114838}, {2.1040650623517703`,
        2.1673310042104785`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1610676327125864`, 
       2.351812215497401}, {2.1610676327125864`, 2.351812215497401}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394,
        2.1487121987448226`}, {2.303081335375164, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`, 
       2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.303081335375164, 
       2.105837267114838}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.303081335375164, 2.351812215497401}, {
       2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`, 
       2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.303081335375164, 
       2.351812215497401}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1610676327125864`, 2.105837267114838}, {2.1040650623517703`,
        2.1673310042104785`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}}], 
      LineBox[{{2.1610676327125864`, 2.105837267114838}, {2.1040650623517703`,
        2.1673310042104785`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}}], 
      LineBox[{{2.1610676327125864`, 2.105837267114838}, {2.1040650623517703`,
        2.1673310042104785`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}}], 
      LineBox[{{2.1610676327125864`, 2.105837267114838}, {2.1040650623517703`,
        2.1673310042104785`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}}], 
      LineBox[{{2.1040650623517703`, 2.1673310042104785`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}}], 
      LineBox[{{2.1040650623517703`, 2.1673310042104785`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}}], 
      LineBox[{{2.1040650623517703`, 2.1673310042104785`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}}], 
      LineBox[{{2.1040650623517703`, 2.1673310042104785`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}}], 
      LineBox[{{2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}], 
      LineBox[{{2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}], 
      LineBox[{{2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}], 
      LineBox[{{2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}], 
      LineBox[{{2.1040650623517703`, 2.2903184784017605`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.1040650623517703`, 2.2903184784017605`}}], 
      LineBox[{{2.1040650623517703`, 2.2903184784017605`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.1040650623517703`, 2.2903184784017605`}}], 
      LineBox[{{2.1040650623517703`, 2.2903184784017605`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.1040650623517703`, 2.2903184784017605`}}], 
      LineBox[{{2.1040650623517703`, 2.2903184784017605`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.1040650623517703`, 2.2903184784017605`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394,
        2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}], 
      LineBox[{{2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394,
        2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}], 
      LineBox[{{2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394,
        2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}], 
      LineBox[{{2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394,
        2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}], 
      LineBox[{{2.349334333388394, 2.1487121987448226`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.349334333388394, 2.1487121987448226`}, {2.349334333388394, 
       2.1487121987448226`}}], 
      LineBox[{{2.349334333388394, 2.1487121987448226`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.349334333388394, 2.1487121987448226`}, {2.349334333388394, 
       2.1487121987448226`}}], 
      LineBox[{{2.349334333388394, 2.1487121987448226`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.349334333388394, 2.1487121987448226`}, {2.349334333388394, 
       2.1487121987448226`}}], 
      LineBox[{{2.349334333388394, 2.1487121987448226`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.349334333388394, 2.1487121987448226`}, {2.349334333388394, 
       2.1487121987448226`}}], 
      LineBox[{{2.303081335375164, 2.105837267114838}, {2.242824056391461, 
       2.0872184616491816`}, {2.242824056391461, 2.0872184616491816`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}}], 
      LineBox[{{2.303081335375164, 2.105837267114838}, {2.242824056391461, 
       2.0872184616491816`}, {2.242824056391461, 2.0872184616491816`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}}], 
      LineBox[{{2.303081335375164, 2.105837267114838}, {2.242824056391461, 
       2.0872184616491816`}, {2.242824056391461, 2.0872184616491816`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}}], 
      LineBox[{{2.303081335375164, 2.105837267114838}, {2.242824056391461, 
       2.0872184616491816`}, {2.242824056391461, 2.0872184616491816`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}}], 
      LineBox[{{2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`,
        2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}}], 
      LineBox[{{2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`,
        2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}}], 
      LineBox[{{2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`,
        2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}}], 
      LineBox[{{2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`,
        2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}], 
      LineBox[{{2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}], 
      LineBox[{{2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}], 
      LineBox[{{2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}], 
      LineBox[{{2.242824056391461, 2.3704310209630575`}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}}], 
      LineBox[{{2.242824056391461, 2.3704310209630575`}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}}], 
      LineBox[{{2.242824056391461, 2.3704310209630575`}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}}], 
      LineBox[{{2.242824056391461, 2.3704310209630575`}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}}], 
      LineBox[{{2.303081335375164, 2.351812215497401}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}], 
      LineBox[{{2.303081335375164, 2.351812215497401}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}], 
      LineBox[{{2.303081335375164, 2.351812215497401}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}], 
      LineBox[{{2.303081335375164, 2.351812215497401}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}], 
      LineBox[{{2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`,
        2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.349334333388394, 
       2.3089372838674165`}}], 
      LineBox[{{2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`,
        2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.349334333388394, 
       2.3089372838674165`}}], 
      LineBox[{{2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`,
        2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.349334333388394, 
       2.3089372838674165`}}], 
      LineBox[{{2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`,
        2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.349334333388394, 
       2.3089372838674165`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.136362568075988, 2.666962461712102}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.136362568075988, 
       2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`,
        2.9098339615821702`}, {2.266717425158318, 2.8927436971920786`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`, 
       2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.266717425158318, 
       2.8927436971920786`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.136362568075988, 2.666962461712102}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}}], 
      LineBox[{{2.136362568075988, 2.666962461712102}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}}], 
      LineBox[{{2.136362568075988, 2.666962461712102}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}}], 
      LineBox[{{2.136362568075988, 2.666962461712102}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}}], 
      LineBox[{{2.0840397163131223`, 2.7234077705820963`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}}], 
      LineBox[{{2.0840397163131223`, 2.7234077705820963`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}}], 
      LineBox[{{2.0840397163131223`, 2.7234077705820963`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}}], 
      LineBox[{{2.0840397163131223`, 2.7234077705820963`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}}], 
      LineBox[{{2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}], 
      LineBox[{{2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}], 
      LineBox[{{2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}], 
      LineBox[{{2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}], 
      LineBox[{{2.0840397163131223`, 2.8362983883220845`}, {2.136362568075988,
        2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}}], 
      LineBox[{{2.0840397163131223`, 2.8362983883220845`}, {2.136362568075988,
        2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}}], 
      LineBox[{{2.0840397163131223`, 2.8362983883220845`}, {2.136362568075988,
        2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}}], 
      LineBox[{{2.0840397163131223`, 2.8362983883220845`}, {2.136362568075988,
        2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}], 
      LineBox[{{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}], 
      LineBox[{{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}], 
      LineBox[{{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}], 
      LineBox[{{2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318,
        2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}}], 
      LineBox[{{2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318,
        2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}}], 
      LineBox[{{2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318,
        2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}}], 
      LineBox[{{2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318,
        2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}}], 
      LineBox[{{2.266717425158318, 2.666962461712102}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}}], 
      LineBox[{{2.266717425158318, 2.666962461712102}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}}], 
      LineBox[{{2.266717425158318, 2.666962461712102}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}}], 
      LineBox[{{2.266717425158318, 2.666962461712102}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}}], 
      LineBox[{{2.2114070653632947`, 2.6498721973220105`}, {2.136362568075988,
        2.666962461712102}, {2.136362568075988, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}}], 
      LineBox[{{2.2114070653632947`, 2.6498721973220105`}, {2.136362568075988,
        2.666962461712102}, {2.136362568075988, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}}], 
      LineBox[{{2.2114070653632947`, 2.6498721973220105`}, {2.136362568075988,
        2.666962461712102}, {2.136362568075988, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}}], 
      LineBox[{{2.2114070653632947`, 2.6498721973220105`}, {2.136362568075988,
        2.666962461712102}, {2.136362568075988, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`,
        2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}], 
      LineBox[{{2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`,
        2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}], 
      LineBox[{{2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`,
        2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}], 
      LineBox[{{2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`,
        2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}], 
      LineBox[{{2.2114070653632947`, 2.9098339615821702`}, {2.266717425158318,
        2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}}], 
      LineBox[{{2.2114070653632947`, 2.9098339615821702`}, {2.266717425158318,
        2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}}], 
      LineBox[{{2.2114070653632947`, 2.9098339615821702`}, {2.266717425158318,
        2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}}], 
      LineBox[{{2.2114070653632947`, 2.9098339615821702`}, {2.266717425158318,
        2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}}], 
      LineBox[{{2.266717425158318, 2.8927436971920786`}, {2.3091732081750425`,
        2.853388652712176}, {2.3091732081750425`, 2.853388652712176}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}], 
      LineBox[{{2.266717425158318, 2.8927436971920786`}, {2.3091732081750425`,
        2.853388652712176}, {2.3091732081750425`, 2.853388652712176}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}], 
      LineBox[{{2.266717425158318, 2.8927436971920786`}, {2.3091732081750425`,
        2.853388652712176}, {2.3091732081750425`, 2.853388652712176}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}], 
      LineBox[{{2.266717425158318, 2.8927436971920786`}, {2.3091732081750425`,
        2.853388652712176}, {2.3091732081750425`, 2.853388652712176}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}], 
      LineBox[{{2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`,
        2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3091732081750425`, 
       2.853388652712176}}], 
      LineBox[{{2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`,
        2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3091732081750425`, 
       2.853388652712176}}], 
      LineBox[{{2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`,
        2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3091732081750425`, 
       2.853388652712176}}], 
      LineBox[{{2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`,
        2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3091732081750425`, 
       2.853388652712176}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1892517173890385`, 3.0970481097196063`}, {2.125544106196512,
        3.1657751700761247`}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.3032292907891616`}, {2.1892517173890385`, 
       3.37195635114568}, {2.1892517173890385`, 3.37195635114568}, {
       2.125544106196512, 3.3032292907891616`}, {2.109892543794143, 
       3.234502230432643}, {2.125544106196512, 3.1657751700761247`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.3479700645788286`, 3.37195635114568}, {
       2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1892517173890385`, 3.0970481097196063`}, {2.125544106196512,
        3.1657751700761247`}, {2.125544106196512, 3.1657751700761247`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}}], 
      LineBox[{{2.1892517173890385`, 3.0970481097196063`}, {2.125544106196512,
        3.1657751700761247`}, {2.125544106196512, 3.1657751700761247`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}}], 
      LineBox[{{2.1892517173890385`, 3.0970481097196063`}, {2.125544106196512,
        3.1657751700761247`}, {2.125544106196512, 3.1657751700761247`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}}], 
      LineBox[{{2.1892517173890385`, 3.0970481097196063`}, {2.125544106196512,
        3.1657751700761247`}, {2.125544106196512, 3.1657751700761247`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}}], 
      LineBox[{{2.125544106196512, 3.1657751700761247`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}}], 
      LineBox[{{2.125544106196512, 3.1657751700761247`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}}], 
      LineBox[{{2.125544106196512, 3.1657751700761247`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}}], 
      LineBox[{{2.125544106196512, 3.1657751700761247`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}}], 
      LineBox[{{2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}], 
      LineBox[{{2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}], 
      LineBox[{{2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}], 
      LineBox[{{2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}], 
      LineBox[{{2.125544106196512, 3.3032292907891616`}, {2.1892517173890385`,
        3.37195635114568}, {2.1892517173890385`, 3.37195635114568}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}}], 
      LineBox[{{2.125544106196512, 3.3032292907891616`}, {2.1892517173890385`,
        3.37195635114568}, {2.1892517173890385`, 3.37195635114568}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}}], 
      LineBox[{{2.125544106196512, 3.3032292907891616`}, {2.1892517173890385`,
        3.37195635114568}, {2.1892517173890385`, 3.37195635114568}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}}], 
      LineBox[{{2.125544106196512, 3.3032292907891616`}, {2.1892517173890385`,
        3.37195635114568}, {2.1892517173890385`, 3.37195635114568}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}], 
      LineBox[{{2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}], 
      LineBox[{{2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}], 
      LineBox[{{2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}], 
      LineBox[{{2.3996636635738158`, 3.1449662905472344`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}}], 
      LineBox[{{2.3996636635738158`, 3.1449662905472344`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}}], 
      LineBox[{{2.3996636635738158`, 3.1449662905472344`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}}], 
      LineBox[{{2.3996636635738158`, 3.1449662905472344`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}}], 
      LineBox[{{2.3479700645788286`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}}], 
      LineBox[{{2.3479700645788286`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}}], 
      LineBox[{{2.3479700645788286`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}}], 
      LineBox[{{2.3479700645788286`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}}], 
      LineBox[{{2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`,
        3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}}], 
      LineBox[{{2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`,
        3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}}], 
      LineBox[{{2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`,
        3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}}], 
      LineBox[{{2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`,
        3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}], 
      LineBox[{{2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}], 
      LineBox[{{2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}], 
      LineBox[{{2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}], 
      LineBox[{{2.2806249031814727`, 3.3927652306745704`}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.2806249031814727`, 3.3927652306745704`}}], 
      LineBox[{{2.2806249031814727`, 3.3927652306745704`}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.2806249031814727`, 3.3927652306745704`}}], 
      LineBox[{{2.2806249031814727`, 3.3927652306745704`}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.2806249031814727`, 3.3927652306745704`}}], 
      LineBox[{{2.2806249031814727`, 3.3927652306745704`}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.2806249031814727`, 3.3927652306745704`}}], 
      LineBox[{{2.3479700645788286`, 3.37195635114568}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}], 
      LineBox[{{2.3479700645788286`, 3.37195635114568}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}], 
      LineBox[{{2.3479700645788286`, 3.37195635114568}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}], 
      LineBox[{{2.3479700645788286`, 3.37195635114568}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}], 
      LineBox[{{2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3996636635738158`, 
       3.324038170318052}}], 
      LineBox[{{2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3996636635738158`, 
       3.324038170318052}}], 
      LineBox[{{2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3996636635738158`, 
       3.324038170318052}}], 
      LineBox[{{2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3996636635738158`, 
       3.324038170318052}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.14719901162296, 3.5857430952338682`}, {2.0863825446760766`, 
       3.651351221426159}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.782567473810741}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}, {
       2.0863825446760766`, 3.782567473810741}, {2.071441272986668, 
       3.71695934761845}, {2.0863825446760766`, 3.651351221426159}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.298714488895545, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.298714488895545, 
       3.5857430952338682`}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.298714488895545, 3.848175600003032}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837, 
       3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.298714488895545, 
       3.848175600003032}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.14719901162296, 3.5857430952338682`}, {2.0863825446760766`, 
       3.651351221426159}, {2.0863825446760766`, 3.651351221426159}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}}], 
      LineBox[{{2.14719901162296, 3.5857430952338682`}, {2.0863825446760766`, 
       3.651351221426159}, {2.0863825446760766`, 3.651351221426159}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}}], 
      LineBox[{{2.14719901162296, 3.5857430952338682`}, {2.0863825446760766`, 
       3.651351221426159}, {2.0863825446760766`, 3.651351221426159}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}}], 
      LineBox[{{2.14719901162296, 3.5857430952338682`}, {2.0863825446760766`, 
       3.651351221426159}, {2.0863825446760766`, 3.651351221426159}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}}], 
      LineBox[{{2.0863825446760766`, 3.651351221426159}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}}], 
      LineBox[{{2.0863825446760766`, 3.651351221426159}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}}], 
      LineBox[{{2.0863825446760766`, 3.651351221426159}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}}], 
      LineBox[{{2.0863825446760766`, 3.651351221426159}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}}], 
      LineBox[{{2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}], 
      LineBox[{{2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}], 
      LineBox[{{2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}], 
      LineBox[{{2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}], 
      LineBox[{{2.0863825446760766`, 3.782567473810741}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}}], 
      LineBox[{{2.0863825446760766`, 3.782567473810741}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}}], 
      LineBox[{{2.0863825446760766`, 3.782567473810741}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}}], 
      LineBox[{{2.0863825446760766`, 3.782567473810741}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}], 
      LineBox[{{2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}], 
      LineBox[{{2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}], 
      LineBox[{{2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}], 
      LineBox[{{2.3480621570280595`, 3.631486679177887}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.3480621570280595`, 3.631486679177887}, {2.3480621570280595`, 
       3.631486679177887}}], 
      LineBox[{{2.3480621570280595`, 3.631486679177887}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.3480621570280595`, 3.631486679177887}, {2.3480621570280595`, 
       3.631486679177887}}], 
      LineBox[{{2.3480621570280595`, 3.631486679177887}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.3480621570280595`, 3.631486679177887}, {2.3480621570280595`, 
       3.631486679177887}}], 
      LineBox[{{2.3480621570280595`, 3.631486679177887}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.3480621570280595`, 3.631486679177887}, {2.3480621570280595`, 
       3.631486679177887}}], 
      LineBox[{{2.298714488895545, 3.5857430952338682`}, {2.234425549073621, 
       3.565878552985596}, {2.234425549073621, 3.565878552985596}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}}], 
      LineBox[{{2.298714488895545, 3.5857430952338682`}, {2.234425549073621, 
       3.565878552985596}, {2.234425549073621, 3.565878552985596}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}}], 
      LineBox[{{2.298714488895545, 3.5857430952338682`}, {2.234425549073621, 
       3.565878552985596}, {2.234425549073621, 3.565878552985596}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}}], 
      LineBox[{{2.298714488895545, 3.5857430952338682`}, {2.234425549073621, 
       3.565878552985596}, {2.234425549073621, 3.565878552985596}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}}], 
      LineBox[{{2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}}], 
      LineBox[{{2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}}], 
      LineBox[{{2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}}], 
      LineBox[{{2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}], 
      LineBox[{{2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}], 
      LineBox[{{2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}], 
      LineBox[{{2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}], 
      LineBox[{{2.234425549073621, 3.868040142251304}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}}], 
      LineBox[{{2.234425549073621, 3.868040142251304}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}}], 
      LineBox[{{2.234425549073621, 3.868040142251304}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}}], 
      LineBox[{{2.234425549073621, 3.868040142251304}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}}], 
      LineBox[{{2.298714488895545, 3.848175600003032}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}], 
      LineBox[{{2.298714488895545, 3.848175600003032}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}], 
      LineBox[{{2.298714488895545, 3.848175600003032}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}], 
      LineBox[{{2.298714488895545, 3.848175600003032}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}], 
      LineBox[{{2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837,
        3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.3480621570280595`, 
       3.8024320160590133`}}], 
      LineBox[{{2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837,
        3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.3480621570280595`, 
       3.8024320160590133`}}], 
      LineBox[{{2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837,
        3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.3480621570280595`, 
       3.8024320160590133`}}], 
      LineBox[{{2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837,
        3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.3480621570280595`, 
       3.8024320160590133`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}], 
      LineBox[{{2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}], 
      LineBox[{{2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}], 
      LineBox[{{2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}], 
      LineBox[{{2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}], 
      LineBox[{{2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}], 
      LineBox[{{2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}], 
      LineBox[{{2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}], 
      LineBox[{{2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}], 
      LineBox[{{2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}], 
      LineBox[{{2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}], 
      LineBox[{{2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}], 
      LineBox[{{2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}], 
      LineBox[{{2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}], 
      LineBox[{{2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}], 
      LineBox[{{2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}], 
      LineBox[{{2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}], 
      LineBox[{{2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}], 
      LineBox[{{2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}], 
      LineBox[{{2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}], 
      LineBox[{{2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}], 
      LineBox[{{2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}], 
      LineBox[{{2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}], 
      LineBox[{{2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}], 
      LineBox[{{2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}], 
      LineBox[{{2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}], 
      LineBox[{{2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}], 
      LineBox[{{2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}], 
      LineBox[{{2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}], 
      LineBox[{{2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}], 
      LineBox[{{2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}], 
      LineBox[{{2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}], 
      LineBox[{{2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}], 
      LineBox[{{2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}], 
      LineBox[{{2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}], 
      LineBox[{{2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}], 
      LineBox[{{2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}], 
      LineBox[{{2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}], 
      LineBox[{{2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}], 
      LineBox[{{2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}], 
      LineBox[{{2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}], 
      LineBox[{{2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}], 
      LineBox[{{2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}], 
      LineBox[{{2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}], 
      LineBox[{{2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}], 
      LineBox[{{2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.454381886469539, -4.186417887001175}, {
       2.454381886469539, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}], 
      LineBox[{{2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}], 
      LineBox[{{2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}], 
      LineBox[{{2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}], 
      LineBox[{{2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}], 
      LineBox[{{2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}], 
      LineBox[{{2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}], 
      LineBox[{{2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}], 
      LineBox[{{2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}], 
      LineBox[{{2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}], 
      LineBox[{{2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}], 
      LineBox[{{2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}], 
      LineBox[{{2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}], 
      LineBox[{{2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}], 
      LineBox[{{2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}], 
      LineBox[{{2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}], 
      LineBox[{{2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}], 
      LineBox[{{2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}], 
      LineBox[{{2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}], 
      LineBox[{{2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}], 
      LineBox[{{2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}], 
      LineBox[{{2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}], 
      LineBox[{{2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}], 
      LineBox[{{2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}], 
      LineBox[{{2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}], 
      LineBox[{{2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}], 
      LineBox[{{2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}], 
      LineBox[{{2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}], 
      LineBox[{{2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}], 
      LineBox[{{2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}], 
      LineBox[{{2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}], 
      LineBox[{{2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}], 
      LineBox[{{2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}], 
      LineBox[{{2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}], 
      LineBox[{{2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}], 
      LineBox[{{2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}], 
      LineBox[{{2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}], 
      LineBox[{{2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}], 
      LineBox[{{2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}], 
      LineBox[{{2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}], 
      LineBox[{{2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}], 
      LineBox[{{2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}], 
      LineBox[{{2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}], 
      LineBox[{{2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}], 
      LineBox[{{2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}], 
      LineBox[{{2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}], 
      LineBox[{{2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}], 
      LineBox[{{2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}], 
      LineBox[{{2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}], 
      LineBox[{{2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}], 
      LineBox[{{2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}], 
      LineBox[{{2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}], 
      LineBox[{{2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}], 
      LineBox[{{2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}], 
      LineBox[{{2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}], 
      LineBox[{{2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}], 
      LineBox[{{2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}], 
      LineBox[{{2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}], 
      LineBox[{{2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}], 
      LineBox[{{2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}], 
      LineBox[{{2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}], 
      LineBox[{{2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}], 
      LineBox[{{2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}], 
      LineBox[{{2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}], 
      LineBox[{{2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}], 
      LineBox[{{2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}], 
      LineBox[{{2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}], 
      LineBox[{{2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}], 
      LineBox[{{2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}], 
      LineBox[{{2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}], 
      LineBox[{{2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}], 
      LineBox[{{2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}], 
      LineBox[{{2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}], 
      LineBox[{{2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}], 
      LineBox[{{2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}], 
      LineBox[{{2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}], 
      LineBox[{{2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}], 
      LineBox[{{2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}], 
      LineBox[{{2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}], 
      LineBox[{{2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}], 
      LineBox[{{2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}], 
      LineBox[{{2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}], 
      LineBox[{{2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}], 
      LineBox[{{2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}], 
      LineBox[{{2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}], 
      LineBox[{{2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}], 
      LineBox[{{2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}], 
      LineBox[{{2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}], 
      LineBox[{{2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}], 
      LineBox[{{2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}], 
      LineBox[{{2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}], 
      LineBox[{{2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}], 
      LineBox[{{2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}], 
      LineBox[{{2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}], 
      LineBox[{{2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}], 
      LineBox[{{2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}], 
      LineBox[{{2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}], 
      LineBox[{{2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}], 
      LineBox[{{2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}], 
      LineBox[{{2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}], 
      LineBox[{{2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}], 
      LineBox[{{2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}], 
      LineBox[{{2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}], 
      LineBox[{{2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}], 
      LineBox[{{2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}], 
      LineBox[{{2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}], 
      LineBox[{{2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}], 
      LineBox[{{2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}], 
      LineBox[{{2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}], 
      LineBox[{{2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}], 
      LineBox[{{2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}], 
      LineBox[{{2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}], 
      LineBox[{{2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}], 
      LineBox[{{2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}], 
      LineBox[{{2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}], 
      LineBox[{{2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}], 
      LineBox[{{2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}], 
      LineBox[{{2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}], 
      LineBox[{{2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}], 
      LineBox[{{2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}], 
      LineBox[{{2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}], 
      LineBox[{{2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}], 
      LineBox[{{2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}], 
      LineBox[{{2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}], 
      LineBox[{{2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}], 
      LineBox[{{2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}], 
      LineBox[{{2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}], 
      LineBox[{{2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}], 
      LineBox[{{2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}], 
      LineBox[{{2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}], 
      LineBox[{{2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}], 
      LineBox[{{2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}], 
      LineBox[{{2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}], 
      LineBox[{{2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}], 
      LineBox[{{2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}], 
      LineBox[{{2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}], 
      LineBox[{{2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}], 
      LineBox[{{2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}], 
      LineBox[{{2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}], 
      LineBox[{{2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}], 
      LineBox[{{2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}], 
      LineBox[{{2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}], 
      LineBox[{{2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}], 
      LineBox[{{2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}], 
      LineBox[{{2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}], 
      LineBox[{{2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}], 
      LineBox[{{2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}], 
      LineBox[{{2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}], 
      LineBox[{{2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}], 
      LineBox[{{2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}], 
      LineBox[{{2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}], 
      LineBox[{{2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}], 
      LineBox[{{2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}], 
      LineBox[{{2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}], 
      LineBox[{{2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}], 
      LineBox[{{2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}], 
      LineBox[{{2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}], 
      LineBox[{{2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}], 
      LineBox[{{2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}], 
      LineBox[{{2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}], 
      LineBox[{{2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}], 
      LineBox[{{2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}], 
      LineBox[{{2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}], 
      LineBox[{{2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}], 
      LineBox[{{2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}], 
      LineBox[{{2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}], 
      LineBox[{{2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}], 
      LineBox[{{2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}], 
      LineBox[{{2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}], 
      LineBox[{{2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}], 
      LineBox[{{2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}], 
      LineBox[{{2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}], 
      LineBox[{{2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}], 
      LineBox[{{2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}], 
      LineBox[{{2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}], 
      LineBox[{{2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}], 
      LineBox[{{2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}], 
      LineBox[{{2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}], 
      LineBox[{{2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}], 
      LineBox[{{2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}], 
      LineBox[{{2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}], 
      LineBox[{{2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}], 
      LineBox[{{2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}], 
      LineBox[{{2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}], 
      LineBox[{{2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}], 
      LineBox[{{2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}], 
      LineBox[{{2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}], 
      LineBox[{{2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}], 
      LineBox[{{2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}], 
      LineBox[{{2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}], 
      LineBox[{{2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}], 
      LineBox[{{2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}], 
      LineBox[{{2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}], 
      LineBox[{{2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}], 
      LineBox[{{2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}], 
      LineBox[{{2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}], 
      LineBox[{{2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}], 
      LineBox[{{2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}], 
      LineBox[{{2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}], 
      LineBox[{{2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}], 
      LineBox[{{2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}], 
      LineBox[{{2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}], 
      LineBox[{{2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}], 
      LineBox[{{2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}], 
      LineBox[{{2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}], 
      LineBox[{{2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}], 
      LineBox[{{2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}], 
      LineBox[{{2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}], 
      LineBox[{{2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}], 
      LineBox[{{2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}], 
      LineBox[{{2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}], 
      LineBox[{{2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}], 
      LineBox[{{2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}], 
      LineBox[{{2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}], 
      LineBox[{{2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}], 
      LineBox[{{2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}], 
      LineBox[{{2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}], 
      LineBox[{{2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}], 
      LineBox[{{2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}], 
      LineBox[{{2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}], 
      LineBox[{{2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}], 
      LineBox[{{2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}], 
      LineBox[{{2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}], 
      LineBox[{{2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}], 
      LineBox[{{2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}], 
      LineBox[{{2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}], 
      LineBox[{{2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}], 
      LineBox[{{2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}], 
      LineBox[{{2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}], 
      LineBox[{{2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}], 
      LineBox[{{2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}], 
      LineBox[{{2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}], 
      LineBox[{{2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}], 
      LineBox[{{2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}], 
      LineBox[{{2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}], 
      LineBox[{{2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}], 
      LineBox[{{2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}], 
      LineBox[{{2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}], 
      LineBox[{{2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}], 
      LineBox[{{2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}], 
      LineBox[{{2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}], 
      LineBox[{{2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}], 
      LineBox[{{2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}], 
      LineBox[{{2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}], 
      LineBox[{{2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}], 
      LineBox[{{2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}], 
      LineBox[{{2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}], 
      LineBox[{{2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}], 
      LineBox[{{2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}], 
      LineBox[{{2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}], 
      LineBox[{{2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}], 
      LineBox[{{2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}], 
      LineBox[{{2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}], 
      LineBox[{{2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}], 
      LineBox[{{2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}], 
      LineBox[{{2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}], 
      LineBox[{{2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}], 
      LineBox[{{2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}], 
      LineBox[{{2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}], 
      LineBox[{{2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}], 
      LineBox[{{2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}], 
      LineBox[{{2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}], 
      LineBox[{{2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}], 
      LineBox[{{2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}], 
      LineBox[{{2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}], 
      LineBox[{{2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}], 
      LineBox[{{2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}], 
      LineBox[{{2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}], 
      LineBox[{{2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}], 
      LineBox[{{2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}], 
      LineBox[{{2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946978`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}], 
      LineBox[{{2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}], 
      LineBox[{{2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}], 
      LineBox[{{2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}], 
      LineBox[{{2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}], 
      LineBox[{{2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}], 
      LineBox[{{2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}], 
      LineBox[{{2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}], 
      LineBox[{{2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}], 
      LineBox[{{2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}], 
      LineBox[{{2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}], 
      LineBox[{{2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}], 
      LineBox[{{2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}], 
      LineBox[{{2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}], 
      LineBox[{{2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}], 
      LineBox[{{2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}], 
      LineBox[{{2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}], 
      LineBox[{{2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}], 
      LineBox[{{2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}], 
      LineBox[{{2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}], 
      LineBox[{{2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}], 
      LineBox[{{2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}], 
      LineBox[{{2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}], 
      LineBox[{{2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}], 
      LineBox[{{2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}], 
      LineBox[{{2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}], 
      LineBox[{{2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}], 
      LineBox[{{2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}], 
      LineBox[{{2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}], 
      LineBox[{{2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}], 
      LineBox[{{2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}], 
      LineBox[{{2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}], 
      LineBox[{{2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}], 
      LineBox[{{2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}], 
      LineBox[{{2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}], 
      LineBox[{{2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}], 
      LineBox[{{2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}], 
      LineBox[{{2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}], 
      LineBox[{{2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}], 
      LineBox[{{2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}], 
      LineBox[{{2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}], 
      LineBox[{{2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}], 
      LineBox[{{2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}], 
      LineBox[{{2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}], 
      LineBox[{{2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}], 
      LineBox[{{2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664749}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}], 
      LineBox[{{2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}], 
      LineBox[{{2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}], 
      LineBox[{{2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}], 
      LineBox[{{2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}], 
      LineBox[{{2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}], 
      LineBox[{{2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}], 
      LineBox[{{2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}], 
      LineBox[{{2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}], 
      LineBox[{{2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}], 
      LineBox[{{2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}], 
      LineBox[{{2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}], 
      LineBox[{{2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}], 
      LineBox[{{2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}], 
      LineBox[{{2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}], 
      LineBox[{{2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}], 
      LineBox[{{2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}], 
      LineBox[{{2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}], 
      LineBox[{{2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}], 
      LineBox[{{2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}], 
      LineBox[{{2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}], 
      LineBox[{{2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}], 
      LineBox[{{2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}], 
      LineBox[{{2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}], 
      LineBox[{{2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}], 
      LineBox[{{2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}], 
      LineBox[{{2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}], 
      LineBox[{{2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}], 
      LineBox[{{2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}], 
      LineBox[{{2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}], 
      LineBox[{{2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}], 
      LineBox[{{2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}], 
      LineBox[{{2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}], 
      LineBox[{{2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}], 
      LineBox[{{2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}], 
      LineBox[{{2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}], 
      LineBox[{{2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}], 
      LineBox[{{2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}], 
      LineBox[{{2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}], 
      LineBox[{{2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}], 
      LineBox[{{2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}], 
      LineBox[{{2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}], 
      LineBox[{{2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}], 
      LineBox[{{2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}], 
      LineBox[{{2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}], 
      LineBox[{{2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {2.330800232545931, 
       0.0626697869094773}, {2.4000468632139706`, 0.13737227969367127`}, {
       2.4000468632139706`, 0.13737227969367127`}, {2.330800232545931, 
       0.06266978690947729}, {2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.08673519865891072}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.400046863213971, 0.13737227969367133`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716687`}, {
       2.6588238891225138`, -0.012032705874716687`}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}], 
      LineBox[{{2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}], 
      LineBox[{{2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}], 
      LineBox[{{2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}], 
      LineBox[{{2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}], 
      LineBox[{{2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}], 
      LineBox[{{2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}], 
      LineBox[{{2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}], 
      LineBox[{{2.31378785457779, -0.012032705874716706`}, {2.330800232545931,
        0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}], 
      LineBox[{{2.31378785457779, -0.012032705874716706`}, {2.330800232545931,
        0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}], 
      LineBox[{{2.31378785457779, -0.012032705874716706`}, {2.330800232545931,
        0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}], 
      LineBox[{{2.31378785457779, -0.012032705874716706`}, {2.330800232545931,
        0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}], 
      LineBox[{{2.330800232545931, 0.0626697869094773}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}, {
       2.330800232545931, 0.0626697869094773}, {2.330800232545931, 
       0.0626697869094773}}], 
      LineBox[{{2.330800232545931, 0.0626697869094773}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}, {
       2.330800232545931, 0.0626697869094773}, {2.330800232545931, 
       0.0626697869094773}}], 
      LineBox[{{2.330800232545931, 0.0626697869094773}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}, {
       2.330800232545931, 0.0626697869094773}, {2.330800232545931, 
       0.0626697869094773}}], 
      LineBox[{{2.330800232545931, 0.0626697869094773}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}, {
       2.330800232545931, 0.0626697869094773}, {2.330800232545931, 
       0.0626697869094773}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}], 
      LineBox[{{2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}], 
      LineBox[{{2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}], 
      LineBox[{{2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}], 
      LineBox[{{2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}], 
      LineBox[{{2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}], 
      LineBox[{{2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}], 
      LineBox[{{2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}], 
      LineBox[{{2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}], 
      LineBox[{{2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}], 
      LineBox[{{2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}], 
      LineBox[{{2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}], 
      LineBox[{{2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}], 
      LineBox[{{2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}], 
      LineBox[{{2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}], 
      LineBox[{{2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.400046863213971, 0.13737227969367133`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}}], 
      LineBox[{{2.400046863213971, 0.13737227969367133`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}}], 
      LineBox[{{2.400046863213971, 0.13737227969367133`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}}], 
      LineBox[{{2.400046863213971, 0.13737227969367133`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}}], 
      LineBox[{{2.4993644350251265`, 0.15999037458657533`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}}], 
      LineBox[{{2.4993644350251265`, 0.15999037458657533`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}}], 
      LineBox[{{2.4993644350251265`, 0.15999037458657533`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}}], 
      LineBox[{{2.4993644350251265`, 0.15999037458657533`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}}], 
      LineBox[{{2.5725648804863326`, 0.13737227969367127`}, {
       2.628752947979398, 0.08528788180238134}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}], 
      LineBox[{{2.5725648804863326`, 0.13737227969367127`}, {
       2.628752947979398, 0.08528788180238134}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}], 
      LineBox[{{2.5725648804863326`, 0.13737227969367127`}, {
       2.628752947979398, 0.08528788180238134}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}], 
      LineBox[{{2.5725648804863326`, 0.13737227969367127`}, {
       2.628752947979398, 0.08528788180238134}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}], 
      LineBox[{{2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}], 
      LineBox[{{2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}], 
      LineBox[{{2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}], 
      LineBox[{{2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3987127096745144`, 0.3952951383987243}, {
       2.3340987007333425`, 0.4650000105364749}, {2.318224456289397, 
       0.5347048826742254}, {2.3340987007333425`, 0.604409754811976}, {
       2.3987127096745144`, 0.6741146269497266}, {2.3987127096745144`, 
       0.6741146269497266}, {2.3340987007333425`, 0.604409754811976}, {
       2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.44389507342194034`}, {2.55968921644475, 0.3952951383987243}, {
       2.4913859041839386`, 0.3741902012841898}, {2.398712709674515, 
       0.3952951383987243}, {2.398712709674515, 0.3952951383987243}, {
       2.4913859041839386`, 0.3741902012841898}, {2.55968921644475, 
       0.3952951383987243}, {2.612118284261615, 0.44389507342194034`}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.398712709674515, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.55968921644475, 0.6741146269497266}, {
       2.612118284261615, 0.6255146919265105}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.6255146919265105}, {2.55968921644475, 
       0.6741146269497266}, {2.4913859041839386`, 0.6952195640642611}, {
       2.398712709674515, 0.6741146269497266}, {2.398712709674515, 
       0.6741146269497266}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3987127096745144`, 0.3952951383987243}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}}], 
      LineBox[{{2.3987127096745144`, 0.3952951383987243}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}}], 
      LineBox[{{2.3987127096745144`, 0.3952951383987243}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}}], 
      LineBox[{{2.3987127096745144`, 0.3952951383987243}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}}], 
      LineBox[{{2.3340987007333425`, 0.4650000105364749}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}}], 
      LineBox[{{2.3340987007333425`, 0.4650000105364749}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}}], 
      LineBox[{{2.3340987007333425`, 0.4650000105364749}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}}], 
      LineBox[{{2.3340987007333425`, 0.4650000105364749}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}}], 
      LineBox[{{2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.604409754811976}, {2.3340987007333425`, 0.604409754811976}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}}], 
      LineBox[{{2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.604409754811976}, {2.3340987007333425`, 0.604409754811976}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}}], 
      LineBox[{{2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.604409754811976}, {2.3340987007333425`, 0.604409754811976}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}}], 
      LineBox[{{2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.604409754811976}, {2.3340987007333425`, 0.604409754811976}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}}], 
      LineBox[{{2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`,
        0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}}], 
      LineBox[{{2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`,
        0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}}], 
      LineBox[{{2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`,
        0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}}], 
      LineBox[{{2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`,
        0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}}], 
      LineBox[{{2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}}], 
      LineBox[{{2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}}], 
      LineBox[{{2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}}], 
      LineBox[{{2.612118284261615, 0.44389507342194034`}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}}], 
      LineBox[{{2.612118284261615, 0.44389507342194034`}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}}], 
      LineBox[{{2.612118284261615, 0.44389507342194034`}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}}], 
      LineBox[{{2.612118284261615, 0.44389507342194034`}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}}], 
      LineBox[{{2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}], 
      LineBox[{{2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}], 
      LineBox[{{2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}], 
      LineBox[{{2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}], 
      LineBox[{{2.4913859041839386`, 0.3741902012841898}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}}], 
      LineBox[{{2.4913859041839386`, 0.3741902012841898}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}}], 
      LineBox[{{2.4913859041839386`, 0.3741902012841898}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}}], 
      LineBox[{{2.4913859041839386`, 0.3741902012841898}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.398712709674515, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.4913859041839386`, 0.6952195640642611}, {
       2.398712709674515, 0.6741146269497266}, {2.398712709674515, 
       0.6741146269497266}}], 
      LineBox[{{2.398712709674515, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.4913859041839386`, 0.6952195640642611}, {
       2.398712709674515, 0.6741146269497266}, {2.398712709674515, 
       0.6741146269497266}}], 
      LineBox[{{2.398712709674515, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.4913859041839386`, 0.6952195640642611}, {
       2.398712709674515, 0.6741146269497266}, {2.398712709674515, 
       0.6741146269497266}}], 
      LineBox[{{2.398712709674515, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.4913859041839386`, 0.6952195640642611}, {
       2.398712709674515, 0.6741146269497266}, {2.398712709674515, 
       0.6741146269497266}}], 
      LineBox[{{2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}}], 
      LineBox[{{2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}}], 
      LineBox[{{2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}}], 
      LineBox[{{2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}}], 
      LineBox[{{2.55968921644475, 0.6741146269497266}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}}], 
      LineBox[{{2.55968921644475, 0.6741146269497266}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}}], 
      LineBox[{{2.55968921644475, 0.6741146269497266}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}}], 
      LineBox[{{2.55968921644475, 0.6741146269497266}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}}], 
      LineBox[{{2.612118284261615, 0.6255146919265105}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}}], 
      LineBox[{{2.612118284261615, 0.6255146919265105}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}}], 
      LineBox[{{2.612118284261615, 0.6255146919265105}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}}], 
      LineBox[{{2.612118284261615, 0.6255146919265105}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4018332238518814`, 0.8644592861496427}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3524497598137852`, 
       0.9177336163282379}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.524865019329917, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917, 
       1.0775566068640234`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4018332238518814`, 0.8644592861496427}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3524497598137852`, 
       0.9177336163282379}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}}], 
      LineBox[{{2.4018332238518814`, 0.8644592861496427}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3524497598137852`, 
       0.9177336163282379}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}}], 
      LineBox[{{2.4018332238518814`, 0.8644592861496427}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3524497598137852`, 
       0.9177336163282379}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}}], 
      LineBox[{{2.4018332238518814`, 0.8644592861496427}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3524497598137852`, 
       0.9177336163282379}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}}], 
      LineBox[{{2.3524497598137852`, 0.9177336163282379}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}}], 
      LineBox[{{2.3524497598137852`, 0.9177336163282379}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}}], 
      LineBox[{{2.3524497598137852`, 0.9177336163282379}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}}], 
      LineBox[{{2.3524497598137852`, 0.9177336163282379}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}}], 
      LineBox[{{2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}], 
      LineBox[{{2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}], 
      LineBox[{{2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}], 
      LineBox[{{2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}], 
      LineBox[{{2.3524497598137852`, 1.0242822766854283`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}}], 
      LineBox[{{2.3524497598137852`, 1.0242822766854283`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}}], 
      LineBox[{{2.3524497598137852`, 1.0242822766854283`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}}], 
      LineBox[{{2.3524497598137852`, 1.0242822766854283`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}], 
      LineBox[{{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}], 
      LineBox[{{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}], 
      LineBox[{{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}], 
      LineBox[{{2.5649357257837195`, 0.9016034470336689}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}}], 
      LineBox[{{2.5649357257837195`, 0.9016034470336689}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}}], 
      LineBox[{{2.5649357257837195`, 0.9016034470336689}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}}], 
      LineBox[{{2.5649357257837195`, 0.9016034470336689}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}}], 
      LineBox[{{2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}], 
      LineBox[{{2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}], 
      LineBox[{{2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}], 
      LineBox[{{2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}], 
      LineBox[{{2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}}], 
      LineBox[{{2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}}], 
      LineBox[{{2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}}], 
      LineBox[{{2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}], 
      LineBox[{{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}], 
      LineBox[{{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}], 
      LineBox[{{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}], 
      LineBox[{{2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917,
        1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}}], 
      LineBox[{{2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917,
        1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}}], 
      LineBox[{{2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917,
        1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}}], 
      LineBox[{{2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917,
        1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}}], 
      LineBox[{{2.524865019329917, 1.0775566068640234`}, {2.5649357257837195`,
        1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}}], 
      LineBox[{{2.524865019329917, 1.0775566068640234`}, {2.5649357257837195`,
        1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}}], 
      LineBox[{{2.524865019329917, 1.0775566068640234`}, {2.5649357257837195`,
        1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}}], 
      LineBox[{{2.524865019329917, 1.0775566068640234`}, {2.5649357257837195`,
        1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}}], 
      LineBox[{{2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5649357257837195`, 1.0404124459799973`}}], 
      LineBox[{{2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5649357257837195`, 1.0404124459799973`}}], 
      LineBox[{{2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5649357257837195`, 1.0404124459799973`}}], 
      LineBox[{{2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5649357257837195`, 1.0404124459799973`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864,
        1.4124740794433617`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`,
        1.3899582874473329`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.3954380777291933`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3954380777291933`, 1.635567907249537}, {2.4943064306580776`,
        1.6580836992455659`}, {2.5671757864471125`, 1.635567907249537}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.653044640806072, 
       1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.5671757864471125`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`,
        1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864,
        1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}], 
      LineBox[{{2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864,
        1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}], 
      LineBox[{{2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864,
        1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}], 
      LineBox[{{2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864,
        1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}], 
      LineBox[{{2.326504653409864, 1.4124740794433617`}, {2.3095692233702336`,
        1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.4124740794433617`}, {2.326504653409864, 
       1.4124740794433617`}}], 
      LineBox[{{2.326504653409864, 1.4124740794433617`}, {2.3095692233702336`,
        1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.4124740794433617`}, {2.326504653409864, 
       1.4124740794433617`}}], 
      LineBox[{{2.326504653409864, 1.4124740794433617`}, {2.3095692233702336`,
        1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.4124740794433617`}, {2.326504653409864, 
       1.4124740794433617`}}], 
      LineBox[{{2.326504653409864, 1.4124740794433617`}, {2.3095692233702336`,
        1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.4124740794433617`}, {2.326504653409864, 
       1.4124740794433617`}}], 
      LineBox[{{2.3095692233702336`, 1.4868386887120868`}, {2.326504653409864,
        1.561203297980812}, {2.326504653409864, 1.561203297980812}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}}], 
      LineBox[{{2.3095692233702336`, 1.4868386887120868`}, {2.326504653409864,
        1.561203297980812}, {2.326504653409864, 1.561203297980812}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}}], 
      LineBox[{{2.3095692233702336`, 1.4868386887120868`}, {2.326504653409864,
        1.561203297980812}, {2.326504653409864, 1.561203297980812}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}}], 
      LineBox[{{2.3095692233702336`, 1.4868386887120868`}, {2.326504653409864,
        1.561203297980812}, {2.326504653409864, 1.561203297980812}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}}], 
      LineBox[{{2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}}], 
      LineBox[{{2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}}], 
      LineBox[{{2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}}], 
      LineBox[{{2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`,
        1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}}], 
      LineBox[{{2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`,
        1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}}], 
      LineBox[{{2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`,
        1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}}], 
      LineBox[{{2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`,
        1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}}], 
      LineBox[{{2.6231097121965172`, 1.3899582874473329`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.6231097121965172`, 1.3899582874473329`}}], 
      LineBox[{{2.6231097121965172`, 1.3899582874473329`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.6231097121965172`, 1.3899582874473329`}}], 
      LineBox[{{2.6231097121965172`, 1.3899582874473329`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.6231097121965172`, 1.3899582874473329`}}], 
      LineBox[{{2.6231097121965172`, 1.3899582874473329`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.6231097121965172`, 1.3899582874473329`}}], 
      LineBox[{{2.5671757864471125`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}}], 
      LineBox[{{2.5671757864471125`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}}], 
      LineBox[{{2.5671757864471125`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}}], 
      LineBox[{{2.5671757864471125`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}}], 
      LineBox[{{2.4943064306580776`, 1.3155936781786077`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}}], 
      LineBox[{{2.4943064306580776`, 1.3155936781786077`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}}], 
      LineBox[{{2.4943064306580776`, 1.3155936781786077`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}}], 
      LineBox[{{2.4943064306580776`, 1.3155936781786077`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3954380777291933`, 1.635567907249537}, {2.4943064306580776`,
        1.6580836992455659`}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}}], 
      LineBox[{{2.3954380777291933`, 1.635567907249537}, {2.4943064306580776`,
        1.6580836992455659`}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}}], 
      LineBox[{{2.3954380777291933`, 1.635567907249537}, {2.4943064306580776`,
        1.6580836992455659`}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}}], 
      LineBox[{{2.3954380777291933`, 1.635567907249537}, {2.4943064306580776`,
        1.6580836992455659`}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}}], 
      LineBox[{{2.4943064306580776`, 1.6580836992455659`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}}], 
      LineBox[{{2.4943064306580776`, 1.6580836992455659`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}}], 
      LineBox[{{2.4943064306580776`, 1.6580836992455659`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}}], 
      LineBox[{{2.4943064306580776`, 1.6580836992455659`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}}], 
      LineBox[{{2.5671757864471125`, 1.635567907249537}, {2.6231097121965172`,
        1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}}], 
      LineBox[{{2.5671757864471125`, 1.635567907249537}, {2.6231097121965172`,
        1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}}], 
      LineBox[{{2.5671757864471125`, 1.635567907249537}, {2.6231097121965172`,
        1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}}], 
      LineBox[{{2.5671757864471125`, 1.635567907249537}, {2.6231097121965172`,
        1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}}], 
      LineBox[{{2.6231097121965172`, 1.5837190899768407`}, {2.653044640806072,
        1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}}], 
      LineBox[{{2.6231097121965172`, 1.5837190899768407`}, {2.653044640806072,
        1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}}], 
      LineBox[{{2.6231097121965172`, 1.5837190899768407`}, {2.653044640806072,
        1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}}], 
      LineBox[{{2.6231097121965172`, 1.5837190899768407`}, {2.653044640806072,
        1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353,
        1.9073760379293059`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.545188770588818, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4095616521939496`, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.545188770588818, 2.08356083288736}, {
       2.5893616970039752`, 2.0426140557853767`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 2.0426140557853767`}, {2.545188770588818, 
       2.08356083288736}, {2.4876413582078234`, 2.101342320771395}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353,
        1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}], 
      LineBox[{{2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353,
        1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}], 
      LineBox[{{2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353,
        1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}], 
      LineBox[{{2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353,
        1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}], 
      LineBox[{{2.355122578962353, 1.9073760379293059`}, {2.3417480929965153`,
        1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 1.9073760379293059`}, {2.355122578962353, 
       1.9073760379293059`}}], 
      LineBox[{{2.355122578962353, 1.9073760379293059`}, {2.3417480929965153`,
        1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 1.9073760379293059`}, {2.355122578962353, 
       1.9073760379293059`}}], 
      LineBox[{{2.355122578962353, 1.9073760379293059`}, {2.3417480929965153`,
        1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 1.9073760379293059`}, {2.355122578962353, 
       1.9073760379293059`}}], 
      LineBox[{{2.355122578962353, 1.9073760379293059`}, {2.3417480929965153`,
        1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 1.9073760379293059`}, {2.355122578962353, 
       1.9073760379293059`}}], 
      LineBox[{{2.3417480929965153`, 1.9661043029153238`}, {2.355122578962353,
        2.024832567901342}, {2.355122578962353, 2.024832567901342}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}}], 
      LineBox[{{2.3417480929965153`, 1.9661043029153238`}, {2.355122578962353,
        2.024832567901342}, {2.355122578962353, 2.024832567901342}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}}], 
      LineBox[{{2.3417480929965153`, 1.9661043029153238`}, {2.355122578962353,
        2.024832567901342}, {2.355122578962353, 2.024832567901342}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}}], 
      LineBox[{{2.3417480929965153`, 1.9661043029153238`}, {2.355122578962353,
        2.024832567901342}, {2.355122578962353, 2.024832567901342}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}}], 
      LineBox[{{2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}}], 
      LineBox[{{2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}}], 
      LineBox[{{2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}}], 
      LineBox[{{2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}], 
      LineBox[{{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}], 
      LineBox[{{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}], 
      LineBox[{{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}], 
      LineBox[{{2.5893616970039752`, 1.8895945500452707`}, {2.545188770588818,
        1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}}], 
      LineBox[{{2.5893616970039752`, 1.8895945500452707`}, {2.545188770588818,
        1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}}], 
      LineBox[{{2.5893616970039752`, 1.8895945500452707`}, {2.545188770588818,
        1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}}], 
      LineBox[{{2.5893616970039752`, 1.8895945500452707`}, {2.545188770588818,
        1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}}], 
      LineBox[{{2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`,
        1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}], 
      LineBox[{{2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`,
        1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}], 
      LineBox[{{2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`,
        1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}], 
      LineBox[{{2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`,
        1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}], 
      LineBox[{{2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}}], 
      LineBox[{{2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}}], 
      LineBox[{{2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}}], 
      LineBox[{{2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4095616521939496`, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4876413582078234`, 2.101342320771395}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}}], 
      LineBox[{{2.4095616521939496`, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4876413582078234`, 2.101342320771395}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}}], 
      LineBox[{{2.4095616521939496`, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4876413582078234`, 2.101342320771395}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}}], 
      LineBox[{{2.4095616521939496`, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4876413582078234`, 2.101342320771395}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}}], 
      LineBox[{{2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}}], 
      LineBox[{{2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}}], 
      LineBox[{{2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}}], 
      LineBox[{{2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}}], 
      LineBox[{{2.545188770588818, 2.08356083288736}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}}], 
      LineBox[{{2.545188770588818, 2.08356083288736}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}}], 
      LineBox[{{2.545188770588818, 2.08356083288736}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}}], 
      LineBox[{{2.545188770588818, 2.08356083288736}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}}], 
      LineBox[{{2.5893616970039752`, 2.0426140557853767`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.5893616970039752`, 2.0426140557853767`}}], 
      LineBox[{{2.5893616970039752`, 2.0426140557853767`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.5893616970039752`, 2.0426140557853767`}}], 
      LineBox[{{2.5893616970039752`, 2.0426140557853767`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.5893616970039752`, 2.0426140557853767`}}], 
      LineBox[{{2.5893616970039752`, 2.0426140557853767`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.5893616970039752`, 2.0426140557853767`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4244243699269568`, 2.4042167880991805`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`,
        2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`,
        2.4511497900904664`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.4244243699269568`, 
       2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4244243699269568`, 2.4042167880991805`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}}], 
      LineBox[{{2.4244243699269568`, 2.4042167880991805`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}}], 
      LineBox[{{2.4244243699269568`, 2.4042167880991805`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}}], 
      LineBox[{{2.4244243699269568`, 2.4042167880991805`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}}], 
      LineBox[{{2.3620265620111156`, 2.4715308472904245`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}}], 
      LineBox[{{2.3620265620111156`, 2.4715308472904245`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}}], 
      LineBox[{{2.3620265620111156`, 2.4715308472904245`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}}], 
      LineBox[{{2.3620265620111156`, 2.4715308472904245`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}}], 
      LineBox[{{2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`,
        2.6061589656729134`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}}], 
      LineBox[{{2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`,
        2.6061589656729134`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}}], 
      LineBox[{{2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`,
        2.6061589656729134`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}}], 
      LineBox[{{2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`,
        2.6061589656729134`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}}], 
      LineBox[{{2.3620265620111156`, 2.6061589656729134`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}}], 
      LineBox[{{2.3620265620111156`, 2.6061589656729134`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}}], 
      LineBox[{{2.3620265620111156`, 2.6061589656729134`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}}], 
      LineBox[{{2.3620265620111156`, 2.6061589656729134`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`,
        2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}}], 
      LineBox[{{2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`,
        2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}}], 
      LineBox[{{2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`,
        2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}}], 
      LineBox[{{2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`,
        2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}}], 
      LineBox[{{2.6305103297592787`, 2.4511497900904664`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6305103297592787`, 2.4511497900904664`}}], 
      LineBox[{{2.6305103297592787`, 2.4511497900904664`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6305103297592787`, 2.4511497900904664`}}], 
      LineBox[{{2.6305103297592787`, 2.4511497900904664`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6305103297592787`, 2.4511497900904664`}}], 
      LineBox[{{2.6305103297592787`, 2.4511497900904664`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6305103297592787`, 2.4511497900904664`}}], 
      LineBox[{{2.5798795307042024`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}}], 
      LineBox[{{2.5798795307042024`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}}], 
      LineBox[{{2.5798795307042024`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}}], 
      LineBox[{{2.5798795307042024`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}}], 
      LineBox[{{2.5139189591763444`, 2.383835730899222}, {2.4244243699269568`,
        2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}}], 
      LineBox[{{2.5139189591763444`, 2.383835730899222}, {2.4244243699269568`,
        2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}}], 
      LineBox[{{2.5139189591763444`, 2.383835730899222}, {2.4244243699269568`,
        2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}}], 
      LineBox[{{2.5139189591763444`, 2.383835730899222}, {2.4244243699269568`,
        2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}], 
      LineBox[{{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}], 
      LineBox[{{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}], 
      LineBox[{{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}], 
      LineBox[{{2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`,
        2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}}], 
      LineBox[{{2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`,
        2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}}], 
      LineBox[{{2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`,
        2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}}], 
      LineBox[{{2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`,
        2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}}], 
      LineBox[{{2.5798795307042024`, 2.6734730248641574`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}], 
      LineBox[{{2.5798795307042024`, 2.6734730248641574`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}], 
      LineBox[{{2.5798795307042024`, 2.6734730248641574`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}], 
      LineBox[{{2.5798795307042024`, 2.6734730248641574`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}], 
      LineBox[{{2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6305103297592787`, 2.6265400228728715`}}], 
      LineBox[{{2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6305103297592787`, 2.6265400228728715`}}], 
      LineBox[{{2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6305103297592787`, 2.6265400228728715`}}], 
      LineBox[{{2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6305103297592787`, 2.6265400228728715`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.301431734658341, 
       2.981364336584796}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.3807909082532364`, 
       2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3807909082532364`, 3.118818457297833}, {2.4721640940456706`,
        3.1396273368267233`}, {2.5395092554430265`, 3.118818457297833}, {
       2.5912028544380137`, 3.070900276470205}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 3.070900276470205}, {2.5395092554430265`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`,
        3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}], 
      LineBox[{{2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}], 
      LineBox[{{2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}], 
      LineBox[{{2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}], 
      LineBox[{{2.31708329706071, 2.9126372762282777`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 2.9126372762282777`}, {2.31708329706071, 
       2.9126372762282777`}}], 
      LineBox[{{2.31708329706071, 2.9126372762282777`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 2.9126372762282777`}, {2.31708329706071, 
       2.9126372762282777`}}], 
      LineBox[{{2.31708329706071, 2.9126372762282777`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 2.9126372762282777`}, {2.31708329706071, 
       2.9126372762282777`}}], 
      LineBox[{{2.31708329706071, 2.9126372762282777`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 2.9126372762282777`}, {2.31708329706071, 
       2.9126372762282777`}}], 
      LineBox[{{2.301431734658341, 2.981364336584796}, {2.31708329706071, 
       3.0500913969413146`}, {2.31708329706071, 3.0500913969413146`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}}], 
      LineBox[{{2.301431734658341, 2.981364336584796}, {2.31708329706071, 
       3.0500913969413146`}, {2.31708329706071, 3.0500913969413146`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}}], 
      LineBox[{{2.301431734658341, 2.981364336584796}, {2.31708329706071, 
       3.0500913969413146`}, {2.31708329706071, 3.0500913969413146`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}}], 
      LineBox[{{2.301431734658341, 2.981364336584796}, {2.31708329706071, 
       3.0500913969413146`}, {2.31708329706071, 3.0500913969413146`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}}], 
      LineBox[{{2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}}], 
      LineBox[{{2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}}], 
      LineBox[{{2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}}], 
      LineBox[{{2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}}], 
      LineBox[{{2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}}], 
      LineBox[{{2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}}], 
      LineBox[{{2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}}], 
      LineBox[{{2.5912028544380137`, 2.8918283966993874`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5912028544380137`, 2.8918283966993874`}}], 
      LineBox[{{2.5912028544380137`, 2.8918283966993874`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5912028544380137`, 2.8918283966993874`}}], 
      LineBox[{{2.5912028544380137`, 2.8918283966993874`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5912028544380137`, 2.8918283966993874`}}], 
      LineBox[{{2.5912028544380137`, 2.8918283966993874`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5912028544380137`, 2.8918283966993874`}}], 
      LineBox[{{2.5395092554430265`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}}], 
      LineBox[{{2.5395092554430265`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}}], 
      LineBox[{{2.5395092554430265`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}}], 
      LineBox[{{2.5395092554430265`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}}], 
      LineBox[{{2.4721640940456706`, 2.823101336342869}, {2.3807909082532364`,
        2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}}], 
      LineBox[{{2.4721640940456706`, 2.823101336342869}, {2.3807909082532364`,
        2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}}], 
      LineBox[{{2.4721640940456706`, 2.823101336342869}, {2.3807909082532364`,
        2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}}], 
      LineBox[{{2.4721640940456706`, 2.823101336342869}, {2.3807909082532364`,
        2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.3807909082532364`, 3.118818457297833}, {2.4721640940456706`,
        3.1396273368267233`}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}}], 
      LineBox[{{2.3807909082532364`, 3.118818457297833}, {2.4721640940456706`,
        3.1396273368267233`}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}}], 
      LineBox[{{2.3807909082532364`, 3.118818457297833}, {2.4721640940456706`,
        3.1396273368267233`}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}}], 
      LineBox[{{2.3807909082532364`, 3.118818457297833}, {2.4721640940456706`,
        3.1396273368267233`}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}}], 
      LineBox[{{2.4721640940456706`, 3.1396273368267233`}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}}], 
      LineBox[{{2.4721640940456706`, 3.1396273368267233`}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}}], 
      LineBox[{{2.4721640940456706`, 3.1396273368267233`}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}}], 
      LineBox[{{2.4721640940456706`, 3.1396273368267233`}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}}], 
      LineBox[{{2.5395092554430265`, 3.118818457297833}, {2.5912028544380137`,
        3.070900276470205}, {2.5912028544380137`, 3.070900276470205}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}}], 
      LineBox[{{2.5395092554430265`, 3.118818457297833}, {2.5912028544380137`,
        3.070900276470205}, {2.5912028544380137`, 3.070900276470205}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}}], 
      LineBox[{{2.5395092554430265`, 3.118818457297833}, {2.5912028544380137`,
        3.070900276470205}, {2.5912028544380137`, 3.070900276470205}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}}], 
      LineBox[{{2.5395092554430265`, 3.118818457297833}, {2.5912028544380137`,
        3.070900276470205}, {2.5912028544380137`, 3.070900276470205}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}}], 
      LineBox[{{2.5912028544380137`, 3.070900276470205}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}}], 
      LineBox[{{2.5912028544380137`, 3.070900276470205}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}}], 
      LineBox[{{2.5912028544380137`, 3.070900276470205}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}}], 
      LineBox[{{2.5912028544380137`, 3.070900276470205}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.351811450299151, 
       3.468550018932752}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.3705050215868937`}, {2.612514693302098, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.612514693302098, 
       3.318032931406392}, {2.669120998912425, 3.3705050215868937`}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.438712531300133, 3.6190671064591116`}, {2.5387693774109517`,
        3.6418535600417896`}, {2.612514693302098, 3.6190671064591116`}, {
       2.669120998912425, 3.56659501627861}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.56659501627861}, {2.612514693302098, 
       3.6190671064591116`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}], 
      LineBox[{{2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}], 
      LineBox[{{2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}], 
      LineBox[{{2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}], 
      LineBox[{{2.3689504605799696`, 3.3932914751695717`}, {2.351811450299151,
        3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.3689504605799696`, 
       3.3932914751695717`}}], 
      LineBox[{{2.3689504605799696`, 3.3932914751695717`}, {2.351811450299151,
        3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.3689504605799696`, 
       3.3932914751695717`}}], 
      LineBox[{{2.3689504605799696`, 3.3932914751695717`}, {2.351811450299151,
        3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.3689504605799696`, 
       3.3932914751695717`}}], 
      LineBox[{{2.3689504605799696`, 3.3932914751695717`}, {2.351811450299151,
        3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.3689504605799696`, 
       3.3932914751695717`}}], 
      LineBox[{{2.351811450299151, 3.468550018932752}, {2.3689504605799696`, 
       3.543808562695932}, {2.3689504605799696`, 3.543808562695932}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}}], 
      LineBox[{{2.351811450299151, 3.468550018932752}, {2.3689504605799696`, 
       3.543808562695932}, {2.3689504605799696`, 3.543808562695932}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}}], 
      LineBox[{{2.351811450299151, 3.468550018932752}, {2.3689504605799696`, 
       3.543808562695932}, {2.3689504605799696`, 3.543808562695932}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}}], 
      LineBox[{{2.351811450299151, 3.468550018932752}, {2.3689504605799696`, 
       3.543808562695932}, {2.3689504605799696`, 3.543808562695932}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}}], 
      LineBox[{{2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}}], 
      LineBox[{{2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}}], 
      LineBox[{{2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}}], 
      LineBox[{{2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}}], 
      LineBox[{{2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}}], 
      LineBox[{{2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}}], 
      LineBox[{{2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}}], 
      LineBox[{{2.669120998912425, 3.3705050215868937`}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}}], 
      LineBox[{{2.669120998912425, 3.3705050215868937`}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}}], 
      LineBox[{{2.669120998912425, 3.3705050215868937`}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}}], 
      LineBox[{{2.669120998912425, 3.3705050215868937`}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}}], 
      LineBox[{{2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}], 
      LineBox[{{2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}], 
      LineBox[{{2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}], 
      LineBox[{{2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}], 
      LineBox[{{2.5387693774109517`, 3.295246477823714}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.5387693774109517`, 
       3.295246477823714}}], 
      LineBox[{{2.5387693774109517`, 3.295246477823714}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.5387693774109517`, 
       3.295246477823714}}], 
      LineBox[{{2.5387693774109517`, 3.295246477823714}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.5387693774109517`, 
       3.295246477823714}}], 
      LineBox[{{2.5387693774109517`, 3.295246477823714}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.5387693774109517`, 
       3.295246477823714}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.438712531300133, 3.6190671064591116`}, {2.5387693774109517`,
        3.6418535600417896`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}}], 
      LineBox[{{2.438712531300133, 3.6190671064591116`}, {2.5387693774109517`,
        3.6418535600417896`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}}], 
      LineBox[{{2.438712531300133, 3.6190671064591116`}, {2.5387693774109517`,
        3.6418535600417896`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}}], 
      LineBox[{{2.438712531300133, 3.6190671064591116`}, {2.5387693774109517`,
        3.6418535600417896`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}}], 
      LineBox[{{2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098,
        3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}}], 
      LineBox[{{2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098,
        3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}}], 
      LineBox[{{2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098,
        3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}}], 
      LineBox[{{2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098,
        3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}}], 
      LineBox[{{2.612514693302098, 3.6190671064591116`}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}}], 
      LineBox[{{2.612514693302098, 3.6190671064591116`}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}}], 
      LineBox[{{2.612514693302098, 3.6190671064591116`}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}}], 
      LineBox[{{2.612514693302098, 3.6190671064591116`}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}}], 
      LineBox[{{2.669120998912425, 3.56659501627861}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}}], 
      LineBox[{{2.669120998912425, 3.56659501627861}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}}], 
      LineBox[{{2.669120998912425, 3.56659501627861}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}}], 
      LineBox[{{2.669120998912425, 3.56659501627861}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7020187365642525`, -4.3990022793182435`}, {
       2.7020187365642525`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}], 
      LineBox[{{2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}], 
      LineBox[{{2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}], 
      LineBox[{{2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}], 
      LineBox[{{2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}], 
      LineBox[{{2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}], 
      LineBox[{{2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}], 
      LineBox[{{2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}], 
      LineBox[{{2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}], 
      LineBox[{{2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}], 
      LineBox[{{2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}], 
      LineBox[{{2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}], 
      LineBox[{{2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}], 
      LineBox[{{2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}], 
      LineBox[{{2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}], 
      LineBox[{{2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}], 
      LineBox[{{2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}], 
      LineBox[{{2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}], 
      LineBox[{{2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}], 
      LineBox[{{2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}], 
      LineBox[{{2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}], 
      LineBox[{{2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}], 
      LineBox[{{2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}], 
      LineBox[{{2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}], 
      LineBox[{{2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}], 
      LineBox[{{2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}], 
      LineBox[{{2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}], 
      LineBox[{{2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}], 
      LineBox[{{2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}], 
      LineBox[{{2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}], 
      LineBox[{{2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}], 
      LineBox[{{2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}], 
      LineBox[{{2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}], 
      LineBox[{{2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}], 
      LineBox[{{2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}], 
      LineBox[{{2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}], 
      LineBox[{{2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}], 
      LineBox[{{2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}], 
      LineBox[{{2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}], 
      LineBox[{{2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}], 
      LineBox[{{2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}], 
      LineBox[{{2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}], 
      LineBox[{{2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}], 
      LineBox[{{2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}], 
      LineBox[{{2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}], 
      LineBox[{{2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}], 
      LineBox[{{2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}], 
      LineBox[{{2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}], 
      LineBox[{{2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}], 
      LineBox[{{2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}], 
      LineBox[{{2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}], 
      LineBox[{{2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}], 
      LineBox[{{2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}], 
      LineBox[{{2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}], 
      LineBox[{{2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}], 
      LineBox[{{2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}], 
      LineBox[{{2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}], 
      LineBox[{{2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}], 
      LineBox[{{2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}], 
      LineBox[{{2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}], 
      LineBox[{{2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}], 
      LineBox[{{2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}], 
      LineBox[{{2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}], 
      LineBox[{{2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}], 
      LineBox[{{2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}], 
      LineBox[{{2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}], 
      LineBox[{{2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}], 
      LineBox[{{2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}], 
      LineBox[{{2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}], 
      LineBox[{{2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}], 
      LineBox[{{2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}], 
      LineBox[{{2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}], 
      LineBox[{{2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}], 
      LineBox[{{2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}], 
      LineBox[{{2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}], 
      LineBox[{{2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}], 
      LineBox[{{2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}], 
      LineBox[{{2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}], 
      LineBox[{{2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}], 
      LineBox[{{2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}], 
      LineBox[{{2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}], 
      LineBox[{{2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}], 
      LineBox[{{2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}], 
      LineBox[{{2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}], 
      LineBox[{{2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}], 
      LineBox[{{2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}], 
      LineBox[{{2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}], 
      LineBox[{{2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}], 
      LineBox[{{2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}], 
      LineBox[{{2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}], 
      LineBox[{{2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.8751543228139944`, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}], 
      LineBox[{{2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}], 
      LineBox[{{2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}], 
      LineBox[{{2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}], 
      LineBox[{{2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}], 
      LineBox[{{2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}], 
      LineBox[{{2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}], 
      LineBox[{{2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}], 
      LineBox[{{2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}], 
      LineBox[{{2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}], 
      LineBox[{{2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}], 
      LineBox[{{2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}], 
      LineBox[{{2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}], 
      LineBox[{{2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}], 
      LineBox[{{2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}], 
      LineBox[{{2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}], 
      LineBox[{{2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}], 
      LineBox[{{2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}], 
      LineBox[{{2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}], 
      LineBox[{{2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}], 
      LineBox[{{2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}], 
      LineBox[{{2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}], 
      LineBox[{{2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}], 
      LineBox[{{2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}], 
      LineBox[{{2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}], 
      LineBox[{{2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}], 
      LineBox[{{2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}], 
      LineBox[{{2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}], 
      LineBox[{{2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}], 
      LineBox[{{2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}], 
      LineBox[{{2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}], 
      LineBox[{{2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}], 
      LineBox[{{2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}], 
      LineBox[{{2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}], 
      LineBox[{{2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}], 
      LineBox[{{2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}], 
      LineBox[{{2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}], 
      LineBox[{{2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}], 
      LineBox[{{2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}], 
      LineBox[{{2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}], 
      LineBox[{{2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}], 
      LineBox[{{2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}], 
      LineBox[{{2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}], 
      LineBox[{{2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}], 
      LineBox[{{2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}], 
      LineBox[{{2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}], 
      LineBox[{{2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}], 
      LineBox[{{2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}], 
      LineBox[{{2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}], 
      LineBox[{{2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}], 
      LineBox[{{2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}], 
      LineBox[{{2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}], 
      LineBox[{{2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}], 
      LineBox[{{2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}], 
      LineBox[{{2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}], 
      LineBox[{{2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}], 
      LineBox[{{2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}], 
      LineBox[{{2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}], 
      LineBox[{{2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}], 
      LineBox[{{2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}], 
      LineBox[{{2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}], 
      LineBox[{{2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}], 
      LineBox[{{2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}], 
      LineBox[{{2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}], 
      LineBox[{{2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}], 
      LineBox[{{2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}], 
      LineBox[{{2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}], 
      LineBox[{{2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}], 
      LineBox[{{2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}], 
      LineBox[{{2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}], 
      LineBox[{{2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}], 
      LineBox[{{2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}], 
      LineBox[{{2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}], 
      LineBox[{{2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}], 
      LineBox[{{2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}], 
      LineBox[{{2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}], 
      LineBox[{{2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}], 
      LineBox[{{2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}], 
      LineBox[{{2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}], 
      LineBox[{{2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}], 
      LineBox[{{2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}], 
      LineBox[{{2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}], 
      LineBox[{{2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}], 
      LineBox[{{2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}], 
      LineBox[{{2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}], 
      LineBox[{{2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}], 
      LineBox[{{2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}], 
      LineBox[{{2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}], 
      LineBox[{{2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}], 
      LineBox[{{2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}], 
      LineBox[{{2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}], 
      LineBox[{{2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}], 
      LineBox[{{2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}], 
      LineBox[{{2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}], 
      LineBox[{{2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}], 
      LineBox[{{2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}], 
      LineBox[{{2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}], 
      LineBox[{{2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}], 
      LineBox[{{2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}], 
      LineBox[{{2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}], 
      LineBox[{{2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}], 
      LineBox[{{2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}], 
      LineBox[{{2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}], 
      LineBox[{{2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}], 
      LineBox[{{2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}], 
      LineBox[{{2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}], 
      LineBox[{{2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}], 
      LineBox[{{2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}], 
      LineBox[{{2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}], 
      LineBox[{{2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}], 
      LineBox[{{2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}], 
      LineBox[{{2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}], 
      LineBox[{{2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}], 
      LineBox[{{2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}], 
      LineBox[{{2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}], 
      LineBox[{{2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}], 
      LineBox[{{2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}], 
      LineBox[{{2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}], 
      LineBox[{{2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}], 
      LineBox[{{2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}], 
      LineBox[{{2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}], 
      LineBox[{{2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}], 
      LineBox[{{2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}], 
      LineBox[{{2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}], 
      LineBox[{{2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}], 
      LineBox[{{2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}], 
      LineBox[{{2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}], 
      LineBox[{{2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}], 
      LineBox[{{2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}], 
      LineBox[{{2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}], 
      LineBox[{{2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}], 
      LineBox[{{2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}], 
      LineBox[{{2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}], 
      LineBox[{{2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}], 
      LineBox[{{2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}], 
      LineBox[{{2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}], 
      LineBox[{{2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}], 
      LineBox[{{2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}], 
      LineBox[{{2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}], 
      LineBox[{{2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}], 
      LineBox[{{2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}], 
      LineBox[{{2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}], 
      LineBox[{{2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}], 
      LineBox[{{2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}], 
      LineBox[{{2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}], 
      LineBox[{{2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}], 
      LineBox[{{2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}], 
      LineBox[{{2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}], 
      LineBox[{{2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}], 
      LineBox[{{2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}], 
      LineBox[{{2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}], 
      LineBox[{{2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}], 
      LineBox[{{2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}], 
      LineBox[{{2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}], 
      LineBox[{{2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}], 
      LineBox[{{2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}], 
      LineBox[{{2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}], 
      LineBox[{{2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}], 
      LineBox[{{2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}], 
      LineBox[{{2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}], 
      LineBox[{{2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}], 
      LineBox[{{2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}], 
      LineBox[{{2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}], 
      LineBox[{{2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}], 
      LineBox[{{2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}], 
      LineBox[{{2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}], 
      LineBox[{{2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}], 
      LineBox[{{2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}], 
      LineBox[{{2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}], 
      LineBox[{{2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}], 
      LineBox[{{2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}], 
      LineBox[{{2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}], 
      LineBox[{{2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}], 
      LineBox[{{2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}], 
      LineBox[{{2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}], 
      LineBox[{{2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}], 
      LineBox[{{2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}], 
      LineBox[{{2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}], 
      LineBox[{{2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}], 
      LineBox[{{2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}], 
      LineBox[{{2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.721727770850301, -1.1056427388683707`}, {
       2.721727770850301, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}], 
      LineBox[{{2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}], 
      LineBox[{{2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}], 
      LineBox[{{2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}], 
      LineBox[{{2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}], 
      LineBox[{{2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}], 
      LineBox[{{2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}], 
      LineBox[{{2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}], 
      LineBox[{{2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}], 
      LineBox[{{2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}], 
      LineBox[{{2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}], 
      LineBox[{{2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}], 
      LineBox[{{2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}], 
      LineBox[{{2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}], 
      LineBox[{{2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}], 
      LineBox[{{2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}], 
      LineBox[{{2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}], 
      LineBox[{{2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}], 
      LineBox[{{2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}], 
      LineBox[{{2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}], 
      LineBox[{{2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}], 
      LineBox[{{2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}], 
      LineBox[{{2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}], 
      LineBox[{{2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}], 
      LineBox[{{2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}], 
      LineBox[{{2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}], 
      LineBox[{{2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}], 
      LineBox[{{2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}], 
      LineBox[{{2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}], 
      LineBox[{{2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}], 
      LineBox[{{2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}], 
      LineBox[{{2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}], 
      LineBox[{{2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}], 
      LineBox[{{2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}], 
      LineBox[{{2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}], 
      LineBox[{{2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}], 
      LineBox[{{2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}], 
      LineBox[{{2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}], 
      LineBox[{{2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}], 
      LineBox[{{2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}], 
      LineBox[{{2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}], 
      LineBox[{{2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}], 
      LineBox[{{2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}], 
      LineBox[{{2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}], 
      LineBox[{{2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}], 
      LineBox[{{2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750842}, {
       2.7149858853970987`, -0.6447945605750842}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.895670479371751}, {
       2.7149858853970987`, -0.895670479371751}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}], 
      LineBox[{{2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}], 
      LineBox[{{2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}], 
      LineBox[{{2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}], 
      LineBox[{{2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}], 
      LineBox[{{2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}], 
      LineBox[{{2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}], 
      LineBox[{{2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}], 
      LineBox[{{2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}], 
      LineBox[{{2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}], 
      LineBox[{{2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}], 
      LineBox[{{2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}], 
      LineBox[{{2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}], 
      LineBox[{{2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}], 
      LineBox[{{2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}], 
      LineBox[{{2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}], 
      LineBox[{{2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}], 
      LineBox[{{2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}], 
      LineBox[{{2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}], 
      LineBox[{{2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}], 
      LineBox[{{2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}], 
      LineBox[{{2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}], 
      LineBox[{{2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}], 
      LineBox[{{2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}], 
      LineBox[{{2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}], 
      LineBox[{{2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}], 
      LineBox[{{2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}], 
      LineBox[{{2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}], 
      LineBox[{{2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}], 
      LineBox[{{2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}], 
      LineBox[{{2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}], 
      LineBox[{{2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}], 
      LineBox[{{2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}], 
      LineBox[{{2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}], 
      LineBox[{{2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}], 
      LineBox[{{2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}], 
      LineBox[{{2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}], 
      LineBox[{{2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}], 
      LineBox[{{2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}], 
      LineBox[{{2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}], 
      LineBox[{{2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}], 
      LineBox[{{2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}], 
      LineBox[{{2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}], 
      LineBox[{{2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}], 
      LineBox[{{2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}], 
      LineBox[{{2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}], 
      LineBox[{{2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}], 
      LineBox[{{2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}], 
      LineBox[{{2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}], 
      LineBox[{{2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}], 
      LineBox[{{2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}], 
      LineBox[{{2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}], 
      LineBox[{{2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}], 
      LineBox[{{2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}], 
      LineBox[{{2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}], 
      LineBox[{{2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}], 
      LineBox[{{2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}], 
      LineBox[{{2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}], 
      LineBox[{{2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}], 
      LineBox[{{2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}], 
      LineBox[{{2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}], 
      LineBox[{{2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}], 
      LineBox[{{2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}], 
      LineBox[{{2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}], 
      LineBox[{{2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}], 
      LineBox[{{2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}], 
      LineBox[{{2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}], 
      LineBox[{{2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}], 
      LineBox[{{2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}], 
      LineBox[{{2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}], 
      LineBox[{{2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}], 
      LineBox[{{2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}], 
      LineBox[{{2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}], 
      LineBox[{{2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}], 
      LineBox[{{2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}], 
      LineBox[{{2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}], 
      LineBox[{{2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}], 
      LineBox[{{2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}], 
      LineBox[{{2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}], 
      LineBox[{{2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}], 
      LineBox[{{2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}], 
      LineBox[{{2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}], 
      LineBox[{{2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}], 
      LineBox[{{2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}], 
      LineBox[{{2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}], 
      LineBox[{{2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}], 
      LineBox[{{2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}], 
      LineBox[{{2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}], 
      LineBox[{{2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}], 
      LineBox[{{2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}], 
      LineBox[{{2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6465276450782134`, 0.08724129137790171}, {2.57529902478603, 
       0.16408193246140756`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.3177632146284193}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.57529902478603, 0.3177632146284193}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.57529902478603, 0.16408193246140756`}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8239835043352755`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.6465276450782134`, 
       0.08724129137790171}, {2.6465276450782134`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8817797968885, 0.34102868873621306`}, {
       2.9127114339638065`, 0.24092257354491345`}, {2.9127114339638065`, 
       0.24092257354491345`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6465276450782134`, 0.08724129137790171}, {2.57529902478603, 
       0.16408193246140756`}, {2.57529902478603, 0.16408193246140756`}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}}], 
      LineBox[{{2.6465276450782134`, 0.08724129137790171}, {2.57529902478603, 
       0.16408193246140756`}, {2.57529902478603, 0.16408193246140756`}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}}], 
      LineBox[{{2.6465276450782134`, 0.08724129137790171}, {2.57529902478603, 
       0.16408193246140756`}, {2.57529902478603, 0.16408193246140756`}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}}], 
      LineBox[{{2.6465276450782134`, 0.08724129137790171}, {2.57529902478603, 
       0.16408193246140756`}, {2.57529902478603, 0.16408193246140756`}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}}], 
      LineBox[{{2.57529902478603, 0.16408193246140756`}, {2.5577997154496823`,
        0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}}], 
      LineBox[{{2.57529902478603, 0.16408193246140756`}, {2.5577997154496823`,
        0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}}], 
      LineBox[{{2.57529902478603, 0.16408193246140756`}, {2.5577997154496823`,
        0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}}], 
      LineBox[{{2.57529902478603, 0.16408193246140756`}, {2.5577997154496823`,
        0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}}], 
      LineBox[{{2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603,
        0.3177632146284193}, {2.57529902478603, 0.3177632146284193}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}}], 
      LineBox[{{2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603,
        0.3177632146284193}, {2.57529902478603, 0.3177632146284193}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}}], 
      LineBox[{{2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603,
        0.3177632146284193}, {2.57529902478603, 0.3177632146284193}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}}], 
      LineBox[{{2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603,
        0.3177632146284193}, {2.57529902478603, 0.3177632146284193}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}}], 
      LineBox[{{2.57529902478603, 0.3177632146284193}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}}], 
      LineBox[{{2.57529902478603, 0.3177632146284193}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}}], 
      LineBox[{{2.57529902478603, 0.3177632146284193}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}}], 
      LineBox[{{2.57529902478603, 0.3177632146284193}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}], 
      LineBox[{{2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}], 
      LineBox[{{2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}], 
      LineBox[{{2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}], 
      LineBox[{{2.8817797968885, 0.14081645835361378`}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8817797968885, 0.14081645835361378`}, {2.8817797968885, 
       0.14081645835361378`}}], 
      LineBox[{{2.8817797968885, 0.14081645835361378`}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8817797968885, 0.14081645835361378`}, {2.8817797968885, 
       0.14081645835361378`}}], 
      LineBox[{{2.8817797968885, 0.14081645835361378`}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8817797968885, 0.14081645835361378`}, {2.8817797968885, 
       0.14081645835361378`}}], 
      LineBox[{{2.8817797968885, 0.14081645835361378`}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8817797968885, 0.14081645835361378`}, {2.8817797968885, 
       0.14081645835361378`}}], 
      LineBox[{{2.8239835043352755`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}}], 
      LineBox[{{2.8239835043352755`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}}], 
      LineBox[{{2.8239835043352755`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}}], 
      LineBox[{{2.8239835043352755`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}}], 
      LineBox[{{2.7486879024457034`, 0.06397581727010793}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}}], 
      LineBox[{{2.7486879024457034`, 0.06397581727010793}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}}], 
      LineBox[{{2.7486879024457034`, 0.06397581727010793}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}}], 
      LineBox[{{2.7486879024457034`, 0.06397581727010793}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}], 
      LineBox[{{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}], 
      LineBox[{{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}], 
      LineBox[{{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}], 
      LineBox[{{2.7486879024457034`, 0.4178693298197189}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.7486879024457034`, 0.4178693298197189}}], 
      LineBox[{{2.7486879024457034`, 0.4178693298197189}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.7486879024457034`, 0.4178693298197189}}], 
      LineBox[{{2.7486879024457034`, 0.4178693298197189}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.7486879024457034`, 0.4178693298197189}}], 
      LineBox[{{2.7486879024457034`, 0.4178693298197189}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.7486879024457034`, 0.4178693298197189}}], 
      LineBox[{{2.8239835043352755`, 0.39460385571192513`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}}], 
      LineBox[{{2.8239835043352755`, 0.39460385571192513`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}}], 
      LineBox[{{2.8239835043352755`, 0.39460385571192513`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}}], 
      LineBox[{{2.8239835043352755`, 0.39460385571192513`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}}], 
      LineBox[{{2.8817797968885, 0.34102868873621306`}, {2.9127114339638065`, 
       0.2409225735449134}, {2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.34102868873621306`}, {2.8817797968885, 
       0.34102868873621306`}}], 
      LineBox[{{2.8817797968885, 0.34102868873621306`}, {2.9127114339638065`, 
       0.2409225735449134}, {2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.34102868873621306`}, {2.8817797968885, 
       0.34102868873621306`}}], 
      LineBox[{{2.8817797968885, 0.34102868873621306`}, {2.9127114339638065`, 
       0.2409225735449134}, {2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.34102868873621306`}, {2.8817797968885, 
       0.34102868873621306`}}], 
      LineBox[{{2.8817797968885, 0.34102868873621306`}, {2.9127114339638065`, 
       0.2409225735449134}, {2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.34102868873621306`}, {2.8817797968885, 
       0.34102868873621306`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.676164126733447, 0.5752985413695367}, {2.609998974613347, 
       0.646676769467184}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.7894332256624785}, {2.676164126733447, 
       0.8608114537601258}, {2.676164126733447, 0.8608114537601258}, {
       2.609998974613347, 0.7894332256624785}, {2.5937436483205367`, 
       0.7180549975648313}, {2.609998974613347, 0.646676769467184}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.841005083559268, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.6761641267334473`, 
       0.5752985413695367}, {2.6761641267334473`, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.841005083559268, 
       0.5752985413695367}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.841005083559268, 0.8608114537601258}, {
       2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.841005083559268, 
       0.8608114537601258}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.676164126733447, 0.5752985413695367}, {2.609998974613347, 
       0.646676769467184}, {2.609998974613347, 0.646676769467184}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}}], 
      LineBox[{{2.676164126733447, 0.5752985413695367}, {2.609998974613347, 
       0.646676769467184}, {2.609998974613347, 0.646676769467184}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}}], 
      LineBox[{{2.676164126733447, 0.5752985413695367}, {2.609998974613347, 
       0.646676769467184}, {2.609998974613347, 0.646676769467184}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}}], 
      LineBox[{{2.676164126733447, 0.5752985413695367}, {2.609998974613347, 
       0.646676769467184}, {2.609998974613347, 0.646676769467184}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}}], 
      LineBox[{{2.609998974613347, 0.646676769467184}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}}], 
      LineBox[{{2.609998974613347, 0.646676769467184}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}}], 
      LineBox[{{2.609998974613347, 0.646676769467184}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}}], 
      LineBox[{{2.609998974613347, 0.646676769467184}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}}], 
      LineBox[{{2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}}], 
      LineBox[{{2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}}], 
      LineBox[{{2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}}], 
      LineBox[{{2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}}], 
      LineBox[{{2.609998974613347, 0.7894332256624785}, {2.6761641267334473`, 
       0.8608114537601258}, {2.6761641267334473`, 0.8608114537601258}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}}], 
      LineBox[{{2.609998974613347, 0.7894332256624785}, {2.6761641267334473`, 
       0.8608114537601258}, {2.6761641267334473`, 0.8608114537601258}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}}], 
      LineBox[{{2.609998974613347, 0.7894332256624785}, {2.6761641267334473`, 
       0.8608114537601258}, {2.6761641267334473`, 0.8608114537601258}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}}], 
      LineBox[{{2.609998974613347, 0.7894332256624785}, {2.6761641267334473`, 
       0.8608114537601258}, {2.6761641267334473`, 0.8608114537601258}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}], 
      LineBox[{{2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}], 
      LineBox[{{2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}], 
      LineBox[{{2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}], 
      LineBox[{{2.894692779222545, 0.6250651809347391}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.894692779222545, 0.6250651809347391}, {2.894692779222545, 
       0.6250651809347391}}], 
      LineBox[{{2.894692779222545, 0.6250651809347391}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.894692779222545, 0.6250651809347391}, {2.894692779222545, 
       0.6250651809347391}}], 
      LineBox[{{2.894692779222545, 0.6250651809347391}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.894692779222545, 0.6250651809347391}, {2.894692779222545, 
       0.6250651809347391}}], 
      LineBox[{{2.894692779222545, 0.6250651809347391}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.894692779222545, 0.6250651809347391}, {2.894692779222545, 
       0.6250651809347391}}], 
      LineBox[{{2.841005083559268, 0.5752985413695367}, {2.77106206160318, 
       0.5536869528370918}, {2.77106206160318, 0.5536869528370918}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}}], 
      LineBox[{{2.841005083559268, 0.5752985413695367}, {2.77106206160318, 
       0.5536869528370918}, {2.77106206160318, 0.5536869528370918}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}}], 
      LineBox[{{2.841005083559268, 0.5752985413695367}, {2.77106206160318, 
       0.5536869528370918}, {2.77106206160318, 0.5536869528370918}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}}], 
      LineBox[{{2.841005083559268, 0.5752985413695367}, {2.77106206160318, 
       0.5536869528370918}, {2.77106206160318, 0.5536869528370918}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}}], 
      LineBox[{{2.77106206160318, 0.5536869528370918}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}}], 
      LineBox[{{2.77106206160318, 0.5536869528370918}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}}], 
      LineBox[{{2.77106206160318, 0.5536869528370918}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}}], 
      LineBox[{{2.77106206160318, 0.5536869528370918}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}], 
      LineBox[{{2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}], 
      LineBox[{{2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}], 
      LineBox[{{2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}], 
      LineBox[{{2.77106206160318, 0.8824230422925707}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}}], 
      LineBox[{{2.77106206160318, 0.8824230422925707}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}}], 
      LineBox[{{2.77106206160318, 0.8824230422925707}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}}], 
      LineBox[{{2.77106206160318, 0.8824230422925707}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}}], 
      LineBox[{{2.841005083559268, 0.8608114537601258}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}], 
      LineBox[{{2.841005083559268, 0.8608114537601258}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}], 
      LineBox[{{2.841005083559268, 0.8608114537601258}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}], 
      LineBox[{{2.841005083559268, 0.8608114537601258}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}], 
      LineBox[{{2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.894692779222545, 
       0.8110448141949235}}], 
      LineBox[{{2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.894692779222545, 
       0.8110448141949235}}], 
      LineBox[{{2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.894692779222545, 
       0.8110448141949235}}], 
      LineBox[{{2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.894692779222545, 
       0.8110448141949235}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.671956865229452, 1.070497511236409}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.671956865229452, 
       1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.584271768053275, 
       1.2223725546121618`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.8473270595818057`, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`,
        1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`, 
       1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.671956865229452, 1.070497511236409}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}}], 
      LineBox[{{2.671956865229452, 1.070497511236409}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}}], 
      LineBox[{{2.671956865229452, 1.070497511236409}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}}], 
      LineBox[{{2.671956865229452, 1.070497511236409}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}}], 
      LineBox[{{2.6015654054242545`, 1.1464350329242854`}, {2.584271768053275,
        1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}}], 
      LineBox[{{2.6015654054242545`, 1.1464350329242854`}, {2.584271768053275,
        1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}}], 
      LineBox[{{2.6015654054242545`, 1.1464350329242854`}, {2.584271768053275,
        1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}}], 
      LineBox[{{2.6015654054242545`, 1.1464350329242854`}, {2.584271768053275,
        1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}}], 
      LineBox[{{2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`,
        1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}], 
      LineBox[{{2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`,
        1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}], 
      LineBox[{{2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`,
        1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}], 
      LineBox[{{2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`,
        1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}], 
      LineBox[{{2.6015654054242545`, 1.2983100763000381`}, {2.671956865229452,
        1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}}], 
      LineBox[{{2.6015654054242545`, 1.2983100763000381`}, {2.671956865229452,
        1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}}], 
      LineBox[{{2.6015654054242545`, 1.2983100763000381`}, {2.671956865229452,
        1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}}], 
      LineBox[{{2.6015654054242545`, 1.2983100763000381`}, {2.671956865229452,
        1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}], 
      LineBox[{{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}], 
      LineBox[{{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}], 
      LineBox[{{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}], 
      LineBox[{{2.9044440637784485`, 1.1234430013674515`}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}}], 
      LineBox[{{2.9044440637784485`, 1.1234430013674515`}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}}], 
      LineBox[{{2.9044440637784485`, 1.1234430013674515`}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}}], 
      LineBox[{{2.9044440637784485`, 1.1234430013674515`}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}}], 
      LineBox[{{2.8473270595818057`, 1.070497511236409}, {2.772916418014183, 
       1.047505479679575}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}}], 
      LineBox[{{2.8473270595818057`, 1.070497511236409}, {2.772916418014183, 
       1.047505479679575}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}}], 
      LineBox[{{2.8473270595818057`, 1.070497511236409}, {2.772916418014183, 
       1.047505479679575}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}}], 
      LineBox[{{2.8473270595818057`, 1.070497511236409}, {2.772916418014183, 
       1.047505479679575}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}}], 
      LineBox[{{2.772916418014183, 1.047505479679575}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}}], 
      LineBox[{{2.772916418014183, 1.047505479679575}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}}], 
      LineBox[{{2.772916418014183, 1.047505479679575}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}}], 
      LineBox[{{2.772916418014183, 1.047505479679575}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}], 
      LineBox[{{2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}], 
      LineBox[{{2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}], 
      LineBox[{{2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}], 
      LineBox[{{2.772916418014183, 1.3972396295447485`}, {2.8473270595818057`,
        1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}}], 
      LineBox[{{2.772916418014183, 1.3972396295447485`}, {2.8473270595818057`,
        1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}}], 
      LineBox[{{2.772916418014183, 1.3972396295447485`}, {2.8473270595818057`,
        1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}}], 
      LineBox[{{2.772916418014183, 1.3972396295447485`}, {2.8473270595818057`,
        1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}}], 
      LineBox[{{2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}], 
      LineBox[{{2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}], 
      LineBox[{{2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}], 
      LineBox[{{2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}], 
      LineBox[{{2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`,
        1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}}], 
      LineBox[{{2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`,
        1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}}], 
      LineBox[{{2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`,
        1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}}], 
      LineBox[{{2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`,
        1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6973738914708894`, 1.641328684369108}, {2.6350785394072926`,
        1.708532215329749}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.842939277251031}, {2.6973738914708894`, 
       1.910142808211672}, {2.6973738914708894`, 1.910142808211672}, {
       2.6350785394072926`, 1.842939277251031}, {2.6197739380896508`, 
       1.77573574629039}, {2.6350785394072926`, 1.708532215329749}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.8525737982333674`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.69737389147089, 
       1.641328684369108}, {2.69737389147089, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.8525737982333674`, 
       1.641328684369108}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`,
        1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.8525737982333674`, 1.910142808211672}, {
       2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.8525737982333674`, 
       1.910142808211672}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`,
        1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6973738914708894`, 1.641328684369108}, {2.6350785394072926`,
        1.708532215329749}, {2.6350785394072926`, 1.708532215329749}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}}], 
      LineBox[{{2.6973738914708894`, 1.641328684369108}, {2.6350785394072926`,
        1.708532215329749}, {2.6350785394072926`, 1.708532215329749}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}}], 
      LineBox[{{2.6973738914708894`, 1.641328684369108}, {2.6350785394072926`,
        1.708532215329749}, {2.6350785394072926`, 1.708532215329749}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}}], 
      LineBox[{{2.6973738914708894`, 1.641328684369108}, {2.6350785394072926`,
        1.708532215329749}, {2.6350785394072926`, 1.708532215329749}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}}], 
      LineBox[{{2.6350785394072926`, 1.708532215329749}, {2.6197739380896508`,
        1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}}], 
      LineBox[{{2.6350785394072926`, 1.708532215329749}, {2.6197739380896508`,
        1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}}], 
      LineBox[{{2.6350785394072926`, 1.708532215329749}, {2.6197739380896508`,
        1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}}], 
      LineBox[{{2.6350785394072926`, 1.708532215329749}, {2.6197739380896508`,
        1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}}], 
      LineBox[{{2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}], 
      LineBox[{{2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}], 
      LineBox[{{2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}], 
      LineBox[{{2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}], 
      LineBox[{{2.6350785394072926`, 1.842939277251031}, {2.6973738914708894`,
        1.910142808211672}, {2.6973738914708894`, 1.910142808211672}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}}], 
      LineBox[{{2.6350785394072926`, 1.842939277251031}, {2.6973738914708894`,
        1.910142808211672}, {2.6973738914708894`, 1.910142808211672}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}}], 
      LineBox[{{2.6350785394072926`, 1.842939277251031}, {2.6973738914708894`,
        1.910142808211672}, {2.6973738914708894`, 1.910142808211672}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}}], 
      LineBox[{{2.6350785394072926`, 1.842939277251031}, {2.6973738914708894`,
        1.910142808211672}, {2.6973738914708894`, 1.910142808211672}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}], 
      LineBox[{{2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}], 
      LineBox[{{2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}], 
      LineBox[{{2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}], 
      LineBox[{{2.9031214626104753`, 1.688184623385299}, {2.8525737982333674`,
        1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.9031214626104753`, 1.688184623385299}, {2.9031214626104753`, 
       1.688184623385299}}], 
      LineBox[{{2.9031214626104753`, 1.688184623385299}, {2.8525737982333674`,
        1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.9031214626104753`, 1.688184623385299}, {2.9031214626104753`, 
       1.688184623385299}}], 
      LineBox[{{2.9031214626104753`, 1.688184623385299}, {2.8525737982333674`,
        1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.9031214626104753`, 1.688184623385299}, {2.9031214626104753`, 
       1.688184623385299}}], 
      LineBox[{{2.9031214626104753`, 1.688184623385299}, {2.8525737982333674`,
        1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.9031214626104753`, 1.688184623385299}, {2.9031214626104753`, 
       1.688184623385299}}], 
      LineBox[{{2.8525737982333674`, 1.641328684369108}, {2.786721532538617, 
       1.6209810924246582`}, {2.786721532538617, 1.6209810924246582`}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}}], 
      LineBox[{{2.8525737982333674`, 1.641328684369108}, {2.786721532538617, 
       1.6209810924246582`}, {2.786721532538617, 1.6209810924246582`}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}}], 
      LineBox[{{2.8525737982333674`, 1.641328684369108}, {2.786721532538617, 
       1.6209810924246582`}, {2.786721532538617, 1.6209810924246582`}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}}], 
      LineBox[{{2.8525737982333674`, 1.641328684369108}, {2.786721532538617, 
       1.6209810924246582`}, {2.786721532538617, 1.6209810924246582`}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}}], 
      LineBox[{{2.786721532538617, 1.6209810924246582`}, {2.6973738914708894`,
        1.641328684369108}, {2.6973738914708894`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}}], 
      LineBox[{{2.786721532538617, 1.6209810924246582`}, {2.6973738914708894`,
        1.641328684369108}, {2.6973738914708894`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}}], 
      LineBox[{{2.786721532538617, 1.6209810924246582`}, {2.6973738914708894`,
        1.641328684369108}, {2.6973738914708894`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}}], 
      LineBox[{{2.786721532538617, 1.6209810924246582`}, {2.6973738914708894`,
        1.641328684369108}, {2.6973738914708894`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}], 
      LineBox[{{2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}], 
      LineBox[{{2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}], 
      LineBox[{{2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}], 
      LineBox[{{2.786721532538617, 1.9304904001561218`}, {2.8525737982333674`,
        1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}}], 
      LineBox[{{2.786721532538617, 1.9304904001561218`}, {2.8525737982333674`,
        1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}}], 
      LineBox[{{2.786721532538617, 1.9304904001561218`}, {2.8525737982333674`,
        1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}}], 
      LineBox[{{2.786721532538617, 1.9304904001561218`}, {2.8525737982333674`,
        1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}}], 
      LineBox[{{2.8525737982333674`, 1.910142808211672}, {2.9031214626104753`,
        1.863286869195481}, {2.9031214626104753`, 1.863286869195481}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}], 
      LineBox[{{2.8525737982333674`, 1.910142808211672}, {2.9031214626104753`,
        1.863286869195481}, {2.9031214626104753`, 1.863286869195481}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}], 
      LineBox[{{2.8525737982333674`, 1.910142808211672}, {2.9031214626104753`,
        1.863286869195481}, {2.9031214626104753`, 1.863286869195481}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}], 
      LineBox[{{2.8525737982333674`, 1.910142808211672}, {2.9031214626104753`,
        1.863286869195481}, {2.9031214626104753`, 1.863286869195481}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}], 
      LineBox[{{2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.9031214626104753`, 
       1.863286869195481}}], 
      LineBox[{{2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.9031214626104753`, 
       1.863286869195481}}], 
      LineBox[{{2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.9031214626104753`, 
       1.863286869195481}}], 
      LineBox[{{2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.9031214626104753`, 
       1.863286869195481}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6247494575628445`, 2.0974156803741835`}, {2.55316978268104, 
       2.174635035233291}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.3290737449515064`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}, {
       2.55316978268104, 2.3290737449515064`}, {2.535584226933734, 
       2.2518543900923986`}, {2.55316978268104, 2.174635035233291}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`,
        2.4296732392233333`}, {2.8030799188210644`, 2.406293099810614}, {
       2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`,
        2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6247494575628445`, 2.0974156803741835`}, {2.55316978268104, 
       2.174635035233291}, {2.55316978268104, 2.174635035233291}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}}], 
      LineBox[{{2.6247494575628445`, 2.0974156803741835`}, {2.55316978268104, 
       2.174635035233291}, {2.55316978268104, 2.174635035233291}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}}], 
      LineBox[{{2.6247494575628445`, 2.0974156803741835`}, {2.55316978268104, 
       2.174635035233291}, {2.55316978268104, 2.174635035233291}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}}], 
      LineBox[{{2.6247494575628445`, 2.0974156803741835`}, {2.55316978268104, 
       2.174635035233291}, {2.55316978268104, 2.174635035233291}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}}], 
      LineBox[{{2.55316978268104, 2.174635035233291}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}}], 
      LineBox[{{2.55316978268104, 2.174635035233291}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}}], 
      LineBox[{{2.55316978268104, 2.174635035233291}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}}], 
      LineBox[{{2.55316978268104, 2.174635035233291}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}}], 
      LineBox[{{2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}], 
      LineBox[{{2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}], 
      LineBox[{{2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}], 
      LineBox[{{2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}], 
      LineBox[{{2.55316978268104, 2.3290737449515064`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}}], 
      LineBox[{{2.55316978268104, 2.3290737449515064`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}}], 
      LineBox[{{2.55316978268104, 2.3290737449515064`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}}], 
      LineBox[{{2.55316978268104, 2.3290737449515064`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}], 
      LineBox[{{2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}], 
      LineBox[{{2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}], 
      LineBox[{{2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}], 
      LineBox[{{2.861161063919244, 2.1512548958205713`}, {2.8030799188210644`,
        2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.861161063919244, 2.1512548958205713`}, {2.861161063919244, 
       2.1512548958205713`}}], 
      LineBox[{{2.861161063919244, 2.1512548958205713`}, {2.8030799188210644`,
        2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.861161063919244, 2.1512548958205713`}, {2.861161063919244, 
       2.1512548958205713`}}], 
      LineBox[{{2.861161063919244, 2.1512548958205713`}, {2.8030799188210644`,
        2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.861161063919244, 2.1512548958205713`}, {2.861161063919244, 
       2.1512548958205713`}}], 
      LineBox[{{2.861161063919244, 2.1512548958205713`}, {2.8030799188210644`,
        2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.861161063919244, 2.1512548958205713`}, {2.861161063919244, 
       2.1512548958205713`}}], 
      LineBox[{{2.8030799188210644`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}}], 
      LineBox[{{2.8030799188210644`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}}], 
      LineBox[{{2.8030799188210644`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}}], 
      LineBox[{{2.8030799188210644`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}}], 
      LineBox[{{2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`,
        2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}}], 
      LineBox[{{2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`,
        2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}}], 
      LineBox[{{2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`,
        2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}}], 
      LineBox[{{2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`,
        2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`,
        2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}], 
      LineBox[{{2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`,
        2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}], 
      LineBox[{{2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`,
        2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}], 
      LineBox[{{2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`,
        2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}], 
      LineBox[{{2.7274132179755792`, 2.4296732392233333`}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.7274132179755792`, 2.4296732392233333`}}], 
      LineBox[{{2.7274132179755792`, 2.4296732392233333`}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.7274132179755792`, 2.4296732392233333`}}], 
      LineBox[{{2.7274132179755792`, 2.4296732392233333`}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.7274132179755792`, 2.4296732392233333`}}], 
      LineBox[{{2.7274132179755792`, 2.4296732392233333`}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.7274132179755792`, 2.4296732392233333`}}], 
      LineBox[{{2.8030799188210644`, 2.406293099810614}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}], 
      LineBox[{{2.8030799188210644`, 2.406293099810614}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}], 
      LineBox[{{2.8030799188210644`, 2.406293099810614}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}], 
      LineBox[{{2.8030799188210644`, 2.406293099810614}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}], 
      LineBox[{{2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.861161063919244, 
       2.352453884364226}}], 
      LineBox[{{2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.861161063919244, 
       2.352453884364226}}], 
      LineBox[{{2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.861161063919244, 
       2.352453884364226}}], 
      LineBox[{{2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.861161063919244, 
       2.352453884364226}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6514813726365816`, 2.616608750210834}, {2.5890835647207404`,
        2.683922809402078}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.818550927784567}, {2.6514813726365816`, 
       2.885864986975811}, {2.6514813726365816`, 2.885864986975811}, {
       2.5890835647207404`, 2.818550927784567}, {2.573753792247959, 
       2.7512368685933226`}, {2.5890835647207404`, 2.683922809402078}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`,
        2.9062460441757696`}, {2.806936533413827, 2.885864986975811}, {
       2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`, 
       2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.806936533413827, 
       2.885864986975811}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6514813726365816`, 2.616608750210834}, {2.5890835647207404`,
        2.683922809402078}, {2.5890835647207404`, 2.683922809402078}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}}], 
      LineBox[{{2.6514813726365816`, 2.616608750210834}, {2.5890835647207404`,
        2.683922809402078}, {2.5890835647207404`, 2.683922809402078}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}}], 
      LineBox[{{2.6514813726365816`, 2.616608750210834}, {2.5890835647207404`,
        2.683922809402078}, {2.5890835647207404`, 2.683922809402078}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}}], 
      LineBox[{{2.6514813726365816`, 2.616608750210834}, {2.5890835647207404`,
        2.683922809402078}, {2.5890835647207404`, 2.683922809402078}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}}], 
      LineBox[{{2.5890835647207404`, 2.683922809402078}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}}], 
      LineBox[{{2.5890835647207404`, 2.683922809402078}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}}], 
      LineBox[{{2.5890835647207404`, 2.683922809402078}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}}], 
      LineBox[{{2.5890835647207404`, 2.683922809402078}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}}], 
      LineBox[{{2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`,
        2.818550927784567}, {2.5890835647207404`, 2.818550927784567}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}], 
      LineBox[{{2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`,
        2.818550927784567}, {2.5890835647207404`, 2.818550927784567}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}], 
      LineBox[{{2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`,
        2.818550927784567}, {2.5890835647207404`, 2.818550927784567}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}], 
      LineBox[{{2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`,
        2.818550927784567}, {2.5890835647207404`, 2.818550927784567}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}], 
      LineBox[{{2.5890835647207404`, 2.818550927784567}, {2.6514813726365816`,
        2.885864986975811}, {2.6514813726365816`, 2.885864986975811}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}}], 
      LineBox[{{2.5890835647207404`, 2.818550927784567}, {2.6514813726365816`,
        2.885864986975811}, {2.6514813726365816`, 2.885864986975811}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}}], 
      LineBox[{{2.5890835647207404`, 2.818550927784567}, {2.6514813726365816`,
        2.885864986975811}, {2.6514813726365816`, 2.885864986975811}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}}], 
      LineBox[{{2.5890835647207404`, 2.818550927784567}, {2.6514813726365816`,
        2.885864986975811}, {2.6514813726365816`, 2.885864986975811}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}], 
      LineBox[{{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}], 
      LineBox[{{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}], 
      LineBox[{{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}], 
      LineBox[{{2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}}], 
      LineBox[{{2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}}], 
      LineBox[{{2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}}], 
      LineBox[{{2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}}], 
      LineBox[{{2.806936533413827, 2.616608750210834}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}}], 
      LineBox[{{2.806936533413827, 2.616608750210834}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}}], 
      LineBox[{{2.806936533413827, 2.616608750210834}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}}], 
      LineBox[{{2.806936533413827, 2.616608750210834}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}}], 
      LineBox[{{2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}}], 
      LineBox[{{2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}}], 
      LineBox[{{2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}}], 
      LineBox[{{2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`,
        2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}], 
      LineBox[{{2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`,
        2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}], 
      LineBox[{{2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`,
        2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}], 
      LineBox[{{2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`,
        2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}], 
      LineBox[{{2.7409759618859693`, 2.9062460441757696`}, {2.806936533413827,
        2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}}], 
      LineBox[{{2.7409759618859693`, 2.9062460441757696`}, {2.806936533413827,
        2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}}], 
      LineBox[{{2.7409759618859693`, 2.9062460441757696`}, {2.806936533413827,
        2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}}], 
      LineBox[{{2.7409759618859693`, 2.9062460441757696`}, {2.806936533413827,
        2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}}], 
      LineBox[{{2.806936533413827, 2.885864986975811}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}], 
      LineBox[{{2.806936533413827, 2.885864986975811}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}], 
      LineBox[{{2.806936533413827, 2.885864986975811}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}], 
      LineBox[{{2.806936533413827, 2.885864986975811}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}], 
      LineBox[{{2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`,
        2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.8575673324689035`, 
       2.838931984984525}}], 
      LineBox[{{2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`,
        2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.8575673324689035`, 
       2.838931984984525}}], 
      LineBox[{{2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`,
        2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.8575673324689035`, 
       2.838931984984525}}], 
      LineBox[{{2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`,
        2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.8575673324689035`, 
       2.838931984984525}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.685911913296408, 3.061827971251255}, {2.621619736032427, 
       3.1311856549653796`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.269901022393628}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}, {
       2.621619736032427, 3.269901022393628}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.621619736032427, 3.1311856549653796`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8460866227472827`, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8982545500606327`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`,
        3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`, 
       3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.685911913296408, 3.061827971251255}, {2.621619736032427, 
       3.1311856549653796`}, {2.621619736032427, 3.1311856549653796`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}}], 
      LineBox[{{2.685911913296408, 3.061827971251255}, {2.621619736032427, 
       3.1311856549653796`}, {2.621619736032427, 3.1311856549653796`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}}], 
      LineBox[{{2.685911913296408, 3.061827971251255}, {2.621619736032427, 
       3.1311856549653796`}, {2.621619736032427, 3.1311856549653796`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}}], 
      LineBox[{{2.685911913296408, 3.061827971251255}, {2.621619736032427, 
       3.1311856549653796`}, {2.621619736032427, 3.1311856549653796`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}}], 
      LineBox[{{2.621619736032427, 3.1311856549653796`}, {2.6058245585709714`,
        3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}}], 
      LineBox[{{2.621619736032427, 3.1311856549653796`}, {2.6058245585709714`,
        3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}}], 
      LineBox[{{2.621619736032427, 3.1311856549653796`}, {2.6058245585709714`,
        3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}}], 
      LineBox[{{2.621619736032427, 3.1311856549653796`}, {2.6058245585709714`,
        3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}}], 
      LineBox[{{2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427,
        3.269901022393628}, {2.621619736032427, 3.269901022393628}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}}], 
      LineBox[{{2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427,
        3.269901022393628}, {2.621619736032427, 3.269901022393628}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}}], 
      LineBox[{{2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427,
        3.269901022393628}, {2.621619736032427, 3.269901022393628}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}}], 
      LineBox[{{2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427,
        3.269901022393628}, {2.621619736032427, 3.269901022393628}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}}], 
      LineBox[{{2.621619736032427, 3.269901022393628}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}}], 
      LineBox[{{2.621619736032427, 3.269901022393628}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}}], 
      LineBox[{{2.621619736032427, 3.269901022393628}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}}], 
      LineBox[{{2.621619736032427, 3.269901022393628}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}], 
      LineBox[{{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}], 
      LineBox[{{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}], 
      LineBox[{{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}], 
      LineBox[{{2.8982545500606323`, 3.1101858380472214`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}}], 
      LineBox[{{2.8982545500606323`, 3.1101858380472214`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}}], 
      LineBox[{{2.8982545500606323`, 3.1101858380472214`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}}], 
      LineBox[{{2.8982545500606323`, 3.1101858380472214`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}}], 
      LineBox[{{2.8460866227472827`, 3.061827971251255}, {2.778123517972477, 
       3.0408281543330973`}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}}], 
      LineBox[{{2.8460866227472827`, 3.061827971251255}, {2.778123517972477, 
       3.0408281543330973`}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}}], 
      LineBox[{{2.8460866227472827`, 3.061827971251255}, {2.778123517972477, 
       3.0408281543330973`}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}}], 
      LineBox[{{2.8460866227472827`, 3.061827971251255}, {2.778123517972477, 
       3.0408281543330973`}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}}], 
      LineBox[{{2.778123517972477, 3.0408281543330973`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}}], 
      LineBox[{{2.778123517972477, 3.0408281543330973`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}}], 
      LineBox[{{2.778123517972477, 3.0408281543330973`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}}], 
      LineBox[{{2.778123517972477, 3.0408281543330973`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}], 
      LineBox[{{2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}], 
      LineBox[{{2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}], 
      LineBox[{{2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}], 
      LineBox[{{2.778123517972477, 3.36025852302591}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}}], 
      LineBox[{{2.778123517972477, 3.36025852302591}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}}], 
      LineBox[{{2.778123517972477, 3.36025852302591}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}}], 
      LineBox[{{2.778123517972477, 3.36025852302591}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}}], 
      LineBox[{{2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8982545500606323`, 
       3.290900839311786}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}], 
      LineBox[{{2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8982545500606323`, 
       3.290900839311786}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}], 
      LineBox[{{2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8982545500606323`, 
       3.290900839311786}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}], 
      LineBox[{{2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8982545500606323`, 
       3.290900839311786}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}], 
      LineBox[{{2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`,
        3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606327`, 3.290900839311786}, {2.8982545500606327`, 
       3.290900839311786}}], 
      LineBox[{{2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`,
        3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606327`, 3.290900839311786}, {2.8982545500606327`, 
       3.290900839311786}}], 
      LineBox[{{2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`,
        3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606327`, 3.290900839311786}, {2.8982545500606327`, 
       3.290900839311786}}], 
      LineBox[{{2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`,
        3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606327`, 3.290900839311786}, {2.8982545500606327`, 
       3.290900839311786}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6312213879819453`, 3.611369347046231}, {2.5601528287587105`,
        3.688037316033885}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.8413732540091914`}, {2.6312213879819453`, 
       3.918041222996845}, {2.6312213879819453`, 3.918041222996845}, {
       2.5601528287587105`, 3.8413732540091914`}, {2.542692842915458, 
       3.764705285021538}, {2.5601528287587105`, 3.688037316033885}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.8082784781149197`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`, 
       3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.8082784781149197`, 
       3.611369347046231}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`,
        3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.8082784781149197`, 3.918041222996845}, {
       2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.8082784781149197`, 
       3.918041222996845}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`,
        3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6312213879819453`, 3.611369347046231}, {2.5601528287587105`,
        3.688037316033885}, {2.5601528287587105`, 3.688037316033885}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}}], 
      LineBox[{{2.6312213879819453`, 3.611369347046231}, {2.5601528287587105`,
        3.688037316033885}, {2.5601528287587105`, 3.688037316033885}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}}], 
      LineBox[{{2.6312213879819453`, 3.611369347046231}, {2.5601528287587105`,
        3.688037316033885}, {2.5601528287587105`, 3.688037316033885}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}}], 
      LineBox[{{2.6312213879819453`, 3.611369347046231}, {2.5601528287587105`,
        3.688037316033885}, {2.5601528287587105`, 3.688037316033885}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}}], 
      LineBox[{{2.5601528287587105`, 3.688037316033885}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}}], 
      LineBox[{{2.5601528287587105`, 3.688037316033885}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}}], 
      LineBox[{{2.5601528287587105`, 3.688037316033885}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}}], 
      LineBox[{{2.5601528287587105`, 3.688037316033885}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}}], 
      LineBox[{{2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}], 
      LineBox[{{2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}], 
      LineBox[{{2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}], 
      LineBox[{{2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}], 
      LineBox[{{2.5601528287587105`, 3.8413732540091914`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.5601528287587105`, 3.8413732540091914`}}], 
      LineBox[{{2.5601528287587105`, 3.8413732540091914`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.5601528287587105`, 3.8413732540091914`}}], 
      LineBox[{{2.5601528287587105`, 3.8413732540091914`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.5601528287587105`, 3.8413732540091914`}}], 
      LineBox[{{2.5601528287587105`, 3.8413732540091914`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.5601528287587105`, 3.8413732540091914`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}], 
      LineBox[{{2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}], 
      LineBox[{{2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}], 
      LineBox[{{2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}], 
      LineBox[{{2.865944893993159, 3.664824122830031}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.865944893993159, 3.664824122830031}, {2.865944893993159, 
       3.664824122830031}}], 
      LineBox[{{2.865944893993159, 3.664824122830031}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.865944893993159, 3.664824122830031}, {2.865944893993159, 
       3.664824122830031}}], 
      LineBox[{{2.865944893993159, 3.664824122830031}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.865944893993159, 3.664824122830031}, {2.865944893993159, 
       3.664824122830031}}], 
      LineBox[{{2.865944893993159, 3.664824122830031}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.865944893993159, 3.664824122830031}, {2.865944893993159, 
       3.664824122830031}}], 
      LineBox[{{2.8082784781149197`, 3.611369347046231}, {2.733152076393428, 
       3.5881561538423776`}, {2.733152076393428, 3.5881561538423776`}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}}], 
      LineBox[{{2.8082784781149197`, 3.611369347046231}, {2.733152076393428, 
       3.5881561538423776`}, {2.733152076393428, 3.5881561538423776`}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}}], 
      LineBox[{{2.8082784781149197`, 3.611369347046231}, {2.733152076393428, 
       3.5881561538423776`}, {2.733152076393428, 3.5881561538423776`}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}}], 
      LineBox[{{2.8082784781149197`, 3.611369347046231}, {2.733152076393428, 
       3.5881561538423776`}, {2.733152076393428, 3.5881561538423776`}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}}], 
      LineBox[{{2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`,
        3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}}], 
      LineBox[{{2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`,
        3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}}], 
      LineBox[{{2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`,
        3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}}], 
      LineBox[{{2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`,
        3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}], 
      LineBox[{{2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}], 
      LineBox[{{2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}], 
      LineBox[{{2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}], 
      LineBox[{{2.733152076393428, 3.9412544162006986`}, {2.8082784781149197`,
        3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}}], 
      LineBox[{{2.733152076393428, 3.9412544162006986`}, {2.8082784781149197`,
        3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}}], 
      LineBox[{{2.733152076393428, 3.9412544162006986`}, {2.8082784781149197`,
        3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}}], 
      LineBox[{{2.733152076393428, 3.9412544162006986`}, {2.8082784781149197`,
        3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}}], 
      LineBox[{{2.8082784781149197`, 3.918041222996845}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}], 
      LineBox[{{2.8082784781149197`, 3.918041222996845}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}], 
      LineBox[{{2.8082784781149197`, 3.918041222996845}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}], 
      LineBox[{{2.8082784781149197`, 3.918041222996845}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}], 
      LineBox[{{2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.865944893993159, 
       3.8645864472130453`}}], 
      LineBox[{{2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.865944893993159, 
       3.8645864472130453`}}], 
      LineBox[{{2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.865944893993159, 
       3.8645864472130453`}}], 
      LineBox[{{2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.865944893993159, 
       3.8645864472130453`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}], 
      LineBox[{{2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}], 
      LineBox[{{2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}], 
      LineBox[{{2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}], 
      LineBox[{{2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}], 
      LineBox[{{2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}], 
      LineBox[{{2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}], 
      LineBox[{{2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}], 
      LineBox[{{2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}], 
      LineBox[{{2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}], 
      LineBox[{{2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}], 
      LineBox[{{2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}], 
      LineBox[{{2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}], 
      LineBox[{{2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}], 
      LineBox[{{2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}], 
      LineBox[{{2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}], 
      LineBox[{{3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}], 
      LineBox[{{3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}], 
      LineBox[{{3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}], 
      LineBox[{{3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}], 
      LineBox[{{3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}], 
      LineBox[{{3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}], 
      LineBox[{{3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}], 
      LineBox[{{3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}], 
      LineBox[{{3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}], 
      LineBox[{{3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}], 
      LineBox[{{3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}], 
      LineBox[{{3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}], 
      LineBox[{{3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}], 
      LineBox[{{3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}], 
      LineBox[{{3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}], 
      LineBox[{{2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}], 
      LineBox[{{2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}], 
      LineBox[{{2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}], 
      LineBox[{{3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}], 
      LineBox[{{3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}], 
      LineBox[{{3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}], 
      LineBox[{{3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}], 
      LineBox[{{3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}], 
      LineBox[{{3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}], 
      LineBox[{{3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}], 
      LineBox[{{3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}], 
      LineBox[{{3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}], 
      LineBox[{{3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}], 
      LineBox[{{3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}], 
      LineBox[{{3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}], 
      LineBox[{{2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}], 
      LineBox[{{2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}], 
      LineBox[{{2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}], 
      LineBox[{{2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}], 
      LineBox[{{2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}], 
      LineBox[{{2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}], 
      LineBox[{{2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}], 
      LineBox[{{2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}], 
      LineBox[{{2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}], 
      LineBox[{{2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}], 
      LineBox[{{2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}], 
      LineBox[{{2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}], 
      LineBox[{{2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}], 
      LineBox[{{2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}], 
      LineBox[{{2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}], 
      LineBox[{{3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}], 
      LineBox[{{3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}], 
      LineBox[{{3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}], 
      LineBox[{{3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}], 
      LineBox[{{3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}], 
      LineBox[{{3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}], 
      LineBox[{{3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}], 
      LineBox[{{3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}], 
      LineBox[{{3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}], 
      LineBox[{{3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}], 
      LineBox[{{3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}], 
      LineBox[{{2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}], 
      LineBox[{{2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}], 
      LineBox[{{2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}], 
      LineBox[{{2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}], 
      LineBox[{{2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}], 
      LineBox[{{2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}], 
      LineBox[{{2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}], 
      LineBox[{{2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}], 
      LineBox[{{2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}], 
      LineBox[{{2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}], 
      LineBox[{{2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}], 
      LineBox[{{3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}], 
      LineBox[{{3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}], 
      LineBox[{{3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}], 
      LineBox[{{3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}], 
      LineBox[{{3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}], 
      LineBox[{{3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}], 
      LineBox[{{3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}], 
      LineBox[{{3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.9294475372540476`, -3.40652189900994}, {
       2.9294475372540476`, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.142697993059333, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}], 
      LineBox[{{2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}], 
      LineBox[{{2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}], 
      LineBox[{{2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}], 
      LineBox[{{2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}], 
      LineBox[{{2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}], 
      LineBox[{{2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}], 
      LineBox[{{2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}], 
      LineBox[{{2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}], 
      LineBox[{{2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}], 
      LineBox[{{2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}], 
      LineBox[{{2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}], 
      LineBox[{{2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}], 
      LineBox[{{2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}], 
      LineBox[{{2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}], 
      LineBox[{{2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}], 
      LineBox[{{3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}], 
      LineBox[{{3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}], 
      LineBox[{{3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}], 
      LineBox[{{3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}], 
      LineBox[{{3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}], 
      LineBox[{{3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}], 
      LineBox[{{3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}], 
      LineBox[{{3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}], 
      LineBox[{{3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}], 
      LineBox[{{3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}], 
      LineBox[{{3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}], 
      LineBox[{{3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}], 
      LineBox[{{3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}], 
      LineBox[{{3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}], 
      LineBox[{{3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}], 
      LineBox[{{2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}], 
      LineBox[{{2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}], 
      LineBox[{{2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}], 
      LineBox[{{3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}], 
      LineBox[{{3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}], 
      LineBox[{{3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}], 
      LineBox[{{3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}], 
      LineBox[{{3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}], 
      LineBox[{{3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}], 
      LineBox[{{3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}], 
      LineBox[{{3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}], 
      LineBox[{{3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}], 
      LineBox[{{3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}], 
      LineBox[{{3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}], 
      LineBox[{{3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}], 
      LineBox[{{2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}], 
      LineBox[{{2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}], 
      LineBox[{{2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}], 
      LineBox[{{2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}], 
      LineBox[{{2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}], 
      LineBox[{{2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}], 
      LineBox[{{2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}], 
      LineBox[{{2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}], 
      LineBox[{{2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}], 
      LineBox[{{2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}], 
      LineBox[{{2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}], 
      LineBox[{{2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}], 
      LineBox[{{2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}], 
      LineBox[{{2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}], 
      LineBox[{{2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}], 
      LineBox[{{3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}], 
      LineBox[{{3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}], 
      LineBox[{{3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}], 
      LineBox[{{3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}], 
      LineBox[{{3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}], 
      LineBox[{{3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}], 
      LineBox[{{3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}], 
      LineBox[{{3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}], 
      LineBox[{{3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}], 
      LineBox[{{3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}], 
      LineBox[{{3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}], 
      LineBox[{{3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}], 
      LineBox[{{3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}], 
      LineBox[{{3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}], 
      LineBox[{{3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}], 
      LineBox[{{2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}], 
      LineBox[{{2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}], 
      LineBox[{{2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}], 
      LineBox[{{3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}], 
      LineBox[{{3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}], 
      LineBox[{{3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}], 
      LineBox[{{3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}], 
      LineBox[{{3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}], 
      LineBox[{{3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}], 
      LineBox[{{3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}], 
      LineBox[{{3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}], 
      LineBox[{{3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}], 
      LineBox[{{3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}], 
      LineBox[{{3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}], 
      LineBox[{{3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.336748980863077}, {
       2.888016917539941, -2.336748980863077}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.8880169175399413`, -2.6367567863982466`}, {
       2.8880169175399413`, -2.6367567863982466`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}], 
      LineBox[{{2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}], 
      LineBox[{{2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}], 
      LineBox[{{2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}], 
      LineBox[{{2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}], 
      LineBox[{{2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}], 
      LineBox[{{2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}], 
      LineBox[{{2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}], 
      LineBox[{{2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}], 
      LineBox[{{2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}], 
      LineBox[{{2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}], 
      LineBox[{{2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}], 
      LineBox[{{2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}], 
      LineBox[{{2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}], 
      LineBox[{{2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}], 
      LineBox[{{2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}], 
      LineBox[{{3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}], 
      LineBox[{{3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}], 
      LineBox[{{3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}], 
      LineBox[{{3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}], 
      LineBox[{{3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}], 
      LineBox[{{3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}], 
      LineBox[{{3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}], 
      LineBox[{{3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}], 
      LineBox[{{3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}], 
      LineBox[{{3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}], 
      LineBox[{{3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}], 
      LineBox[{{2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}], 
      LineBox[{{2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}], 
      LineBox[{{2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}], 
      LineBox[{{2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}], 
      LineBox[{{2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}], 
      LineBox[{{2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}], 
      LineBox[{{2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}], 
      LineBox[{{2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}], 
      LineBox[{{2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}], 
      LineBox[{{2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}], 
      LineBox[{{2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}], 
      LineBox[{{3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}], 
      LineBox[{{3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}], 
      LineBox[{{3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}], 
      LineBox[{{3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}], 
      LineBox[{{3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}], 
      LineBox[{{3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}], 
      LineBox[{{3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}], 
      LineBox[{{3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814847`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}], 
      LineBox[{{2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}], 
      LineBox[{{2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}], 
      LineBox[{{2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}], 
      LineBox[{{2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}], 
      LineBox[{{2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}], 
      LineBox[{{2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}], 
      LineBox[{{2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}], 
      LineBox[{{2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}], 
      LineBox[{{2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}], 
      LineBox[{{2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}], 
      LineBox[{{2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}], 
      LineBox[{{2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}], 
      LineBox[{{2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}], 
      LineBox[{{2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}], 
      LineBox[{{2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}], 
      LineBox[{{3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}], 
      LineBox[{{3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}], 
      LineBox[{{3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}], 
      LineBox[{{3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}], 
      LineBox[{{3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}], 
      LineBox[{{3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}], 
      LineBox[{{3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}], 
      LineBox[{{3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}], 
      LineBox[{{3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}], 
      LineBox[{{3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}], 
      LineBox[{{3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}], 
      LineBox[{{3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}], 
      LineBox[{{3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}], 
      LineBox[{{3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}], 
      LineBox[{{3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}], 
      LineBox[{{2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}], 
      LineBox[{{2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}], 
      LineBox[{{2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}], 
      LineBox[{{3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}], 
      LineBox[{{3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}], 
      LineBox[{{3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}], 
      LineBox[{{3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}], 
      LineBox[{{3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}], 
      LineBox[{{3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}], 
      LineBox[{{3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}], 
      LineBox[{{3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}], 
      LineBox[{{3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}], 
      LineBox[{{3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}], 
      LineBox[{{3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}], 
      LineBox[{{3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}], 
      LineBox[{{2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}], 
      LineBox[{{2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}], 
      LineBox[{{2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}], 
      LineBox[{{2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}], 
      LineBox[{{2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}], 
      LineBox[{{2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}], 
      LineBox[{{2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}], 
      LineBox[{{2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}], 
      LineBox[{{2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}], 
      LineBox[{{2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}], 
      LineBox[{{2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}], 
      LineBox[{{2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}], 
      LineBox[{{2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}], 
      LineBox[{{2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}], 
      LineBox[{{2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}], 
      LineBox[{{3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}], 
      LineBox[{{3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}], 
      LineBox[{{3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}], 
      LineBox[{{3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}], 
      LineBox[{{3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}], 
      LineBox[{{3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}], 
      LineBox[{{3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}], 
      LineBox[{{3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}], 
      LineBox[{{3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}], 
      LineBox[{{3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}], 
      LineBox[{{3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}], 
      LineBox[{{3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}], 
      LineBox[{{3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}], 
      LineBox[{{3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}], 
      LineBox[{{3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}], 
      LineBox[{{2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}], 
      LineBox[{{2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}], 
      LineBox[{{2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}], 
      LineBox[{{3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}], 
      LineBox[{{3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}], 
      LineBox[{{3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}], 
      LineBox[{{3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}], 
      LineBox[{{3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}], 
      LineBox[{{3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}], 
      LineBox[{{3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}], 
      LineBox[{{3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}], 
      LineBox[{{3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}], 
      LineBox[{{3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}], 
      LineBox[{{3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}], 
      LineBox[{{3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499283}, {
       2.89892525804436, -0.8685904706499283}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}], 
      LineBox[{{2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}], 
      LineBox[{{2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}], 
      LineBox[{{2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}], 
      LineBox[{{2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}], 
      LineBox[{{2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}], 
      LineBox[{{2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}], 
      LineBox[{{2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}], 
      LineBox[{{2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}], 
      LineBox[{{2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}], 
      LineBox[{{2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}], 
      LineBox[{{2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}], 
      LineBox[{{2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}], 
      LineBox[{{2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}], 
      LineBox[{{2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}], 
      LineBox[{{2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}], 
      LineBox[{{3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}], 
      LineBox[{{3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}], 
      LineBox[{{3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}], 
      LineBox[{{3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}], 
      LineBox[{{3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}], 
      LineBox[{{3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}], 
      LineBox[{{3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}], 
      LineBox[{{3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}], 
      LineBox[{{3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}], 
      LineBox[{{3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}], 
      LineBox[{{3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}], 
      LineBox[{{2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}], 
      LineBox[{{2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}], 
      LineBox[{{2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}], 
      LineBox[{{2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}], 
      LineBox[{{2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}], 
      LineBox[{{2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}], 
      LineBox[{{2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}], 
      LineBox[{{2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}], 
      LineBox[{{2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}], 
      LineBox[{{2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}], 
      LineBox[{{2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}], 
      LineBox[{{3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}], 
      LineBox[{{3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}], 
      LineBox[{{3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}], 
      LineBox[{{3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}], 
      LineBox[{{3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}], 
      LineBox[{{3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}], 
      LineBox[{{3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}], 
      LineBox[{{3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705926}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}], 
      LineBox[{{2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}], 
      LineBox[{{2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}], 
      LineBox[{{2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}], 
      LineBox[{{2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}], 
      LineBox[{{2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}], 
      LineBox[{{2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}], 
      LineBox[{{2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}], 
      LineBox[{{2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}], 
      LineBox[{{2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}], 
      LineBox[{{2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}], 
      LineBox[{{2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}], 
      LineBox[{{2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}], 
      LineBox[{{2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}], 
      LineBox[{{2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}], 
      LineBox[{{2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}], 
      LineBox[{{3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}], 
      LineBox[{{3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}], 
      LineBox[{{3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}], 
      LineBox[{{3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}], 
      LineBox[{{3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}], 
      LineBox[{{3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}], 
      LineBox[{{3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}], 
      LineBox[{{3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}], 
      LineBox[{{3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}], 
      LineBox[{{3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}], 
      LineBox[{{3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}], 
      LineBox[{{3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}], 
      LineBox[{{3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}], 
      LineBox[{{3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}], 
      LineBox[{{3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}], 
      LineBox[{{2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}], 
      LineBox[{{2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}], 
      LineBox[{{2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}], 
      LineBox[{{3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}], 
      LineBox[{{3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}], 
      LineBox[{{3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}], 
      LineBox[{{3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}], 
      LineBox[{{3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}], 
      LineBox[{{3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}], 
      LineBox[{{3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}], 
      LineBox[{{3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}], 
      LineBox[{{3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}], 
      LineBox[{{3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}], 
      LineBox[{{3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}], 
      LineBox[{{3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {2.8961820431828613`, 
       0.024849648472386653`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9611761774634457`, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.123099711825315, 
       0.09496459558635739}, {3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.04526529864158409}, {
       3.20406147900625, -0.04526529864158409}, {3.1758372207608407`, 
       0.04607874629936418}, {3.123099711825315, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {2.9611761774634457`, 
       0.09496459558635739}, {2.9611761774634457`, 0.09496459558635739}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}], 
      LineBox[{{2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}], 
      LineBox[{{2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}], 
      LineBox[{{2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}], 
      LineBox[{{2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}], 
      LineBox[{{2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}], 
      LineBox[{{2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}], 
      LineBox[{{2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}], 
      LineBox[{{2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, 0.02484964847238664}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}], 
      LineBox[{{2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, 0.02484964847238664}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}], 
      LineBox[{{2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, 0.02484964847238664}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}], 
      LineBox[{{2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, 0.02484964847238664}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}], 
      LineBox[{{2.8961820431828613`, 0.024849648472386653`}, {
       2.9611761774634457`, 0.09496459558635739}, {2.9611761774634457`, 
       0.09496459558635739}, {2.8961820431828613`, 0.024849648472386653`}, {
       2.8961820431828613`, 0.024849648472386653`}}], 
      LineBox[{{2.8961820431828613`, 0.024849648472386653`}, {
       2.9611761774634457`, 0.09496459558635739}, {2.9611761774634457`, 
       0.09496459558635739}, {2.8961820431828613`, 0.024849648472386653`}, {
       2.8961820431828613`, 0.024849648472386653`}}], 
      LineBox[{{2.8961820431828613`, 0.024849648472386653`}, {
       2.9611761774634457`, 0.09496459558635739}, {2.9611761774634457`, 
       0.09496459558635739}, {2.8961820431828613`, 0.024849648472386653`}, {
       2.8961820431828613`, 0.024849648472386653`}}], 
      LineBox[{{2.8961820431828613`, 0.024849648472386653`}, {
       2.9611761774634457`, 0.09496459558635739}, {2.9611761774634457`, 
       0.09496459558635739}, {2.8961820431828613`, 0.024849648472386653`}, {
       2.8961820431828613`, 0.024849648472386653`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}], 
      LineBox[{{3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}], 
      LineBox[{{3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}], 
      LineBox[{{3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}], 
      LineBox[{{3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}], 
      LineBox[{{3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}], 
      LineBox[{{3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}], 
      LineBox[{{3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}], 
      LineBox[{{3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}], 
      LineBox[{{3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}], 
      LineBox[{{3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}], 
      LineBox[{{3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}], 
      LineBox[{{3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}], 
      LineBox[{{3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}], 
      LineBox[{{3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}], 
      LineBox[{{3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9611761774634457`, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}}], 
      LineBox[{{2.9611761774634457`, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}}], 
      LineBox[{{2.9611761774634457`, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}}], 
      LineBox[{{2.9611761774634457`, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}}], 
      LineBox[{{3.0543945699894386`, 0.11619369341333496`}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}}], 
      LineBox[{{3.0543945699894386`, 0.11619369341333496`}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}}], 
      LineBox[{{3.0543945699894386`, 0.11619369341333496`}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}}], 
      LineBox[{{3.0543945699894386`, 0.11619369341333496`}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}}], 
      LineBox[{{3.123099711825315, 0.09496459558635739}, {3.1758372207608407`,
        0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}], 
      LineBox[{{3.123099711825315, 0.09496459558635739}, {3.1758372207608407`,
        0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}], 
      LineBox[{{3.123099711825315, 0.09496459558635739}, {3.1758372207608407`,
        0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}], 
      LineBox[{{3.123099711825315, 0.09496459558635739}, {3.1758372207608407`,
        0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}], 
      LineBox[{{3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}], 
      LineBox[{{3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}], 
      LineBox[{{3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}], 
      LineBox[{{3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 
       0.04607874629936418}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.45377262516406985`}, {3.1101424147695993`, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.1101424147695993`, 
       0.4084403088625691}, {3.159046411956666, 0.45377262516406985`}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.959989170356145, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.1101424147695993`, 0.6685133571079801}, {
       3.159046411956666, 0.6231810408064793}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.6231810408064793}, {3.1101424147695993`, 
       0.6685133571079801}, {3.046431478646575, 0.6881993028678322}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}], 
      LineBox[{{2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}], 
      LineBox[{{2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}], 
      LineBox[{{2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}], 
      LineBox[{{2.8997194870853753`, 0.47345857092392185`}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}}], 
      LineBox[{{2.8997194870853753`, 0.47345857092392185`}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}}], 
      LineBox[{{2.8997194870853753`, 0.47345857092392185`}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}}], 
      LineBox[{{2.8997194870853753`, 0.47345857092392185`}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}}], 
      LineBox[{{2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}], 
      LineBox[{{2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}], 
      LineBox[{{2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}], 
      LineBox[{{2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}], 
      LineBox[{{2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}}], 
      LineBox[{{2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}}], 
      LineBox[{{2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}}], 
      LineBox[{{2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}}], 
      LineBox[{{3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}}], 
      LineBox[{{3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}}], 
      LineBox[{{3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}}], 
      LineBox[{{3.159046411956666, 0.45377262516406985`}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.159046411956666, 0.45377262516406985`}, {
       3.159046411956666, 0.45377262516406985`}}], 
      LineBox[{{3.159046411956666, 0.45377262516406985`}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.159046411956666, 0.45377262516406985`}, {
       3.159046411956666, 0.45377262516406985`}}], 
      LineBox[{{3.159046411956666, 0.45377262516406985`}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.159046411956666, 0.45377262516406985`}, {
       3.159046411956666, 0.45377262516406985`}}], 
      LineBox[{{3.159046411956666, 0.45377262516406985`}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.159046411956666, 0.45377262516406985`}, {
       3.159046411956666, 0.45377262516406985`}}], 
      LineBox[{{3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}], 
      LineBox[{{3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}], 
      LineBox[{{3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}], 
      LineBox[{{3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}], 
      LineBox[{{3.046431478646575, 0.3887543631027171}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.046431478646575, 
       0.3887543631027171}}], 
      LineBox[{{3.046431478646575, 0.3887543631027171}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.046431478646575, 
       0.3887543631027171}}], 
      LineBox[{{3.046431478646575, 0.3887543631027171}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.046431478646575, 
       0.3887543631027171}}], 
      LineBox[{{3.046431478646575, 0.3887543631027171}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.046431478646575, 
       0.3887543631027171}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.959989170356145, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.046431478646575, 0.6881993028678322}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}}], 
      LineBox[{{2.959989170356145, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.046431478646575, 0.6881993028678322}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}}], 
      LineBox[{{2.959989170356145, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.046431478646575, 0.6881993028678322}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}}], 
      LineBox[{{2.959989170356145, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.046431478646575, 0.6881993028678322}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}}], 
      LineBox[{{3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}}], 
      LineBox[{{3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}}], 
      LineBox[{{3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}}], 
      LineBox[{{3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}}], 
      LineBox[{{3.1101424147695993`, 0.6685133571079801}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}}], 
      LineBox[{{3.1101424147695993`, 0.6685133571079801}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}}], 
      LineBox[{{3.1101424147695993`, 0.6685133571079801}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}}], 
      LineBox[{{3.1101424147695993`, 0.6685133571079801}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}}], 
      LineBox[{{3.159046411956666, 0.6231810408064793}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}}], 
      LineBox[{{3.159046411956666, 0.6231810408064793}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}}], 
      LineBox[{{3.159046411956666, 0.6231810408064793}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}}], 
      LineBox[{{3.159046411956666, 0.6231810408064793}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.8470178172435943`, 
       0.9900294163368778}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       0.8910998630921676}, {3.110073108772125, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {2.934702914419771, 
       0.838154372961125}, {2.934702914419771, 0.838154372961125}, {
       3.0356624672045025`, 0.8151623414042912}, {3.110073108772125, 
       0.8381543729611252}, {3.167190112968768, 0.8910998630921676}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.934702914419771, 1.1419044597126304`}, {3.0356624672045025`,
        1.1648964912694644`}, {3.110073108772125, 1.1419044597126304`}, {
       3.167190112968768, 1.088958969581588}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 1.088958969581588}, {3.110073108772125, 
       1.1419044597126304`}, {3.0356624672045025`, 1.1648964912694644`}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}], 
      LineBox[{{2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}], 
      LineBox[{{2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}], 
      LineBox[{{2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}], 
      LineBox[{{2.864311454614574, 0.9140918946490014}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 0.9140918946490014}, {2.864311454614574, 
       0.9140918946490014}}], 
      LineBox[{{2.864311454614574, 0.9140918946490014}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 0.9140918946490014}, {2.864311454614574, 
       0.9140918946490014}}], 
      LineBox[{{2.864311454614574, 0.9140918946490014}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 0.9140918946490014}, {2.864311454614574, 
       0.9140918946490014}}], 
      LineBox[{{2.864311454614574, 0.9140918946490014}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 0.9140918946490014}, {2.864311454614574, 
       0.9140918946490014}}], 
      LineBox[{{2.8470178172435943`, 0.9900294163368778}, {2.864311454614574, 
       1.065966938024754}, {2.864311454614574, 1.065966938024754}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}}], 
      LineBox[{{2.8470178172435943`, 0.9900294163368778}, {2.864311454614574, 
       1.065966938024754}, {2.864311454614574, 1.065966938024754}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}}], 
      LineBox[{{2.8470178172435943`, 0.9900294163368778}, {2.864311454614574, 
       1.065966938024754}, {2.864311454614574, 1.065966938024754}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}}], 
      LineBox[{{2.8470178172435943`, 0.9900294163368778}, {2.864311454614574, 
       1.065966938024754}, {2.864311454614574, 1.065966938024754}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}}], 
      LineBox[{{2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}}], 
      LineBox[{{2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}}], 
      LineBox[{{2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}}], 
      LineBox[{{2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}}], 
      LineBox[{{3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}}], 
      LineBox[{{3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}}], 
      LineBox[{{3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}}], 
      LineBox[{{3.167190112968768, 0.8910998630921676}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}}], 
      LineBox[{{3.167190112968768, 0.8910998630921676}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}}], 
      LineBox[{{3.167190112968768, 0.8910998630921676}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}}], 
      LineBox[{{3.167190112968768, 0.8910998630921676}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}}], 
      LineBox[{{3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}], 
      LineBox[{{3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}], 
      LineBox[{{3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}], 
      LineBox[{{3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}], 
      LineBox[{{3.0356624672045025`, 0.8151623414042912}, {2.934702914419771, 
       0.8381543729611252}, {2.934702914419771, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {3.0356624672045025`, 
       0.8151623414042912}}], 
      LineBox[{{3.0356624672045025`, 0.8151623414042912}, {2.934702914419771, 
       0.8381543729611252}, {2.934702914419771, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {3.0356624672045025`, 
       0.8151623414042912}}], 
      LineBox[{{3.0356624672045025`, 0.8151623414042912}, {2.934702914419771, 
       0.8381543729611252}, {2.934702914419771, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {3.0356624672045025`, 
       0.8151623414042912}}], 
      LineBox[{{3.0356624672045025`, 0.8151623414042912}, {2.934702914419771, 
       0.8381543729611252}, {2.934702914419771, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {3.0356624672045025`, 
       0.8151623414042912}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.934702914419771, 1.1419044597126304`}, {3.0356624672045025`,
        1.1648964912694644`}, {3.0356624672045025`, 1.1648964912694644`}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}}], 
      LineBox[{{2.934702914419771, 1.1419044597126304`}, {3.0356624672045025`,
        1.1648964912694644`}, {3.0356624672045025`, 1.1648964912694644`}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}}], 
      LineBox[{{2.934702914419771, 1.1419044597126304`}, {3.0356624672045025`,
        1.1648964912694644`}, {3.0356624672045025`, 1.1648964912694644`}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}}], 
      LineBox[{{2.934702914419771, 1.1419044597126304`}, {3.0356624672045025`,
        1.1648964912694644`}, {3.0356624672045025`, 1.1648964912694644`}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}}], 
      LineBox[{{3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125,
        1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}}], 
      LineBox[{{3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125,
        1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}}], 
      LineBox[{{3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125,
        1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}}], 
      LineBox[{{3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125,
        1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}}], 
      LineBox[{{3.110073108772125, 1.1419044597126304`}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}}], 
      LineBox[{{3.110073108772125, 1.1419044597126304`}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}}], 
      LineBox[{{3.110073108772125, 1.1419044597126304`}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}}], 
      LineBox[{{3.110073108772125, 1.1419044597126304`}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}}], 
      LineBox[{{3.167190112968768, 1.088958969581588}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}}], 
      LineBox[{{3.167190112968768, 1.088958969581588}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}}], 
      LineBox[{{3.167190112968768, 1.088958969581588}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}}], 
      LineBox[{{3.167190112968768, 1.088958969581588}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069,
        1.4299048668781584`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069,
        1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}], 
      LineBox[{{2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069,
        1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}], 
      LineBox[{{2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069,
        1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}], 
      LineBox[{{2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069,
        1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}], 
      LineBox[{{2.832416264095069, 1.4299048668781584`}, {2.8154193030214407`,
        1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.4299048668781584`}, {2.832416264095069, 
       1.4299048668781584`}}], 
      LineBox[{{2.832416264095069, 1.4299048668781584`}, {2.8154193030214407`,
        1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.4299048668781584`}, {2.832416264095069, 
       1.4299048668781584`}}], 
      LineBox[{{2.832416264095069, 1.4299048668781584`}, {2.8154193030214407`,
        1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.4299048668781584`}, {2.832416264095069, 
       1.4299048668781584`}}], 
      LineBox[{{2.832416264095069, 1.4299048668781584`}, {2.8154193030214407`,
        1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.4299048668781584`}, {2.832416264095069, 
       1.4299048668781584`}}], 
      LineBox[{{2.8154193030214407`, 1.5045396630444403`}, {2.832416264095069,
        1.5791744592107222`}, {2.832416264095069, 1.5791744592107222`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}}], 
      LineBox[{{2.8154193030214407`, 1.5045396630444403`}, {2.832416264095069,
        1.5791744592107222`}, {2.832416264095069, 1.5791744592107222`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}}], 
      LineBox[{{2.8154193030214407`, 1.5045396630444403`}, {2.832416264095069,
        1.5791744592107222`}, {2.832416264095069, 1.5791744592107222`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}}], 
      LineBox[{{2.8154193030214407`, 1.5045396630444403`}, {2.832416264095069,
        1.5791744592107222`}, {2.832416264095069, 1.5791744592107222`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}}], 
      LineBox[{{2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`,
        1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}}], 
      LineBox[{{2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`,
        1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}}], 
      LineBox[{{2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`,
        1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}}], 
      LineBox[{{2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`,
        1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}], 
      LineBox[{{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}], 
      LineBox[{{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}], 
      LineBox[{{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}], 
      LineBox[{{3.1300989699159936`, 1.4073072688719153`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1300989699159936`, 1.4073072688719153`}}], 
      LineBox[{{3.1300989699159936`, 1.4073072688719153`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1300989699159936`, 1.4073072688719153`}}], 
      LineBox[{{3.1300989699159936`, 1.4073072688719153`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1300989699159936`, 1.4073072688719153`}}], 
      LineBox[{{3.1300989699159936`, 1.4073072688719153`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1300989699159936`, 1.4073072688719153`}}], 
      LineBox[{{3.0739618209665345`, 1.3552700707118768`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}}], 
      LineBox[{{3.0739618209665345`, 1.3552700707118768`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}}], 
      LineBox[{{3.0739618209665345`, 1.3552700707118768`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}}], 
      LineBox[{{3.0739618209665345`, 1.3552700707118768`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}}], 
      LineBox[{{3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}}], 
      LineBox[{{3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}}], 
      LineBox[{{3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}}], 
      LineBox[{{3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}], 
      LineBox[{{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}], 
      LineBox[{{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}], 
      LineBox[{{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}], 
      LineBox[{{3.0008277109434465`, 1.6764068533832472`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}}], 
      LineBox[{{3.0008277109434465`, 1.6764068533832472`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}}], 
      LineBox[{{3.0008277109434465`, 1.6764068533832472`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}}], 
      LineBox[{{3.0008277109434465`, 1.6764068533832472`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}}], 
      LineBox[{{3.0739618209665345`, 1.6538092553770039`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}], 
      LineBox[{{3.0739618209665345`, 1.6538092553770039`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}], 
      LineBox[{{3.0739618209665345`, 1.6538092553770039`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}], 
      LineBox[{{3.0739618209665345`, 1.6538092553770039`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}], 
      LineBox[{{3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1300989699159936`, 1.6017720572169654`}}], 
      LineBox[{{3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1300989699159936`, 1.6017720572169654`}}], 
      LineBox[{{3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1300989699159936`, 1.6017720572169654`}}], 
      LineBox[{{3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1300989699159936`, 1.6017720572169654`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`,
        1.9236442374196498`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       1.9032966454751998`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.126895594691735, 1.9032966454751998`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.921148023552149, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.0763479303146273`, 2.125254830301573}, {
       3.126895594691735, 2.0783988912853815`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 2.0783988912853815`}, {3.0763479303146273`, 
       2.125254830301573}, {3.010495664619877, 2.145602422246023}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`,
        2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`,
        1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}], 
      LineBox[{{2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`,
        1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}], 
      LineBox[{{2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`,
        1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}], 
      LineBox[{{2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`,
        1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}], 
      LineBox[{{2.8588526714885525`, 1.9236442374196498`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}}], 
      LineBox[{{2.8588526714885525`, 1.9236442374196498`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}}], 
      LineBox[{{2.8588526714885525`, 1.9236442374196498`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}}], 
      LineBox[{{2.8588526714885525`, 1.9236442374196498`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}}], 
      LineBox[{{2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}], 
      LineBox[{{2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}], 
      LineBox[{{2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}], 
      LineBox[{{2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}], 
      LineBox[{{2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}}], 
      LineBox[{{2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}}], 
      LineBox[{{2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}}], 
      LineBox[{{2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}}], 
      LineBox[{{3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}}], 
      LineBox[{{3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}}], 
      LineBox[{{3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}}], 
      LineBox[{{3.126895594691735, 1.9032966454751998`}, {3.0763479303146273`,
        1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}}], 
      LineBox[{{3.126895594691735, 1.9032966454751998`}, {3.0763479303146273`,
        1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}}], 
      LineBox[{{3.126895594691735, 1.9032966454751998`}, {3.0763479303146273`,
        1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}}], 
      LineBox[{{3.126895594691735, 1.9032966454751998`}, {3.0763479303146273`,
        1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}}], 
      LineBox[{{3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877,
        1.836093114514559}, {3.010495664619877, 1.836093114514559}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}], 
      LineBox[{{3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877,
        1.836093114514559}, {3.010495664619877, 1.836093114514559}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}], 
      LineBox[{{3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877,
        1.836093114514559}, {3.010495664619877, 1.836093114514559}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}], 
      LineBox[{{3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877,
        1.836093114514559}, {3.010495664619877, 1.836093114514559}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}], 
      LineBox[{{3.010495664619877, 1.836093114514559}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.010495664619877, 
       1.836093114514559}}], 
      LineBox[{{3.010495664619877, 1.836093114514559}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.010495664619877, 
       1.836093114514559}}], 
      LineBox[{{3.010495664619877, 1.836093114514559}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.010495664619877, 
       1.836093114514559}}], 
      LineBox[{{3.010495664619877, 1.836093114514559}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.010495664619877, 
       1.836093114514559}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.921148023552149, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.010495664619877, 2.145602422246023}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}}], 
      LineBox[{{2.921148023552149, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.010495664619877, 2.145602422246023}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}}], 
      LineBox[{{2.921148023552149, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.010495664619877, 2.145602422246023}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}}], 
      LineBox[{{2.921148023552149, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.010495664619877, 2.145602422246023}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}}], 
      LineBox[{{3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}}], 
      LineBox[{{3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}}], 
      LineBox[{{3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}}], 
      LineBox[{{3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}}], 
      LineBox[{{3.0763479303146273`, 2.125254830301573}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}}], 
      LineBox[{{3.0763479303146273`, 2.125254830301573}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}}], 
      LineBox[{{3.0763479303146273`, 2.125254830301573}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}}], 
      LineBox[{{3.0763479303146273`, 2.125254830301573}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}}], 
      LineBox[{{3.126895594691735, 2.0783988912853815`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}}], 
      LineBox[{{3.126895594691735, 2.0783988912853815`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}}], 
      LineBox[{{3.126895594691735, 2.0783988912853815`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}}], 
      LineBox[{{3.126895594691735, 2.0783988912853815`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`, 
       2.662963044905966}, {2.9340305420043453`, 2.662963044905966}, {
       2.858671461130262, 2.5816665090180773`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142,
        2.394458826743442}, {3.1217768495205718`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {2.9340305420043453`, 
       2.3377769013544105`}, {2.9340305420043453`, 2.3377769013544105`}, {
       3.0421149477599716`, 2.313162290855553}, {3.1217768495205718`, 
       2.337776901354411}, {3.182924678397142, 2.394458826743442}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`,
        2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`, 
       2.662963044905966}, {3.182924678397142, 2.606281119516935}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`,
        2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}], 
      LineBox[{{2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}], 
      LineBox[{{2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}], 
      LineBox[{{2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}], 
      LineBox[{{2.858671461130262, 2.4190734372422997`}, {2.8401573882462317`,
        2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.4190734372422997`}, {2.858671461130262, 
       2.4190734372422997`}}], 
      LineBox[{{2.858671461130262, 2.4190734372422997`}, {2.8401573882462317`,
        2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.4190734372422997`}, {2.858671461130262, 
       2.4190734372422997`}}], 
      LineBox[{{2.858671461130262, 2.4190734372422997`}, {2.8401573882462317`,
        2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.4190734372422997`}, {2.858671461130262, 
       2.4190734372422997`}}], 
      LineBox[{{2.858671461130262, 2.4190734372422997`}, {2.8401573882462317`,
        2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.4190734372422997`}, {2.858671461130262, 
       2.4190734372422997`}}], 
      LineBox[{{2.8401573882462317`, 2.5003699731301885`}, {2.858671461130262,
        2.5816665090180773`}, {2.858671461130262, 2.5816665090180773`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}}], 
      LineBox[{{2.8401573882462317`, 2.5003699731301885`}, {2.858671461130262,
        2.5816665090180773`}, {2.858671461130262, 2.5816665090180773`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}}], 
      LineBox[{{2.8401573882462317`, 2.5003699731301885`}, {2.858671461130262,
        2.5816665090180773`}, {2.858671461130262, 2.5816665090180773`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}}], 
      LineBox[{{2.8401573882462317`, 2.5003699731301885`}, {2.858671461130262,
        2.5816665090180773`}, {2.858671461130262, 2.5816665090180773`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}}], 
      LineBox[{{2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`,
        2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}}], 
      LineBox[{{2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`,
        2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}}], 
      LineBox[{{2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`,
        2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}}], 
      LineBox[{{2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`,
        2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142,
        2.394458826743442}, {3.182924678397142, 2.394458826743442}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}}], 
      LineBox[{{3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142,
        2.394458826743442}, {3.182924678397142, 2.394458826743442}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}}], 
      LineBox[{{3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142,
        2.394458826743442}, {3.182924678397142, 2.394458826743442}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}}], 
      LineBox[{{3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142,
        2.394458826743442}, {3.182924678397142, 2.394458826743442}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}}], 
      LineBox[{{3.182924678397142, 2.394458826743442}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}}], 
      LineBox[{{3.182924678397142, 2.394458826743442}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}}], 
      LineBox[{{3.182924678397142, 2.394458826743442}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}}], 
      LineBox[{{3.182924678397142, 2.394458826743442}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}}], 
      LineBox[{{3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`,
        2.313162290855553}, {3.0421149477599716`, 2.313162290855553}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}], 
      LineBox[{{3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`,
        2.313162290855553}, {3.0421149477599716`, 2.313162290855553}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}], 
      LineBox[{{3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`,
        2.313162290855553}, {3.0421149477599716`, 2.313162290855553}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}], 
      LineBox[{{3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`,
        2.313162290855553}, {3.0421149477599716`, 2.313162290855553}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}], 
      LineBox[{{3.0421149477599716`, 2.313162290855553}, {2.9340305420043453`,
        2.337776901354411}, {2.9340305420043453`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {3.0421149477599716`, 
       2.313162290855553}}], 
      LineBox[{{3.0421149477599716`, 2.313162290855553}, {2.9340305420043453`,
        2.337776901354411}, {2.9340305420043453`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {3.0421149477599716`, 
       2.313162290855553}}], 
      LineBox[{{3.0421149477599716`, 2.313162290855553}, {2.9340305420043453`,
        2.337776901354411}, {2.9340305420043453`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {3.0421149477599716`, 
       2.313162290855553}}], 
      LineBox[{{3.0421149477599716`, 2.313162290855553}, {2.9340305420043453`,
        2.337776901354411}, {2.9340305420043453`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {3.0421149477599716`, 
       2.313162290855553}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}], 
      LineBox[{{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}], 
      LineBox[{{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}], 
      LineBox[{{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}], 
      LineBox[{{3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`,
        2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}}], 
      LineBox[{{3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`,
        2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}}], 
      LineBox[{{3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`,
        2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}}], 
      LineBox[{{3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`,
        2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}}], 
      LineBox[{{3.1217768495205718`, 2.662963044905966}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}}], 
      LineBox[{{3.1217768495205718`, 2.662963044905966}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}}], 
      LineBox[{{3.1217768495205718`, 2.662963044905966}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}}], 
      LineBox[{{3.1217768495205718`, 2.662963044905966}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}}], 
      LineBox[{{3.182924678397142, 2.606281119516935}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}}], 
      LineBox[{{3.182924678397142, 2.606281119516935}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}}], 
      LineBox[{{3.182924678397142, 2.606281119516935}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}}], 
      LineBox[{{3.182924678397142, 2.606281119516935}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`,
        2.9727513799026544`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.88603184364156, 
       3.0410854545733312`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.0557879445798726`, 2.883727412194738}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}, {3.0557879445798726`, 2.883727412194738}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.964937236453439, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.1227480220771957`, 3.177753603914685}, {
       3.1741460337976903`, 3.1301094222812478`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 3.1301094222812478`}, {3.1227480220771957`, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`,
        3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`,
        2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}], 
      LineBox[{{2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`,
        2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}], 
      LineBox[{{2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`,
        2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}], 
      LineBox[{{2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`,
        2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}], 
      LineBox[{{2.9015939094183896`, 2.9727513799026544`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.9015939094183896`, 
       2.9727513799026544`}}], 
      LineBox[{{2.9015939094183896`, 2.9727513799026544`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.9015939094183896`, 
       2.9727513799026544`}}], 
      LineBox[{{2.9015939094183896`, 2.9727513799026544`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.9015939094183896`, 
       2.9727513799026544`}}], 
      LineBox[{{2.9015939094183896`, 2.9727513799026544`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.9015939094183896`, 
       2.9727513799026544`}}], 
      LineBox[{{2.88603184364156, 3.0410854545733312`}, {2.9015939094183896`, 
       3.109419529244008}, {2.9015939094183896`, 3.109419529244008}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}}], 
      LineBox[{{2.88603184364156, 3.0410854545733312`}, {2.9015939094183896`, 
       3.109419529244008}, {2.9015939094183896`, 3.109419529244008}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}}], 
      LineBox[{{2.88603184364156, 3.0410854545733312`}, {2.9015939094183896`, 
       3.109419529244008}, {2.9015939094183896`, 3.109419529244008}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}}], 
      LineBox[{{2.88603184364156, 3.0410854545733312`}, {2.9015939094183896`, 
       3.109419529244008}, {2.9015939094183896`, 3.109419529244008}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}}], 
      LineBox[{{2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}}], 
      LineBox[{{2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}}], 
      LineBox[{{2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}}], 
      LineBox[{{2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}], 
      LineBox[{{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}], 
      LineBox[{{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}], 
      LineBox[{{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}], 
      LineBox[{{3.1741460337976903`, 2.9520614868654147`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1741460337976903`, 2.9520614868654147`}}], 
      LineBox[{{3.1741460337976903`, 2.9520614868654147`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1741460337976903`, 2.9520614868654147`}}], 
      LineBox[{{3.1741460337976903`, 2.9520614868654147`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1741460337976903`, 2.9520614868654147`}}], 
      LineBox[{{3.1741460337976903`, 2.9520614868654147`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1741460337976903`, 2.9520614868654147`}}], 
      LineBox[{{3.1227480220771957`, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}}], 
      LineBox[{{3.1227480220771957`, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}}], 
      LineBox[{{3.1227480220771957`, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}}], 
      LineBox[{{3.1227480220771957`, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}}], 
      LineBox[{{3.0557879445798726`, 2.883727412194738}, {2.964937236453439, 
       2.9044173052319775`}, {2.964937236453439, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}}], 
      LineBox[{{3.0557879445798726`, 2.883727412194738}, {2.964937236453439, 
       2.9044173052319775`}, {2.964937236453439, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}}], 
      LineBox[{{3.0557879445798726`, 2.883727412194738}, {2.964937236453439, 
       2.9044173052319775`}, {2.964937236453439, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}}], 
      LineBox[{{3.0557879445798726`, 2.883727412194738}, {2.964937236453439, 
       2.9044173052319775`}, {2.964937236453439, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.964937236453439, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.0557879445798726`, 3.1984434969519246`}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}}], 
      LineBox[{{2.964937236453439, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.0557879445798726`, 3.1984434969519246`}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}}], 
      LineBox[{{2.964937236453439, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.0557879445798726`, 3.1984434969519246`}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}}], 
      LineBox[{{2.964937236453439, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.0557879445798726`, 3.1984434969519246`}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}}], 
      LineBox[{{3.0557879445798726`, 3.1984434969519246`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}}], 
      LineBox[{{3.0557879445798726`, 3.1984434969519246`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}}], 
      LineBox[{{3.0557879445798726`, 3.1984434969519246`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}}], 
      LineBox[{{3.0557879445798726`, 3.1984434969519246`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}}], 
      LineBox[{{3.1227480220771957`, 3.177753603914685}, {3.1741460337976903`,
        3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}}], 
      LineBox[{{3.1227480220771957`, 3.177753603914685}, {3.1741460337976903`,
        3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}}], 
      LineBox[{{3.1227480220771957`, 3.177753603914685}, {3.1741460337976903`,
        3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}}], 
      LineBox[{{3.1227480220771957`, 3.177753603914685}, {3.1741460337976903`,
        3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}}], 
      LineBox[{{3.1741460337976903`, 3.1301094222812478`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1741460337976903`, 3.1301094222812478`}}], 
      LineBox[{{3.1741460337976903`, 3.1301094222812478`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1741460337976903`, 3.1301094222812478`}}], 
      LineBox[{{3.1741460337976903`, 3.1301094222812478`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1741460337976903`, 3.1301094222812478`}}], 
      LineBox[{{3.1741460337976903`, 3.1301094222812478`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1741460337976903`, 3.1301094222812478`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8489083345715707`, 
       3.53712285676085}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.450037840492806}, {3.0804688095844512`, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.0804688095844512`, 
       3.403431354178486}, {3.130747367169189, 3.450037840492806}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`,
        3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.926095159575864, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.0804688095844512`, 3.670814359343214}, {
       3.130747367169189, 3.624207873028894}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.624207873028894}, {3.0804688095844512`, 
       3.670814359343214}, {3.014967129662749, 3.6910536243200758`}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`,
        3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}], 
      LineBox[{{2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}], 
      LineBox[{{2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}], 
      LineBox[{{2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}], 
      LineBox[{{2.8641314569085345`, 3.470277105469668}, {2.8489083345715707`,
        3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.470277105469668}, {2.8641314569085345`, 
       3.470277105469668}}], 
      LineBox[{{2.8641314569085345`, 3.470277105469668}, {2.8489083345715707`,
        3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.470277105469668}, {2.8641314569085345`, 
       3.470277105469668}}], 
      LineBox[{{2.8641314569085345`, 3.470277105469668}, {2.8489083345715707`,
        3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.470277105469668}, {2.8641314569085345`, 
       3.470277105469668}}], 
      LineBox[{{2.8641314569085345`, 3.470277105469668}, {2.8489083345715707`,
        3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.470277105469668}, {2.8641314569085345`, 
       3.470277105469668}}], 
      LineBox[{{2.8489083345715707`, 3.53712285676085}, {2.8641314569085345`, 
       3.603968608052032}, {2.8641314569085345`, 3.603968608052032}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}}], 
      LineBox[{{2.8489083345715707`, 3.53712285676085}, {2.8641314569085345`, 
       3.603968608052032}, {2.8641314569085345`, 3.603968608052032}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}}], 
      LineBox[{{2.8489083345715707`, 3.53712285676085}, {2.8641314569085345`, 
       3.603968608052032}, {2.8641314569085345`, 3.603968608052032}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}}], 
      LineBox[{{2.8489083345715707`, 3.53712285676085}, {2.8641314569085345`, 
       3.603968608052032}, {2.8641314569085345`, 3.603968608052032}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}}], 
      LineBox[{{2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}}], 
      LineBox[{{2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}}], 
      LineBox[{{2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}}], 
      LineBox[{{2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}}], 
      LineBox[{{3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}}], 
      LineBox[{{3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}}], 
      LineBox[{{3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}}], 
      LineBox[{{3.130747367169189, 3.450037840492806}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}}], 
      LineBox[{{3.130747367169189, 3.450037840492806}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}}], 
      LineBox[{{3.130747367169189, 3.450037840492806}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}}], 
      LineBox[{{3.130747367169189, 3.450037840492806}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}}], 
      LineBox[{{3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}], 
      LineBox[{{3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}], 
      LineBox[{{3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}], 
      LineBox[{{3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}], 
      LineBox[{{3.014967129662749, 3.383192089201624}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.014967129662749, 
       3.383192089201624}}], 
      LineBox[{{3.014967129662749, 3.383192089201624}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.014967129662749, 
       3.383192089201624}}], 
      LineBox[{{3.014967129662749, 3.383192089201624}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.014967129662749, 
       3.383192089201624}}], 
      LineBox[{{3.014967129662749, 3.383192089201624}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.014967129662749, 
       3.383192089201624}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{2.926095159575864, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.014967129662749, 3.6910536243200758`}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}}], 
      LineBox[{{2.926095159575864, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.014967129662749, 3.6910536243200758`}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}}], 
      LineBox[{{2.926095159575864, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.014967129662749, 3.6910536243200758`}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}}], 
      LineBox[{{2.926095159575864, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.014967129662749, 3.6910536243200758`}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}}], 
      LineBox[{{3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`,
        3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}}], 
      LineBox[{{3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`,
        3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}}], 
      LineBox[{{3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`,
        3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}}], 
      LineBox[{{3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`,
        3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}}], 
      LineBox[{{3.0804688095844512`, 3.670814359343214}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}}], 
      LineBox[{{3.0804688095844512`, 3.670814359343214}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}}], 
      LineBox[{{3.0804688095844512`, 3.670814359343214}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}}], 
      LineBox[{{3.0804688095844512`, 3.670814359343214}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}}], 
      LineBox[{{3.130747367169189, 3.624207873028894}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}}], 
      LineBox[{{3.130747367169189, 3.624207873028894}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}}], 
      LineBox[{{3.130747367169189, 3.624207873028894}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}}], 
      LineBox[{{3.130747367169189, 3.624207873028894}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}], 
      LineBox[{{3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}], 
      LineBox[{{3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}], 
      LineBox[{{3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}], 
      LineBox[{{3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}], 
      LineBox[{{3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}], 
      LineBox[{{3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}], 
      LineBox[{{3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}], 
      LineBox[{{3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}], 
      LineBox[{{3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}], 
      LineBox[{{3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}], 
      LineBox[{{3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}], 
      LineBox[{{3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}], 
      LineBox[{{3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}], 
      LineBox[{{3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}], 
      LineBox[{{3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}], 
      LineBox[{{3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}], 
      LineBox[{{3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}], 
      LineBox[{{3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}], 
      LineBox[{{3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}], 
      LineBox[{{3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}], 
      LineBox[{{3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}], 
      LineBox[{{3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}], 
      LineBox[{{3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}], 
      LineBox[{{3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}], 
      LineBox[{{3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}], 
      LineBox[{{3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}], 
      LineBox[{{3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}], 
      LineBox[{{3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}], 
      LineBox[{{3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}], 
      LineBox[{{3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}], 
      LineBox[{{3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}], 
      LineBox[{{3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}], 
      LineBox[{{3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}], 
      LineBox[{{3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}], 
      LineBox[{{3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}], 
      LineBox[{{3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}], 
      LineBox[{{3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}], 
      LineBox[{{3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}], 
      LineBox[{{3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}], 
      LineBox[{{3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}], 
      LineBox[{{3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}], 
      LineBox[{{3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}], 
      LineBox[{{3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}], 
      LineBox[{{3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}], 
      LineBox[{{3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3014538080137714`, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}], 
      LineBox[{{3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}], 
      LineBox[{{3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}], 
      LineBox[{{3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}], 
      LineBox[{{3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}], 
      LineBox[{{3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}], 
      LineBox[{{3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}], 
      LineBox[{{3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}], 
      LineBox[{{3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}], 
      LineBox[{{3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}], 
      LineBox[{{3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}], 
      LineBox[{{3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}], 
      LineBox[{{3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}], 
      LineBox[{{3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}], 
      LineBox[{{3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}], 
      LineBox[{{3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}], 
      LineBox[{{3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}], 
      LineBox[{{3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}], 
      LineBox[{{3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}], 
      LineBox[{{3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}], 
      LineBox[{{3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}], 
      LineBox[{{3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}], 
      LineBox[{{3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}], 
      LineBox[{{3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}], 
      LineBox[{{3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}], 
      LineBox[{{3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}], 
      LineBox[{{3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}], 
      LineBox[{{3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}], 
      LineBox[{{3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}], 
      LineBox[{{3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}], 
      LineBox[{{3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}], 
      LineBox[{{3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}], 
      LineBox[{{3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}], 
      LineBox[{{3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}], 
      LineBox[{{3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}], 
      LineBox[{{3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}], 
      LineBox[{{3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}], 
      LineBox[{{3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}], 
      LineBox[{{3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}], 
      LineBox[{{3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}], 
      LineBox[{{3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}], 
      LineBox[{{3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}], 
      LineBox[{{3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}], 
      LineBox[{{3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}], 
      LineBox[{{3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}], 
      LineBox[{{3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}], 
      LineBox[{{3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}], 
      LineBox[{{3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}], 
      LineBox[{{3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}], 
      LineBox[{{3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}], 
      LineBox[{{3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}], 
      LineBox[{{3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}], 
      LineBox[{{3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}], 
      LineBox[{{3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}], 
      LineBox[{{3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}], 
      LineBox[{{3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}], 
      LineBox[{{3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}], 
      LineBox[{{3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}], 
      LineBox[{{3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}], 
      LineBox[{{3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}], 
      LineBox[{{3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}], 
      LineBox[{{3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}], 
      LineBox[{{3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}], 
      LineBox[{{3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}], 
      LineBox[{{3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}], 
      LineBox[{{3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}], 
      LineBox[{{3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}], 
      LineBox[{{3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}], 
      LineBox[{{3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}], 
      LineBox[{{3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}], 
      LineBox[{{3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}], 
      LineBox[{{3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}], 
      LineBox[{{3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}], 
      LineBox[{{3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}], 
      LineBox[{{3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}], 
      LineBox[{{3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}], 
      LineBox[{{3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}], 
      LineBox[{{3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}], 
      LineBox[{{3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}], 
      LineBox[{{3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}], 
      LineBox[{{3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}], 
      LineBox[{{3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}], 
      LineBox[{{3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}], 
      LineBox[{{3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}], 
      LineBox[{{3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}], 
      LineBox[{{3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}], 
      LineBox[{{3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}], 
      LineBox[{{3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}], 
      LineBox[{{3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}], 
      LineBox[{{3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}], 
      LineBox[{{3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}], 
      LineBox[{{3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}], 
      LineBox[{{3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}], 
      LineBox[{{3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}], 
      LineBox[{{3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}], 
      LineBox[{{3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}], 
      LineBox[{{3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}], 
      LineBox[{{3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}], 
      LineBox[{{3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}], 
      LineBox[{{3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}], 
      LineBox[{{3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}], 
      LineBox[{{3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}], 
      LineBox[{{3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}], 
      LineBox[{{3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}], 
      LineBox[{{3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}], 
      LineBox[{{3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}], 
      LineBox[{{3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}], 
      LineBox[{{3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}], 
      LineBox[{{3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}], 
      LineBox[{{3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}], 
      LineBox[{{3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}], 
      LineBox[{{3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}], 
      LineBox[{{3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}], 
      LineBox[{{3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}], 
      LineBox[{{3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}], 
      LineBox[{{3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}], 
      LineBox[{{3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}], 
      LineBox[{{3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}], 
      LineBox[{{3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}], 
      LineBox[{{3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}], 
      LineBox[{{3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}], 
      LineBox[{{3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}], 
      LineBox[{{3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}], 
      LineBox[{{3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}], 
      LineBox[{{3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}], 
      LineBox[{{3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}], 
      LineBox[{{3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}], 
      LineBox[{{3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}], 
      LineBox[{{3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}], 
      LineBox[{{3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}], 
      LineBox[{{3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}], 
      LineBox[{{3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}], 
      LineBox[{{3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}], 
      LineBox[{{3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}], 
      LineBox[{{3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}], 
      LineBox[{{3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}], 
      LineBox[{{3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}], 
      LineBox[{{3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}], 
      LineBox[{{3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}], 
      LineBox[{{3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}], 
      LineBox[{{3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}], 
      LineBox[{{3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}], 
      LineBox[{{3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}], 
      LineBox[{{3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}], 
      LineBox[{{3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}], 
      LineBox[{{3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}], 
      LineBox[{{3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}], 
      LineBox[{{3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}], 
      LineBox[{{3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}], 
      LineBox[{{3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}], 
      LineBox[{{3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}], 
      LineBox[{{3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}], 
      LineBox[{{3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}], 
      LineBox[{{3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}], 
      LineBox[{{3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}], 
      LineBox[{{3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}], 
      LineBox[{{3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}], 
      LineBox[{{3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}], 
      LineBox[{{3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}], 
      LineBox[{{3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}], 
      LineBox[{{3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}], 
      LineBox[{{3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}], 
      LineBox[{{3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}], 
      LineBox[{{3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}], 
      LineBox[{{3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}], 
      LineBox[{{3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}], 
      LineBox[{{3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}], 
      LineBox[{{3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}], 
      LineBox[{{3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}], 
      LineBox[{{3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}], 
      LineBox[{{3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}], 
      LineBox[{{3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}], 
      LineBox[{{3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}], 
      LineBox[{{3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}], 
      LineBox[{{3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}], 
      LineBox[{{3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}], 
      LineBox[{{3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}], 
      LineBox[{{3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}], 
      LineBox[{{3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}], 
      LineBox[{{3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}], 
      LineBox[{{3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}], 
      LineBox[{{3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}], 
      LineBox[{{3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}], 
      LineBox[{{3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}], 
      LineBox[{{3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}], 
      LineBox[{{3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}], 
      LineBox[{{3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}], 
      LineBox[{{3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}], 
      LineBox[{{3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}], 
      LineBox[{{3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}], 
      LineBox[{{3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}], 
      LineBox[{{3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}], 
      LineBox[{{3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}], 
      LineBox[{{3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}], 
      LineBox[{{3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}], 
      LineBox[{{3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}], 
      LineBox[{{3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}], 
      LineBox[{{3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}], 
      LineBox[{{3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}], 
      LineBox[{{3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}], 
      LineBox[{{3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}], 
      LineBox[{{3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}], 
      LineBox[{{3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}], 
      LineBox[{{3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}], 
      LineBox[{{3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}], 
      LineBox[{{3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}], 
      LineBox[{{3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}], 
      LineBox[{{3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}], 
      LineBox[{{3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}], 
      LineBox[{{3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}], 
      LineBox[{{3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}], 
      LineBox[{{3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}], 
      LineBox[{{3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}], 
      LineBox[{{3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}], 
      LineBox[{{3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}], 
      LineBox[{{3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}], 
      LineBox[{{3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}], 
      LineBox[{{3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}], 
      LineBox[{{3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}], 
      LineBox[{{3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}], 
      LineBox[{{3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}], 
      LineBox[{{3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}], 
      LineBox[{{3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}], 
      LineBox[{{3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}], 
      LineBox[{{3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}], 
      LineBox[{{3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}], 
      LineBox[{{3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}], 
      LineBox[{{3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}], 
      LineBox[{{3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}], 
      LineBox[{{3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}], 
      LineBox[{{3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}], 
      LineBox[{{3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}], 
      LineBox[{{3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}], 
      LineBox[{{3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}], 
      LineBox[{{3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}], 
      LineBox[{{3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}], 
      LineBox[{{3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}], 
      LineBox[{{3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}], 
      LineBox[{{3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}], 
      LineBox[{{3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}], 
      LineBox[{{3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}], 
      LineBox[{{3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}], 
      LineBox[{{3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}], 
      LineBox[{{3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}], 
      LineBox[{{3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}], 
      LineBox[{{3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}], 
      LineBox[{{3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}], 
      LineBox[{{3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}], 
      LineBox[{{3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}], 
      LineBox[{{3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}], 
      LineBox[{{3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}], 
      LineBox[{{3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}], 
      LineBox[{{3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}], 
      LineBox[{{3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}], 
      LineBox[{{3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}], 
      LineBox[{{3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}], 
      LineBox[{{3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}], 
      LineBox[{{3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}], 
      LineBox[{{3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}], 
      LineBox[{{3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}], 
      LineBox[{{3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}], 
      LineBox[{{3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}], 
      LineBox[{{3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}], 
      LineBox[{{3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}], 
      LineBox[{{3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}], 
      LineBox[{{3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}], 
      LineBox[{{3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}], 
      LineBox[{{3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}], 
      LineBox[{{3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}], 
      LineBox[{{3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}], 
      LineBox[{{3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}], 
      LineBox[{{3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}], 
      LineBox[{{3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}], 
      LineBox[{{3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}], 
      LineBox[{{3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}], 
      LineBox[{{3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}], 
      LineBox[{{3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}], 
      LineBox[{{3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}], 
      LineBox[{{3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}], 
      LineBox[{{3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}], 
      LineBox[{{3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}], 
      LineBox[{{3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}], 
      LineBox[{{3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}], 
      LineBox[{{3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}], 
      LineBox[{{3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}], 
      LineBox[{{3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}], 
      LineBox[{{3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}], 
      LineBox[{{3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}], 
      LineBox[{{3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}], 
      LineBox[{{3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}], 
      LineBox[{{3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}], 
      LineBox[{{3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}], 
      LineBox[{{3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}], 
      LineBox[{{3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}], 
      LineBox[{{3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}], 
      LineBox[{{3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}], 
      LineBox[{{3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}], 
      LineBox[{{3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}], 
      LineBox[{{3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}], 
      LineBox[{{3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}], 
      LineBox[{{3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}], 
      LineBox[{{3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}], 
      LineBox[{{3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}], 
      LineBox[{{3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}], 
      LineBox[{{3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}], 
      LineBox[{{3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}], 
      LineBox[{{3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}], 
      LineBox[{{3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}], 
      LineBox[{{3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}], 
      LineBox[{{3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}], 
      LineBox[{{3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}], 
      LineBox[{{3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}], 
      LineBox[{{3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}], 
      LineBox[{{3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}], 
      LineBox[{{3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}], 
      LineBox[{{3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.1449202032691863}, {
       3.1836394581301835`, -0.1449202032691863}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.35084787490958663`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}], 
      LineBox[{{3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}], 
      LineBox[{{3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}], 
      LineBox[{{3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}], 
      LineBox[{{3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}], 
      LineBox[{{3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}], 
      LineBox[{{3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}], 
      LineBox[{{3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}], 
      LineBox[{{3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}], 
      LineBox[{{3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}], 
      LineBox[{{3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}], 
      LineBox[{{3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}], 
      LineBox[{{3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}], 
      LineBox[{{3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}], 
      LineBox[{{3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}], 
      LineBox[{{3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}], 
      LineBox[{{3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}], 
      LineBox[{{3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}], 
      LineBox[{{3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}], 
      LineBox[{{3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}], 
      LineBox[{{3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}], 
      LineBox[{{3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}], 
      LineBox[{{3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}], 
      LineBox[{{3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}], 
      LineBox[{{3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}], 
      LineBox[{{3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}], 
      LineBox[{{3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}], 
      LineBox[{{3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}], 
      LineBox[{{3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}], 
      LineBox[{{3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}], 
      LineBox[{{3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}], 
      LineBox[{{3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}], 
      LineBox[{{3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}], 
      LineBox[{{3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}], 
      LineBox[{{3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}], 
      LineBox[{{3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}], 
      LineBox[{{3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}], 
      LineBox[{{3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}], 
      LineBox[{{3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}], 
      LineBox[{{3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}], 
      LineBox[{{3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}], 
      LineBox[{{3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}], 
      LineBox[{{3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}], 
      LineBox[{{3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}], 
      LineBox[{{3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}], 
      LineBox[{{3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1543700209256644`, 0.1216113847941172}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.1543700209256644`, 0.4060719235638665}, {3.1543700209256644`, 
       0.4060719235638665}, {3.0884487473052338`, 0.3349567888714292}, {
       3.072253336609394, 0.26384165417899186`}, {3.0884487473052338`, 
       0.1927265194865545}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.12161138479411718`}, {3.1543700209256644`, 
       0.12161138479411718`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.318603389558205, 
       0.4060719235638665}, {3.372093197447488, 0.3564887191303286}, {
       3.4007200738744756`, 0.26384165417899186`}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1543700209256644`, 0.1216113847941172}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}}], 
      LineBox[{{3.1543700209256644`, 0.1216113847941172}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}}], 
      LineBox[{{3.1543700209256644`, 0.1216113847941172}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}}], 
      LineBox[{{3.1543700209256644`, 0.1216113847941172}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}}], 
      LineBox[{{3.0884487473052338`, 0.19272651948655453`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}}], 
      LineBox[{{3.0884487473052338`, 0.19272651948655453`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}}], 
      LineBox[{{3.0884487473052338`, 0.19272651948655453`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}}], 
      LineBox[{{3.0884487473052338`, 0.19272651948655453`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}}], 
      LineBox[{{3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}}], 
      LineBox[{{3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}}], 
      LineBox[{{3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}}], 
      LineBox[{{3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}}], 
      LineBox[{{3.0884487473052338`, 0.3349567888714292}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.0884487473052338`, 0.3349567888714292}}], 
      LineBox[{{3.0884487473052338`, 0.3349567888714292}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.0884487473052338`, 0.3349567888714292}}], 
      LineBox[{{3.0884487473052338`, 0.3349567888714292}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.0884487473052338`, 0.3349567888714292}}], 
      LineBox[{{3.0884487473052338`, 0.3349567888714292}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.0884487473052338`, 0.3349567888714292}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}], 
      LineBox[{{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}], 
      LineBox[{{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}], 
      LineBox[{{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}], 
      LineBox[{{3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}}], 
      LineBox[{{3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}}], 
      LineBox[{{3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}}], 
      LineBox[{{3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}}], 
      LineBox[{{3.318603389558205, 0.1216113847941172}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}}], 
      LineBox[{{3.318603389558205, 0.1216113847941172}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}}], 
      LineBox[{{3.318603389558205, 0.1216113847941172}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}}], 
      LineBox[{{3.318603389558205, 0.1216113847941172}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}}], 
      LineBox[{{3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.1216113847941172}, {3.1543700209256644`, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}}], 
      LineBox[{{3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.1216113847941172}, {3.1543700209256644`, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}}], 
      LineBox[{{3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.1216113847941172}, {3.1543700209256644`, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}}], 
      LineBox[{{3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.1216113847941172}, {3.1543700209256644`, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}], 
      LineBox[{{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}], 
      LineBox[{{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}], 
      LineBox[{{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}], 
      LineBox[{{3.2489181709730826`, 0.42760385382276594`}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.2489181709730826`, 0.42760385382276594`}}], 
      LineBox[{{3.2489181709730826`, 0.42760385382276594`}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.2489181709730826`, 0.42760385382276594`}}], 
      LineBox[{{3.2489181709730826`, 0.42760385382276594`}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.2489181709730826`, 0.42760385382276594`}}], 
      LineBox[{{3.2489181709730826`, 0.42760385382276594`}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.2489181709730826`, 0.42760385382276594`}}], 
      LineBox[{{3.318603389558205, 0.4060719235638665}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}], 
      LineBox[{{3.318603389558205, 0.4060719235638665}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}], 
      LineBox[{{3.318603389558205, 0.4060719235638665}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}], 
      LineBox[{{3.318603389558205, 0.4060719235638665}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}], 
      LineBox[{{3.372093197447488, 0.3564887191303286}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.3564887191303286}, {3.372093197447488, 
       0.3564887191303286}}], 
      LineBox[{{3.372093197447488, 0.3564887191303286}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.3564887191303286}, {3.372093197447488, 
       0.3564887191303286}}], 
      LineBox[{{3.372093197447488, 0.3564887191303286}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.3564887191303286}, {3.372093197447488, 
       0.3564887191303286}}], 
      LineBox[{{3.372093197447488, 0.3564887191303286}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.3564887191303286}, {3.372093197447488, 
       0.3564887191303286}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1939818044282577`, 0.5966727036078434}, {3.133712121157488, 
       0.6616909656691962}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.7917274897919017}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}, {
       3.133712121157488, 0.7917274897919017}, {3.1189051822215306`, 
       0.7267092277305489}, {3.133712121157488, 0.6616909656691962}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.344135048841712, 0.5966727036078434}, {
       3.2804241127186877`, 0.5769867578479915}, {3.1939818044282577`, 
       0.5966727036078434}, {3.1939818044282577`, 0.5966727036078434}, {
       3.2804241127186877`, 0.5769867578479915}, {3.344135048841712, 
       0.5966727036078434}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.344135048841712, 
       0.8567457518532544}, {3.393039046028779, 0.8114134355517537}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1939818044282577`, 0.5966727036078434}, {3.133712121157488, 
       0.6616909656691962}, {3.133712121157488, 0.6616909656691962}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}}], 
      LineBox[{{3.1939818044282577`, 0.5966727036078434}, {3.133712121157488, 
       0.6616909656691962}, {3.133712121157488, 0.6616909656691962}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}}], 
      LineBox[{{3.1939818044282577`, 0.5966727036078434}, {3.133712121157488, 
       0.6616909656691962}, {3.133712121157488, 0.6616909656691962}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}}], 
      LineBox[{{3.1939818044282577`, 0.5966727036078434}, {3.133712121157488, 
       0.6616909656691962}, {3.133712121157488, 0.6616909656691962}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}}], 
      LineBox[{{3.133712121157488, 0.6616909656691962}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}}], 
      LineBox[{{3.133712121157488, 0.6616909656691962}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}}], 
      LineBox[{{3.133712121157488, 0.6616909656691962}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}}], 
      LineBox[{{3.133712121157488, 0.6616909656691962}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}}], 
      LineBox[{{3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}}], 
      LineBox[{{3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}}], 
      LineBox[{{3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}}], 
      LineBox[{{3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}}], 
      LineBox[{{3.133712121157488, 0.7917274897919017}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}}], 
      LineBox[{{3.133712121157488, 0.7917274897919017}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}}], 
      LineBox[{{3.133712121157488, 0.7917274897919017}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}}], 
      LineBox[{{3.133712121157488, 0.7917274897919017}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}], 
      LineBox[{{3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}], 
      LineBox[{{3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}], 
      LineBox[{{3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}], 
      LineBox[{{3.393039046028779, 0.6420050199093441}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.393039046028779, 0.6420050199093441}, {3.393039046028779, 
       0.6420050199093441}}], 
      LineBox[{{3.393039046028779, 0.6420050199093441}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.393039046028779, 0.6420050199093441}, {3.393039046028779, 
       0.6420050199093441}}], 
      LineBox[{{3.393039046028779, 0.6420050199093441}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.393039046028779, 0.6420050199093441}, {3.393039046028779, 
       0.6420050199093441}}], 
      LineBox[{{3.393039046028779, 0.6420050199093441}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.393039046028779, 0.6420050199093441}, {3.393039046028779, 
       0.6420050199093441}}], 
      LineBox[{{3.344135048841712, 0.5966727036078434}, {3.2804241127186877`, 
       0.5769867578479915}, {3.2804241127186877`, 0.5769867578479915}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}}], 
      LineBox[{{3.344135048841712, 0.5966727036078434}, {3.2804241127186877`, 
       0.5769867578479915}, {3.2804241127186877`, 0.5769867578479915}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}}], 
      LineBox[{{3.344135048841712, 0.5966727036078434}, {3.2804241127186877`, 
       0.5769867578479915}, {3.2804241127186877`, 0.5769867578479915}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}}], 
      LineBox[{{3.344135048841712, 0.5966727036078434}, {3.2804241127186877`, 
       0.5769867578479915}, {3.2804241127186877`, 0.5769867578479915}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}}], 
      LineBox[{{3.2804241127186877`, 0.5769867578479915}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}}], 
      LineBox[{{3.2804241127186877`, 0.5769867578479915}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}}], 
      LineBox[{{3.2804241127186877`, 0.5769867578479915}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}}], 
      LineBox[{{3.2804241127186877`, 0.5769867578479915}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}], 
      LineBox[{{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}], 
      LineBox[{{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}], 
      LineBox[{{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}], 
      LineBox[{{3.2804241127186877`, 0.8764316976131064}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}}], 
      LineBox[{{3.2804241127186877`, 0.8764316976131064}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}}], 
      LineBox[{{3.2804241127186877`, 0.8764316976131064}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}}], 
      LineBox[{{3.2804241127186877`, 0.8764316976131064}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}}], 
      LineBox[{{3.344135048841712, 0.8567457518532544}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}], 
      LineBox[{{3.344135048841712, 0.8567457518532544}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}], 
      LineBox[{{3.344135048841712, 0.8567457518532544}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}], 
      LineBox[{{3.344135048841712, 0.8567457518532544}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}], 
      LineBox[{{3.393039046028779, 0.8114134355517537}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.8114134355517537}, {3.393039046028779, 
       0.8114134355517537}}], 
      LineBox[{{3.393039046028779, 0.8114134355517537}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.8114134355517537}, {3.393039046028779, 
       0.8114134355517537}}], 
      LineBox[{{3.393039046028779, 0.8114134355517537}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.8114134355517537}, {3.393039046028779, 
       0.8114134355517537}}], 
      LineBox[{{3.393039046028779, 0.8114134355517537}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.8114134355517537}, {3.393039046028779, 
       0.8114134355517537}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2131200024055504`, 1.155328504564207}, {3.156857698012141, 
       1.2160236509911746`}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.3374139438451094`}, {3.2131200024055504`, 
       1.398109090272077}, {3.2131200024055504`, 1.398109090272077}, {
       3.156857698012141, 1.3374139438451094`}, {3.143035284149324, 
       1.276718797418142}, {3.156857698012141, 1.2160236509911746`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.3532894389180044`, 1.155328504564207}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.2131200024055504`, 
       1.155328504564207}, {3.2131200024055504`, 1.155328504564207}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.3532894389180044`, 
       1.155328504564207}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`,
        1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`,
        1.4164861019387387`}, {3.3532894389180044`, 1.398109090272077}, {
       3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`,
        1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2131200024055504`, 1.155328504564207}, {3.156857698012141, 
       1.2160236509911746`}, {3.156857698012141, 1.2160236509911746`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}}], 
      LineBox[{{3.2131200024055504`, 1.155328504564207}, {3.156857698012141, 
       1.2160236509911746`}, {3.156857698012141, 1.2160236509911746`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}}], 
      LineBox[{{3.2131200024055504`, 1.155328504564207}, {3.156857698012141, 
       1.2160236509911746`}, {3.156857698012141, 1.2160236509911746`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}}], 
      LineBox[{{3.2131200024055504`, 1.155328504564207}, {3.156857698012141, 
       1.2160236509911746`}, {3.156857698012141, 1.2160236509911746`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}}], 
      LineBox[{{3.156857698012141, 1.2160236509911746`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}}], 
      LineBox[{{3.156857698012141, 1.2160236509911746`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}}], 
      LineBox[{{3.156857698012141, 1.2160236509911746`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}}], 
      LineBox[{{3.156857698012141, 1.2160236509911746`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}}], 
      LineBox[{{3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}], 
      LineBox[{{3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}], 
      LineBox[{{3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}], 
      LineBox[{{3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}], 
      LineBox[{{3.156857698012141, 1.3374139438451094`}, {3.2131200024055504`,
        1.398109090272077}, {3.2131200024055504`, 1.398109090272077}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}}], 
      LineBox[{{3.156857698012141, 1.3374139438451094`}, {3.2131200024055504`,
        1.398109090272077}, {3.2131200024055504`, 1.398109090272077}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}}], 
      LineBox[{{3.156857698012141, 1.3374139438451094`}, {3.2131200024055504`,
        1.398109090272077}, {3.2131200024055504`, 1.398109090272077}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}}], 
      LineBox[{{3.156857698012141, 1.3374139438451094`}, {3.2131200024055504`,
        1.398109090272077}, {3.2131200024055504`, 1.398109090272077}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}], 
      LineBox[{{3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}], 
      LineBox[{{3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}], 
      LineBox[{{3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}], 
      LineBox[{{3.398941770678766, 1.1976466393245127`}, {3.3532894389180044`,
        1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.398941770678766, 1.1976466393245127`}, {3.398941770678766, 
       1.1976466393245127`}}], 
      LineBox[{{3.398941770678766, 1.1976466393245127`}, {3.3532894389180044`,
        1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.398941770678766, 1.1976466393245127`}, {3.398941770678766, 
       1.1976466393245127`}}], 
      LineBox[{{3.398941770678766, 1.1976466393245127`}, {3.3532894389180044`,
        1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.398941770678766, 1.1976466393245127`}, {3.398941770678766, 
       1.1976466393245127`}}], 
      LineBox[{{3.398941770678766, 1.1976466393245127`}, {3.3532894389180044`,
        1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.398941770678766, 1.1976466393245127`}, {3.398941770678766, 
       1.1976466393245127`}}], 
      LineBox[{{3.3532894389180044`, 1.155328504564207}, {3.2938146932944257`,
        1.1369514928975453`}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}}], 
      LineBox[{{3.3532894389180044`, 1.155328504564207}, {3.2938146932944257`,
        1.1369514928975453`}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}}], 
      LineBox[{{3.3532894389180044`, 1.155328504564207}, {3.2938146932944257`,
        1.1369514928975453`}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}}], 
      LineBox[{{3.3532894389180044`, 1.155328504564207}, {3.2938146932944257`,
        1.1369514928975453`}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}}], 
      LineBox[{{3.2938146932944257`, 1.1369514928975453`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}}], 
      LineBox[{{3.2938146932944257`, 1.1369514928975453`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}}], 
      LineBox[{{3.2938146932944257`, 1.1369514928975453`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}}], 
      LineBox[{{3.2938146932944257`, 1.1369514928975453`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`,
        1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}], 
      LineBox[{{3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`,
        1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}], 
      LineBox[{{3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`,
        1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}], 
      LineBox[{{3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`,
        1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}], 
      LineBox[{{3.2938146932944257`, 1.4164861019387387`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2938146932944257`, 1.4164861019387387`}}], 
      LineBox[{{3.2938146932944257`, 1.4164861019387387`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2938146932944257`, 1.4164861019387387`}}], 
      LineBox[{{3.2938146932944257`, 1.4164861019387387`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2938146932944257`, 1.4164861019387387`}}], 
      LineBox[{{3.2938146932944257`, 1.4164861019387387`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2938146932944257`, 1.4164861019387387`}}], 
      LineBox[{{3.3532894389180044`, 1.398109090272077}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}], 
      LineBox[{{3.3532894389180044`, 1.398109090272077}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}], 
      LineBox[{{3.3532894389180044`, 1.398109090272077}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}], 
      LineBox[{{3.3532894389180044`, 1.398109090272077}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}], 
      LineBox[{{3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.398941770678766, 
       1.3557909555117713`}}], 
      LineBox[{{3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.398941770678766, 
       1.3557909555117713`}}], 
      LineBox[{{3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.398941770678766, 
       1.3557909555117713`}}], 
      LineBox[{{3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.398941770678766, 
       1.3557909555117713`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.187547313631859, 1.6218574822294558`}, {3.120122808958755, 
       1.694594285814401}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.8400678929842909`}, {3.187547313631859, 
       1.912804696569236}, {3.187547313631859, 1.912804696569236}, {
       3.120122808958755, 1.8400678929842909`}, {3.1035580873723374`, 
       1.767331089399346}, {3.120122808958755, 1.694594285814401}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`,
        1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.1875473136318595`, 
       1.6218574822294558`}, {3.1875473136318595`, 1.6218574822294558`}, {
       3.284251485663053, 1.5998345501374374`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.3555257661509033`, 1.912804696569236}, {
       3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.3555257661509033`, 
       1.912804696569236}, {3.2842514856630527`, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`,
        1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.187547313631859, 1.6218574822294558`}, {3.120122808958755, 
       1.694594285814401}, {3.120122808958755, 1.694594285814401}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}}], 
      LineBox[{{3.187547313631859, 1.6218574822294558`}, {3.120122808958755, 
       1.694594285814401}, {3.120122808958755, 1.694594285814401}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}}], 
      LineBox[{{3.187547313631859, 1.6218574822294558`}, {3.120122808958755, 
       1.694594285814401}, {3.120122808958755, 1.694594285814401}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}}], 
      LineBox[{{3.187547313631859, 1.6218574822294558`}, {3.120122808958755, 
       1.694594285814401}, {3.120122808958755, 1.694594285814401}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}}], 
      LineBox[{{3.120122808958755, 1.694594285814401}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}}], 
      LineBox[{{3.120122808958755, 1.694594285814401}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}}], 
      LineBox[{{3.120122808958755, 1.694594285814401}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}}], 
      LineBox[{{3.120122808958755, 1.694594285814401}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}}], 
      LineBox[{{3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}], 
      LineBox[{{3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}], 
      LineBox[{{3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}], 
      LineBox[{{3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}], 
      LineBox[{{3.120122808958755, 1.8400678929842909`}, {3.1875473136318595`,
        1.912804696569236}, {3.1875473136318595`, 1.912804696569236}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}}], 
      LineBox[{{3.120122808958755, 1.8400678929842909`}, {3.1875473136318595`,
        1.912804696569236}, {3.1875473136318595`, 1.912804696569236}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}}], 
      LineBox[{{3.120122808958755, 1.8400678929842909`}, {3.1875473136318595`,
        1.912804696569236}, {3.1875473136318595`, 1.912804696569236}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}}], 
      LineBox[{{3.120122808958755, 1.8400678929842909`}, {3.1875473136318595`,
        1.912804696569236}, {3.1875473136318595`, 1.912804696569236}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}], 
      LineBox[{{3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}], 
      LineBox[{{3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}], 
      LineBox[{{3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}], 
      LineBox[{{3.410235325052336, 1.6725713537223823`}, {3.3555257661509033`,
        1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.410235325052336, 1.6725713537223823`}, {3.410235325052336, 
       1.6725713537223823`}}], 
      LineBox[{{3.410235325052336, 1.6725713537223823`}, {3.3555257661509033`,
        1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.410235325052336, 1.6725713537223823`}, {3.410235325052336, 
       1.6725713537223823`}}], 
      LineBox[{{3.410235325052336, 1.6725713537223823`}, {3.3555257661509033`,
        1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.410235325052336, 1.6725713537223823`}, {3.410235325052336, 
       1.6725713537223823`}}], 
      LineBox[{{3.410235325052336, 1.6725713537223823`}, {3.3555257661509033`,
        1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.410235325052336, 1.6725713537223823`}, {3.410235325052336, 
       1.6725713537223823`}}], 
      LineBox[{{3.3555257661509033`, 1.6218574822294558`}, {3.284251485663053,
        1.5998345501374374`}, {3.284251485663053, 1.5998345501374374`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}}], 
      LineBox[{{3.3555257661509033`, 1.6218574822294558`}, {3.284251485663053,
        1.5998345501374374`}, {3.284251485663053, 1.5998345501374374`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}}], 
      LineBox[{{3.3555257661509033`, 1.6218574822294558`}, {3.284251485663053,
        1.5998345501374374`}, {3.284251485663053, 1.5998345501374374`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}}], 
      LineBox[{{3.3555257661509033`, 1.6218574822294558`}, {3.284251485663053,
        1.5998345501374374`}, {3.284251485663053, 1.5998345501374374`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}}], 
      LineBox[{{3.2842514856630527`, 1.5998345501374374`}, {3.187547313631859,
        1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.2842514856630527`, 
       1.5998345501374374`}}], 
      LineBox[{{3.2842514856630527`, 1.5998345501374374`}, {3.187547313631859,
        1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.2842514856630527`, 
       1.5998345501374374`}}], 
      LineBox[{{3.2842514856630527`, 1.5998345501374374`}, {3.187547313631859,
        1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.2842514856630527`, 
       1.5998345501374374`}}], 
      LineBox[{{3.2842514856630527`, 1.5998345501374374`}, {3.187547313631859,
        1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.2842514856630527`, 
       1.5998345501374374`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}], 
      LineBox[{{3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}], 
      LineBox[{{3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}], 
      LineBox[{{3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}], 
      LineBox[{{3.284251485663053, 1.9348276286612545`}, {3.3555257661509033`,
        1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}}], 
      LineBox[{{3.284251485663053, 1.9348276286612545`}, {3.3555257661509033`,
        1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}}], 
      LineBox[{{3.284251485663053, 1.9348276286612545`}, {3.3555257661509033`,
        1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}}], 
      LineBox[{{3.284251485663053, 1.9348276286612545`}, {3.3555257661509033`,
        1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}}], 
      LineBox[{{3.3555257661509033`, 1.912804696569236}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}], 
      LineBox[{{3.3555257661509033`, 1.912804696569236}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}], 
      LineBox[{{3.3555257661509033`, 1.912804696569236}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}], 
      LineBox[{{3.3555257661509033`, 1.912804696569236}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}], 
      LineBox[{{3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.410235325052336, 
       1.8620908250763095`}}], 
      LineBox[{{3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.410235325052336, 
       1.8620908250763095`}}], 
      LineBox[{{3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.410235325052336, 
       1.8620908250763095`}}], 
      LineBox[{{3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.410235325052336, 
       1.8620908250763095`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2139840262737485`, 2.0903156208758826`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206, 
       2.2304705024144686`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218,
        2.139175319825627}, {3.375820943442834, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.375820943442834, 
       2.0903156208758826`}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.375820943442834, 
       2.3706253839530547`}, {3.428530241686218, 2.32176568500331}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2139840262737485`, 2.0903156208758826`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}}], 
      LineBox[{{3.2139840262737485`, 2.0903156208758826`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}}], 
      LineBox[{{3.2139840262737485`, 2.0903156208758826`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}}], 
      LineBox[{{3.2139840262737485`, 2.0903156208758826`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}}], 
      LineBox[{{3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206,
        2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}}], 
      LineBox[{{3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206,
        2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}}], 
      LineBox[{{3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206,
        2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}}], 
      LineBox[{{3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206,
        2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}}], 
      LineBox[{{3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`,
        2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}], 
      LineBox[{{3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`,
        2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}], 
      LineBox[{{3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`,
        2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}], 
      LineBox[{{3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`,
        2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}], 
      LineBox[{{3.1490246590792523`, 2.3005479431837617`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.1490246590792523`, 2.3005479431837617`}}], 
      LineBox[{{3.1490246590792523`, 2.3005479431837617`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.1490246590792523`, 2.3005479431837617`}}], 
      LineBox[{{3.1490246590792523`, 2.3005479431837617`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.1490246590792523`, 2.3005479431837617`}}], 
      LineBox[{{3.1490246590792523`, 2.3005479431837617`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.1490246590792523`, 2.3005479431837617`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218,
        2.139175319825627}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}], 
      LineBox[{{3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218,
        2.139175319825627}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}], 
      LineBox[{{3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218,
        2.139175319825627}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}], 
      LineBox[{{3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218,
        2.139175319825627}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}], 
      LineBox[{{3.428530241686218, 2.139175319825627}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.428530241686218, 2.139175319825627}, {3.428530241686218, 
       2.139175319825627}}], 
      LineBox[{{3.428530241686218, 2.139175319825627}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.428530241686218, 2.139175319825627}, {3.428530241686218, 
       2.139175319825627}}], 
      LineBox[{{3.428530241686218, 2.139175319825627}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.428530241686218, 2.139175319825627}, {3.428530241686218, 
       2.139175319825627}}], 
      LineBox[{{3.428530241686218, 2.139175319825627}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.428530241686218, 2.139175319825627}, {3.428530241686218, 
       2.139175319825627}}], 
      LineBox[{{3.375820943442834, 2.0903156208758826`}, {3.3071525538094035`,
        2.069097879056334}, {3.3071525538094035`, 2.069097879056334}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}}], 
      LineBox[{{3.375820943442834, 2.0903156208758826`}, {3.3071525538094035`,
        2.069097879056334}, {3.3071525538094035`, 2.069097879056334}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}}], 
      LineBox[{{3.375820943442834, 2.0903156208758826`}, {3.3071525538094035`,
        2.069097879056334}, {3.3071525538094035`, 2.069097879056334}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}}], 
      LineBox[{{3.375820943442834, 2.0903156208758826`}, {3.3071525538094035`,
        2.069097879056334}, {3.3071525538094035`, 2.069097879056334}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}}], 
      LineBox[{{3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`,
        2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}}], 
      LineBox[{{3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`,
        2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}}], 
      LineBox[{{3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`,
        2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}}], 
      LineBox[{{3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`,
        2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}], 
      LineBox[{{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}], 
      LineBox[{{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}], 
      LineBox[{{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}], 
      LineBox[{{3.3071525538094035`, 2.391843125772603}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}}], 
      LineBox[{{3.3071525538094035`, 2.391843125772603}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}}], 
      LineBox[{{3.3071525538094035`, 2.391843125772603}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}}], 
      LineBox[{{3.3071525538094035`, 2.391843125772603}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}}], 
      LineBox[{{3.375820943442834, 2.3706253839530547`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}], 
      LineBox[{{3.375820943442834, 2.3706253839530547`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}], 
      LineBox[{{3.375820943442834, 2.3706253839530547`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}], 
      LineBox[{{3.375820943442834, 2.3706253839530547`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}], 
      LineBox[{{3.428530241686218, 2.32176568500331}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.32176568500331}, {3.428530241686218, 
       2.32176568500331}}], 
      LineBox[{{3.428530241686218, 2.32176568500331}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.32176568500331}, {3.428530241686218, 
       2.32176568500331}}], 
      LineBox[{{3.428530241686218, 2.32176568500331}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.32176568500331}, {3.428530241686218, 
       2.32176568500331}}], 
      LineBox[{{3.428530241686218, 2.32176568500331}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.32176568500331}, {3.428530241686218, 
       2.32176568500331}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2161885240513723`, 2.626792816072176}, {3.1526303469981327`,
        2.6953586685460285`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.2161885240513723`, 
       2.9010562259675865`}, {3.2161885240513723`, 2.9010562259675865`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.216188524051373, 2.626792816072176}, {3.216188524051373, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.374534577583353, 2.9010562259675865`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.374534577583353, 
       2.9010562259675865`}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.2161885240513723`, 2.626792816072176}, {3.1526303469981327`,
        2.6953586685460285`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}}], 
      LineBox[{{3.2161885240513723`, 2.626792816072176}, {3.1526303469981327`,
        2.6953586685460285`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}}], 
      LineBox[{{3.2161885240513723`, 2.626792816072176}, {3.1526303469981327`,
        2.6953586685460285`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}}], 
      LineBox[{{3.2161885240513723`, 2.626792816072176}, {3.1526303469981327`,
        2.6953586685460285`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}}], 
      LineBox[{{3.1526303469981327`, 2.6953586685460285`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}}], 
      LineBox[{{3.1526303469981327`, 2.6953586685460285`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}}], 
      LineBox[{{3.1526303469981327`, 2.6953586685460285`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}}], 
      LineBox[{{3.1526303469981327`, 2.6953586685460285`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}}], 
      LineBox[{{3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}], 
      LineBox[{{3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}], 
      LineBox[{{3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}], 
      LineBox[{{3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}], 
      LineBox[{{3.1526303469981327`, 2.832490373493734}, {3.216188524051373, 
       2.9010562259675865`}, {3.216188524051373, 2.9010562259675865`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}}], 
      LineBox[{{3.1526303469981327`, 2.832490373493734}, {3.216188524051373, 
       2.9010562259675865`}, {3.216188524051373, 2.9010562259675865`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}}], 
      LineBox[{{3.1526303469981327`, 2.832490373493734}, {3.216188524051373, 
       2.9010562259675865`}, {3.216188524051373, 2.9010562259675865`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}}], 
      LineBox[{{3.1526303469981327`, 2.832490373493734}, {3.216188524051373, 
       2.9010562259675865`}, {3.216188524051373, 2.9010562259675865`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}], 
      LineBox[{{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}], 
      LineBox[{{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}], 
      LineBox[{{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}], 
      LineBox[{{3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}}], 
      LineBox[{{3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}}], 
      LineBox[{{3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}}], 
      LineBox[{{3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}}], 
      LineBox[{{3.374534577583353, 2.626792816072176}, {3.307347382652485, 
       2.6060327463627675`}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}}], 
      LineBox[{{3.374534577583353, 2.626792816072176}, {3.307347382652485, 
       2.6060327463627675`}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}}], 
      LineBox[{{3.374534577583353, 2.626792816072176}, {3.307347382652485, 
       2.6060327463627675`}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}}], 
      LineBox[{{3.374534577583353, 2.626792816072176}, {3.307347382652485, 
       2.6060327463627675`}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}}], 
      LineBox[{{3.307347382652485, 2.6060327463627675`}, {3.2161885240513723`,
        2.626792816072176}, {3.2161885240513723`, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}}], 
      LineBox[{{3.307347382652485, 2.6060327463627675`}, {3.2161885240513723`,
        2.626792816072176}, {3.2161885240513723`, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}}], 
      LineBox[{{3.307347382652485, 2.6060327463627675`}, {3.2161885240513723`,
        2.626792816072176}, {3.2161885240513723`, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}}], 
      LineBox[{{3.307347382652485, 2.6060327463627675`}, {3.2161885240513723`,
        2.626792816072176}, {3.2161885240513723`, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}], 
      LineBox[{{3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}], 
      LineBox[{{3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}], 
      LineBox[{{3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}], 
      LineBox[{{3.307347382652485, 2.921816295676995}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}}], 
      LineBox[{{3.307347382652485, 2.921816295676995}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}}], 
      LineBox[{{3.307347382652485, 2.921816295676995}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}}], 
      LineBox[{{3.307347382652485, 2.921816295676995}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}}], 
      LineBox[{{3.374534577583353, 2.9010562259675865`}, {3.4261069228014702`,
        2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}], 
      LineBox[{{3.374534577583353, 2.9010562259675865`}, {3.4261069228014702`,
        2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}], 
      LineBox[{{3.374534577583353, 2.9010562259675865`}, {3.4261069228014702`,
        2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}], 
      LineBox[{{3.374534577583353, 2.9010562259675865`}, {3.4261069228014702`,
        2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}], 
      LineBox[{{3.4261069228014702`, 2.8532504432031427`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}}], 
      LineBox[{{3.4261069228014702`, 2.8532504432031427`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}}], 
      LineBox[{{3.4261069228014702`, 2.8532504432031427`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}}], 
      LineBox[{{3.4261069228014702`, 2.8532504432031427`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1787599168276444`, 3.13657422973422}, {3.115416589792595, 
       3.204908304404897}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.3415764537462507`}, {3.1787599168276444`, 
       3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.115416589792595, 3.3415764537462507`}, {3.0998545240157656`, 
       3.273242379075574}, {3.115416589792595, 3.204908304404897}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`,
        3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.336570702451401, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`, 
       3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.336570702451401, 
       3.13657422973422}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078,
        3.430600421454167}, {3.336570702451401, 3.4099105284169275`}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.336570702451401, 
       3.4099105284169275`}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1787599168276444`, 3.13657422973422}, {3.115416589792595, 
       3.204908304404897}, {3.115416589792595, 3.204908304404897}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}}], 
      LineBox[{{3.1787599168276444`, 3.13657422973422}, {3.115416589792595, 
       3.204908304404897}, {3.115416589792595, 3.204908304404897}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}}], 
      LineBox[{{3.1787599168276444`, 3.13657422973422}, {3.115416589792595, 
       3.204908304404897}, {3.115416589792595, 3.204908304404897}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}}], 
      LineBox[{{3.1787599168276444`, 3.13657422973422}, {3.115416589792595, 
       3.204908304404897}, {3.115416589792595, 3.204908304404897}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}}], 
      LineBox[{{3.115416589792595, 3.204908304404897}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}}], 
      LineBox[{{3.115416589792595, 3.204908304404897}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}}], 
      LineBox[{{3.115416589792595, 3.204908304404897}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}}], 
      LineBox[{{3.115416589792595, 3.204908304404897}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}}], 
      LineBox[{{3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}], 
      LineBox[{{3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}], 
      LineBox[{{3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}], 
      LineBox[{{3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}], 
      LineBox[{{3.115416589792595, 3.3415764537462507`}, {3.1787599168276444`,
        3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}}], 
      LineBox[{{3.115416589792595, 3.3415764537462507`}, {3.1787599168276444`,
        3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}}], 
      LineBox[{{3.115416589792595, 3.3415764537462507`}, {3.1787599168276444`,
        3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}}], 
      LineBox[{{3.115416589792595, 3.3415764537462507`}, {3.1787599168276444`,
        3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}], 
      LineBox[{{3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}], 
      LineBox[{{3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}], 
      LineBox[{{3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}], 
      LineBox[{{3.3879687141718957`, 3.1842184113676573`}, {3.336570702451401,
        3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.3879687141718957`, 
       3.1842184113676573`}}], 
      LineBox[{{3.3879687141718957`, 3.1842184113676573`}, {3.336570702451401,
        3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.3879687141718957`, 
       3.1842184113676573`}}], 
      LineBox[{{3.3879687141718957`, 3.1842184113676573`}, {3.336570702451401,
        3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.3879687141718957`, 
       3.1842184113676573`}}], 
      LineBox[{{3.3879687141718957`, 3.1842184113676573`}, {3.336570702451401,
        3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.3879687141718957`, 
       3.1842184113676573`}}], 
      LineBox[{{3.336570702451401, 3.13657422973422}, {3.269610624954078, 
       3.1158843366969804`}, {3.269610624954078, 3.1158843366969804`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}}], 
      LineBox[{{3.336570702451401, 3.13657422973422}, {3.269610624954078, 
       3.1158843366969804`}, {3.269610624954078, 3.1158843366969804`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}}], 
      LineBox[{{3.336570702451401, 3.13657422973422}, {3.269610624954078, 
       3.1158843366969804`}, {3.269610624954078, 3.1158843366969804`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}}], 
      LineBox[{{3.336570702451401, 3.13657422973422}, {3.269610624954078, 
       3.1158843366969804`}, {3.269610624954078, 3.1158843366969804`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}}], 
      LineBox[{{3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`,
        3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}}], 
      LineBox[{{3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`,
        3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}}], 
      LineBox[{{3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`,
        3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}}], 
      LineBox[{{3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`,
        3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078,
        3.430600421454167}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}], 
      LineBox[{{3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078,
        3.430600421454167}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}], 
      LineBox[{{3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078,
        3.430600421454167}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}], 
      LineBox[{{3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078,
        3.430600421454167}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}], 
      LineBox[{{3.269610624954078, 3.430600421454167}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}}], 
      LineBox[{{3.269610624954078, 3.430600421454167}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}}], 
      LineBox[{{3.269610624954078, 3.430600421454167}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}}], 
      LineBox[{{3.269610624954078, 3.430600421454167}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}}], 
      LineBox[{{3.336570702451401, 3.4099105284169275`}, {3.3879687141718957`,
        3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}], 
      LineBox[{{3.336570702451401, 3.4099105284169275`}, {3.3879687141718957`,
        3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}], 
      LineBox[{{3.336570702451401, 3.4099105284169275`}, {3.3879687141718957`,
        3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}], 
      LineBox[{{3.336570702451401, 3.4099105284169275`}, {3.3879687141718957`,
        3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}], 
      LineBox[{{3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.3879687141718957`, 
       3.3622663467834903`}}], 
      LineBox[{{3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.3879687141718957`, 
       3.3622663467834903`}}], 
      LineBox[{{3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.3879687141718957`, 
       3.3622663467834903`}}], 
      LineBox[{{3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.3879687141718957`, 
       3.3622663467834903`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.134137681383431, 3.6315611514164683`}, {3.0721739787161013`,
        3.6984069027076503`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}, {
       3.0721739787161013`, 3.832098405290014}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756,
        3.6781676377307884`}, {3.288511331392018, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431, 
       3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.288511331392018, 
       3.6315611514164683`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.288511331392018, 3.898944156581196}, {
       3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.288511331392018, 
       3.898944156581196}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.134137681383431, 3.6315611514164683`}, {3.0721739787161013`,
        3.6984069027076503`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}}], 
      LineBox[{{3.134137681383431, 3.6315611514164683`}, {3.0721739787161013`,
        3.6984069027076503`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}}], 
      LineBox[{{3.134137681383431, 3.6315611514164683`}, {3.0721739787161013`,
        3.6984069027076503`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}}], 
      LineBox[{{3.134137681383431, 3.6315611514164683`}, {3.0721739787161013`,
        3.6984069027076503`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}}], 
      LineBox[{{3.0721739787161013`, 3.6984069027076503`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}}], 
      LineBox[{{3.0721739787161013`, 3.6984069027076503`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}}], 
      LineBox[{{3.0721739787161013`, 3.6984069027076503`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}}], 
      LineBox[{{3.0721739787161013`, 3.6984069027076503`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}}], 
      LineBox[{{3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}], 
      LineBox[{{3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}], 
      LineBox[{{3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}], 
      LineBox[{{3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}], 
      LineBox[{{3.0721739787161013`, 3.832098405290014}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}}], 
      LineBox[{{3.0721739787161013`, 3.832098405290014}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}}], 
      LineBox[{{3.0721739787161013`, 3.832098405290014}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}}], 
      LineBox[{{3.0721739787161013`, 3.832098405290014}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756,
        3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}], 
      LineBox[{{3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756,
        3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}], 
      LineBox[{{3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756,
        3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}], 
      LineBox[{{3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756,
        3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}], 
      LineBox[{{3.338789888976756, 3.6781676377307884`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.338789888976756, 3.6781676377307884`}, {3.338789888976756, 
       3.6781676377307884`}}], 
      LineBox[{{3.338789888976756, 3.6781676377307884`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.338789888976756, 3.6781676377307884`}, {3.338789888976756, 
       3.6781676377307884`}}], 
      LineBox[{{3.338789888976756, 3.6781676377307884`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.338789888976756, 3.6781676377307884`}, {3.338789888976756, 
       3.6781676377307884`}}], 
      LineBox[{{3.338789888976756, 3.6781676377307884`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.338789888976756, 3.6781676377307884`}, {3.338789888976756, 
       3.6781676377307884`}}], 
      LineBox[{{3.288511331392018, 3.6315611514164683`}, {3.2230096514703157`,
        3.6113218864396064`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}}], 
      LineBox[{{3.288511331392018, 3.6315611514164683`}, {3.2230096514703157`,
        3.6113218864396064`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}}], 
      LineBox[{{3.288511331392018, 3.6315611514164683`}, {3.2230096514703157`,
        3.6113218864396064`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}}], 
      LineBox[{{3.288511331392018, 3.6315611514164683`}, {3.2230096514703157`,
        3.6113218864396064`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}}], 
      LineBox[{{3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431,
        3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}}], 
      LineBox[{{3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431,
        3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}}], 
      LineBox[{{3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431,
        3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}}], 
      LineBox[{{3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431,
        3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}], 
      LineBox[{{3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}], 
      LineBox[{{3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}], 
      LineBox[{{3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}], 
      LineBox[{{3.2230096514703157`, 3.919183421558058}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}}], 
      LineBox[{{3.2230096514703157`, 3.919183421558058}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}}], 
      LineBox[{{3.2230096514703157`, 3.919183421558058}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}}], 
      LineBox[{{3.2230096514703157`, 3.919183421558058}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}}], 
      LineBox[{{3.288511331392018, 3.898944156581196}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}], 
      LineBox[{{3.288511331392018, 3.898944156581196}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}], 
      LineBox[{{3.288511331392018, 3.898944156581196}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}], 
      LineBox[{{3.288511331392018, 3.898944156581196}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}], 
      LineBox[{{3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.338789888976756, 
       3.852337670266876}}], 
      LineBox[{{3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.338789888976756, 
       3.852337670266876}}], 
      LineBox[{{3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.338789888976756, 
       3.852337670266876}}], 
      LineBox[{{3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.338789888976756, 
       3.852337670266876}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}], 
      LineBox[{{3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}], 
      LineBox[{{3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}], 
      LineBox[{{3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}], 
      LineBox[{{3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}], 
      LineBox[{{3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}], 
      LineBox[{{3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}], 
      LineBox[{{3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}], 
      LineBox[{{3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}], 
      LineBox[{{3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}], 
      LineBox[{{3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}], 
      LineBox[{{3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}], 
      LineBox[{{3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}], 
      LineBox[{{3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}], 
      LineBox[{{3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}], 
      LineBox[{{3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}], 
      LineBox[{{3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}], 
      LineBox[{{3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}], 
      LineBox[{{3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}], 
      LineBox[{{3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}], 
      LineBox[{{3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}], 
      LineBox[{{3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}], 
      LineBox[{{3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}], 
      LineBox[{{3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}], 
      LineBox[{{3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}], 
      LineBox[{{3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}], 
      LineBox[{{3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}], 
      LineBox[{{3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}], 
      LineBox[{{3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}], 
      LineBox[{{3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}], 
      LineBox[{{3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}], 
      LineBox[{{3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}], 
      LineBox[{{3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}], 
      LineBox[{{3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}], 
      LineBox[{{3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}], 
      LineBox[{{3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}], 
      LineBox[{{3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}], 
      LineBox[{{3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}], 
      LineBox[{{3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}], 
      LineBox[{{3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}], 
      LineBox[{{3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}], 
      LineBox[{{3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}], 
      LineBox[{{3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}], 
      LineBox[{{3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}], 
      LineBox[{{3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}], 
      LineBox[{{3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}], 
      LineBox[{{3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}], 
      LineBox[{{3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}], 
      LineBox[{{3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}], 
      LineBox[{{3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}], 
      LineBox[{{3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}], 
      LineBox[{{3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}], 
      LineBox[{{3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}], 
      LineBox[{{3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}], 
      LineBox[{{3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}], 
      LineBox[{{3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}], 
      LineBox[{{3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}], 
      LineBox[{{3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}], 
      LineBox[{{3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}], 
      LineBox[{{3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}], 
      LineBox[{{3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}], 
      LineBox[{{3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}], 
      LineBox[{{3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}], 
      LineBox[{{3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}], 
      LineBox[{{3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}], 
      LineBox[{{3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}], 
      LineBox[{{3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}], 
      LineBox[{{3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}], 
      LineBox[{{3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}], 
      LineBox[{{3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}], 
      LineBox[{{3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}], 
      LineBox[{{3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}], 
      LineBox[{{3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}], 
      LineBox[{{3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}], 
      LineBox[{{3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}], 
      LineBox[{{3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}], 
      LineBox[{{3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}], 
      LineBox[{{3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}], 
      LineBox[{{3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}], 
      LineBox[{{3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}], 
      LineBox[{{3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}], 
      LineBox[{{3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}], 
      LineBox[{{3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}], 
      LineBox[{{3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}], 
      LineBox[{{3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}], 
      LineBox[{{3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}], 
      LineBox[{{3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}], 
      LineBox[{{3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}], 
      LineBox[{{3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}], 
      LineBox[{{3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}], 
      LineBox[{{3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}], 
      LineBox[{{3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}], 
      LineBox[{{3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}], 
      LineBox[{{3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}], 
      LineBox[{{3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}], 
      LineBox[{{3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}], 
      LineBox[{{3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}], 
      LineBox[{{3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}], 
      LineBox[{{3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}], 
      LineBox[{{3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}], 
      LineBox[{{3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}], 
      LineBox[{{3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}], 
      LineBox[{{3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}], 
      LineBox[{{3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}], 
      LineBox[{{3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}], 
      LineBox[{{3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}], 
      LineBox[{{3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}], 
      LineBox[{{3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}], 
      LineBox[{{3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}], 
      LineBox[{{3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}], 
      LineBox[{{3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}], 
      LineBox[{{3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}], 
      LineBox[{{3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}], 
      LineBox[{{3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}], 
      LineBox[{{3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}], 
      LineBox[{{3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}], 
      LineBox[{{3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}], 
      LineBox[{{3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}], 
      LineBox[{{3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}], 
      LineBox[{{3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}], 
      LineBox[{{3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}], 
      LineBox[{{3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}], 
      LineBox[{{3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}], 
      LineBox[{{3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}], 
      LineBox[{{3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}], 
      LineBox[{{3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}], 
      LineBox[{{3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}], 
      LineBox[{{3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}], 
      LineBox[{{3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}], 
      LineBox[{{3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}], 
      LineBox[{{3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}], 
      LineBox[{{3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}], 
      LineBox[{{3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}], 
      LineBox[{{3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}], 
      LineBox[{{3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}], 
      LineBox[{{3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}], 
      LineBox[{{3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}], 
      LineBox[{{3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}], 
      LineBox[{{3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}], 
      LineBox[{{3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}], 
      LineBox[{{3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}], 
      LineBox[{{3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}], 
      LineBox[{{3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}], 
      LineBox[{{3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}], 
      LineBox[{{3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}], 
      LineBox[{{3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}], 
      LineBox[{{3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}], 
      LineBox[{{3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}], 
      LineBox[{{3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}], 
      LineBox[{{3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}], 
      LineBox[{{3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}], 
      LineBox[{{3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}], 
      LineBox[{{3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}], 
      LineBox[{{3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}], 
      LineBox[{{3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}], 
      LineBox[{{3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}], 
      LineBox[{{3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}], 
      LineBox[{{3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}], 
      LineBox[{{3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}], 
      LineBox[{{3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}], 
      LineBox[{{3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}], 
      LineBox[{{3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}], 
      LineBox[{{3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}], 
      LineBox[{{3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}], 
      LineBox[{{3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}], 
      LineBox[{{3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}], 
      LineBox[{{3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}], 
      LineBox[{{3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}], 
      LineBox[{{3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}], 
      LineBox[{{3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}], 
      LineBox[{{3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}], 
      LineBox[{{3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}], 
      LineBox[{{3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}], 
      LineBox[{{3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}], 
      LineBox[{{3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}], 
      LineBox[{{3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}], 
      LineBox[{{3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}], 
      LineBox[{{3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}], 
      LineBox[{{3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}], 
      LineBox[{{3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}], 
      LineBox[{{3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}], 
      LineBox[{{3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}], 
      LineBox[{{3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}], 
      LineBox[{{3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}], 
      LineBox[{{3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}], 
      LineBox[{{3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}], 
      LineBox[{{3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}], 
      LineBox[{{3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}], 
      LineBox[{{3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}], 
      LineBox[{{3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}], 
      LineBox[{{3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}], 
      LineBox[{{3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}], 
      LineBox[{{3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}], 
      LineBox[{{3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}], 
      LineBox[{{3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}], 
      LineBox[{{3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}], 
      LineBox[{{3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}], 
      LineBox[{{3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}], 
      LineBox[{{3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}], 
      LineBox[{{3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}], 
      LineBox[{{3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}], 
      LineBox[{{3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}], 
      LineBox[{{3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}], 
      LineBox[{{3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}], 
      LineBox[{{3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}], 
      LineBox[{{3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}], 
      LineBox[{{3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}], 
      LineBox[{{3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}], 
      LineBox[{{3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}], 
      LineBox[{{3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}], 
      LineBox[{{3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}], 
      LineBox[{{3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}], 
      LineBox[{{3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}], 
      LineBox[{{3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}], 
      LineBox[{{3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}], 
      LineBox[{{3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}], 
      LineBox[{{3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}], 
      LineBox[{{3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}], 
      LineBox[{{3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}], 
      LineBox[{{3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}], 
      LineBox[{{3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}], 
      LineBox[{{3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}], 
      LineBox[{{3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}], 
      LineBox[{{3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}], 
      LineBox[{{3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}], 
      LineBox[{{3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}], 
      LineBox[{{3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}], 
      LineBox[{{3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}], 
      LineBox[{{3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}], 
      LineBox[{{3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}], 
      LineBox[{{3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}], 
      LineBox[{{3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}], 
      LineBox[{{3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}], 
      LineBox[{{3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}], 
      LineBox[{{3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}], 
      LineBox[{{3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}], 
      LineBox[{{3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}], 
      LineBox[{{3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}], 
      LineBox[{{3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}], 
      LineBox[{{3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}], 
      LineBox[{{3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}], 
      LineBox[{{3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}], 
      LineBox[{{3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}], 
      LineBox[{{3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}], 
      LineBox[{{3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}], 
      LineBox[{{3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}], 
      LineBox[{{3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}], 
      LineBox[{{3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}], 
      LineBox[{{3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}], 
      LineBox[{{3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}], 
      LineBox[{{3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}], 
      LineBox[{{3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}], 
      LineBox[{{3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}], 
      LineBox[{{3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}], 
      LineBox[{{3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}], 
      LineBox[{{3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}], 
      LineBox[{{3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}], 
      LineBox[{{3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}], 
      LineBox[{{3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}], 
      LineBox[{{3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}], 
      LineBox[{{3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}], 
      LineBox[{{3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}], 
      LineBox[{{3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}], 
      LineBox[{{3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}], 
      LineBox[{{3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}], 
      LineBox[{{3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}], 
      LineBox[{{3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}], 
      LineBox[{{3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}], 
      LineBox[{{3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}], 
      LineBox[{{3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}], 
      LineBox[{{3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}], 
      LineBox[{{3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}], 
      LineBox[{{3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}], 
      LineBox[{{3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}], 
      LineBox[{{3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}], 
      LineBox[{{3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}], 
      LineBox[{{3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}], 
      LineBox[{{3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}], 
      LineBox[{{3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}], 
      LineBox[{{3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}], 
      LineBox[{{3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}], 
      LineBox[{{3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}], 
      LineBox[{{3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}], 
      LineBox[{{3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}], 
      LineBox[{{3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}], 
      LineBox[{{3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}], 
      LineBox[{{3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}], 
      LineBox[{{3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}], 
      LineBox[{{3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}], 
      LineBox[{{3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}], 
      LineBox[{{3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}], 
      LineBox[{{3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}], 
      LineBox[{{3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}], 
      LineBox[{{3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}], 
      LineBox[{{3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}], 
      LineBox[{{3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}], 
      LineBox[{{3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}], 
      LineBox[{{3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}], 
      LineBox[{{3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}], 
      LineBox[{{3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}], 
      LineBox[{{3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}], 
      LineBox[{{3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}], 
      LineBox[{{3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}], 
      LineBox[{{3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}], 
      LineBox[{{3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}], 
      LineBox[{{3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}], 
      LineBox[{{3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}], 
      LineBox[{{3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}], 
      LineBox[{{3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}], 
      LineBox[{{3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}], 
      LineBox[{{3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}], 
      LineBox[{{3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}], 
      LineBox[{{3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}], 
      LineBox[{{3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}], 
      LineBox[{{3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}], 
      LineBox[{{3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}], 
      LineBox[{{3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}], 
      LineBox[{{3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}], 
      LineBox[{{3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}], 
      LineBox[{{3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}], 
      LineBox[{{3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}], 
      LineBox[{{3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}], 
      LineBox[{{3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}], 
      LineBox[{{3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}], 
      LineBox[{{3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}], 
      LineBox[{{3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}], 
      LineBox[{{3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}], 
      LineBox[{{3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}], 
      LineBox[{{3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}], 
      LineBox[{{3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}], 
      LineBox[{{3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}], 
      LineBox[{{3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}], 
      LineBox[{{3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}], 
      LineBox[{{3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}], 
      LineBox[{{3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}], 
      LineBox[{{3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}], 
      LineBox[{{3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}], 
      LineBox[{{3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}], 
      LineBox[{{3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}], 
      LineBox[{{3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}], 
      LineBox[{{3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}], 
      LineBox[{{3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}], 
      LineBox[{{3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}], 
      LineBox[{{3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}], 
      LineBox[{{3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}], 
      LineBox[{{3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}], 
      LineBox[{{3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}], 
      LineBox[{{3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}], 
      LineBox[{{3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}], 
      LineBox[{{3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}], 
      LineBox[{{3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}], 
      LineBox[{{3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}], 
      LineBox[{{3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}], 
      LineBox[{{3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}], 
      LineBox[{{3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}], 
      LineBox[{{3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}], 
      LineBox[{{3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}], 
      LineBox[{{3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}], 
      LineBox[{{3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}], 
      LineBox[{{3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}], 
      LineBox[{{3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}], 
      LineBox[{{3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}], 
      LineBox[{{3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}], 
      LineBox[{{3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}], 
      LineBox[{{3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}], 
      LineBox[{{3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}], 
      LineBox[{{3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}], 
      LineBox[{{3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}], 
      LineBox[{{3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}], 
      LineBox[{{3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}], 
      LineBox[{{3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}], 
      LineBox[{{3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}], 
      LineBox[{{3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}], 
      LineBox[{{3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}], 
      LineBox[{{3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}], 
      LineBox[{{3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}], 
      LineBox[{{3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}], 
      LineBox[{{3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}], 
      LineBox[{{3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}], 
      LineBox[{{3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}], 
      LineBox[{{3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}], 
      LineBox[{{3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}], 
      LineBox[{{3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}], 
      LineBox[{{3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}], 
      LineBox[{{3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}], 
      LineBox[{{3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}], 
      LineBox[{{3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}], 
      LineBox[{{3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}], 
      LineBox[{{3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}], 
      LineBox[{{3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}], 
      LineBox[{{3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}], 
      LineBox[{{3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}], 
      LineBox[{{3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}], 
      LineBox[{{3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}], 
      LineBox[{{3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}], 
      LineBox[{{3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}], 
      LineBox[{{3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}], 
      LineBox[{{3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}], 
      LineBox[{{3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}], 
      LineBox[{{3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}], 
      LineBox[{{3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}], 
      LineBox[{{3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}], 
      LineBox[{{3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}], 
      LineBox[{{3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}], 
      LineBox[{{3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}], 
      LineBox[{{3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.050843271701497675`}, {3.3699974202933296`, 0.1208358605419901}, {
       3.3699974202933296`, 0.1208358605419901}, {3.305116707906138, 
       0.05084327170149765}, {3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948728}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3699974202933296`, 0.12083586054199012`}, {
       3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.019149317138994783`}, {
       3.6124588603433523`, -0.019149317138994783`}, {3.584283856524442, 
       0.07203532242419103}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}], 
      LineBox[{{3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}], 
      LineBox[{{3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}], 
      LineBox[{{3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}], 
      LineBox[{{3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}], 
      LineBox[{{3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}], 
      LineBox[{{3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}], 
      LineBox[{{3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}], 
      LineBox[{{3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}], 
      LineBox[{{3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}], 
      LineBox[{{3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}], 
      LineBox[{{3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}], 
      LineBox[{{3.305116707906138, 0.050843271701497675`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.305116707906138, 0.050843271701497675`}, {
       3.305116707906138, 0.050843271701497675`}}], 
      LineBox[{{3.305116707906138, 0.050843271701497675`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.305116707906138, 0.050843271701497675`}, {
       3.305116707906138, 0.050843271701497675`}}], 
      LineBox[{{3.305116707906138, 0.050843271701497675`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.305116707906138, 0.050843271701497675`}, {
       3.305116707906138, 0.050843271701497675`}}], 
      LineBox[{{3.305116707906138, 0.050843271701497675`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.305116707906138, 0.050843271701497675`}, {
       3.305116707906138, 0.050843271701497675`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}], 
      LineBox[{{3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}], 
      LineBox[{{3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}], 
      LineBox[{{3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}], 
      LineBox[{{3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}], 
      LineBox[{{3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}], 
      LineBox[{{3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}], 
      LineBox[{{3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}], 
      LineBox[{{3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}], 
      LineBox[{{3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}], 
      LineBox[{{3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}], 
      LineBox[{{3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}], 
      LineBox[{{3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}], 
      LineBox[{{3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}], 
      LineBox[{{3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}], 
      LineBox[{{3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3699974202933296`, 0.12083586054199012`}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}}], 
      LineBox[{{3.3699974202933296`, 0.12083586054199012`}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}}], 
      LineBox[{{3.3699974202933296`, 0.12083586054199012`}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}}], 
      LineBox[{{3.3699974202933296`, 0.12083586054199012`}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}}], 
      LineBox[{{3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}}], 
      LineBox[{{3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}}], 
      LineBox[{{3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}}], 
      LineBox[{{3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}}], 
      LineBox[{{3.5316383803266778`, 0.1208358605419901}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}}], 
      LineBox[{{3.5316383803266778`, 0.1208358605419901}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}}], 
      LineBox[{{3.5316383803266778`, 0.1208358605419901}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}}], 
      LineBox[{{3.5316383803266778`, 0.1208358605419901}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}}], 
      LineBox[{{3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}], 
      LineBox[{{3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}], 
      LineBox[{{3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}], 
      LineBox[{{3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.3162514506499883`, 0.496006128325597}, {
       3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289947}, {3.392547878113848, 0.6281554171289947}, {
       3.331298964899875, 0.5620807727272958}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.4299314839238981}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`,
        0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`,
        0.409925691327259}, {3.545140733041566, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.392547878113848, 
       0.36385683952219916`}, {3.392547878113848, 0.36385683952219916`}, {
       3.4803946553187286`, 0.34385104692556}, {3.545140733041566, 
       0.3638568395221992}, {3.5948392965145173`, 0.409925691327259}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.392547878113848, 0.6281554171289948}, {3.4803946553187286`, 
       0.648161209725634}, {3.545140733041566, 0.6281554171289947}, {
       3.5948392965145173`, 0.582086565323935}, {3.6214371605054256`, 
       0.496006128325597}, {3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.582086565323935}, {3.545140733041566, 
       0.6281554171289947}, {3.4803946553187286`, 0.648161209725634}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}], 
      LineBox[{{3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}], 
      LineBox[{{3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}], 
      LineBox[{{3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}], 
      LineBox[{{3.331298964899875, 0.42993148392389813`}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}}], 
      LineBox[{{3.331298964899875, 0.42993148392389813`}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}}], 
      LineBox[{{3.331298964899875, 0.42993148392389813`}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}}], 
      LineBox[{{3.331298964899875, 0.42993148392389813`}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}}], 
      LineBox[{{3.3162514506499883`, 0.496006128325597}, {3.331298964899875, 
       0.5620807727272958}, {3.331298964899875, 0.5620807727272958}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}}], 
      LineBox[{{3.3162514506499883`, 0.496006128325597}, {3.331298964899875, 
       0.5620807727272958}, {3.331298964899875, 0.5620807727272958}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}}], 
      LineBox[{{3.3162514506499883`, 0.496006128325597}, {3.331298964899875, 
       0.5620807727272958}, {3.331298964899875, 0.5620807727272958}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}}], 
      LineBox[{{3.3162514506499883`, 0.496006128325597}, {3.331298964899875, 
       0.5620807727272958}, {3.331298964899875, 0.5620807727272958}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}}], 
      LineBox[{{3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}}], 
      LineBox[{{3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}}], 
      LineBox[{{3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}}], 
      LineBox[{{3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`,
        0.409925691327259}, {3.5948392965145173`, 0.409925691327259}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}}], 
      LineBox[{{3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`,
        0.409925691327259}, {3.5948392965145173`, 0.409925691327259}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}}], 
      LineBox[{{3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`,
        0.409925691327259}, {3.5948392965145173`, 0.409925691327259}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}}], 
      LineBox[{{3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`,
        0.409925691327259}, {3.5948392965145173`, 0.409925691327259}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}}], 
      LineBox[{{3.5948392965145173`, 0.409925691327259}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}}], 
      LineBox[{{3.5948392965145173`, 0.409925691327259}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}}], 
      LineBox[{{3.5948392965145173`, 0.409925691327259}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}}], 
      LineBox[{{3.5948392965145173`, 0.409925691327259}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}}], 
      LineBox[{{3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}], 
      LineBox[{{3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}], 
      LineBox[{{3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}], 
      LineBox[{{3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}], 
      LineBox[{{3.4803946553187286`, 0.34385104692556}, {3.392547878113848, 
       0.3638568395221992}, {3.392547878113848, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.4803946553187286`, 
       0.34385104692556}}], 
      LineBox[{{3.4803946553187286`, 0.34385104692556}, {3.392547878113848, 
       0.3638568395221992}, {3.392547878113848, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.4803946553187286`, 
       0.34385104692556}}], 
      LineBox[{{3.4803946553187286`, 0.34385104692556}, {3.392547878113848, 
       0.3638568395221992}, {3.392547878113848, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.4803946553187286`, 
       0.34385104692556}}], 
      LineBox[{{3.4803946553187286`, 0.34385104692556}, {3.392547878113848, 
       0.3638568395221992}, {3.392547878113848, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.4803946553187286`, 
       0.34385104692556}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.392547878113848, 0.6281554171289948}, {3.4803946553187286`, 
       0.648161209725634}, {3.4803946553187286`, 0.648161209725634}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}}], 
      LineBox[{{3.392547878113848, 0.6281554171289948}, {3.4803946553187286`, 
       0.648161209725634}, {3.4803946553187286`, 0.648161209725634}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}}], 
      LineBox[{{3.392547878113848, 0.6281554171289948}, {3.4803946553187286`, 
       0.648161209725634}, {3.4803946553187286`, 0.648161209725634}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}}], 
      LineBox[{{3.392547878113848, 0.6281554171289948}, {3.4803946553187286`, 
       0.648161209725634}, {3.4803946553187286`, 0.648161209725634}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}}], 
      LineBox[{{3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}}], 
      LineBox[{{3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}}], 
      LineBox[{{3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}}], 
      LineBox[{{3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}}], 
      LineBox[{{3.545140733041566, 0.6281554171289947}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}}], 
      LineBox[{{3.545140733041566, 0.6281554171289947}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}}], 
      LineBox[{{3.545140733041566, 0.6281554171289947}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}}], 
      LineBox[{{3.545140733041566, 0.6281554171289947}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}}], 
      LineBox[{{3.5948392965145173`, 0.582086565323935}, {3.6214371605054256`,
        0.496006128325597}, {3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}}], 
      LineBox[{{3.5948392965145173`, 0.582086565323935}, {3.6214371605054256`,
        0.496006128325597}, {3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}}], 
      LineBox[{{3.5948392965145173`, 0.582086565323935}, {3.6214371605054256`,
        0.496006128325597}, {3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}}], 
      LineBox[{{3.5948392965145173`, 0.582086565323935}, {3.6214371605054256`,
        0.496006128325597}, {3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4609081828876924`, 0.8794844506267455}, {
       3.3978218899830983`, 0.9475412397444591}, {3.382322971853105, 
       1.0155980288621729`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`, 
       0.9475412397444591}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`,
        0.9269353020173516}, {3.6180786049568665`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.4609081828876924`, 
       0.8794844506267455}, {3.4609081828876924`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6692680541678104`, 0.9269353020173516}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4609081828876924`, 0.8794844506267455}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}}], 
      LineBox[{{3.4609081828876924`, 0.8794844506267455}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}}], 
      LineBox[{{3.4609081828876924`, 0.8794844506267455}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}}], 
      LineBox[{{3.4609081828876924`, 0.8794844506267455}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}}], 
      LineBox[{{3.3978218899830983`, 0.9475412397444591}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}}], 
      LineBox[{{3.3978218899830983`, 0.9475412397444591}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}}], 
      LineBox[{{3.3978218899830983`, 0.9475412397444591}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}}], 
      LineBox[{{3.3978218899830983`, 0.9475412397444591}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}}], 
      LineBox[{{3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`,
        1.0836548179798866`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}}], 
      LineBox[{{3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`,
        1.0836548179798866`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}}], 
      LineBox[{{3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`,
        1.0836548179798866`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}}], 
      LineBox[{{3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`,
        1.0836548179798866`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}}], 
      LineBox[{{3.3978218899830983`, 1.0836548179798866`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}}], 
      LineBox[{{3.3978218899830983`, 1.0836548179798866`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}}], 
      LineBox[{{3.3978218899830983`, 1.0836548179798866`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}}], 
      LineBox[{{3.3978218899830983`, 1.0836548179798866`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`,
        0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}}], 
      LineBox[{{3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`,
        0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}}], 
      LineBox[{{3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`,
        0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}}], 
      LineBox[{{3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`,
        0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}}], 
      LineBox[{{3.6692680541678104`, 0.9269353020173516}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6692680541678104`, 0.9269353020173516}}], 
      LineBox[{{3.6692680541678104`, 0.9269353020173516}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6692680541678104`, 0.9269353020173516}}], 
      LineBox[{{3.6692680541678104`, 0.9269353020173516}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6692680541678104`, 0.9269353020173516}}], 
      LineBox[{{3.6692680541678104`, 0.9269353020173516}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6692680541678104`, 0.9269353020173516}}], 
      LineBox[{{3.6180786049568665`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.5513902376159296`, 
       0.8588785128996379}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}}], 
      LineBox[{{3.6180786049568665`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.5513902376159296`, 
       0.8588785128996379}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}}], 
      LineBox[{{3.6180786049568665`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.5513902376159296`, 
       0.8588785128996379}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}}], 
      LineBox[{{3.6180786049568665`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.5513902376159296`, 
       0.8588785128996379}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}}], 
      LineBox[{{3.5513902376159296`, 0.8588785128996379}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}}], 
      LineBox[{{3.5513902376159296`, 0.8588785128996379}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}}], 
      LineBox[{{3.5513902376159296`, 0.8588785128996379}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}}], 
      LineBox[{{3.5513902376159296`, 0.8588785128996379}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}], 
      LineBox[{{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}], 
      LineBox[{{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}], 
      LineBox[{{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}], 
      LineBox[{{3.5513902376159296`, 1.1723175448247078`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}}], 
      LineBox[{{3.5513902376159296`, 1.1723175448247078`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}}], 
      LineBox[{{3.5513902376159296`, 1.1723175448247078`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}}], 
      LineBox[{{3.5513902376159296`, 1.1723175448247078`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}}], 
      LineBox[{{3.6180786049568665`, 1.1517116070976003`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}], 
      LineBox[{{3.6180786049568665`, 1.1517116070976003`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}], 
      LineBox[{{3.6180786049568665`, 1.1517116070976003`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}], 
      LineBox[{{3.6180786049568665`, 1.1517116070976003`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}], 
      LineBox[{{3.6692680541678104`, 1.1042607557069941`}, {3.696663815991454,
        1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}}], 
      LineBox[{{3.6692680541678104`, 1.1042607557069941`}, {3.696663815991454,
        1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}}], 
      LineBox[{{3.6692680541678104`, 1.1042607557069941`}, {3.696663815991454,
        1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}}], 
      LineBox[{{3.6692680541678104`, 1.1042607557069941`}, {3.696663815991454,
        1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3932656603378537`, 1.3701247467497086`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.323180942081627, 
       1.4915150396036436`}, {3.3370033559444443`, 1.552210186030611}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3370033559444443`, 1.552210186030611}, {
       3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.4124428815100143`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.579087428611069, 1.4124428815100143`}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3932656603378537`, 1.6129053324575786`}, {3.473960351226729,
        1.6312823441242403`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.579087428611069, 1.570587197697273}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.570587197697273}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.473960351226729, 1.6312823441242403`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3932656603378537`, 1.3701247467497086`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}}], 
      LineBox[{{3.3932656603378537`, 1.3701247467497086`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}}], 
      LineBox[{{3.3932656603378537`, 1.3701247467497086`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}}], 
      LineBox[{{3.3932656603378537`, 1.3701247467497086`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}}], 
      LineBox[{{3.3370033559444443`, 1.4308198931766762`}, {3.323180942081627,
        1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}}], 
      LineBox[{{3.3370033559444443`, 1.4308198931766762`}, {3.323180942081627,
        1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}}], 
      LineBox[{{3.3370033559444443`, 1.4308198931766762`}, {3.323180942081627,
        1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}}], 
      LineBox[{{3.3370033559444443`, 1.4308198931766762`}, {3.323180942081627,
        1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}}], 
      LineBox[{{3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`,
        1.552210186030611}, {3.3370033559444443`, 1.552210186030611}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}}], 
      LineBox[{{3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`,
        1.552210186030611}, {3.3370033559444443`, 1.552210186030611}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}}], 
      LineBox[{{3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`,
        1.552210186030611}, {3.3370033559444443`, 1.552210186030611}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}}], 
      LineBox[{{3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`,
        1.552210186030611}, {3.3370033559444443`, 1.552210186030611}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}}], 
      LineBox[{{3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`,
        1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}}], 
      LineBox[{{3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`,
        1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}}], 
      LineBox[{{3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`,
        1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}}], 
      LineBox[{{3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`,
        1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}}], 
      LineBox[{{3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}}], 
      LineBox[{{3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}}], 
      LineBox[{{3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}}], 
      LineBox[{{3.579087428611069, 1.4124428815100143`}, {3.5334350968503077`,
        1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}}], 
      LineBox[{{3.579087428611069, 1.4124428815100143`}, {3.5334350968503077`,
        1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}}], 
      LineBox[{{3.579087428611069, 1.4124428815100143`}, {3.5334350968503077`,
        1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}}], 
      LineBox[{{3.579087428611069, 1.4124428815100143`}, {3.5334350968503077`,
        1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}}], 
      LineBox[{{3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729,
        1.351747735083047}, {3.473960351226729, 1.351747735083047}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}], 
      LineBox[{{3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729,
        1.351747735083047}, {3.473960351226729, 1.351747735083047}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}], 
      LineBox[{{3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729,
        1.351747735083047}, {3.473960351226729, 1.351747735083047}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}], 
      LineBox[{{3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729,
        1.351747735083047}, {3.473960351226729, 1.351747735083047}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}], 
      LineBox[{{3.473960351226729, 1.351747735083047}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.473960351226729, 
       1.351747735083047}}], 
      LineBox[{{3.473960351226729, 1.351747735083047}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.473960351226729, 
       1.351747735083047}}], 
      LineBox[{{3.473960351226729, 1.351747735083047}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.473960351226729, 
       1.351747735083047}}], 
      LineBox[{{3.473960351226729, 1.351747735083047}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.473960351226729, 
       1.351747735083047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3932656603378537`, 1.6129053324575786`}, {3.473960351226729,
        1.6312823441242403`}, {3.473960351226729, 1.6312823441242403`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}}], 
      LineBox[{{3.3932656603378537`, 1.6129053324575786`}, {3.473960351226729,
        1.6312823441242403`}, {3.473960351226729, 1.6312823441242403`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}}], 
      LineBox[{{3.3932656603378537`, 1.6129053324575786`}, {3.473960351226729,
        1.6312823441242403`}, {3.473960351226729, 1.6312823441242403`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}}], 
      LineBox[{{3.3932656603378537`, 1.6129053324575786`}, {3.473960351226729,
        1.6312823441242403`}, {3.473960351226729, 1.6312823441242403`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}}], 
      LineBox[{{3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`,
        1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}}], 
      LineBox[{{3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`,
        1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}}], 
      LineBox[{{3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`,
        1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}}], 
      LineBox[{{3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`,
        1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}}], 
      LineBox[{{3.5334350968503077`, 1.6129053324575786`}, {3.579087428611069,
        1.570587197697273}, {3.579087428611069, 1.570587197697273}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}}], 
      LineBox[{{3.5334350968503077`, 1.6129053324575786`}, {3.579087428611069,
        1.570587197697273}, {3.579087428611069, 1.570587197697273}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}}], 
      LineBox[{{3.5334350968503077`, 1.6129053324575786`}, {3.579087428611069,
        1.570587197697273}, {3.579087428611069, 1.570587197697273}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}}], 
      LineBox[{{3.5334350968503077`, 1.6129053324575786`}, {3.579087428611069,
        1.570587197697273}, {3.579087428611069, 1.570587197697273}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}}], 
      LineBox[{{3.579087428611069, 1.570587197697273}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}}], 
      LineBox[{{3.579087428611069, 1.570587197697273}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}}], 
      LineBox[{{3.579087428611069, 1.570587197697273}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}}], 
      LineBox[{{3.579087428611069, 1.570587197697273}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 2.0660510715613603`}, {3.4739269594743862`, 
       2.1231143175752094`}, {3.4739269594743862`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.605708881262104, 
       1.894861333519814}, {3.5497930092209513`, 1.877583972816913}, {
       3.4739269594743867`, 1.894861333519814}, {3.4739269594743867`, 
       1.894861333519814}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.6486294505617396`, 2.083328432264261}, {
       3.6715998421559632`, 2.0089878255475115`}, {3.6715998421559632`, 
       2.0089878255475115`}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}], 
      LineBox[{{3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}], 
      LineBox[{{3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}], 
      LineBox[{{3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}], 
      LineBox[{{3.421031301322045, 1.9519245795336626`}, {3.4080359985805275`,
        2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 1.9519245795336626`}, {3.421031301322045, 
       1.9519245795336626`}}], 
      LineBox[{{3.421031301322045, 1.9519245795336626`}, {3.4080359985805275`,
        2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 1.9519245795336626`}, {3.421031301322045, 
       1.9519245795336626`}}], 
      LineBox[{{3.421031301322045, 1.9519245795336626`}, {3.4080359985805275`,
        2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 1.9519245795336626`}, {3.421031301322045, 
       1.9519245795336626`}}], 
      LineBox[{{3.421031301322045, 1.9519245795336626`}, {3.4080359985805275`,
        2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 1.9519245795336626`}, {3.421031301322045, 
       1.9519245795336626`}}], 
      LineBox[{{3.4080359985805275`, 2.0089878255475115`}, {3.421031301322045,
        2.0660510715613603`}, {3.421031301322045, 2.0660510715613603`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}}], 
      LineBox[{{3.4080359985805275`, 2.0089878255475115`}, {3.421031301322045,
        2.0660510715613603`}, {3.421031301322045, 2.0660510715613603`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}}], 
      LineBox[{{3.4080359985805275`, 2.0089878255475115`}, {3.421031301322045,
        2.0660510715613603`}, {3.421031301322045, 2.0660510715613603`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}}], 
      LineBox[{{3.4080359985805275`, 2.0089878255475115`}, {3.421031301322045,
        2.0660510715613603`}, {3.421031301322045, 2.0660510715613603`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}}], 
      LineBox[{{3.421031301322045, 2.0660510715613603`}, {3.4739269594743867`,
        2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}}], 
      LineBox[{{3.421031301322045, 2.0660510715613603`}, {3.4739269594743867`,
        2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}}], 
      LineBox[{{3.421031301322045, 2.0660510715613603`}, {3.4739269594743867`,
        2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}}], 
      LineBox[{{3.421031301322045, 2.0660510715613603`}, {3.4739269594743867`,
        2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}], 
      LineBox[{{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}], 
      LineBox[{{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}], 
      LineBox[{{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}], 
      LineBox[{{3.6486294505617396`, 1.934647218830762}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}}], 
      LineBox[{{3.6486294505617396`, 1.934647218830762}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}}], 
      LineBox[{{3.6486294505617396`, 1.934647218830762}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}}], 
      LineBox[{{3.6486294505617396`, 1.934647218830762}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}}], 
      LineBox[{{3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}], 
      LineBox[{{3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}], 
      LineBox[{{3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}], 
      LineBox[{{3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}], 
      LineBox[{{3.5497930092209513`, 1.877583972816913}, {3.4739269594743867`,
        1.894861333519814}, {3.4739269594743867`, 1.894861333519814}, {
       3.5497930092209513`, 1.877583972816913}, {3.5497930092209513`, 
       1.877583972816913}}], 
      LineBox[{{3.5497930092209513`, 1.877583972816913}, {3.4739269594743867`,
        1.894861333519814}, {3.4739269594743867`, 1.894861333519814}, {
       3.5497930092209513`, 1.877583972816913}, {3.5497930092209513`, 
       1.877583972816913}}], 
      LineBox[{{3.5497930092209513`, 1.877583972816913}, {3.4739269594743867`,
        1.894861333519814}, {3.4739269594743867`, 1.894861333519814}, {
       3.5497930092209513`, 1.877583972816913}, {3.5497930092209513`, 
       1.877583972816913}}], 
      LineBox[{{3.5497930092209513`, 1.877583972816913}, {3.4739269594743867`,
        1.894861333519814}, {3.4739269594743867`, 1.894861333519814}, {
       3.5497930092209513`, 1.877583972816913}, {3.5497930092209513`, 
       1.877583972816913}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}], 
      LineBox[{{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}], 
      LineBox[{{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}], 
      LineBox[{{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}], 
      LineBox[{{3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}}], 
      LineBox[{{3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}}], 
      LineBox[{{3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}}], 
      LineBox[{{3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}}], 
      LineBox[{{3.605708881262104, 2.1231143175752094`}, {3.6486294505617396`,
        2.083328432264261}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}}], 
      LineBox[{{3.605708881262104, 2.1231143175752094`}, {3.6486294505617396`,
        2.083328432264261}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}}], 
      LineBox[{{3.605708881262104, 2.1231143175752094`}, {3.6486294505617396`,
        2.083328432264261}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}}], 
      LineBox[{{3.605708881262104, 2.1231143175752094`}, {3.6486294505617396`,
        2.083328432264261}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}}], 
      LineBox[{{3.6486294505617396`, 2.083328432264261}, {3.6715998421559632`,
        2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}}], 
      LineBox[{{3.6486294505617396`, 2.083328432264261}, {3.6715998421559632`,
        2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}}], 
      LineBox[{{3.6486294505617396`, 2.083328432264261}, {3.6715998421559632`,
        2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}}], 
      LineBox[{{3.6486294505617396`, 2.083328432264261}, {3.6715998421559632`,
        2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`,
        2.432669725717018}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858, 
       2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.313900799082868, 
       2.5012355781908706`}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956,
        2.411909656007609}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.3930738258488584`, 
       2.3641038732431654`}, {3.3930738258488584`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.602992224598956, 2.411909656007609}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3930738258488584`, 2.638367283138576}, {3.4842326844499705`,
        2.6591273528479844`}, {3.5514198793808385`, 2.638367283138576}, {
       3.602992224598956, 2.590561500374132}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.590561500374132}, {3.5514198793808385`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.3930738258488584`, 2.638367283138576}, {3.3930738258488584`, 
       2.638367283138576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`,
        2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`,
        2.432669725717018}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}], 
      LineBox[{{3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`,
        2.432669725717018}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}], 
      LineBox[{{3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`,
        2.432669725717018}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}], 
      LineBox[{{3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`,
        2.432669725717018}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}], 
      LineBox[{{3.3295156487956183`, 2.432669725717018}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.432669725717018}, {3.3295156487956183`, 
       2.432669725717018}}], 
      LineBox[{{3.3295156487956183`, 2.432669725717018}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.432669725717018}, {3.3295156487956183`, 
       2.432669725717018}}], 
      LineBox[{{3.3295156487956183`, 2.432669725717018}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.432669725717018}, {3.3295156487956183`, 
       2.432669725717018}}], 
      LineBox[{{3.3295156487956183`, 2.432669725717018}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.432669725717018}, {3.3295156487956183`, 
       2.432669725717018}}], 
      LineBox[{{3.313900799082868, 2.5012355781908706`}, {3.3295156487956183`,
        2.5698014306647234`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}}], 
      LineBox[{{3.313900799082868, 2.5012355781908706`}, {3.3295156487956183`,
        2.5698014306647234`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}}], 
      LineBox[{{3.313900799082868, 2.5012355781908706`}, {3.3295156487956183`,
        2.5698014306647234`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}}], 
      LineBox[{{3.313900799082868, 2.5012355781908706`}, {3.3295156487956183`,
        2.5698014306647234`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}}], 
      LineBox[{{3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858,
        2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}}], 
      LineBox[{{3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858,
        2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}}], 
      LineBox[{{3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858,
        2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}}], 
      LineBox[{{3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858,
        2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956,
        2.411909656007609}, {3.602992224598956, 2.411909656007609}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}}], 
      LineBox[{{3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956,
        2.411909656007609}, {3.602992224598956, 2.411909656007609}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}}], 
      LineBox[{{3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956,
        2.411909656007609}, {3.602992224598956, 2.411909656007609}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}}], 
      LineBox[{{3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956,
        2.411909656007609}, {3.602992224598956, 2.411909656007609}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}}], 
      LineBox[{{3.602992224598956, 2.411909656007609}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}}], 
      LineBox[{{3.602992224598956, 2.411909656007609}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}}], 
      LineBox[{{3.602992224598956, 2.411909656007609}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}}], 
      LineBox[{{3.602992224598956, 2.411909656007609}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}}], 
      LineBox[{{3.5514198793808385`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}}], 
      LineBox[{{3.5514198793808385`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}}], 
      LineBox[{{3.5514198793808385`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}}], 
      LineBox[{{3.5514198793808385`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}}], 
      LineBox[{{3.4842326844499705`, 2.343343803533757}, {3.393073825848858, 
       2.3641038732431654`}, {3.393073825848858, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}}], 
      LineBox[{{3.4842326844499705`, 2.343343803533757}, {3.393073825848858, 
       2.3641038732431654`}, {3.393073825848858, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}}], 
      LineBox[{{3.4842326844499705`, 2.343343803533757}, {3.393073825848858, 
       2.3641038732431654`}, {3.393073825848858, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}}], 
      LineBox[{{3.4842326844499705`, 2.343343803533757}, {3.393073825848858, 
       2.3641038732431654`}, {3.393073825848858, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3930738258488584`, 2.638367283138576}, {3.4842326844499705`,
        2.6591273528479844`}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.3930738258488584`, 2.638367283138576}, {3.3930738258488584`, 
       2.638367283138576}}], 
      LineBox[{{3.3930738258488584`, 2.638367283138576}, {3.4842326844499705`,
        2.6591273528479844`}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.3930738258488584`, 2.638367283138576}, {3.3930738258488584`, 
       2.638367283138576}}], 
      LineBox[{{3.3930738258488584`, 2.638367283138576}, {3.4842326844499705`,
        2.6591273528479844`}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.3930738258488584`, 2.638367283138576}, {3.3930738258488584`, 
       2.638367283138576}}], 
      LineBox[{{3.3930738258488584`, 2.638367283138576}, {3.4842326844499705`,
        2.6591273528479844`}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.3930738258488584`, 2.638367283138576}, {3.3930738258488584`, 
       2.638367283138576}}], 
      LineBox[{{3.4842326844499705`, 2.6591273528479844`}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}}], 
      LineBox[{{3.4842326844499705`, 2.6591273528479844`}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}}], 
      LineBox[{{3.4842326844499705`, 2.6591273528479844`}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}}], 
      LineBox[{{3.4842326844499705`, 2.6591273528479844`}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}}], 
      LineBox[{{3.5514198793808385`, 2.638367283138576}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}}], 
      LineBox[{{3.5514198793808385`, 2.638367283138576}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}}], 
      LineBox[{{3.5514198793808385`, 2.638367283138576}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}}], 
      LineBox[{{3.5514198793808385`, 2.638367283138576}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}}], 
      LineBox[{{3.602992224598956, 2.590561500374132}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}}], 
      LineBox[{{3.602992224598956, 2.590561500374132}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}}], 
      LineBox[{{3.602992224598956, 2.590561500374132}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}}], 
      LineBox[{{3.602992224598956, 2.590561500374132}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614, 
       3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.338123279802715, 
       3.02017230453673}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       2.927137772449133}, {3.585503614170412, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.420583391258614, 
       2.877347201897321}, {3.420583391258614, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.585503614170412, 
       2.877347201897321}, {3.639217126315117, 2.927137772449133}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.420583391258614, 3.1629974071761393`}, {3.5155269591312686`,
        3.1846193879440317`}, {3.585503614170412, 3.1629974071761393`}, {
       3.639217126315117, 3.113206836624327}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 3.113206836624327}, {3.585503614170412, 
       3.1629974071761393`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}], 
      LineBox[{{3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}], 
      LineBox[{{3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}], 
      LineBox[{{3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}], 
      LineBox[{{3.3543864226971536`, 2.9487597532170255`}, {3.338123279802715,
        3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.3543864226971536`, 
       2.9487597532170255`}}], 
      LineBox[{{3.3543864226971536`, 2.9487597532170255`}, {3.338123279802715,
        3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.3543864226971536`, 
       2.9487597532170255`}}], 
      LineBox[{{3.3543864226971536`, 2.9487597532170255`}, {3.338123279802715,
        3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.3543864226971536`, 
       2.9487597532170255`}}], 
      LineBox[{{3.3543864226971536`, 2.9487597532170255`}, {3.338123279802715,
        3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.3543864226971536`, 
       2.9487597532170255`}}], 
      LineBox[{{3.338123279802715, 3.02017230453673}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}}], 
      LineBox[{{3.338123279802715, 3.02017230453673}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}}], 
      LineBox[{{3.338123279802715, 3.02017230453673}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}}], 
      LineBox[{{3.338123279802715, 3.02017230453673}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}}], 
      LineBox[{{3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614,
        3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}}], 
      LineBox[{{3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614,
        3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}}], 
      LineBox[{{3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614,
        3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}}], 
      LineBox[{{3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614,
        3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}}], 
      LineBox[{{3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}}], 
      LineBox[{{3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}}], 
      LineBox[{{3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}}], 
      LineBox[{{3.639217126315117, 2.927137772449133}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}}], 
      LineBox[{{3.639217126315117, 2.927137772449133}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}}], 
      LineBox[{{3.639217126315117, 2.927137772449133}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}}], 
      LineBox[{{3.639217126315117, 2.927137772449133}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}}], 
      LineBox[{{3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}], 
      LineBox[{{3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}], 
      LineBox[{{3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}], 
      LineBox[{{3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}], 
      LineBox[{{3.5155269591312686`, 2.8557252211294286`}, {3.420583391258614,
        2.877347201897321}, {3.420583391258614, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.5155269591312686`, 
       2.8557252211294286`}}], 
      LineBox[{{3.5155269591312686`, 2.8557252211294286`}, {3.420583391258614,
        2.877347201897321}, {3.420583391258614, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.5155269591312686`, 
       2.8557252211294286`}}], 
      LineBox[{{3.5155269591312686`, 2.8557252211294286`}, {3.420583391258614,
        2.877347201897321}, {3.420583391258614, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.5155269591312686`, 
       2.8557252211294286`}}], 
      LineBox[{{3.5155269591312686`, 2.8557252211294286`}, {3.420583391258614,
        2.877347201897321}, {3.420583391258614, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.5155269591312686`, 
       2.8557252211294286`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.420583391258614, 3.1629974071761393`}, {3.5155269591312686`,
        3.1846193879440317`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}}], 
      LineBox[{{3.420583391258614, 3.1629974071761393`}, {3.5155269591312686`,
        3.1846193879440317`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}}], 
      LineBox[{{3.420583391258614, 3.1629974071761393`}, {3.5155269591312686`,
        3.1846193879440317`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}}], 
      LineBox[{{3.420583391258614, 3.1629974071761393`}, {3.5155269591312686`,
        3.1846193879440317`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}}], 
      LineBox[{{3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412,
        3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}}], 
      LineBox[{{3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412,
        3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}}], 
      LineBox[{{3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412,
        3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}}], 
      LineBox[{{3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412,
        3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}}], 
      LineBox[{{3.585503614170412, 3.1629974071761393`}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}}], 
      LineBox[{{3.585503614170412, 3.1629974071761393`}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}}], 
      LineBox[{{3.585503614170412, 3.1629974071761393`}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}}], 
      LineBox[{{3.585503614170412, 3.1629974071761393`}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}}], 
      LineBox[{{3.639217126315117, 3.113206836624327}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}}], 
      LineBox[{{3.639217126315117, 3.113206836624327}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}}], 
      LineBox[{{3.639217126315117, 3.113206836624327}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}}], 
      LineBox[{{3.639217126315117, 3.113206836624327}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.3531564528406683`, 
       3.474797770957089}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`,
        3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6821036109144325`, 3.474797770957089}, {3.6534348643509507`,
        3.3820151988970673`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.4353932423591096`, 
       3.3323594732598014`}, {3.4353932423591096`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.653434864350951, 3.3820151988970673`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.653434864350951, 3.5675803430171107`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}, {3.6534348643509507`, 3.5675803430171107`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}], 
      LineBox[{{3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}], 
      LineBox[{{3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}], 
      LineBox[{{3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}], 
      LineBox[{{3.369375551208411, 3.403578622108445}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.403578622108445}, {3.369375551208411, 
       3.403578622108445}}], 
      LineBox[{{3.369375551208411, 3.403578622108445}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.403578622108445}, {3.369375551208411, 
       3.403578622108445}}], 
      LineBox[{{3.369375551208411, 3.403578622108445}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.403578622108445}, {3.369375551208411, 
       3.403578622108445}}], 
      LineBox[{{3.369375551208411, 3.403578622108445}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.403578622108445}, {3.369375551208411, 
       3.403578622108445}}], 
      LineBox[{{3.3531564528406683`, 3.474797770957089}, {3.369375551208411, 
       3.5460169198057327`}, {3.369375551208411, 3.5460169198057327`}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}}], 
      LineBox[{{3.3531564528406683`, 3.474797770957089}, {3.369375551208411, 
       3.5460169198057327`}, {3.369375551208411, 3.5460169198057327`}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}}], 
      LineBox[{{3.3531564528406683`, 3.474797770957089}, {3.369375551208411, 
       3.5460169198057327`}, {3.369375551208411, 3.5460169198057327`}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}}], 
      LineBox[{{3.3531564528406683`, 3.474797770957089}, {3.369375551208411, 
       3.5460169198057327`}, {3.369375551208411, 3.5460169198057327`}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}}], 
      LineBox[{{3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}}], 
      LineBox[{{3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}}], 
      LineBox[{{3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}}], 
      LineBox[{{3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6821036109144325`, 3.474797770957089}, {3.6534348643509507`,
        3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}}], 
      LineBox[{{3.6821036109144325`, 3.474797770957089}, {3.6534348643509507`,
        3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}}], 
      LineBox[{{3.6821036109144325`, 3.474797770957089}, {3.6534348643509507`,
        3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}}], 
      LineBox[{{3.6821036109144325`, 3.474797770957089}, {3.6534348643509507`,
        3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}}], 
      LineBox[{{3.6534348643509507`, 3.3820151988970673`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6534348643509507`, 3.3820151988970673`}}], 
      LineBox[{{3.6534348643509507`, 3.3820151988970673`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6534348643509507`, 3.3820151988970673`}}], 
      LineBox[{{3.6534348643509507`, 3.3820151988970673`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6534348643509507`, 3.3820151988970673`}}], 
      LineBox[{{3.6534348643509507`, 3.3820151988970673`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6534348643509507`, 3.3820151988970673`}}], 
      LineBox[{{3.5998668213959917`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}}], 
      LineBox[{{3.5998668213959917`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}}], 
      LineBox[{{3.5998668213959917`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}}], 
      LineBox[{{3.5998668213959917`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}}], 
      LineBox[{{3.5300796800732894`, 3.3107960500484235`}, {3.435393242359109,
        3.3323594732598014`}, {3.435393242359109, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}}], 
      LineBox[{{3.5300796800732894`, 3.3107960500484235`}, {3.435393242359109,
        3.3323594732598014`}, {3.435393242359109, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}}], 
      LineBox[{{3.5300796800732894`, 3.3107960500484235`}, {3.435393242359109,
        3.3323594732598014`}, {3.435393242359109, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}}], 
      LineBox[{{3.5300796800732894`, 3.3107960500484235`}, {3.435393242359109,
        3.3323594732598014`}, {3.435393242359109, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}], 
      LineBox[{{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}], 
      LineBox[{{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}], 
      LineBox[{{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}], 
      LineBox[{{3.5300796800732894`, 3.6387994918657545`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}}], 
      LineBox[{{3.5300796800732894`, 3.6387994918657545`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}}], 
      LineBox[{{3.5300796800732894`, 3.6387994918657545`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}}], 
      LineBox[{{3.5300796800732894`, 3.6387994918657545`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}}], 
      LineBox[{{3.5998668213959917`, 3.6172360686543765`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}], 
      LineBox[{{3.5998668213959917`, 3.6172360686543765`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}], 
      LineBox[{{3.5998668213959917`, 3.6172360686543765`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}], 
      LineBox[{{3.5998668213959917`, 3.6172360686543765`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}], 
      LineBox[{{3.653434864350951, 3.5675803430171107`}, {3.6821036109144325`,
        3.474797770957089}, {3.6821036109144325`, 3.474797770957089}, {
       3.653434864350951, 3.5675803430171107`}, {3.653434864350951, 
       3.5675803430171107`}}], 
      LineBox[{{3.653434864350951, 3.5675803430171107`}, {3.6821036109144325`,
        3.474797770957089}, {3.6821036109144325`, 3.474797770957089}, {
       3.653434864350951, 3.5675803430171107`}, {3.653434864350951, 
       3.5675803430171107`}}], 
      LineBox[{{3.653434864350951, 3.5675803430171107`}, {3.6821036109144325`,
        3.474797770957089}, {3.6821036109144325`, 3.474797770957089}, {
       3.653434864350951, 3.5675803430171107`}, {3.653434864350951, 
       3.5675803430171107`}}], 
      LineBox[{{3.653434864350951, 3.5675803430171107`}, {3.6821036109144325`,
        3.474797770957089}, {3.6821036109144325`, 3.474797770957089}, {
       3.653434864350951, 3.5675803430171107`}, {3.653434864350951, 
       3.5675803430171107`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}], 
      LineBox[{{3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}], 
      LineBox[{{3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}], 
      LineBox[{{3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}], 
      LineBox[{{3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}], 
      LineBox[{{3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}], 
      LineBox[{{3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}], 
      LineBox[{{3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}], 
      LineBox[{{3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}], 
      LineBox[{{3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}], 
      LineBox[{{3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}], 
      LineBox[{{3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}], 
      LineBox[{{3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}], 
      LineBox[{{3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}], 
      LineBox[{{3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}], 
      LineBox[{{3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}], 
      LineBox[{{3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}], 
      LineBox[{{3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}], 
      LineBox[{{3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}], 
      LineBox[{{3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}], 
      LineBox[{{3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}], 
      LineBox[{{3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}], 
      LineBox[{{3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}], 
      LineBox[{{3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}], 
      LineBox[{{3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}], 
      LineBox[{{3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}], 
      LineBox[{{3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}], 
      LineBox[{{3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}], 
      LineBox[{{3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}], 
      LineBox[{{3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}], 
      LineBox[{{3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}], 
      LineBox[{{3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}], 
      LineBox[{{3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}], 
      LineBox[{{3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}], 
      LineBox[{{3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}], 
      LineBox[{{3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}], 
      LineBox[{{3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}], 
      LineBox[{{3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}], 
      LineBox[{{3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}], 
      LineBox[{{3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}], 
      LineBox[{{3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}], 
      LineBox[{{3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}], 
      LineBox[{{3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}], 
      LineBox[{{3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}], 
      LineBox[{{3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}], 
      LineBox[{{3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}], 
      LineBox[{{3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}], 
      LineBox[{{3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}], 
      LineBox[{{3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}], 
      LineBox[{{3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}], 
      LineBox[{{3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}], 
      LineBox[{{3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}], 
      LineBox[{{3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}], 
      LineBox[{{3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}], 
      LineBox[{{3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}], 
      LineBox[{{3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}], 
      LineBox[{{3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}], 
      LineBox[{{3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}], 
      LineBox[{{3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}], 
      LineBox[{{3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}], 
      LineBox[{{3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}], 
      LineBox[{{3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}], 
      LineBox[{{3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}], 
      LineBox[{{3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}], 
      LineBox[{{3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}], 
      LineBox[{{3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}], 
      LineBox[{{3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}], 
      LineBox[{{3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}], 
      LineBox[{{3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}], 
      LineBox[{{3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}], 
      LineBox[{{3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}], 
      LineBox[{{3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}], 
      LineBox[{{3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}], 
      LineBox[{{3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}], 
      LineBox[{{3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}], 
      LineBox[{{3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}], 
      LineBox[{{3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}], 
      LineBox[{{3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}], 
      LineBox[{{3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}], 
      LineBox[{{3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}], 
      LineBox[{{3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}], 
      LineBox[{{3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}], 
      LineBox[{{3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}], 
      LineBox[{{3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}], 
      LineBox[{{3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}], 
      LineBox[{{3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}], 
      LineBox[{{3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}], 
      LineBox[{{3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}], 
      LineBox[{{3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}], 
      LineBox[{{3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}], 
      LineBox[{{3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}], 
      LineBox[{{3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}], 
      LineBox[{{3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}], 
      LineBox[{{3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}], 
      LineBox[{{3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}], 
      LineBox[{{3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}], 
      LineBox[{{3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}], 
      LineBox[{{3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}], 
      LineBox[{{3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}], 
      LineBox[{{3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}], 
      LineBox[{{3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}], 
      LineBox[{{3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}], 
      LineBox[{{3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}], 
      LineBox[{{3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}], 
      LineBox[{{3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}], 
      LineBox[{{3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}], 
      LineBox[{{3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}], 
      LineBox[{{3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}], 
      LineBox[{{3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}], 
      LineBox[{{3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}], 
      LineBox[{{3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}], 
      LineBox[{{3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}], 
      LineBox[{{3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}], 
      LineBox[{{3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}], 
      LineBox[{{3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}], 
      LineBox[{{3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}], 
      LineBox[{{3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}], 
      LineBox[{{3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}], 
      LineBox[{{3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}], 
      LineBox[{{3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}], 
      LineBox[{{3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}], 
      LineBox[{{3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}], 
      LineBox[{{3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}], 
      LineBox[{{3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}], 
      LineBox[{{3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}], 
      LineBox[{{3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}], 
      LineBox[{{3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}], 
      LineBox[{{3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}], 
      LineBox[{{3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}], 
      LineBox[{{3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}], 
      LineBox[{{3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}], 
      LineBox[{{3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}], 
      LineBox[{{3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}], 
      LineBox[{{3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}], 
      LineBox[{{3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}], 
      LineBox[{{3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}], 
      LineBox[{{3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}], 
      LineBox[{{3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}], 
      LineBox[{{3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}], 
      LineBox[{{3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}], 
      LineBox[{{3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}], 
      LineBox[{{3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}], 
      LineBox[{{3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}], 
      LineBox[{{3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}], 
      LineBox[{{3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}], 
      LineBox[{{3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}], 
      LineBox[{{3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}], 
      LineBox[{{3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}], 
      LineBox[{{3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}], 
      LineBox[{{3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}], 
      LineBox[{{3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}], 
      LineBox[{{3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}], 
      LineBox[{{3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}], 
      LineBox[{{3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}], 
      LineBox[{{3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}], 
      LineBox[{{3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}], 
      LineBox[{{3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}], 
      LineBox[{{3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}], 
      LineBox[{{3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}], 
      LineBox[{{3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}], 
      LineBox[{{3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}], 
      LineBox[{{3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}], 
      LineBox[{{3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}], 
      LineBox[{{3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}], 
      LineBox[{{3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}], 
      LineBox[{{3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}], 
      LineBox[{{3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}], 
      LineBox[{{3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}], 
      LineBox[{{3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}], 
      LineBox[{{3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}], 
      LineBox[{{3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}], 
      LineBox[{{3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}], 
      LineBox[{{3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}], 
      LineBox[{{3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}], 
      LineBox[{{3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}], 
      LineBox[{{3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}], 
      LineBox[{{3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}], 
      LineBox[{{3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}], 
      LineBox[{{3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}], 
      LineBox[{{3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}], 
      LineBox[{{3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}], 
      LineBox[{{3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}], 
      LineBox[{{3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}], 
      LineBox[{{3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}], 
      LineBox[{{3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}], 
      LineBox[{{3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}], 
      LineBox[{{3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}], 
      LineBox[{{3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}], 
      LineBox[{{3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}], 
      LineBox[{{3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}], 
      LineBox[{{3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}], 
      LineBox[{{3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}], 
      LineBox[{{3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}], 
      LineBox[{{3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}], 
      LineBox[{{3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}], 
      LineBox[{{3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}], 
      LineBox[{{3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}], 
      LineBox[{{3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}], 
      LineBox[{{3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}], 
      LineBox[{{3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}], 
      LineBox[{{3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}], 
      LineBox[{{3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}], 
      LineBox[{{3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}], 
      LineBox[{{3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}], 
      LineBox[{{3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}], 
      LineBox[{{3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}], 
      LineBox[{{3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}], 
      LineBox[{{3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}], 
      LineBox[{{3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}], 
      LineBox[{{3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}], 
      LineBox[{{3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}], 
      LineBox[{{3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}], 
      LineBox[{{3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}], 
      LineBox[{{3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}], 
      LineBox[{{3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}], 
      LineBox[{{3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}], 
      LineBox[{{3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}], 
      LineBox[{{3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}], 
      LineBox[{{3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}], 
      LineBox[{{3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}], 
      LineBox[{{3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}], 
      LineBox[{{3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}], 
      LineBox[{{3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}], 
      LineBox[{{3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}], 
      LineBox[{{3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}], 
      LineBox[{{3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}], 
      LineBox[{{3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}], 
      LineBox[{{3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}], 
      LineBox[{{3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}], 
      LineBox[{{3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}], 
      LineBox[{{3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}], 
      LineBox[{{3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}], 
      LineBox[{{3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}], 
      LineBox[{{3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}], 
      LineBox[{{3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}], 
      LineBox[{{3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}], 
      LineBox[{{3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}], 
      LineBox[{{3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}], 
      LineBox[{{3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}], 
      LineBox[{{3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}], 
      LineBox[{{3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}], 
      LineBox[{{3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}], 
      LineBox[{{3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}], 
      LineBox[{{3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}], 
      LineBox[{{3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}], 
      LineBox[{{3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}], 
      LineBox[{{3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}], 
      LineBox[{{3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}], 
      LineBox[{{3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}], 
      LineBox[{{3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}], 
      LineBox[{{3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}], 
      LineBox[{{3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}], 
      LineBox[{{3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}], 
      LineBox[{{3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}], 
      LineBox[{{3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}], 
      LineBox[{{3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}], 
      LineBox[{{3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}], 
      LineBox[{{3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}], 
      LineBox[{{3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}], 
      LineBox[{{3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}], 
      LineBox[{{3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}], 
      LineBox[{{3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}], 
      LineBox[{{3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}], 
      LineBox[{{3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}], 
      LineBox[{{3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}], 
      LineBox[{{3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}], 
      LineBox[{{3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}], 
      LineBox[{{3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}], 
      LineBox[{{3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}], 
      LineBox[{{3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}], 
      LineBox[{{3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.9082284200808335`, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}], 
      LineBox[{{3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}], 
      LineBox[{{3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}], 
      LineBox[{{3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}], 
      LineBox[{{3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}], 
      LineBox[{{3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}], 
      LineBox[{{3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}], 
      LineBox[{{3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}], 
      LineBox[{{3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}], 
      LineBox[{{3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}], 
      LineBox[{{3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}], 
      LineBox[{{3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}], 
      LineBox[{{3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}], 
      LineBox[{{3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}], 
      LineBox[{{3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}], 
      LineBox[{{3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}], 
      LineBox[{{3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}], 
      LineBox[{{3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}], 
      LineBox[{{3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}], 
      LineBox[{{3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}], 
      LineBox[{{3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}], 
      LineBox[{{3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}], 
      LineBox[{{3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}], 
      LineBox[{{3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}], 
      LineBox[{{3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}], 
      LineBox[{{3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}], 
      LineBox[{{3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}], 
      LineBox[{{3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}], 
      LineBox[{{3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}], 
      LineBox[{{3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}], 
      LineBox[{{3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}], 
      LineBox[{{3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}], 
      LineBox[{{3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}], 
      LineBox[{{3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}], 
      LineBox[{{3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}], 
      LineBox[{{3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}], 
      LineBox[{{3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}], 
      LineBox[{{3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}], 
      LineBox[{{3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}], 
      LineBox[{{3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}], 
      LineBox[{{3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}], 
      LineBox[{{3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}], 
      LineBox[{{3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}], 
      LineBox[{{3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}], 
      LineBox[{{3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}], 
      LineBox[{{3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}], 
      LineBox[{{3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}], 
      LineBox[{{3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}], 
      LineBox[{{3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}], 
      LineBox[{{3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}], 
      LineBox[{{3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}], 
      LineBox[{{3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}], 
      LineBox[{{3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}], 
      LineBox[{{3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}], 
      LineBox[{{3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}], 
      LineBox[{{3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}], 
      LineBox[{{3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}], 
      LineBox[{{3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}], 
      LineBox[{{3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}], 
      LineBox[{{3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}], 
      LineBox[{{3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}], 
      LineBox[{{3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}], 
      LineBox[{{3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}], 
      LineBox[{{3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}], 
      LineBox[{{3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}], 
      LineBox[{{3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}], 
      LineBox[{{3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}], 
      LineBox[{{3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}], 
      LineBox[{{3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}], 
      LineBox[{{3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}], 
      LineBox[{{3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}], 
      LineBox[{{3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}], 
      LineBox[{{3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}], 
      LineBox[{{3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}], 
      LineBox[{{3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}], 
      LineBox[{{3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}], 
      LineBox[{{3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}], 
      LineBox[{{3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}], 
      LineBox[{{3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}], 
      LineBox[{{3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}], 
      LineBox[{{3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}], 
      LineBox[{{3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}], 
      LineBox[{{3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}], 
      LineBox[{{3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}], 
      LineBox[{{3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}], 
      LineBox[{{3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}], 
      LineBox[{{3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}], 
      LineBox[{{3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}], 
      LineBox[{{3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}], 
      LineBox[{{3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}], 
      LineBox[{{3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989236}, {
       3.623727020289535, -0.09441595434989236}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.3160106176676708}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.3898755054402636}, {
       3.623727020289535, -0.3898755054402636}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.24214572989507793`}, {
       3.8796024973245427`, -0.24214572989507793`}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}], 
      LineBox[{{3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}], 
      LineBox[{{3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}], 
      LineBox[{{3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}], 
      LineBox[{{3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}], 
      LineBox[{{3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}], 
      LineBox[{{3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}], 
      LineBox[{{3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}], 
      LineBox[{{3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}], 
      LineBox[{{3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}], 
      LineBox[{{3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}], 
      LineBox[{{3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}], 
      LineBox[{{3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}], 
      LineBox[{{3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}], 
      LineBox[{{3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}], 
      LineBox[{{3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}], 
      LineBox[{{3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}], 
      LineBox[{{3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}], 
      LineBox[{{3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}], 
      LineBox[{{3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}], 
      LineBox[{{3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}], 
      LineBox[{{3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}], 
      LineBox[{{3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}], 
      LineBox[{{3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}], 
      LineBox[{{3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}], 
      LineBox[{{3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}], 
      LineBox[{{3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}], 
      LineBox[{{3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}], 
      LineBox[{{3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}], 
      LineBox[{{3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}], 
      LineBox[{{3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}], 
      LineBox[{{3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}], 
      LineBox[{{3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}], 
      LineBox[{{3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}], 
      LineBox[{{3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}], 
      LineBox[{{3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}], 
      LineBox[{{3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}], 
      LineBox[{{3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}], 
      LineBox[{{3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}], 
      LineBox[{{3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}], 
      LineBox[{{3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}], 
      LineBox[{{3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}], 
      LineBox[{{3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}], 
      LineBox[{{3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}], 
      LineBox[{{3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}], 
      LineBox[{{3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6841497319344017`, 0.07657465936013377}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.28732293175018514`}, {
       3.6841497319344017`, 0.3575723558802022}, {3.6841497319344017`, 
       0.3575723558802022}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`, 
       0.14682408349015086`}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`,
        0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8463838276619278`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013375}, {3.6841497319344017`, 
       0.07657465936013375}, {3.7775469127471086`, 0.05530484516886244}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8992224845427534`, 0.3085927459414564}, {
       3.927500875525691, 0.21707350762016803`}, {3.927500875525691, 
       0.21707350762016803`}, {3.8992224845427534`, 0.3085927459414564}, {
       3.8463838276619278`, 0.3575723558802022}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6841497319344017`, 0.07657465936013377}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}}], 
      LineBox[{{3.6841497319344017`, 0.07657465936013377}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}}], 
      LineBox[{{3.6841497319344017`, 0.07657465936013377}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}}], 
      LineBox[{{3.6841497319344017`, 0.07657465936013377}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}}], 
      LineBox[{{3.6190309421046325`, 0.1468240834901509}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}}], 
      LineBox[{{3.6190309421046325`, 0.1468240834901509}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}}], 
      LineBox[{{3.6190309421046325`, 0.1468240834901509}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}}], 
      LineBox[{{3.6190309421046325`, 0.1468240834901509}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}}], 
      LineBox[{{3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`,
        0.2873229317501851}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}], 
      LineBox[{{3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`,
        0.2873229317501851}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}], 
      LineBox[{{3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`,
        0.2873229317501851}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}], 
      LineBox[{{3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`,
        0.2873229317501851}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}], 
      LineBox[{{3.6190309421046325`, 0.28732293175018514`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6190309421046325`, 0.28732293175018514`}, {
       3.6190309421046325`, 0.28732293175018514`}}], 
      LineBox[{{3.6190309421046325`, 0.28732293175018514`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6190309421046325`, 0.28732293175018514`}, {
       3.6190309421046325`, 0.28732293175018514`}}], 
      LineBox[{{3.6190309421046325`, 0.28732293175018514`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6190309421046325`, 0.28732293175018514`}, {
       3.6190309421046325`, 0.28732293175018514`}}], 
      LineBox[{{3.6190309421046325`, 0.28732293175018514`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6190309421046325`, 0.28732293175018514`}, {
       3.6190309421046325`, 0.28732293175018514`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}], 
      LineBox[{{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}], 
      LineBox[{{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}], 
      LineBox[{{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}], 
      LineBox[{{3.8992224845427534`, 0.12555426929887958`}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}}], 
      LineBox[{{3.8992224845427534`, 0.12555426929887958`}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}}], 
      LineBox[{{3.8992224845427534`, 0.12555426929887958`}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}}], 
      LineBox[{{3.8992224845427534`, 0.12555426929887958`}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}}], 
      LineBox[{{3.8463838276619278`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}}], 
      LineBox[{{3.8463838276619278`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}}], 
      LineBox[{{3.8463838276619278`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}}], 
      LineBox[{{3.8463838276619278`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}}], 
      LineBox[{{3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013377}, {3.6841497319344017`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}}], 
      LineBox[{{3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013377}, {3.6841497319344017`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}}], 
      LineBox[{{3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013377}, {3.6841497319344017`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}}], 
      LineBox[{{3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013377}, {3.6841497319344017`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}], 
      LineBox[{{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}], 
      LineBox[{{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}], 
      LineBox[{{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}], 
      LineBox[{{3.7775469127471086`, 0.3788421700714736}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.7775469127471086`, 0.3788421700714736}, {
       3.7775469127471086`, 0.3788421700714736}}], 
      LineBox[{{3.7775469127471086`, 0.3788421700714736}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.7775469127471086`, 0.3788421700714736}, {
       3.7775469127471086`, 0.3788421700714736}}], 
      LineBox[{{3.7775469127471086`, 0.3788421700714736}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.7775469127471086`, 0.3788421700714736}, {
       3.7775469127471086`, 0.3788421700714736}}], 
      LineBox[{{3.7775469127471086`, 0.3788421700714736}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.7775469127471086`, 0.3788421700714736}, {
       3.7775469127471086`, 0.3788421700714736}}], 
      LineBox[{{3.8463838276619278`, 0.3575723558802022}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}], 
      LineBox[{{3.8463838276619278`, 0.3575723558802022}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}], 
      LineBox[{{3.8463838276619278`, 0.3575723558802022}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}], 
      LineBox[{{3.8463838276619278`, 0.3575723558802022}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}], 
      LineBox[{{3.8992224845427534`, 0.3085927459414564}, {3.927500875525691, 
       0.21707350762016797`}, {3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}}], 
      LineBox[{{3.8992224845427534`, 0.3085927459414564}, {3.927500875525691, 
       0.21707350762016797`}, {3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}}], 
      LineBox[{{3.8992224845427534`, 0.3085927459414564}, {3.927500875525691, 
       0.21707350762016797`}, {3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}}], 
      LineBox[{{3.8992224845427534`, 0.3085927459414564}, {3.927500875525691, 
       0.21707350762016797`}, {3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.677390132218771, 0.6515683873327646}, {3.614303839314177, 
       0.7196251764504782}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.8557387546859057}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}, {
       3.614303839314177, 0.8557387546859057}, {3.5988049211841835`, 
       0.7876819655681919}, {3.614303839314177, 0.7196251764504782}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.834560554287945, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.834560554287945, 
       0.6515683873327646}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.834560554287945, 0.9237955438036193}, {
       3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.834560554287945, 
       0.9237955438036193}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.677390132218771, 0.6515683873327646}, {3.614303839314177, 
       0.7196251764504782}, {3.614303839314177, 0.7196251764504782}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}}], 
      LineBox[{{3.677390132218771, 0.6515683873327646}, {3.614303839314177, 
       0.7196251764504782}, {3.614303839314177, 0.7196251764504782}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}}], 
      LineBox[{{3.677390132218771, 0.6515683873327646}, {3.614303839314177, 
       0.7196251764504782}, {3.614303839314177, 0.7196251764504782}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}}], 
      LineBox[{{3.677390132218771, 0.6515683873327646}, {3.614303839314177, 
       0.7196251764504782}, {3.614303839314177, 0.7196251764504782}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}}], 
      LineBox[{{3.614303839314177, 0.7196251764504782}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}}], 
      LineBox[{{3.614303839314177, 0.7196251764504782}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}}], 
      LineBox[{{3.614303839314177, 0.7196251764504782}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}}], 
      LineBox[{{3.614303839314177, 0.7196251764504782}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}}], 
      LineBox[{{3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}}], 
      LineBox[{{3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}}], 
      LineBox[{{3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}}], 
      LineBox[{{3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}}], 
      LineBox[{{3.614303839314177, 0.8557387546859057}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}}], 
      LineBox[{{3.614303839314177, 0.8557387546859057}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}}], 
      LineBox[{{3.614303839314177, 0.8557387546859057}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}}], 
      LineBox[{{3.614303839314177, 0.8557387546859057}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}], 
      LineBox[{{3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}], 
      LineBox[{{3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}], 
      LineBox[{{3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}], 
      LineBox[{{3.885750003498889, 0.6990192387233707}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.885750003498889, 0.6990192387233707}, {3.885750003498889, 
       0.6990192387233707}}], 
      LineBox[{{3.885750003498889, 0.6990192387233707}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.885750003498889, 0.6990192387233707}, {3.885750003498889, 
       0.6990192387233707}}], 
      LineBox[{{3.885750003498889, 0.6990192387233707}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.885750003498889, 0.6990192387233707}, {3.885750003498889, 
       0.6990192387233707}}], 
      LineBox[{{3.885750003498889, 0.6990192387233707}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.885750003498889, 0.6990192387233707}, {3.885750003498889, 
       0.6990192387233707}}], 
      LineBox[{{3.834560554287945, 0.6515683873327646}, {3.767872186947008, 
       0.630962449605657}, {3.767872186947008, 0.630962449605657}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}}], 
      LineBox[{{3.834560554287945, 0.6515683873327646}, {3.767872186947008, 
       0.630962449605657}, {3.767872186947008, 0.630962449605657}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}}], 
      LineBox[{{3.834560554287945, 0.6515683873327646}, {3.767872186947008, 
       0.630962449605657}, {3.767872186947008, 0.630962449605657}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}}], 
      LineBox[{{3.834560554287945, 0.6515683873327646}, {3.767872186947008, 
       0.630962449605657}, {3.767872186947008, 0.630962449605657}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}}], 
      LineBox[{{3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}}], 
      LineBox[{{3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}}], 
      LineBox[{{3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}}], 
      LineBox[{{3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}], 
      LineBox[{{3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}], 
      LineBox[{{3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}], 
      LineBox[{{3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}], 
      LineBox[{{3.767872186947008, 0.9444014815307269}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}}], 
      LineBox[{{3.767872186947008, 0.9444014815307269}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}}], 
      LineBox[{{3.767872186947008, 0.9444014815307269}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}}], 
      LineBox[{{3.767872186947008, 0.9444014815307269}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}}], 
      LineBox[{{3.834560554287945, 0.9237955438036193}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}], 
      LineBox[{{3.834560554287945, 0.9237955438036193}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}], 
      LineBox[{{3.834560554287945, 0.9237955438036193}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}], 
      LineBox[{{3.834560554287945, 0.9237955438036193}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}], 
      LineBox[{{3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.885750003498889, 
       0.8763446924130132}}], 
      LineBox[{{3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.885750003498889, 
       0.8763446924130132}}], 
      LineBox[{{3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.885750003498889, 
       0.8763446924130132}}], 
      LineBox[{{3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.885750003498889, 
       0.8763446924130132}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.723271125538312, 1.1634707003604499`}, {3.663572215605023, 
       1.2278732185117645`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.3566782548143932`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}, {
       3.663572215605023, 1.3566782548143932`}, {3.64890550315601, 
       1.2922757366630788`}, {3.663572215605023, 1.2278732185117645`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.872002370302917, 1.4210807729657078`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.872002370302917, 
       1.4210807729657078`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.723271125538312, 1.1634707003604499`}, {3.663572215605023, 
       1.2278732185117645`}, {3.663572215605023, 1.2278732185117645`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}}], 
      LineBox[{{3.723271125538312, 1.1634707003604499`}, {3.663572215605023, 
       1.2278732185117645`}, {3.663572215605023, 1.2278732185117645`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}}], 
      LineBox[{{3.723271125538312, 1.1634707003604499`}, {3.663572215605023, 
       1.2278732185117645`}, {3.663572215605023, 1.2278732185117645`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}}], 
      LineBox[{{3.723271125538312, 1.1634707003604499`}, {3.663572215605023, 
       1.2278732185117645`}, {3.663572215605023, 1.2278732185117645`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}}], 
      LineBox[{{3.663572215605023, 1.2278732185117645`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}}], 
      LineBox[{{3.663572215605023, 1.2278732185117645`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}}], 
      LineBox[{{3.663572215605023, 1.2278732185117645`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}}], 
      LineBox[{{3.663572215605023, 1.2278732185117645`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}}], 
      LineBox[{{3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}], 
      LineBox[{{3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}], 
      LineBox[{{3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}], 
      LineBox[{{3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}], 
      LineBox[{{3.663572215605023, 1.3566782548143932`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}}], 
      LineBox[{{3.663572215605023, 1.3566782548143932`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}}], 
      LineBox[{{3.663572215605023, 1.3566782548143932`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}}], 
      LineBox[{{3.663572215605023, 1.3566782548143932`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}], 
      LineBox[{{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}], 
      LineBox[{{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}], 
      LineBox[{{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}], 
      LineBox[{{3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917,
        1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}}], 
      LineBox[{{3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917,
        1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}}], 
      LineBox[{{3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917,
        1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}}], 
      LineBox[{{3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917,
        1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}}], 
      LineBox[{{3.872002370302917, 1.1634707003604499`}, {3.808894797291684, 
       1.1439711868556393`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}}], 
      LineBox[{{3.872002370302917, 1.1634707003604499`}, {3.808894797291684, 
       1.1439711868556393`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}}], 
      LineBox[{{3.872002370302917, 1.1634707003604499`}, {3.808894797291684, 
       1.1439711868556393`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}}], 
      LineBox[{{3.872002370302917, 1.1634707003604499`}, {3.808894797291684, 
       1.1439711868556393`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}}], 
      LineBox[{{3.808894797291684, 1.1439711868556393`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}}], 
      LineBox[{{3.808894797291684, 1.1439711868556393`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}}], 
      LineBox[{{3.808894797291684, 1.1439711868556393`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}}], 
      LineBox[{{3.808894797291684, 1.1439711868556393`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}], 
      LineBox[{{3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}], 
      LineBox[{{3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}], 
      LineBox[{{3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}], 
      LineBox[{{3.808894797291684, 1.4405802864705184`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}}], 
      LineBox[{{3.808894797291684, 1.4405802864705184`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}}], 
      LineBox[{{3.808894797291684, 1.4405802864705184`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}}], 
      LineBox[{{3.808894797291684, 1.4405802864705184`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}}], 
      LineBox[{{3.872002370302917, 1.4210807729657078`}, {3.9204432308651374`,
        1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}], 
      LineBox[{{3.872002370302917, 1.4210807729657078`}, {3.9204432308651374`,
        1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}], 
      LineBox[{{3.872002370302917, 1.4210807729657078`}, {3.9204432308651374`,
        1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}], 
      LineBox[{{3.872002370302917, 1.4210807729657078`}, {3.9204432308651374`,
        1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}], 
      LineBox[{{3.9204432308651374`, 1.3761777683192038`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}}], 
      LineBox[{{3.9204432308651374`, 1.3761777683192038`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}}], 
      LineBox[{{3.9204432308651374`, 1.3761777683192038`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}}], 
      LineBox[{{3.9204432308651374`, 1.3761777683192038`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6892944729860564`, 1.638707803899425}, {3.623985978677152, 
       1.7091618791055594`}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.8500700295178287`}, {3.6892944729860564`, 
       1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.623985978677152, 1.8500700295178287`}, {3.607941114414521, 
       1.779615954311694}, {3.623985978677152, 1.7091618791055594`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.8520011901291284`, 1.638707803899425}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.6892944729860564`, 
       1.638707803899425}, {3.6892944729860564`, 1.638707803899425}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.8520011901291284`, 
       1.638707803899425}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`,
        1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.9049937769264647`, 1.871401807069184}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}, {3.9049937769264647`, 1.871401807069184}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6892944729860564`, 1.638707803899425}, {3.623985978677152, 
       1.7091618791055594`}, {3.623985978677152, 1.7091618791055594`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}}], 
      LineBox[{{3.6892944729860564`, 1.638707803899425}, {3.623985978677152, 
       1.7091618791055594`}, {3.623985978677152, 1.7091618791055594`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}}], 
      LineBox[{{3.6892944729860564`, 1.638707803899425}, {3.623985978677152, 
       1.7091618791055594`}, {3.623985978677152, 1.7091618791055594`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}}], 
      LineBox[{{3.6892944729860564`, 1.638707803899425}, {3.623985978677152, 
       1.7091618791055594`}, {3.623985978677152, 1.7091618791055594`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}}], 
      LineBox[{{3.623985978677152, 1.7091618791055594`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}}], 
      LineBox[{{3.623985978677152, 1.7091618791055594`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}}], 
      LineBox[{{3.623985978677152, 1.7091618791055594`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}}], 
      LineBox[{{3.623985978677152, 1.7091618791055594`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}}], 
      LineBox[{{3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}], 
      LineBox[{{3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}], 
      LineBox[{{3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}], 
      LineBox[{{3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}], 
      LineBox[{{3.623985978677152, 1.8500700295178287`}, {3.6892944729860564`,
        1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}}], 
      LineBox[{{3.623985978677152, 1.8500700295178287`}, {3.6892944729860564`,
        1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}}], 
      LineBox[{{3.623985978677152, 1.8500700295178287`}, {3.6892944729860564`,
        1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}}], 
      LineBox[{{3.623985978677152, 1.8500700295178287`}, {3.6892944729860564`,
        1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}], 
      LineBox[{{3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}], 
      LineBox[{{3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}], 
      LineBox[{{3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}], 
      LineBox[{{3.9049937769264647`, 1.687830101554204}, {3.8520011901291284`,
        1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.9049937769264647`, 1.687830101554204}, {3.9049937769264647`, 
       1.687830101554204}}], 
      LineBox[{{3.9049937769264647`, 1.687830101554204}, {3.8520011901291284`,
        1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.9049937769264647`, 1.687830101554204}, {3.9049937769264647`, 
       1.687830101554204}}], 
      LineBox[{{3.9049937769264647`, 1.687830101554204}, {3.8520011901291284`,
        1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.9049937769264647`, 1.687830101554204}, {3.9049937769264647`, 
       1.687830101554204}}], 
      LineBox[{{3.9049937769264647`, 1.687830101554204}, {3.8520011901291284`,
        1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.9049937769264647`, 1.687830101554204}, {3.9049937769264647`, 
       1.687830101554204}}], 
      LineBox[{{3.8520011901291284`, 1.638707803899425}, {3.7829637390691606`,
        1.6173760263480697`}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}}], 
      LineBox[{{3.8520011901291284`, 1.638707803899425}, {3.7829637390691606`,
        1.6173760263480697`}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}}], 
      LineBox[{{3.8520011901291284`, 1.638707803899425}, {3.7829637390691606`,
        1.6173760263480697`}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}}], 
      LineBox[{{3.8520011901291284`, 1.638707803899425}, {3.7829637390691606`,
        1.6173760263480697`}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}}], 
      LineBox[{{3.7829637390691606`, 1.6173760263480697`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}}], 
      LineBox[{{3.7829637390691606`, 1.6173760263480697`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}}], 
      LineBox[{{3.7829637390691606`, 1.6173760263480697`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}}], 
      LineBox[{{3.7829637390691606`, 1.6173760263480697`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}], 
      LineBox[{{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}], 
      LineBox[{{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}], 
      LineBox[{{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}], 
      LineBox[{{3.7829637390691606`, 1.9418558822753185`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.7829637390691606`, 1.9418558822753185`}}], 
      LineBox[{{3.7829637390691606`, 1.9418558822753185`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.7829637390691606`, 1.9418558822753185`}}], 
      LineBox[{{3.7829637390691606`, 1.9418558822753185`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.7829637390691606`, 1.9418558822753185`}}], 
      LineBox[{{3.7829637390691606`, 1.9418558822753185`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.7829637390691606`, 1.9418558822753185`}}], 
      LineBox[{{3.8520011901291284`, 1.9205241047239632`}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}], 
      LineBox[{{3.8520011901291284`, 1.9205241047239632`}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}], 
      LineBox[{{3.8520011901291284`, 1.9205241047239632`}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}], 
      LineBox[{{3.8520011901291284`, 1.9205241047239632`}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}], 
      LineBox[{{3.9049937769264647`, 1.871401807069184}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}}], 
      LineBox[{{3.9049937769264647`, 1.871401807069184}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}}], 
      LineBox[{{3.9049937769264647`, 1.871401807069184}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}}], 
      LineBox[{{3.9049937769264647`, 1.871401807069184}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.635527855224726, 2.1030704834939313`}, {3.5826321970723845`,
        2.1601337295077805`}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.274260221535478}, {3.635527855224726, 
       2.331323467549327}, {3.635527855224726, 2.331323467549327}, {
       3.5826321970723845`, 2.274260221535478}, {3.569636894330867, 
       2.217196975521629}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.635527855224726, 2.1030704834939313`}, {3.635527855224726, 
       2.1030704834939313`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.7673097770124437`, 2.331323467549327}, {
       3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.7673097770124437`, 
       2.331323467549327}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`,
        2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.635527855224726, 2.1030704834939313`}, {3.5826321970723845`,
        2.1601337295077805`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.635527855224726, 2.1030704834939313`}, {3.635527855224726, 
       2.1030704834939313`}}], 
      LineBox[{{3.635527855224726, 2.1030704834939313`}, {3.5826321970723845`,
        2.1601337295077805`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.635527855224726, 2.1030704834939313`}, {3.635527855224726, 
       2.1030704834939313`}}], 
      LineBox[{{3.635527855224726, 2.1030704834939313`}, {3.5826321970723845`,
        2.1601337295077805`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.635527855224726, 2.1030704834939313`}, {3.635527855224726, 
       2.1030704834939313`}}], 
      LineBox[{{3.635527855224726, 2.1030704834939313`}, {3.5826321970723845`,
        2.1601337295077805`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.635527855224726, 2.1030704834939313`}, {3.635527855224726, 
       2.1030704834939313`}}], 
      LineBox[{{3.5826321970723845`, 2.1601337295077805`}, {3.569636894330867,
        2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}}], 
      LineBox[{{3.5826321970723845`, 2.1601337295077805`}, {3.569636894330867,
        2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}}], 
      LineBox[{{3.5826321970723845`, 2.1601337295077805`}, {3.569636894330867,
        2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}}], 
      LineBox[{{3.5826321970723845`, 2.1601337295077805`}, {3.569636894330867,
        2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}}], 
      LineBox[{{3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}], 
      LineBox[{{3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}], 
      LineBox[{{3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}], 
      LineBox[{{3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}], 
      LineBox[{{3.5826321970723845`, 2.274260221535478}, {3.6355278552247263`,
        2.331323467549327}, {3.6355278552247263`, 2.331323467549327}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}}], 
      LineBox[{{3.5826321970723845`, 2.274260221535478}, {3.6355278552247263`,
        2.331323467549327}, {3.6355278552247263`, 2.331323467549327}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}}], 
      LineBox[{{3.5826321970723845`, 2.274260221535478}, {3.6355278552247263`,
        2.331323467549327}, {3.6355278552247263`, 2.331323467549327}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}}], 
      LineBox[{{3.5826321970723845`, 2.274260221535478}, {3.6355278552247263`,
        2.331323467549327}, {3.6355278552247263`, 2.331323467549327}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}], 
      LineBox[{{3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}], 
      LineBox[{{3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}], 
      LineBox[{{3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}], 
      LineBox[{{3.8102303463120792`, 2.1428563688048796`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}}], 
      LineBox[{{3.8102303463120792`, 2.1428563688048796`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}}], 
      LineBox[{{3.8102303463120792`, 2.1428563688048796`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}}], 
      LineBox[{{3.8102303463120792`, 2.1428563688048796`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}}], 
      LineBox[{{3.7673097770124437`, 2.1030704834939313`}, {3.711393904971291,
        2.085793122791031}, {3.711393904971291, 2.085793122791031}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}}], 
      LineBox[{{3.7673097770124437`, 2.1030704834939313`}, {3.711393904971291,
        2.085793122791031}, {3.711393904971291, 2.085793122791031}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}}], 
      LineBox[{{3.7673097770124437`, 2.1030704834939313`}, {3.711393904971291,
        2.085793122791031}, {3.711393904971291, 2.085793122791031}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}}], 
      LineBox[{{3.7673097770124437`, 2.1030704834939313`}, {3.711393904971291,
        2.085793122791031}, {3.711393904971291, 2.085793122791031}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}}], 
      LineBox[{{3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}}], 
      LineBox[{{3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}}], 
      LineBox[{{3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}}], 
      LineBox[{{3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}], 
      LineBox[{{3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}], 
      LineBox[{{3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}], 
      LineBox[{{3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}], 
      LineBox[{{3.711393904971291, 2.3486008282522275`}, {3.7673097770124437`,
        2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}}], 
      LineBox[{{3.711393904971291, 2.3486008282522275`}, {3.7673097770124437`,
        2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}}], 
      LineBox[{{3.711393904971291, 2.3486008282522275`}, {3.7673097770124437`,
        2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}}], 
      LineBox[{{3.711393904971291, 2.3486008282522275`}, {3.7673097770124437`,
        2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}}], 
      LineBox[{{3.7673097770124437`, 2.331323467549327}, {3.8102303463120792`,
        2.291537582238379}, {3.8102303463120792`, 2.291537582238379}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}], 
      LineBox[{{3.7673097770124437`, 2.331323467549327}, {3.8102303463120792`,
        2.291537582238379}, {3.8102303463120792`, 2.291537582238379}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}], 
      LineBox[{{3.7673097770124437`, 2.331323467549327}, {3.8102303463120792`,
        2.291537582238379}, {3.8102303463120792`, 2.291537582238379}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}], 
      LineBox[{{3.7673097770124437`, 2.331323467549327}, {3.8102303463120792`,
        2.291537582238379}, {3.8102303463120792`, 2.291537582238379}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}], 
      LineBox[{{3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.8102303463120792`, 
       2.291537582238379}}], 
      LineBox[{{3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.8102303463120792`, 
       2.291537582238379}}], 
      LineBox[{{3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.8102303463120792`, 
       2.291537582238379}}], 
      LineBox[{{3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.8102303463120792`, 
       2.291537582238379}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7155755679839824`, 2.6521410778825736`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772, 
       2.766325146936083}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.847423973994404, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.847423973994404, 
       2.6521410778825736`}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631,
        2.8977952931528477`}, {3.847423973994404, 2.8805092159895924`}, {
       3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.847423973994404, 
       2.8805092159895924`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7155755679839824`, 2.6521410778825736`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}}], 
      LineBox[{{3.7155755679839824`, 2.6521410778825736`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}}], 
      LineBox[{{3.7155755679839824`, 2.6521410778825736`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}}], 
      LineBox[{{3.7155755679839824`, 2.6521410778825736`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}}], 
      LineBox[{{3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772,
        2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}}], 
      LineBox[{{3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772,
        2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}}], 
      LineBox[{{3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772,
        2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}}], 
      LineBox[{{3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772,
        2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}}], 
      LineBox[{{3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}], 
      LineBox[{{3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}], 
      LineBox[{{3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}], 
      LineBox[{{3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}], 
      LineBox[{{3.6626532238745013`, 2.8234171814628377`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.6626532238745013`, 2.8234171814628377`}}], 
      LineBox[{{3.6626532238745013`, 2.8234171814628377`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.6626532238745013`, 2.8234171814628377`}}], 
      LineBox[{{3.6626532238745013`, 2.8234171814628377`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.6626532238745013`, 2.8234171814628377`}}], 
      LineBox[{{3.6626532238745013`, 2.8234171814628377`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.6626532238745013`, 2.8234171814628377`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}], 
      LineBox[{{3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}], 
      LineBox[{{3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}], 
      LineBox[{{3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}], 
      LineBox[{{3.890366196800447, 2.691947035246073}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.890366196800447, 2.691947035246073}, {3.890366196800447, 
       2.691947035246073}}], 
      LineBox[{{3.890366196800447, 2.691947035246073}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.890366196800447, 2.691947035246073}, {3.890366196800447, 
       2.691947035246073}}], 
      LineBox[{{3.890366196800447, 2.691947035246073}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.890366196800447, 2.691947035246073}, {3.890366196800447, 
       2.691947035246073}}], 
      LineBox[{{3.890366196800447, 2.691947035246073}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.890366196800447, 2.691947035246073}, {3.890366196800447, 
       2.691947035246073}}], 
      LineBox[{{3.847423973994404, 2.6521410778825736`}, {3.791479892292631, 
       2.6348550007193183`}, {3.791479892292631, 2.6348550007193183`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}}], 
      LineBox[{{3.847423973994404, 2.6521410778825736`}, {3.791479892292631, 
       2.6348550007193183`}, {3.791479892292631, 2.6348550007193183`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}}], 
      LineBox[{{3.847423973994404, 2.6521410778825736`}, {3.791479892292631, 
       2.6348550007193183`}, {3.791479892292631, 2.6348550007193183`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}}], 
      LineBox[{{3.847423973994404, 2.6521410778825736`}, {3.791479892292631, 
       2.6348550007193183`}, {3.791479892292631, 2.6348550007193183`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}}], 
      LineBox[{{3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`,
        2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}}], 
      LineBox[{{3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`,
        2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}}], 
      LineBox[{{3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`,
        2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}}], 
      LineBox[{{3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`,
        2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631,
        2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}], 
      LineBox[{{3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631,
        2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}], 
      LineBox[{{3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631,
        2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}], 
      LineBox[{{3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631,
        2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}], 
      LineBox[{{3.791479892292631, 2.8977952931528477`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}}], 
      LineBox[{{3.791479892292631, 2.8977952931528477`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}}], 
      LineBox[{{3.791479892292631, 2.8977952931528477`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}}], 
      LineBox[{{3.791479892292631, 2.8977952931528477`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}}], 
      LineBox[{{3.847423973994404, 2.8805092159895924`}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}], 
      LineBox[{{3.847423973994404, 2.8805092159895924`}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}], 
      LineBox[{{3.847423973994404, 2.8805092159895924`}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}], 
      LineBox[{{3.847423973994404, 2.8805092159895924`}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}], 
      LineBox[{{3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.890366196800447, 
       2.840703258626093}}], 
      LineBox[{{3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.890366196800447, 
       2.840703258626093}}], 
      LineBox[{{3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.890366196800447, 
       2.840703258626093}}], 
      LineBox[{{3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.890366196800447, 
       2.840703258626093}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.696824065786324, 3.114339105657419}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6119376320388636`, 3.26136672178135}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.696824065786324, 
       3.408394337905281}, {3.696824065786324, 3.408394337905281}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.866596933281245, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.866596933281245, 
       3.114339105657419}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.866596933281245, 3.408394337905281}, {
       3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`, 
       3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.866596933281245, 
       3.408394337905281}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.696824065786324, 3.114339105657419}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}}], 
      LineBox[{{3.696824065786324, 3.114339105657419}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}}], 
      LineBox[{{3.696824065786324, 3.114339105657419}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}}], 
      LineBox[{{3.696824065786324, 3.114339105657419}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}}], 
      LineBox[{{3.6286793047999115`, 3.1878529137193845`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}}], 
      LineBox[{{3.6286793047999115`, 3.1878529137193845`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}}], 
      LineBox[{{3.6286793047999115`, 3.1878529137193845`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}}], 
      LineBox[{{3.6286793047999115`, 3.1878529137193845`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}}], 
      LineBox[{{3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}], 
      LineBox[{{3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}], 
      LineBox[{{3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}], 
      LineBox[{{3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}], 
      LineBox[{{3.6286793047999115`, 3.3348805298433155`}, {3.696824065786324,
        3.408394337905281}, {3.696824065786324, 3.408394337905281}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}}], 
      LineBox[{{3.6286793047999115`, 3.3348805298433155`}, {3.696824065786324,
        3.408394337905281}, {3.696824065786324, 3.408394337905281}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}}], 
      LineBox[{{3.6286793047999115`, 3.3348805298433155`}, {3.696824065786324,
        3.408394337905281}, {3.696824065786324, 3.408394337905281}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}}], 
      LineBox[{{3.6286793047999115`, 3.3348805298433155`}, {3.696824065786324,
        3.408394337905281}, {3.696824065786324, 3.408394337905281}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}], 
      LineBox[{{3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}], 
      LineBox[{{3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}], 
      LineBox[{{3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}], 
      LineBox[{{3.921890922211316, 3.1655947236013153`}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.921890922211316, 3.1655947236013153`}, {3.921890922211316, 
       3.1655947236013153`}}], 
      LineBox[{{3.921890922211316, 3.1655947236013153`}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.921890922211316, 3.1655947236013153`}, {3.921890922211316, 
       3.1655947236013153`}}], 
      LineBox[{{3.921890922211316, 3.1655947236013153`}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.921890922211316, 3.1655947236013153`}, {3.921890922211316, 
       3.1655947236013153`}}], 
      LineBox[{{3.921890922211316, 3.1655947236013153`}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.921890922211316, 3.1655947236013153`}, {3.921890922211316, 
       3.1655947236013153`}}], 
      LineBox[{{3.866596933281245, 3.114339105657419}, {3.7945612715901254`, 
       3.09208091553935}, {3.7945612715901254`, 3.09208091553935}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}}], 
      LineBox[{{3.866596933281245, 3.114339105657419}, {3.7945612715901254`, 
       3.09208091553935}, {3.7945612715901254`, 3.09208091553935}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}}], 
      LineBox[{{3.866596933281245, 3.114339105657419}, {3.7945612715901254`, 
       3.09208091553935}, {3.7945612715901254`, 3.09208091553935}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}}], 
      LineBox[{{3.866596933281245, 3.114339105657419}, {3.7945612715901254`, 
       3.09208091553935}, {3.7945612715901254`, 3.09208091553935}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}}], 
      LineBox[{{3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}}], 
      LineBox[{{3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}}], 
      LineBox[{{3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}}], 
      LineBox[{{3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}], 
      LineBox[{{3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}], 
      LineBox[{{3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}], 
      LineBox[{{3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}], 
      LineBox[{{3.7945612715901254`, 3.43065252802335}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}}], 
      LineBox[{{3.7945612715901254`, 3.43065252802335}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}}], 
      LineBox[{{3.7945612715901254`, 3.43065252802335}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}}], 
      LineBox[{{3.7945612715901254`, 3.43065252802335}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}}], 
      LineBox[{{3.866596933281245, 3.408394337905281}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}], 
      LineBox[{{3.866596933281245, 3.408394337905281}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}], 
      LineBox[{{3.866596933281245, 3.408394337905281}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}], 
      LineBox[{{3.866596933281245, 3.408394337905281}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}], 
      LineBox[{{3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`,
        3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.921890922211316, 
       3.3571387199613847`}}], 
      LineBox[{{3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`,
        3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.921890922211316, 
       3.3571387199613847`}}], 
      LineBox[{{3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`,
        3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.921890922211316, 
       3.3571387199613847`}}], 
      LineBox[{{3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`,
        3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.921890922211316, 
       3.3571387199613847`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7148601024473007`, 3.648248975358725}, {3.651995136994538, 
       3.716066998890101}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.8517030459528527`}, {3.7148601024473007`, 
       3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.651995136994538, 3.8517030459528527`}, {3.636550594163804, 
       3.783885022421477}, {3.651995136994538, 3.716066998890101}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.871479119014294, 3.648248975358725}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.7148601024473007`, 
       3.648248975358725}, {3.7148601024473007`, 3.648248975358725}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.871479119014294, 
       3.648248975358725}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.871479119014294, 
       3.9195210694842286`}, {3.922488978811549, 3.8722366912772883`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7148601024473007`, 3.648248975358725}, {3.651995136994538, 
       3.716066998890101}, {3.651995136994538, 3.716066998890101}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}}], 
      LineBox[{{3.7148601024473007`, 3.648248975358725}, {3.651995136994538, 
       3.716066998890101}, {3.651995136994538, 3.716066998890101}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}}], 
      LineBox[{{3.7148601024473007`, 3.648248975358725}, {3.651995136994538, 
       3.716066998890101}, {3.651995136994538, 3.716066998890101}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}}], 
      LineBox[{{3.7148601024473007`, 3.648248975358725}, {3.651995136994538, 
       3.716066998890101}, {3.651995136994538, 3.716066998890101}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}}], 
      LineBox[{{3.651995136994538, 3.716066998890101}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}}], 
      LineBox[{{3.651995136994538, 3.716066998890101}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}}], 
      LineBox[{{3.651995136994538, 3.716066998890101}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}}], 
      LineBox[{{3.651995136994538, 3.716066998890101}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}}], 
      LineBox[{{3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}], 
      LineBox[{{3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}], 
      LineBox[{{3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}], 
      LineBox[{{3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}], 
      LineBox[{{3.651995136994538, 3.8517030459528527`}, {3.7148601024473007`,
        3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}}], 
      LineBox[{{3.651995136994538, 3.8517030459528527`}, {3.7148601024473007`,
        3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}}], 
      LineBox[{{3.651995136994538, 3.8517030459528527`}, {3.7148601024473007`,
        3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}}], 
      LineBox[{{3.651995136994538, 3.8517030459528527`}, {3.7148601024473007`,
        3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}], 
      LineBox[{{3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}], 
      LineBox[{{3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}], 
      LineBox[{{3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}], 
      LineBox[{{3.922488978811549, 3.6955333535656654`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.922488978811549, 3.6955333535656654`}, {3.922488978811549, 
       3.6955333535656654`}}], 
      LineBox[{{3.922488978811549, 3.6955333535656654`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.922488978811549, 3.6955333535656654`}, {3.922488978811549, 
       3.6955333535656654`}}], 
      LineBox[{{3.922488978811549, 3.6955333535656654`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.922488978811549, 3.6955333535656654`}, {3.922488978811549, 
       3.6955333535656654`}}], 
      LineBox[{{3.922488978811549, 3.6955333535656654`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.922488978811549, 3.6955333535656654`}, {3.922488978811549, 
       3.6955333535656654`}}], 
      LineBox[{{3.871479119014294, 3.648248975358725}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}}], 
      LineBox[{{3.871479119014294, 3.648248975358725}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}}], 
      LineBox[{{3.871479119014294, 3.648248975358725}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}}], 
      LineBox[{{3.871479119014294, 3.648248975358725}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}}], 
      LineBox[{{3.8050247163863045`, 3.6277153300342895`}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}}], 
      LineBox[{{3.8050247163863045`, 3.6277153300342895`}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}}], 
      LineBox[{{3.8050247163863045`, 3.6277153300342895`}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}}], 
      LineBox[{{3.8050247163863045`, 3.6277153300342895`}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}], 
      LineBox[{{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}], 
      LineBox[{{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}], 
      LineBox[{{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}], 
      LineBox[{{3.8050247163863045`, 3.940054714808664}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}}], 
      LineBox[{{3.8050247163863045`, 3.940054714808664}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}}], 
      LineBox[{{3.8050247163863045`, 3.940054714808664}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}}], 
      LineBox[{{3.8050247163863045`, 3.940054714808664}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}}], 
      LineBox[{{3.871479119014294, 3.9195210694842286`}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}], 
      LineBox[{{3.871479119014294, 3.9195210694842286`}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}], 
      LineBox[{{3.871479119014294, 3.9195210694842286`}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}], 
      LineBox[{{3.871479119014294, 3.9195210694842286`}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}], 
      LineBox[{{3.922488978811549, 3.8722366912772883`}, {3.9497886272977905`,
        3.783885022421477}, {3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.8722366912772883`}, {3.922488978811549, 
       3.8722366912772883`}}], 
      LineBox[{{3.922488978811549, 3.8722366912772883`}, {3.9497886272977905`,
        3.783885022421477}, {3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.8722366912772883`}, {3.922488978811549, 
       3.8722366912772883`}}], 
      LineBox[{{3.922488978811549, 3.8722366912772883`}, {3.9497886272977905`,
        3.783885022421477}, {3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.8722366912772883`}, {3.922488978811549, 
       3.8722366912772883`}}], 
      LineBox[{{3.922488978811549, 3.8722366912772883`}, {3.9497886272977905`,
        3.783885022421477}, {3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.8722366912772883`}, {3.922488978811549, 
       3.8722366912772883`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}], 
      LineBox[{{3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}], 
      LineBox[{{3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}], 
      LineBox[{{3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}], 
      LineBox[{{3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}], 
      LineBox[{{3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}], 
      LineBox[{{3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}], 
      LineBox[{{3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}], 
      LineBox[{{3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}], 
      LineBox[{{3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}], 
      LineBox[{{3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}], 
      LineBox[{{3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}], 
      LineBox[{{3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}], 
      LineBox[{{3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}], 
      LineBox[{{3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}], 
      LineBox[{{3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}], 
      LineBox[{{4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}], 
      LineBox[{{4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}], 
      LineBox[{{4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}], 
      LineBox[{{4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}], 
      LineBox[{{4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}], 
      LineBox[{{4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}], 
      LineBox[{{4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}], 
      LineBox[{{4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}], 
      LineBox[{{4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}], 
      LineBox[{{4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}], 
      LineBox[{{4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}], 
      LineBox[{{4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}], 
      LineBox[{{4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}], 
      LineBox[{{4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}], 
      LineBox[{{4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}], 
      LineBox[{{3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}], 
      LineBox[{{3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}], 
      LineBox[{{3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}], 
      LineBox[{{4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}], 
      LineBox[{{4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}], 
      LineBox[{{4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}], 
      LineBox[{{4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}], 
      LineBox[{{4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}], 
      LineBox[{{4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}], 
      LineBox[{{4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}], 
      LineBox[{{4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}], 
      LineBox[{{4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}], 
      LineBox[{{4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}], 
      LineBox[{{4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}], 
      LineBox[{{4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}], 
      LineBox[{{3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}], 
      LineBox[{{3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}], 
      LineBox[{{3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}], 
      LineBox[{{3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}], 
      LineBox[{{3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}], 
      LineBox[{{3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}], 
      LineBox[{{3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}], 
      LineBox[{{3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}], 
      LineBox[{{3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}], 
      LineBox[{{3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}], 
      LineBox[{{3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}], 
      LineBox[{{3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}], 
      LineBox[{{3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}], 
      LineBox[{{3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}], 
      LineBox[{{3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}], 
      LineBox[{{4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}], 
      LineBox[{{4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}], 
      LineBox[{{4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}], 
      LineBox[{{4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}], 
      LineBox[{{4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}], 
      LineBox[{{4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}], 
      LineBox[{{4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}], 
      LineBox[{{4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}], 
      LineBox[{{4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}], 
      LineBox[{{4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}], 
      LineBox[{{4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}], 
      LineBox[{{4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}], 
      LineBox[{{4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}], 
      LineBox[{{4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}], 
      LineBox[{{4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}], 
      LineBox[{{3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}], 
      LineBox[{{3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}], 
      LineBox[{{3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}], 
      LineBox[{{4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}], 
      LineBox[{{4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}], 
      LineBox[{{4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}], 
      LineBox[{{4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}], 
      LineBox[{{4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}], 
      LineBox[{{4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}], 
      LineBox[{{4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}], 
      LineBox[{{4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}], 
      LineBox[{{4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}], 
      LineBox[{{4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}], 
      LineBox[{{4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}], 
      LineBox[{{4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}], 
      LineBox[{{3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}], 
      LineBox[{{3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}], 
      LineBox[{{3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}], 
      LineBox[{{3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}], 
      LineBox[{{3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}], 
      LineBox[{{3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}], 
      LineBox[{{3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}], 
      LineBox[{{3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}], 
      LineBox[{{3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}], 
      LineBox[{{3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}], 
      LineBox[{{3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}], 
      LineBox[{{3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}], 
      LineBox[{{3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}], 
      LineBox[{{3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}], 
      LineBox[{{3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}], 
      LineBox[{{4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}], 
      LineBox[{{4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}], 
      LineBox[{{4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}], 
      LineBox[{{4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}], 
      LineBox[{{4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}], 
      LineBox[{{4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}], 
      LineBox[{{4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}], 
      LineBox[{{4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}], 
      LineBox[{{4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}], 
      LineBox[{{4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}], 
      LineBox[{{4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}], 
      LineBox[{{4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}], 
      LineBox[{{4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}], 
      LineBox[{{4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}], 
      LineBox[{{4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}], 
      LineBox[{{3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}], 
      LineBox[{{3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}], 
      LineBox[{{3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}], 
      LineBox[{{4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}], 
      LineBox[{{4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}], 
      LineBox[{{4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}], 
      LineBox[{{4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}], 
      LineBox[{{4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}], 
      LineBox[{{4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}], 
      LineBox[{{4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}], 
      LineBox[{{4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}], 
      LineBox[{{4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}], 
      LineBox[{{4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}], 
      LineBox[{{4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}], 
      LineBox[{{4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}], 
      LineBox[{{3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}], 
      LineBox[{{3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}], 
      LineBox[{{3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}], 
      LineBox[{{3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}], 
      LineBox[{{3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}], 
      LineBox[{{3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}], 
      LineBox[{{3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}], 
      LineBox[{{3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}], 
      LineBox[{{3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}], 
      LineBox[{{3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}], 
      LineBox[{{3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}], 
      LineBox[{{3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}], 
      LineBox[{{3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}], 
      LineBox[{{3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}], 
      LineBox[{{3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}], 
      LineBox[{{4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}], 
      LineBox[{{4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}], 
      LineBox[{{4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}], 
      LineBox[{{4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}], 
      LineBox[{{4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}], 
      LineBox[{{4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}], 
      LineBox[{{4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}], 
      LineBox[{{4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}], 
      LineBox[{{4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}], 
      LineBox[{{4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}], 
      LineBox[{{4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}], 
      LineBox[{{4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}], 
      LineBox[{{4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}], 
      LineBox[{{4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}], 
      LineBox[{{4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}], 
      LineBox[{{3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}], 
      LineBox[{{3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}], 
      LineBox[{{3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}], 
      LineBox[{{4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}], 
      LineBox[{{4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}], 
      LineBox[{{4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}], 
      LineBox[{{4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}], 
      LineBox[{{4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}], 
      LineBox[{{4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}], 
      LineBox[{{4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}], 
      LineBox[{{4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}], 
      LineBox[{{4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}], 
      LineBox[{{4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}], 
      LineBox[{{4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}], 
      LineBox[{{4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.554629568923093}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}], 
      LineBox[{{3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}], 
      LineBox[{{3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}], 
      LineBox[{{3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}], 
      LineBox[{{3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}], 
      LineBox[{{3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}], 
      LineBox[{{3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}], 
      LineBox[{{3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}], 
      LineBox[{{3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}], 
      LineBox[{{3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}], 
      LineBox[{{3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}], 
      LineBox[{{3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}], 
      LineBox[{{3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}], 
      LineBox[{{3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}], 
      LineBox[{{3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}], 
      LineBox[{{3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}], 
      LineBox[{{4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}], 
      LineBox[{{4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}], 
      LineBox[{{4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}], 
      LineBox[{{4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}], 
      LineBox[{{4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}], 
      LineBox[{{4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}], 
      LineBox[{{4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}], 
      LineBox[{{4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}], 
      LineBox[{{4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}], 
      LineBox[{{4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}], 
      LineBox[{{4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}], 
      LineBox[{{3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}], 
      LineBox[{{3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}], 
      LineBox[{{3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}], 
      LineBox[{{3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}], 
      LineBox[{{3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}], 
      LineBox[{{3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}], 
      LineBox[{{3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}], 
      LineBox[{{3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}], 
      LineBox[{{3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}], 
      LineBox[{{3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}], 
      LineBox[{{3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}], 
      LineBox[{{4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}], 
      LineBox[{{4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}], 
      LineBox[{{4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}], 
      LineBox[{{4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}], 
      LineBox[{{4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}], 
      LineBox[{{4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}], 
      LineBox[{{4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}], 
      LineBox[{{4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.144868573454172}, {
       3.9121493648584376`, -2.144868573454172}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}], 
      LineBox[{{3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}], 
      LineBox[{{3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}], 
      LineBox[{{3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}], 
      LineBox[{{3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}], 
      LineBox[{{3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}], 
      LineBox[{{3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}], 
      LineBox[{{3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}], 
      LineBox[{{3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}], 
      LineBox[{{3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}], 
      LineBox[{{3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}], 
      LineBox[{{3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}], 
      LineBox[{{3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}], 
      LineBox[{{3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}], 
      LineBox[{{3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}], 
      LineBox[{{3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}], 
      LineBox[{{4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}], 
      LineBox[{{4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}], 
      LineBox[{{4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}], 
      LineBox[{{4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}], 
      LineBox[{{4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}], 
      LineBox[{{4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}], 
      LineBox[{{4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}], 
      LineBox[{{4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}], 
      LineBox[{{4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}], 
      LineBox[{{4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}], 
      LineBox[{{4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}], 
      LineBox[{{3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}], 
      LineBox[{{3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}], 
      LineBox[{{3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}], 
      LineBox[{{3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}], 
      LineBox[{{3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}], 
      LineBox[{{3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}], 
      LineBox[{{3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}], 
      LineBox[{{3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}], 
      LineBox[{{3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}], 
      LineBox[{{3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}], 
      LineBox[{{3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}], 
      LineBox[{{4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}], 
      LineBox[{{4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}], 
      LineBox[{{4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}], 
      LineBox[{{4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}], 
      LineBox[{{4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}], 
      LineBox[{{4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}], 
      LineBox[{{4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}], 
      LineBox[{{4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}], 
      LineBox[{{3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}], 
      LineBox[{{3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}], 
      LineBox[{{3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}], 
      LineBox[{{3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}], 
      LineBox[{{3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}], 
      LineBox[{{3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}], 
      LineBox[{{3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}], 
      LineBox[{{3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}], 
      LineBox[{{3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}], 
      LineBox[{{3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}], 
      LineBox[{{3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}], 
      LineBox[{{3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}], 
      LineBox[{{3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}], 
      LineBox[{{3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}], 
      LineBox[{{3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}], 
      LineBox[{{4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}], 
      LineBox[{{4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}], 
      LineBox[{{4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}], 
      LineBox[{{4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}], 
      LineBox[{{4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}], 
      LineBox[{{4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}], 
      LineBox[{{4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}], 
      LineBox[{{4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}], 
      LineBox[{{4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}], 
      LineBox[{{4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}], 
      LineBox[{{4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}], 
      LineBox[{{3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}], 
      LineBox[{{3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}], 
      LineBox[{{3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}], 
      LineBox[{{3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}], 
      LineBox[{{3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}], 
      LineBox[{{3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}], 
      LineBox[{{3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}], 
      LineBox[{{3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}], 
      LineBox[{{3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}], 
      LineBox[{{3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}], 
      LineBox[{{3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}], 
      LineBox[{{4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}], 
      LineBox[{{4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}], 
      LineBox[{{4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}], 
      LineBox[{{4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}], 
      LineBox[{{4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}], 
      LineBox[{{4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}], 
      LineBox[{{4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}], 
      LineBox[{{4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}], 
      LineBox[{{3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}], 
      LineBox[{{3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}], 
      LineBox[{{3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}], 
      LineBox[{{3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}], 
      LineBox[{{3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}], 
      LineBox[{{3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}], 
      LineBox[{{3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}], 
      LineBox[{{3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}], 
      LineBox[{{3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}], 
      LineBox[{{3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}], 
      LineBox[{{3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}], 
      LineBox[{{3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}], 
      LineBox[{{3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}], 
      LineBox[{{3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}], 
      LineBox[{{3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}], 
      LineBox[{{4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}], 
      LineBox[{{4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}], 
      LineBox[{{4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}], 
      LineBox[{{4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}], 
      LineBox[{{4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}], 
      LineBox[{{4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}], 
      LineBox[{{4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}], 
      LineBox[{{4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}], 
      LineBox[{{4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}], 
      LineBox[{{4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}], 
      LineBox[{{4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}], 
      LineBox[{{4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}], 
      LineBox[{{4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}], 
      LineBox[{{4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}], 
      LineBox[{{4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}], 
      LineBox[{{3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}], 
      LineBox[{{3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}], 
      LineBox[{{3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}], 
      LineBox[{{4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}], 
      LineBox[{{4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}], 
      LineBox[{{4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}], 
      LineBox[{{4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}], 
      LineBox[{{4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}], 
      LineBox[{{4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}], 
      LineBox[{{4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}], 
      LineBox[{{4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}], 
      LineBox[{{4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}], 
      LineBox[{{4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}], 
      LineBox[{{4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}], 
      LineBox[{{4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827628, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}], 
      LineBox[{{3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}], 
      LineBox[{{3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}], 
      LineBox[{{3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}], 
      LineBox[{{3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}], 
      LineBox[{{3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}], 
      LineBox[{{3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}], 
      LineBox[{{3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}], 
      LineBox[{{3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}], 
      LineBox[{{3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}], 
      LineBox[{{3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}], 
      LineBox[{{3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}], 
      LineBox[{{3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}], 
      LineBox[{{3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}], 
      LineBox[{{3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}], 
      LineBox[{{3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}], 
      LineBox[{{4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}], 
      LineBox[{{4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}], 
      LineBox[{{4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}], 
      LineBox[{{4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}], 
      LineBox[{{4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}], 
      LineBox[{{4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}], 
      LineBox[{{4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}], 
      LineBox[{{4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}], 
      LineBox[{{4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}], 
      LineBox[{{4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}], 
      LineBox[{{4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}], 
      LineBox[{{3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}], 
      LineBox[{{3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}], 
      LineBox[{{3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}], 
      LineBox[{{3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}], 
      LineBox[{{3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}], 
      LineBox[{{3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}], 
      LineBox[{{3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}], 
      LineBox[{{3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}], 
      LineBox[{{3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}], 
      LineBox[{{3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}], 
      LineBox[{{3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}], 
      LineBox[{{4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}], 
      LineBox[{{4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}], 
      LineBox[{{4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}], 
      LineBox[{{4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}], 
      LineBox[{{4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}], 
      LineBox[{{4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}], 
      LineBox[{{4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}], 
      LineBox[{{4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.1660644381081866}, {3.9460740047629037`, 
       0.1660644381081866}, {3.8809552149331346`, 0.0958150139781695}, {
       3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, -0.04468383428186476}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188187`}, {
       3.9460740047629037`, -0.11493325841188187`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 
       0.025565589848152364`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9460740047629037`, 0.16606443810818663`}, {
       4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.161146757371255, 0.11708482816944078`}, {
       4.189425148354193, 0.0255655898481524}, {4.189425148354193, 
       0.0255655898481524}, {4.161146757371255, 0.11708482816944078`}, {
       4.10830810049043, 0.1660644381081866}, {4.039471185575611, 
       0.18733425229945794`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}], 
      LineBox[{{3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}], 
      LineBox[{{3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}], 
      LineBox[{{3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}], 
      LineBox[{{3.8809552149331346`, -0.04468383428186473}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}], 
      LineBox[{{3.8809552149331346`, -0.04468383428186473}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}], 
      LineBox[{{3.8809552149331346`, -0.04468383428186473}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}], 
      LineBox[{{3.8809552149331346`, -0.04468383428186473}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}], 
      LineBox[{{3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8809552149331346`, 
       0.0958150139781695}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}}], 
      LineBox[{{3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8809552149331346`, 
       0.0958150139781695}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}}], 
      LineBox[{{3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8809552149331346`, 
       0.0958150139781695}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}}], 
      LineBox[{{3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8809552149331346`, 
       0.0958150139781695}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}}], 
      LineBox[{{3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.8809552149331346`, 0.09581501397816952}, {
       3.8809552149331346`, 0.09581501397816952}}], 
      LineBox[{{3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.8809552149331346`, 0.09581501397816952}, {
       3.8809552149331346`, 0.09581501397816952}}], 
      LineBox[{{3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.8809552149331346`, 0.09581501397816952}, {
       3.8809552149331346`, 0.09581501397816952}}], 
      LineBox[{{3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.8809552149331346`, 0.09581501397816952}, {
       3.8809552149331346`, 0.09581501397816952}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}], 
      LineBox[{{4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}], 
      LineBox[{{4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}], 
      LineBox[{{4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}], 
      LineBox[{{4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}], 
      LineBox[{{4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}], 
      LineBox[{{4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}], 
      LineBox[{{4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}], 
      LineBox[{{4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}], 
      LineBox[{{4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}], 
      LineBox[{{4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}], 
      LineBox[{{4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}], 
      LineBox[{{4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}], 
      LineBox[{{4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}], 
      LineBox[{{4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}], 
      LineBox[{{4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9460740047629037`, 0.16606443810818663`}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}}], 
      LineBox[{{3.9460740047629037`, 0.16606443810818663`}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}}], 
      LineBox[{{3.9460740047629037`, 0.16606443810818663`}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}}], 
      LineBox[{{3.9460740047629037`, 0.16606443810818663`}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}}], 
      LineBox[{{4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}}], 
      LineBox[{{4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}}], 
      LineBox[{{4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}}], 
      LineBox[{{4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}}], 
      LineBox[{{4.10830810049043, 0.1660644381081866}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}], 
      LineBox[{{4.10830810049043, 0.1660644381081866}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}], 
      LineBox[{{4.10830810049043, 0.1660644381081866}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}], 
      LineBox[{{4.10830810049043, 0.1660644381081866}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}], 
      LineBox[{{4.161146757371255, 0.11708482816944078`}, {4.189425148354193, 
       0.025565589848152354`}, {4.189425148354193, 0.025565589848152354`}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}}], 
      LineBox[{{4.161146757371255, 0.11708482816944078`}, {4.189425148354193, 
       0.025565589848152354`}, {4.189425148354193, 0.025565589848152354`}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}}], 
      LineBox[{{4.161146757371255, 0.11708482816944078`}, {4.189425148354193, 
       0.025565589848152354`}, {4.189425148354193, 0.025565589848152354`}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}}], 
      LineBox[{{4.161146757371255, 0.11708482816944078`}, {4.189425148354193, 
       0.025565589848152354`}, {4.189425148354193, 0.025565589848152354`}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9146358014357365`, 0.40214195501842886`}, {
       3.848274986486314, 0.47373126199391613`}, {3.831971590128944, 
       0.5453205689694034}, {3.848274986486314, 0.6169098759448907}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}, {3.848274986486314, 0.6169098759448907}, {
       3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.47373126199391613`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.45205576391962143`}, {4.079964224049322, 0.40214195501842886`}, {
       4.009814367390542, 0.38046645694413417`}, {3.9146358014357365`, 
       0.40214195501842886`}, {3.9146358014357365`, 0.40214195501842886`}, {
       4.009814367390542, 0.38046645694413417`}, {4.079964224049322, 
       0.40214195501842886`}, {4.133810684350731, 0.45205576391962143`}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9146358014357365`, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.079964224049322, 0.6884991829203779}, {
       4.133810684350731, 0.6385853740191854}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.6385853740191854}, {4.079964224049322, 
       0.6884991829203779}, {4.009814367390542, 0.7101746809946726}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9146358014357365`, 0.40214195501842886`}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}}], 
      LineBox[{{3.9146358014357365`, 0.40214195501842886`}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}}], 
      LineBox[{{3.9146358014357365`, 0.40214195501842886`}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}}], 
      LineBox[{{3.9146358014357365`, 0.40214195501842886`}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}}], 
      LineBox[{{3.848274986486314, 0.47373126199391613`}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}}], 
      LineBox[{{3.848274986486314, 0.47373126199391613`}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}}], 
      LineBox[{{3.848274986486314, 0.47373126199391613`}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}}], 
      LineBox[{{3.848274986486314, 0.47373126199391613`}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}}], 
      LineBox[{{3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.6169098759448907}, {3.848274986486314, 0.6169098759448907}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}}], 
      LineBox[{{3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.6169098759448907}, {3.848274986486314, 0.6169098759448907}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}}], 
      LineBox[{{3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.6169098759448907}, {3.848274986486314, 0.6169098759448907}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}}], 
      LineBox[{{3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.6169098759448907}, {3.848274986486314, 0.6169098759448907}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}}], 
      LineBox[{{3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}}], 
      LineBox[{{3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}}], 
      LineBox[{{3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}}], 
      LineBox[{{3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}}], 
      LineBox[{{4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}}], 
      LineBox[{{4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}}], 
      LineBox[{{4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}}], 
      LineBox[{{4.133810684350731, 0.45205576391962143`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}}], 
      LineBox[{{4.133810684350731, 0.45205576391962143`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}}], 
      LineBox[{{4.133810684350731, 0.45205576391962143`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}}], 
      LineBox[{{4.133810684350731, 0.45205576391962143`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}}], 
      LineBox[{{4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}], 
      LineBox[{{4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}], 
      LineBox[{{4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}], 
      LineBox[{{4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}], 
      LineBox[{{4.009814367390542, 0.38046645694413417`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}}], 
      LineBox[{{4.009814367390542, 0.38046645694413417`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}}], 
      LineBox[{{4.009814367390542, 0.38046645694413417`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}}], 
      LineBox[{{4.009814367390542, 0.38046645694413417`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9146358014357365`, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.009814367390542, 0.7101746809946726}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}}], 
      LineBox[{{3.9146358014357365`, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.009814367390542, 0.7101746809946726}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}}], 
      LineBox[{{3.9146358014357365`, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.009814367390542, 0.7101746809946726}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}}], 
      LineBox[{{3.9146358014357365`, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.009814367390542, 0.7101746809946726}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}}], 
      LineBox[{{4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}}], 
      LineBox[{{4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}}], 
      LineBox[{{4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}}], 
      LineBox[{{4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}}], 
      LineBox[{{4.079964224049322, 0.6884991829203779}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}}], 
      LineBox[{{4.079964224049322, 0.6884991829203779}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}}], 
      LineBox[{{4.079964224049322, 0.6884991829203779}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}}], 
      LineBox[{{4.079964224049322, 0.6884991829203779}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}}], 
      LineBox[{{4.133810684350731, 0.6385853740191854}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}}], 
      LineBox[{{4.133810684350731, 0.6385853740191854}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}}], 
      LineBox[{{4.133810684350731, 0.6385853740191854}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}}], 
      LineBox[{{4.133810684350731, 0.6385853740191854}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9548521886333052`, 0.9045553983786268}, {
       3.8912970408566845`, 0.9731179829026513}, {3.875682935370741, 
       1.0416805674266758`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`, 
       0.9731179829026513}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384,
        0.9523589026488359}, {4.113190695158433, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.113190695158433, 
       0.9045553983786268}, {4.164760582362384, 0.9523589026488359}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9548521886333052`, 1.1788057364747249`}, {4.046006702468539,
        1.1995648167285402`}, {4.113190695158433, 1.1788057364747249`}, {
       4.164760582362384, 1.1310022322045157`}, {4.1923599484209975`, 
       1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 1.1310022322045157`}, {4.113190695158433, 
       1.1788057364747249`}, {4.046006702468539, 1.1995648167285402`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9548521886333052`, 0.9045553983786268}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}}], 
      LineBox[{{3.9548521886333052`, 0.9045553983786268}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}}], 
      LineBox[{{3.9548521886333052`, 0.9045553983786268}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}}], 
      LineBox[{{3.9548521886333052`, 0.9045553983786268}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}}], 
      LineBox[{{3.8912970408566845`, 0.9731179829026513}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}}], 
      LineBox[{{3.8912970408566845`, 0.9731179829026513}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}}], 
      LineBox[{{3.8912970408566845`, 0.9731179829026513}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}}], 
      LineBox[{{3.8912970408566845`, 0.9731179829026513}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}}], 
      LineBox[{{3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`,
        1.1102431519507003`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}}], 
      LineBox[{{3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`,
        1.1102431519507003`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}}], 
      LineBox[{{3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`,
        1.1102431519507003`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}}], 
      LineBox[{{3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`,
        1.1102431519507003`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}}], 
      LineBox[{{3.8912970408566845`, 1.1102431519507003`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}}], 
      LineBox[{{3.8912970408566845`, 1.1102431519507003`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}}], 
      LineBox[{{3.8912970408566845`, 1.1102431519507003`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}}], 
      LineBox[{{3.8912970408566845`, 1.1102431519507003`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384,
        0.9523589026488359}, {4.164760582362384, 0.9523589026488359}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}}], 
      LineBox[{{4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384,
        0.9523589026488359}, {4.164760582362384, 0.9523589026488359}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}}], 
      LineBox[{{4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384,
        0.9523589026488359}, {4.164760582362384, 0.9523589026488359}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}}], 
      LineBox[{{4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384,
        0.9523589026488359}, {4.164760582362384, 0.9523589026488359}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}}], 
      LineBox[{{4.164760582362384, 0.9523589026488359}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}}], 
      LineBox[{{4.164760582362384, 0.9523589026488359}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}}], 
      LineBox[{{4.164760582362384, 0.9523589026488359}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}}], 
      LineBox[{{4.164760582362384, 0.9523589026488359}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}}], 
      LineBox[{{4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}], 
      LineBox[{{4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}], 
      LineBox[{{4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}], 
      LineBox[{{4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}], 
      LineBox[{{4.046006702468539, 0.8837963181248114}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.046006702468539, 
       0.8837963181248114}}], 
      LineBox[{{4.046006702468539, 0.8837963181248114}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.046006702468539, 
       0.8837963181248114}}], 
      LineBox[{{4.046006702468539, 0.8837963181248114}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.046006702468539, 
       0.8837963181248114}}], 
      LineBox[{{4.046006702468539, 0.8837963181248114}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.046006702468539, 
       0.8837963181248114}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9548521886333052`, 1.1788057364747249`}, {4.046006702468539,
        1.1995648167285402`}, {4.046006702468539, 1.1995648167285402`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}}], 
      LineBox[{{3.9548521886333052`, 1.1788057364747249`}, {4.046006702468539,
        1.1995648167285402`}, {4.046006702468539, 1.1995648167285402`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}}], 
      LineBox[{{3.9548521886333052`, 1.1788057364747249`}, {4.046006702468539,
        1.1995648167285402`}, {4.046006702468539, 1.1995648167285402`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}}], 
      LineBox[{{3.9548521886333052`, 1.1788057364747249`}, {4.046006702468539,
        1.1995648167285402`}, {4.046006702468539, 1.1995648167285402`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}}], 
      LineBox[{{4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}}], 
      LineBox[{{4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}}], 
      LineBox[{{4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}}], 
      LineBox[{{4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}}], 
      LineBox[{{4.113190695158433, 1.1788057364747249`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}}], 
      LineBox[{{4.113190695158433, 1.1788057364747249`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}}], 
      LineBox[{{4.113190695158433, 1.1788057364747249`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}}], 
      LineBox[{{4.113190695158433, 1.1788057364747249`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}}], 
      LineBox[{{4.164760582362384, 1.1310022322045157`}, {4.1923599484209975`,
        1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}}], 
      LineBox[{{4.164760582362384, 1.1310022322045157`}, {4.1923599484209975`,
        1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}}], 
      LineBox[{{4.164760582362384, 1.1310022322045157`}, {4.1923599484209975`,
        1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}}], 
      LineBox[{{4.164760582362384, 1.1310022322045157`}, {4.1923599484209975`,
        1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9420879018335357`, 1.3649729363001064`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8823889919002466`, 
       1.429375454451421}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`,
        1.4098759409466104`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {3.9420879018335357`, 
       1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9420879018335357`, 1.6225830089053643`}, {4.027711573586907,
        1.642082522410175}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.165184768980443, 
       1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.027711573586907, 1.642082522410175}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9420879018335357`, 1.3649729363001064`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}}], 
      LineBox[{{3.9420879018335357`, 1.3649729363001064`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}}], 
      LineBox[{{3.9420879018335357`, 1.3649729363001064`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}}], 
      LineBox[{{3.9420879018335357`, 1.3649729363001064`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}}], 
      LineBox[{{3.8823889919002466`, 1.429375454451421}, {3.8677222794512334`,
        1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}}], 
      LineBox[{{3.8823889919002466`, 1.429375454451421}, {3.8677222794512334`,
        1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}}], 
      LineBox[{{3.8823889919002466`, 1.429375454451421}, {3.8677222794512334`,
        1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}}], 
      LineBox[{{3.8823889919002466`, 1.429375454451421}, {3.8677222794512334`,
        1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}}], 
      LineBox[{{3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}], 
      LineBox[{{3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}], 
      LineBox[{{3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}], 
      LineBox[{{3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}], 
      LineBox[{{3.8823889919002466`, 1.5581804907540497`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}}], 
      LineBox[{{3.8823889919002466`, 1.5581804907540497`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}}], 
      LineBox[{{3.8823889919002466`, 1.5581804907540497`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}}], 
      LineBox[{{3.8823889919002466`, 1.5581804907540497`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`,
        1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}}], 
      LineBox[{{4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`,
        1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}}], 
      LineBox[{{4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`,
        1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}}], 
      LineBox[{{4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`,
        1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}}], 
      LineBox[{{4.1392600071603605`, 1.4098759409466104`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.1392600071603605`, 1.4098759409466104`}}], 
      LineBox[{{4.1392600071603605`, 1.4098759409466104`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.1392600071603605`, 1.4098759409466104`}}], 
      LineBox[{{4.1392600071603605`, 1.4098759409466104`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.1392600071603605`, 1.4098759409466104`}}], 
      LineBox[{{4.1392600071603605`, 1.4098759409466104`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.1392600071603605`, 1.4098759409466104`}}], 
      LineBox[{{4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907,
        1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}], 
      LineBox[{{4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907,
        1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}], 
      LineBox[{{4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907,
        1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}], 
      LineBox[{{4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907,
        1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}], 
      LineBox[{{4.027711573586907, 1.3454734227952958`}, {3.9420879018335357`,
        1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.027711573586907, 
       1.3454734227952958`}}], 
      LineBox[{{4.027711573586907, 1.3454734227952958`}, {3.9420879018335357`,
        1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.027711573586907, 
       1.3454734227952958`}}], 
      LineBox[{{4.027711573586907, 1.3454734227952958`}, {3.9420879018335357`,
        1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.027711573586907, 
       1.3454734227952958`}}], 
      LineBox[{{4.027711573586907, 1.3454734227952958`}, {3.9420879018335357`,
        1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.027711573586907, 
       1.3454734227952958`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9420879018335357`, 1.6225830089053643`}, {4.027711573586907,
        1.642082522410175}, {4.027711573586907, 1.642082522410175}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}}], 
      LineBox[{{3.9420879018335357`, 1.6225830089053643`}, {4.027711573586907,
        1.642082522410175}, {4.027711573586907, 1.642082522410175}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}}], 
      LineBox[{{3.9420879018335357`, 1.6225830089053643`}, {4.027711573586907,
        1.642082522410175}, {4.027711573586907, 1.642082522410175}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}}], 
      LineBox[{{3.9420879018335357`, 1.6225830089053643`}, {4.027711573586907,
        1.642082522410175}, {4.027711573586907, 1.642082522410175}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}}], 
      LineBox[{{4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}}], 
      LineBox[{{4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}}], 
      LineBox[{{4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}}], 
      LineBox[{{4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}}], 
      LineBox[{{4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}], 
      LineBox[{{4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}], 
      LineBox[{{4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}], 
      LineBox[{{4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}], 
      LineBox[{{4.1392600071603605`, 1.5776800042588603`}, {4.165184768980443,
        1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}}], 
      LineBox[{{4.1392600071603605`, 1.5776800042588603`}, {4.165184768980443,
        1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}}], 
      LineBox[{{4.1392600071603605`, 1.5776800042588603`}, {4.165184768980443,
        1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}}], 
      LineBox[{{4.1392600071603605`, 1.5776800042588603`}, {4.165184768980443,
        1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9566161923789354`, 1.8307520142789462`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.873543787256683, 
       1.9746376406576325`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.9566161923789354`, 2.118523267036319}, {3.9566161923789354`, 
       2.118523267036319}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       1.8809122963246523`}, {4.122761002623441, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {3.956616192378936, 
       1.8307520142789462`}, {3.956616192378936, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.122761002623441, 
       1.8307520142789462`}, {4.176873355403977, 1.8809122963246523`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.956616192378936, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.122761002623441, 2.118523267036319}, {
       4.176873355403977, 2.0683629849906127`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 2.0683629849906127`}, {4.122761002623441, 
       2.118523267036319}, {4.052264747720598, 2.140305798179956}, {
       3.956616192378936, 2.118523267036319}, {3.956616192378936, 
       2.118523267036319}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9566161923789354`, 1.8307520142789462`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}}], 
      LineBox[{{3.9566161923789354`, 1.8307520142789462`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}}], 
      LineBox[{{3.9566161923789354`, 1.8307520142789462`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}}], 
      LineBox[{{3.9566161923789354`, 1.8307520142789462`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}}], 
      LineBox[{{3.8899276893789887`, 1.9026948274682893`}, {3.873543787256683,
        1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}}], 
      LineBox[{{3.8899276893789887`, 1.9026948274682893`}, {3.873543787256683,
        1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}}], 
      LineBox[{{3.8899276893789887`, 1.9026948274682893`}, {3.873543787256683,
        1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}}], 
      LineBox[{{3.8899276893789887`, 1.9026948274682893`}, {3.873543787256683,
        1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}}], 
      LineBox[{{3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`,
        2.0465804538469756`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}}], 
      LineBox[{{3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`,
        2.0465804538469756`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}}], 
      LineBox[{{3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`,
        2.0465804538469756`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}}], 
      LineBox[{{3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`,
        2.0465804538469756`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}}], 
      LineBox[{{3.8899276893789887`, 2.0465804538469756`}, {
       3.9566161923789354`, 2.118523267036319}, {3.9566161923789354`, 
       2.118523267036319}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}}], 
      LineBox[{{3.8899276893789887`, 2.0465804538469756`}, {
       3.9566161923789354`, 2.118523267036319}, {3.9566161923789354`, 
       2.118523267036319}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}}], 
      LineBox[{{3.8899276893789887`, 2.0465804538469756`}, {
       3.9566161923789354`, 2.118523267036319}, {3.9566161923789354`, 
       2.118523267036319}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}}], 
      LineBox[{{3.8899276893789887`, 2.0465804538469756`}, {
       3.9566161923789354`, 2.118523267036319}, {3.9566161923789354`, 
       2.118523267036319}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}}], 
      LineBox[{{4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}}], 
      LineBox[{{4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}}], 
      LineBox[{{4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}}], 
      LineBox[{{4.176873355403977, 1.8809122963246523`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}}], 
      LineBox[{{4.176873355403977, 1.8809122963246523`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}}], 
      LineBox[{{4.176873355403977, 1.8809122963246523`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}}], 
      LineBox[{{4.176873355403977, 1.8809122963246523`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}}], 
      LineBox[{{4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}], 
      LineBox[{{4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}], 
      LineBox[{{4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}], 
      LineBox[{{4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}], 
      LineBox[{{4.052264747720598, 1.808969483135309}, {3.9566161923789354`, 
       1.8307520142789462`}, {3.9566161923789354`, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.052264747720598, 
       1.808969483135309}}], 
      LineBox[{{4.052264747720598, 1.808969483135309}, {3.9566161923789354`, 
       1.8307520142789462`}, {3.9566161923789354`, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.052264747720598, 
       1.808969483135309}}], 
      LineBox[{{4.052264747720598, 1.808969483135309}, {3.9566161923789354`, 
       1.8307520142789462`}, {3.9566161923789354`, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.052264747720598, 
       1.808969483135309}}], 
      LineBox[{{4.052264747720598, 1.808969483135309}, {3.9566161923789354`, 
       1.8307520142789462`}, {3.9566161923789354`, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.052264747720598, 
       1.808969483135309}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.956616192378936, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.052264747720598, 2.140305798179956}, {
       3.956616192378936, 2.118523267036319}, {3.956616192378936, 
       2.118523267036319}}], 
      LineBox[{{3.956616192378936, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.052264747720598, 2.140305798179956}, {
       3.956616192378936, 2.118523267036319}, {3.956616192378936, 
       2.118523267036319}}], 
      LineBox[{{3.956616192378936, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.052264747720598, 2.140305798179956}, {
       3.956616192378936, 2.118523267036319}, {3.956616192378936, 
       2.118523267036319}}], 
      LineBox[{{3.956616192378936, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.052264747720598, 2.140305798179956}, {
       3.956616192378936, 2.118523267036319}, {3.956616192378936, 
       2.118523267036319}}], 
      LineBox[{{4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}}], 
      LineBox[{{4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}}], 
      LineBox[{{4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}}], 
      LineBox[{{4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}}], 
      LineBox[{{4.122761002623441, 2.118523267036319}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}}], 
      LineBox[{{4.122761002623441, 2.118523267036319}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}}], 
      LineBox[{{4.122761002623441, 2.118523267036319}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}}], 
      LineBox[{{4.122761002623441, 2.118523267036319}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}}], 
      LineBox[{{4.176873355403977, 2.0683629849906127`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}}], 
      LineBox[{{4.176873355403977, 2.0683629849906127`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}}], 
      LineBox[{{4.176873355403977, 2.0683629849906127`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}}], 
      LineBox[{{4.176873355403977, 2.0683629849906127`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9383834009412166`, 2.3637752100298126`}, {
       3.8703583872564233`, 2.437159836038459}, {3.8536461337802725`, 
       2.510544462047106}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`, 
       2.437159836038459}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`,
        2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.4149407590989673`}, {4.107857935263105, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {3.9383834009412166`, 
       2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.107857935263105, 
       2.3637752100298126`}, {4.163054758895738, 2.4149407590989673`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9383834009412166`, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.107857935263105, 2.657313714064399}, {
       4.163054758895738, 2.6061481649952443`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.6061481649952443`}, {4.107857935263105, 
       2.657313714064399}, {4.035948858154321, 2.679532791003891}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9383834009412166`, 2.3637752100298126`}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}}], 
      LineBox[{{3.9383834009412166`, 2.3637752100298126`}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}}], 
      LineBox[{{3.9383834009412166`, 2.3637752100298126`}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}}], 
      LineBox[{{3.9383834009412166`, 2.3637752100298126`}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}}], 
      LineBox[{{3.8703583872564233`, 2.437159836038459}, {3.8536461337802725`,
        2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}}], 
      LineBox[{{3.8703583872564233`, 2.437159836038459}, {3.8536461337802725`,
        2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}}], 
      LineBox[{{3.8703583872564233`, 2.437159836038459}, {3.8536461337802725`,
        2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}}], 
      LineBox[{{3.8703583872564233`, 2.437159836038459}, {3.8536461337802725`,
        2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}}], 
      LineBox[{{3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`,
        2.5839290880557524`}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}}], 
      LineBox[{{3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`,
        2.5839290880557524`}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}}], 
      LineBox[{{3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`,
        2.5839290880557524`}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}}], 
      LineBox[{{3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`,
        2.5839290880557524`}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}}], 
      LineBox[{{3.8703583872564233`, 2.5839290880557524`}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}}], 
      LineBox[{{3.8703583872564233`, 2.5839290880557524`}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}}], 
      LineBox[{{3.8703583872564233`, 2.5839290880557524`}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}}], 
      LineBox[{{3.8703583872564233`, 2.5839290880557524`}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}}], 
      LineBox[{{4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}}], 
      LineBox[{{4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}}], 
      LineBox[{{4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}}], 
      LineBox[{{4.163054758895738, 2.4149407590989673`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}}], 
      LineBox[{{4.163054758895738, 2.4149407590989673`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}}], 
      LineBox[{{4.163054758895738, 2.4149407590989673`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}}], 
      LineBox[{{4.163054758895738, 2.4149407590989673`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}}], 
      LineBox[{{4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}], 
      LineBox[{{4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}], 
      LineBox[{{4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}], 
      LineBox[{{4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}], 
      LineBox[{{4.035948858154321, 2.3415561330903207`}, {3.9383834009412166`,
        2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.035948858154321, 
       2.3415561330903207`}}], 
      LineBox[{{4.035948858154321, 2.3415561330903207`}, {3.9383834009412166`,
        2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.035948858154321, 
       2.3415561330903207`}}], 
      LineBox[{{4.035948858154321, 2.3415561330903207`}, {3.9383834009412166`,
        2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.035948858154321, 
       2.3415561330903207`}}], 
      LineBox[{{4.035948858154321, 2.3415561330903207`}, {3.9383834009412166`,
        2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.035948858154321, 
       2.3415561330903207`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9383834009412166`, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.035948858154321, 2.679532791003891}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}}], 
      LineBox[{{3.9383834009412166`, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.035948858154321, 2.679532791003891}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}}], 
      LineBox[{{3.9383834009412166`, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.035948858154321, 2.679532791003891}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}}], 
      LineBox[{{3.9383834009412166`, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.035948858154321, 2.679532791003891}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}}], 
      LineBox[{{4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}}], 
      LineBox[{{4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}}], 
      LineBox[{{4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}}], 
      LineBox[{{4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}}], 
      LineBox[{{4.107857935263105, 2.657313714064399}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}}], 
      LineBox[{{4.107857935263105, 2.657313714064399}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}}], 
      LineBox[{{4.107857935263105, 2.657313714064399}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}}], 
      LineBox[{{4.107857935263105, 2.657313714064399}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}}], 
      LineBox[{{4.163054758895738, 2.6061481649952443`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}}], 
      LineBox[{{4.163054758895738, 2.6061481649952443`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}}], 
      LineBox[{{4.163054758895738, 2.6061481649952443`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}}], 
      LineBox[{{4.163054758895738, 2.6061481649952443`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8884503960691674`, 2.8512649149400016`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.822526193063957, 
       2.965448983993511}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       2.891070872303501}, {4.020298802079589, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.8884503960691674`, 
       2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {4.020298802079589, 
       2.8512649149400016`}, {4.063241024885632, 2.891070872303501}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8884503960691674`, 3.0796330530470204`}, {3.964354720377816,
        3.0969191302102757`}, {4.020298802079589, 3.0796330530470204`}, {
       4.063241024885632, 3.039827095683521}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 3.039827095683521}, {4.020298802079589, 
       3.0796330530470204`}, {3.964354720377816, 3.0969191302102757`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8884503960691674`, 2.8512649149400016`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}}], 
      LineBox[{{3.8884503960691674`, 2.8512649149400016`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}}], 
      LineBox[{{3.8884503960691674`, 2.8512649149400016`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}}], 
      LineBox[{{3.8884503960691674`, 2.8512649149400016`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}}], 
      LineBox[{{3.8355280519596864`, 2.9083569494667563`}, {3.822526193063957,
        2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}}], 
      LineBox[{{3.8355280519596864`, 2.9083569494667563`}, {3.822526193063957,
        2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}}], 
      LineBox[{{3.8355280519596864`, 2.9083569494667563`}, {3.822526193063957,
        2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}}], 
      LineBox[{{3.8355280519596864`, 2.9083569494667563`}, {3.822526193063957,
        2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}}], 
      LineBox[{{3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}}], 
      LineBox[{{3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}}], 
      LineBox[{{3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}}], 
      LineBox[{{3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}}], 
      LineBox[{{3.8355280519596864`, 3.0225410185202657`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}}], 
      LineBox[{{3.8355280519596864`, 3.0225410185202657`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}}], 
      LineBox[{{3.8355280519596864`, 3.0225410185202657`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}}], 
      LineBox[{{3.8355280519596864`, 3.0225410185202657`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}}], 
      LineBox[{{4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}}], 
      LineBox[{{4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}}], 
      LineBox[{{4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}}], 
      LineBox[{{4.063241024885632, 2.891070872303501}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}}], 
      LineBox[{{4.063241024885632, 2.891070872303501}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}}], 
      LineBox[{{4.063241024885632, 2.891070872303501}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}}], 
      LineBox[{{4.063241024885632, 2.891070872303501}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}}], 
      LineBox[{{4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}], 
      LineBox[{{4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}], 
      LineBox[{{4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}], 
      LineBox[{{4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}], 
      LineBox[{{3.964354720377816, 2.8339788377767463`}, {3.8884503960691674`,
        2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.964354720377816, 
       2.8339788377767463`}}], 
      LineBox[{{3.964354720377816, 2.8339788377767463`}, {3.8884503960691674`,
        2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.964354720377816, 
       2.8339788377767463`}}], 
      LineBox[{{3.964354720377816, 2.8339788377767463`}, {3.8884503960691674`,
        2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.964354720377816, 
       2.8339788377767463`}}], 
      LineBox[{{3.964354720377816, 2.8339788377767463`}, {3.8884503960691674`,
        2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.964354720377816, 
       2.8339788377767463`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8884503960691674`, 3.0796330530470204`}, {3.964354720377816,
        3.0969191302102757`}, {3.964354720377816, 3.0969191302102757`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}}], 
      LineBox[{{3.8884503960691674`, 3.0796330530470204`}, {3.964354720377816,
        3.0969191302102757`}, {3.964354720377816, 3.0969191302102757`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}}], 
      LineBox[{{3.8884503960691674`, 3.0796330530470204`}, {3.964354720377816,
        3.0969191302102757`}, {3.964354720377816, 3.0969191302102757`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}}], 
      LineBox[{{3.8884503960691674`, 3.0796330530470204`}, {3.964354720377816,
        3.0969191302102757`}, {3.964354720377816, 3.0969191302102757`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}}], 
      LineBox[{{3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}}], 
      LineBox[{{3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}}], 
      LineBox[{{3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}}], 
      LineBox[{{3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}}], 
      LineBox[{{4.020298802079589, 3.0796330530470204`}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}}], 
      LineBox[{{4.020298802079589, 3.0796330530470204`}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}}], 
      LineBox[{{4.020298802079589, 3.0796330530470204`}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}}], 
      LineBox[{{4.020298802079589, 3.0796330530470204`}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}}], 
      LineBox[{{4.063241024885632, 3.039827095683521}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}}], 
      LineBox[{{4.063241024885632, 3.039827095683521}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}}], 
      LineBox[{{4.063241024885632, 3.039827095683521}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}}], 
      LineBox[{{4.063241024885632, 3.039827095683521}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084,
        3.4804938366968705`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223,
        3.461149312750143}, {4.068829127886373, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {3.9212800556869225`, 
       3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.068829127886373, 
       3.4166032142820963`}, {4.116884962044223, 3.461149312750143}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9212800556869225`, 3.672165703941192}, {4.0062231578946355`,
        3.6915102278879193`}, {4.068829127886373, 3.672165703941192}, {
       4.116884962044223, 3.6276196054731455`}, {4.1426036639860975`, 
       3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.6276196054731455`}, {4.068829127886373, 
       3.672165703941192}, {4.0062231578946355`, 3.6915102278879193`}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084,
        3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}], 
      LineBox[{{3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084,
        3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}], 
      LineBox[{{3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084,
        3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}], 
      LineBox[{{3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084,
        3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}], 
      LineBox[{{3.862055655421084, 3.4804938366968705`}, {3.8475055195871977`,
        3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.4804938366968705`}, {3.862055655421084, 
       3.4804938366968705`}}], 
      LineBox[{{3.862055655421084, 3.4804938366968705`}, {3.8475055195871977`,
        3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.4804938366968705`}, {3.862055655421084, 
       3.4804938366968705`}}], 
      LineBox[{{3.862055655421084, 3.4804938366968705`}, {3.8475055195871977`,
        3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.4804938366968705`}, {3.862055655421084, 
       3.4804938366968705`}}], 
      LineBox[{{3.862055655421084, 3.4804938366968705`}, {3.8475055195871977`,
        3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.4804938366968705`}, {3.862055655421084, 
       3.4804938366968705`}}], 
      LineBox[{{3.8475055195871977`, 3.5443844591116442`}, {3.862055655421084,
        3.608275081526418}, {3.862055655421084, 3.608275081526418}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}}], 
      LineBox[{{3.8475055195871977`, 3.5443844591116442`}, {3.862055655421084,
        3.608275081526418}, {3.862055655421084, 3.608275081526418}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}}], 
      LineBox[{{3.8475055195871977`, 3.5443844591116442`}, {3.862055655421084,
        3.608275081526418}, {3.862055655421084, 3.608275081526418}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}}], 
      LineBox[{{3.8475055195871977`, 3.5443844591116442`}, {3.862055655421084,
        3.608275081526418}, {3.862055655421084, 3.608275081526418}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}}], 
      LineBox[{{3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}}], 
      LineBox[{{3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}}], 
      LineBox[{{3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}}], 
      LineBox[{{3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223,
        3.461149312750143}, {4.116884962044223, 3.461149312750143}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}}], 
      LineBox[{{4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223,
        3.461149312750143}, {4.116884962044223, 3.461149312750143}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}}], 
      LineBox[{{4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223,
        3.461149312750143}, {4.116884962044223, 3.461149312750143}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}}], 
      LineBox[{{4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223,
        3.461149312750143}, {4.116884962044223, 3.461149312750143}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}}], 
      LineBox[{{4.116884962044223, 3.461149312750143}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}}], 
      LineBox[{{4.116884962044223, 3.461149312750143}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}}], 
      LineBox[{{4.116884962044223, 3.461149312750143}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}}], 
      LineBox[{{4.116884962044223, 3.461149312750143}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}}], 
      LineBox[{{4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`,
        3.397258690335369}, {4.0062231578946355`, 3.397258690335369}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}], 
      LineBox[{{4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`,
        3.397258690335369}, {4.0062231578946355`, 3.397258690335369}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}], 
      LineBox[{{4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`,
        3.397258690335369}, {4.0062231578946355`, 3.397258690335369}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}], 
      LineBox[{{4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`,
        3.397258690335369}, {4.0062231578946355`, 3.397258690335369}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}], 
      LineBox[{{4.0062231578946355`, 3.397258690335369}, {3.9212800556869225`,
        3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.0062231578946355`, 
       3.397258690335369}}], 
      LineBox[{{4.0062231578946355`, 3.397258690335369}, {3.9212800556869225`,
        3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.0062231578946355`, 
       3.397258690335369}}], 
      LineBox[{{4.0062231578946355`, 3.397258690335369}, {3.9212800556869225`,
        3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.0062231578946355`, 
       3.397258690335369}}], 
      LineBox[{{4.0062231578946355`, 3.397258690335369}, {3.9212800556869225`,
        3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.0062231578946355`, 
       3.397258690335369}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{3.9212800556869225`, 3.672165703941192}, {4.0062231578946355`,
        3.6915102278879193`}, {4.0062231578946355`, 3.6915102278879193`}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}}], 
      LineBox[{{3.9212800556869225`, 3.672165703941192}, {4.0062231578946355`,
        3.6915102278879193`}, {4.0062231578946355`, 3.6915102278879193`}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}}], 
      LineBox[{{3.9212800556869225`, 3.672165703941192}, {4.0062231578946355`,
        3.6915102278879193`}, {4.0062231578946355`, 3.6915102278879193`}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}}], 
      LineBox[{{3.9212800556869225`, 3.672165703941192}, {4.0062231578946355`,
        3.6915102278879193`}, {4.0062231578946355`, 3.6915102278879193`}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}}], 
      LineBox[{{4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373,
        3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}}], 
      LineBox[{{4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373,
        3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}}], 
      LineBox[{{4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373,
        3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}}], 
      LineBox[{{4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373,
        3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}}], 
      LineBox[{{4.068829127886373, 3.672165703941192}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}}], 
      LineBox[{{4.068829127886373, 3.672165703941192}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}}], 
      LineBox[{{4.068829127886373, 3.672165703941192}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}}], 
      LineBox[{{4.068829127886373, 3.672165703941192}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}}], 
      LineBox[{{4.116884962044223, 3.6276196054731455`}, {4.1426036639860975`,
        3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}}], 
      LineBox[{{4.116884962044223, 3.6276196054731455`}, {4.1426036639860975`,
        3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}}], 
      LineBox[{{4.116884962044223, 3.6276196054731455`}, {4.1426036639860975`,
        3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}}], 
      LineBox[{{4.116884962044223, 3.6276196054731455`}, {4.1426036639860975`,
        3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768254}, {
       4.195930844480385, -4.069043655768254}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436583}, {
       4.195930844480385, -4.343071758436583}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}], 
      LineBox[{{4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}], 
      LineBox[{{4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}], 
      LineBox[{{4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}], 
      LineBox[{{4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}], 
      LineBox[{{4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}], 
      LineBox[{{4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}], 
      LineBox[{{4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}], 
      LineBox[{{4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}], 
      LineBox[{{4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}], 
      LineBox[{{4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}], 
      LineBox[{{4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}], 
      LineBox[{{4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}], 
      LineBox[{{4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}], 
      LineBox[{{4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}], 
      LineBox[{{4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}], 
      LineBox[{{4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}], 
      LineBox[{{4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}], 
      LineBox[{{4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}], 
      LineBox[{{4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}], 
      LineBox[{{4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}], 
      LineBox[{{4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}], 
      LineBox[{{4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}], 
      LineBox[{{4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}], 
      LineBox[{{4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}], 
      LineBox[{{4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}], 
      LineBox[{{4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}], 
      LineBox[{{4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}], 
      LineBox[{{4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}], 
      LineBox[{{4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}], 
      LineBox[{{4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}], 
      LineBox[{{4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}], 
      LineBox[{{4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}], 
      LineBox[{{4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}], 
      LineBox[{{4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}], 
      LineBox[{{4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}], 
      LineBox[{{4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}], 
      LineBox[{{4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}], 
      LineBox[{{4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}], 
      LineBox[{{4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}], 
      LineBox[{{4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}], 
      LineBox[{{4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}], 
      LineBox[{{4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}], 
      LineBox[{{4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}], 
      LineBox[{{4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}], 
      LineBox[{{4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}], 
      LineBox[{{4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}], 
      LineBox[{{4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}], 
      LineBox[{{4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}], 
      LineBox[{{4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}], 
      LineBox[{{4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}], 
      LineBox[{{4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}], 
      LineBox[{{4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}], 
      LineBox[{{4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}], 
      LineBox[{{4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}], 
      LineBox[{{4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}], 
      LineBox[{{4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}], 
      LineBox[{{4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}], 
      LineBox[{{4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}], 
      LineBox[{{4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}], 
      LineBox[{{4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}], 
      LineBox[{{4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}], 
      LineBox[{{4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}], 
      LineBox[{{4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}], 
      LineBox[{{4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}], 
      LineBox[{{4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}], 
      LineBox[{{4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}], 
      LineBox[{{4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}], 
      LineBox[{{4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}], 
      LineBox[{{4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}], 
      LineBox[{{4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}], 
      LineBox[{{4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}], 
      LineBox[{{4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}], 
      LineBox[{{4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}], 
      LineBox[{{4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}], 
      LineBox[{{4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}], 
      LineBox[{{4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}], 
      LineBox[{{4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}], 
      LineBox[{{4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}], 
      LineBox[{{4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}], 
      LineBox[{{4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}], 
      LineBox[{{4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}], 
      LineBox[{{4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}], 
      LineBox[{{4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}], 
      LineBox[{{4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}], 
      LineBox[{{4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}], 
      LineBox[{{4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}], 
      LineBox[{{4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}], 
      LineBox[{{4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}], 
      LineBox[{{4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}], 
      LineBox[{{4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}], 
      LineBox[{{4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}], 
      LineBox[{{4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}], 
      LineBox[{{4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}], 
      LineBox[{{4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}], 
      LineBox[{{4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}], 
      LineBox[{{4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}], 
      LineBox[{{4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}], 
      LineBox[{{4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}], 
      LineBox[{{4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}], 
      LineBox[{{4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}], 
      LineBox[{{4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}], 
      LineBox[{{4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}], 
      LineBox[{{4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}], 
      LineBox[{{4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}], 
      LineBox[{{4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}], 
      LineBox[{{4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}], 
      LineBox[{{4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}], 
      LineBox[{{4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}], 
      LineBox[{{4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}], 
      LineBox[{{4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}], 
      LineBox[{{4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}], 
      LineBox[{{4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}], 
      LineBox[{{4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}], 
      LineBox[{{4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}], 
      LineBox[{{4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}], 
      LineBox[{{4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}], 
      LineBox[{{4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}], 
      LineBox[{{4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}], 
      LineBox[{{4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}], 
      LineBox[{{4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}], 
      LineBox[{{4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}], 
      LineBox[{{4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}], 
      LineBox[{{4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}], 
      LineBox[{{4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}], 
      LineBox[{{4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}], 
      LineBox[{{4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}], 
      LineBox[{{4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}], 
      LineBox[{{4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}], 
      LineBox[{{4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}], 
      LineBox[{{4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}], 
      LineBox[{{4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}], 
      LineBox[{{4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}], 
      LineBox[{{4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}], 
      LineBox[{{4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}], 
      LineBox[{{4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}], 
      LineBox[{{4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}], 
      LineBox[{{4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}], 
      LineBox[{{4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}], 
      LineBox[{{4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}], 
      LineBox[{{4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}], 
      LineBox[{{4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}], 
      LineBox[{{4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}], 
      LineBox[{{4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}], 
      LineBox[{{4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}], 
      LineBox[{{4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}], 
      LineBox[{{4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}], 
      LineBox[{{4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}], 
      LineBox[{{4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}], 
      LineBox[{{4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}], 
      LineBox[{{4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}], 
      LineBox[{{4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}], 
      LineBox[{{4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}], 
      LineBox[{{4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}], 
      LineBox[{{4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}], 
      LineBox[{{4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}], 
      LineBox[{{4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}], 
      LineBox[{{4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}], 
      LineBox[{{4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}], 
      LineBox[{{4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}], 
      LineBox[{{4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}], 
      LineBox[{{4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}], 
      LineBox[{{4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}], 
      LineBox[{{4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}], 
      LineBox[{{4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}], 
      LineBox[{{4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}], 
      LineBox[{{4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}], 
      LineBox[{{4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}], 
      LineBox[{{4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}], 
      LineBox[{{4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}], 
      LineBox[{{4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}], 
      LineBox[{{4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}], 
      LineBox[{{4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}], 
      LineBox[{{4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}], 
      LineBox[{{4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}], 
      LineBox[{{4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}], 
      LineBox[{{4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}], 
      LineBox[{{4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}], 
      LineBox[{{4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}], 
      LineBox[{{4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}], 
      LineBox[{{4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}], 
      LineBox[{{4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}], 
      LineBox[{{4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}], 
      LineBox[{{4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}], 
      LineBox[{{4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}], 
      LineBox[{{4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}], 
      LineBox[{{4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}], 
      LineBox[{{4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}], 
      LineBox[{{4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}], 
      LineBox[{{4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}], 
      LineBox[{{4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}], 
      LineBox[{{4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}], 
      LineBox[{{4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}], 
      LineBox[{{4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}], 
      LineBox[{{4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}], 
      LineBox[{{4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}], 
      LineBox[{{4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}], 
      LineBox[{{4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}], 
      LineBox[{{4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}], 
      LineBox[{{4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}], 
      LineBox[{{4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}], 
      LineBox[{{4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}], 
      LineBox[{{4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}], 
      LineBox[{{4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}], 
      LineBox[{{4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}], 
      LineBox[{{4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}], 
      LineBox[{{4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}], 
      LineBox[{{4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}], 
      LineBox[{{4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}], 
      LineBox[{{4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}], 
      LineBox[{{4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}], 
      LineBox[{{4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}], 
      LineBox[{{4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}], 
      LineBox[{{4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}], 
      LineBox[{{4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}], 
      LineBox[{{4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}], 
      LineBox[{{4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}], 
      LineBox[{{4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}], 
      LineBox[{{4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}], 
      LineBox[{{4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}], 
      LineBox[{{4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}], 
      LineBox[{{4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}], 
      LineBox[{{4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}], 
      LineBox[{{4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}], 
      LineBox[{{4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}], 
      LineBox[{{4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}], 
      LineBox[{{4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}], 
      LineBox[{{4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}], 
      LineBox[{{4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}], 
      LineBox[{{4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}], 
      LineBox[{{4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}], 
      LineBox[{{4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}], 
      LineBox[{{4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}], 
      LineBox[{{4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}], 
      LineBox[{{4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}], 
      LineBox[{{4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}], 
      LineBox[{{4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}], 
      LineBox[{{4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}], 
      LineBox[{{4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}], 
      LineBox[{{4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}], 
      LineBox[{{4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}], 
      LineBox[{{4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}], 
      LineBox[{{4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}], 
      LineBox[{{4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}], 
      LineBox[{{4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}], 
      LineBox[{{4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}], 
      LineBox[{{4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}], 
      LineBox[{{4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}], 
      LineBox[{{4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}], 
      LineBox[{{4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}], 
      LineBox[{{4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}], 
      LineBox[{{4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}], 
      LineBox[{{4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}], 
      LineBox[{{4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}], 
      LineBox[{{4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}], 
      LineBox[{{4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}], 
      LineBox[{{4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}], 
      LineBox[{{4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}], 
      LineBox[{{4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}], 
      LineBox[{{4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}], 
      LineBox[{{4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}], 
      LineBox[{{4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}], 
      LineBox[{{4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}], 
      LineBox[{{4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}], 
      LineBox[{{4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}], 
      LineBox[{{4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}], 
      LineBox[{{4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}], 
      LineBox[{{4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}], 
      LineBox[{{4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}], 
      LineBox[{{4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}], 
      LineBox[{{4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}], 
      LineBox[{{4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}], 
      LineBox[{{4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}], 
      LineBox[{{4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}], 
      LineBox[{{4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}], 
      LineBox[{{4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}], 
      LineBox[{{4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}], 
      LineBox[{{4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}], 
      LineBox[{{4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}], 
      LineBox[{{4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}], 
      LineBox[{{4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}], 
      LineBox[{{4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}], 
      LineBox[{{4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}], 
      LineBox[{{4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}], 
      LineBox[{{4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}], 
      LineBox[{{4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}], 
      LineBox[{{4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}], 
      LineBox[{{4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}], 
      LineBox[{{4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}], 
      LineBox[{{4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}], 
      LineBox[{{4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}], 
      LineBox[{{4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}], 
      LineBox[{{4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}], 
      LineBox[{{4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}], 
      LineBox[{{4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}], 
      LineBox[{{4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}], 
      LineBox[{{4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}], 
      LineBox[{{4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}], 
      LineBox[{{4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}], 
      LineBox[{{4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}], 
      LineBox[{{4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}], 
      LineBox[{{4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}], 
      LineBox[{{4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}], 
      LineBox[{{4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}], 
      LineBox[{{4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}], 
      LineBox[{{4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}], 
      LineBox[{{4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}], 
      LineBox[{{4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}], 
      LineBox[{{4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}], 
      LineBox[{{4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}], 
      LineBox[{{4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}], 
      LineBox[{{4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}], 
      LineBox[{{4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}], 
      LineBox[{{4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}], 
      LineBox[{{4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}], 
      LineBox[{{4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978406}, {
       4.194682367669636, -0.6416079560978406}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.9089633228694212}, {
       4.194682367669636, -0.9089633228694212}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}], 
      LineBox[{{4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}], 
      LineBox[{{4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}], 
      LineBox[{{4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}], 
      LineBox[{{4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}], 
      LineBox[{{4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}], 
      LineBox[{{4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}], 
      LineBox[{{4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}], 
      LineBox[{{4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}], 
      LineBox[{{4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}], 
      LineBox[{{4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}], 
      LineBox[{{4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}], 
      LineBox[{{4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}], 
      LineBox[{{4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}], 
      LineBox[{{4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}], 
      LineBox[{{4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}], 
      LineBox[{{4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}], 
      LineBox[{{4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}], 
      LineBox[{{4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}], 
      LineBox[{{4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}], 
      LineBox[{{4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}], 
      LineBox[{{4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}], 
      LineBox[{{4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}], 
      LineBox[{{4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}], 
      LineBox[{{4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}], 
      LineBox[{{4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}], 
      LineBox[{{4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}], 
      LineBox[{{4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}], 
      LineBox[{{4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}], 
      LineBox[{{4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}], 
      LineBox[{{4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}], 
      LineBox[{{4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}], 
      LineBox[{{4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}], 
      LineBox[{{4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}], 
      LineBox[{{4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}], 
      LineBox[{{4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}], 
      LineBox[{{4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}], 
      LineBox[{{4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}], 
      LineBox[{{4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}], 
      LineBox[{{4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}], 
      LineBox[{{4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}], 
      LineBox[{{4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}], 
      LineBox[{{4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}], 
      LineBox[{{4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}], 
      LineBox[{{4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}], 
      LineBox[{{4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.23983224181911383`}, {
       4.443769916351422, -0.23983224181911383`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}], 
      LineBox[{{4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}], 
      LineBox[{{4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}], 
      LineBox[{{4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}], 
      LineBox[{{4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}], 
      LineBox[{{4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}], 
      LineBox[{{4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}], 
      LineBox[{{4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}], 
      LineBox[{{4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}], 
      LineBox[{{4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}], 
      LineBox[{{4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}], 
      LineBox[{{4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}], 
      LineBox[{{4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}], 
      LineBox[{{4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}], 
      LineBox[{{4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}], 
      LineBox[{{4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}], 
      LineBox[{{4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}], 
      LineBox[{{4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}], 
      LineBox[{{4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}], 
      LineBox[{{4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}], 
      LineBox[{{4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}], 
      LineBox[{{4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}], 
      LineBox[{{4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}], 
      LineBox[{{4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}], 
      LineBox[{{4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}], 
      LineBox[{{4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}], 
      LineBox[{{4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}], 
      LineBox[{{4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}], 
      LineBox[{{4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}], 
      LineBox[{{4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}], 
      LineBox[{{4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}], 
      LineBox[{{4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}], 
      LineBox[{{4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}], 
      LineBox[{{4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}], 
      LineBox[{{4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}], 
      LineBox[{{4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}], 
      LineBox[{{4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}], 
      LineBox[{{4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}], 
      LineBox[{{4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}], 
      LineBox[{{4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}], 
      LineBox[{{4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}], 
      LineBox[{{4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}], 
      LineBox[{{4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}], 
      LineBox[{{4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}], 
      LineBox[{{4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}], 
      LineBox[{{4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.21729290763344, 0.1230984505667839}, {4.151908727757882, 
       0.19363417451802362`}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.33470562242050306`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}, {
       4.151908727757882, 0.334705622420503}, {4.135845269211973, 
       0.2641698984692633}, {4.151908727757882, 0.1936341745180236}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.380188184476373, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.380188184476373, 
       0.1230984505667839}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.380188184476373, 0.4052413463717427}, {
       4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.380188184476373, 
       0.4052413463717427}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.21729290763344, 0.1230984505667839}, {4.151908727757882, 
       0.19363417451802362`}, {4.151908727757882, 0.19363417451802362`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}}], 
      LineBox[{{4.21729290763344, 0.1230984505667839}, {4.151908727757882, 
       0.19363417451802362`}, {4.151908727757882, 0.19363417451802362`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}}], 
      LineBox[{{4.21729290763344, 0.1230984505667839}, {4.151908727757882, 
       0.19363417451802362`}, {4.151908727757882, 0.19363417451802362`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}}], 
      LineBox[{{4.21729290763344, 0.1230984505667839}, {4.151908727757882, 
       0.19363417451802362`}, {4.151908727757882, 0.19363417451802362`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}}], 
      LineBox[{{4.151908727757882, 0.19363417451802362`}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}}], 
      LineBox[{{4.151908727757882, 0.19363417451802362`}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}}], 
      LineBox[{{4.151908727757882, 0.19363417451802362`}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}}], 
      LineBox[{{4.151908727757882, 0.19363417451802362`}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}}], 
      LineBox[{{4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.334705622420503}, {4.151908727757882, 0.334705622420503}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}], 
      LineBox[{{4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.334705622420503}, {4.151908727757882, 0.334705622420503}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}], 
      LineBox[{{4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.334705622420503}, {4.151908727757882, 0.334705622420503}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}], 
      LineBox[{{4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.334705622420503}, {4.151908727757882, 0.334705622420503}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}], 
      LineBox[{{4.151908727757882, 0.33470562242050306`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}, {
       4.151908727757882, 0.33470562242050306`}, {4.151908727757882, 
       0.33470562242050306`}}], 
      LineBox[{{4.151908727757882, 0.33470562242050306`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}, {
       4.151908727757882, 0.33470562242050306`}, {4.151908727757882, 
       0.33470562242050306`}}], 
      LineBox[{{4.151908727757882, 0.33470562242050306`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}, {
       4.151908727757882, 0.33470562242050306`}, {4.151908727757882, 
       0.33470562242050306`}}], 
      LineBox[{{4.151908727757882, 0.33470562242050306`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}, {
       4.151908727757882, 0.33470562242050306`}, {4.151908727757882, 
       0.33470562242050306`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}], 
      LineBox[{{4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}], 
      LineBox[{{4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}], 
      LineBox[{{4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}], 
      LineBox[{{4.433242184019519, 0.1722776757157991}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.433242184019519, 0.1722776757157991}, {4.433242184019519, 
       0.1722776757157991}}], 
      LineBox[{{4.433242184019519, 0.1722776757157991}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.433242184019519, 0.1722776757157991}, {4.433242184019519, 
       0.1722776757157991}}], 
      LineBox[{{4.433242184019519, 0.1722776757157991}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.433242184019519, 0.1722776757157991}, {4.433242184019519, 
       0.1722776757157991}}], 
      LineBox[{{4.433242184019519, 0.1722776757157991}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.433242184019519, 0.1722776757157991}, {4.433242184019519, 
       0.1722776757157991}}], 
      LineBox[{{4.380188184476373, 0.1230984505667839}, {4.311070726387319, 
       0.10174195176455939`}, {4.311070726387319, 0.10174195176455939`}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}}], 
      LineBox[{{4.380188184476373, 0.1230984505667839}, {4.311070726387319, 
       0.10174195176455939`}, {4.311070726387319, 0.10174195176455939`}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}}], 
      LineBox[{{4.380188184476373, 0.1230984505667839}, {4.311070726387319, 
       0.10174195176455939`}, {4.311070726387319, 0.10174195176455939`}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}}], 
      LineBox[{{4.380188184476373, 0.1230984505667839}, {4.311070726387319, 
       0.10174195176455939`}, {4.311070726387319, 0.10174195176455939`}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}}], 
      LineBox[{{4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}}], 
      LineBox[{{4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}}], 
      LineBox[{{4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}}], 
      LineBox[{{4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}], 
      LineBox[{{4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}], 
      LineBox[{{4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}], 
      LineBox[{{4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}], 
      LineBox[{{4.311070726387319, 0.42659784517396726`}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}}], 
      LineBox[{{4.311070726387319, 0.42659784517396726`}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}}], 
      LineBox[{{4.311070726387319, 0.42659784517396726`}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}}], 
      LineBox[{{4.311070726387319, 0.42659784517396726`}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}}], 
      LineBox[{{4.380188184476373, 0.4052413463717427}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}], 
      LineBox[{{4.380188184476373, 0.4052413463717427}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}], 
      LineBox[{{4.380188184476373, 0.4052413463717427}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}], 
      LineBox[{{4.380188184476373, 0.4052413463717427}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}], 
      LineBox[{{4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.433242184019519, 
       0.3560621212227275}}], 
      LineBox[{{4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.433242184019519, 
       0.3560621212227275}}], 
      LineBox[{{4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.433242184019519, 
       0.3560621212227275}}], 
      LineBox[{{4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.433242184019519, 
       0.3560621212227275}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.17840521788017, 0.6015401602364004}, {4.112044402930747, 
       0.6731294672118877}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.8163080811628622}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}, {
       4.112044402930747, 0.8163080811628622}, {4.095741006573377, 
       0.744718774187375}, {4.112044402930747, 0.6731294672118877}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.343733640493755, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.343733640493755, 
       0.6015401602364004}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.343733640493755, 0.8878973881383495}, {
       4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.343733640493755, 
       0.8878973881383495}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.17840521788017, 0.6015401602364004}, {4.112044402930747, 
       0.6731294672118877}, {4.112044402930747, 0.6731294672118877}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}}], 
      LineBox[{{4.17840521788017, 0.6015401602364004}, {4.112044402930747, 
       0.6731294672118877}, {4.112044402930747, 0.6731294672118877}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}}], 
      LineBox[{{4.17840521788017, 0.6015401602364004}, {4.112044402930747, 
       0.6731294672118877}, {4.112044402930747, 0.6731294672118877}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}}], 
      LineBox[{{4.17840521788017, 0.6015401602364004}, {4.112044402930747, 
       0.6731294672118877}, {4.112044402930747, 0.6731294672118877}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}}], 
      LineBox[{{4.112044402930747, 0.6731294672118877}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}}], 
      LineBox[{{4.112044402930747, 0.6731294672118877}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}}], 
      LineBox[{{4.112044402930747, 0.6731294672118877}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}}], 
      LineBox[{{4.112044402930747, 0.6731294672118877}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}}], 
      LineBox[{{4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}], 
      LineBox[{{4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}], 
      LineBox[{{4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}], 
      LineBox[{{4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}], 
      LineBox[{{4.112044402930747, 0.8163080811628622}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}}], 
      LineBox[{{4.112044402930747, 0.8163080811628622}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}}], 
      LineBox[{{4.112044402930747, 0.8163080811628622}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}}], 
      LineBox[{{4.112044402930747, 0.8163080811628622}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}], 
      LineBox[{{4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}], 
      LineBox[{{4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}], 
      LineBox[{{4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}], 
      LineBox[{{4.397580100795165, 0.651453969137593}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.397580100795165, 0.651453969137593}, {4.397580100795165, 
       0.651453969137593}}], 
      LineBox[{{4.397580100795165, 0.651453969137593}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.397580100795165, 0.651453969137593}, {4.397580100795165, 
       0.651453969137593}}], 
      LineBox[{{4.397580100795165, 0.651453969137593}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.397580100795165, 0.651453969137593}, {4.397580100795165, 
       0.651453969137593}}], 
      LineBox[{{4.397580100795165, 0.651453969137593}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.397580100795165, 0.651453969137593}, {4.397580100795165, 
       0.651453969137593}}], 
      LineBox[{{4.343733640493755, 0.6015401602364004}, {4.273583783834976, 
       0.5798646621621057}, {4.273583783834976, 0.5798646621621057}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}}], 
      LineBox[{{4.343733640493755, 0.6015401602364004}, {4.273583783834976, 
       0.5798646621621057}, {4.273583783834976, 0.5798646621621057}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}}], 
      LineBox[{{4.343733640493755, 0.6015401602364004}, {4.273583783834976, 
       0.5798646621621057}, {4.273583783834976, 0.5798646621621057}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}}], 
      LineBox[{{4.343733640493755, 0.6015401602364004}, {4.273583783834976, 
       0.5798646621621057}, {4.273583783834976, 0.5798646621621057}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}}], 
      LineBox[{{4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}}], 
      LineBox[{{4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}}], 
      LineBox[{{4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}}], 
      LineBox[{{4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}], 
      LineBox[{{4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}], 
      LineBox[{{4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}], 
      LineBox[{{4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}], 
      LineBox[{{4.273583783834976, 0.9095728862126442}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}}], 
      LineBox[{{4.273583783834976, 0.9095728862126442}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}}], 
      LineBox[{{4.273583783834976, 0.9095728862126442}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}}], 
      LineBox[{{4.273583783834976, 0.9095728862126442}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}}], 
      LineBox[{{4.343733640493755, 0.8878973881383495}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}], 
      LineBox[{{4.343733640493755, 0.8878973881383495}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}], 
      LineBox[{{4.343733640493755, 0.8878973881383495}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}], 
      LineBox[{{4.343733640493755, 0.8878973881383495}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}], 
      LineBox[{{4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.397580100795165, 
       0.8379835792371569}}], 
      LineBox[{{4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.397580100795165, 
       0.8379835792371569}}], 
      LineBox[{{4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.397580100795165, 
       0.8379835792371569}}], 
      LineBox[{{4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.397580100795165, 
       0.8379835792371569}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174516701005696, 1.13266027030957}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.174516701005696, 
       1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.095347447743132, 
       1.2697854393576191`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.332855207530824, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.332855207530824, 
       1.13266027030957}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.332855207530824, 1.4069106084056682`}, {
       4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.332855207530824, 
       1.4069106084056682`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174516701005696, 1.13266027030957}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}}], 
      LineBox[{{4.174516701005696, 1.13266027030957}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}}], 
      LineBox[{{4.174516701005696, 1.13266027030957}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}}], 
      LineBox[{{4.174516701005696, 1.13266027030957}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}}], 
      LineBox[{{4.1109615532290755`, 1.2012228548335946`}, {4.095347447743132,
        1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}}], 
      LineBox[{{4.1109615532290755`, 1.2012228548335946`}, {4.095347447743132,
        1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}}], 
      LineBox[{{4.1109615532290755`, 1.2012228548335946`}, {4.095347447743132,
        1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}}], 
      LineBox[{{4.1109615532290755`, 1.2012228548335946`}, {4.095347447743132,
        1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}}], 
      LineBox[{{4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`,
        1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}], 
      LineBox[{{4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`,
        1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}], 
      LineBox[{{4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`,
        1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}], 
      LineBox[{{4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`,
        1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}], 
      LineBox[{{4.1109615532290755`, 1.3383480238816436`}, {4.174516701005696,
        1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}}], 
      LineBox[{{4.1109615532290755`, 1.3383480238816436`}, {4.174516701005696,
        1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}}], 
      LineBox[{{4.1109615532290755`, 1.3383480238816436`}, {4.174516701005696,
        1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}}], 
      LineBox[{{4.1109615532290755`, 1.3383480238816436`}, {4.174516701005696,
        1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}], 
      LineBox[{{4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}], 
      LineBox[{{4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}], 
      LineBox[{{4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}], 
      LineBox[{{4.384425094734775, 1.1804637745797792`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.384425094734775, 1.1804637745797792`}, {4.384425094734775, 
       1.1804637745797792`}}], 
      LineBox[{{4.384425094734775, 1.1804637745797792`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.384425094734775, 1.1804637745797792`}, {4.384425094734775, 
       1.1804637745797792`}}], 
      LineBox[{{4.384425094734775, 1.1804637745797792`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.384425094734775, 1.1804637745797792`}, {4.384425094734775, 
       1.1804637745797792`}}], 
      LineBox[{{4.384425094734775, 1.1804637745797792`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.384425094734775, 1.1804637745797792`}, {4.384425094734775, 
       1.1804637745797792`}}], 
      LineBox[{{4.332855207530824, 1.13266027030957}, {4.265671214840929, 
       1.1119011900557547`}, {4.265671214840929, 1.1119011900557547`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}}], 
      LineBox[{{4.332855207530824, 1.13266027030957}, {4.265671214840929, 
       1.1119011900557547`}, {4.265671214840929, 1.1119011900557547`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}}], 
      LineBox[{{4.332855207530824, 1.13266027030957}, {4.265671214840929, 
       1.1119011900557547`}, {4.265671214840929, 1.1119011900557547`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}}], 
      LineBox[{{4.332855207530824, 1.13266027030957}, {4.265671214840929, 
       1.1119011900557547`}, {4.265671214840929, 1.1119011900557547`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}}], 
      LineBox[{{4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}}], 
      LineBox[{{4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}}], 
      LineBox[{{4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}}], 
      LineBox[{{4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}], 
      LineBox[{{4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}], 
      LineBox[{{4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}], 
      LineBox[{{4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}], 
      LineBox[{{4.265671214840929, 1.4276696886594835`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}}], 
      LineBox[{{4.265671214840929, 1.4276696886594835`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}}], 
      LineBox[{{4.265671214840929, 1.4276696886594835`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}}], 
      LineBox[{{4.265671214840929, 1.4276696886594835`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}}], 
      LineBox[{{4.332855207530824, 1.4069106084056682`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}], 
      LineBox[{{4.332855207530824, 1.4069106084056682`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}], 
      LineBox[{{4.332855207530824, 1.4069106084056682`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}], 
      LineBox[{{4.332855207530824, 1.4069106084056682`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}], 
      LineBox[{{4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.384425094734775, 
       1.359107104135459}}], 
      LineBox[{{4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.384425094734775, 
       1.359107104135459}}], 
      LineBox[{{4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.384425094734775, 
       1.359107104135459}}], 
      LineBox[{{4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.384425094734775, 
       1.359107104135459}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.202817042195127, 1.6066413738311724`}, {4.136012909023033, 
       1.6787089275604827`}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.8228440350191033`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}, {
       4.136012909023033, 1.8228440350191033`}, {4.119600599104216, 
       1.750776481289793}, {4.136012909023033, 1.6787089275604827`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.369249928376947, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127, 
       1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.369249928376947, 
       1.6066413738311724`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`,
        1.9167318882885902`}, {4.369249928376947, 1.8949115887484136`}, {
       4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.369249928376947, 
       1.8949115887484136`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.202817042195127, 1.6066413738311724`}, {4.136012909023033, 
       1.6787089275604827`}, {4.136012909023033, 1.6787089275604827`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}}], 
      LineBox[{{4.202817042195127, 1.6066413738311724`}, {4.136012909023033, 
       1.6787089275604827`}, {4.136012909023033, 1.6787089275604827`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}}], 
      LineBox[{{4.202817042195127, 1.6066413738311724`}, {4.136012909023033, 
       1.6787089275604827`}, {4.136012909023033, 1.6787089275604827`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}}], 
      LineBox[{{4.202817042195127, 1.6066413738311724`}, {4.136012909023033, 
       1.6787089275604827`}, {4.136012909023033, 1.6787089275604827`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}}], 
      LineBox[{{4.136012909023033, 1.6787089275604827`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}}], 
      LineBox[{{4.136012909023033, 1.6787089275604827`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}}], 
      LineBox[{{4.136012909023033, 1.6787089275604827`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}}], 
      LineBox[{{4.136012909023033, 1.6787089275604827`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}}], 
      LineBox[{{4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}], 
      LineBox[{{4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}], 
      LineBox[{{4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}], 
      LineBox[{{4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}], 
      LineBox[{{4.136012909023033, 1.8228440350191033`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}}], 
      LineBox[{{4.136012909023033, 1.8228440350191033`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}}], 
      LineBox[{{4.136012909023033, 1.8228440350191033`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}}], 
      LineBox[{{4.136012909023033, 1.8228440350191033`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}], 
      LineBox[{{4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}], 
      LineBox[{{4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}], 
      LineBox[{{4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}], 
      LineBox[{{4.423456105735721, 1.6568886280203061`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.423456105735721, 1.6568886280203061`}, {4.423456105735721, 
       1.6568886280203061`}}], 
      LineBox[{{4.423456105735721, 1.6568886280203061`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.423456105735721, 1.6568886280203061`}, {4.423456105735721, 
       1.6568886280203061`}}], 
      LineBox[{{4.423456105735721, 1.6568886280203061`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.423456105735721, 1.6568886280203061`}, {4.423456105735721, 
       1.6568886280203061`}}], 
      LineBox[{{4.423456105735721, 1.6568886280203061`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.423456105735721, 1.6568886280203061`}, {4.423456105735721, 
       1.6568886280203061`}}], 
      LineBox[{{4.369249928376947, 1.6066413738311724`}, {4.2986314410993565`,
        1.5848210742909958`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}}], 
      LineBox[{{4.369249928376947, 1.6066413738311724`}, {4.2986314410993565`,
        1.5848210742909958`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}}], 
      LineBox[{{4.369249928376947, 1.6066413738311724`}, {4.2986314410993565`,
        1.5848210742909958`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}}], 
      LineBox[{{4.369249928376947, 1.6066413738311724`}, {4.2986314410993565`,
        1.5848210742909958`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}}], 
      LineBox[{{4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127,
        1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}}], 
      LineBox[{{4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127,
        1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}}], 
      LineBox[{{4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127,
        1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}}], 
      LineBox[{{4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127,
        1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`,
        1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}], 
      LineBox[{{4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`,
        1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}], 
      LineBox[{{4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`,
        1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}], 
      LineBox[{{4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`,
        1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}], 
      LineBox[{{4.2986314410993565`, 1.9167318882885902`}, {4.369249928376947,
        1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}}], 
      LineBox[{{4.2986314410993565`, 1.9167318882885902`}, {4.369249928376947,
        1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}}], 
      LineBox[{{4.2986314410993565`, 1.9167318882885902`}, {4.369249928376947,
        1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}}], 
      LineBox[{{4.2986314410993565`, 1.9167318882885902`}, {4.369249928376947,
        1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}}], 
      LineBox[{{4.369249928376947, 1.8949115887484136`}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}], 
      LineBox[{{4.369249928376947, 1.8949115887484136`}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}], 
      LineBox[{{4.369249928376947, 1.8949115887484136`}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}], 
      LineBox[{{4.369249928376947, 1.8949115887484136`}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}], 
      LineBox[{{4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.423456105735721, 
       1.84466433455928}}], 
      LineBox[{{4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.423456105735721, 
       1.84466433455928}}], 
      LineBox[{{4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.423456105735721, 
       1.84466433455928}}], 
      LineBox[{{4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.423456105735721, 
       1.84466433455928}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.156457484897694, 2.1062122968949697`}, {4.090145643539342, 
       2.1777487717066637`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.3208217213300517`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}, {
       4.090145643539342, 2.3208217213300517`}, {4.073854278918877, 
       2.2492852465183577`}, {4.090145643539342, 2.1777487717066637`}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.321663896855328, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.321663896855328, 
       2.1062122968949697`}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.321663896855328, 2.3923581961417457`}, {
       4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.321663896855328, 
       2.3923581961417457`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.156457484897694, 2.1062122968949697`}, {4.090145643539342, 
       2.1777487717066637`}, {4.090145643539342, 2.1777487717066637`}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}}], 
      LineBox[{{4.156457484897694, 2.1062122968949697`}, {4.090145643539342, 
       2.1777487717066637`}, {4.090145643539342, 2.1777487717066637`}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}}], 
      LineBox[{{4.156457484897694, 2.1062122968949697`}, {4.090145643539342, 
       2.1777487717066637`}, {4.090145643539342, 2.1777487717066637`}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}}], 
      LineBox[{{4.156457484897694, 2.1062122968949697`}, {4.090145643539342, 
       2.1777487717066637`}, {4.090145643539342, 2.1777487717066637`}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}}], 
      LineBox[{{4.090145643539342, 2.1777487717066637`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}}], 
      LineBox[{{4.090145643539342, 2.1777487717066637`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}}], 
      LineBox[{{4.090145643539342, 2.1777487717066637`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}}], 
      LineBox[{{4.090145643539342, 2.1777487717066637`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}}], 
      LineBox[{{4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}], 
      LineBox[{{4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}], 
      LineBox[{{4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}], 
      LineBox[{{4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}], 
      LineBox[{{4.090145643539342, 2.3208217213300517`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}}], 
      LineBox[{{4.090145643539342, 2.3208217213300517`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}}], 
      LineBox[{{4.090145643539342, 2.3208217213300517`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}}], 
      LineBox[{{4.090145643539342, 2.3208217213300517`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}], 
      LineBox[{{4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}], 
      LineBox[{{4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}], 
      LineBox[{{4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}], 
      LineBox[{{4.375470619029208, 2.156089269924454}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.375470619029208, 2.156089269924454}, {4.375470619029208, 
       2.156089269924454}}], 
      LineBox[{{4.375470619029208, 2.156089269924454}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.375470619029208, 2.156089269924454}, {4.375470619029208, 
       2.156089269924454}}], 
      LineBox[{{4.375470619029208, 2.156089269924454}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.375470619029208, 2.156089269924454}, {4.375470619029208, 
       2.156089269924454}}], 
      LineBox[{{4.375470619029208, 2.156089269924454}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.375470619029208, 2.156089269924454}, {4.375470619029208, 
       2.156089269924454}}], 
      LineBox[{{4.321663896855328, 2.1062122968949697`}, {4.251565810060983, 
       2.08455279511276}, {4.251565810060983, 2.08455279511276}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}}], 
      LineBox[{{4.321663896855328, 2.1062122968949697`}, {4.251565810060983, 
       2.08455279511276}, {4.251565810060983, 2.08455279511276}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}}], 
      LineBox[{{4.321663896855328, 2.1062122968949697`}, {4.251565810060983, 
       2.08455279511276}, {4.251565810060983, 2.08455279511276}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}}], 
      LineBox[{{4.321663896855328, 2.1062122968949697`}, {4.251565810060983, 
       2.08455279511276}, {4.251565810060983, 2.08455279511276}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}}], 
      LineBox[{{4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}}], 
      LineBox[{{4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}}], 
      LineBox[{{4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}}], 
      LineBox[{{4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}], 
      LineBox[{{4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}], 
      LineBox[{{4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}], 
      LineBox[{{4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}], 
      LineBox[{{4.251565810060983, 2.4140176979239554`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}}], 
      LineBox[{{4.251565810060983, 2.4140176979239554`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}}], 
      LineBox[{{4.251565810060983, 2.4140176979239554`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}}], 
      LineBox[{{4.251565810060983, 2.4140176979239554`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}}], 
      LineBox[{{4.321663896855328, 2.3923581961417457`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}], 
      LineBox[{{4.321663896855328, 2.3923581961417457`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}], 
      LineBox[{{4.321663896855328, 2.3923581961417457`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}], 
      LineBox[{{4.321663896855328, 2.3923581961417457`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}], 
      LineBox[{{4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.375470619029208, 
       2.3424812231122614`}}], 
      LineBox[{{4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.375470619029208, 
       2.3424812231122614`}}], 
      LineBox[{{4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.375470619029208, 
       2.3424812231122614`}}], 
      LineBox[{{4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.375470619029208, 
       2.3424812231122614`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.188559794873285, 2.65820611976988}, {4.123431755250747, 
       2.7284655224731633`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.86898432787973}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}, {
       4.123431755250747, 2.86898432787973}, {4.1074312247456, 
       2.7987249251764466`}, {4.123431755250747, 2.7284655224731633`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.350816935128657, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.350816935128657, 
       2.65820611976988}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.350816935128657, 2.939243730583013}, {
       4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.350816935128657, 
       2.939243730583013}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.188559794873285, 2.65820611976988}, {4.123431755250747, 
       2.7284655224731633`}, {4.123431755250747, 2.7284655224731633`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}}], 
      LineBox[{{4.188559794873285, 2.65820611976988}, {4.123431755250747, 
       2.7284655224731633`}, {4.123431755250747, 2.7284655224731633`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}}], 
      LineBox[{{4.188559794873285, 2.65820611976988}, {4.123431755250747, 
       2.7284655224731633`}, {4.123431755250747, 2.7284655224731633`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}}], 
      LineBox[{{4.188559794873285, 2.65820611976988}, {4.123431755250747, 
       2.7284655224731633`}, {4.123431755250747, 2.7284655224731633`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}}], 
      LineBox[{{4.123431755250747, 2.7284655224731633`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}}], 
      LineBox[{{4.123431755250747, 2.7284655224731633`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}}], 
      LineBox[{{4.123431755250747, 2.7284655224731633`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}}], 
      LineBox[{{4.123431755250747, 2.7284655224731633`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}}], 
      LineBox[{{4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}], 
      LineBox[{{4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}], 
      LineBox[{{4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}], 
      LineBox[{{4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}], 
      LineBox[{{4.123431755250747, 2.86898432787973}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}}], 
      LineBox[{{4.123431755250747, 2.86898432787973}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}}], 
      LineBox[{{4.123431755250747, 2.86898432787973}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}}], 
      LineBox[{{4.123431755250747, 2.86898432787973}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}], 
      LineBox[{{4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}], 
      LineBox[{{4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}], 
      LineBox[{{4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}], 
      LineBox[{{4.403663097471847, 2.707192687013008}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.403663097471847, 2.707192687013008}, {4.403663097471847, 
       2.707192687013008}}], 
      LineBox[{{4.403663097471847, 2.707192687013008}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.403663097471847, 2.707192687013008}, {4.403663097471847, 
       2.707192687013008}}], 
      LineBox[{{4.403663097471847, 2.707192687013008}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.403663097471847, 2.707192687013008}, {4.403663097471847, 
       2.707192687013008}}], 
      LineBox[{{4.403663097471847, 2.707192687013008}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.403663097471847, 2.707192687013008}, {4.403663097471847, 
       2.707192687013008}}], 
      LineBox[{{4.350816935128657, 2.65820611976988}, {4.281970242280319, 
       2.6369332843097246`}, {4.281970242280319, 2.6369332843097246`}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}}], 
      LineBox[{{4.350816935128657, 2.65820611976988}, {4.281970242280319, 
       2.6369332843097246`}, {4.281970242280319, 2.6369332843097246`}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}}], 
      LineBox[{{4.350816935128657, 2.65820611976988}, {4.281970242280319, 
       2.6369332843097246`}, {4.281970242280319, 2.6369332843097246`}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}}], 
      LineBox[{{4.350816935128657, 2.65820611976988}, {4.281970242280319, 
       2.6369332843097246`}, {4.281970242280319, 2.6369332843097246`}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}}], 
      LineBox[{{4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}}], 
      LineBox[{{4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}}], 
      LineBox[{{4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}}], 
      LineBox[{{4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}], 
      LineBox[{{4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}], 
      LineBox[{{4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}], 
      LineBox[{{4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}], 
      LineBox[{{4.281970242280319, 2.9605165660431685`}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}}], 
      LineBox[{{4.281970242280319, 2.9605165660431685`}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}}], 
      LineBox[{{4.281970242280319, 2.9605165660431685`}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}}], 
      LineBox[{{4.281970242280319, 2.9605165660431685`}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}}], 
      LineBox[{{4.350816935128657, 2.939243730583013}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}], 
      LineBox[{{4.350816935128657, 2.939243730583013}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}], 
      LineBox[{{4.350816935128657, 2.939243730583013}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}], 
      LineBox[{{4.350816935128657, 2.939243730583013}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}], 
      LineBox[{{4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.403663097471847, 
       2.8902571633398852`}}], 
      LineBox[{{4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.403663097471847, 
       2.8902571633398852`}}], 
      LineBox[{{4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.403663097471847, 
       2.8902571633398852`}}], 
      LineBox[{{4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.403663097471847, 
       2.8902571633398852`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.161998696829344, 3.127081073459997}, {4.088587078065991, 
       3.2062767089449236`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.3646679799147754`}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}, {
       4.088587078065991, 3.3646679799147754`}, {4.070551453897613, 
       3.2854723444298495`}, {4.088587078065991, 3.2062767089449236`}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`,
        3.182298199905384}, {4.3448931826928066`, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.3448931826928066`, 
       3.127081073459997}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`,
        3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.161998696829344, 3.127081073459997}, {4.088587078065991, 
       3.2062767089449236`}, {4.088587078065991, 3.2062767089449236`}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}}], 
      LineBox[{{4.161998696829344, 3.127081073459997}, {4.088587078065991, 
       3.2062767089449236`}, {4.088587078065991, 3.2062767089449236`}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}}], 
      LineBox[{{4.161998696829344, 3.127081073459997}, {4.088587078065991, 
       3.2062767089449236`}, {4.088587078065991, 3.2062767089449236`}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}}], 
      LineBox[{{4.161998696829344, 3.127081073459997}, {4.088587078065991, 
       3.2062767089449236`}, {4.088587078065991, 3.2062767089449236`}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}}], 
      LineBox[{{4.088587078065991, 3.2062767089449236`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}}], 
      LineBox[{{4.088587078065991, 3.2062767089449236`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}}], 
      LineBox[{{4.088587078065991, 3.2062767089449236`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}}], 
      LineBox[{{4.088587078065991, 3.2062767089449236`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}}], 
      LineBox[{{4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}], 
      LineBox[{{4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}], 
      LineBox[{{4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}], 
      LineBox[{{4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}], 
      LineBox[{{4.088587078065991, 3.3646679799147754`}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}}], 
      LineBox[{{4.088587078065991, 3.3646679799147754`}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}}], 
      LineBox[{{4.088587078065991, 3.3646679799147754`}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}}], 
      LineBox[{{4.088587078065991, 3.3646679799147754`}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`,
        3.182298199905384}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}], 
      LineBox[{{4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`,
        3.182298199905384}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}], 
      LineBox[{{4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`,
        3.182298199905384}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}], 
      LineBox[{{4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`,
        3.182298199905384}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}], 
      LineBox[{{4.4044608028074155`, 3.182298199905384}, {4.3448931826928066`,
        3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.4044608028074155`, 3.182298199905384}, {4.4044608028074155`, 
       3.182298199905384}}], 
      LineBox[{{4.4044608028074155`, 3.182298199905384}, {4.3448931826928066`,
        3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.4044608028074155`, 3.182298199905384}, {4.4044608028074155`, 
       3.182298199905384}}], 
      LineBox[{{4.4044608028074155`, 3.182298199905384}, {4.3448931826928066`,
        3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.4044608028074155`, 3.182298199905384}, {4.4044608028074155`, 
       3.182298199905384}}], 
      LineBox[{{4.4044608028074155`, 3.182298199905384}, {4.3448931826928066`,
        3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.4044608028074155`, 3.182298199905384}, {4.4044608028074155`, 
       3.182298199905384}}], 
      LineBox[{{4.3448931826928066`, 3.127081073459997}, {4.267289938409819, 
       3.103102564420458}, {4.267289938409819, 3.103102564420458}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}}], 
      LineBox[{{4.3448931826928066`, 3.127081073459997}, {4.267289938409819, 
       3.103102564420458}, {4.267289938409819, 3.103102564420458}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}}], 
      LineBox[{{4.3448931826928066`, 3.127081073459997}, {4.267289938409819, 
       3.103102564420458}, {4.267289938409819, 3.103102564420458}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}}], 
      LineBox[{{4.3448931826928066`, 3.127081073459997}, {4.267289938409819, 
       3.103102564420458}, {4.267289938409819, 3.103102564420458}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}}], 
      LineBox[{{4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}}], 
      LineBox[{{4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}}], 
      LineBox[{{4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}}], 
      LineBox[{{4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}], 
      LineBox[{{4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}], 
      LineBox[{{4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}], 
      LineBox[{{4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}], 
      LineBox[{{4.267289938409819, 3.467842124439241}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}}], 
      LineBox[{{4.267289938409819, 3.467842124439241}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}}], 
      LineBox[{{4.267289938409819, 3.467842124439241}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}}], 
      LineBox[{{4.267289938409819, 3.467842124439241}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}}], 
      LineBox[{{4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}], 
      LineBox[{{4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}], 
      LineBox[{{4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}], 
      LineBox[{{4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}], 
      LineBox[{{4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}}], 
      LineBox[{{4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}}], 
      LineBox[{{4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}}], 
      LineBox[{{4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1567597612428475`, 3.5944577140817042`}, {4.097535360977009,
        3.6583483364964784`}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.786129581326026}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}, {
       4.097535360977009, 3.786129581326026}, {4.082985225143123, 
       3.722238958911252}, {4.097535360977009, 3.6583483364964784`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.304308833442297, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.304308833442297, 
       3.5944577140817042`}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.304308833442297, 3.8500202037408}, {
       4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.304308833442297, 
       3.8500202037408}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1567597612428475`, 3.5944577140817042`}, {4.097535360977009,
        3.6583483364964784`}, {4.097535360977009, 3.6583483364964784`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}}], 
      LineBox[{{4.1567597612428475`, 3.5944577140817042`}, {4.097535360977009,
        3.6583483364964784`}, {4.097535360977009, 3.6583483364964784`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}}], 
      LineBox[{{4.1567597612428475`, 3.5944577140817042`}, {4.097535360977009,
        3.6583483364964784`}, {4.097535360977009, 3.6583483364964784`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}}], 
      LineBox[{{4.1567597612428475`, 3.5944577140817042`}, {4.097535360977009,
        3.6583483364964784`}, {4.097535360977009, 3.6583483364964784`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}}], 
      LineBox[{{4.097535360977009, 3.6583483364964784`}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}}], 
      LineBox[{{4.097535360977009, 3.6583483364964784`}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}}], 
      LineBox[{{4.097535360977009, 3.6583483364964784`}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}}], 
      LineBox[{{4.097535360977009, 3.6583483364964784`}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}}], 
      LineBox[{{4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}], 
      LineBox[{{4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}], 
      LineBox[{{4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}], 
      LineBox[{{4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}], 
      LineBox[{{4.097535360977009, 3.786129581326026}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}}], 
      LineBox[{{4.097535360977009, 3.786129581326026}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}}], 
      LineBox[{{4.097535360977009, 3.786129581326026}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}}], 
      LineBox[{{4.097535360977009, 3.786129581326026}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}], 
      LineBox[{{4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}], 
      LineBox[{{4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}], 
      LineBox[{{4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}], 
      LineBox[{{4.352364667600148, 3.639003812549751}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.352364667600148, 3.639003812549751}, {4.352364667600148, 
       3.639003812549751}}], 
      LineBox[{{4.352364667600148, 3.639003812549751}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.352364667600148, 3.639003812549751}, {4.352364667600148, 
       3.639003812549751}}], 
      LineBox[{{4.352364667600148, 3.639003812549751}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.352364667600148, 3.639003812549751}, {4.352364667600148, 
       3.639003812549751}}], 
      LineBox[{{4.352364667600148, 3.639003812549751}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.352364667600148, 3.639003812549751}, {4.352364667600148, 
       3.639003812549751}}], 
      LineBox[{{4.304308833442297, 3.5944577140817042`}, {4.241702863450561, 
       3.575113190134977}, {4.241702863450561, 3.575113190134977}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}}], 
      LineBox[{{4.304308833442297, 3.5944577140817042`}, {4.241702863450561, 
       3.575113190134977}, {4.241702863450561, 3.575113190134977}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}}], 
      LineBox[{{4.304308833442297, 3.5944577140817042`}, {4.241702863450561, 
       3.575113190134977}, {4.241702863450561, 3.575113190134977}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}}], 
      LineBox[{{4.304308833442297, 3.5944577140817042`}, {4.241702863450561, 
       3.575113190134977}, {4.241702863450561, 3.575113190134977}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}}], 
      LineBox[{{4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}}], 
      LineBox[{{4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}}], 
      LineBox[{{4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}}], 
      LineBox[{{4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}], 
      LineBox[{{4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}], 
      LineBox[{{4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}], 
      LineBox[{{4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}], 
      LineBox[{{4.241702863450561, 3.869364727687527}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}}], 
      LineBox[{{4.241702863450561, 3.869364727687527}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}}], 
      LineBox[{{4.241702863450561, 3.869364727687527}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}}], 
      LineBox[{{4.241702863450561, 3.869364727687527}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}}], 
      LineBox[{{4.304308833442297, 3.8500202037408}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}], 
      LineBox[{{4.304308833442297, 3.8500202037408}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}], 
      LineBox[{{4.304308833442297, 3.8500202037408}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}], 
      LineBox[{{4.304308833442297, 3.8500202037408}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}], 
      LineBox[{{4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.352364667600148, 
       3.8054741052727534`}}], 
      LineBox[{{4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.352364667600148, 
       3.8054741052727534`}}], 
      LineBox[{{4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.352364667600148, 
       3.8054741052727534`}}], 
      LineBox[{{4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.352364667600148, 
       3.8054741052727534`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}], 
      LineBox[{{4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}], 
      LineBox[{{4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}], 
      LineBox[{{4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}], 
      LineBox[{{4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}], 
      LineBox[{{4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}], 
      LineBox[{{4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}], 
      LineBox[{{4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}], 
      LineBox[{{4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}], 
      LineBox[{{4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}], 
      LineBox[{{4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}], 
      LineBox[{{4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}], 
      LineBox[{{4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}], 
      LineBox[{{4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}], 
      LineBox[{{4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}], 
      LineBox[{{4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}], 
      LineBox[{{4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}], 
      LineBox[{{4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}], 
      LineBox[{{4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}], 
      LineBox[{{4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}], 
      LineBox[{{4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}], 
      LineBox[{{4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}], 
      LineBox[{{4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}], 
      LineBox[{{4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}], 
      LineBox[{{4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}], 
      LineBox[{{4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}], 
      LineBox[{{4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}], 
      LineBox[{{4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}], 
      LineBox[{{4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}], 
      LineBox[{{4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}], 
      LineBox[{{4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}], 
      LineBox[{{4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}], 
      LineBox[{{4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}], 
      LineBox[{{4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}], 
      LineBox[{{4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}], 
      LineBox[{{4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}], 
      LineBox[{{4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}], 
      LineBox[{{4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}], 
      LineBox[{{4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}], 
      LineBox[{{4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}], 
      LineBox[{{4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}], 
      LineBox[{{4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}], 
      LineBox[{{4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}], 
      LineBox[{{4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}], 
      LineBox[{{4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}], 
      LineBox[{{4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.450433646995931, -3.882718012404513}, {
       4.450433646995931, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.450433646995932, -4.14241486745002}, {
       4.450433646995932, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}], 
      LineBox[{{4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}], 
      LineBox[{{4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}], 
      LineBox[{{4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}], 
      LineBox[{{4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}], 
      LineBox[{{4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}], 
      LineBox[{{4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}], 
      LineBox[{{4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}], 
      LineBox[{{4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}], 
      LineBox[{{4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}], 
      LineBox[{{4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}], 
      LineBox[{{4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}], 
      LineBox[{{4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}], 
      LineBox[{{4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}], 
      LineBox[{{4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}], 
      LineBox[{{4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}], 
      LineBox[{{4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}], 
      LineBox[{{4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}], 
      LineBox[{{4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}], 
      LineBox[{{4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}], 
      LineBox[{{4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}], 
      LineBox[{{4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}], 
      LineBox[{{4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}], 
      LineBox[{{4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}], 
      LineBox[{{4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}], 
      LineBox[{{4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}], 
      LineBox[{{4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}], 
      LineBox[{{4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}], 
      LineBox[{{4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}], 
      LineBox[{{4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}], 
      LineBox[{{4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}], 
      LineBox[{{4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}], 
      LineBox[{{4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}], 
      LineBox[{{4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}], 
      LineBox[{{4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}], 
      LineBox[{{4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}], 
      LineBox[{{4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}], 
      LineBox[{{4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}], 
      LineBox[{{4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}], 
      LineBox[{{4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}], 
      LineBox[{{4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}], 
      LineBox[{{4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}], 
      LineBox[{{4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}], 
      LineBox[{{4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}], 
      LineBox[{{4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}], 
      LineBox[{{4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}], 
      LineBox[{{4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}], 
      LineBox[{{4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}], 
      LineBox[{{4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}], 
      LineBox[{{4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}], 
      LineBox[{{4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}], 
      LineBox[{{4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}], 
      LineBox[{{4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}], 
      LineBox[{{4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}], 
      LineBox[{{4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}], 
      LineBox[{{4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}], 
      LineBox[{{4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}], 
      LineBox[{{4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}], 
      LineBox[{{4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}], 
      LineBox[{{4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}], 
      LineBox[{{4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}], 
      LineBox[{{4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}], 
      LineBox[{{4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}], 
      LineBox[{{4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}], 
      LineBox[{{4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}], 
      LineBox[{{4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}], 
      LineBox[{{4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}], 
      LineBox[{{4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}], 
      LineBox[{{4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}], 
      LineBox[{{4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}], 
      LineBox[{{4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}], 
      LineBox[{{4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}], 
      LineBox[{{4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}], 
      LineBox[{{4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}], 
      LineBox[{{4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}], 
      LineBox[{{4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}], 
      LineBox[{{4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}], 
      LineBox[{{4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}], 
      LineBox[{{4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}], 
      LineBox[{{4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}], 
      LineBox[{{4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}], 
      LineBox[{{4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}], 
      LineBox[{{4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}], 
      LineBox[{{4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}], 
      LineBox[{{4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}], 
      LineBox[{{4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}], 
      LineBox[{{4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}], 
      LineBox[{{4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}], 
      LineBox[{{4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}], 
      LineBox[{{4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}], 
      LineBox[{{4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}], 
      LineBox[{{4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}], 
      LineBox[{{4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}], 
      LineBox[{{4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}], 
      LineBox[{{4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}], 
      LineBox[{{4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}], 
      LineBox[{{4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}], 
      LineBox[{{4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}], 
      LineBox[{{4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}], 
      LineBox[{{4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}], 
      LineBox[{{4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}], 
      LineBox[{{4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}], 
      LineBox[{{4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}], 
      LineBox[{{4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}], 
      LineBox[{{4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}], 
      LineBox[{{4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}], 
      LineBox[{{4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}], 
      LineBox[{{4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}], 
      LineBox[{{4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}], 
      LineBox[{{4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}], 
      LineBox[{{4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}], 
      LineBox[{{4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}], 
      LineBox[{{4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}], 
      LineBox[{{4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}], 
      LineBox[{{4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}], 
      LineBox[{{4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}], 
      LineBox[{{4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}], 
      LineBox[{{4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}], 
      LineBox[{{4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}], 
      LineBox[{{4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}], 
      LineBox[{{4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}], 
      LineBox[{{4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}], 
      LineBox[{{4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}], 
      LineBox[{{4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}], 
      LineBox[{{4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}], 
      LineBox[{{4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}], 
      LineBox[{{4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}], 
      LineBox[{{4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}], 
      LineBox[{{4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}], 
      LineBox[{{4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}], 
      LineBox[{{4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}], 
      LineBox[{{4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}], 
      LineBox[{{4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}], 
      LineBox[{{4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}], 
      LineBox[{{4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}], 
      LineBox[{{4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}], 
      LineBox[{{4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}], 
      LineBox[{{4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}], 
      LineBox[{{4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}], 
      LineBox[{{4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}], 
      LineBox[{{4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}], 
      LineBox[{{4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}], 
      LineBox[{{4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}], 
      LineBox[{{4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}], 
      LineBox[{{4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}], 
      LineBox[{{4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}], 
      LineBox[{{4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}], 
      LineBox[{{4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}], 
      LineBox[{{4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}], 
      LineBox[{{4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}], 
      LineBox[{{4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}], 
      LineBox[{{4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}], 
      LineBox[{{4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}], 
      LineBox[{{4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}], 
      LineBox[{{4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}], 
      LineBox[{{4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}], 
      LineBox[{{4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}], 
      LineBox[{{4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}], 
      LineBox[{{4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}], 
      LineBox[{{4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}], 
      LineBox[{{4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}], 
      LineBox[{{4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}], 
      LineBox[{{4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}], 
      LineBox[{{4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}], 
      LineBox[{{4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}], 
      LineBox[{{4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}], 
      LineBox[{{4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}], 
      LineBox[{{4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}], 
      LineBox[{{4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}], 
      LineBox[{{4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}], 
      LineBox[{{4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}], 
      LineBox[{{4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}], 
      LineBox[{{4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}], 
      LineBox[{{4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}], 
      LineBox[{{4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}], 
      LineBox[{{4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}], 
      LineBox[{{4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}], 
      LineBox[{{4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}], 
      LineBox[{{4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}], 
      LineBox[{{4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}], 
      LineBox[{{4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.8738891877655433`}, {
       4.416001624487471, -1.8738891877655433`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}], 
      LineBox[{{4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}], 
      LineBox[{{4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}], 
      LineBox[{{4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}], 
      LineBox[{{4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}], 
      LineBox[{{4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}], 
      LineBox[{{4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}], 
      LineBox[{{4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}], 
      LineBox[{{4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}], 
      LineBox[{{4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}], 
      LineBox[{{4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}], 
      LineBox[{{4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}], 
      LineBox[{{4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}], 
      LineBox[{{4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}], 
      LineBox[{{4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}], 
      LineBox[{{4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}], 
      LineBox[{{4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}], 
      LineBox[{{4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}], 
      LineBox[{{4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}], 
      LineBox[{{4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}], 
      LineBox[{{4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}], 
      LineBox[{{4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}], 
      LineBox[{{4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}], 
      LineBox[{{4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}], 
      LineBox[{{4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}], 
      LineBox[{{4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}], 
      LineBox[{{4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}], 
      LineBox[{{4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}], 
      LineBox[{{4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}], 
      LineBox[{{4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}], 
      LineBox[{{4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}], 
      LineBox[{{4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}], 
      LineBox[{{4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}], 
      LineBox[{{4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}], 
      LineBox[{{4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}], 
      LineBox[{{4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}], 
      LineBox[{{4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}], 
      LineBox[{{4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}], 
      LineBox[{{4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}], 
      LineBox[{{4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}], 
      LineBox[{{4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}], 
      LineBox[{{4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}], 
      LineBox[{{4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}], 
      LineBox[{{4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}], 
      LineBox[{{4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}], 
      LineBox[{{4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826337, -1.361074581946569}, {
       4.465432820826337, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.465432820826338, -1.622304792118444}, {
       4.465432820826338, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}], 
      LineBox[{{4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}], 
      LineBox[{{4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}], 
      LineBox[{{4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}], 
      LineBox[{{4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}], 
      LineBox[{{4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}], 
      LineBox[{{4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}], 
      LineBox[{{4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}], 
      LineBox[{{4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}], 
      LineBox[{{4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}], 
      LineBox[{{4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}], 
      LineBox[{{4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}], 
      LineBox[{{4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}], 
      LineBox[{{4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}], 
      LineBox[{{4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}], 
      LineBox[{{4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}], 
      LineBox[{{4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}], 
      LineBox[{{4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}], 
      LineBox[{{4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}], 
      LineBox[{{4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}], 
      LineBox[{{4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}], 
      LineBox[{{4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}], 
      LineBox[{{4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}], 
      LineBox[{{4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}], 
      LineBox[{{4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}], 
      LineBox[{{4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}], 
      LineBox[{{4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}], 
      LineBox[{{4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}], 
      LineBox[{{4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}], 
      LineBox[{{4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}], 
      LineBox[{{4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}], 
      LineBox[{{4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}], 
      LineBox[{{4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}], 
      LineBox[{{4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}], 
      LineBox[{{4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}], 
      LineBox[{{4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}], 
      LineBox[{{4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}], 
      LineBox[{{4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}], 
      LineBox[{{4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}], 
      LineBox[{{4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}], 
      LineBox[{{4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}], 
      LineBox[{{4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}], 
      LineBox[{{4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}], 
      LineBox[{{4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}], 
      LineBox[{{4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}], 
      LineBox[{{4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}], 
      LineBox[{{4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}], 
      LineBox[{{4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}], 
      LineBox[{{4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}], 
      LineBox[{{4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}], 
      LineBox[{{4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}], 
      LineBox[{{4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}], 
      LineBox[{{4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}], 
      LineBox[{{4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}], 
      LineBox[{{4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}], 
      LineBox[{{4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}], 
      LineBox[{{4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}], 
      LineBox[{{4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}], 
      LineBox[{{4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}], 
      LineBox[{{4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}], 
      LineBox[{{4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}], 
      LineBox[{{4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}], 
      LineBox[{{4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}], 
      LineBox[{{4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}], 
      LineBox[{{4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}], 
      LineBox[{{4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}], 
      LineBox[{{4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}], 
      LineBox[{{4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}], 
      LineBox[{{4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}], 
      LineBox[{{4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}], 
      LineBox[{{4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}], 
      LineBox[{{4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}], 
      LineBox[{{4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}], 
      LineBox[{{4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}], 
      LineBox[{{4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}], 
      LineBox[{{4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}], 
      LineBox[{{4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}], 
      LineBox[{{4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}], 
      LineBox[{{4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}], 
      LineBox[{{4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}], 
      LineBox[{{4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}], 
      LineBox[{{4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}], 
      LineBox[{{4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}], 
      LineBox[{{4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}], 
      LineBox[{{4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}], 
      LineBox[{{4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}], 
      LineBox[{{4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}], 
      LineBox[{{4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}], 
      LineBox[{{4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}], 
      LineBox[{{4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}], 
      LineBox[{{4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}], 
      LineBox[{{4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}], 
      LineBox[{{4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}], 
      LineBox[{{4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}], 
      LineBox[{{4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}], 
      LineBox[{{4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}], 
      LineBox[{{4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}], 
      LineBox[{{4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}], 
      LineBox[{{4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}], 
      LineBox[{{4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}], 
      LineBox[{{4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}], 
      LineBox[{{4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}], 
      LineBox[{{4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}], 
      LineBox[{{4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}], 
      LineBox[{{4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}], 
      LineBox[{{4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}], 
      LineBox[{{4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}], 
      LineBox[{{4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}], 
      LineBox[{{4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}], 
      LineBox[{{4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}], 
      LineBox[{{4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}], 
      LineBox[{{4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}], 
      LineBox[{{4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}], 
      LineBox[{{4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}], 
      LineBox[{{4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}], 
      LineBox[{{4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}], 
      LineBox[{{4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}], 
      LineBox[{{4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}], 
      LineBox[{{4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}], 
      LineBox[{{4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}], 
      LineBox[{{4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}], 
      LineBox[{{4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}], 
      LineBox[{{4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}], 
      LineBox[{{4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}], 
      LineBox[{{4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}], 
      LineBox[{{4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}], 
      LineBox[{{4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}], 
      LineBox[{{4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}], 
      LineBox[{{4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}], 
      LineBox[{{4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}], 
      LineBox[{{4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}], 
      LineBox[{{4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}], 
      LineBox[{{4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}], 
      LineBox[{{4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}], 
      LineBox[{{4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}], 
      LineBox[{{4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.405230586241278, 0.09930782547216266}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.033216582995696686`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.390140358038502, 0.033045621238232986`}, {4.390140358038502,
        0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.466653360941616, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.619679366747845, 0.1655700297060923}, {
       4.669519004823792, 0.11937040661661835`}, {4.6961923696509595`, 
       0.033045621238233}, {4.6961923696509595`, 0.033045621238233}, {
       4.669519004823792, 0.11937040661661835`}, {4.619679366747845, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}], 
      LineBox[{{4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}], 
      LineBox[{{4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}], 
      LineBox[{{4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}], 
      LineBox[{{4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}], 
      LineBox[{{4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}], 
      LineBox[{{4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}], 
      LineBox[{{4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}], 
      LineBox[{{4.390140358038502, 0.033045621238232986`}, {4.405230586241278,
        0.09930782547216264}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}}], 
      LineBox[{{4.390140358038502, 0.033045621238232986`}, {4.405230586241278,
        0.09930782547216264}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}}], 
      LineBox[{{4.390140358038502, 0.033045621238232986`}, {4.405230586241278,
        0.09930782547216264}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}}], 
      LineBox[{{4.390140358038502, 0.033045621238232986`}, {4.405230586241278,
        0.09930782547216264}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}}], 
      LineBox[{{4.405230586241278, 0.09930782547216266}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}, {
       4.405230586241278, 0.09930782547216266}, {4.405230586241278, 
       0.09930782547216266}}], 
      LineBox[{{4.405230586241278, 0.09930782547216266}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}, {
       4.405230586241278, 0.09930782547216266}, {4.405230586241278, 
       0.09930782547216266}}], 
      LineBox[{{4.405230586241278, 0.09930782547216266}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}, {
       4.405230586241278, 0.09930782547216266}, {4.405230586241278, 
       0.09930782547216266}}], 
      LineBox[{{4.405230586241278, 0.09930782547216266}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}, {
       4.405230586241278, 0.09930782547216266}, {4.405230586241278, 
       0.09930782547216266}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}], 
      LineBox[{{4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}], 
      LineBox[{{4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}], 
      LineBox[{{4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}], 
      LineBox[{{4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}], 
      LineBox[{{4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}], 
      LineBox[{{4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}], 
      LineBox[{{4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}], 
      LineBox[{{4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}], 
      LineBox[{{4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}], 
      LineBox[{{4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}], 
      LineBox[{{4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}], 
      LineBox[{{4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}], 
      LineBox[{{4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}], 
      LineBox[{{4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}], 
      LineBox[{{4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.466653360941616, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}}], 
      LineBox[{{4.466653360941616, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}}], 
      LineBox[{{4.466653360941616, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}}], 
      LineBox[{{4.466653360941616, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}}], 
      LineBox[{{4.5547495004691205`, 0.18563261085054802`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}}], 
      LineBox[{{4.5547495004691205`, 0.18563261085054802`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}}], 
      LineBox[{{4.5547495004691205`, 0.18563261085054802`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}}], 
      LineBox[{{4.5547495004691205`, 0.18563261085054802`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}}], 
      LineBox[{{4.619679366747845, 0.1655700297060923}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}], 
      LineBox[{{4.619679366747845, 0.1655700297060923}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}], 
      LineBox[{{4.619679366747845, 0.1655700297060923}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}], 
      LineBox[{{4.619679366747845, 0.1655700297060923}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}], 
      LineBox[{{4.669519004823792, 0.11937040661661835`}, {
       4.6961923696509595`, 0.03304562123823296}, {4.6961923696509595`, 
       0.03304562123823296}, {4.669519004823792, 0.11937040661661835`}, {
       4.669519004823792, 0.11937040661661835`}}], 
      LineBox[{{4.669519004823792, 0.11937040661661835`}, {
       4.6961923696509595`, 0.03304562123823296}, {4.6961923696509595`, 
       0.03304562123823296}, {4.669519004823792, 0.11937040661661835`}, {
       4.669519004823792, 0.11937040661661835`}}], 
      LineBox[{{4.669519004823792, 0.11937040661661835`}, {
       4.6961923696509595`, 0.03304562123823296}, {4.6961923696509595`, 
       0.03304562123823296}, {4.669519004823792, 0.11937040661661835`}, {
       4.669519004823792, 0.11937040661661835`}}], 
      LineBox[{{4.669519004823792, 0.11937040661661835`}, {
       4.6961923696509595`, 0.03304562123823296}, {4.6961923696509595`, 
       0.03304562123823296}, {4.669519004823792, 0.11937040661661835`}, {
       4.669519004823792, 0.11937040661661835`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176955}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.3972815645442097}, {4.615938939122161, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.615938939122161, 
       0.35646247982246826`}, {4.659974112421801, 0.3972815645442097}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.480734773418538, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.615938939122161, 0.5906429642161046}, {
       4.659974112421801, 0.5498238794943632}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.5498238794943632}, {4.615938939122161, 
       0.5906429642161046}, {4.5585709881440835`, 0.6083690005927722}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}], 
      LineBox[{{4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}], 
      LineBox[{{4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}], 
      LineBox[{{4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}], 
      LineBox[{{4.426465468245164, 0.41500760092087735`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}}], 
      LineBox[{{4.426465468245164, 0.41500760092087735`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}}], 
      LineBox[{{4.426465468245164, 0.41500760092087735`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}}], 
      LineBox[{{4.426465468245164, 0.41500760092087735`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}}], 
      LineBox[{{4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176955}, {4.426465468245164, 
       0.5320978431176955}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}], 
      LineBox[{{4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176955}, {4.426465468245164, 
       0.5320978431176955}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}], 
      LineBox[{{4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176955}, {4.426465468245164, 
       0.5320978431176955}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}], 
      LineBox[{{4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176955}, {4.426465468245164, 
       0.5320978431176955}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}], 
      LineBox[{{4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176956}, {4.426465468245164, 
       0.5320978431176956}}], 
      LineBox[{{4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176956}, {4.426465468245164, 
       0.5320978431176956}}], 
      LineBox[{{4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176956}, {4.426465468245164, 
       0.5320978431176956}}], 
      LineBox[{{4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176956}, {4.426465468245164, 
       0.5320978431176956}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}}], 
      LineBox[{{4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}}], 
      LineBox[{{4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}}], 
      LineBox[{{4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}}], 
      LineBox[{{4.659974112421801, 0.3972815645442097}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}}], 
      LineBox[{{4.659974112421801, 0.3972815645442097}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}}], 
      LineBox[{{4.659974112421801, 0.3972815645442097}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}}], 
      LineBox[{{4.659974112421801, 0.3972815645442097}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}}], 
      LineBox[{{4.615938939122161, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}}], 
      LineBox[{{4.615938939122161, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}}], 
      LineBox[{{4.615938939122161, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}}], 
      LineBox[{{4.615938939122161, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}}], 
      LineBox[{{4.5585709881440835`, 0.3387364434458006}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}}], 
      LineBox[{{4.5585709881440835`, 0.3387364434458006}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}}], 
      LineBox[{{4.5585709881440835`, 0.3387364434458006}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}}], 
      LineBox[{{4.5585709881440835`, 0.3387364434458006}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.480734773418538, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.5585709881440835`, 0.6083690005927722}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}}], 
      LineBox[{{4.480734773418538, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.5585709881440835`, 0.6083690005927722}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}}], 
      LineBox[{{4.480734773418538, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.5585709881440835`, 0.6083690005927722}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}}], 
      LineBox[{{4.480734773418538, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.5585709881440835`, 0.6083690005927722}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}}], 
      LineBox[{{4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}}], 
      LineBox[{{4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}}], 
      LineBox[{{4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}}], 
      LineBox[{{4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}}], 
      LineBox[{{4.615938939122161, 0.5906429642161046}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}}], 
      LineBox[{{4.615938939122161, 0.5906429642161046}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}}], 
      LineBox[{{4.615938939122161, 0.5906429642161046}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}}], 
      LineBox[{{4.615938939122161, 0.5906429642161046}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}}], 
      LineBox[{{4.659974112421801, 0.5498238794943632}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}}], 
      LineBox[{{4.659974112421801, 0.5498238794943632}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}}], 
      LineBox[{{4.659974112421801, 0.5498238794943632}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}}], 
      LineBox[{{4.659974112421801, 0.5498238794943632}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.334579078046893, 
       1.010806662326981}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       0.910363695568482}, {4.601658560729791, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.601658560729791, 
       0.8566082511049836}, {4.659649334626015, 0.910363695568482}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.423605572274526, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.601658560729791, 1.1650050735489783`}, {
       4.659649334626015, 1.1112496290854799`}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 1.1112496290854799`}, {4.601658560729791, 
       1.1650050735489783`}, {4.526109593284566, 1.1883488346964786`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}], 
      LineBox[{{4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}], 
      LineBox[{{4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}], 
      LineBox[{{4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}], 
      LineBox[{{4.352137271595894, 0.9337074567159822}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 0.9337074567159822}, {4.352137271595894, 
       0.9337074567159822}}], 
      LineBox[{{4.352137271595894, 0.9337074567159822}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 0.9337074567159822}, {4.352137271595894, 
       0.9337074567159822}}], 
      LineBox[{{4.352137271595894, 0.9337074567159822}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 0.9337074567159822}, {4.352137271595894, 
       0.9337074567159822}}], 
      LineBox[{{4.352137271595894, 0.9337074567159822}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 0.9337074567159822}, {4.352137271595894, 
       0.9337074567159822}}], 
      LineBox[{{4.334579078046893, 1.010806662326981}, {4.352137271595894, 
       1.0879058679379796`}, {4.352137271595894, 1.0879058679379796`}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}}], 
      LineBox[{{4.334579078046893, 1.010806662326981}, {4.352137271595894, 
       1.0879058679379796`}, {4.352137271595894, 1.0879058679379796`}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}}], 
      LineBox[{{4.334579078046893, 1.010806662326981}, {4.352137271595894, 
       1.0879058679379796`}, {4.352137271595894, 1.0879058679379796`}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}}], 
      LineBox[{{4.334579078046893, 1.010806662326981}, {4.352137271595894, 
       1.0879058679379796`}, {4.352137271595894, 1.0879058679379796`}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}}], 
      LineBox[{{4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}}], 
      LineBox[{{4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}}], 
      LineBox[{{4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}}], 
      LineBox[{{4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}}], 
      LineBox[{{4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}}], 
      LineBox[{{4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}}], 
      LineBox[{{4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}}], 
      LineBox[{{4.659649334626015, 0.910363695568482}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}}], 
      LineBox[{{4.659649334626015, 0.910363695568482}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}}], 
      LineBox[{{4.659649334626015, 0.910363695568482}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}}], 
      LineBox[{{4.659649334626015, 0.910363695568482}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}}], 
      LineBox[{{4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}], 
      LineBox[{{4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}], 
      LineBox[{{4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}], 
      LineBox[{{4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}], 
      LineBox[{{4.526109593284566, 0.8332644899574833}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.526109593284566, 
       0.8332644899574833}}], 
      LineBox[{{4.526109593284566, 0.8332644899574833}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.526109593284566, 
       0.8332644899574833}}], 
      LineBox[{{4.526109593284566, 0.8332644899574833}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.526109593284566, 
       0.8332644899574833}}], 
      LineBox[{{4.526109593284566, 0.8332644899574833}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.526109593284566, 
       0.8332644899574833}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.423605572274526, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.526109593284566, 1.1883488346964786`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}}], 
      LineBox[{{4.423605572274526, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.526109593284566, 1.1883488346964786`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}}], 
      LineBox[{{4.423605572274526, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.526109593284566, 1.1883488346964786`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}}], 
      LineBox[{{4.423605572274526, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.526109593284566, 1.1883488346964786`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}}], 
      LineBox[{{4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}}], 
      LineBox[{{4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}}], 
      LineBox[{{4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}}], 
      LineBox[{{4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}}], 
      LineBox[{{4.601658560729791, 1.1650050735489783`}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}}], 
      LineBox[{{4.601658560729791, 1.1650050735489783`}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}}], 
      LineBox[{{4.601658560729791, 1.1650050735489783`}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}}], 
      LineBox[{{4.601658560729791, 1.1650050735489783`}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}}], 
      LineBox[{{4.659649334626015, 1.1112496290854799`}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}}], 
      LineBox[{{4.659649334626015, 1.1112496290854799`}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}}], 
      LineBox[{{4.659649334626015, 1.1112496290854799`}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}}], 
      LineBox[{{4.659649334626015, 1.1112496290854799`}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.401465626199836, 
       1.4565727107085416`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`,
        1.3822557366633184`}, {4.599075669223352, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.599075669223352, 
       1.3424824991743407`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.467335640541008, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.599075669223352, 1.5706629222427424`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.664945683564524, 
       1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.599075669223352, 
       1.5706629222427424`}, {4.543177572681962, 1.5879347905208652`}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}], 
      LineBox[{{4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}], 
      LineBox[{{4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}], 
      LineBox[{{4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}], 
      LineBox[{{4.414456797770858, 1.3995276049414411`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.3995276049414411`}, {4.414456797770858, 
       1.3995276049414411`}}], 
      LineBox[{{4.414456797770858, 1.3995276049414411`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.3995276049414411`}, {4.414456797770858, 
       1.3995276049414411`}}], 
      LineBox[{{4.414456797770858, 1.3995276049414411`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.3995276049414411`}, {4.414456797770858, 
       1.3995276049414411`}}], 
      LineBox[{{4.414456797770858, 1.3995276049414411`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.3995276049414411`}, {4.414456797770858, 
       1.3995276049414411`}}], 
      LineBox[{{4.401465626199836, 1.4565727107085416`}, {4.414456797770858, 
       1.513617816475642}, {4.414456797770858, 1.513617816475642}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}}], 
      LineBox[{{4.401465626199836, 1.4565727107085416`}, {4.414456797770858, 
       1.513617816475642}, {4.414456797770858, 1.513617816475642}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}}], 
      LineBox[{{4.401465626199836, 1.4565727107085416`}, {4.414456797770858, 
       1.513617816475642}, {4.414456797770858, 1.513617816475642}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}}], 
      LineBox[{{4.401465626199836, 1.4565727107085416`}, {4.414456797770858, 
       1.513617816475642}, {4.414456797770858, 1.513617816475642}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}}], 
      LineBox[{{4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}}], 
      LineBox[{{4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}}], 
      LineBox[{{4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}}], 
      LineBox[{{4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`,
        1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}}], 
      LineBox[{{4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`,
        1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}}], 
      LineBox[{{4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`,
        1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}}], 
      LineBox[{{4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`,
        1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}}], 
      LineBox[{{4.6419825941937205`, 1.3822557366633184`}, {4.599075669223352,
        1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}}], 
      LineBox[{{4.6419825941937205`, 1.3822557366633184`}, {4.599075669223352,
        1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}}], 
      LineBox[{{4.6419825941937205`, 1.3822557366633184`}, {4.599075669223352,
        1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}}], 
      LineBox[{{4.6419825941937205`, 1.3822557366633184`}, {4.599075669223352,
        1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}}], 
      LineBox[{{4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}], 
      LineBox[{{4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}], 
      LineBox[{{4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}], 
      LineBox[{{4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}], 
      LineBox[{{4.543177572681962, 1.325210630896218}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.543177572681962, 
       1.325210630896218}}], 
      LineBox[{{4.543177572681962, 1.325210630896218}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.543177572681962, 
       1.325210630896218}}], 
      LineBox[{{4.543177572681962, 1.325210630896218}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.543177572681962, 
       1.325210630896218}}], 
      LineBox[{{4.543177572681962, 1.325210630896218}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.543177572681962, 
       1.325210630896218}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.467335640541008, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.543177572681962, 1.5879347905208652`}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}}], 
      LineBox[{{4.467335640541008, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.543177572681962, 1.5879347905208652`}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}}], 
      LineBox[{{4.467335640541008, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.543177572681962, 1.5879347905208652`}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}}], 
      LineBox[{{4.467335640541008, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.543177572681962, 1.5879347905208652`}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}}], 
      LineBox[{{4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}}], 
      LineBox[{{4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}}], 
      LineBox[{{4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}}], 
      LineBox[{{4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}}], 
      LineBox[{{4.599075669223352, 1.5706629222427424`}, {4.6419825941937205`,
        1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}}], 
      LineBox[{{4.599075669223352, 1.5706629222427424`}, {4.6419825941937205`,
        1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}}], 
      LineBox[{{4.599075669223352, 1.5706629222427424`}, {4.6419825941937205`,
        1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}}], 
      LineBox[{{4.599075669223352, 1.5706629222427424`}, {4.6419825941937205`,
        1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}}], 
      LineBox[{{4.6419825941937205`, 1.5308896847537647`}, {4.664945683564524,
        1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}}], 
      LineBox[{{4.6419825941937205`, 1.5308896847537647`}, {4.664945683564524,
        1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}}], 
      LineBox[{{4.6419825941937205`, 1.5308896847537647`}, {4.664945683564524,
        1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}}], 
      LineBox[{{4.6419825941937205`, 1.5308896847537647`}, {4.664945683564524,
        1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.375721509963879, 
       1.9733731022542473`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447,
        1.8822629686709618`}, {4.617984837401234, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.456475952442997, 
       1.8335023049435155`}, {4.456475952442997, 1.8335023049435155`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.617984837401234, 
       1.8335023049435157`}, {4.670587297551447, 1.8822629686709618`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.456475952442997, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.617984837401234, 2.113243899564979}, {
       4.670587297551447, 2.0644832358375327`}, {4.6987392798803524`, 
       1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 2.0644832358375327`}, {4.617984837401234, 
       2.113243899564979}, {4.5494556338327685`, 2.134418634492899}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}], 
      LineBox[{{4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}], 
      LineBox[{{4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}], 
      LineBox[{{4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}], 
      LineBox[{{4.391648253382131, 1.9034377035988814`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 1.9034377035988814`}, {4.391648253382131, 
       1.9034377035988814`}}], 
      LineBox[{{4.391648253382131, 1.9034377035988814`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 1.9034377035988814`}, {4.391648253382131, 
       1.9034377035988814`}}], 
      LineBox[{{4.391648253382131, 1.9034377035988814`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 1.9034377035988814`}, {4.391648253382131, 
       1.9034377035988814`}}], 
      LineBox[{{4.391648253382131, 1.9034377035988814`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 1.9034377035988814`}, {4.391648253382131, 
       1.9034377035988814`}}], 
      LineBox[{{4.375721509963879, 1.9733731022542473`}, {4.391648253382131, 
       2.043308500909613}, {4.391648253382131, 2.043308500909613}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}}], 
      LineBox[{{4.375721509963879, 1.9733731022542473`}, {4.391648253382131, 
       2.043308500909613}, {4.391648253382131, 2.043308500909613}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}}], 
      LineBox[{{4.375721509963879, 1.9733731022542473`}, {4.391648253382131, 
       2.043308500909613}, {4.391648253382131, 2.043308500909613}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}}], 
      LineBox[{{4.375721509963879, 1.9733731022542473`}, {4.391648253382131, 
       2.043308500909613}, {4.391648253382131, 2.043308500909613}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}}], 
      LineBox[{{4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}}], 
      LineBox[{{4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}}], 
      LineBox[{{4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}}], 
      LineBox[{{4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447,
        1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}}], 
      LineBox[{{4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447,
        1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}}], 
      LineBox[{{4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447,
        1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}}], 
      LineBox[{{4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447,
        1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}}], 
      LineBox[{{4.670587297551447, 1.8822629686709618`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}}], 
      LineBox[{{4.670587297551447, 1.8822629686709618`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}}], 
      LineBox[{{4.670587297551447, 1.8822629686709618`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}}], 
      LineBox[{{4.670587297551447, 1.8822629686709618`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}}], 
      LineBox[{{4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`,
        1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}], 
      LineBox[{{4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`,
        1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}], 
      LineBox[{{4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`,
        1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}], 
      LineBox[{{4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`,
        1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}], 
      LineBox[{{4.5494556338327685`, 1.8123275700155959`}, {4.456475952442997,
        1.8335023049435157`}, {4.456475952442997, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.5494556338327685`, 
       1.8123275700155959`}}], 
      LineBox[{{4.5494556338327685`, 1.8123275700155959`}, {4.456475952442997,
        1.8335023049435157`}, {4.456475952442997, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.5494556338327685`, 
       1.8123275700155959`}}], 
      LineBox[{{4.5494556338327685`, 1.8123275700155959`}, {4.456475952442997,
        1.8335023049435157`}, {4.456475952442997, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.5494556338327685`, 
       1.8123275700155959`}}], 
      LineBox[{{4.5494556338327685`, 1.8123275700155959`}, {4.456475952442997,
        1.8335023049435157`}, {4.456475952442997, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.5494556338327685`, 
       1.8123275700155959`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.456475952442997, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.5494556338327685`, 2.134418634492899}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}}], 
      LineBox[{{4.456475952442997, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.5494556338327685`, 2.134418634492899}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}}], 
      LineBox[{{4.456475952442997, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.5494556338327685`, 2.134418634492899}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}}], 
      LineBox[{{4.456475952442997, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.5494556338327685`, 2.134418634492899}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}}], 
      LineBox[{{4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}}], 
      LineBox[{{4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}}], 
      LineBox[{{4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}}], 
      LineBox[{{4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}}], 
      LineBox[{{4.617984837401234, 2.113243899564979}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}}], 
      LineBox[{{4.617984837401234, 2.113243899564979}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}}], 
      LineBox[{{4.617984837401234, 2.113243899564979}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}}], 
      LineBox[{{4.617984837401234, 2.113243899564979}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}}], 
      LineBox[{{4.670587297551447, 2.0644832358375327`}, {4.6987392798803524`,
        1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}}], 
      LineBox[{{4.670587297551447, 2.0644832358375327`}, {4.6987392798803524`,
        1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}}], 
      LineBox[{{4.670587297551447, 2.0644832358375327`}, {4.6987392798803524`,
        1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}}], 
      LineBox[{{4.670587297551447, 2.0644832358375327`}, {4.6987392798803524`,
        1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.33191766748663, 
       2.464307059914166}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.3751661986713355`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.620410167967646, 2.3751661986713355`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410926667568854, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.620410167967646, 2.5534479211569963`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.5534479211569963`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.50189666784431, 2.6218717223558095`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}], 
      LineBox[{{4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}], 
      LineBox[{{4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}], 
      LineBox[{{4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}], 
      LineBox[{{4.34750016714128, 2.395883258715353}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.395883258715353}, {4.34750016714128, 
       2.395883258715353}}], 
      LineBox[{{4.34750016714128, 2.395883258715353}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.395883258715353}, {4.34750016714128, 
       2.395883258715353}}], 
      LineBox[{{4.34750016714128, 2.395883258715353}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.395883258715353}, {4.34750016714128, 
       2.395883258715353}}], 
      LineBox[{{4.34750016714128, 2.395883258715353}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.395883258715353}, {4.34750016714128, 
       2.395883258715353}}], 
      LineBox[{{4.33191766748663, 2.464307059914166}, {4.34750016714128, 
       2.5327308611129786`}, {4.34750016714128, 2.5327308611129786`}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}}], 
      LineBox[{{4.33191766748663, 2.464307059914166}, {4.34750016714128, 
       2.5327308611129786`}, {4.34750016714128, 2.5327308611129786`}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}}], 
      LineBox[{{4.33191766748663, 2.464307059914166}, {4.34750016714128, 
       2.5327308611129786`}, {4.34750016714128, 2.5327308611129786`}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}}], 
      LineBox[{{4.33191766748663, 2.464307059914166}, {4.34750016714128, 
       2.5327308611129786`}, {4.34750016714128, 2.5327308611129786`}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}}], 
      LineBox[{{4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}}], 
      LineBox[{{4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}}], 
      LineBox[{{4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}}], 
      LineBox[{{4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}}], 
      LineBox[{{4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}}], 
      LineBox[{{4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}}], 
      LineBox[{{4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}}], 
      LineBox[{{4.620410167967646, 2.3751661986713355`}, {4.5689446677333025`,
        2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}}], 
      LineBox[{{4.620410167967646, 2.3751661986713355`}, {4.5689446677333025`,
        2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}}], 
      LineBox[{{4.620410167967646, 2.3751661986713355`}, {4.5689446677333025`,
        2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}}], 
      LineBox[{{4.620410167967646, 2.3751661986713355`}, {4.5689446677333025`,
        2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}}], 
      LineBox[{{4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}], 
      LineBox[{{4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}], 
      LineBox[{{4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}], 
      LineBox[{{4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}], 
      LineBox[{{4.50189666784431, 2.3067423974725223`}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.50189666784431, 
       2.3067423974725223`}}], 
      LineBox[{{4.50189666784431, 2.3067423974725223`}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.50189666784431, 
       2.3067423974725223`}}], 
      LineBox[{{4.50189666784431, 2.3067423974725223`}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.50189666784431, 
       2.3067423974725223`}}], 
      LineBox[{{4.50189666784431, 2.3067423974725223`}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.50189666784431, 
       2.3067423974725223`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.410926667568854, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.50189666784431, 2.6218717223558095`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}}], 
      LineBox[{{4.410926667568854, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.50189666784431, 2.6218717223558095`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}}], 
      LineBox[{{4.410926667568854, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.50189666784431, 2.6218717223558095`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}}], 
      LineBox[{{4.410926667568854, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.50189666784431, 2.6218717223558095`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}}], 
      LineBox[{{4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}}], 
      LineBox[{{4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}}], 
      LineBox[{{4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}}], 
      LineBox[{{4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}}], 
      LineBox[{{4.5689446677333025`, 2.6011546623117914`}, {4.620410167967646,
        2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}}], 
      LineBox[{{4.5689446677333025`, 2.6011546623117914`}, {4.620410167967646,
        2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}}], 
      LineBox[{{4.5689446677333025`, 2.6011546623117914`}, {4.620410167967646,
        2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}}], 
      LineBox[{{4.5689446677333025`, 2.6011546623117914`}, {4.620410167967646,
        2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}}], 
      LineBox[{{4.620410167967646, 2.5534479211569963`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}}], 
      LineBox[{{4.620410167967646, 2.5534479211569963`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}}], 
      LineBox[{{4.620410167967646, 2.5534479211569963`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}}], 
      LineBox[{{4.620410167967646, 2.5534479211569963`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 3.0645464425864537`}, {4.448246037231085, 
       3.132985584810507}, {4.448246037231085, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.369219322858757, 
       2.9961073003624}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       2.906946453205628}, {4.606299465975743, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.448246037231086, 
       2.8592290159142935`}, {4.448246037231086, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.606299465975743, 
       2.8592290159142935`}, {4.6577765050828805`, 2.906946453205628}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.448246037231086, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.606299465975743, 3.132985584810507}, {
       4.6577765050828805`, 3.085268147519172}, {4.6853261803480715`, 
       2.9961073003624}, {4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 3.085268147519172}, {4.606299465975743, 
       3.132985584810507}, {4.539236433524387, 3.1537072897432257`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}], 
      LineBox[{{4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}], 
      LineBox[{{4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}], 
      LineBox[{{4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}], 
      LineBox[{{4.384805316202975, 2.9276681581383466`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 2.9276681581383466`}, {4.384805316202975, 
       2.9276681581383466`}}], 
      LineBox[{{4.384805316202975, 2.9276681581383466`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 2.9276681581383466`}, {4.384805316202975, 
       2.9276681581383466`}}], 
      LineBox[{{4.384805316202975, 2.9276681581383466`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 2.9276681581383466`}, {4.384805316202975, 
       2.9276681581383466`}}], 
      LineBox[{{4.384805316202975, 2.9276681581383466`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 2.9276681581383466`}, {4.384805316202975, 
       2.9276681581383466`}}], 
      LineBox[{{4.369219322858757, 2.9961073003624}, {4.384805316202975, 
       3.0645464425864537`}, {4.384805316202975, 3.0645464425864537`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}}], 
      LineBox[{{4.369219322858757, 2.9961073003624}, {4.384805316202975, 
       3.0645464425864537`}, {4.384805316202975, 3.0645464425864537`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}}], 
      LineBox[{{4.369219322858757, 2.9961073003624}, {4.384805316202975, 
       3.0645464425864537`}, {4.384805316202975, 3.0645464425864537`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}}], 
      LineBox[{{4.369219322858757, 2.9961073003624}, {4.384805316202975, 
       3.0645464425864537`}, {4.384805316202975, 3.0645464425864537`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}}], 
      LineBox[{{4.384805316202975, 3.0645464425864537`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}}], 
      LineBox[{{4.384805316202975, 3.0645464425864537`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}}], 
      LineBox[{{4.384805316202975, 3.0645464425864537`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}}], 
      LineBox[{{4.384805316202975, 3.0645464425864537`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}}], 
      LineBox[{{4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}}], 
      LineBox[{{4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}}], 
      LineBox[{{4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}}], 
      LineBox[{{4.6577765050828805`, 2.906946453205628}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}}], 
      LineBox[{{4.6577765050828805`, 2.906946453205628}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}}], 
      LineBox[{{4.6577765050828805`, 2.906946453205628}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}}], 
      LineBox[{{4.6577765050828805`, 2.906946453205628}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}}], 
      LineBox[{{4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}], 
      LineBox[{{4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}], 
      LineBox[{{4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}], 
      LineBox[{{4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}], 
      LineBox[{{4.539236433524387, 2.8385073109815746`}, {4.448246037231085, 
       2.8592290159142935`}, {4.448246037231085, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.539236433524387, 
       2.8385073109815746`}}], 
      LineBox[{{4.539236433524387, 2.8385073109815746`}, {4.448246037231085, 
       2.8592290159142935`}, {4.448246037231085, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.539236433524387, 
       2.8385073109815746`}}], 
      LineBox[{{4.539236433524387, 2.8385073109815746`}, {4.448246037231085, 
       2.8592290159142935`}, {4.448246037231085, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.539236433524387, 
       2.8385073109815746`}}], 
      LineBox[{{4.539236433524387, 2.8385073109815746`}, {4.448246037231085, 
       2.8592290159142935`}, {4.448246037231085, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.539236433524387, 
       2.8385073109815746`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.448246037231086, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.539236433524387, 3.1537072897432257`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}}], 
      LineBox[{{4.448246037231086, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.539236433524387, 3.1537072897432257`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}}], 
      LineBox[{{4.448246037231086, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.539236433524387, 3.1537072897432257`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}}], 
      LineBox[{{4.448246037231086, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.539236433524387, 3.1537072897432257`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}}], 
      LineBox[{{4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}}], 
      LineBox[{{4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}}], 
      LineBox[{{4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}}], 
      LineBox[{{4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}}], 
      LineBox[{{4.606299465975743, 3.132985584810507}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}}], 
      LineBox[{{4.606299465975743, 3.132985584810507}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}}], 
      LineBox[{{4.606299465975743, 3.132985584810507}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}}], 
      LineBox[{{4.606299465975743, 3.132985584810507}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}}], 
      LineBox[{{4.6577765050828805`, 3.085268147519172}, {4.6853261803480715`,
        2.9961073003624}, {4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}}], 
      LineBox[{{4.6577765050828805`, 3.085268147519172}, {4.6853261803480715`,
        2.9961073003624}, {4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}}], 
      LineBox[{{4.6577765050828805`, 3.085268147519172}, {4.6853261803480715`,
        2.9961073003624}, {4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}}], 
      LineBox[{{4.6577765050828805`, 3.085268147519172}, {4.6853261803480715`,
        2.9961073003624}, {4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.395452954243414, 
       3.536211307589053}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.4516199077549645`}, {4.62038286259062, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.62038286259062, 
       3.406347964455996}, {4.669221730055957, 3.4516199077549645`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.470429590359148, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.62038286259062, 3.66607465072211}, {
       4.669221730055957, 3.6208027074231417`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.6208027074231417`}, {4.62038286259062, 
       3.66607465072211}, {4.556756775882355, 3.6857343789896704`}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}], 
      LineBox[{{4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}], 
      LineBox[{{4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}], 
      LineBox[{{4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}], 
      LineBox[{{4.41024017348634, 3.4712796360225244`}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.4712796360225244`}, {4.41024017348634, 
       3.4712796360225244`}}], 
      LineBox[{{4.41024017348634, 3.4712796360225244`}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.4712796360225244`}, {4.41024017348634, 
       3.4712796360225244`}}], 
      LineBox[{{4.41024017348634, 3.4712796360225244`}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.4712796360225244`}, {4.41024017348634, 
       3.4712796360225244`}}], 
      LineBox[{{4.41024017348634, 3.4712796360225244`}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.4712796360225244`}, {4.41024017348634, 
       3.4712796360225244`}}], 
      LineBox[{{4.395452954243414, 3.536211307589053}, {4.41024017348634, 
       3.601142979155582}, {4.41024017348634, 3.601142979155582}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}}], 
      LineBox[{{4.395452954243414, 3.536211307589053}, {4.41024017348634, 
       3.601142979155582}, {4.41024017348634, 3.601142979155582}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}}], 
      LineBox[{{4.395452954243414, 3.536211307589053}, {4.41024017348634, 
       3.601142979155582}, {4.41024017348634, 3.601142979155582}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}}], 
      LineBox[{{4.395452954243414, 3.536211307589053}, {4.41024017348634, 
       3.601142979155582}, {4.41024017348634, 3.601142979155582}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}}], 
      LineBox[{{4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}}], 
      LineBox[{{4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}}], 
      LineBox[{{4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}}], 
      LineBox[{{4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}}], 
      LineBox[{{4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}}], 
      LineBox[{{4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}}], 
      LineBox[{{4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}}], 
      LineBox[{{4.669221730055957, 3.4516199077549645`}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}}], 
      LineBox[{{4.669221730055957, 3.4516199077549645`}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}}], 
      LineBox[{{4.669221730055957, 3.4516199077549645`}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}}], 
      LineBox[{{4.669221730055957, 3.4516199077549645`}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}}], 
      LineBox[{{4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}], 
      LineBox[{{4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}], 
      LineBox[{{4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}], 
      LineBox[{{4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}], 
      LineBox[{{4.556756775882355, 3.386688236188436}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.556756775882355, 
       3.386688236188436}}], 
      LineBox[{{4.556756775882355, 3.386688236188436}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.556756775882355, 
       3.386688236188436}}], 
      LineBox[{{4.556756775882355, 3.386688236188436}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.556756775882355, 
       3.386688236188436}}], 
      LineBox[{{4.556756775882355, 3.386688236188436}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.556756775882355, 
       3.386688236188436}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.470429590359148, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.556756775882355, 3.6857343789896704`}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}}], 
      LineBox[{{4.470429590359148, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.556756775882355, 3.6857343789896704`}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}}], 
      LineBox[{{4.470429590359148, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.556756775882355, 3.6857343789896704`}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}}], 
      LineBox[{{4.470429590359148, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.556756775882355, 3.6857343789896704`}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}}], 
      LineBox[{{4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}}], 
      LineBox[{{4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}}], 
      LineBox[{{4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}}], 
      LineBox[{{4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}}], 
      LineBox[{{4.62038286259062, 3.66607465072211}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}}], 
      LineBox[{{4.62038286259062, 3.66607465072211}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}}], 
      LineBox[{{4.62038286259062, 3.66607465072211}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}}], 
      LineBox[{{4.62038286259062, 3.66607465072211}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}}], 
      LineBox[{{4.669221730055957, 3.6208027074231417`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}}], 
      LineBox[{{4.669221730055957, 3.6208027074231417`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}}], 
      LineBox[{{4.669221730055957, 3.6208027074231417`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}}], 
      LineBox[{{4.669221730055957, 3.6208027074231417`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}], 
      LineBox[{{4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}], 
      LineBox[{{4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}], 
      LineBox[{{4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}], 
      LineBox[{{4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}], 
      LineBox[{{4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}], 
      LineBox[{{4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}], 
      LineBox[{{4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}], 
      LineBox[{{4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}], 
      LineBox[{{4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}], 
      LineBox[{{4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}], 
      LineBox[{{4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}], 
      LineBox[{{4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}], 
      LineBox[{{4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}], 
      LineBox[{{4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}], 
      LineBox[{{4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}], 
      LineBox[{{4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}], 
      LineBox[{{4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}], 
      LineBox[{{4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}], 
      LineBox[{{4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}], 
      LineBox[{{4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}], 
      LineBox[{{4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}], 
      LineBox[{{4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}], 
      LineBox[{{4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}], 
      LineBox[{{4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}], 
      LineBox[{{4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}], 
      LineBox[{{4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}], 
      LineBox[{{4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}], 
      LineBox[{{4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}], 
      LineBox[{{4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}], 
      LineBox[{{4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}], 
      LineBox[{{4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}], 
      LineBox[{{4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}], 
      LineBox[{{4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}], 
      LineBox[{{4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}], 
      LineBox[{{4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}], 
      LineBox[{{4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}], 
      LineBox[{{4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}], 
      LineBox[{{4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}], 
      LineBox[{{4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}], 
      LineBox[{{4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}], 
      LineBox[{{4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}], 
      LineBox[{{4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}], 
      LineBox[{{4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}], 
      LineBox[{{4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}], 
      LineBox[{{4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.6295947149828365`, -3.6422505778556866`}, {
       4.6295947149828365`, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.629594714982837, -3.901947432901194}, {
       4.629594714982837, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}], 
      LineBox[{{4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}], 
      LineBox[{{4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}], 
      LineBox[{{4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}], 
      LineBox[{{4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}], 
      LineBox[{{4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}], 
      LineBox[{{4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}], 
      LineBox[{{4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}], 
      LineBox[{{4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}], 
      LineBox[{{4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}], 
      LineBox[{{4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}], 
      LineBox[{{4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}], 
      LineBox[{{4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}], 
      LineBox[{{4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}], 
      LineBox[{{4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}], 
      LineBox[{{4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}], 
      LineBox[{{4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}], 
      LineBox[{{4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}], 
      LineBox[{{4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}], 
      LineBox[{{4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}], 
      LineBox[{{4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}], 
      LineBox[{{4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}], 
      LineBox[{{4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}], 
      LineBox[{{4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}], 
      LineBox[{{4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}], 
      LineBox[{{4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}], 
      LineBox[{{4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}], 
      LineBox[{{4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}], 
      LineBox[{{4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}], 
      LineBox[{{4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}], 
      LineBox[{{4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}], 
      LineBox[{{4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}], 
      LineBox[{{4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}], 
      LineBox[{{4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}], 
      LineBox[{{4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}], 
      LineBox[{{4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}], 
      LineBox[{{4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}], 
      LineBox[{{4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}], 
      LineBox[{{4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}], 
      LineBox[{{4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}], 
      LineBox[{{4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}], 
      LineBox[{{4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}], 
      LineBox[{{4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}], 
      LineBox[{{4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}], 
      LineBox[{{4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}], 
      LineBox[{{4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}], 
      LineBox[{{4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}], 
      LineBox[{{4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}], 
      LineBox[{{4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}], 
      LineBox[{{4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}], 
      LineBox[{{4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}], 
      LineBox[{{4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}], 
      LineBox[{{4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}], 
      LineBox[{{4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}], 
      LineBox[{{4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}], 
      LineBox[{{4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}], 
      LineBox[{{4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}], 
      LineBox[{{4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}], 
      LineBox[{{4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}], 
      LineBox[{{4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}], 
      LineBox[{{4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}], 
      LineBox[{{4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}], 
      LineBox[{{4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}], 
      LineBox[{{4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}], 
      LineBox[{{4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}], 
      LineBox[{{4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}], 
      LineBox[{{4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}], 
      LineBox[{{4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}], 
      LineBox[{{4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}], 
      LineBox[{{4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}], 
      LineBox[{{4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}], 
      LineBox[{{4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}], 
      LineBox[{{4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}], 
      LineBox[{{4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}], 
      LineBox[{{4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}], 
      LineBox[{{4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}], 
      LineBox[{{4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}], 
      LineBox[{{4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}], 
      LineBox[{{4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}], 
      LineBox[{{4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}], 
      LineBox[{{4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}], 
      LineBox[{{4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}], 
      LineBox[{{4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}], 
      LineBox[{{4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}], 
      LineBox[{{4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}], 
      LineBox[{{4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}], 
      LineBox[{{4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}], 
      LineBox[{{4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}], 
      LineBox[{{4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}], 
      LineBox[{{4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}], 
      LineBox[{{4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}], 
      LineBox[{{4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}], 
      LineBox[{{4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}], 
      LineBox[{{4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}], 
      LineBox[{{4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}], 
      LineBox[{{4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}], 
      LineBox[{{4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}], 
      LineBox[{{4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}], 
      LineBox[{{4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}], 
      LineBox[{{4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}], 
      LineBox[{{4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}], 
      LineBox[{{4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}], 
      LineBox[{{4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}], 
      LineBox[{{4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}], 
      LineBox[{{4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}], 
      LineBox[{{4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}], 
      LineBox[{{4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}], 
      LineBox[{{4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}], 
      LineBox[{{4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}], 
      LineBox[{{4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}], 
      LineBox[{{4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}], 
      LineBox[{{4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}], 
      LineBox[{{4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}], 
      LineBox[{{4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}], 
      LineBox[{{4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}], 
      LineBox[{{4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}], 
      LineBox[{{4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}], 
      LineBox[{{4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}], 
      LineBox[{{4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}], 
      LineBox[{{4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}], 
      LineBox[{{4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}], 
      LineBox[{{4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}], 
      LineBox[{{4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}], 
      LineBox[{{4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}], 
      LineBox[{{4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}], 
      LineBox[{{4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}], 
      LineBox[{{4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}], 
      LineBox[{{4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}], 
      LineBox[{{4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}], 
      LineBox[{{4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}], 
      LineBox[{{4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}], 
      LineBox[{{4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}], 
      LineBox[{{4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}], 
      LineBox[{{4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}], 
      LineBox[{{4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}], 
      LineBox[{{4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.1240829876163936`}, {
       4.698940132472584, -2.1240829876163936`}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.3784288023735765`}, {
       4.698940132472584, -2.3784288023735765`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}], 
      LineBox[{{4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}], 
      LineBox[{{4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}], 
      LineBox[{{4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}], 
      LineBox[{{4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}], 
      LineBox[{{4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}], 
      LineBox[{{4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}], 
      LineBox[{{4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}], 
      LineBox[{{4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}], 
      LineBox[{{4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}], 
      LineBox[{{4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}], 
      LineBox[{{4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}], 
      LineBox[{{4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}], 
      LineBox[{{4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}], 
      LineBox[{{4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}], 
      LineBox[{{4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}], 
      LineBox[{{4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}], 
      LineBox[{{4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}], 
      LineBox[{{4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}], 
      LineBox[{{4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}], 
      LineBox[{{4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}], 
      LineBox[{{4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}], 
      LineBox[{{4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}], 
      LineBox[{{4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}], 
      LineBox[{{4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}], 
      LineBox[{{4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}], 
      LineBox[{{4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}], 
      LineBox[{{4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}], 
      LineBox[{{4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}], 
      LineBox[{{4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}], 
      LineBox[{{4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}], 
      LineBox[{{4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}], 
      LineBox[{{4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}], 
      LineBox[{{4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}], 
      LineBox[{{4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}], 
      LineBox[{{4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}], 
      LineBox[{{4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}], 
      LineBox[{{4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}], 
      LineBox[{{4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}], 
      LineBox[{{4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}], 
      LineBox[{{4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}], 
      LineBox[{{4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}], 
      LineBox[{{4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}], 
      LineBox[{{4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}], 
      LineBox[{{4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}], 
      LineBox[{{4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.679032421183577, -1.5740616887609251`}, {
       4.679032421183577, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.679032421183578, -1.8352918989328}, {
       4.679032421183578, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}], 
      LineBox[{{4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}], 
      LineBox[{{4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}], 
      LineBox[{{4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}], 
      LineBox[{{4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}], 
      LineBox[{{4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}], 
      LineBox[{{4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}], 
      LineBox[{{4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}], 
      LineBox[{{4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}], 
      LineBox[{{4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}], 
      LineBox[{{4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}], 
      LineBox[{{4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}], 
      LineBox[{{4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}], 
      LineBox[{{4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}], 
      LineBox[{{4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}], 
      LineBox[{{4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}], 
      LineBox[{{4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}], 
      LineBox[{{4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}], 
      LineBox[{{4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}], 
      LineBox[{{4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}], 
      LineBox[{{4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}], 
      LineBox[{{4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}], 
      LineBox[{{4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}], 
      LineBox[{{4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}], 
      LineBox[{{4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}], 
      LineBox[{{4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}], 
      LineBox[{{4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}], 
      LineBox[{{4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}], 
      LineBox[{{4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}], 
      LineBox[{{4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}], 
      LineBox[{{4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}], 
      LineBox[{{4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}], 
      LineBox[{{4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}], 
      LineBox[{{4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}], 
      LineBox[{{4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}], 
      LineBox[{{4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}], 
      LineBox[{{4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}], 
      LineBox[{{4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}], 
      LineBox[{{4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}], 
      LineBox[{{4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}], 
      LineBox[{{4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}], 
      LineBox[{{4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}], 
      LineBox[{{4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}], 
      LineBox[{{4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}], 
      LineBox[{{4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}], 
      LineBox[{{4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.2799140717567363`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}], 
      LineBox[{{4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}], 
      LineBox[{{4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}], 
      LineBox[{{4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}], 
      LineBox[{{4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}], 
      LineBox[{{4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}], 
      LineBox[{{4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}], 
      LineBox[{{4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}], 
      LineBox[{{4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}], 
      LineBox[{{4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}], 
      LineBox[{{4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}], 
      LineBox[{{4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}], 
      LineBox[{{4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}], 
      LineBox[{{4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}], 
      LineBox[{{4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}], 
      LineBox[{{4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}], 
      LineBox[{{4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}], 
      LineBox[{{4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}], 
      LineBox[{{4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}], 
      LineBox[{{4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}], 
      LineBox[{{4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}], 
      LineBox[{{4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}], 
      LineBox[{{4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}], 
      LineBox[{{4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}], 
      LineBox[{{4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}], 
      LineBox[{{4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}], 
      LineBox[{{4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}], 
      LineBox[{{4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}], 
      LineBox[{{4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}], 
      LineBox[{{4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}], 
      LineBox[{{4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}], 
      LineBox[{{4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}], 
      LineBox[{{4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}], 
      LineBox[{{4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}], 
      LineBox[{{4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}], 
      LineBox[{{4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}], 
      LineBox[{{4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}], 
      LineBox[{{4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}], 
      LineBox[{{4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}], 
      LineBox[{{4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}], 
      LineBox[{{4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}], 
      LineBox[{{4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}], 
      LineBox[{{4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}], 
      LineBox[{{4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}], 
      LineBox[{{4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}], 
      LineBox[{{4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}], 
      LineBox[{{4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}], 
      LineBox[{{4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}], 
      LineBox[{{4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}], 
      LineBox[{{4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}], 
      LineBox[{{4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}], 
      LineBox[{{4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}], 
      LineBox[{{4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}], 
      LineBox[{{4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}], 
      LineBox[{{4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}], 
      LineBox[{{4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}], 
      LineBox[{{4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}], 
      LineBox[{{4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}], 
      LineBox[{{4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}], 
      LineBox[{{4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}], 
      LineBox[{{4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}], 
      LineBox[{{4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}], 
      LineBox[{{4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}], 
      LineBox[{{4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}], 
      LineBox[{{4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}], 
      LineBox[{{4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}], 
      LineBox[{{4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}], 
      LineBox[{{4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}], 
      LineBox[{{4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}], 
      LineBox[{{4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}], 
      LineBox[{{4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}], 
      LineBox[{{4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}], 
      LineBox[{{4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}], 
      LineBox[{{4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}], 
      LineBox[{{4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}], 
      LineBox[{{4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}], 
      LineBox[{{4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}], 
      LineBox[{{4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}], 
      LineBox[{{4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}], 
      LineBox[{{4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}], 
      LineBox[{{4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}], 
      LineBox[{{4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}], 
      LineBox[{{4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}], 
      LineBox[{{4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}], 
      LineBox[{{4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}], 
      LineBox[{{4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}], 
      LineBox[{{4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}], 
      LineBox[{{4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}], 
      LineBox[{{4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}], 
      LineBox[{{4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}], 
      LineBox[{{4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833331}, {
       4.6417842317253495`, -0.09563014472833331}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240929}, {
       4.6417842317253495`, -0.3752411744240929}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.23543565957621304`}, {
       4.883934486620202, -0.23543565957621304`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}], 
      LineBox[{{4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}], 
      LineBox[{{4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}], 
      LineBox[{{4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}], 
      LineBox[{{4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}], 
      LineBox[{{4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}], 
      LineBox[{{4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}], 
      LineBox[{{4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}], 
      LineBox[{{4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}], 
      LineBox[{{4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}], 
      LineBox[{{4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}], 
      LineBox[{{4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}], 
      LineBox[{{4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}], 
      LineBox[{{4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}], 
      LineBox[{{4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}], 
      LineBox[{{4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}], 
      LineBox[{{4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}], 
      LineBox[{{4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}], 
      LineBox[{{4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}], 
      LineBox[{{4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}], 
      LineBox[{{4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}], 
      LineBox[{{4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}], 
      LineBox[{{4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}], 
      LineBox[{{4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}], 
      LineBox[{{4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}], 
      LineBox[{{4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}], 
      LineBox[{{4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}], 
      LineBox[{{4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}], 
      LineBox[{{4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}], 
      LineBox[{{4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}], 
      LineBox[{{4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}], 
      LineBox[{{4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}], 
      LineBox[{{4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}], 
      LineBox[{{4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}], 
      LineBox[{{4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}], 
      LineBox[{{4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}], 
      LineBox[{{4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}], 
      LineBox[{{4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}], 
      LineBox[{{4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}], 
      LineBox[{{4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}], 
      LineBox[{{4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}], 
      LineBox[{{4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}], 
      LineBox[{{4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}], 
      LineBox[{{4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}], 
      LineBox[{{4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}], 
      LineBox[{{4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.663699681880105, 0.15735319333361192`}, {4.60943037670673, 
       0.215898314432021}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.3329885566288392}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}, {
       4.60943037670673, 0.3329885566288392}, {4.596097599028293, 
       0.2744434355304301}, {4.60943037670673, 0.215898314432021}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.798903847583728, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.798903847583728, 
       0.15735319333361192`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.798903847583728, 0.3915336777272483}, {
       4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.798903847583728, 
       0.3915336777272483}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.663699681880105, 0.15735319333361192`}, {4.60943037670673, 
       0.215898314432021}, {4.60943037670673, 0.215898314432021}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}}], 
      LineBox[{{4.663699681880105, 0.15735319333361192`}, {4.60943037670673, 
       0.215898314432021}, {4.60943037670673, 0.215898314432021}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}}], 
      LineBox[{{4.663699681880105, 0.15735319333361192`}, {4.60943037670673, 
       0.215898314432021}, {4.60943037670673, 0.215898314432021}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}}], 
      LineBox[{{4.663699681880105, 0.15735319333361192`}, {4.60943037670673, 
       0.215898314432021}, {4.60943037670673, 0.215898314432021}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}}], 
      LineBox[{{4.60943037670673, 0.215898314432021}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}}], 
      LineBox[{{4.60943037670673, 0.215898314432021}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}}], 
      LineBox[{{4.60943037670673, 0.215898314432021}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}}], 
      LineBox[{{4.60943037670673, 0.215898314432021}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}}], 
      LineBox[{{4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}], 
      LineBox[{{4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}], 
      LineBox[{{4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}], 
      LineBox[{{4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}], 
      LineBox[{{4.60943037670673, 0.3329885566288392}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}}], 
      LineBox[{{4.60943037670673, 0.3329885566288392}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}}], 
      LineBox[{{4.60943037670673, 0.3329885566288392}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}}], 
      LineBox[{{4.60943037670673, 0.3329885566288392}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}], 
      LineBox[{{4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}], 
      LineBox[{{4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}], 
      LineBox[{{4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}], 
      LineBox[{{4.842939020883367, 0.19817227805535337`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.842939020883367, 0.19817227805535337`}, {4.842939020883367, 
       0.19817227805535337`}}], 
      LineBox[{{4.842939020883367, 0.19817227805535337`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.842939020883367, 0.19817227805535337`}, {4.842939020883367, 
       0.19817227805535337`}}], 
      LineBox[{{4.842939020883367, 0.19817227805535337`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.842939020883367, 0.19817227805535337`}, {4.842939020883367, 
       0.19817227805535337`}}], 
      LineBox[{{4.842939020883367, 0.19817227805535337`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.842939020883367, 0.19817227805535337`}, {4.842939020883367, 
       0.19817227805535337`}}], 
      LineBox[{{4.798903847583728, 0.15735319333361192`}, {4.74153589660565, 
       0.13962715695694428`}, {4.74153589660565, 0.13962715695694428`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}}], 
      LineBox[{{4.798903847583728, 0.15735319333361192`}, {4.74153589660565, 
       0.13962715695694428`}, {4.74153589660565, 0.13962715695694428`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}}], 
      LineBox[{{4.798903847583728, 0.15735319333361192`}, {4.74153589660565, 
       0.13962715695694428`}, {4.74153589660565, 0.13962715695694428`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}}], 
      LineBox[{{4.798903847583728, 0.15735319333361192`}, {4.74153589660565, 
       0.13962715695694428`}, {4.74153589660565, 0.13962715695694428`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}}], 
      LineBox[{{4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}}], 
      LineBox[{{4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}}], 
      LineBox[{{4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}}], 
      LineBox[{{4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}], 
      LineBox[{{4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}], 
      LineBox[{{4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}], 
      LineBox[{{4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}], 
      LineBox[{{4.74153589660565, 0.40925971410391593`}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}}], 
      LineBox[{{4.74153589660565, 0.40925971410391593`}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}}], 
      LineBox[{{4.74153589660565, 0.40925971410391593`}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}}], 
      LineBox[{{4.74153589660565, 0.40925971410391593`}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}}], 
      LineBox[{{4.798903847583728, 0.3915336777272483}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}], 
      LineBox[{{4.798903847583728, 0.3915336777272483}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}], 
      LineBox[{{4.798903847583728, 0.3915336777272483}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}], 
      LineBox[{{4.798903847583728, 0.3915336777272483}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}], 
      LineBox[{{4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.842939020883367, 
       0.35071459300550684`}}], 
      LineBox[{{4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.842939020883367, 
       0.35071459300550684`}}], 
      LineBox[{{4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.842939020883367, 
       0.35071459300550684`}}], 
      LineBox[{{4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.842939020883367, 
       0.35071459300550684`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.666669201903647, 0.58238880896803}, {4.603603926616283, 
       0.6504229245147085}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.7864911556080653}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}, {
       4.603603926616283, 0.7864911556080653}, {4.588110172053741, 
       0.7184570400613869}, {4.603603926616283, 0.6504229245147085}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.823787261603459, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.823787261603459, 
       0.58238880896803}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.823787261603459, 0.8545252711547437}, {
       4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.823787261603459, 
       0.8545252711547437}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.666669201903647, 0.58238880896803}, {4.603603926616283, 
       0.6504229245147085}, {4.603603926616283, 0.6504229245147085}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}}], 
      LineBox[{{4.666669201903647, 0.58238880896803}, {4.603603926616283, 
       0.6504229245147085}, {4.603603926616283, 0.6504229245147085}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}}], 
      LineBox[{{4.666669201903647, 0.58238880896803}, {4.603603926616283, 
       0.6504229245147085}, {4.603603926616283, 0.6504229245147085}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}}], 
      LineBox[{{4.666669201903647, 0.58238880896803}, {4.603603926616283, 
       0.6504229245147085}, {4.603603926616283, 0.6504229245147085}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}}], 
      LineBox[{{4.603603926616283, 0.6504229245147085}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}}], 
      LineBox[{{4.603603926616283, 0.6504229245147085}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}}], 
      LineBox[{{4.603603926616283, 0.6504229245147085}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}}], 
      LineBox[{{4.603603926616283, 0.6504229245147085}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}}], 
      LineBox[{{4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}], 
      LineBox[{{4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}], 
      LineBox[{{4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}], 
      LineBox[{{4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}], 
      LineBox[{{4.603603926616283, 0.7864911556080653}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}}], 
      LineBox[{{4.603603926616283, 0.7864911556080653}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}}], 
      LineBox[{{4.603603926616283, 0.7864911556080653}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}}], 
      LineBox[{{4.603603926616283, 0.7864911556080653}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}], 
      LineBox[{{4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}], 
      LineBox[{{4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}], 
      LineBox[{{4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}], 
      LineBox[{{4.874959656709618, 0.6298238517925308}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.874959656709618, 0.6298238517925308}, {4.874959656709618, 
       0.6298238517925308}}], 
      LineBox[{{4.874959656709618, 0.6298238517925308}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.874959656709618, 0.6298238517925308}, {4.874959656709618, 
       0.6298238517925308}}], 
      LineBox[{{4.874959656709618, 0.6298238517925308}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.874959656709618, 0.6298238517925308}, {4.874959656709618, 
       0.6298238517925308}}], 
      LineBox[{{4.874959656709618, 0.6298238517925308}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.874959656709618, 0.6298238517925308}, {4.874959656709618, 
       0.6298238517925308}}], 
      LineBox[{{4.823787261603459, 0.58238880896803}, {4.757121111934759, 
       0.5617897362458524}, {4.757121111934759, 0.5617897362458524}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}}], 
      LineBox[{{4.823787261603459, 0.58238880896803}, {4.757121111934759, 
       0.5617897362458524}, {4.757121111934759, 0.5617897362458524}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}}], 
      LineBox[{{4.823787261603459, 0.58238880896803}, {4.757121111934759, 
       0.5617897362458524}, {4.757121111934759, 0.5617897362458524}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}}], 
      LineBox[{{4.823787261603459, 0.58238880896803}, {4.757121111934759, 
       0.5617897362458524}, {4.757121111934759, 0.5617897362458524}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}}], 
      LineBox[{{4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}}], 
      LineBox[{{4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}}], 
      LineBox[{{4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}}], 
      LineBox[{{4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}], 
      LineBox[{{4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}], 
      LineBox[{{4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}], 
      LineBox[{{4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}], 
      LineBox[{{4.757121111934759, 0.8751243438769214}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}}], 
      LineBox[{{4.757121111934759, 0.8751243438769214}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}}], 
      LineBox[{{4.757121111934759, 0.8751243438769214}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}}], 
      LineBox[{{4.757121111934759, 0.8751243438769214}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}}], 
      LineBox[{{4.823787261603459, 0.8545252711547437}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}], 
      LineBox[{{4.823787261603459, 0.8545252711547437}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}], 
      LineBox[{{4.823787261603459, 0.8545252711547437}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}], 
      LineBox[{{4.823787261603459, 0.8545252711547437}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}], 
      LineBox[{{4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.874959656709618, 
       0.807090228330243}}], 
      LineBox[{{4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.874959656709618, 
       0.807090228330243}}], 
      LineBox[{{4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.874959656709618, 
       0.807090228330243}}], 
      LineBox[{{4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.874959656709618, 
       0.807090228330243}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.67002552391586, 1.174141916407176}, {4.61714668114571, 
       1.2311870221742764`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.3452772337084773`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}, {
       4.61714668114571, 1.3452772337084773`}, {4.604155509574688, 
       1.2882321279413769`}, {4.61714668114571, 1.2311870221742764`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.801765552598204, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.801765552598204, 
       1.174141916407176}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.801765552598204, 1.4023223394755777`}, {
       4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.801765552598204, 
       1.4023223394755777`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.67002552391586, 1.174141916407176}, {4.61714668114571, 
       1.2311870221742764`}, {4.61714668114571, 1.2311870221742764`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}}], 
      LineBox[{{4.67002552391586, 1.174141916407176}, {4.61714668114571, 
       1.2311870221742764`}, {4.61714668114571, 1.2311870221742764`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}}], 
      LineBox[{{4.67002552391586, 1.174141916407176}, {4.61714668114571, 
       1.2311870221742764`}, {4.61714668114571, 1.2311870221742764`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}}], 
      LineBox[{{4.67002552391586, 1.174141916407176}, {4.61714668114571, 
       1.2311870221742764`}, {4.61714668114571, 1.2311870221742764`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}}], 
      LineBox[{{4.61714668114571, 1.2311870221742764`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}}], 
      LineBox[{{4.61714668114571, 1.2311870221742764`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}}], 
      LineBox[{{4.61714668114571, 1.2311870221742764`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}}], 
      LineBox[{{4.61714668114571, 1.2311870221742764`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}}], 
      LineBox[{{4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}], 
      LineBox[{{4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}], 
      LineBox[{{4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}], 
      LineBox[{{4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}], 
      LineBox[{{4.61714668114571, 1.3452772337084773`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}}], 
      LineBox[{{4.61714668114571, 1.3452772337084773`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}}], 
      LineBox[{{4.61714668114571, 1.3452772337084773`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}}], 
      LineBox[{{4.61714668114571, 1.3452772337084773`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}], 
      LineBox[{{4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}], 
      LineBox[{{4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}], 
      LineBox[{{4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}], 
      LineBox[{{4.844672477568572, 1.2139151538961537`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.844672477568572, 1.2139151538961537`}, {4.844672477568572, 
       1.2139151538961537`}}], 
      LineBox[{{4.844672477568572, 1.2139151538961537`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.844672477568572, 1.2139151538961537`}, {4.844672477568572, 
       1.2139151538961537`}}], 
      LineBox[{{4.844672477568572, 1.2139151538961537`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.844672477568572, 1.2139151538961537`}, {4.844672477568572, 
       1.2139151538961537`}}], 
      LineBox[{{4.844672477568572, 1.2139151538961537`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.844672477568572, 1.2139151538961537`}, {4.844672477568572, 
       1.2139151538961537`}}], 
      LineBox[{{4.801765552598204, 1.174141916407176}, {4.745867456056814, 
       1.1568700481290533`}, {4.745867456056814, 1.1568700481290533`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}}], 
      LineBox[{{4.801765552598204, 1.174141916407176}, {4.745867456056814, 
       1.1568700481290533`}, {4.745867456056814, 1.1568700481290533`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}}], 
      LineBox[{{4.801765552598204, 1.174141916407176}, {4.745867456056814, 
       1.1568700481290533`}, {4.745867456056814, 1.1568700481290533`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}}], 
      LineBox[{{4.801765552598204, 1.174141916407176}, {4.745867456056814, 
       1.1568700481290533`}, {4.745867456056814, 1.1568700481290533`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}}], 
      LineBox[{{4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}}], 
      LineBox[{{4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}}], 
      LineBox[{{4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}}], 
      LineBox[{{4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}], 
      LineBox[{{4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}], 
      LineBox[{{4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}], 
      LineBox[{{4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}], 
      LineBox[{{4.745867456056814, 1.4195942077537005`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}}], 
      LineBox[{{4.745867456056814, 1.4195942077537005`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}}], 
      LineBox[{{4.745867456056814, 1.4195942077537005`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}}], 
      LineBox[{{4.745867456056814, 1.4195942077537005`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}}], 
      LineBox[{{4.801765552598204, 1.4023223394755777`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}], 
      LineBox[{{4.801765552598204, 1.4023223394755777`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}], 
      LineBox[{{4.801765552598204, 1.4023223394755777`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}], 
      LineBox[{{4.801765552598204, 1.4023223394755777`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}], 
      LineBox[{{4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.844672477568572, 
       1.3625491019866}}], 
      LineBox[{{4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.844672477568572, 
       1.3625491019866}}], 
      LineBox[{{4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.844672477568572, 
       1.3625491019866}}], 
      LineBox[{{4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.844672477568572, 
       1.3625491019866}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.639631419250643, 1.571161184081378}, {4.577647285921705, 
       1.6380289757424187`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.7717645590644997`}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}, {
       4.577647285921705, 1.7717645590644997`}, {4.562419144219407, 
       1.7048967674034592`}, {4.577647285921705, 1.6380289757424187`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.7940559693131135`, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.7940559693131135`, 
       1.571161184081378}, {4.8443511047353915`, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`,
        1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349, 
       1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.844351104735391, 1.7920104973284015`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.639631419250643, 1.571161184081378}, {4.577647285921705, 
       1.6380289757424187`}, {4.577647285921705, 1.6380289757424187`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}}], 
      LineBox[{{4.639631419250643, 1.571161184081378}, {4.577647285921705, 
       1.6380289757424187`}, {4.577647285921705, 1.6380289757424187`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}}], 
      LineBox[{{4.639631419250643, 1.571161184081378}, {4.577647285921705, 
       1.6380289757424187`}, {4.577647285921705, 1.6380289757424187`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}}], 
      LineBox[{{4.639631419250643, 1.571161184081378}, {4.577647285921705, 
       1.6380289757424187`}, {4.577647285921705, 1.6380289757424187`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}}], 
      LineBox[{{4.577647285921705, 1.6380289757424187`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}}], 
      LineBox[{{4.577647285921705, 1.6380289757424187`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}}], 
      LineBox[{{4.577647285921705, 1.6380289757424187`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}}], 
      LineBox[{{4.577647285921705, 1.6380289757424187`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}}], 
      LineBox[{{4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}], 
      LineBox[{{4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}], 
      LineBox[{{4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}], 
      LineBox[{{4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}], 
      LineBox[{{4.577647285921705, 1.7717645590644997`}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}}], 
      LineBox[{{4.577647285921705, 1.7717645590644997`}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}}], 
      LineBox[{{4.577647285921705, 1.7717645590644997`}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}}], 
      LineBox[{{4.577647285921705, 1.7717645590644997`}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}], 
      LineBox[{{4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}], 
      LineBox[{{4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}], 
      LineBox[{{4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}], 
      LineBox[{{4.844351104735391, 1.617783037478517}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.844351104735391, 1.617783037478517}, {4.844351104735391, 
       1.617783037478517}}], 
      LineBox[{{4.844351104735391, 1.617783037478517}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.844351104735391, 1.617783037478517}, {4.844351104735391, 
       1.617783037478517}}], 
      LineBox[{{4.844351104735391, 1.617783037478517}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.844351104735391, 1.617783037478517}, {4.844351104735391, 
       1.617783037478517}}], 
      LineBox[{{4.844351104735391, 1.617783037478517}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.844351104735391, 1.617783037478517}, {4.844351104735391, 
       1.617783037478517}}], 
      LineBox[{{4.7940559693131135`, 1.571161184081378}, {4.728532692188538, 
       1.5509152458174764`}, {4.728532692188538, 1.5509152458174764`}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}}], 
      LineBox[{{4.7940559693131135`, 1.571161184081378}, {4.728532692188538, 
       1.5509152458174764`}, {4.728532692188538, 1.5509152458174764`}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}}], 
      LineBox[{{4.7940559693131135`, 1.571161184081378}, {4.728532692188538, 
       1.5509152458174764`}, {4.728532692188538, 1.5509152458174764`}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}}], 
      LineBox[{{4.7940559693131135`, 1.571161184081378}, {4.728532692188538, 
       1.5509152458174764`}, {4.728532692188538, 1.5509152458174764`}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}}], 
      LineBox[{{4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}}], 
      LineBox[{{4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}}], 
      LineBox[{{4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}}], 
      LineBox[{{4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}], 
      LineBox[{{4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}], 
      LineBox[{{4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}], 
      LineBox[{{4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}], 
      LineBox[{{4.728532692188538, 1.858878288989442}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}}], 
      LineBox[{{4.728532692188538, 1.858878288989442}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}}], 
      LineBox[{{4.728532692188538, 1.858878288989442}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}}], 
      LineBox[{{4.728532692188538, 1.858878288989442}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}}], 
      LineBox[{{4.7940559693131135`, 1.8386323507255404`}, {4.844351104735391,
        1.7920104973284015`}, {4.844351104735391, 1.7920104973284015`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}}], 
      LineBox[{{4.7940559693131135`, 1.8386323507255404`}, {4.844351104735391,
        1.7920104973284015`}, {4.844351104735391, 1.7920104973284015`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}}], 
      LineBox[{{4.7940559693131135`, 1.8386323507255404`}, {4.844351104735391,
        1.7920104973284015`}, {4.844351104735391, 1.7920104973284015`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}}], 
      LineBox[{{4.7940559693131135`, 1.8386323507255404`}, {4.844351104735391,
        1.7920104973284015`}, {4.844351104735391, 1.7920104973284015`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}}], 
      LineBox[{{4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349,
        1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.8443511047353915`, 
       1.7920104973284015`}}], 
      LineBox[{{4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349,
        1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.8443511047353915`, 
       1.7920104973284015`}}], 
      LineBox[{{4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349,
        1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.8443511047353915`, 
       1.7920104973284015`}}], 
      LineBox[{{4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349,
        1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.8443511047353915`, 
       1.7920104973284015`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.65232379860786, 2.1234835309221913`}, {4.588897298180285, 
       2.191907332121004}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.3287549345186296`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}, {
       4.588897298180285, 2.3287549345186296`}, {4.573314798525636, 
       2.260331133319817}, {4.588897298180285, 2.191907332121004}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.810341798772308, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.810341798772308, 
       2.1234835309221913`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.810341798772308, 2.3971787357174423`}, {
       4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.810341798772308, 
       2.3971787357174423`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.65232379860786, 2.1234835309221913`}, {4.588897298180285, 
       2.191907332121004}, {4.588897298180285, 2.191907332121004}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}}], 
      LineBox[{{4.65232379860786, 2.1234835309221913`}, {4.588897298180285, 
       2.191907332121004}, {4.588897298180285, 2.191907332121004}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}}], 
      LineBox[{{4.65232379860786, 2.1234835309221913`}, {4.588897298180285, 
       2.191907332121004}, {4.588897298180285, 2.191907332121004}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}}], 
      LineBox[{{4.65232379860786, 2.1234835309221913`}, {4.588897298180285, 
       2.191907332121004}, {4.588897298180285, 2.191907332121004}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}}], 
      LineBox[{{4.588897298180285, 2.191907332121004}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}}], 
      LineBox[{{4.588897298180285, 2.191907332121004}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}}], 
      LineBox[{{4.588897298180285, 2.191907332121004}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}}], 
      LineBox[{{4.588897298180285, 2.191907332121004}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}}], 
      LineBox[{{4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}], 
      LineBox[{{4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}], 
      LineBox[{{4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}], 
      LineBox[{{4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}], 
      LineBox[{{4.588897298180285, 2.3287549345186296`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}}], 
      LineBox[{{4.588897298180285, 2.3287549345186296`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}}], 
      LineBox[{{4.588897298180285, 2.3287549345186296`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}}], 
      LineBox[{{4.588897298180285, 2.3287549345186296`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}], 
      LineBox[{{4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}], 
      LineBox[{{4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}], 
      LineBox[{{4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}], 
      LineBox[{{4.861807299006651, 2.1711902720769864`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.861807299006651, 2.1711902720769864`}, {4.861807299006651, 
       2.1711902720769864`}}], 
      LineBox[{{4.861807299006651, 2.1711902720769864`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.861807299006651, 2.1711902720769864`}, {4.861807299006651, 
       2.1711902720769864`}}], 
      LineBox[{{4.861807299006651, 2.1711902720769864`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.861807299006651, 2.1711902720769864`}, {4.861807299006651, 
       2.1711902720769864`}}], 
      LineBox[{{4.861807299006651, 2.1711902720769864`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.861807299006651, 2.1711902720769864`}, {4.861807299006651, 
       2.1711902720769864`}}], 
      LineBox[{{4.810341798772308, 2.1234835309221913`}, {4.7432937988833155`,
        2.1027664708781733`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}}], 
      LineBox[{{4.810341798772308, 2.1234835309221913`}, {4.7432937988833155`,
        2.1027664708781733`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}}], 
      LineBox[{{4.810341798772308, 2.1234835309221913`}, {4.7432937988833155`,
        2.1027664708781733`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}}], 
      LineBox[{{4.810341798772308, 2.1234835309221913`}, {4.7432937988833155`,
        2.1027664708781733`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}}], 
      LineBox[{{4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}}], 
      LineBox[{{4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}}], 
      LineBox[{{4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}}], 
      LineBox[{{4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}], 
      LineBox[{{4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}], 
      LineBox[{{4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}], 
      LineBox[{{4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}], 
      LineBox[{{4.7432937988833155`, 2.4178957957614604`}, {4.810341798772308,
        2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}}], 
      LineBox[{{4.7432937988833155`, 2.4178957957614604`}, {4.810341798772308,
        2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}}], 
      LineBox[{{4.7432937988833155`, 2.4178957957614604`}, {4.810341798772308,
        2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}}], 
      LineBox[{{4.7432937988833155`, 2.4178957957614604`}, {4.810341798772308,
        2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}}], 
      LineBox[{{4.810341798772308, 2.3971787357174423`}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}], 
      LineBox[{{4.810341798772308, 2.3971787357174423`}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}], 
      LineBox[{{4.810341798772308, 2.3971787357174423`}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}], 
      LineBox[{{4.810341798772308, 2.3971787357174423`}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}], 
      LineBox[{{4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.861807299006651, 
       2.349471994562647}}], 
      LineBox[{{4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.861807299006651, 
       2.349471994562647}}], 
      LineBox[{{4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.861807299006651, 
       2.349471994562647}}], 
      LineBox[{{4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.861807299006651, 
       2.349471994562647}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6722871712835765`, 2.6362287567121045`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248, 
       2.7731070411602112`}, {4.6088464502554665`, 2.841546183384265}, {
       4.6722871712835765`, 2.909985325608318}, {4.6722871712835765`, 
       2.909985325608318}, {4.6088464502554665`, 2.841546183384265}, {
       4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.830340600028235, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.672287171283577, 
       2.6362287567121045`}, {4.672287171283577, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.830340600028235, 
       2.6362287567121045`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.830340600028235, 2.909985325608318}, {
       4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.830340600028235, 
       2.909985325608318}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6722871712835765`, 2.6362287567121045`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}}], 
      LineBox[{{4.6722871712835765`, 2.6362287567121045`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}}], 
      LineBox[{{4.6722871712835765`, 2.6362287567121045`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}}], 
      LineBox[{{4.6722871712835765`, 2.6362287567121045`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}}], 
      LineBox[{{4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248,
        2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}}], 
      LineBox[{{4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248,
        2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}}], 
      LineBox[{{4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248,
        2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}}], 
      LineBox[{{4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248,
        2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}}], 
      LineBox[{{4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`,
        2.841546183384265}, {4.6088464502554665`, 2.841546183384265}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}], 
      LineBox[{{4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`,
        2.841546183384265}, {4.6088464502554665`, 2.841546183384265}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}], 
      LineBox[{{4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`,
        2.841546183384265}, {4.6088464502554665`, 2.841546183384265}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}], 
      LineBox[{{4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`,
        2.841546183384265}, {4.6088464502554665`, 2.841546183384265}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}], 
      LineBox[{{4.6088464502554665`, 2.841546183384265}, {4.672287171283577, 
       2.909985325608318}, {4.672287171283577, 2.909985325608318}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}}], 
      LineBox[{{4.6088464502554665`, 2.841546183384265}, {4.672287171283577, 
       2.909985325608318}, {4.672287171283577, 2.909985325608318}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}}], 
      LineBox[{{4.6088464502554665`, 2.841546183384265}, {4.672287171283577, 
       2.909985325608318}, {4.672287171283577, 2.909985325608318}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}}], 
      LineBox[{{4.6088464502554665`, 2.841546183384265}, {4.672287171283577, 
       2.909985325608318}, {4.672287171283577, 2.909985325608318}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}], 
      LineBox[{{4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}], 
      LineBox[{{4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}], 
      LineBox[{{4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}], 
      LineBox[{{4.881817639135372, 2.6839461940034393`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.881817639135372, 2.6839461940034393`}, {4.881817639135372, 
       2.6839461940034393`}}], 
      LineBox[{{4.881817639135372, 2.6839461940034393`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.881817639135372, 2.6839461940034393`}, {4.881817639135372, 
       2.6839461940034393`}}], 
      LineBox[{{4.881817639135372, 2.6839461940034393`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.881817639135372, 2.6839461940034393`}, {4.881817639135372, 
       2.6839461940034393`}}], 
      LineBox[{{4.881817639135372, 2.6839461940034393`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.881817639135372, 2.6839461940034393`}, {4.881817639135372, 
       2.6839461940034393`}}], 
      LineBox[{{4.830340600028235, 2.6362287567121045`}, {4.763277567576878, 
       2.615507051779386}, {4.763277567576878, 2.615507051779386}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}}], 
      LineBox[{{4.830340600028235, 2.6362287567121045`}, {4.763277567576878, 
       2.615507051779386}, {4.763277567576878, 2.615507051779386}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}}], 
      LineBox[{{4.830340600028235, 2.6362287567121045`}, {4.763277567576878, 
       2.615507051779386}, {4.763277567576878, 2.615507051779386}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}}], 
      LineBox[{{4.830340600028235, 2.6362287567121045`}, {4.763277567576878, 
       2.615507051779386}, {4.763277567576878, 2.615507051779386}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}}], 
      LineBox[{{4.763277567576878, 2.615507051779386}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}}], 
      LineBox[{{4.763277567576878, 2.615507051779386}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}}], 
      LineBox[{{4.763277567576878, 2.615507051779386}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}}], 
      LineBox[{{4.763277567576878, 2.615507051779386}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}], 
      LineBox[{{4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}], 
      LineBox[{{4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}], 
      LineBox[{{4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}], 
      LineBox[{{4.763277567576878, 2.9307070305410363`}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}}], 
      LineBox[{{4.763277567576878, 2.9307070305410363`}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}}], 
      LineBox[{{4.763277567576878, 2.9307070305410363`}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}}], 
      LineBox[{{4.763277567576878, 2.9307070305410363`}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}}], 
      LineBox[{{4.830340600028235, 2.909985325608318}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}], 
      LineBox[{{4.830340600028235, 2.909985325608318}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}], 
      LineBox[{{4.830340600028235, 2.909985325608318}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}], 
      LineBox[{{4.830340600028235, 2.909985325608318}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}], 
      LineBox[{{4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.881817639135372, 
       2.862267888316983}}], 
      LineBox[{{4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.881817639135372, 
       2.862267888316983}}], 
      LineBox[{{4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.881817639135372, 
       2.862267888316983}}], 
      LineBox[{{4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.881817639135372, 
       2.862267888316983}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6971938896706895`, 3.100537343278087}, {4.63188089426916, 
       3.1709962742127398`}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.3119141360820463`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}, {
       4.63188089426916, 3.3119141360820463`}, {4.615834924186819, 
       3.241455205147393}, {4.63188089426916, 3.1709962742127398`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.85991182063843, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`, 
       3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.85991182063843, 
       3.100537343278087}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.85991182063843, 3.382373067016699}, {
       4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.85991182063843, 
       3.382373067016699}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6971938896706895`, 3.100537343278087}, {4.63188089426916, 
       3.1709962742127398`}, {4.63188089426916, 3.1709962742127398`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}}], 
      LineBox[{{4.6971938896706895`, 3.100537343278087}, {4.63188089426916, 
       3.1709962742127398`}, {4.63188089426916, 3.1709962742127398`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}}], 
      LineBox[{{4.6971938896706895`, 3.100537343278087}, {4.63188089426916, 
       3.1709962742127398`}, {4.63188089426916, 3.1709962742127398`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}}], 
      LineBox[{{4.6971938896706895`, 3.100537343278087}, {4.63188089426916, 
       3.1709962742127398`}, {4.63188089426916, 3.1709962742127398`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}}], 
      LineBox[{{4.63188089426916, 3.1709962742127398`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}}], 
      LineBox[{{4.63188089426916, 3.1709962742127398`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}}], 
      LineBox[{{4.63188089426916, 3.1709962742127398`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}}], 
      LineBox[{{4.63188089426916, 3.1709962742127398`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}}], 
      LineBox[{{4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}], 
      LineBox[{{4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}], 
      LineBox[{{4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}], 
      LineBox[{{4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}], 
      LineBox[{{4.63188089426916, 3.3119141360820463`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}}], 
      LineBox[{{4.63188089426916, 3.3119141360820463`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}}], 
      LineBox[{{4.63188089426916, 3.3119141360820463`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}}], 
      LineBox[{{4.63188089426916, 3.3119141360820463`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}], 
      LineBox[{{4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}], 
      LineBox[{{4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}], 
      LineBox[{{4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}], 
      LineBox[{{4.912908059710163, 3.1496630264650856`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.912908059710163, 3.1496630264650856`}, {4.912908059710163, 
       3.1496630264650856`}}], 
      LineBox[{{4.912908059710163, 3.1496630264650856`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.912908059710163, 3.1496630264650856`}, {4.912908059710163, 
       3.1496630264650856`}}], 
      LineBox[{{4.912908059710163, 3.1496630264650856`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.912908059710163, 3.1496630264650856`}, {4.912908059710163, 
       3.1496630264650856`}}], 
      LineBox[{{4.912908059710163, 3.1496630264650856`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.912908059710163, 3.1496630264650856`}, {4.912908059710163, 
       3.1496630264650856`}}], 
      LineBox[{{4.85991182063843, 3.100537343278087}, {4.790869611484357, 
       3.0792040955304327`}, {4.790869611484357, 3.0792040955304327`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}}], 
      LineBox[{{4.85991182063843, 3.100537343278087}, {4.790869611484357, 
       3.0792040955304327`}, {4.790869611484357, 3.0792040955304327`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}}], 
      LineBox[{{4.85991182063843, 3.100537343278087}, {4.790869611484357, 
       3.0792040955304327`}, {4.790869611484357, 3.0792040955304327`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}}], 
      LineBox[{{4.85991182063843, 3.100537343278087}, {4.790869611484357, 
       3.0792040955304327`}, {4.790869611484357, 3.0792040955304327`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}}], 
      LineBox[{{4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`,
        3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}}], 
      LineBox[{{4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`,
        3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}}], 
      LineBox[{{4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`,
        3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}}], 
      LineBox[{{4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`,
        3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}], 
      LineBox[{{4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}], 
      LineBox[{{4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}], 
      LineBox[{{4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}], 
      LineBox[{{4.790869611484357, 3.4037063147643534`}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}}], 
      LineBox[{{4.790869611484357, 3.4037063147643534`}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}}], 
      LineBox[{{4.790869611484357, 3.4037063147643534`}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}}], 
      LineBox[{{4.790869611484357, 3.4037063147643534`}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}}], 
      LineBox[{{4.85991182063843, 3.382373067016699}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}], 
      LineBox[{{4.85991182063843, 3.382373067016699}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}], 
      LineBox[{{4.85991182063843, 3.382373067016699}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}], 
      LineBox[{{4.85991182063843, 3.382373067016699}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}], 
      LineBox[{{4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.912908059710163, 
       3.3332473838297005`}}], 
      LineBox[{{4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.912908059710163, 
       3.3332473838297005`}}], 
      LineBox[{{4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.912908059710163, 
       3.3332473838297005`}}], 
      LineBox[{{4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.912908059710163, 
       3.3332473838297005`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.703973804758928, 3.594499593022139}, {4.64378438788612, 
       3.659431264588667}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.7892946077217244`}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}, {
       4.64378438788612, 3.7892946077217244`}, {4.628997168643194, 
       3.7243629361551958`}, {4.64378438788612, 3.659431264588667}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.8539270769903995`, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.8539270769903995`, 
       3.594499593022139}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`,
        3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.703973804758928, 3.594499593022139}, {4.64378438788612, 
       3.659431264588667}, {4.64378438788612, 3.659431264588667}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}}], 
      LineBox[{{4.703973804758928, 3.594499593022139}, {4.64378438788612, 
       3.659431264588667}, {4.64378438788612, 3.659431264588667}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}}], 
      LineBox[{{4.703973804758928, 3.594499593022139}, {4.64378438788612, 
       3.659431264588667}, {4.64378438788612, 3.659431264588667}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}}], 
      LineBox[{{4.703973804758928, 3.594499593022139}, {4.64378438788612, 
       3.659431264588667}, {4.64378438788612, 3.659431264588667}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}}], 
      LineBox[{{4.64378438788612, 3.659431264588667}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}}], 
      LineBox[{{4.64378438788612, 3.659431264588667}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}}], 
      LineBox[{{4.64378438788612, 3.659431264588667}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}}], 
      LineBox[{{4.64378438788612, 3.659431264588667}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}}], 
      LineBox[{{4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}], 
      LineBox[{{4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}], 
      LineBox[{{4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}], 
      LineBox[{{4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}], 
      LineBox[{{4.64378438788612, 3.7892946077217244`}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}}], 
      LineBox[{{4.64378438788612, 3.7892946077217244`}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}}], 
      LineBox[{{4.64378438788612, 3.7892946077217244`}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}}], 
      LineBox[{{4.64378438788612, 3.7892946077217244`}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}], 
      LineBox[{{4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}], 
      LineBox[{{4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}], 
      LineBox[{{4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}], 
      LineBox[{{4.902765944455737, 3.639771536321107}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.902765944455737, 3.639771536321107}, {4.902765944455737, 
       3.639771536321107}}], 
      LineBox[{{4.902765944455737, 3.639771536321107}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.902765944455737, 3.639771536321107}, {4.902765944455737, 
       3.639771536321107}}], 
      LineBox[{{4.902765944455737, 3.639771536321107}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.902765944455737, 3.639771536321107}, {4.902765944455737, 
       3.639771536321107}}], 
      LineBox[{{4.902765944455737, 3.639771536321107}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.902765944455737, 3.639771536321107}, {4.902765944455737, 
       3.639771536321107}}], 
      LineBox[{{4.8539270769903995`, 3.594499593022139}, {4.790300990282135, 
       3.5748398647545785`}, {4.790300990282135, 3.5748398647545785`}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}}], 
      LineBox[{{4.8539270769903995`, 3.594499593022139}, {4.790300990282135, 
       3.5748398647545785`}, {4.790300990282135, 3.5748398647545785`}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}}], 
      LineBox[{{4.8539270769903995`, 3.594499593022139}, {4.790300990282135, 
       3.5748398647545785`}, {4.790300990282135, 3.5748398647545785`}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}}], 
      LineBox[{{4.8539270769903995`, 3.594499593022139}, {4.790300990282135, 
       3.5748398647545785`}, {4.790300990282135, 3.5748398647545785`}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}}], 
      LineBox[{{4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}}], 
      LineBox[{{4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}}], 
      LineBox[{{4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}}], 
      LineBox[{{4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}], 
      LineBox[{{4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}], 
      LineBox[{{4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}], 
      LineBox[{{4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}], 
      LineBox[{{4.790300990282135, 3.873886007555813}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}}], 
      LineBox[{{4.790300990282135, 3.873886007555813}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}}], 
      LineBox[{{4.790300990282135, 3.873886007555813}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}}], 
      LineBox[{{4.790300990282135, 3.873886007555813}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}}], 
      LineBox[{{4.8539270769903995`, 3.8542262792882527`}, {4.902765944455737,
        3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}}], 
      LineBox[{{4.8539270769903995`, 3.8542262792882527`}, {4.902765944455737,
        3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}}], 
      LineBox[{{4.8539270769903995`, 3.8542262792882527`}, {4.902765944455737,
        3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}}], 
      LineBox[{{4.8539270769903995`, 3.8542262792882527`}, {4.902765944455737,
        3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}}], 
      LineBox[{{4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.902765944455737, 
       3.8089543359892843`}}], 
      LineBox[{{4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.902765944455737, 
       3.8089543359892843`}}], 
      LineBox[{{4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.902765944455737, 
       3.8089543359892843`}}], 
      LineBox[{{4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.902765944455737, 
       3.8089543359892843`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}], 
      LineBox[{{4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}], 
      LineBox[{{4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}], 
      LineBox[{{4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}], 
      LineBox[{{4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}], 
      LineBox[{{4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}], 
      LineBox[{{4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}], 
      LineBox[{{4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}], 
      LineBox[{{4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}], 
      LineBox[{{4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}], 
      LineBox[{{4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}], 
      LineBox[{{4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}], 
      LineBox[{{4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}], 
      LineBox[{{4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}], 
      LineBox[{{4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}], 
      LineBox[{{4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}], 
      LineBox[{{5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}], 
      LineBox[{{5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}], 
      LineBox[{{5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}], 
      LineBox[{{5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}], 
      LineBox[{{5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}], 
      LineBox[{{5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}], 
      LineBox[{{5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}], 
      LineBox[{{5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}], 
      LineBox[{{5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}], 
      LineBox[{{5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}], 
      LineBox[{{5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}], 
      LineBox[{{4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}], 
      LineBox[{{4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}], 
      LineBox[{{4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}], 
      LineBox[{{4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}], 
      LineBox[{{4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}], 
      LineBox[{{4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}], 
      LineBox[{{4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}], 
      LineBox[{{4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}], 
      LineBox[{{4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}], 
      LineBox[{{4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}], 
      LineBox[{{4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}], 
      LineBox[{{5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}], 
      LineBox[{{5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}], 
      LineBox[{{5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}], 
      LineBox[{{5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}], 
      LineBox[{{5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}], 
      LineBox[{{5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}], 
      LineBox[{{5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}], 
      LineBox[{{5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}], 
      LineBox[{{4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}], 
      LineBox[{{4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}], 
      LineBox[{{4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}], 
      LineBox[{{4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}], 
      LineBox[{{4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}], 
      LineBox[{{4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}], 
      LineBox[{{4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}], 
      LineBox[{{4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}], 
      LineBox[{{4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}], 
      LineBox[{{4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}], 
      LineBox[{{4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}], 
      LineBox[{{4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}], 
      LineBox[{{4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}], 
      LineBox[{{4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}], 
      LineBox[{{4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}], 
      LineBox[{{5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}], 
      LineBox[{{5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}], 
      LineBox[{{5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}], 
      LineBox[{{5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}], 
      LineBox[{{5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}], 
      LineBox[{{5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}], 
      LineBox[{{5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}], 
      LineBox[{{5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}], 
      LineBox[{{5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}], 
      LineBox[{{5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}], 
      LineBox[{{5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}], 
      LineBox[{{5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}], 
      LineBox[{{5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}], 
      LineBox[{{5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}], 
      LineBox[{{5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}], 
      LineBox[{{4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}], 
      LineBox[{{4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}], 
      LineBox[{{4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}], 
      LineBox[{{5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}], 
      LineBox[{{5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}], 
      LineBox[{{5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}], 
      LineBox[{{5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}], 
      LineBox[{{5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}], 
      LineBox[{{5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}], 
      LineBox[{{5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}], 
      LineBox[{{5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}], 
      LineBox[{{5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}], 
      LineBox[{{5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}], 
      LineBox[{{5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}], 
      LineBox[{{5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}], 
      LineBox[{{4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}], 
      LineBox[{{4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}], 
      LineBox[{{4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}], 
      LineBox[{{4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}], 
      LineBox[{{4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}], 
      LineBox[{{4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}], 
      LineBox[{{4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}], 
      LineBox[{{4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}], 
      LineBox[{{4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}], 
      LineBox[{{4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}], 
      LineBox[{{4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}], 
      LineBox[{{4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}], 
      LineBox[{{4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}], 
      LineBox[{{4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}], 
      LineBox[{{4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}], 
      LineBox[{{5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}], 
      LineBox[{{5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}], 
      LineBox[{{5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}], 
      LineBox[{{5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}], 
      LineBox[{{5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}], 
      LineBox[{{5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}], 
      LineBox[{{5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}], 
      LineBox[{{5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}], 
      LineBox[{{5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}], 
      LineBox[{{5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}], 
      LineBox[{{5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}], 
      LineBox[{{5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}], 
      LineBox[{{5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}], 
      LineBox[{{5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}], 
      LineBox[{{5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}], 
      LineBox[{{4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}], 
      LineBox[{{4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}], 
      LineBox[{{4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}], 
      LineBox[{{5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}], 
      LineBox[{{5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}], 
      LineBox[{{5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}], 
      LineBox[{{5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}], 
      LineBox[{{5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}], 
      LineBox[{{5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}], 
      LineBox[{{5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}], 
      LineBox[{{5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}], 
      LineBox[{{5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}], 
      LineBox[{{5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}], 
      LineBox[{{5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}], 
      LineBox[{{5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}], 
      LineBox[{{4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}], 
      LineBox[{{4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}], 
      LineBox[{{4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}], 
      LineBox[{{4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}], 
      LineBox[{{4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}], 
      LineBox[{{4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}], 
      LineBox[{{4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}], 
      LineBox[{{4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}], 
      LineBox[{{4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}], 
      LineBox[{{4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}], 
      LineBox[{{4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}], 
      LineBox[{{4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}], 
      LineBox[{{4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}], 
      LineBox[{{4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}], 
      LineBox[{{4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}], 
      LineBox[{{5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}], 
      LineBox[{{5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}], 
      LineBox[{{5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}], 
      LineBox[{{5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}], 
      LineBox[{{5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}], 
      LineBox[{{5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}], 
      LineBox[{{5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}], 
      LineBox[{{5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}], 
      LineBox[{{5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}], 
      LineBox[{{5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}], 
      LineBox[{{5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}], 
      LineBox[{{5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}], 
      LineBox[{{5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}], 
      LineBox[{{5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}], 
      LineBox[{{5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}], 
      LineBox[{{4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}], 
      LineBox[{{4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}], 
      LineBox[{{4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}], 
      LineBox[{{5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}], 
      LineBox[{{5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}], 
      LineBox[{{5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}], 
      LineBox[{{5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}], 
      LineBox[{{5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}], 
      LineBox[{{5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}], 
      LineBox[{{5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}], 
      LineBox[{{5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}], 
      LineBox[{{5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}], 
      LineBox[{{5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}], 
      LineBox[{{5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}], 
      LineBox[{{5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}], 
      LineBox[{{4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}], 
      LineBox[{{4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}], 
      LineBox[{{4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}], 
      LineBox[{{4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}], 
      LineBox[{{4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}], 
      LineBox[{{4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}], 
      LineBox[{{4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}], 
      LineBox[{{4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}], 
      LineBox[{{4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}], 
      LineBox[{{4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}], 
      LineBox[{{4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}], 
      LineBox[{{4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}], 
      LineBox[{{4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}], 
      LineBox[{{4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}], 
      LineBox[{{4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}], 
      LineBox[{{5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}], 
      LineBox[{{5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}], 
      LineBox[{{5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}], 
      LineBox[{{5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}], 
      LineBox[{{5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}], 
      LineBox[{{5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}], 
      LineBox[{{5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}], 
      LineBox[{{5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}], 
      LineBox[{{5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}], 
      LineBox[{{5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}], 
      LineBox[{{5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}], 
      LineBox[{{4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}], 
      LineBox[{{4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}], 
      LineBox[{{4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}], 
      LineBox[{{4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}], 
      LineBox[{{4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}], 
      LineBox[{{4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}], 
      LineBox[{{4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}], 
      LineBox[{{4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}], 
      LineBox[{{4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}], 
      LineBox[{{4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}], 
      LineBox[{{4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}], 
      LineBox[{{5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}], 
      LineBox[{{5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}], 
      LineBox[{{5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}], 
      LineBox[{{5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}], 
      LineBox[{{5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}], 
      LineBox[{{5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}], 
      LineBox[{{5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}], 
      LineBox[{{5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988245`}, {
       4.873652682593564, -1.8617779626988245`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}], 
      LineBox[{{4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}], 
      LineBox[{{4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}], 
      LineBox[{{4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}], 
      LineBox[{{4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}], 
      LineBox[{{4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}], 
      LineBox[{{4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}], 
      LineBox[{{4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}], 
      LineBox[{{4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}], 
      LineBox[{{4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}], 
      LineBox[{{4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}], 
      LineBox[{{4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}], 
      LineBox[{{4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}], 
      LineBox[{{4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}], 
      LineBox[{{4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}], 
      LineBox[{{4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}], 
      LineBox[{{5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}], 
      LineBox[{{5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}], 
      LineBox[{{5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}], 
      LineBox[{{5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}], 
      LineBox[{{5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}], 
      LineBox[{{5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}], 
      LineBox[{{5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}], 
      LineBox[{{5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}], 
      LineBox[{{5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}], 
      LineBox[{{5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}], 
      LineBox[{{5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}], 
      LineBox[{{4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}], 
      LineBox[{{4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}], 
      LineBox[{{4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}], 
      LineBox[{{4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}], 
      LineBox[{{4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}], 
      LineBox[{{4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}], 
      LineBox[{{4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}], 
      LineBox[{{4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}], 
      LineBox[{{4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}], 
      LineBox[{{4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}], 
      LineBox[{{4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}], 
      LineBox[{{5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}], 
      LineBox[{{5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}], 
      LineBox[{{5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}], 
      LineBox[{{5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}], 
      LineBox[{{5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}], 
      LineBox[{{5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}], 
      LineBox[{{5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}], 
      LineBox[{{5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}], 
      LineBox[{{4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}], 
      LineBox[{{4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}], 
      LineBox[{{4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}], 
      LineBox[{{4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}], 
      LineBox[{{4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}], 
      LineBox[{{4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}], 
      LineBox[{{4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}], 
      LineBox[{{4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}], 
      LineBox[{{4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}], 
      LineBox[{{4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}], 
      LineBox[{{4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}], 
      LineBox[{{4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}], 
      LineBox[{{4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}], 
      LineBox[{{4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}], 
      LineBox[{{4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}], 
      LineBox[{{5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}], 
      LineBox[{{5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}], 
      LineBox[{{5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}], 
      LineBox[{{5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}], 
      LineBox[{{5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}], 
      LineBox[{{5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}], 
      LineBox[{{5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}], 
      LineBox[{{5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}], 
      LineBox[{{5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}], 
      LineBox[{{5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}], 
      LineBox[{{5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}], 
      LineBox[{{5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}], 
      LineBox[{{5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}], 
      LineBox[{{5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}], 
      LineBox[{{5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}], 
      LineBox[{{4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}], 
      LineBox[{{4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}], 
      LineBox[{{4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}], 
      LineBox[{{5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}], 
      LineBox[{{5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}], 
      LineBox[{{5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}], 
      LineBox[{{5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}], 
      LineBox[{{5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}], 
      LineBox[{{5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}], 
      LineBox[{{5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}], 
      LineBox[{{5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}], 
      LineBox[{{5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}], 
      LineBox[{{5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}], 
      LineBox[{{5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}], 
      LineBox[{{5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}], 
      LineBox[{{4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}], 
      LineBox[{{4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}], 
      LineBox[{{4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}], 
      LineBox[{{4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}], 
      LineBox[{{4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}], 
      LineBox[{{4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}], 
      LineBox[{{4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}], 
      LineBox[{{4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}], 
      LineBox[{{4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}], 
      LineBox[{{4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}], 
      LineBox[{{4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}], 
      LineBox[{{4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}], 
      LineBox[{{4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}], 
      LineBox[{{4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}], 
      LineBox[{{4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}], 
      LineBox[{{5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}], 
      LineBox[{{5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}], 
      LineBox[{{5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}], 
      LineBox[{{5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}], 
      LineBox[{{5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}], 
      LineBox[{{5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}], 
      LineBox[{{5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}], 
      LineBox[{{5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}], 
      LineBox[{{5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}], 
      LineBox[{{5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}], 
      LineBox[{{5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}], 
      LineBox[{{5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}], 
      LineBox[{{5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}], 
      LineBox[{{5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}], 
      LineBox[{{5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}], 
      LineBox[{{4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}], 
      LineBox[{{4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}], 
      LineBox[{{4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}], 
      LineBox[{{5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}], 
      LineBox[{{5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}], 
      LineBox[{{5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}], 
      LineBox[{{5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}], 
      LineBox[{{5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}], 
      LineBox[{{5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}], 
      LineBox[{{5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}], 
      LineBox[{{5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}], 
      LineBox[{{5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}], 
      LineBox[{{5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}], 
      LineBox[{{5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}], 
      LineBox[{{5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.3838535728859904}, {
       4.928263853343283, -0.3838535728859904}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}], 
      LineBox[{{4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}], 
      LineBox[{{4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}], 
      LineBox[{{4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}], 
      LineBox[{{4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}], 
      LineBox[{{4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}], 
      LineBox[{{4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}], 
      LineBox[{{4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}], 
      LineBox[{{4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}], 
      LineBox[{{4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}], 
      LineBox[{{4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}], 
      LineBox[{{4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}], 
      LineBox[{{4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}], 
      LineBox[{{4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}], 
      LineBox[{{4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}], 
      LineBox[{{4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}], 
      LineBox[{{5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}], 
      LineBox[{{5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}], 
      LineBox[{{5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}], 
      LineBox[{{5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}], 
      LineBox[{{5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}], 
      LineBox[{{5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}], 
      LineBox[{{5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}], 
      LineBox[{{5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}], 
      LineBox[{{5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}], 
      LineBox[{{5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}], 
      LineBox[{{5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}], 
      LineBox[{{5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}], 
      LineBox[{{5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}], 
      LineBox[{{5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}], 
      LineBox[{{5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}], 
      LineBox[{{4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}], 
      LineBox[{{4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}], 
      LineBox[{{4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}], 
      LineBox[{{5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}], 
      LineBox[{{5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}], 
      LineBox[{{5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}], 
      LineBox[{{5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}], 
      LineBox[{{5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}], 
      LineBox[{{5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}], 
      LineBox[{{5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}], 
      LineBox[{{5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}], 
      LineBox[{{5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}], 
      LineBox[{{5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}], 
      LineBox[{{5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}], 
      LineBox[{{5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, 0.09437020280328935}, {
       4.903692688761734, 0.1633401011782614}, {4.903692688761734, 
       0.1633401011782614}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, -0.04356959394665484}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.824053109976192, 0.025400304428317255`}, {4.824053109976192,
        0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162691`}, {
       4.903692688761734, -0.11253949232162691`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 
       0.025400304428317238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.903692688761734, 0.16334010117826142`}, {4.995388729675026, 
       0.18422250614305444`}, {5.062971846332819, 0.1633401011782614}, {
       5.114848097853341, 0.11525260776808234`}, {5.1426114251183614`, 
       0.025400304428317273`}, {5.1426114251183614`, 0.025400304428317273`}, {
       5.114848097853341, 0.11525260776808234`}, {5.062971846332819, 
       0.1633401011782614}, {4.995388729675026, 0.18422250614305444`}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}], 
      LineBox[{{4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}], 
      LineBox[{{4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}], 
      LineBox[{{4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}], 
      LineBox[{{4.839759975113463, -0.043569593946654814`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}], 
      LineBox[{{4.839759975113463, -0.043569593946654814`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}], 
      LineBox[{{4.839759975113463, -0.043569593946654814`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}], 
      LineBox[{{4.839759975113463, -0.043569593946654814`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}], 
      LineBox[{{4.824053109976192, 0.025400304428317255`}, {4.839759975113463,
        0.09437020280328932}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}}], 
      LineBox[{{4.824053109976192, 0.025400304428317255`}, {4.839759975113463,
        0.09437020280328932}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}}], 
      LineBox[{{4.824053109976192, 0.025400304428317255`}, {4.839759975113463,
        0.09437020280328932}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}}], 
      LineBox[{{4.824053109976192, 0.025400304428317255`}, {4.839759975113463,
        0.09437020280328932}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}}], 
      LineBox[{{4.839759975113463, 0.09437020280328935}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}, {
       4.839759975113463, 0.09437020280328935}, {4.839759975113463, 
       0.09437020280328935}}], 
      LineBox[{{4.839759975113463, 0.09437020280328935}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}, {
       4.839759975113463, 0.09437020280328935}, {4.839759975113463, 
       0.09437020280328935}}], 
      LineBox[{{4.839759975113463, 0.09437020280328935}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}, {
       4.839759975113463, 0.09437020280328935}, {4.839759975113463, 
       0.09437020280328935}}], 
      LineBox[{{4.839759975113463, 0.09437020280328935}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}, {
       4.839759975113463, 0.09437020280328935}, {4.839759975113463, 
       0.09437020280328935}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 0.025400304428317238`}}],
       LineBox[{{5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 0.025400304428317238`}}],
       LineBox[{{5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 0.025400304428317238`}}],
       LineBox[{{5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 0.025400304428317238`}}],
       LineBox[{{5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}], 
      LineBox[{{5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}], 
      LineBox[{{5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}], 
      LineBox[{{5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}], 
      LineBox[{{5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}], 
      LineBox[{{5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}], 
      LineBox[{{5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}], 
      LineBox[{{5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}], 
      LineBox[{{4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}], 
      LineBox[{{4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}], 
      LineBox[{{4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}], 
      LineBox[{{4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.903692688761734, 0.16334010117826142`}, {4.995388729675026, 
       0.18422250614305444`}, {4.995388729675026, 0.18422250614305444`}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}}], 
      LineBox[{{4.903692688761734, 0.16334010117826142`}, {4.995388729675026, 
       0.18422250614305444`}, {4.995388729675026, 0.18422250614305444`}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}}], 
      LineBox[{{4.903692688761734, 0.16334010117826142`}, {4.995388729675026, 
       0.18422250614305444`}, {4.995388729675026, 0.18422250614305444`}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}}], 
      LineBox[{{4.903692688761734, 0.16334010117826142`}, {4.995388729675026, 
       0.18422250614305444`}, {4.995388729675026, 0.18422250614305444`}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}}], 
      LineBox[{{4.995388729675026, 0.18422250614305444`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}}], 
      LineBox[{{4.995388729675026, 0.18422250614305444`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}}], 
      LineBox[{{4.995388729675026, 0.18422250614305444`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}}], 
      LineBox[{{4.995388729675026, 0.18422250614305444`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}}], 
      LineBox[{{5.062971846332819, 0.1633401011782614}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}], 
      LineBox[{{5.062971846332819, 0.1633401011782614}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}], 
      LineBox[{{5.062971846332819, 0.1633401011782614}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}], 
      LineBox[{{5.062971846332819, 0.1633401011782614}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}], 
      LineBox[{{5.114848097853341, 0.11525260776808234`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.1426114251183614`, 
       0.025400304428317227`}, {5.114848097853341, 0.11525260776808234`}, {
       5.114848097853341, 0.11525260776808234`}}], 
      LineBox[{{5.114848097853341, 0.11525260776808234`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.1426114251183614`, 
       0.025400304428317227`}, {5.114848097853341, 0.11525260776808234`}, {
       5.114848097853341, 0.11525260776808234`}}], 
      LineBox[{{5.114848097853341, 0.11525260776808234`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.1426114251183614`, 
       0.025400304428317227`}, {5.114848097853341, 0.11525260776808234`}, {
       5.114848097853341, 0.11525260776808234`}}], 
      LineBox[{{5.114848097853341, 0.11525260776808234`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.1426114251183614`, 
       0.025400304428317227`}, {5.114848097853341, 0.11525260776808234`}, {
       5.114848097853341, 0.11525260776808234`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.874002364174817, 
       0.5429196016106428}, {4.888970412742282, 0.47719389635071857`}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.101682885921789, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.101682885921789, 
       0.4114681910907944}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.949895871423808, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.101682885921789, 0.6743710121304911}, {
       5.1511189920747995`, 0.6285454491960256}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.6285454491960256}, {5.101682885921789, 
       0.6743710121304911}, {5.037278731201314, 0.6942711544559498}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}], 
      LineBox[{{4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}], 
      LineBox[{{4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}], 
      LineBox[{{4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}], 
      LineBox[{{4.888970412742282, 0.4771938963507186}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.4771938963507186}, {4.888970412742282, 
       0.4771938963507186}}], 
      LineBox[{{4.888970412742282, 0.4771938963507186}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.4771938963507186}, {4.888970412742282, 
       0.4771938963507186}}], 
      LineBox[{{4.888970412742282, 0.4771938963507186}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.4771938963507186}, {4.888970412742282, 
       0.4771938963507186}}], 
      LineBox[{{4.888970412742282, 0.4771938963507186}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.4771938963507186}, {4.888970412742282, 
       0.4771938963507186}}], 
      LineBox[{{4.874002364174817, 0.5429196016106428}, {4.888970412742282, 
       0.608645306870567}, {4.888970412742282, 0.608645306870567}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}}], 
      LineBox[{{4.874002364174817, 0.5429196016106428}, {4.888970412742282, 
       0.608645306870567}, {4.888970412742282, 0.608645306870567}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}}], 
      LineBox[{{4.874002364174817, 0.5429196016106428}, {4.888970412742282, 
       0.608645306870567}, {4.888970412742282, 0.608645306870567}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}}], 
      LineBox[{{4.874002364174817, 0.5429196016106428}, {4.888970412742282, 
       0.608645306870567}, {4.888970412742282, 0.608645306870567}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}}], 
      LineBox[{{4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}}], 
      LineBox[{{4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}}], 
      LineBox[{{4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}}], 
      LineBox[{{4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}}], 
      LineBox[{{5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}}], 
      LineBox[{{5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}}], 
      LineBox[{{5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}}], 
      LineBox[{{5.1511189920747995`, 0.45729375402525996`}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.1511189920747995`, 0.45729375402525996`}}], 
      LineBox[{{5.1511189920747995`, 0.45729375402525996`}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.1511189920747995`, 0.45729375402525996`}}], 
      LineBox[{{5.1511189920747995`, 0.45729375402525996`}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.1511189920747995`, 0.45729375402525996`}}], 
      LineBox[{{5.1511189920747995`, 0.45729375402525996`}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.1511189920747995`, 0.45729375402525996`}}], 
      LineBox[{{5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}], 
      LineBox[{{5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}], 
      LineBox[{{5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}], 
      LineBox[{{5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}], 
      LineBox[{{5.037278731201314, 0.3915680487653358}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.037278731201314, 
       0.3915680487653358}}], 
      LineBox[{{5.037278731201314, 0.3915680487653358}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.037278731201314, 
       0.3915680487653358}}], 
      LineBox[{{5.037278731201314, 0.3915680487653358}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.037278731201314, 
       0.3915680487653358}}], 
      LineBox[{{5.037278731201314, 0.3915680487653358}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.037278731201314, 
       0.3915680487653358}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.949895871423808, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.037278731201314, 0.6942711544559498}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}}], 
      LineBox[{{4.949895871423808, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.037278731201314, 0.6942711544559498}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}}], 
      LineBox[{{4.949895871423808, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.037278731201314, 0.6942711544559498}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}}], 
      LineBox[{{4.949895871423808, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.037278731201314, 0.6942711544559498}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}}], 
      LineBox[{{5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}}], 
      LineBox[{{5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}}], 
      LineBox[{{5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}}], 
      LineBox[{{5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}}], 
      LineBox[{{5.101682885921789, 0.6743710121304911}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}}], 
      LineBox[{{5.101682885921789, 0.6743710121304911}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}}], 
      LineBox[{{5.101682885921789, 0.6743710121304911}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}}], 
      LineBox[{{5.101682885921789, 0.6743710121304911}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}}], 
      LineBox[{{5.1511189920747995`, 0.6285454491960256}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}}], 
      LineBox[{{5.1511189920747995`, 0.6285454491960256}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}}], 
      LineBox[{{5.1511189920747995`, 0.6285454491960256}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}}], 
      LineBox[{{5.1511189920747995`, 0.6285454491960256}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.838129532382327, 
       1.0010373682731215`}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       0.9072513902123325}, {5.087507973817757, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {4.92125567952747, 
       0.8570586579802866}, {4.92125567952747, 0.8570586579802866}, {
       5.0169661127796505`, 0.835262035065915}, {5.087507973817757, 
       0.8570586579802867}, {5.141655333497366, 0.9072513902123325}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.92125567952747, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.087507973817757, 1.1450160785659564`}, {
       5.141655333497366, 1.0948233463339105`}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 1.0948233463339105`}, {5.087507973817757, 
       1.1450160785659564`}, {5.0169661127796505`, 1.166812701480328}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}], 
      LineBox[{{4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}], 
      LineBox[{{4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}], 
      LineBox[{{4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}], 
      LineBox[{{4.854524033740824, 0.929048013126704}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 0.929048013126704}, {4.854524033740824, 
       0.929048013126704}}], 
      LineBox[{{4.854524033740824, 0.929048013126704}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 0.929048013126704}, {4.854524033740824, 
       0.929048013126704}}], 
      LineBox[{{4.854524033740824, 0.929048013126704}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 0.929048013126704}, {4.854524033740824, 
       0.929048013126704}}], 
      LineBox[{{4.854524033740824, 0.929048013126704}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 0.929048013126704}, {4.854524033740824, 
       0.929048013126704}}], 
      LineBox[{{4.838129532382327, 1.0010373682731215`}, {4.854524033740824, 
       1.073026723419539}, {4.854524033740824, 1.073026723419539}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}}], 
      LineBox[{{4.838129532382327, 1.0010373682731215`}, {4.854524033740824, 
       1.073026723419539}, {4.854524033740824, 1.073026723419539}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}}], 
      LineBox[{{4.838129532382327, 1.0010373682731215`}, {4.854524033740824, 
       1.073026723419539}, {4.854524033740824, 1.073026723419539}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}}], 
      LineBox[{{4.838129532382327, 1.0010373682731215`}, {4.854524033740824, 
       1.073026723419539}, {4.854524033740824, 1.073026723419539}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}}], 
      LineBox[{{4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}}], 
      LineBox[{{4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}}], 
      LineBox[{{4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}}], 
      LineBox[{{4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}}], 
      LineBox[{{5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}}], 
      LineBox[{{5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}}], 
      LineBox[{{5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}}], 
      LineBox[{{5.141655333497366, 0.9072513902123325}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}}], 
      LineBox[{{5.141655333497366, 0.9072513902123325}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}}], 
      LineBox[{{5.141655333497366, 0.9072513902123325}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}}], 
      LineBox[{{5.141655333497366, 0.9072513902123325}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}}], 
      LineBox[{{5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}], 
      LineBox[{{5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}], 
      LineBox[{{5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}], 
      LineBox[{{5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}], 
      LineBox[{{5.0169661127796505`, 0.835262035065915}, {4.92125567952747, 
       0.8570586579802867}, {4.92125567952747, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {5.0169661127796505`, 
       0.835262035065915}}], 
      LineBox[{{5.0169661127796505`, 0.835262035065915}, {4.92125567952747, 
       0.8570586579802867}, {4.92125567952747, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {5.0169661127796505`, 
       0.835262035065915}}], 
      LineBox[{{5.0169661127796505`, 0.835262035065915}, {4.92125567952747, 
       0.8570586579802867}, {4.92125567952747, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {5.0169661127796505`, 
       0.835262035065915}}], 
      LineBox[{{5.0169661127796505`, 0.835262035065915}, {4.92125567952747, 
       0.8570586579802867}, {4.92125567952747, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {5.0169661127796505`, 
       0.835262035065915}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.92125567952747, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.0169661127796505`, 1.166812701480328}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}}], 
      LineBox[{{4.92125567952747, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.0169661127796505`, 1.166812701480328}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}}], 
      LineBox[{{4.92125567952747, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.0169661127796505`, 1.166812701480328}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}}], 
      LineBox[{{4.92125567952747, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.0169661127796505`, 1.166812701480328}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}}], 
      LineBox[{{5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}}], 
      LineBox[{{5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}}], 
      LineBox[{{5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}}], 
      LineBox[{{5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}}], 
      LineBox[{{5.087507973817757, 1.1450160785659564`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}}], 
      LineBox[{{5.087507973817757, 1.1450160785659564`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}}], 
      LineBox[{{5.087507973817757, 1.1450160785659564`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}}], 
      LineBox[{{5.087507973817757, 1.1450160785659564`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}}], 
      LineBox[{{5.141655333497366, 1.0948233463339105`}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}}], 
      LineBox[{{5.141655333497366, 1.0948233463339105`}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}}], 
      LineBox[{{5.141655333497366, 1.0948233463339105`}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}}], 
      LineBox[{{5.141655333497366, 1.0948233463339105`}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.832759097504514, 
       1.496787602616387}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.4014964331319508`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.141156249776097, 1.4014964331319508`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.917219354143963, 1.6430770583362206`}, {5.0144658648169225`,
        1.6652234999607403`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.141156249776097, 1.5920787721008234`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.5920787721008234`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}], 
      LineBox[{{4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}], 
      LineBox[{{4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}], 
      LineBox[{{4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}], 
      LineBox[{{4.849416717757221, 1.4236428747564702`}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.4236428747564702`}, {4.849416717757221, 
       1.4236428747564702`}}], 
      LineBox[{{4.849416717757221, 1.4236428747564702`}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.4236428747564702`}, {4.849416717757221, 
       1.4236428747564702`}}], 
      LineBox[{{4.849416717757221, 1.4236428747564702`}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.4236428747564702`}, {4.849416717757221, 
       1.4236428747564702`}}], 
      LineBox[{{4.849416717757221, 1.4236428747564702`}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.4236428747564702`}, {4.849416717757221, 
       1.4236428747564702`}}], 
      LineBox[{{4.832759097504514, 1.496787602616387}, {4.849416717757221, 
       1.569932330476304}, {4.849416717757221, 1.569932330476304}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}}], 
      LineBox[{{4.832759097504514, 1.496787602616387}, {4.849416717757221, 
       1.569932330476304}, {4.849416717757221, 1.569932330476304}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}}], 
      LineBox[{{4.832759097504514, 1.496787602616387}, {4.849416717757221, 
       1.569932330476304}, {4.849416717757221, 1.569932330476304}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}}], 
      LineBox[{{4.832759097504514, 1.496787602616387}, {4.849416717757221, 
       1.569932330476304}, {4.849416717757221, 1.569932330476304}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}}], 
      LineBox[{{4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}}], 
      LineBox[{{4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}}], 
      LineBox[{{4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}}], 
      LineBox[{{4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}}], 
      LineBox[{{5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}}], 
      LineBox[{{5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}}], 
      LineBox[{{5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}}], 
      LineBox[{{5.141156249776097, 1.4014964331319508`}, {5.0861398674228635`,
        1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}}], 
      LineBox[{{5.141156249776097, 1.4014964331319508`}, {5.0861398674228635`,
        1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}}], 
      LineBox[{{5.141156249776097, 1.4014964331319508`}, {5.0861398674228635`,
        1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}}], 
      LineBox[{{5.141156249776097, 1.4014964331319508`}, {5.0861398674228635`,
        1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}}], 
      LineBox[{{5.0861398674228635`, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}}], 
      LineBox[{{5.0861398674228635`, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}}], 
      LineBox[{{5.0861398674228635`, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}}], 
      LineBox[{{5.0861398674228635`, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}}], 
      LineBox[{{5.0144658648169225`, 1.328351705272034}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}}], 
      LineBox[{{5.0144658648169225`, 1.328351705272034}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}}], 
      LineBox[{{5.0144658648169225`, 1.328351705272034}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}}], 
      LineBox[{{5.0144658648169225`, 1.328351705272034}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.917219354143963, 1.6430770583362206`}, {5.0144658648169225`,
        1.6652234999607403`}, {5.0144658648169225`, 1.6652234999607403`}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}}], 
      LineBox[{{4.917219354143963, 1.6430770583362206`}, {5.0144658648169225`,
        1.6652234999607403`}, {5.0144658648169225`, 1.6652234999607403`}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}}], 
      LineBox[{{4.917219354143963, 1.6430770583362206`}, {5.0144658648169225`,
        1.6652234999607403`}, {5.0144658648169225`, 1.6652234999607403`}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}}], 
      LineBox[{{4.917219354143963, 1.6430770583362206`}, {5.0144658648169225`,
        1.6652234999607403`}, {5.0144658648169225`, 1.6652234999607403`}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}}], 
      LineBox[{{5.0144658648169225`, 1.6652234999607403`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}}], 
      LineBox[{{5.0144658648169225`, 1.6652234999607403`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}}], 
      LineBox[{{5.0144658648169225`, 1.6652234999607403`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}}], 
      LineBox[{{5.0144658648169225`, 1.6652234999607403`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}}], 
      LineBox[{{5.0861398674228635`, 1.6430770583362206`}, {5.141156249776097,
        1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}}], 
      LineBox[{{5.0861398674228635`, 1.6430770583362206`}, {5.141156249776097,
        1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}}], 
      LineBox[{{5.0861398674228635`, 1.6430770583362206`}, {5.141156249776097,
        1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}}], 
      LineBox[{{5.0861398674228635`, 1.6430770583362206`}, {5.141156249776097,
        1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}}], 
      LineBox[{{5.141156249776097, 1.5920787721008234`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}}], 
      LineBox[{{5.141156249776097, 1.5920787721008234`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}}], 
      LineBox[{{5.141156249776097, 1.5920787721008234`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}}], 
      LineBox[{{5.141156249776097, 1.5920787721008234`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.905457129279017, 
       1.96461187479596}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       1.8914425397714019`}, {5.100015581476041, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.100015581476041, 
       1.8522835000468914`}, {5.142259916748895, 1.8914425397714019`}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.970309946678024, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.100015581476041, 2.0769402495450286`}, {
       5.142259916748895, 2.037781209820518}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 2.037781209820518}, {5.100015581476041, 
       2.0769402495450286`}, {5.044980690650383, 2.0939453971950526`}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}], 
      LineBox[{{4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}], 
      LineBox[{{4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}], 
      LineBox[{{4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}], 
      LineBox[{{4.91824768483182, 1.9084476874214258`}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 1.9084476874214258`}, {4.91824768483182, 
       1.9084476874214258`}}], 
      LineBox[{{4.91824768483182, 1.9084476874214258`}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 1.9084476874214258`}, {4.91824768483182, 
       1.9084476874214258`}}], 
      LineBox[{{4.91824768483182, 1.9084476874214258`}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 1.9084476874214258`}, {4.91824768483182, 
       1.9084476874214258`}}], 
      LineBox[{{4.91824768483182, 1.9084476874214258`}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 1.9084476874214258`}, {4.91824768483182, 
       1.9084476874214258`}}], 
      LineBox[{{4.905457129279017, 1.96461187479596}, {4.91824768483182, 
       2.020776062170494}, {4.91824768483182, 2.020776062170494}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}}], 
      LineBox[{{4.905457129279017, 1.96461187479596}, {4.91824768483182, 
       2.020776062170494}, {4.91824768483182, 2.020776062170494}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}}], 
      LineBox[{{4.905457129279017, 1.96461187479596}, {4.91824768483182, 
       2.020776062170494}, {4.91824768483182, 2.020776062170494}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}}], 
      LineBox[{{4.905457129279017, 1.96461187479596}, {4.91824768483182, 
       2.020776062170494}, {4.91824768483182, 2.020776062170494}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}}], 
      LineBox[{{4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}}], 
      LineBox[{{4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}}], 
      LineBox[{{4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}}], 
      LineBox[{{4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}}], 
      LineBox[{{5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}}], 
      LineBox[{{5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}}], 
      LineBox[{{5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}}], 
      LineBox[{{5.142259916748895, 1.8914425397714019`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}}], 
      LineBox[{{5.142259916748895, 1.8914425397714019`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}}], 
      LineBox[{{5.142259916748895, 1.8914425397714019`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}}], 
      LineBox[{{5.142259916748895, 1.8914425397714019`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}}], 
      LineBox[{{5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}], 
      LineBox[{{5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}], 
      LineBox[{{5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}], 
      LineBox[{{5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}], 
      LineBox[{{5.044980690650383, 1.8352783523968677`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.044980690650383, 
       1.8352783523968677`}}], 
      LineBox[{{5.044980690650383, 1.8352783523968677`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.044980690650383, 
       1.8352783523968677`}}], 
      LineBox[{{5.044980690650383, 1.8352783523968677`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.044980690650383, 
       1.8352783523968677`}}], 
      LineBox[{{5.044980690650383, 1.8352783523968677`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.044980690650383, 
       1.8352783523968677`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.970309946678024, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.044980690650383, 2.0939453971950526`}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}}], 
      LineBox[{{4.970309946678024, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.044980690650383, 2.0939453971950526`}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}}], 
      LineBox[{{4.970309946678024, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.044980690650383, 2.0939453971950526`}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}}], 
      LineBox[{{4.970309946678024, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.044980690650383, 2.0939453971950526`}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}}], 
      LineBox[{{5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}}], 
      LineBox[{{5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}}], 
      LineBox[{{5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}}], 
      LineBox[{{5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}}], 
      LineBox[{{5.100015581476041, 2.0769402495450286`}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}}], 
      LineBox[{{5.100015581476041, 2.0769402495450286`}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}}], 
      LineBox[{{5.100015581476041, 2.0769402495450286`}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}}], 
      LineBox[{{5.100015581476041, 2.0769402495450286`}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}}], 
      LineBox[{{5.142259916748895, 2.037781209820518}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}}], 
      LineBox[{{5.142259916748895, 2.037781209820518}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}}], 
      LineBox[{{5.142259916748895, 2.037781209820518}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}}], 
      LineBox[{{5.142259916748895, 2.037781209820518}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.910684658403933, 
       2.539406099066727}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.4614885895907976`}, {5.117868583713569, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.117868583713569, 
       2.4197884040174453`}, {5.162854278784081, 2.4614885895907976`}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.979745966840478, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.117868583713569, 2.6590237941160084`}, {
       5.162854278784081, 2.617323608542656}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.617323608542656}, {5.117868583713569, 
       2.6590237941160084`}, {5.059262316129264, 2.677132456067297}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}], 
      LineBox[{{4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}], 
      LineBox[{{4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}], 
      LineBox[{{4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}], 
      LineBox[{{4.924305230917724, 2.4795972515420863`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.4795972515420863`}, {4.924305230917724, 
       2.4795972515420863`}}], 
      LineBox[{{4.924305230917724, 2.4795972515420863`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.4795972515420863`}, {4.924305230917724, 
       2.4795972515420863`}}], 
      LineBox[{{4.924305230917724, 2.4795972515420863`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.4795972515420863`}, {4.924305230917724, 
       2.4795972515420863`}}], 
      LineBox[{{4.924305230917724, 2.4795972515420863`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.4795972515420863`}, {4.924305230917724, 
       2.4795972515420863`}}], 
      LineBox[{{4.910684658403933, 2.539406099066727}, {4.924305230917724, 
       2.5992149465913674`}, {4.924305230917724, 2.5992149465913674`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}}], 
      LineBox[{{4.910684658403933, 2.539406099066727}, {4.924305230917724, 
       2.5992149465913674`}, {4.924305230917724, 2.5992149465913674`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}}], 
      LineBox[{{4.910684658403933, 2.539406099066727}, {4.924305230917724, 
       2.5992149465913674`}, {4.924305230917724, 2.5992149465913674`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}}], 
      LineBox[{{4.910684658403933, 2.539406099066727}, {4.924305230917724, 
       2.5992149465913674`}, {4.924305230917724, 2.5992149465913674`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}}], 
      LineBox[{{4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}}], 
      LineBox[{{4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}}], 
      LineBox[{{4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}}], 
      LineBox[{{4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}}], 
      LineBox[{{5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}}], 
      LineBox[{{5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}}], 
      LineBox[{{5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}}], 
      LineBox[{{5.162854278784081, 2.4614885895907976`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}}], 
      LineBox[{{5.162854278784081, 2.4614885895907976`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}}], 
      LineBox[{{5.162854278784081, 2.4614885895907976`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}}], 
      LineBox[{{5.162854278784081, 2.4614885895907976`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}}], 
      LineBox[{{5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}], 
      LineBox[{{5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}], 
      LineBox[{{5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}], 
      LineBox[{{5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}], 
      LineBox[{{5.059262316129264, 2.4016797420661566`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.059262316129264, 
       2.4016797420661566`}}], 
      LineBox[{{5.059262316129264, 2.4016797420661566`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.059262316129264, 
       2.4016797420661566`}}], 
      LineBox[{{5.059262316129264, 2.4016797420661566`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.059262316129264, 
       2.4016797420661566`}}], 
      LineBox[{{5.059262316129264, 2.4016797420661566`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.059262316129264, 
       2.4016797420661566`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.979745966840478, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.059262316129264, 2.677132456067297}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}}], 
      LineBox[{{4.979745966840478, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.059262316129264, 2.677132456067297}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}}], 
      LineBox[{{4.979745966840478, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.059262316129264, 2.677132456067297}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}}], 
      LineBox[{{4.979745966840478, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.059262316129264, 2.677132456067297}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}}], 
      LineBox[{{5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}}], 
      LineBox[{{5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}}], 
      LineBox[{{5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}}], 
      LineBox[{{5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}}], 
      LineBox[{{5.117868583713569, 2.6590237941160084`}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}}], 
      LineBox[{{5.117868583713569, 2.6590237941160084`}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}}], 
      LineBox[{{5.117868583713569, 2.6590237941160084`}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}}], 
      LineBox[{{5.117868583713569, 2.6590237941160084`}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}}], 
      LineBox[{{5.162854278784081, 2.617323608542656}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}}], 
      LineBox[{{5.162854278784081, 2.617323608542656}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}}], 
      LineBox[{{5.162854278784081, 2.617323608542656}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}}], 
      LineBox[{{5.162854278784081, 2.617323608542656}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 3.0627309742051247`}, {4.907638449644008, 
       3.1327112266676638`}, {4.907638449644008, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.826832214449598, 
       2.9927507217425853`}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888,
        2.9015821537120545`}, {5.069250920032828, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {4.907638449644009, 
       2.8527902168175068`}, {4.907638449644009, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.069250920032828, 
       2.8527902168175068`}, {5.121887117326888, 2.9015821537120545`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.907638449644009, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.069250920032828, 3.1327112266676638`}, {
       5.121887117326888, 3.083919289773116}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 3.083919289773116}, {5.069250920032828, 
       3.1327112266676638`}, {5.000677764535273, 3.153899542235655}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}], 
      LineBox[{{4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}], 
      LineBox[{{4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}], 
      LineBox[{{4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}], 
      LineBox[{{4.842769172653094, 2.922770469280046}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 2.922770469280046}, {4.842769172653094, 
       2.922770469280046}}], 
      LineBox[{{4.842769172653094, 2.922770469280046}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 2.922770469280046}, {4.842769172653094, 
       2.922770469280046}}], 
      LineBox[{{4.842769172653094, 2.922770469280046}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 2.922770469280046}, {4.842769172653094, 
       2.922770469280046}}], 
      LineBox[{{4.842769172653094, 2.922770469280046}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 2.922770469280046}, {4.842769172653094, 
       2.922770469280046}}], 
      LineBox[{{4.826832214449598, 2.9927507217425853`}, {4.842769172653094, 
       3.0627309742051247`}, {4.842769172653094, 3.0627309742051247`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}}], 
      LineBox[{{4.826832214449598, 2.9927507217425853`}, {4.842769172653094, 
       3.0627309742051247`}, {4.842769172653094, 3.0627309742051247`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}}], 
      LineBox[{{4.826832214449598, 2.9927507217425853`}, {4.842769172653094, 
       3.0627309742051247`}, {4.842769172653094, 3.0627309742051247`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}}], 
      LineBox[{{4.826832214449598, 2.9927507217425853`}, {4.842769172653094, 
       3.0627309742051247`}, {4.842769172653094, 3.0627309742051247`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}}], 
      LineBox[{{4.842769172653094, 3.0627309742051247`}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}}], 
      LineBox[{{4.842769172653094, 3.0627309742051247`}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}}], 
      LineBox[{{4.842769172653094, 3.0627309742051247`}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}}], 
      LineBox[{{4.842769172653094, 3.0627309742051247`}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888,
        2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}}], 
      LineBox[{{5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888,
        2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}}], 
      LineBox[{{5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888,
        2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}}], 
      LineBox[{{5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888,
        2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}}], 
      LineBox[{{5.121887117326888, 2.9015821537120545`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}}], 
      LineBox[{{5.121887117326888, 2.9015821537120545`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}}], 
      LineBox[{{5.121887117326888, 2.9015821537120545`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}}], 
      LineBox[{{5.121887117326888, 2.9015821537120545`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}}], 
      LineBox[{{5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}], 
      LineBox[{{5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}], 
      LineBox[{{5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}], 
      LineBox[{{5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}], 
      LineBox[{{5.000677764535273, 2.8316019012495155`}, {4.907638449644009, 
       2.8527902168175068`}, {4.907638449644009, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.000677764535273, 
       2.8316019012495155`}}], 
      LineBox[{{5.000677764535273, 2.8316019012495155`}, {4.907638449644009, 
       2.8527902168175068`}, {4.907638449644009, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.000677764535273, 
       2.8316019012495155`}}], 
      LineBox[{{5.000677764535273, 2.8316019012495155`}, {4.907638449644009, 
       2.8527902168175068`}, {4.907638449644009, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.000677764535273, 
       2.8316019012495155`}}], 
      LineBox[{{5.000677764535273, 2.8316019012495155`}, {4.907638449644009, 
       2.8527902168175068`}, {4.907638449644009, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.000677764535273, 
       2.8316019012495155`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.907638449644009, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.000677764535273, 3.153899542235655}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}}], 
      LineBox[{{4.907638449644009, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.000677764535273, 3.153899542235655}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}}], 
      LineBox[{{4.907638449644009, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.000677764535273, 3.153899542235655}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}}], 
      LineBox[{{4.907638449644009, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.000677764535273, 3.153899542235655}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}}], 
      LineBox[{{5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}}], 
      LineBox[{{5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}}], 
      LineBox[{{5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}}], 
      LineBox[{{5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}}], 
      LineBox[{{5.069250920032828, 3.1327112266676638`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}}], 
      LineBox[{{5.069250920032828, 3.1327112266676638`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}}], 
      LineBox[{{5.069250920032828, 3.1327112266676638`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}}], 
      LineBox[{{5.069250920032828, 3.1327112266676638`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}}], 
      LineBox[{{5.121887117326888, 3.083919289773116}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}}], 
      LineBox[{{5.121887117326888, 3.083919289773116}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}}], 
      LineBox[{{5.121887117326888, 3.083919289773116}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}}], 
      LineBox[{{5.121887117326888, 3.083919289773116}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.89204021083357, 
       3.456468031047497}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.38020120150832}, {5.094834951337038, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.094834951337038, 
       3.3393844330275795`}, {5.138867625901722, 3.38020120150832}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.95963845766806, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.094834951337038, 3.5735516290674147`}, {
       5.138867625901722, 3.5327348605866744`}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.5327348605866744`}, {5.094834951337038, 
       3.5735516290674147`}, {5.037470255649987, 3.591276659596633}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}], 
      LineBox[{{4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}], 
      LineBox[{{4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}], 
      LineBox[{{4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}], 
      LineBox[{{4.905372231955938, 3.3979262320375385`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.3979262320375385`}, {4.905372231955938, 
       3.3979262320375385`}}], 
      LineBox[{{4.905372231955938, 3.3979262320375385`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.3979262320375385`}, {4.905372231955938, 
       3.3979262320375385`}}], 
      LineBox[{{4.905372231955938, 3.3979262320375385`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.3979262320375385`}, {4.905372231955938, 
       3.3979262320375385`}}], 
      LineBox[{{4.905372231955938, 3.3979262320375385`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.3979262320375385`}, {4.905372231955938, 
       3.3979262320375385`}}], 
      LineBox[{{4.89204021083357, 3.456468031047497}, {4.905372231955938, 
       3.5150098300574557`}, {4.905372231955938, 3.5150098300574557`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}}], 
      LineBox[{{4.89204021083357, 3.456468031047497}, {4.905372231955938, 
       3.5150098300574557`}, {4.905372231955938, 3.5150098300574557`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}}], 
      LineBox[{{4.89204021083357, 3.456468031047497}, {4.905372231955938, 
       3.5150098300574557`}, {4.905372231955938, 3.5150098300574557`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}}], 
      LineBox[{{4.89204021083357, 3.456468031047497}, {4.905372231955938, 
       3.5150098300574557`}, {4.905372231955938, 3.5150098300574557`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}}], 
      LineBox[{{4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}}], 
      LineBox[{{4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}}], 
      LineBox[{{4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}}], 
      LineBox[{{4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}}], 
      LineBox[{{5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}}], 
      LineBox[{{5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}}], 
      LineBox[{{5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}}], 
      LineBox[{{5.138867625901722, 3.38020120150832}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}}], 
      LineBox[{{5.138867625901722, 3.38020120150832}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}}], 
      LineBox[{{5.138867625901722, 3.38020120150832}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}}], 
      LineBox[{{5.138867625901722, 3.38020120150832}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}}], 
      LineBox[{{5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}], 
      LineBox[{{5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}], 
      LineBox[{{5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}], 
      LineBox[{{5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}], 
      LineBox[{{5.037470255649987, 3.3216594024983612`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.037470255649987, 
       3.3216594024983612`}}], 
      LineBox[{{5.037470255649987, 3.3216594024983612`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.037470255649987, 
       3.3216594024983612`}}], 
      LineBox[{{5.037470255649987, 3.3216594024983612`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.037470255649987, 
       3.3216594024983612`}}], 
      LineBox[{{5.037470255649987, 3.3216594024983612`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.037470255649987, 
       3.3216594024983612`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{4.95963845766806, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.037470255649987, 3.591276659596633}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}}], 
      LineBox[{{4.95963845766806, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.037470255649987, 3.591276659596633}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}}], 
      LineBox[{{4.95963845766806, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.037470255649987, 3.591276659596633}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}}], 
      LineBox[{{4.95963845766806, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.037470255649987, 3.591276659596633}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}}], 
      LineBox[{{5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}}], 
      LineBox[{{5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}}], 
      LineBox[{{5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}}], 
      LineBox[{{5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}}], 
      LineBox[{{5.094834951337038, 3.5735516290674147`}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}}], 
      LineBox[{{5.094834951337038, 3.5735516290674147`}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}}], 
      LineBox[{{5.094834951337038, 3.5735516290674147`}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}}], 
      LineBox[{{5.094834951337038, 3.5735516290674147`}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}}], 
      LineBox[{{5.138867625901722, 3.5327348605866744`}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}}], 
      LineBox[{{5.138867625901722, 3.5327348605866744`}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}}], 
      LineBox[{{5.138867625901722, 3.5327348605866744`}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}}], 
      LineBox[{{5.138867625901722, 3.5327348605866744`}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}], 
      LineBox[{{5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}], 
      LineBox[{{5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}], 
      LineBox[{{5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}], 
      LineBox[{{5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}], 
      LineBox[{{5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}], 
      LineBox[{{5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}], 
      LineBox[{{5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}], 
      LineBox[{{5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}], 
      LineBox[{{5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}], 
      LineBox[{{5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}], 
      LineBox[{{5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}], 
      LineBox[{{5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}], 
      LineBox[{{5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}], 
      LineBox[{{5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}], 
      LineBox[{{5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}], 
      LineBox[{{5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}], 
      LineBox[{{5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}], 
      LineBox[{{5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}], 
      LineBox[{{5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}], 
      LineBox[{{5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}], 
      LineBox[{{5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}], 
      LineBox[{{5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}], 
      LineBox[{{5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}], 
      LineBox[{{5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}], 
      LineBox[{{5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}], 
      LineBox[{{5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}], 
      LineBox[{{5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}], 
      LineBox[{{5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}], 
      LineBox[{{5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}], 
      LineBox[{{5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}], 
      LineBox[{{5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}], 
      LineBox[{{5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}], 
      LineBox[{{5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}], 
      LineBox[{{5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}], 
      LineBox[{{5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}], 
      LineBox[{{5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}], 
      LineBox[{{5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}], 
      LineBox[{{5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}], 
      LineBox[{{5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}], 
      LineBox[{{5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}], 
      LineBox[{{5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}], 
      LineBox[{{5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}], 
      LineBox[{{5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}], 
      LineBox[{{5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}], 
      LineBox[{{5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}], 
      LineBox[{{5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}], 
      LineBox[{{5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}], 
      LineBox[{{5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}], 
      LineBox[{{5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}], 
      LineBox[{{5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}], 
      LineBox[{{5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}], 
      LineBox[{{5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}], 
      LineBox[{{5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}], 
      LineBox[{{5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}], 
      LineBox[{{5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}], 
      LineBox[{{5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}], 
      LineBox[{{5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}], 
      LineBox[{{5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}], 
      LineBox[{{5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}], 
      LineBox[{{5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}], 
      LineBox[{{5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}], 
      LineBox[{{5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}], 
      LineBox[{{5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}], 
      LineBox[{{5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}], 
      LineBox[{{5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}], 
      LineBox[{{5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}], 
      LineBox[{{5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}], 
      LineBox[{{5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}], 
      LineBox[{{5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}], 
      LineBox[{{5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}], 
      LineBox[{{5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}], 
      LineBox[{{5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}], 
      LineBox[{{5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}], 
      LineBox[{{5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}], 
      LineBox[{{5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}], 
      LineBox[{{5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}], 
      LineBox[{{5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}], 
      LineBox[{{5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}], 
      LineBox[{{5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}], 
      LineBox[{{5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}], 
      LineBox[{{5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}], 
      LineBox[{{5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}], 
      LineBox[{{5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}], 
      LineBox[{{5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}], 
      LineBox[{{5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}], 
      LineBox[{{5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}], 
      LineBox[{{5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}], 
      LineBox[{{5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}], 
      LineBox[{{5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}], 
      LineBox[{{5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}], 
      LineBox[{{5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}], 
      LineBox[{{5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}], 
      LineBox[{{5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}], 
      LineBox[{{5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}], 
      LineBox[{{5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}], 
      LineBox[{{5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}], 
      LineBox[{{5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}], 
      LineBox[{{5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}], 
      LineBox[{{5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}], 
      LineBox[{{5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}], 
      LineBox[{{5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}], 
      LineBox[{{5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}], 
      LineBox[{{5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}], 
      LineBox[{{5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}], 
      LineBox[{{5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}], 
      LineBox[{{5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}], 
      LineBox[{{5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}], 
      LineBox[{{5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}], 
      LineBox[{{5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}], 
      LineBox[{{5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}], 
      LineBox[{{5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}], 
      LineBox[{{5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}], 
      LineBox[{{5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}], 
      LineBox[{{5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}], 
      LineBox[{{5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}], 
      LineBox[{{5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}], 
      LineBox[{{5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}], 
      LineBox[{{5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}], 
      LineBox[{{5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}], 
      LineBox[{{5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}], 
      LineBox[{{5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}], 
      LineBox[{{5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}], 
      LineBox[{{5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}], 
      LineBox[{{5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}], 
      LineBox[{{5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}], 
      LineBox[{{5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}], 
      LineBox[{{5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}], 
      LineBox[{{5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}], 
      LineBox[{{5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}], 
      LineBox[{{5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}], 
      LineBox[{{5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}], 
      LineBox[{{5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}], 
      LineBox[{{5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}], 
      LineBox[{{5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}], 
      LineBox[{{5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.572334059908817}, {
       5.150456015732221, -2.572334059908817}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.872891371667967}, {
       5.150456015732221, -2.872891371667967}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}], 
      LineBox[{{5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}], 
      LineBox[{{5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}], 
      LineBox[{{5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}], 
      LineBox[{{5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}], 
      LineBox[{{5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}], 
      LineBox[{{5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}], 
      LineBox[{{5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}], 
      LineBox[{{5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}], 
      LineBox[{{5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}], 
      LineBox[{{5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}], 
      LineBox[{{5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}], 
      LineBox[{{5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}], 
      LineBox[{{5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}], 
      LineBox[{{5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}], 
      LineBox[{{5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}], 
      LineBox[{{5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}], 
      LineBox[{{5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}], 
      LineBox[{{5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}], 
      LineBox[{{5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}], 
      LineBox[{{5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}], 
      LineBox[{{5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}], 
      LineBox[{{5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}], 
      LineBox[{{5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}], 
      LineBox[{{5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}], 
      LineBox[{{5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}], 
      LineBox[{{5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}], 
      LineBox[{{5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}], 
      LineBox[{{5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}], 
      LineBox[{{5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}], 
      LineBox[{{5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}], 
      LineBox[{{5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}], 
      LineBox[{{5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}], 
      LineBox[{{5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}], 
      LineBox[{{5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}], 
      LineBox[{{5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}], 
      LineBox[{{5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}], 
      LineBox[{{5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}], 
      LineBox[{{5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}], 
      LineBox[{{5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}], 
      LineBox[{{5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}], 
      LineBox[{{5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}], 
      LineBox[{{5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}], 
      LineBox[{{5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}], 
      LineBox[{{5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}], 
      LineBox[{{5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.35914164638797, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}], 
      LineBox[{{5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}], 
      LineBox[{{5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}], 
      LineBox[{{5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}], 
      LineBox[{{5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}], 
      LineBox[{{5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}], 
      LineBox[{{5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}], 
      LineBox[{{5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}], 
      LineBox[{{5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}], 
      LineBox[{{5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}], 
      LineBox[{{5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}], 
      LineBox[{{5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}], 
      LineBox[{{5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}], 
      LineBox[{{5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}], 
      LineBox[{{5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}], 
      LineBox[{{5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}], 
      LineBox[{{5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}], 
      LineBox[{{5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}], 
      LineBox[{{5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}], 
      LineBox[{{5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}], 
      LineBox[{{5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}], 
      LineBox[{{5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}], 
      LineBox[{{5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}], 
      LineBox[{{5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}], 
      LineBox[{{5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}], 
      LineBox[{{5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}], 
      LineBox[{{5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}], 
      LineBox[{{5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}], 
      LineBox[{{5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}], 
      LineBox[{{5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}], 
      LineBox[{{5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}], 
      LineBox[{{5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}], 
      LineBox[{{5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}], 
      LineBox[{{5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}], 
      LineBox[{{5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}], 
      LineBox[{{5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}], 
      LineBox[{{5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}], 
      LineBox[{{5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}], 
      LineBox[{{5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}], 
      LineBox[{{5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}], 
      LineBox[{{5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}], 
      LineBox[{{5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}], 
      LineBox[{{5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}], 
      LineBox[{{5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}], 
      LineBox[{{5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}], 
      LineBox[{{5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}], 
      LineBox[{{5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}], 
      LineBox[{{5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}], 
      LineBox[{{5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}], 
      LineBox[{{5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}], 
      LineBox[{{5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}], 
      LineBox[{{5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}], 
      LineBox[{{5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}], 
      LineBox[{{5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}], 
      LineBox[{{5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}], 
      LineBox[{{5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}], 
      LineBox[{{5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}], 
      LineBox[{{5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}], 
      LineBox[{{5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}], 
      LineBox[{{5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}], 
      LineBox[{{5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}], 
      LineBox[{{5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}], 
      LineBox[{{5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}], 
      LineBox[{{5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}], 
      LineBox[{{5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}], 
      LineBox[{{5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}], 
      LineBox[{{5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}], 
      LineBox[{{5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}], 
      LineBox[{{5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}], 
      LineBox[{{5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}], 
      LineBox[{{5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}], 
      LineBox[{{5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}], 
      LineBox[{{5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}], 
      LineBox[{{5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}], 
      LineBox[{{5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}], 
      LineBox[{{5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}], 
      LineBox[{{5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}], 
      LineBox[{{5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}], 
      LineBox[{{5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}], 
      LineBox[{{5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}], 
      LineBox[{{5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}], 
      LineBox[{{5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}], 
      LineBox[{{5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}], 
      LineBox[{{5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}], 
      LineBox[{{5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}], 
      LineBox[{{5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}], 
      LineBox[{{5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}], 
      LineBox[{{5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}], 
      LineBox[{{5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}], 
      LineBox[{{5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}], 
      LineBox[{{5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.162208191993878}, {
       5.19335521461503, -1.162208191993878}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848608`}, {
       5.19335521461503, -1.4089886270848608`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}], 
      LineBox[{{5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}], 
      LineBox[{{5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}], 
      LineBox[{{5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}], 
      LineBox[{{5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}], 
      LineBox[{{5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}], 
      LineBox[{{5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}], 
      LineBox[{{5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}], 
      LineBox[{{5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}], 
      LineBox[{{5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}], 
      LineBox[{{5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}], 
      LineBox[{{5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}], 
      LineBox[{{5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}], 
      LineBox[{{5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}], 
      LineBox[{{5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}], 
      LineBox[{{5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}], 
      LineBox[{{5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}], 
      LineBox[{{5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}], 
      LineBox[{{5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}], 
      LineBox[{{5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}], 
      LineBox[{{5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}], 
      LineBox[{{5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}], 
      LineBox[{{5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}], 
      LineBox[{{5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}], 
      LineBox[{{5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}], 
      LineBox[{{5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}], 
      LineBox[{{5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}], 
      LineBox[{{5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}], 
      LineBox[{{5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}], 
      LineBox[{{5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}], 
      LineBox[{{5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}], 
      LineBox[{{5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}], 
      LineBox[{{5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}], 
      LineBox[{{5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}], 
      LineBox[{{5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}], 
      LineBox[{{5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}], 
      LineBox[{{5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}], 
      LineBox[{{5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}], 
      LineBox[{{5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}], 
      LineBox[{{5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}], 
      LineBox[{{5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}], 
      LineBox[{{5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}], 
      LineBox[{{5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}], 
      LineBox[{{5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}], 
      LineBox[{{5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}], 
      LineBox[{{5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.3321267483001495`, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}], 
      LineBox[{{5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}], 
      LineBox[{{5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}], 
      LineBox[{{5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}], 
      LineBox[{{5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}], 
      LineBox[{{5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}], 
      LineBox[{{5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}], 
      LineBox[{{5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}], 
      LineBox[{{5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}], 
      LineBox[{{5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}], 
      LineBox[{{5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}], 
      LineBox[{{5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}], 
      LineBox[{{5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}], 
      LineBox[{{5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}], 
      LineBox[{{5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}], 
      LineBox[{{5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}], 
      LineBox[{{5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}], 
      LineBox[{{5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}], 
      LineBox[{{5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}], 
      LineBox[{{5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}], 
      LineBox[{{5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}], 
      LineBox[{{5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}], 
      LineBox[{{5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}], 
      LineBox[{{5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}], 
      LineBox[{{5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}], 
      LineBox[{{5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}], 
      LineBox[{{5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}], 
      LineBox[{{5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}], 
      LineBox[{{5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}], 
      LineBox[{{5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}], 
      LineBox[{{5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}], 
      LineBox[{{5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}], 
      LineBox[{{5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}], 
      LineBox[{{5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}], 
      LineBox[{{5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}], 
      LineBox[{{5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}], 
      LineBox[{{5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}], 
      LineBox[{{5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}], 
      LineBox[{{5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}], 
      LineBox[{{5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}], 
      LineBox[{{5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}], 
      LineBox[{{5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}], 
      LineBox[{{5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}], 
      LineBox[{{5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}], 
      LineBox[{{5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}], 
      LineBox[{{5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.20021028433532914`}, {
       5.459273354743041, -0.20021028433532914`}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}], 
      LineBox[{{5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}], 
      LineBox[{{5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}], 
      LineBox[{{5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}], 
      LineBox[{{5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}], 
      LineBox[{{5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}], 
      LineBox[{{5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}], 
      LineBox[{{5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}], 
      LineBox[{{5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}], 
      LineBox[{{5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}], 
      LineBox[{{5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}], 
      LineBox[{{5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}], 
      LineBox[{{5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}], 
      LineBox[{{5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}], 
      LineBox[{{5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}], 
      LineBox[{{5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}], 
      LineBox[{{5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}], 
      LineBox[{{5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}], 
      LineBox[{{5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}], 
      LineBox[{{5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}], 
      LineBox[{{5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}], 
      LineBox[{{5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}], 
      LineBox[{{5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}], 
      LineBox[{{5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}], 
      LineBox[{{5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}], 
      LineBox[{{5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}], 
      LineBox[{{5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}], 
      LineBox[{{5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}], 
      LineBox[{{5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}], 
      LineBox[{{5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}], 
      LineBox[{{5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}], 
      LineBox[{{5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}], 
      LineBox[{{5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}], 
      LineBox[{{5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}], 
      LineBox[{{5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}], 
      LineBox[{{5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}], 
      LineBox[{{5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}], 
      LineBox[{{5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}], 
      LineBox[{{5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}], 
      LineBox[{{5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}], 
      LineBox[{{5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}], 
      LineBox[{{5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}], 
      LineBox[{{5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}], 
      LineBox[{{5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}], 
      LineBox[{{5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}], 
      LineBox[{{5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.131303594638972, 0.1103341841679071}, {5.0673708809907, 
       0.17930408254287916`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.3172438792928233}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}, {
       5.0673708809907, 0.3172438792928233}, {5.051664015853429, 
       0.24827398091785124`}, {5.0673708809907, 0.17930408254287916`}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.290582752210057, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.11033418416790708`}, {5.131303594638972, 0.11033418416790708`}, {
       5.222999635552264, 0.08945177920311406}, {5.290582752210057, 
       0.1103341841679071}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.290582752210057, 0.3862137776677954}, {
       5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785127`}, {5.370222330995599, 0.24827398091785127`}, {
       5.342459003730578, 0.3381262842576163}, {5.290582752210057, 
       0.3862137776677954}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.131303594638972, 0.1103341841679071}, {5.0673708809907, 
       0.17930408254287916`}, {5.0673708809907, 0.17930408254287916`}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}}], 
      LineBox[{{5.131303594638972, 0.1103341841679071}, {5.0673708809907, 
       0.17930408254287916`}, {5.0673708809907, 0.17930408254287916`}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}}], 
      LineBox[{{5.131303594638972, 0.1103341841679071}, {5.0673708809907, 
       0.17930408254287916`}, {5.0673708809907, 0.17930408254287916`}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}}], 
      LineBox[{{5.131303594638972, 0.1103341841679071}, {5.0673708809907, 
       0.17930408254287916`}, {5.0673708809907, 0.17930408254287916`}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}}], 
      LineBox[{{5.0673708809907, 0.17930408254287916`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}}], 
      LineBox[{{5.0673708809907, 0.17930408254287916`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}}], 
      LineBox[{{5.0673708809907, 0.17930408254287916`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}}], 
      LineBox[{{5.0673708809907, 0.17930408254287916`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}}], 
      LineBox[{{5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}], 
      LineBox[{{5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}], 
      LineBox[{{5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}], 
      LineBox[{{5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}], 
      LineBox[{{5.0673708809907, 0.3172438792928233}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}}], 
      LineBox[{{5.0673708809907, 0.3172438792928233}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}}], 
      LineBox[{{5.0673708809907, 0.3172438792928233}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}}], 
      LineBox[{{5.0673708809907, 0.3172438792928233}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}], 
      LineBox[{{5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}], 
      LineBox[{{5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}], 
      LineBox[{{5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}], 
      LineBox[{{5.342459003730578, 0.15842167757808617`}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.342459003730578, 0.15842167757808617`}, {5.342459003730578, 
       0.15842167757808617`}}], 
      LineBox[{{5.342459003730578, 0.15842167757808617`}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.342459003730578, 0.15842167757808617`}, {5.342459003730578, 
       0.15842167757808617`}}], 
      LineBox[{{5.342459003730578, 0.15842167757808617`}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.342459003730578, 0.15842167757808617`}, {5.342459003730578, 
       0.15842167757808617`}}], 
      LineBox[{{5.342459003730578, 0.15842167757808617`}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.342459003730578, 0.15842167757808617`}, {5.342459003730578, 
       0.15842167757808617`}}], 
      LineBox[{{5.290582752210057, 0.1103341841679071}, {5.222999635552264, 
       0.08945177920311406}, {5.222999635552264, 0.08945177920311406}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}}], 
      LineBox[{{5.290582752210057, 0.1103341841679071}, {5.222999635552264, 
       0.08945177920311406}, {5.222999635552264, 0.08945177920311406}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}}], 
      LineBox[{{5.290582752210057, 0.1103341841679071}, {5.222999635552264, 
       0.08945177920311406}, {5.222999635552264, 0.08945177920311406}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}}], 
      LineBox[{{5.290582752210057, 0.1103341841679071}, {5.222999635552264, 
       0.08945177920311406}, {5.222999635552264, 0.08945177920311406}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}}], 
      LineBox[{{5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}}], 
      LineBox[{{5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}}], 
      LineBox[{{5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}}], 
      LineBox[{{5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}], 
      LineBox[{{5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}], 
      LineBox[{{5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}], 
      LineBox[{{5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}], 
      LineBox[{{5.222999635552264, 0.4070961826325884}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}}], 
      LineBox[{{5.222999635552264, 0.4070961826325884}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}}], 
      LineBox[{{5.222999635552264, 0.4070961826325884}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}}], 
      LineBox[{{5.222999635552264, 0.4070961826325884}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}}], 
      LineBox[{{5.290582752210057, 0.3862137776677954}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}], 
      LineBox[{{5.290582752210057, 0.3862137776677954}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}], 
      LineBox[{{5.290582752210057, 0.3862137776677954}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}], 
      LineBox[{{5.290582752210057, 0.3862137776677954}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}], 
      LineBox[{{5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785122`}, {5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.3381262842576163}, {5.342459003730578, 
       0.3381262842576163}}], 
      LineBox[{{5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785122`}, {5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.3381262842576163}, {5.342459003730578, 
       0.3381262842576163}}], 
      LineBox[{{5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785122`}, {5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.3381262842576163}, {5.342459003730578, 
       0.3381262842576163}}], 
      LineBox[{{5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785122`}, {5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.3381262842576163}, {5.342459003730578, 
       0.3381262842576163}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.165093633765845, 0.6255875834022371}, {5.104168175084318, 
       0.6913132886621612}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.8227646991820096}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}, {
       5.104168175084318, 0.8227646991820096}, {5.089200126516854, 
       0.7570389939220854}, {5.104168175084318, 0.6913132886621612}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.316880648263825, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.316880648263825, 
       0.6255875834022371}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.316880648263825, 0.8884904044419337}, {
       5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.316880648263825, 
       0.8884904044419337}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.165093633765845, 0.6255875834022371}, {5.104168175084318, 
       0.6913132886621612}, {5.104168175084318, 0.6913132886621612}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}}], 
      LineBox[{{5.165093633765845, 0.6255875834022371}, {5.104168175084318, 
       0.6913132886621612}, {5.104168175084318, 0.6913132886621612}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}}], 
      LineBox[{{5.165093633765845, 0.6255875834022371}, {5.104168175084318, 
       0.6913132886621612}, {5.104168175084318, 0.6913132886621612}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}}], 
      LineBox[{{5.165093633765845, 0.6255875834022371}, {5.104168175084318, 
       0.6913132886621612}, {5.104168175084318, 0.6913132886621612}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}}], 
      LineBox[{{5.104168175084318, 0.6913132886621612}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}}], 
      LineBox[{{5.104168175084318, 0.6913132886621612}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}}], 
      LineBox[{{5.104168175084318, 0.6913132886621612}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}}], 
      LineBox[{{5.104168175084318, 0.6913132886621612}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}}], 
      LineBox[{{5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}], 
      LineBox[{{5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}], 
      LineBox[{{5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}], 
      LineBox[{{5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}], 
      LineBox[{{5.104168175084318, 0.8227646991820096}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}}], 
      LineBox[{{5.104168175084318, 0.8227646991820096}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}}], 
      LineBox[{{5.104168175084318, 0.8227646991820096}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}}], 
      LineBox[{{5.104168175084318, 0.8227646991820096}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}], 
      LineBox[{{5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}], 
      LineBox[{{5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}], 
      LineBox[{{5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}], 
      LineBox[{{5.366316754416836, 0.6714131463367026}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.366316754416836, 0.6714131463367026}, {5.366316754416836, 
       0.6714131463367026}}], 
      LineBox[{{5.366316754416836, 0.6714131463367026}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.366316754416836, 0.6714131463367026}, {5.366316754416836, 
       0.6714131463367026}}], 
      LineBox[{{5.366316754416836, 0.6714131463367026}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.366316754416836, 0.6714131463367026}, {5.366316754416836, 
       0.6714131463367026}}], 
      LineBox[{{5.366316754416836, 0.6714131463367026}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.366316754416836, 0.6714131463367026}, {5.366316754416836, 
       0.6714131463367026}}], 
      LineBox[{{5.316880648263825, 0.6255875834022371}, {5.252476493543351, 
       0.6056874410767784}, {5.252476493543351, 0.6056874410767784}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}}], 
      LineBox[{{5.316880648263825, 0.6255875834022371}, {5.252476493543351, 
       0.6056874410767784}, {5.252476493543351, 0.6056874410767784}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}}], 
      LineBox[{{5.316880648263825, 0.6255875834022371}, {5.252476493543351, 
       0.6056874410767784}, {5.252476493543351, 0.6056874410767784}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}}], 
      LineBox[{{5.316880648263825, 0.6255875834022371}, {5.252476493543351, 
       0.6056874410767784}, {5.252476493543351, 0.6056874410767784}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}}], 
      LineBox[{{5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}}], 
      LineBox[{{5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}}], 
      LineBox[{{5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}}], 
      LineBox[{{5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}], 
      LineBox[{{5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}], 
      LineBox[{{5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}], 
      LineBox[{{5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}], 
      LineBox[{{5.252476493543351, 0.9083905467673924}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}}], 
      LineBox[{{5.252476493543351, 0.9083905467673924}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}}], 
      LineBox[{{5.252476493543351, 0.9083905467673924}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}}], 
      LineBox[{{5.252476493543351, 0.9083905467673924}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}}], 
      LineBox[{{5.316880648263825, 0.8884904044419337}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}], 
      LineBox[{{5.316880648263825, 0.8884904044419337}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}], 
      LineBox[{{5.316880648263825, 0.8884904044419337}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}], 
      LineBox[{{5.316880648263825, 0.8884904044419337}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}], 
      LineBox[{{5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.366316754416836, 
       0.8426648415074682}}], 
      LineBox[{{5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.366316754416836, 
       0.8426648415074682}}], 
      LineBox[{{5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.366316754416836, 
       0.8426648415074682}}], 
      LineBox[{{5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.366316754416836, 
       0.8426648415074682}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150580321776822, 1.0978272395775193`}, {5.0838486759901755`,
        1.1698165947239367`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.150580321776822, 
       1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.067454174631679, 
       1.2418059498703542`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.316832616067108, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.316832616067108, 
       1.0978272395775193`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.316832616067108, 1.3857846601631891`}, {
       5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.316832616067108, 
       1.3857846601631891`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150580321776822, 1.0978272395775193`}, {5.0838486759901755`,
        1.1698165947239367`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}}], 
      LineBox[{{5.150580321776822, 1.0978272395775193`}, {5.0838486759901755`,
        1.1698165947239367`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}}], 
      LineBox[{{5.150580321776822, 1.0978272395775193`}, {5.0838486759901755`,
        1.1698165947239367`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}}], 
      LineBox[{{5.150580321776822, 1.0978272395775193`}, {5.0838486759901755`,
        1.1698165947239367`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}}], 
      LineBox[{{5.0838486759901755`, 1.1698165947239367`}, {5.067454174631679,
        1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}}], 
      LineBox[{{5.0838486759901755`, 1.1698165947239367`}, {5.067454174631679,
        1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}}], 
      LineBox[{{5.0838486759901755`, 1.1698165947239367`}, {5.067454174631679,
        1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}}], 
      LineBox[{{5.0838486759901755`, 1.1698165947239367`}, {5.067454174631679,
        1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}}], 
      LineBox[{{5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`,
        1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}], 
      LineBox[{{5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`,
        1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}], 
      LineBox[{{5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`,
        1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}], 
      LineBox[{{5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`,
        1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}], 
      LineBox[{{5.0838486759901755`, 1.3137953050167717`}, {5.150580321776822,
        1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}}], 
      LineBox[{{5.0838486759901755`, 1.3137953050167717`}, {5.150580321776822,
        1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}}], 
      LineBox[{{5.0838486759901755`, 1.3137953050167717`}, {5.150580321776822,
        1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}}], 
      LineBox[{{5.0838486759901755`, 1.3137953050167717`}, {5.150580321776822,
        1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}], 
      LineBox[{{5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}], 
      LineBox[{{5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}], 
      LineBox[{{5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}], 
      LineBox[{{5.370979975746717, 1.1480199718095652`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.370979975746717, 1.1480199718095652`}, {5.370979975746717, 
       1.1480199718095652`}}], 
      LineBox[{{5.370979975746717, 1.1480199718095652`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.370979975746717, 1.1480199718095652`}, {5.370979975746717, 
       1.1480199718095652`}}], 
      LineBox[{{5.370979975746717, 1.1480199718095652`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.370979975746717, 1.1480199718095652`}, {5.370979975746717, 
       1.1480199718095652`}}], 
      LineBox[{{5.370979975746717, 1.1480199718095652`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.370979975746717, 1.1480199718095652`}, {5.370979975746717, 
       1.1480199718095652`}}], 
      LineBox[{{5.316832616067108, 1.0978272395775193`}, {5.246290755029002, 
       1.0760306166631477`}, {5.246290755029002, 1.0760306166631477`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}}], 
      LineBox[{{5.316832616067108, 1.0978272395775193`}, {5.246290755029002, 
       1.0760306166631477`}, {5.246290755029002, 1.0760306166631477`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}}], 
      LineBox[{{5.316832616067108, 1.0978272395775193`}, {5.246290755029002, 
       1.0760306166631477`}, {5.246290755029002, 1.0760306166631477`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}}], 
      LineBox[{{5.316832616067108, 1.0978272395775193`}, {5.246290755029002, 
       1.0760306166631477`}, {5.246290755029002, 1.0760306166631477`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}}], 
      LineBox[{{5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}}], 
      LineBox[{{5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}}], 
      LineBox[{{5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}}], 
      LineBox[{{5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}], 
      LineBox[{{5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}], 
      LineBox[{{5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}], 
      LineBox[{{5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}], 
      LineBox[{{5.246290755029002, 1.4075812830775607`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}}], 
      LineBox[{{5.246290755029002, 1.4075812830775607`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}}], 
      LineBox[{{5.246290755029002, 1.4075812830775607`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}}], 
      LineBox[{{5.246290755029002, 1.4075812830775607`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}}], 
      LineBox[{{5.316832616067108, 1.3857846601631891`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}], 
      LineBox[{{5.316832616067108, 1.3857846601631891`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}], 
      LineBox[{{5.316832616067108, 1.3857846601631891`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}], 
      LineBox[{{5.316832616067108, 1.3857846601631891`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}], 
      LineBox[{{5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.370979975746717, 
       1.3355919279311432`}}], 
      LineBox[{{5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.370979975746717, 
       1.3355919279311432`}}], 
      LineBox[{{5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.370979975746717, 
       1.3355919279311432`}}], 
      LineBox[{{5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.370979975746717, 
       1.3355919279311432`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.139179486262469, 1.655364010422419}, {5.087117224416264, 
       1.7115281977969534`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.8238565725460218`}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}, {
       5.087117224416264, 1.8238565725460218`}, {5.074326668863462, 
       1.7676923851714876`}, {5.087117224416264, 1.7115281977969534`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339,
        1.6945230501469295`}, {5.268885121060485, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469, 
       1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.268885121060485, 
       1.655364010422419}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`,
        1.89702590757058}, {5.268885121060485, 1.8800207599205563`}, {
       5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`, 
       1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.268885121060485, 
       1.8800207599205563`}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.139179486262469, 1.655364010422419}, {5.087117224416264, 
       1.7115281977969534`}, {5.087117224416264, 1.7115281977969534`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}}], 
      LineBox[{{5.139179486262469, 1.655364010422419}, {5.087117224416264, 
       1.7115281977969534`}, {5.087117224416264, 1.7115281977969534`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}}], 
      LineBox[{{5.139179486262469, 1.655364010422419}, {5.087117224416264, 
       1.7115281977969534`}, {5.087117224416264, 1.7115281977969534`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}}], 
      LineBox[{{5.139179486262469, 1.655364010422419}, {5.087117224416264, 
       1.7115281977969534`}, {5.087117224416264, 1.7115281977969534`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}}], 
      LineBox[{{5.087117224416264, 1.7115281977969534`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}}], 
      LineBox[{{5.087117224416264, 1.7115281977969534`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}}], 
      LineBox[{{5.087117224416264, 1.7115281977969534`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}}], 
      LineBox[{{5.087117224416264, 1.7115281977969534`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}}], 
      LineBox[{{5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}], 
      LineBox[{{5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}], 
      LineBox[{{5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}], 
      LineBox[{{5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}], 
      LineBox[{{5.087117224416264, 1.8238565725460218`}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}}], 
      LineBox[{{5.087117224416264, 1.8238565725460218`}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}}], 
      LineBox[{{5.087117224416264, 1.8238565725460218`}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}}], 
      LineBox[{{5.087117224416264, 1.8238565725460218`}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339,
        1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}], 
      LineBox[{{5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339,
        1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}], 
      LineBox[{{5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339,
        1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}], 
      LineBox[{{5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339,
        1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}], 
      LineBox[{{5.311129456333339, 1.6945230501469295`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.311129456333339, 1.6945230501469295`}, {5.311129456333339, 
       1.6945230501469295`}}], 
      LineBox[{{5.311129456333339, 1.6945230501469295`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.311129456333339, 1.6945230501469295`}, {5.311129456333339, 
       1.6945230501469295`}}], 
      LineBox[{{5.311129456333339, 1.6945230501469295`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.311129456333339, 1.6945230501469295`}, {5.311129456333339, 
       1.6945230501469295`}}], 
      LineBox[{{5.311129456333339, 1.6945230501469295`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.311129456333339, 1.6945230501469295`}, {5.311129456333339, 
       1.6945230501469295`}}], 
      LineBox[{{5.268885121060485, 1.655364010422419}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}}], 
      LineBox[{{5.268885121060485, 1.655364010422419}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}}], 
      LineBox[{{5.268885121060485, 1.655364010422419}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}}], 
      LineBox[{{5.268885121060485, 1.655364010422419}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}}], 
      LineBox[{{5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469,
        1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}}], 
      LineBox[{{5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469,
        1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}}], 
      LineBox[{{5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469,
        1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}}], 
      LineBox[{{5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469,
        1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`,
        1.89702590757058}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}], 
      LineBox[{{5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`,
        1.89702590757058}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}], 
      LineBox[{{5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`,
        1.89702590757058}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}], 
      LineBox[{{5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`,
        1.89702590757058}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}], 
      LineBox[{{5.2138502302348275`, 1.89702590757058}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}}], 
      LineBox[{{5.2138502302348275`, 1.89702590757058}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}}], 
      LineBox[{{5.2138502302348275`, 1.89702590757058}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}}], 
      LineBox[{{5.2138502302348275`, 1.89702590757058}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}}], 
      LineBox[{{5.268885121060485, 1.8800207599205563`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}], 
      LineBox[{{5.268885121060485, 1.8800207599205563`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}], 
      LineBox[{{5.268885121060485, 1.8800207599205563`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}], 
      LineBox[{{5.268885121060485, 1.8800207599205563`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}], 
      LineBox[{{5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`,
        1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.311129456333339, 
       1.8408617201960458`}}], 
      LineBox[{{5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`,
        1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.311129456333339, 
       1.8408617201960458`}}], 
      LineBox[{{5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`,
        1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.311129456333339, 
       1.8408617201960458`}}], 
      LineBox[{{5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`,
        1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.311129456333339, 
       1.8408617201960458`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.157996230359432, 2.0842942662045143`}, {5.090443811161005, 
       2.157169062552612}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.3029186552488077`}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}, {
       5.090443811161005, 2.3029186552488077`}, {5.073847663782004, 
       2.23004385890071}, {5.090443811161005, 2.157169062552612}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.326293363514285, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.326293363514285, 
       2.0842942662045143`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.326293363514285, 2.3757934515969055`}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713, 
       2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.326293363514285, 
       2.3757934515969055`}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.157996230359432, 2.0842942662045143`}, {5.090443811161005, 
       2.157169062552612}, {5.090443811161005, 2.157169062552612}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}}], 
      LineBox[{{5.157996230359432, 2.0842942662045143`}, {5.090443811161005, 
       2.157169062552612}, {5.090443811161005, 2.157169062552612}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}}], 
      LineBox[{{5.157996230359432, 2.0842942662045143`}, {5.090443811161005, 
       2.157169062552612}, {5.090443811161005, 2.157169062552612}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}}], 
      LineBox[{{5.157996230359432, 2.0842942662045143`}, {5.090443811161005, 
       2.157169062552612}, {5.090443811161005, 2.157169062552612}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}}], 
      LineBox[{{5.090443811161005, 2.157169062552612}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}}], 
      LineBox[{{5.090443811161005, 2.157169062552612}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}}], 
      LineBox[{{5.090443811161005, 2.157169062552612}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}}], 
      LineBox[{{5.090443811161005, 2.157169062552612}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}}], 
      LineBox[{{5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}], 
      LineBox[{{5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}], 
      LineBox[{{5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}], 
      LineBox[{{5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}], 
      LineBox[{{5.090443811161005, 2.3029186552488077`}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}}], 
      LineBox[{{5.090443811161005, 2.3029186552488077`}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}}], 
      LineBox[{{5.090443811161005, 2.3029186552488077`}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}}], 
      LineBox[{{5.090443811161005, 2.3029186552488077`}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}], 
      LineBox[{{5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}], 
      LineBox[{{5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}], 
      LineBox[{{5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}], 
      LineBox[{{5.3811067147578555`, 2.1351043496137274`}, {5.326293363514285,
        2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.3811067147578555`, 
       2.1351043496137274`}}], 
      LineBox[{{5.3811067147578555`, 2.1351043496137274`}, {5.326293363514285,
        2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.3811067147578555`, 
       2.1351043496137274`}}], 
      LineBox[{{5.3811067147578555`, 2.1351043496137274`}, {5.326293363514285,
        2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.3811067147578555`, 
       2.1351043496137274`}}], 
      LineBox[{{5.3811067147578555`, 2.1351043496137274`}, {5.326293363514285,
        2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.3811067147578555`, 
       2.1351043496137274`}}], 
      LineBox[{{5.326293363514285, 2.0842942662045143`}, {5.254883864891715, 
       2.0622295532656296`}, {5.254883864891715, 2.0622295532656296`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}}], 
      LineBox[{{5.326293363514285, 2.0842942662045143`}, {5.254883864891715, 
       2.0622295532656296`}, {5.254883864891715, 2.0622295532656296`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}}], 
      LineBox[{{5.326293363514285, 2.0842942662045143`}, {5.254883864891715, 
       2.0622295532656296`}, {5.254883864891715, 2.0622295532656296`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}}], 
      LineBox[{{5.326293363514285, 2.0842942662045143`}, {5.254883864891715, 
       2.0622295532656296`}, {5.254883864891715, 2.0622295532656296`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}}], 
      LineBox[{{5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}}], 
      LineBox[{{5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}}], 
      LineBox[{{5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}}], 
      LineBox[{{5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}], 
      LineBox[{{5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}], 
      LineBox[{{5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}], 
      LineBox[{{5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}], 
      LineBox[{{5.254883864891715, 2.39785816453579}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}}], 
      LineBox[{{5.254883864891715, 2.39785816453579}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}}], 
      LineBox[{{5.254883864891715, 2.39785816453579}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}}], 
      LineBox[{{5.254883864891715, 2.39785816453579}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}}], 
      LineBox[{{5.326293363514285, 2.3757934515969055`}, {5.3811067147578555`,
        2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}], 
      LineBox[{{5.326293363514285, 2.3757934515969055`}, {5.3811067147578555`,
        2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}], 
      LineBox[{{5.326293363514285, 2.3757934515969055`}, {5.3811067147578555`,
        2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}], 
      LineBox[{{5.326293363514285, 2.3757934515969055`}, {5.3811067147578555`,
        2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}], 
      LineBox[{{5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713,
        2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.3811067147578555`, 
       2.3249833681876924`}}], 
      LineBox[{{5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713,
        2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.3811067147578555`, 
       2.3249833681876924`}}], 
      LineBox[{{5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713,
        2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.3811067147578555`, 
       2.3249833681876924`}}], 
      LineBox[{{5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713,
        2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.3811067147578555`, 
       2.3249833681876924`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.182662311074757, 2.6072354269601368`}, {5.127221575152003, 
       2.6670442744847778`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.786661969534059}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}, {
       5.127221575152003, 2.786661969534059}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.127221575152003, 2.6670442744847778`}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.320784927947847, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.320784927947847, 
       2.6072354269601368`}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.320784927947847, 2.8464708170587}, {
       5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.320784927947847, 
       2.8464708170587}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.182662311074757, 2.6072354269601368`}, {5.127221575152003, 
       2.6670442744847778`}, {5.127221575152003, 2.6670442744847778`}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}}], 
      LineBox[{{5.182662311074757, 2.6072354269601368`}, {5.127221575152003, 
       2.6670442744847778`}, {5.127221575152003, 2.6670442744847778`}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}}], 
      LineBox[{{5.182662311074757, 2.6072354269601368`}, {5.127221575152003, 
       2.6670442744847778`}, {5.127221575152003, 2.6670442744847778`}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}}], 
      LineBox[{{5.182662311074757, 2.6072354269601368`}, {5.127221575152003, 
       2.6670442744847778`}, {5.127221575152003, 2.6670442744847778`}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}}], 
      LineBox[{{5.127221575152003, 2.6670442744847778`}, {5.1136010026382115`,
        2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}}], 
      LineBox[{{5.127221575152003, 2.6670442744847778`}, {5.1136010026382115`,
        2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}}], 
      LineBox[{{5.127221575152003, 2.6670442744847778`}, {5.1136010026382115`,
        2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}}], 
      LineBox[{{5.127221575152003, 2.6670442744847778`}, {5.1136010026382115`,
        2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}}], 
      LineBox[{{5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003,
        2.786661969534059}, {5.127221575152003, 2.786661969534059}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}}], 
      LineBox[{{5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003,
        2.786661969534059}, {5.127221575152003, 2.786661969534059}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}}], 
      LineBox[{{5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003,
        2.786661969534059}, {5.127221575152003, 2.786661969534059}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}}], 
      LineBox[{{5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003,
        2.786661969534059}, {5.127221575152003, 2.786661969534059}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}}], 
      LineBox[{{5.127221575152003, 2.786661969534059}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}}], 
      LineBox[{{5.127221575152003, 2.786661969534059}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}}], 
      LineBox[{{5.127221575152003, 2.786661969534059}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}}], 
      LineBox[{{5.127221575152003, 2.786661969534059}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}], 
      LineBox[{{5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}], 
      LineBox[{{5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}], 
      LineBox[{{5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}], 
      LineBox[{{5.36577062301836, 2.648935612533489}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.36577062301836, 2.648935612533489}, {5.36577062301836, 
       2.648935612533489}}], 
      LineBox[{{5.36577062301836, 2.648935612533489}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.36577062301836, 2.648935612533489}, {5.36577062301836, 
       2.648935612533489}}], 
      LineBox[{{5.36577062301836, 2.648935612533489}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.36577062301836, 2.648935612533489}, {5.36577062301836, 
       2.648935612533489}}], 
      LineBox[{{5.36577062301836, 2.648935612533489}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.36577062301836, 2.648935612533489}, {5.36577062301836, 
       2.648935612533489}}], 
      LineBox[{{5.320784927947847, 2.6072354269601368`}, {5.262178660363542, 
       2.589126765008848}, {5.262178660363542, 2.589126765008848}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}}], 
      LineBox[{{5.320784927947847, 2.6072354269601368`}, {5.262178660363542, 
       2.589126765008848}, {5.262178660363542, 2.589126765008848}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}}], 
      LineBox[{{5.320784927947847, 2.6072354269601368`}, {5.262178660363542, 
       2.589126765008848}, {5.262178660363542, 2.589126765008848}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}}], 
      LineBox[{{5.320784927947847, 2.6072354269601368`}, {5.262178660363542, 
       2.589126765008848}, {5.262178660363542, 2.589126765008848}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}}], 
      LineBox[{{5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}}], 
      LineBox[{{5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}}], 
      LineBox[{{5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}}], 
      LineBox[{{5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}], 
      LineBox[{{5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}], 
      LineBox[{{5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}], 
      LineBox[{{5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}], 
      LineBox[{{5.262178660363542, 2.8645794790099885`}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}}], 
      LineBox[{{5.262178660363542, 2.8645794790099885`}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}}], 
      LineBox[{{5.262178660363542, 2.8645794790099885`}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}}], 
      LineBox[{{5.262178660363542, 2.8645794790099885`}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}}], 
      LineBox[{{5.320784927947847, 2.8464708170587}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}], 
      LineBox[{{5.320784927947847, 2.8464708170587}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}], 
      LineBox[{{5.320784927947847, 2.8464708170587}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}], 
      LineBox[{{5.320784927947847, 2.8464708170587}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}], 
      LineBox[{{5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.36577062301836, 
       2.8047706314853476`}}], 
      LineBox[{{5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.36577062301836, 
       2.8047706314853476`}}], 
      LineBox[{{5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.36577062301836, 
       2.8047706314853476`}}], 
      LineBox[{{5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.36577062301836, 
       2.8047706314853476`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.13732711194462, 3.1355729766691844`}, {5.083060886232498, 
       3.1941147756791435`}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.3111983736990607`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}, {
       5.083060886232498, 3.3111983736990607`}, {5.06972886511013, 
       3.252656574689102}, {5.083060886232498, 3.1941147756791435`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.272523605613598, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.272523605613598, 
       3.1355729766691844`}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.272523605613598, 3.3697401727090197`}, {
       5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.272523605613598, 
       3.3697401727090197`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.13732711194462, 3.1355729766691844`}, {5.083060886232498, 
       3.1941147756791435`}, {5.083060886232498, 3.1941147756791435`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}}], 
      LineBox[{{5.13732711194462, 3.1355729766691844`}, {5.083060886232498, 
       3.1941147756791435`}, {5.083060886232498, 3.1941147756791435`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}}], 
      LineBox[{{5.13732711194462, 3.1355729766691844`}, {5.083060886232498, 
       3.1941147756791435`}, {5.083060886232498, 3.1941147756791435`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}}], 
      LineBox[{{5.13732711194462, 3.1355729766691844`}, {5.083060886232498, 
       3.1941147756791435`}, {5.083060886232498, 3.1941147756791435`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}}], 
      LineBox[{{5.083060886232498, 3.1941147756791435`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}}], 
      LineBox[{{5.083060886232498, 3.1941147756791435`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}}], 
      LineBox[{{5.083060886232498, 3.1941147756791435`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}}], 
      LineBox[{{5.083060886232498, 3.1941147756791435`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}}], 
      LineBox[{{5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}], 
      LineBox[{{5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}], 
      LineBox[{{5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}], 
      LineBox[{{5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}], 
      LineBox[{{5.083060886232498, 3.3111983736990607`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}}], 
      LineBox[{{5.083060886232498, 3.3111983736990607`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}}], 
      LineBox[{{5.083060886232498, 3.3111983736990607`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}}], 
      LineBox[{{5.083060886232498, 3.3111983736990607`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}], 
      LineBox[{{5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}], 
      LineBox[{{5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}], 
      LineBox[{{5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}], 
      LineBox[{{5.316556280178282, 3.176389745149925}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.316556280178282, 3.176389745149925}, {5.316556280178282, 
       3.176389745149925}}], 
      LineBox[{{5.316556280178282, 3.176389745149925}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.316556280178282, 3.176389745149925}, {5.316556280178282, 
       3.176389745149925}}], 
      LineBox[{{5.316556280178282, 3.176389745149925}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.316556280178282, 3.176389745149925}, {5.316556280178282, 
       3.176389745149925}}], 
      LineBox[{{5.316556280178282, 3.176389745149925}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.316556280178282, 3.176389745149925}, {5.316556280178282, 
       3.176389745149925}}], 
      LineBox[{{5.272523605613598, 3.1355729766691844`}, {5.215158909926547, 
       3.1178479461399657`}, {5.215158909926547, 3.1178479461399657`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}}], 
      LineBox[{{5.272523605613598, 3.1355729766691844`}, {5.215158909926547, 
       3.1178479461399657`}, {5.215158909926547, 3.1178479461399657`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}}], 
      LineBox[{{5.272523605613598, 3.1355729766691844`}, {5.215158909926547, 
       3.1178479461399657`}, {5.215158909926547, 3.1178479461399657`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}}], 
      LineBox[{{5.272523605613598, 3.1355729766691844`}, {5.215158909926547, 
       3.1178479461399657`}, {5.215158909926547, 3.1178479461399657`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}}], 
      LineBox[{{5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}}], 
      LineBox[{{5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}}], 
      LineBox[{{5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}}], 
      LineBox[{{5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}], 
      LineBox[{{5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}], 
      LineBox[{{5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}], 
      LineBox[{{5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}], 
      LineBox[{{5.215158909926547, 3.3874652032382384`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}}], 
      LineBox[{{5.215158909926547, 3.3874652032382384`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}}], 
      LineBox[{{5.215158909926547, 3.3874652032382384`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}}], 
      LineBox[{{5.215158909926547, 3.3874652032382384`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}}], 
      LineBox[{{5.272523605613598, 3.3697401727090197`}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}], 
      LineBox[{{5.272523605613598, 3.3697401727090197`}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}], 
      LineBox[{{5.272523605613598, 3.3697401727090197`}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}], 
      LineBox[{{5.272523605613598, 3.3697401727090197`}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}], 
      LineBox[{{5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.316556280178282, 
       3.3289234042282794`}}], 
      LineBox[{{5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.316556280178282, 
       3.3289234042282794`}}], 
      LineBox[{{5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.316556280178282, 
       3.3289234042282794`}}], 
      LineBox[{{5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.316556280178282, 
       3.3289234042282794`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.145336877765792, 3.610015039022549}, {5.075165998255072, 
       3.6857146011491078`}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.8371137254022245`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}, {
       5.075165998255072, 3.8371137254022245`}, {5.057926552623181, 
       3.761414163275666}, {5.075165998255072, 3.6857146011491078`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.320157528051014, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.320157528051014, 
       3.610015039022549}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.320157528051014, 3.9128132875287833`}, {
       5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.320157528051014, 
       3.9128132875287833`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.145336877765792, 3.610015039022549}, {5.075165998255072, 
       3.6857146011491078`}, {5.075165998255072, 3.6857146011491078`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}}], 
      LineBox[{{5.145336877765792, 3.610015039022549}, {5.075165998255072, 
       3.6857146011491078`}, {5.075165998255072, 3.6857146011491078`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}}], 
      LineBox[{{5.145336877765792, 3.610015039022549}, {5.075165998255072, 
       3.6857146011491078`}, {5.075165998255072, 3.6857146011491078`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}}], 
      LineBox[{{5.145336877765792, 3.610015039022549}, {5.075165998255072, 
       3.6857146011491078`}, {5.075165998255072, 3.6857146011491078`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}}], 
      LineBox[{{5.075165998255072, 3.6857146011491078`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}}], 
      LineBox[{{5.075165998255072, 3.6857146011491078`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}}], 
      LineBox[{{5.075165998255072, 3.6857146011491078`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}}], 
      LineBox[{{5.075165998255072, 3.6857146011491078`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}}], 
      LineBox[{{5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}], 
      LineBox[{{5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}], 
      LineBox[{{5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}], 
      LineBox[{{5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}], 
      LineBox[{{5.075165998255072, 3.8371137254022245`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}}], 
      LineBox[{{5.075165998255072, 3.8371137254022245`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}}], 
      LineBox[{{5.075165998255072, 3.8371137254022245`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}}], 
      LineBox[{{5.075165998255072, 3.8371137254022245`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}], 
      LineBox[{{5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}], 
      LineBox[{{5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}], 
      LineBox[{{5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}], 
      LineBox[{{5.377095549092027, 3.662794617950206}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.377095549092027, 3.662794617950206}, {5.377095549092027, 
       3.662794617950206}}], 
      LineBox[{{5.377095549092027, 3.662794617950206}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.377095549092027, 3.662794617950206}, {5.377095549092027, 
       3.662794617950206}}], 
      LineBox[{{5.377095549092027, 3.662794617950206}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.377095549092027, 3.662794617950206}, {5.377095549092027, 
       3.662794617950206}}], 
      LineBox[{{5.377095549092027, 3.662794617950206}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.377095549092027, 3.662794617950206}, {5.377095549092027, 
       3.662794617950206}}], 
      LineBox[{{5.320157528051014, 3.610015039022549}, {5.24598006137811, 
       3.5870950558236476`}, {5.24598006137811, 3.5870950558236476`}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}}], 
      LineBox[{{5.320157528051014, 3.610015039022549}, {5.24598006137811, 
       3.5870950558236476`}, {5.24598006137811, 3.5870950558236476`}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}}], 
      LineBox[{{5.320157528051014, 3.610015039022549}, {5.24598006137811, 
       3.5870950558236476`}, {5.24598006137811, 3.5870950558236476`}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}}], 
      LineBox[{{5.320157528051014, 3.610015039022549}, {5.24598006137811, 
       3.5870950558236476`}, {5.24598006137811, 3.5870950558236476`}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}}], 
      LineBox[{{5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}}], 
      LineBox[{{5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}}], 
      LineBox[{{5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}}], 
      LineBox[{{5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}], 
      LineBox[{{5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}], 
      LineBox[{{5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}], 
      LineBox[{{5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}], 
      LineBox[{{5.24598006137811, 3.9357332707276846`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}}], 
      LineBox[{{5.24598006137811, 3.9357332707276846`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}}], 
      LineBox[{{5.24598006137811, 3.9357332707276846`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}}], 
      LineBox[{{5.24598006137811, 3.9357332707276846`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}}], 
      LineBox[{{5.320157528051014, 3.9128132875287833`}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}], 
      LineBox[{{5.320157528051014, 3.9128132875287833`}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}], 
      LineBox[{{5.320157528051014, 3.9128132875287833`}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}], 
      LineBox[{{5.320157528051014, 3.9128132875287833`}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}], 
      LineBox[{{5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.377095549092027, 
       3.8600337086011263`}}], 
      LineBox[{{5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.377095549092027, 
       3.8600337086011263`}}], 
      LineBox[{{5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.377095549092027, 
       3.8600337086011263`}}], 
      LineBox[{{5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.377095549092027, 
       3.8600337086011263`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}], 
      LineBox[{{5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}], 
      LineBox[{{5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}], 
      LineBox[{{5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}], 
      LineBox[{{5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}], 
      LineBox[{{5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}], 
      LineBox[{{5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}], 
      LineBox[{{5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}], 
      LineBox[{{5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}], 
      LineBox[{{5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}], 
      LineBox[{{5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}], 
      LineBox[{{5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}], 
      LineBox[{{5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}], 
      LineBox[{{5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}], 
      LineBox[{{5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}], 
      LineBox[{{5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}], 
      LineBox[{{5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}], 
      LineBox[{{5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}], 
      LineBox[{{5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}], 
      LineBox[{{5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}], 
      LineBox[{{5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}], 
      LineBox[{{5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}], 
      LineBox[{{5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}], 
      LineBox[{{5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}], 
      LineBox[{{5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}], 
      LineBox[{{5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}], 
      LineBox[{{5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}], 
      LineBox[{{5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}], 
      LineBox[{{5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}], 
      LineBox[{{5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}], 
      LineBox[{{5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}], 
      LineBox[{{5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}], 
      LineBox[{{5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}], 
      LineBox[{{5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}], 
      LineBox[{{5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}], 
      LineBox[{{5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}], 
      LineBox[{{5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}], 
      LineBox[{{5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}], 
      LineBox[{{5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}], 
      LineBox[{{5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}], 
      LineBox[{{5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}], 
      LineBox[{{5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}], 
      LineBox[{{5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}], 
      LineBox[{{5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}], 
      LineBox[{{5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}], 
      LineBox[{{5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.867806430401208}, {
       5.440105828095692, -3.867806430401208}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}], 
      LineBox[{{5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}], 
      LineBox[{{5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}], 
      LineBox[{{5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}], 
      LineBox[{{5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}], 
      LineBox[{{5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}], 
      LineBox[{{5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}], 
      LineBox[{{5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}], 
      LineBox[{{5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}], 
      LineBox[{{5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}], 
      LineBox[{{5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}], 
      LineBox[{{5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}], 
      LineBox[{{5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}], 
      LineBox[{{5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}], 
      LineBox[{{5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}], 
      LineBox[{{5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}], 
      LineBox[{{5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}], 
      LineBox[{{5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}], 
      LineBox[{{5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}], 
      LineBox[{{5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}], 
      LineBox[{{5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}], 
      LineBox[{{5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}], 
      LineBox[{{5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}], 
      LineBox[{{5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}], 
      LineBox[{{5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}], 
      LineBox[{{5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}], 
      LineBox[{{5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}], 
      LineBox[{{5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}], 
      LineBox[{{5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}], 
      LineBox[{{5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}], 
      LineBox[{{5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}], 
      LineBox[{{5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}], 
      LineBox[{{5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}], 
      LineBox[{{5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}], 
      LineBox[{{5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}], 
      LineBox[{{5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}], 
      LineBox[{{5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}], 
      LineBox[{{5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}], 
      LineBox[{{5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}], 
      LineBox[{{5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}], 
      LineBox[{{5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}], 
      LineBox[{{5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}], 
      LineBox[{{5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}], 
      LineBox[{{5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}], 
      LineBox[{{5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}], 
      LineBox[{{5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}], 
      LineBox[{{5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}], 
      LineBox[{{5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}], 
      LineBox[{{5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}], 
      LineBox[{{5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}], 
      LineBox[{{5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}], 
      LineBox[{{5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}], 
      LineBox[{{5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}], 
      LineBox[{{5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}], 
      LineBox[{{5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}], 
      LineBox[{{5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}], 
      LineBox[{{5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}], 
      LineBox[{{5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}], 
      LineBox[{{5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}], 
      LineBox[{{5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}], 
      LineBox[{{5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}], 
      LineBox[{{5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}], 
      LineBox[{{5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}], 
      LineBox[{{5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}], 
      LineBox[{{5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}], 
      LineBox[{{5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}], 
      LineBox[{{5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}], 
      LineBox[{{5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}], 
      LineBox[{{5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}], 
      LineBox[{{5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}], 
      LineBox[{{5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}], 
      LineBox[{{5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}], 
      LineBox[{{5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}], 
      LineBox[{{5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}], 
      LineBox[{{5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}], 
      LineBox[{{5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}], 
      LineBox[{{5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}], 
      LineBox[{{5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}], 
      LineBox[{{5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}], 
      LineBox[{{5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}], 
      LineBox[{{5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}], 
      LineBox[{{5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}], 
      LineBox[{{5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}], 
      LineBox[{{5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}], 
      LineBox[{{5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}], 
      LineBox[{{5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}], 
      LineBox[{{5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}], 
      LineBox[{{5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}], 
      LineBox[{{5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}], 
      LineBox[{{5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}], 
      LineBox[{{5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}], 
      LineBox[{{5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}], 
      LineBox[{{5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}], 
      LineBox[{{5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}], 
      LineBox[{{5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}], 
      LineBox[{{5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}], 
      LineBox[{{5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}], 
      LineBox[{{5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}], 
      LineBox[{{5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}], 
      LineBox[{{5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}], 
      LineBox[{{5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}], 
      LineBox[{{5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}], 
      LineBox[{{5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}], 
      LineBox[{{5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}], 
      LineBox[{{5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}], 
      LineBox[{{5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}], 
      LineBox[{{5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}], 
      LineBox[{{5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}], 
      LineBox[{{5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}], 
      LineBox[{{5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}], 
      LineBox[{{5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}], 
      LineBox[{{5.655704607951876, -3.0827011012836247`}, {5.609560489035312,
        -3.1254751057515655`}, {5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}], 
      LineBox[{{5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}], 
      LineBox[{{5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}], 
      LineBox[{{5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}], 
      LineBox[{{5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}], 
      LineBox[{{5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}], 
      LineBox[{{5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}], 
      LineBox[{{5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}], 
      LineBox[{{5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}], 
      LineBox[{{5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}], 
      LineBox[{{5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}], 
      LineBox[{{5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}], 
      LineBox[{{5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}], 
      LineBox[{{5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}], 
      LineBox[{{5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}], 
      LineBox[{{5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}], 
      LineBox[{{5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}], 
      LineBox[{{5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}], 
      LineBox[{{5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}], 
      LineBox[{{5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}], 
      LineBox[{{5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}], 
      LineBox[{{5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}], 
      LineBox[{{5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}], 
      LineBox[{{5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}], 
      LineBox[{{5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}], 
      LineBox[{{5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}], 
      LineBox[{{5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}], 
      LineBox[{{5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}], 
      LineBox[{{5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}], 
      LineBox[{{5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}], 
      LineBox[{{5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}], 
      LineBox[{{5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}], 
      LineBox[{{5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}], 
      LineBox[{{5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}], 
      LineBox[{{5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}], 
      LineBox[{{5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}], 
      LineBox[{{5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}], 
      LineBox[{{5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}], 
      LineBox[{{5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}], 
      LineBox[{{5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}], 
      LineBox[{{5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}], 
      LineBox[{{5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}], 
      LineBox[{{5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}], 
      LineBox[{{5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}], 
      LineBox[{{5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}], 
      LineBox[{{5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}], 
      LineBox[{{5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}], 
      LineBox[{{5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}], 
      LineBox[{{5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}], 
      LineBox[{{5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}], 
      LineBox[{{5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}], 
      LineBox[{{5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}], 
      LineBox[{{5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}], 
      LineBox[{{5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}], 
      LineBox[{{5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}], 
      LineBox[{{5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}], 
      LineBox[{{5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}], 
      LineBox[{{5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}], 
      LineBox[{{5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}], 
      LineBox[{{5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}], 
      LineBox[{{5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}], 
      LineBox[{{5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}], 
      LineBox[{{5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}], 
      LineBox[{{5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}], 
      LineBox[{{5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}], 
      LineBox[{{5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}], 
      LineBox[{{5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}], 
      LineBox[{{5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}], 
      LineBox[{{5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}], 
      LineBox[{{5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}], 
      LineBox[{{5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}], 
      LineBox[{{5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}], 
      LineBox[{{5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}], 
      LineBox[{{5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}], 
      LineBox[{{5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}], 
      LineBox[{{5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}], 
      LineBox[{{5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}], 
      LineBox[{{5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}], 
      LineBox[{{5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}], 
      LineBox[{{5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}], 
      LineBox[{{5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}], 
      LineBox[{{5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}], 
      LineBox[{{5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}], 
      LineBox[{{5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}], 
      LineBox[{{5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}], 
      LineBox[{{5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}], 
      LineBox[{{5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}], 
      LineBox[{{5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}], 
      LineBox[{{5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}], 
      LineBox[{{5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}], 
      LineBox[{{5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}], 
      LineBox[{{5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}], 
      LineBox[{{5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}], 
      LineBox[{{5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}], 
      LineBox[{{5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}], 
      LineBox[{{5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}], 
      LineBox[{{5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}], 
      LineBox[{{5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}], 
      LineBox[{{5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}], 
      LineBox[{{5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}], 
      LineBox[{{5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}], 
      LineBox[{{5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}], 
      LineBox[{{5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}], 
      LineBox[{{5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}], 
      LineBox[{{5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}], 
      LineBox[{{5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}], 
      LineBox[{{5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}], 
      LineBox[{{5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}], 
      LineBox[{{5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}], 
      LineBox[{{5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}], 
      LineBox[{{5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}], 
      LineBox[{{5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}], 
      LineBox[{{5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}], 
      LineBox[{{5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}], 
      LineBox[{{5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727374`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}], 
      LineBox[{{5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}], 
      LineBox[{{5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}], 
      LineBox[{{5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}], 
      LineBox[{{5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}], 
      LineBox[{{5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}], 
      LineBox[{{5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}], 
      LineBox[{{5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}], 
      LineBox[{{5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}], 
      LineBox[{{5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}], 
      LineBox[{{5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}], 
      LineBox[{{5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}], 
      LineBox[{{5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}], 
      LineBox[{{5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}], 
      LineBox[{{5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}], 
      LineBox[{{5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}], 
      LineBox[{{5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}], 
      LineBox[{{5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}], 
      LineBox[{{5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}], 
      LineBox[{{5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}], 
      LineBox[{{5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}], 
      LineBox[{{5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}], 
      LineBox[{{5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}], 
      LineBox[{{5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}], 
      LineBox[{{5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}], 
      LineBox[{{5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}], 
      LineBox[{{5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}], 
      LineBox[{{5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}], 
      LineBox[{{5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}], 
      LineBox[{{5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}], 
      LineBox[{{5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}], 
      LineBox[{{5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}], 
      LineBox[{{5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}], 
      LineBox[{{5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}], 
      LineBox[{{5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}], 
      LineBox[{{5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}], 
      LineBox[{{5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}], 
      LineBox[{{5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}], 
      LineBox[{{5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}], 
      LineBox[{{5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}], 
      LineBox[{{5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}], 
      LineBox[{{5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}], 
      LineBox[{{5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}], 
      LineBox[{{5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}], 
      LineBox[{{5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}], 
      LineBox[{{5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}], 
      LineBox[{{5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}], 
      LineBox[{{5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}], 
      LineBox[{{5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}], 
      LineBox[{{5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}], 
      LineBox[{{5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}], 
      LineBox[{{5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}], 
      LineBox[{{5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}], 
      LineBox[{{5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}], 
      LineBox[{{5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}], 
      LineBox[{{5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}], 
      LineBox[{{5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}], 
      LineBox[{{5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}], 
      LineBox[{{5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}], 
      LineBox[{{5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}], 
      LineBox[{{5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}], 
      LineBox[{{5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}], 
      LineBox[{{5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}], 
      LineBox[{{5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}], 
      LineBox[{{5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}], 
      LineBox[{{5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}], 
      LineBox[{{5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}], 
      LineBox[{{5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}], 
      LineBox[{{5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}], 
      LineBox[{{5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}], 
      LineBox[{{5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}], 
      LineBox[{{5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}], 
      LineBox[{{5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}], 
      LineBox[{{5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}], 
      LineBox[{{5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}], 
      LineBox[{{5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}], 
      LineBox[{{5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}], 
      LineBox[{{5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}], 
      LineBox[{{5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}], 
      LineBox[{{5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}], 
      LineBox[{{5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}], 
      LineBox[{{5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}], 
      LineBox[{{5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}], 
      LineBox[{{5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}], 
      LineBox[{{5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}], 
      LineBox[{{5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}], 
      LineBox[{{5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}], 
      LineBox[{{5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}], 
      LineBox[{{5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}], 
      LineBox[{{5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}], 
      LineBox[{{5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}], 
      LineBox[{{5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}], 
      LineBox[{{5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}], 
      LineBox[{{5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}], 
      LineBox[{{5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}], 
      LineBox[{{5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}], 
      LineBox[{{5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}], 
      LineBox[{{5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}], 
      LineBox[{{5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}], 
      LineBox[{{5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}], 
      LineBox[{{5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}], 
      LineBox[{{5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}], 
      LineBox[{{5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}], 
      LineBox[{{5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}], 
      LineBox[{{5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}], 
      LineBox[{{5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}], 
      LineBox[{{5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}], 
      LineBox[{{5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}], 
      LineBox[{{5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}], 
      LineBox[{{5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}], 
      LineBox[{{5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}], 
      LineBox[{{5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}], 
      LineBox[{{5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}], 
      LineBox[{{5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}], 
      LineBox[{{5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}], 
      LineBox[{{5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}], 
      LineBox[{{5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}], 
      LineBox[{{5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}], 
      LineBox[{{5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}], 
      LineBox[{{5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}], 
      LineBox[{{5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}], 
      LineBox[{{5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}], 
      LineBox[{{5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}], 
      LineBox[{{5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}], 
      LineBox[{{5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}], 
      LineBox[{{5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}], 
      LineBox[{{5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}], 
      LineBox[{{5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}], 
      LineBox[{{5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}], 
      LineBox[{{5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}], 
      LineBox[{{5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}], 
      LineBox[{{5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}], 
      LineBox[{{5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}], 
      LineBox[{{5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}], 
      LineBox[{{5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}], 
      LineBox[{{5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {5.424236492931953, 
       0.04563835604737325}, {5.435847212432175, 0.09662180417608038}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333887}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.05632854021004101}, {
       5.483107107934601, -0.05632854021004101}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 
       0.045638356047373235`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.483107107934601, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.600848337939898, 0.1476052523047875}, {
       5.639195939441774, 0.11205835019702573`}, {5.659718952942547, 
       0.04563835604737326}, {5.659718952942547, 0.04563835604737326}, {
       5.639195939441774, 0.11205835019702573`}, {5.600848337939898, 
       0.1476052523047875}, {5.5508900169378, 0.16304179832573287`}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}], 
      LineBox[{{5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}], 
      LineBox[{{5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}], 
      LineBox[{{5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}], 
      LineBox[{{5.435847212432175, -0.005345092081333873}, {5.424236492931953,
        0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}], 
      LineBox[{{5.435847212432175, -0.005345092081333873}, {5.424236492931953,
        0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}], 
      LineBox[{{5.435847212432175, -0.005345092081333873}, {5.424236492931953,
        0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}], 
      LineBox[{{5.435847212432175, -0.005345092081333873}, {5.424236492931953,
        0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}], 
      LineBox[{{5.424236492931953, 0.04563835604737325}, {5.435847212432175, 
       0.09662180417608038}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}}], 
      LineBox[{{5.424236492931953, 0.04563835604737325}, {5.435847212432175, 
       0.09662180417608038}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}}], 
      LineBox[{{5.424236492931953, 0.04563835604737325}, {5.435847212432175, 
       0.09662180417608038}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}}], 
      LineBox[{{5.424236492931953, 0.04563835604737325}, {5.435847212432175, 
       0.09662180417608038}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}}], 
      LineBox[{{5.435847212432175, 0.09662180417608038}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}}], 
      LineBox[{{5.435847212432175, 0.09662180417608038}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}}], 
      LineBox[{{5.435847212432175, 0.09662180417608038}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}}], 
      LineBox[{{5.435847212432175, 0.09662180417608038}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}], 
      LineBox[{{5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}], 
      LineBox[{{5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}], 
      LineBox[{{5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}], 
      LineBox[{{5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}], 
      LineBox[{{5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}], 
      LineBox[{{5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}], 
      LineBox[{{5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}], 
      LineBox[{{5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}], 
      LineBox[{{5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}], 
      LineBox[{{5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}], 
      LineBox[{{5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}], 
      LineBox[{{5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}], 
      LineBox[{{5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}], 
      LineBox[{{5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}], 
      LineBox[{{5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.483107107934601, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.5508900169378, 0.16304179832573287`}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}}], 
      LineBox[{{5.483107107934601, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.5508900169378, 0.16304179832573287`}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}}], 
      LineBox[{{5.483107107934601, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.5508900169378, 0.16304179832573287`}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}}], 
      LineBox[{{5.483107107934601, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.5508900169378, 0.16304179832573287`}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}}], 
      LineBox[{{5.5508900169378, 0.16304179832573287`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}}], 
      LineBox[{{5.5508900169378, 0.16304179832573287`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}}], 
      LineBox[{{5.5508900169378, 0.16304179832573287`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}}], 
      LineBox[{{5.5508900169378, 0.16304179832573287`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}}], 
      LineBox[{{5.600848337939898, 0.1476052523047875}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}], 
      LineBox[{{5.600848337939898, 0.1476052523047875}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}], 
      LineBox[{{5.600848337939898, 0.1476052523047875}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}], 
      LineBox[{{5.600848337939898, 0.1476052523047875}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}], 
      LineBox[{{5.639195939441774, 0.11205835019702573`}, {5.659718952942547, 
       0.04563835604737323}, {5.659718952942547, 0.04563835604737323}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}}], 
      LineBox[{{5.639195939441774, 0.11205835019702573`}, {5.659718952942547, 
       0.04563835604737323}, {5.659718952942547, 0.04563835604737323}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}}], 
      LineBox[{{5.639195939441774, 0.11205835019702573`}, {5.659718952942547, 
       0.04563835604737323}, {5.659718952942547, 0.04563835604737323}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}}], 
      LineBox[{{5.639195939441774, 0.11205835019702573`}, {5.659718952942547, 
       0.04563835604737323}, {5.659718952942547, 0.04563835604737323}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.3151241046364435`, 
       0.5077284477255412}, {5.332568692952917, 0.43112809031078175`}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.4079353682440293}, {5.5804755264770405`, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.5804755264770405`, 
       0.3545277328960224}, {5.638091087778953, 0.4079353682440293}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.403574578583309, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.5804755264770405`, 0.66092916255506}, {
       5.638091087778953, 0.607521527207053}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.607521527207053}, {5.5804755264770405`, 
       0.66092916255506}, {5.505415376858655, 0.6841218846218124}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}], 
      LineBox[{{5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}], 
      LineBox[{{5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}], 
      LineBox[{{5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}], 
      LineBox[{{5.332568692952917, 0.4311280903107818}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.4311280903107818}, {5.332568692952917, 
       0.4311280903107818}}], 
      LineBox[{{5.332568692952917, 0.4311280903107818}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.4311280903107818}, {5.332568692952917, 
       0.4311280903107818}}], 
      LineBox[{{5.332568692952917, 0.4311280903107818}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.4311280903107818}, {5.332568692952917, 
       0.4311280903107818}}], 
      LineBox[{{5.332568692952917, 0.4311280903107818}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.4311280903107818}, {5.332568692952917, 
       0.4311280903107818}}], 
      LineBox[{{5.3151241046364435`, 0.5077284477255412}, {5.332568692952917, 
       0.5843288051403005}, {5.332568692952917, 0.5843288051403005}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}}], 
      LineBox[{{5.3151241046364435`, 0.5077284477255412}, {5.332568692952917, 
       0.5843288051403005}, {5.332568692952917, 0.5843288051403005}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}}], 
      LineBox[{{5.3151241046364435`, 0.5077284477255412}, {5.332568692952917, 
       0.5843288051403005}, {5.332568692952917, 0.5843288051403005}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}}], 
      LineBox[{{5.3151241046364435`, 0.5077284477255412}, {5.332568692952917, 
       0.5843288051403005}, {5.332568692952917, 0.5843288051403005}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}}], 
      LineBox[{{5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}}], 
      LineBox[{{5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}}], 
      LineBox[{{5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}}], 
      LineBox[{{5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}}], 
      LineBox[{{5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}}], 
      LineBox[{{5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}}], 
      LineBox[{{5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}}], 
      LineBox[{{5.638091087778953, 0.4079353682440293}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}}], 
      LineBox[{{5.638091087778953, 0.4079353682440293}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}}], 
      LineBox[{{5.638091087778953, 0.4079353682440293}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}}], 
      LineBox[{{5.638091087778953, 0.4079353682440293}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}}], 
      LineBox[{{5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}], 
      LineBox[{{5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}], 
      LineBox[{{5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}], 
      LineBox[{{5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}], 
      LineBox[{{5.505415376858655, 0.3313350108292699}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.505415376858655, 
       0.3313350108292699}}], 
      LineBox[{{5.505415376858655, 0.3313350108292699}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.505415376858655, 
       0.3313350108292699}}], 
      LineBox[{{5.505415376858655, 0.3313350108292699}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.505415376858655, 
       0.3313350108292699}}], 
      LineBox[{{5.505415376858655, 0.3313350108292699}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.505415376858655, 
       0.3313350108292699}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.403574578583309, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.505415376858655, 0.6841218846218124}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}}], 
      LineBox[{{5.403574578583309, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.505415376858655, 0.6841218846218124}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}}], 
      LineBox[{{5.403574578583309, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.505415376858655, 0.6841218846218124}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}}], 
      LineBox[{{5.403574578583309, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.505415376858655, 0.6841218846218124}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}}], 
      LineBox[{{5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}}], 
      LineBox[{{5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}}], 
      LineBox[{{5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}}], 
      LineBox[{{5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}}], 
      LineBox[{{5.5804755264770405`, 0.66092916255506}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}}], 
      LineBox[{{5.5804755264770405`, 0.66092916255506}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}}], 
      LineBox[{{5.5804755264770405`, 0.66092916255506}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}}], 
      LineBox[{{5.5804755264770405`, 0.66092916255506}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}}], 
      LineBox[{{5.638091087778953, 0.607521527207053}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}}], 
      LineBox[{{5.638091087778953, 0.607521527207053}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}}], 
      LineBox[{{5.638091087778953, 0.607521527207053}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}}], 
      LineBox[{{5.638091087778953, 0.607521527207053}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.342004179910006, 
       0.9842241927717074}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       0.8898887375377044}, {5.592843690088268, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.425617349969427, 
       0.8394019340468944}, {5.425617349969427, 0.8394019340468944}, {
       5.521888535472614, 0.8174776081752979}, {5.592843690088268, 
       0.8394019340468946}, {5.647308290561745, 0.8898887375377044}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.425617349969427, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.592843690088268, 1.1290464514965202`}, {
       5.647308290561745, 1.0785596480057102`}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 1.0785596480057102`}, {5.592843690088268, 
       1.1290464514965202`}, {5.521888535472614, 1.1509707773681168`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}], 
      LineBox[{{5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}], 
      LineBox[{{5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}], 
      LineBox[{{5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}], 
      LineBox[{{5.358494734052182, 0.9118130634093009}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 0.9118130634093009}, {5.358494734052182, 
       0.9118130634093009}}], 
      LineBox[{{5.358494734052182, 0.9118130634093009}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 0.9118130634093009}, {5.358494734052182, 
       0.9118130634093009}}], 
      LineBox[{{5.358494734052182, 0.9118130634093009}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 0.9118130634093009}, {5.358494734052182, 
       0.9118130634093009}}], 
      LineBox[{{5.358494734052182, 0.9118130634093009}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 0.9118130634093009}, {5.358494734052182, 
       0.9118130634093009}}], 
      LineBox[{{5.342004179910006, 0.9842241927717074}, {5.358494734052182, 
       1.0566353221341138`}, {5.358494734052182, 1.0566353221341138`}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}}], 
      LineBox[{{5.342004179910006, 0.9842241927717074}, {5.358494734052182, 
       1.0566353221341138`}, {5.358494734052182, 1.0566353221341138`}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}}], 
      LineBox[{{5.342004179910006, 0.9842241927717074}, {5.358494734052182, 
       1.0566353221341138`}, {5.358494734052182, 1.0566353221341138`}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}}], 
      LineBox[{{5.342004179910006, 0.9842241927717074}, {5.358494734052182, 
       1.0566353221341138`}, {5.358494734052182, 1.0566353221341138`}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}}], 
      LineBox[{{5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}}], 
      LineBox[{{5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}}], 
      LineBox[{{5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}}], 
      LineBox[{{5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}}], 
      LineBox[{{5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}}], 
      LineBox[{{5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}}], 
      LineBox[{{5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}}], 
      LineBox[{{5.647308290561745, 0.8898887375377044}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}}], 
      LineBox[{{5.647308290561745, 0.8898887375377044}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}}], 
      LineBox[{{5.647308290561745, 0.8898887375377044}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}}], 
      LineBox[{{5.647308290561745, 0.8898887375377044}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}}], 
      LineBox[{{5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}], 
      LineBox[{{5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}], 
      LineBox[{{5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}], 
      LineBox[{{5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}], 
      LineBox[{{5.521888535472614, 0.8174776081752979}, {5.425617349969427, 
       0.8394019340468946}, {5.425617349969427, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.521888535472614, 
       0.8174776081752979}}], 
      LineBox[{{5.521888535472614, 0.8174776081752979}, {5.425617349969427, 
       0.8394019340468946}, {5.425617349969427, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.521888535472614, 
       0.8174776081752979}}], 
      LineBox[{{5.521888535472614, 0.8174776081752979}, {5.425617349969427, 
       0.8394019340468946}, {5.425617349969427, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.521888535472614, 
       0.8174776081752979}}], 
      LineBox[{{5.521888535472614, 0.8174776081752979}, {5.425617349969427, 
       0.8394019340468946}, {5.425617349969427, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.521888535472614, 
       0.8174776081752979}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.425617349969427, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.521888535472614, 1.1509707773681168`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}}], 
      LineBox[{{5.425617349969427, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.521888535472614, 1.1509707773681168`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}}], 
      LineBox[{{5.425617349969427, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.521888535472614, 1.1509707773681168`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}}], 
      LineBox[{{5.425617349969427, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.521888535472614, 1.1509707773681168`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}}], 
      LineBox[{{5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}}], 
      LineBox[{{5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}}], 
      LineBox[{{5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}}], 
      LineBox[{{5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}}], 
      LineBox[{{5.592843690088268, 1.1290464514965202`}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}}], 
      LineBox[{{5.592843690088268, 1.1290464514965202`}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}}], 
      LineBox[{{5.592843690088268, 1.1290464514965202`}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}}], 
      LineBox[{{5.592843690088268, 1.1290464514965202`}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}}], 
      LineBox[{{5.647308290561745, 1.0785596480057102`}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}}], 
      LineBox[{{5.647308290561745, 1.0785596480057102`}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}}], 
      LineBox[{{5.647308290561745, 1.0785596480057102`}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}}], 
      LineBox[{{5.647308290561745, 1.0785596480057102`}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`,
        1.4708322469856543`}, {5.609427703729535, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.609427703729535, 
       1.4340612113058158`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.487631802742497, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.609427703729535, 1.6450178999689933`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.670325654223054, 
       1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.609427703729535, 
       1.6450178999689933`}, {5.55774896113464, 1.6609860364549491`}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}], 
      LineBox[{{5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}], 
      LineBox[{{5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}], 
      LineBox[{{5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}], 
      LineBox[{{5.438744411698491, 1.4868003834716101`}, {5.4267338522489785`,
        1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.4868003834716101`}, {5.438744411698491, 
       1.4868003834716101`}}], 
      LineBox[{{5.438744411698491, 1.4868003834716101`}, {5.4267338522489785`,
        1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.4868003834716101`}, {5.438744411698491, 
       1.4868003834716101`}}], 
      LineBox[{{5.438744411698491, 1.4868003834716101`}, {5.4267338522489785`,
        1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.4868003834716101`}, {5.438744411698491, 
       1.4868003834716101`}}], 
      LineBox[{{5.438744411698491, 1.4868003834716101`}, {5.4267338522489785`,
        1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.4868003834716101`}, {5.438744411698491, 
       1.4868003834716101`}}], 
      LineBox[{{5.4267338522489785`, 1.5395395556374045`}, {5.438744411698491,
        1.592278727803199}, {5.438744411698491, 1.592278727803199}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}}], 
      LineBox[{{5.4267338522489785`, 1.5395395556374045`}, {5.438744411698491,
        1.592278727803199}, {5.438744411698491, 1.592278727803199}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}}], 
      LineBox[{{5.4267338522489785`, 1.5395395556374045`}, {5.438744411698491,
        1.592278727803199}, {5.438744411698491, 1.592278727803199}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}}], 
      LineBox[{{5.4267338522489785`, 1.5395395556374045`}, {5.438744411698491,
        1.592278727803199}, {5.438744411698491, 1.592278727803199}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}}], 
      LineBox[{{5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}}], 
      LineBox[{{5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}}], 
      LineBox[{{5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}}], 
      LineBox[{{5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`,
        1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}}], 
      LineBox[{{5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`,
        1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}}], 
      LineBox[{{5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`,
        1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}}], 
      LineBox[{{5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`,
        1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}}], 
      LineBox[{{5.6490958868749175`, 1.4708322469856543`}, {5.609427703729535,
        1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}}], 
      LineBox[{{5.6490958868749175`, 1.4708322469856543`}, {5.609427703729535,
        1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}}], 
      LineBox[{{5.6490958868749175`, 1.4708322469856543`}, {5.609427703729535,
        1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}}], 
      LineBox[{{5.6490958868749175`, 1.4708322469856543`}, {5.609427703729535,
        1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}}], 
      LineBox[{{5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}], 
      LineBox[{{5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}], 
      LineBox[{{5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}], 
      LineBox[{{5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}], 
      LineBox[{{5.55774896113464, 1.41809307481986}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.55774896113464, 
       1.41809307481986}}], 
      LineBox[{{5.55774896113464, 1.41809307481986}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.55774896113464, 
       1.41809307481986}}], 
      LineBox[{{5.55774896113464, 1.41809307481986}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.55774896113464, 
       1.41809307481986}}], 
      LineBox[{{5.55774896113464, 1.41809307481986}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.55774896113464, 
       1.41809307481986}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.487631802742497, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.55774896113464, 1.6609860364549491`}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}}], 
      LineBox[{{5.487631802742497, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.55774896113464, 1.6609860364549491`}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}}], 
      LineBox[{{5.487631802742497, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.55774896113464, 1.6609860364549491`}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}}], 
      LineBox[{{5.487631802742497, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.55774896113464, 1.6609860364549491`}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}}], 
      LineBox[{{5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}}], 
      LineBox[{{5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}}], 
      LineBox[{{5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}}], 
      LineBox[{{5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}}], 
      LineBox[{{5.609427703729535, 1.6450178999689933`}, {5.6490958868749175`,
        1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}}], 
      LineBox[{{5.609427703729535, 1.6450178999689933`}, {5.6490958868749175`,
        1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}}], 
      LineBox[{{5.609427703729535, 1.6450178999689933`}, {5.6490958868749175`,
        1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}}], 
      LineBox[{{5.609427703729535, 1.6450178999689933`}, {5.6490958868749175`,
        1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}}], 
      LineBox[{{5.6490958868749175`, 1.6082468642891548`}, {5.670325654223054,
        1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}}], 
      LineBox[{{5.6490958868749175`, 1.6082468642891548`}, {5.670325654223054,
        1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}}], 
      LineBox[{{5.6490958868749175`, 1.6082468642891548`}, {5.670325654223054,
        1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}}], 
      LineBox[{{5.6490958868749175`, 1.6082468642891548`}, {5.670325654223054,
        1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.422994625543855, 
       2.0372116199566723`}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       1.9705986682616246`}, {5.600119547804168, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.600119547804168, 
       1.9349484984094896`}, {5.638578553396819, 1.9705986682616246`}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.482036266297293, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.600119547804168, 2.139474741503855}, {
       5.638578553396819, 2.10382457165172}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 2.10382457165172}, {5.600119547804168, 
       2.139474741503855}, {5.550016092266663, 2.1549561324253115`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}], 
      LineBox[{{5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}], 
      LineBox[{{5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}], 
      LineBox[{{5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}], 
      LineBox[{{5.434639075488708, 1.986080059183081}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 1.986080059183081}, {5.434639075488708, 
       1.986080059183081}}], 
      LineBox[{{5.434639075488708, 1.986080059183081}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 1.986080059183081}, {5.434639075488708, 
       1.986080059183081}}], 
      LineBox[{{5.434639075488708, 1.986080059183081}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 1.986080059183081}, {5.434639075488708, 
       1.986080059183081}}], 
      LineBox[{{5.434639075488708, 1.986080059183081}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 1.986080059183081}, {5.434639075488708, 
       1.986080059183081}}], 
      LineBox[{{5.422994625543855, 2.0372116199566723`}, {5.434639075488708, 
       2.0883431807302637`}, {5.434639075488708, 2.0883431807302637`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}}], 
      LineBox[{{5.422994625543855, 2.0372116199566723`}, {5.434639075488708, 
       2.0883431807302637`}, {5.434639075488708, 2.0883431807302637`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}}], 
      LineBox[{{5.422994625543855, 2.0372116199566723`}, {5.434639075488708, 
       2.0883431807302637`}, {5.434639075488708, 2.0883431807302637`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}}], 
      LineBox[{{5.422994625543855, 2.0372116199566723`}, {5.434639075488708, 
       2.0883431807302637`}, {5.434639075488708, 2.0883431807302637`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}}], 
      LineBox[{{5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}}], 
      LineBox[{{5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}}], 
      LineBox[{{5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}}], 
      LineBox[{{5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}}], 
      LineBox[{{5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}}], 
      LineBox[{{5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}}], 
      LineBox[{{5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}}], 
      LineBox[{{5.638578553396819, 1.9705986682616246`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}}], 
      LineBox[{{5.638578553396819, 1.9705986682616246`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}}], 
      LineBox[{{5.638578553396819, 1.9705986682616246`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}}], 
      LineBox[{{5.638578553396819, 1.9705986682616246`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}}], 
      LineBox[{{5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}], 
      LineBox[{{5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}], 
      LineBox[{{5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}], 
      LineBox[{{5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}], 
      LineBox[{{5.550016092266663, 1.9194671074880334`}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.550016092266663, 
       1.9194671074880334`}}], 
      LineBox[{{5.550016092266663, 1.9194671074880334`}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.550016092266663, 
       1.9194671074880334`}}], 
      LineBox[{{5.550016092266663, 1.9194671074880334`}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.550016092266663, 
       1.9194671074880334`}}], 
      LineBox[{{5.550016092266663, 1.9194671074880334`}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.550016092266663, 
       1.9194671074880334`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.482036266297293, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.550016092266663, 2.1549561324253115`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}}], 
      LineBox[{{5.482036266297293, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.550016092266663, 2.1549561324253115`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}}], 
      LineBox[{{5.482036266297293, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.550016092266663, 2.1549561324253115`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}}], 
      LineBox[{{5.482036266297293, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.550016092266663, 2.1549561324253115`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}}], 
      LineBox[{{5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}}], 
      LineBox[{{5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}}], 
      LineBox[{{5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}}], 
      LineBox[{{5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}}], 
      LineBox[{{5.600119547804168, 2.139474741503855}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}}], 
      LineBox[{{5.600119547804168, 2.139474741503855}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}}], 
      LineBox[{{5.600119547804168, 2.139474741503855}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}}], 
      LineBox[{{5.600119547804168, 2.139474741503855}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}}], 
      LineBox[{{5.638578553396819, 2.10382457165172}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}}], 
      LineBox[{{5.638578553396819, 2.10382457165172}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}}], 
      LineBox[{{5.638578553396819, 2.10382457165172}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}}], 
      LineBox[{{5.638578553396819, 2.10382457165172}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.6560577882824896`}, {5.429898798779611, 2.6560577882824896`}, {
       5.361754302615776, 2.582544265908168}, {5.345012694915826, 
       2.509030743533846}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.4132591175407136`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.429898798779611, 
       2.362003698785202}, {5.429898798779611, 2.362003698785202}, {
       5.527635624759366, 2.339745595166392}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.654964780555043, 2.4132591175407136`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.429898798779611, 2.65605778828249}, {5.527635624759366, 
       2.6783158919013004`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.654964780555043, 2.6048023695269786`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.6048023695269786`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.527635624759366, 2.6783158919013004`}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}], 
      LineBox[{{5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}], 
      LineBox[{{5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}], 
      LineBox[{{5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}], 
      LineBox[{{5.361754302615776, 2.4355172211595244`}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.4355172211595244`}, {5.361754302615776, 
       2.4355172211595244`}}], 
      LineBox[{{5.361754302615776, 2.4355172211595244`}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.4355172211595244`}, {5.361754302615776, 
       2.4355172211595244`}}], 
      LineBox[{{5.361754302615776, 2.4355172211595244`}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.4355172211595244`}, {5.361754302615776, 
       2.4355172211595244`}}], 
      LineBox[{{5.361754302615776, 2.4355172211595244`}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.4355172211595244`}, {5.361754302615776, 
       2.4355172211595244`}}], 
      LineBox[{{5.345012694915826, 2.509030743533846}, {5.361754302615776, 
       2.582544265908168}, {5.361754302615776, 2.582544265908168}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}}], 
      LineBox[{{5.345012694915826, 2.509030743533846}, {5.361754302615776, 
       2.582544265908168}, {5.361754302615776, 2.582544265908168}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}}], 
      LineBox[{{5.345012694915826, 2.509030743533846}, {5.361754302615776, 
       2.582544265908168}, {5.361754302615776, 2.582544265908168}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}}], 
      LineBox[{{5.345012694915826, 2.509030743533846}, {5.361754302615776, 
       2.582544265908168}, {5.361754302615776, 2.582544265908168}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}}], 
      LineBox[{{5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}}], 
      LineBox[{{5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}}], 
      LineBox[{{5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}}], 
      LineBox[{{5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}}], 
      LineBox[{{5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}}], 
      LineBox[{{5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}}], 
      LineBox[{{5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}}], 
      LineBox[{{5.654964780555043, 2.4132591175407136`}, {5.5996710065071795`,
        2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}}], 
      LineBox[{{5.654964780555043, 2.4132591175407136`}, {5.5996710065071795`,
        2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}}], 
      LineBox[{{5.654964780555043, 2.4132591175407136`}, {5.5996710065071795`,
        2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}}], 
      LineBox[{{5.654964780555043, 2.4132591175407136`}, {5.5996710065071795`,
        2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}}], 
      LineBox[{{5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366,
        2.339745595166392}, {5.527635624759366, 2.339745595166392}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}], 
      LineBox[{{5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366,
        2.339745595166392}, {5.527635624759366, 2.339745595166392}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}], 
      LineBox[{{5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366,
        2.339745595166392}, {5.527635624759366, 2.339745595166392}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}], 
      LineBox[{{5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366,
        2.339745595166392}, {5.527635624759366, 2.339745595166392}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}], 
      LineBox[{{5.527635624759366, 2.339745595166392}, {5.429898798779611, 
       2.3620036987852027`}, {5.429898798779611, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.527635624759366, 
       2.339745595166392}}], 
      LineBox[{{5.527635624759366, 2.339745595166392}, {5.429898798779611, 
       2.3620036987852027`}, {5.429898798779611, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.527635624759366, 
       2.339745595166392}}], 
      LineBox[{{5.527635624759366, 2.339745595166392}, {5.429898798779611, 
       2.3620036987852027`}, {5.429898798779611, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.527635624759366, 
       2.339745595166392}}], 
      LineBox[{{5.527635624759366, 2.339745595166392}, {5.429898798779611, 
       2.3620036987852027`}, {5.429898798779611, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.527635624759366, 
       2.339745595166392}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.429898798779611, 2.65605778828249}, {5.527635624759366, 
       2.6783158919013004`}, {5.527635624759366, 2.6783158919013004`}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}}], 
      LineBox[{{5.429898798779611, 2.65605778828249}, {5.527635624759366, 
       2.6783158919013004`}, {5.527635624759366, 2.6783158919013004`}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}}], 
      LineBox[{{5.429898798779611, 2.65605778828249}, {5.527635624759366, 
       2.6783158919013004`}, {5.527635624759366, 2.6783158919013004`}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}}], 
      LineBox[{{5.429898798779611, 2.65605778828249}, {5.527635624759366, 
       2.6783158919013004`}, {5.527635624759366, 2.6783158919013004`}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}}], 
      LineBox[{{5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`,
        2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}}], 
      LineBox[{{5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`,
        2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}}], 
      LineBox[{{5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`,
        2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}}], 
      LineBox[{{5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`,
        2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}}], 
      LineBox[{{5.5996710065071795`, 2.6560577882824896`}, {5.654964780555043,
        2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}}], 
      LineBox[{{5.5996710065071795`, 2.6560577882824896`}, {5.654964780555043,
        2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}}], 
      LineBox[{{5.5996710065071795`, 2.6560577882824896`}, {5.654964780555043,
        2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}}], 
      LineBox[{{5.5996710065071795`, 2.6560577882824896`}, {5.654964780555043,
        2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}}], 
      LineBox[{{5.654964780555043, 2.6048023695269786`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}}], 
      LineBox[{{5.654964780555043, 2.6048023695269786`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}}], 
      LineBox[{{5.654964780555043, 2.6048023695269786`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}}], 
      LineBox[{{5.654964780555043, 2.6048023695269786`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.293893225237583, 
       2.9899887628063078`}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       2.900596364258633}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.583199792635015, 2.900596364258633}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.373125172581725, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.583199792635015, 3.0793811613539823`}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 3.0793811613539823`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.464351871618802, 3.14799804054532}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}], 
      LineBox[{{5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}], 
      LineBox[{{5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}], 
      LineBox[{{5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}], 
      LineBox[{{5.309519695523783, 2.92137188361497}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 2.92137188361497}, {5.309519695523783, 
       2.92137188361497}}], 
      LineBox[{{5.309519695523783, 2.92137188361497}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 2.92137188361497}, {5.309519695523783, 
       2.92137188361497}}], 
      LineBox[{{5.309519695523783, 2.92137188361497}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 2.92137188361497}, {5.309519695523783, 
       2.92137188361497}}], 
      LineBox[{{5.309519695523783, 2.92137188361497}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 2.92137188361497}, {5.309519695523783, 
       2.92137188361497}}], 
      LineBox[{{5.293893225237583, 2.9899887628063078`}, {5.309519695523783, 
       3.0586056419976457`}, {5.309519695523783, 3.0586056419976457`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}}], 
      LineBox[{{5.293893225237583, 2.9899887628063078`}, {5.309519695523783, 
       3.0586056419976457`}, {5.309519695523783, 3.0586056419976457`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}}], 
      LineBox[{{5.293893225237583, 2.9899887628063078`}, {5.309519695523783, 
       3.0586056419976457`}, {5.309519695523783, 3.0586056419976457`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}}], 
      LineBox[{{5.293893225237583, 2.9899887628063078`}, {5.309519695523783, 
       3.0586056419976457`}, {5.309519695523783, 3.0586056419976457`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}}], 
      LineBox[{{5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}}], 
      LineBox[{{5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}}], 
      LineBox[{{5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}}], 
      LineBox[{{5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}}], 
      LineBox[{{5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}}], 
      LineBox[{{5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}}], 
      LineBox[{{5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}}], 
      LineBox[{{5.583199792635015, 2.900596364258633}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}}], 
      LineBox[{{5.583199792635015, 2.900596364258633}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}}], 
      LineBox[{{5.583199792635015, 2.900596364258633}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}}], 
      LineBox[{{5.583199792635015, 2.900596364258633}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}}], 
      LineBox[{{5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802,
        2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}], 
      LineBox[{{5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802,
        2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}], 
      LineBox[{{5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802,
        2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}], 
      LineBox[{{5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802,
        2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}], 
      LineBox[{{5.464351871618802, 2.8319794850672957`}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.464351871618802, 
       2.8319794850672957`}}], 
      LineBox[{{5.464351871618802, 2.8319794850672957`}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.464351871618802, 
       2.8319794850672957`}}], 
      LineBox[{{5.464351871618802, 2.8319794850672957`}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.464351871618802, 
       2.8319794850672957`}}], 
      LineBox[{{5.464351871618802, 2.8319794850672957`}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.464351871618802, 
       2.8319794850672957`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.373125172581725, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.464351871618802, 3.14799804054532}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}}], 
      LineBox[{{5.373125172581725, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.464351871618802, 3.14799804054532}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}}], 
      LineBox[{{5.373125172581725, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.464351871618802, 3.14799804054532}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}}], 
      LineBox[{{5.373125172581725, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.464351871618802, 3.14799804054532}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}}], 
      LineBox[{{5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}}], 
      LineBox[{{5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}}], 
      LineBox[{{5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}}], 
      LineBox[{{5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}}], 
      LineBox[{{5.5315890672700085`, 3.1272225211889833`}, {5.583199792635015,
        3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}}], 
      LineBox[{{5.5315890672700085`, 3.1272225211889833`}, {5.583199792635015,
        3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}}], 
      LineBox[{{5.5315890672700085`, 3.1272225211889833`}, {5.583199792635015,
        3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}}], 
      LineBox[{{5.5315890672700085`, 3.1272225211889833`}, {5.583199792635015,
        3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}}], 
      LineBox[{{5.583199792635015, 3.0793811613539823`}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}}], 
      LineBox[{{5.583199792635015, 3.0793811613539823`}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}}], 
      LineBox[{{5.583199792635015, 3.0793811613539823`}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}}], 
      LineBox[{{5.583199792635015, 3.0793811613539823`}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.317162575190067, 
       3.526795912348139}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.428176367022679}, {5.579393550617899, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.579393550617899, 
       3.375396788095022}, {5.636331571658912, 3.428176367022679}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.404572900332678, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.579393550617899, 3.6781950366012564`}, {
       5.636331571658912, 3.6254154576735993`}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.6254154576735993`}, {5.579393550617899, 
       3.6781950366012564`}, {5.505216083944996, 3.7011150198001577`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}], 
      LineBox[{{5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}], 
      LineBox[{{5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}], 
      LineBox[{{5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}], 
      LineBox[{{5.334402020821957, 3.451096350221581}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.451096350221581}, {5.334402020821957, 
       3.451096350221581}}], 
      LineBox[{{5.334402020821957, 3.451096350221581}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.451096350221581}, {5.334402020821957, 
       3.451096350221581}}], 
      LineBox[{{5.334402020821957, 3.451096350221581}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.451096350221581}, {5.334402020821957, 
       3.451096350221581}}], 
      LineBox[{{5.334402020821957, 3.451096350221581}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.451096350221581}, {5.334402020821957, 
       3.451096350221581}}], 
      LineBox[{{5.317162575190067, 3.526795912348139}, {5.334402020821957, 
       3.6024954744746975`}, {5.334402020821957, 3.6024954744746975`}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}}], 
      LineBox[{{5.317162575190067, 3.526795912348139}, {5.334402020821957, 
       3.6024954744746975`}, {5.334402020821957, 3.6024954744746975`}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}}], 
      LineBox[{{5.317162575190067, 3.526795912348139}, {5.334402020821957, 
       3.6024954744746975`}, {5.334402020821957, 3.6024954744746975`}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}}], 
      LineBox[{{5.317162575190067, 3.526795912348139}, {5.334402020821957, 
       3.6024954744746975`}, {5.334402020821957, 3.6024954744746975`}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}}], 
      LineBox[{{5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}}], 
      LineBox[{{5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}}], 
      LineBox[{{5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}}], 
      LineBox[{{5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}}], 
      LineBox[{{5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}}], 
      LineBox[{{5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}}], 
      LineBox[{{5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}}], 
      LineBox[{{5.636331571658912, 3.428176367022679}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}}], 
      LineBox[{{5.636331571658912, 3.428176367022679}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}}], 
      LineBox[{{5.636331571658912, 3.428176367022679}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}}], 
      LineBox[{{5.636331571658912, 3.428176367022679}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}}], 
      LineBox[{{5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}], 
      LineBox[{{5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}], 
      LineBox[{{5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}], 
      LineBox[{{5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}], 
      LineBox[{{5.505216083944996, 3.3524768048961207`}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.505216083944996, 
       3.3524768048961207`}}], 
      LineBox[{{5.505216083944996, 3.3524768048961207`}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.505216083944996, 
       3.3524768048961207`}}], 
      LineBox[{{5.505216083944996, 3.3524768048961207`}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.505216083944996, 
       3.3524768048961207`}}], 
      LineBox[{{5.505216083944996, 3.3524768048961207`}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.505216083944996, 
       3.3524768048961207`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.404572900332678, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.505216083944996, 3.7011150198001577`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}}], 
      LineBox[{{5.404572900332678, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.505216083944996, 3.7011150198001577`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}}], 
      LineBox[{{5.404572900332678, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.505216083944996, 3.7011150198001577`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}}], 
      LineBox[{{5.404572900332678, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.505216083944996, 3.7011150198001577`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}}], 
      LineBox[{{5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}}], 
      LineBox[{{5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}}], 
      LineBox[{{5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}}], 
      LineBox[{{5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}}], 
      LineBox[{{5.579393550617899, 3.6781950366012564`}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}}], 
      LineBox[{{5.579393550617899, 3.6781950366012564`}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}}], 
      LineBox[{{5.579393550617899, 3.6781950366012564`}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}}], 
      LineBox[{{5.579393550617899, 3.6781950366012564`}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}}], 
      LineBox[{{5.636331571658912, 3.6254154576735993`}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}}], 
      LineBox[{{5.636331571658912, 3.6254154576735993`}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}}], 
      LineBox[{{5.636331571658912, 3.6254154576735993`}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}}], 
      LineBox[{{5.636331571658912, 3.6254154576735993`}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}], 
      LineBox[{{5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}], 
      LineBox[{{5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}], 
      LineBox[{{5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}], 
      LineBox[{{5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}], 
      LineBox[{{5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}], 
      LineBox[{{5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}], 
      LineBox[{{5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}], 
      LineBox[{{5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}], 
      LineBox[{{5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}], 
      LineBox[{{5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}], 
      LineBox[{{5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}], 
      LineBox[{{5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}], 
      LineBox[{{5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}], 
      LineBox[{{5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}], 
      LineBox[{{5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}], 
      LineBox[{{5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}], 
      LineBox[{{5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}], 
      LineBox[{{5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}], 
      LineBox[{{5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}], 
      LineBox[{{5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}], 
      LineBox[{{5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}], 
      LineBox[{{5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}], 
      LineBox[{{5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}], 
      LineBox[{{5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}], 
      LineBox[{{5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}], 
      LineBox[{{5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}], 
      LineBox[{{5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}], 
      LineBox[{{5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}], 
      LineBox[{{5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}], 
      LineBox[{{5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}], 
      LineBox[{{5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}], 
      LineBox[{{5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}], 
      LineBox[{{5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}], 
      LineBox[{{5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}], 
      LineBox[{{5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}], 
      LineBox[{{5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}], 
      LineBox[{{5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}], 
      LineBox[{{5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}], 
      LineBox[{{5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}], 
      LineBox[{{5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}], 
      LineBox[{{5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}], 
      LineBox[{{5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}], 
      LineBox[{{5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}], 
      LineBox[{{5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}], 
      LineBox[{{5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.67483065003865, -3.6284336430882127`}, {
       5.67483065003865, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}], 
      LineBox[{{5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}], 
      LineBox[{{5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}], 
      LineBox[{{5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}], 
      LineBox[{{5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}], 
      LineBox[{{5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}], 
      LineBox[{{5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}], 
      LineBox[{{5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}], 
      LineBox[{{5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}], 
      LineBox[{{5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}], 
      LineBox[{{5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}], 
      LineBox[{{5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}], 
      LineBox[{{5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}], 
      LineBox[{{5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}], 
      LineBox[{{5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}], 
      LineBox[{{5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}], 
      LineBox[{{5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}], 
      LineBox[{{5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}], 
      LineBox[{{5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}], 
      LineBox[{{5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}], 
      LineBox[{{5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}], 
      LineBox[{{5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}], 
      LineBox[{{5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}], 
      LineBox[{{5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}], 
      LineBox[{{5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}], 
      LineBox[{{5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}], 
      LineBox[{{5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}], 
      LineBox[{{5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}], 
      LineBox[{{5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}], 
      LineBox[{{5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}], 
      LineBox[{{5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}], 
      LineBox[{{5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}], 
      LineBox[{{5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}], 
      LineBox[{{5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}], 
      LineBox[{{5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}], 
      LineBox[{{5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}], 
      LineBox[{{5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}], 
      LineBox[{{5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}], 
      LineBox[{{5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}], 
      LineBox[{{5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}], 
      LineBox[{{5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}], 
      LineBox[{{5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}], 
      LineBox[{{5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}], 
      LineBox[{{5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}], 
      LineBox[{{5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}], 
      LineBox[{{5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}], 
      LineBox[{{5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}], 
      LineBox[{{5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}], 
      LineBox[{{5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}], 
      LineBox[{{5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}], 
      LineBox[{{5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}], 
      LineBox[{{5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}], 
      LineBox[{{5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}], 
      LineBox[{{5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}], 
      LineBox[{{5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}], 
      LineBox[{{5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}], 
      LineBox[{{5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}], 
      LineBox[{{5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}], 
      LineBox[{{5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}], 
      LineBox[{{5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}], 
      LineBox[{{5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}], 
      LineBox[{{5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}], 
      LineBox[{{5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}], 
      LineBox[{{5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}], 
      LineBox[{{5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}], 
      LineBox[{{5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}], 
      LineBox[{{5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}], 
      LineBox[{{5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}], 
      LineBox[{{5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}], 
      LineBox[{{5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}], 
      LineBox[{{5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}], 
      LineBox[{{5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}], 
      LineBox[{{5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}], 
      LineBox[{{5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}], 
      LineBox[{{5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}], 
      LineBox[{{5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}], 
      LineBox[{{5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}], 
      LineBox[{{5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}], 
      LineBox[{{5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}], 
      LineBox[{{5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}], 
      LineBox[{{5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}], 
      LineBox[{{5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}], 
      LineBox[{{5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}], 
      LineBox[{{5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}], 
      LineBox[{{5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}], 
      LineBox[{{5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}], 
      LineBox[{{5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}], 
      LineBox[{{5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}], 
      LineBox[{{5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}], 
      LineBox[{{5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}], 
      LineBox[{{5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}], 
      LineBox[{{5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}], 
      LineBox[{{5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}], 
      LineBox[{{5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}], 
      LineBox[{{5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}], 
      LineBox[{{5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}], 
      LineBox[{{5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}], 
      LineBox[{{5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}], 
      LineBox[{{5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}], 
      LineBox[{{5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}], 
      LineBox[{{5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}], 
      LineBox[{{5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}], 
      LineBox[{{5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}], 
      LineBox[{{5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}], 
      LineBox[{{5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}], 
      LineBox[{{5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}], 
      LineBox[{{5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}], 
      LineBox[{{5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}], 
      LineBox[{{5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}], 
      LineBox[{{5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}], 
      LineBox[{{5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}], 
      LineBox[{{5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}], 
      LineBox[{{5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}], 
      LineBox[{{5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}], 
      LineBox[{{5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}], 
      LineBox[{{5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}], 
      LineBox[{{5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}], 
      LineBox[{{5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}], 
      LineBox[{{5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}], 
      LineBox[{{5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}], 
      LineBox[{{5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}], 
      LineBox[{{5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}], 
      LineBox[{{5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}], 
      LineBox[{{5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}], 
      LineBox[{{5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}], 
      LineBox[{{5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}], 
      LineBox[{{5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}], 
      LineBox[{{5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}], 
      LineBox[{{5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}], 
      LineBox[{{5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}], 
      LineBox[{{5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}], 
      LineBox[{{5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}], 
      LineBox[{{5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}], 
      LineBox[{{5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}], 
      LineBox[{{5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}], 
      LineBox[{{5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}], 
      LineBox[{{5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}], 
      LineBox[{{5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}], 
      LineBox[{{5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}], 
      LineBox[{{5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}], 
      LineBox[{{5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}], 
      LineBox[{{5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}], 
      LineBox[{{5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}], 
      LineBox[{{5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}], 
      LineBox[{{5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}], 
      LineBox[{{5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}], 
      LineBox[{{5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}], 
      LineBox[{{5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}], 
      LineBox[{{5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}], 
      LineBox[{{5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}], 
      LineBox[{{5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}], 
      LineBox[{{5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}], 
      LineBox[{{5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}], 
      LineBox[{{5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}], 
      LineBox[{{5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}], 
      LineBox[{{5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}], 
      LineBox[{{5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}], 
      LineBox[{{5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}], 
      LineBox[{{5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}], 
      LineBox[{{5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}], 
      LineBox[{{5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}], 
      LineBox[{{5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}], 
      LineBox[{{5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}], 
      LineBox[{{5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}], 
      LineBox[{{5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}], 
      LineBox[{{5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}], 
      LineBox[{{5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}], 
      LineBox[{{5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}], 
      LineBox[{{5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}], 
      LineBox[{{5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}], 
      LineBox[{{5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}], 
      LineBox[{{5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}], 
      LineBox[{{5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}], 
      LineBox[{{5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}], 
      LineBox[{{5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}], 
      LineBox[{{5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}], 
      LineBox[{{5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}], 
      LineBox[{{5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}], 
      LineBox[{{5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}], 
      LineBox[{{5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}], 
      LineBox[{{5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954885`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}], 
      LineBox[{{5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}], 
      LineBox[{{5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}], 
      LineBox[{{5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}], 
      LineBox[{{5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}], 
      LineBox[{{5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}], 
      LineBox[{{5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}], 
      LineBox[{{5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}], 
      LineBox[{{5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}], 
      LineBox[{{5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}], 
      LineBox[{{5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}], 
      LineBox[{{5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}], 
      LineBox[{{5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}], 
      LineBox[{{5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}], 
      LineBox[{{5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}], 
      LineBox[{{5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}], 
      LineBox[{{5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}], 
      LineBox[{{5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}], 
      LineBox[{{5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}], 
      LineBox[{{5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}], 
      LineBox[{{5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}], 
      LineBox[{{5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}], 
      LineBox[{{5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}], 
      LineBox[{{5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}], 
      LineBox[{{5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}], 
      LineBox[{{5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}], 
      LineBox[{{5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}], 
      LineBox[{{5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}], 
      LineBox[{{5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}], 
      LineBox[{{5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}], 
      LineBox[{{5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}], 
      LineBox[{{5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}], 
      LineBox[{{5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}], 
      LineBox[{{5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}], 
      LineBox[{{5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}], 
      LineBox[{{5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}], 
      LineBox[{{5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}], 
      LineBox[{{5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}], 
      LineBox[{{5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}], 
      LineBox[{{5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}], 
      LineBox[{{5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}], 
      LineBox[{{5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}], 
      LineBox[{{5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}], 
      LineBox[{{5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}], 
      LineBox[{{5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}], 
      LineBox[{{5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}], 
      LineBox[{{5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}], 
      LineBox[{{5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}], 
      LineBox[{{5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}], 
      LineBox[{{5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}], 
      LineBox[{{5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}], 
      LineBox[{{5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}], 
      LineBox[{{5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}], 
      LineBox[{{5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}], 
      LineBox[{{5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}], 
      LineBox[{{5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}], 
      LineBox[{{5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}], 
      LineBox[{{5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}], 
      LineBox[{{5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}], 
      LineBox[{{5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}], 
      LineBox[{{5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}], 
      LineBox[{{5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}], 
      LineBox[{{5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}], 
      LineBox[{{5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}], 
      LineBox[{{5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}], 
      LineBox[{{5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}], 
      LineBox[{{5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}], 
      LineBox[{{5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}], 
      LineBox[{{5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}], 
      LineBox[{{5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}], 
      LineBox[{{5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}], 
      LineBox[{{5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}], 
      LineBox[{{5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}], 
      LineBox[{{5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}], 
      LineBox[{{5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}], 
      LineBox[{{5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}], 
      LineBox[{{5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}], 
      LineBox[{{5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}], 
      LineBox[{{5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}], 
      LineBox[{{5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}], 
      LineBox[{{5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}], 
      LineBox[{{5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}], 
      LineBox[{{5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}], 
      LineBox[{{5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}], 
      LineBox[{{5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}], 
      LineBox[{{5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}], 
      LineBox[{{5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}], 
      LineBox[{{5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}], 
      LineBox[{{5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}], 
      LineBox[{{5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}], 
      LineBox[{{5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}], 
      LineBox[{{5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}], 
      LineBox[{{5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}], 
      LineBox[{{5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}], 
      LineBox[{{5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}], 
      LineBox[{{5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}], 
      LineBox[{{5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}], 
      LineBox[{{5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}], 
      LineBox[{{5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}], 
      LineBox[{{5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}], 
      LineBox[{{5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}], 
      LineBox[{{5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}], 
      LineBox[{{5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}], 
      LineBox[{{5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}], 
      LineBox[{{5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}], 
      LineBox[{{5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}], 
      LineBox[{{5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}], 
      LineBox[{{5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}], 
      LineBox[{{5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}], 
      LineBox[{{5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}], 
      LineBox[{{5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}], 
      LineBox[{{5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}], 
      LineBox[{{5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}], 
      LineBox[{{5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}], 
      LineBox[{{5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}], 
      LineBox[{{5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}], 
      LineBox[{{5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}], 
      LineBox[{{5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}], 
      LineBox[{{5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}], 
      LineBox[{{5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}], 
      LineBox[{{5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}], 
      LineBox[{{5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}], 
      LineBox[{{5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}], 
      LineBox[{{5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}], 
      LineBox[{{5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}], 
      LineBox[{{5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}], 
      LineBox[{{5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}], 
      LineBox[{{5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}], 
      LineBox[{{5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}], 
      LineBox[{{5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}], 
      LineBox[{{5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}], 
      LineBox[{{5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}], 
      LineBox[{{5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}], 
      LineBox[{{5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}], 
      LineBox[{{5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}], 
      LineBox[{{5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979662`}, {
       5.700969390825196, -0.17255877448979662`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.406962720019234}, {
       5.700969390825196, -0.406962720019234}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}], 
      LineBox[{{5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}], 
      LineBox[{{5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}], 
      LineBox[{{5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}], 
      LineBox[{{5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}], 
      LineBox[{{5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}], 
      LineBox[{{5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}], 
      LineBox[{{5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}], 
      LineBox[{{5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}], 
      LineBox[{{5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}], 
      LineBox[{{5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}], 
      LineBox[{{5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}], 
      LineBox[{{5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}], 
      LineBox[{{5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}], 
      LineBox[{{5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}], 
      LineBox[{{5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}], 
      LineBox[{{5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}], 
      LineBox[{{5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}], 
      LineBox[{{5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}], 
      LineBox[{{5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}], 
      LineBox[{{5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}], 
      LineBox[{{5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}], 
      LineBox[{{5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}], 
      LineBox[{{5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}], 
      LineBox[{{5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}], 
      LineBox[{{5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}], 
      LineBox[{{5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}], 
      LineBox[{{5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}], 
      LineBox[{{5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}], 
      LineBox[{{5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}], 
      LineBox[{{5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}], 
      LineBox[{{5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}], 
      LineBox[{{5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}], 
      LineBox[{{5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}], 
      LineBox[{{5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}], 
      LineBox[{{5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}], 
      LineBox[{{5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}], 
      LineBox[{{5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}], 
      LineBox[{{5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}], 
      LineBox[{{5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}], 
      LineBox[{{5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}], 
      LineBox[{{5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}], 
      LineBox[{{5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}], 
      LineBox[{{5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}], 
      LineBox[{{5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}], 
      LineBox[{{5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.641727282507628, 0.117716365463937}, {5.594467387005202, 
       0.16869981359264413`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.27066670985005836`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}, {
       5.594467387005202, 0.27066670985005836`}, {5.58285666750498, 
       0.21968326172135125`}, {5.594467387005202, 0.1686998135926441}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.7594685125129255`, 0.117716365463937}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.641727282507628, 
       0.11771636546393699`}, {5.641727282507628, 0.11771636546393699`}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`,
        0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7594685125129255`, 0.3216501579787655}, {
       5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135125`}, {5.818339127515574, 0.21968326172135125`}, {
       5.797816114014801, 0.2861032558710037}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.641727282507628, 0.117716365463937}, {5.594467387005202, 
       0.16869981359264413`}, {5.594467387005202, 0.16869981359264413`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}}], 
      LineBox[{{5.641727282507628, 0.117716365463937}, {5.594467387005202, 
       0.16869981359264413`}, {5.594467387005202, 0.16869981359264413`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}}], 
      LineBox[{{5.641727282507628, 0.117716365463937}, {5.594467387005202, 
       0.16869981359264413`}, {5.594467387005202, 0.16869981359264413`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}}], 
      LineBox[{{5.641727282507628, 0.117716365463937}, {5.594467387005202, 
       0.16869981359264413`}, {5.594467387005202, 0.16869981359264413`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}}], 
      LineBox[{{5.594467387005202, 0.16869981359264413`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}}], 
      LineBox[{{5.594467387005202, 0.16869981359264413`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}}], 
      LineBox[{{5.594467387005202, 0.16869981359264413`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}}], 
      LineBox[{{5.594467387005202, 0.16869981359264413`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}}], 
      LineBox[{{5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}], 
      LineBox[{{5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}], 
      LineBox[{{5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}], 
      LineBox[{{5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}], 
      LineBox[{{5.594467387005202, 0.27066670985005836`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}}], 
      LineBox[{{5.594467387005202, 0.27066670985005836`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}}], 
      LineBox[{{5.594467387005202, 0.27066670985005836`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}}], 
      LineBox[{{5.594467387005202, 0.27066670985005836`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}], 
      LineBox[{{5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}], 
      LineBox[{{5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}], 
      LineBox[{{5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}], 
      LineBox[{{5.797816114014801, 0.15326326757169878`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}}], 
      LineBox[{{5.797816114014801, 0.15326326757169878`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}}], 
      LineBox[{{5.797816114014801, 0.15326326757169878`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}}], 
      LineBox[{{5.797816114014801, 0.15326326757169878`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}}], 
      LineBox[{{5.7594685125129255`, 0.117716365463937}, {5.7095101915108275`,
        0.10227981944299162`}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}}], 
      LineBox[{{5.7594685125129255`, 0.117716365463937}, {5.7095101915108275`,
        0.10227981944299162`}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}}], 
      LineBox[{{5.7594685125129255`, 0.117716365463937}, {5.7095101915108275`,
        0.10227981944299162`}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}}], 
      LineBox[{{5.7594685125129255`, 0.117716365463937}, {5.7095101915108275`,
        0.10227981944299162`}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}}], 
      LineBox[{{5.7095101915108275`, 0.10227981944299162`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}}], 
      LineBox[{{5.7095101915108275`, 0.10227981944299162`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}}], 
      LineBox[{{5.7095101915108275`, 0.10227981944299162`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}}], 
      LineBox[{{5.7095101915108275`, 0.10227981944299162`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}], 
      LineBox[{{5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}], 
      LineBox[{{5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}], 
      LineBox[{{5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}], 
      LineBox[{{5.7095101915108275`, 0.33708670399971086`}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.7095101915108275`, 0.33708670399971086`}}], 
      LineBox[{{5.7095101915108275`, 0.33708670399971086`}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.7095101915108275`, 0.33708670399971086`}}], 
      LineBox[{{5.7095101915108275`, 0.33708670399971086`}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.7095101915108275`, 0.33708670399971086`}}], 
      LineBox[{{5.7095101915108275`, 0.33708670399971086`}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.7095101915108275`, 0.33708670399971086`}}], 
      LineBox[{{5.7594685125129255`, 0.3216501579787655}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}}], 
      LineBox[{{5.7594685125129255`, 0.3216501579787655}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}}], 
      LineBox[{{5.7594685125129255`, 0.3216501579787655}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}}], 
      LineBox[{{5.7594685125129255`, 0.3216501579787655}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}}], 
      LineBox[{{5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135122`}, {5.818339127515574, 0.21968326172135122`}, {
       5.797816114014801, 0.2861032558710037}, {5.797816114014801, 
       0.2861032558710037}}], 
      LineBox[{{5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135122`}, {5.818339127515574, 0.21968326172135122`}, {
       5.797816114014801, 0.2861032558710037}, {5.797816114014801, 
       0.2861032558710037}}], 
      LineBox[{{5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135122`}, {5.818339127515574, 0.21968326172135122`}, {
       5.797816114014801, 0.2861032558710037}, {5.797816114014801, 
       0.2861032558710037}}], 
      LineBox[{{5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135122`}, {5.818339127515574, 0.21968326172135122`}, {
       5.797816114014801, 0.2861032558710037}, {5.797816114014801, 
       0.2861032558710037}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.690554404791883, 0.6390918836757744}, {5.62976465582665, 
       0.7046711868074756}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.8358297930708781}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}, {
       5.62976465582665, 0.8358297930708781}, {5.614829948159171, 
       0.7702504899391769}, {5.62976465582665, 0.7046711868074756}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.842003318057306, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.842003318057306, 
       0.6390918836757744}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.842003318057306, 0.9014090962025794}, {
       5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.842003318057306, 
       0.9014090962025794}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.690554404791883, 0.6390918836757744}, {5.62976465582665, 
       0.7046711868074756}, {5.62976465582665, 0.7046711868074756}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}}], 
      LineBox[{{5.690554404791883, 0.6390918836757744}, {5.62976465582665, 
       0.7046711868074756}, {5.62976465582665, 0.7046711868074756}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}}], 
      LineBox[{{5.690554404791883, 0.6390918836757744}, {5.62976465582665, 
       0.7046711868074756}, {5.62976465582665, 0.7046711868074756}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}}], 
      LineBox[{{5.690554404791883, 0.6390918836757744}, {5.62976465582665, 
       0.7046711868074756}, {5.62976465582665, 0.7046711868074756}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}}], 
      LineBox[{{5.62976465582665, 0.7046711868074756}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}}], 
      LineBox[{{5.62976465582665, 0.7046711868074756}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}}], 
      LineBox[{{5.62976465582665, 0.7046711868074756}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}}], 
      LineBox[{{5.62976465582665, 0.7046711868074756}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}}], 
      LineBox[{{5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}], 
      LineBox[{{5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}], 
      LineBox[{{5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}], 
      LineBox[{{5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}], 
      LineBox[{{5.62976465582665, 0.8358297930708781}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}}], 
      LineBox[{{5.62976465582665, 0.8358297930708781}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}}], 
      LineBox[{{5.62976465582665, 0.8358297930708781}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}}], 
      LineBox[{{5.62976465582665, 0.8358297930708781}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}], 
      LineBox[{{5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}], 
      LineBox[{{5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}], 
      LineBox[{{5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}], 
      LineBox[{{5.8913293066981005`, 0.684815371479755}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.8913293066981005`, 0.684815371479755}, {5.8913293066981005`, 
       0.684815371479755}}], 
      LineBox[{{5.8913293066981005`, 0.684815371479755}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.8913293066981005`, 0.684815371479755}, {5.8913293066981005`, 
       0.684815371479755}}], 
      LineBox[{{5.8913293066981005`, 0.684815371479755}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.8913293066981005`, 0.684815371479755}, {5.8913293066981005`, 
       0.684815371479755}}], 
      LineBox[{{5.8913293066981005`, 0.684815371479755}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.8913293066981005`, 0.684815371479755}, {5.8913293066981005`, 
       0.684815371479755}}], 
      LineBox[{{5.842003318057306, 0.6390918836757744}, {5.7777426217490335`, 
       0.6192360683480538}, {5.7777426217490335`, 0.6192360683480538}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}}], 
      LineBox[{{5.842003318057306, 0.6390918836757744}, {5.7777426217490335`, 
       0.6192360683480538}, {5.7777426217490335`, 0.6192360683480538}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}}], 
      LineBox[{{5.842003318057306, 0.6390918836757744}, {5.7777426217490335`, 
       0.6192360683480538}, {5.7777426217490335`, 0.6192360683480538}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}}], 
      LineBox[{{5.842003318057306, 0.6390918836757744}, {5.7777426217490335`, 
       0.6192360683480538}, {5.7777426217490335`, 0.6192360683480538}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}}], 
      LineBox[{{5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}}], 
      LineBox[{{5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}}], 
      LineBox[{{5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}}], 
      LineBox[{{5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}], 
      LineBox[{{5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}], 
      LineBox[{{5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}], 
      LineBox[{{5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}], 
      LineBox[{{5.7777426217490335`, 0.9212649115303}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}}], 
      LineBox[{{5.7777426217490335`, 0.9212649115303}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}}], 
      LineBox[{{5.7777426217490335`, 0.9212649115303}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}}], 
      LineBox[{{5.7777426217490335`, 0.9212649115303}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}}], 
      LineBox[{{5.842003318057306, 0.9014090962025794}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}], 
      LineBox[{{5.842003318057306, 0.9014090962025794}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}], 
      LineBox[{{5.842003318057306, 0.9014090962025794}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}], 
      LineBox[{{5.842003318057306, 0.9014090962025794}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}], 
      LineBox[{{5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.8913293066981005`, 
       0.8556856083985988}}], 
      LineBox[{{5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.8913293066981005`, 
       0.8556856083985988}}], 
      LineBox[{{5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.8913293066981005`, 
       0.8556856083985988}}], 
      LineBox[{{5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.8913293066981005`, 
       0.8556856083985988}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668788769640803, 1.087304322590759}, {5.596678723561459, 
       1.1650958359819856`}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.3206788627644384`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}, {
       5.596678723561459, 1.3206788627644384`}, {5.578962867246617, 
       1.242887349373212}, {5.596678723561459, 1.1650958359819856`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.848440574429175, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476115, 1.0637509475135936`}, {5.848440574429175, 
       1.087304322590759}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.848440574429175, 1.398470376155665}, {
       5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.848440574429175, 
       1.398470376155665}, {5.772213219476114, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668788769640803, 1.087304322590759}, {5.596678723561459, 
       1.1650958359819856`}, {5.596678723561459, 1.1650958359819856`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}}], 
      LineBox[{{5.668788769640803, 1.087304322590759}, {5.596678723561459, 
       1.1650958359819856`}, {5.596678723561459, 1.1650958359819856`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}}], 
      LineBox[{{5.668788769640803, 1.087304322590759}, {5.596678723561459, 
       1.1650958359819856`}, {5.596678723561459, 1.1650958359819856`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}}], 
      LineBox[{{5.668788769640803, 1.087304322590759}, {5.596678723561459, 
       1.1650958359819856`}, {5.596678723561459, 1.1650958359819856`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}}], 
      LineBox[{{5.596678723561459, 1.1650958359819856`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}}], 
      LineBox[{{5.596678723561459, 1.1650958359819856`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}}], 
      LineBox[{{5.596678723561459, 1.1650958359819856`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}}], 
      LineBox[{{5.596678723561459, 1.1650958359819856`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}}], 
      LineBox[{{5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}], 
      LineBox[{{5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}], 
      LineBox[{{5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}], 
      LineBox[{{5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}], 
      LineBox[{{5.596678723561459, 1.3206788627644384`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}}], 
      LineBox[{{5.596678723561459, 1.3206788627644384`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}}], 
      LineBox[{{5.596678723561459, 1.3206788627644384`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}}], 
      LineBox[{{5.596678723561459, 1.3206788627644384`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}], 
      LineBox[{{5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}], 
      LineBox[{{5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}], 
      LineBox[{{5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}], 
      LineBox[{{5.9069520730673934`, 1.14154246090482}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.9069520730673934`, 1.14154246090482}, {5.9069520730673934`, 
       1.14154246090482}}], 
      LineBox[{{5.9069520730673934`, 1.14154246090482}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.9069520730673934`, 1.14154246090482}, {5.9069520730673934`, 
       1.14154246090482}}], 
      LineBox[{{5.9069520730673934`, 1.14154246090482}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.9069520730673934`, 1.14154246090482}, {5.9069520730673934`, 
       1.14154246090482}}], 
      LineBox[{{5.9069520730673934`, 1.14154246090482}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.9069520730673934`, 1.14154246090482}, {5.9069520730673934`, 
       1.14154246090482}}], 
      LineBox[{{5.848440574429175, 1.087304322590759}, {5.772213219476115, 
       1.0637509475135936`}, {5.772213219476115, 1.0637509475135936`}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}}], 
      LineBox[{{5.848440574429175, 1.087304322590759}, {5.772213219476115, 
       1.0637509475135936`}, {5.772213219476115, 1.0637509475135936`}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}}], 
      LineBox[{{5.848440574429175, 1.087304322590759}, {5.772213219476115, 
       1.0637509475135936`}, {5.772213219476115, 1.0637509475135936`}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}}], 
      LineBox[{{5.848440574429175, 1.087304322590759}, {5.772213219476115, 
       1.0637509475135936`}, {5.772213219476115, 1.0637509475135936`}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}}], 
      LineBox[{{5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.772213219476114, 
       1.0637509475135936`}}], 
      LineBox[{{5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.772213219476114, 
       1.0637509475135936`}}], 
      LineBox[{{5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.772213219476114, 
       1.0637509475135936`}}], 
      LineBox[{{5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.772213219476114, 
       1.0637509475135936`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}], 
      LineBox[{{5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}], 
      LineBox[{{5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}], 
      LineBox[{{5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}], 
      LineBox[{{5.772213219476115, 1.4220237512328304`}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}}], 
      LineBox[{{5.772213219476115, 1.4220237512328304`}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}}], 
      LineBox[{{5.772213219476115, 1.4220237512328304`}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}}], 
      LineBox[{{5.772213219476115, 1.4220237512328304`}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}}], 
      LineBox[{{5.848440574429175, 1.398470376155665}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}], 
      LineBox[{{5.848440574429175, 1.398470376155665}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}], 
      LineBox[{{5.848440574429175, 1.398470376155665}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}], 
      LineBox[{{5.848440574429175, 1.398470376155665}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}], 
      LineBox[{{5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.9069520730673934`, 
       1.344232237841604}}], 
      LineBox[{{5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.9069520730673934`, 
       1.344232237841604}}], 
      LineBox[{{5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.9069520730673934`, 
       1.344232237841604}}], 
      LineBox[{{5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.9069520730673934`, 
       1.344232237841604}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.650757437115237, 1.6149672460295592`}, {5.601870046071231, 
       1.6677064181953536`}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.7731847625269423`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}, {
       5.601870046071231, 1.7731847625269423`}, {5.589859486621719, 
       1.720445590361148}, {5.601870046071231, 1.6677064181953536`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.772553338102275, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.772553338102275, 
       1.6149672460295592`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.772553338102275, 1.8259239346927367`}, {
       5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.772553338102275, 
       1.8259239346927367`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.650757437115237, 1.6149672460295592`}, {5.601870046071231, 
       1.6677064181953536`}, {5.601870046071231, 1.6677064181953536`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}}], 
      LineBox[{{5.650757437115237, 1.6149672460295592`}, {5.601870046071231, 
       1.6677064181953536`}, {5.601870046071231, 1.6677064181953536`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}}], 
      LineBox[{{5.650757437115237, 1.6149672460295592`}, {5.601870046071231, 
       1.6677064181953536`}, {5.601870046071231, 1.6677064181953536`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}}], 
      LineBox[{{5.650757437115237, 1.6149672460295592`}, {5.601870046071231, 
       1.6677064181953536`}, {5.601870046071231, 1.6677064181953536`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}}], 
      LineBox[{{5.601870046071231, 1.6677064181953536`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}}], 
      LineBox[{{5.601870046071231, 1.6677064181953536`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}}], 
      LineBox[{{5.601870046071231, 1.6677064181953536`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}}], 
      LineBox[{{5.601870046071231, 1.6677064181953536`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}}], 
      LineBox[{{5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}], 
      LineBox[{{5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}], 
      LineBox[{{5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}], 
      LineBox[{{5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}], 
      LineBox[{{5.601870046071231, 1.7731847625269423`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}}], 
      LineBox[{{5.601870046071231, 1.7731847625269423`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}}], 
      LineBox[{{5.601870046071231, 1.7731847625269423`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}}], 
      LineBox[{{5.601870046071231, 1.7731847625269423`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}], 
      LineBox[{{5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}], 
      LineBox[{{5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}], 
      LineBox[{{5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}], 
      LineBox[{{5.812221521247658, 1.6517382817093977`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.812221521247658, 1.6517382817093977`}, {5.812221521247658, 
       1.6517382817093977`}}], 
      LineBox[{{5.812221521247658, 1.6517382817093977`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.812221521247658, 1.6517382817093977`}, {5.812221521247658, 
       1.6517382817093977`}}], 
      LineBox[{{5.812221521247658, 1.6517382817093977`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.812221521247658, 1.6517382817093977`}, {5.812221521247658, 
       1.6517382817093977`}}], 
      LineBox[{{5.812221521247658, 1.6517382817093977`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.812221521247658, 1.6517382817093977`}, {5.812221521247658, 
       1.6517382817093977`}}], 
      LineBox[{{5.772553338102275, 1.6149672460295592`}, {5.72087459550738, 
       1.5989991095436034`}, {5.72087459550738, 1.5989991095436034`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}}], 
      LineBox[{{5.772553338102275, 1.6149672460295592`}, {5.72087459550738, 
       1.5989991095436034`}, {5.72087459550738, 1.5989991095436034`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}}], 
      LineBox[{{5.772553338102275, 1.6149672460295592`}, {5.72087459550738, 
       1.5989991095436034`}, {5.72087459550738, 1.5989991095436034`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}}], 
      LineBox[{{5.772553338102275, 1.6149672460295592`}, {5.72087459550738, 
       1.5989991095436034`}, {5.72087459550738, 1.5989991095436034`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}}], 
      LineBox[{{5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}}], 
      LineBox[{{5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}}], 
      LineBox[{{5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}}], 
      LineBox[{{5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}], 
      LineBox[{{5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}], 
      LineBox[{{5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}], 
      LineBox[{{5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}], 
      LineBox[{{5.72087459550738, 1.8418920711786926`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}}], 
      LineBox[{{5.72087459550738, 1.8418920711786926`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}}], 
      LineBox[{{5.72087459550738, 1.8418920711786926`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}}], 
      LineBox[{{5.72087459550738, 1.8418920711786926`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}}], 
      LineBox[{{5.772553338102275, 1.8259239346927367`}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}], 
      LineBox[{{5.772553338102275, 1.8259239346927367`}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}], 
      LineBox[{{5.772553338102275, 1.8259239346927367`}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}], 
      LineBox[{{5.772553338102275, 1.8259239346927367`}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}], 
      LineBox[{{5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.812221521247658, 
       1.7891528990128982`}}], 
      LineBox[{{5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.812221521247658, 
       1.7891528990128982`}}], 
      LineBox[{{5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.812221521247658, 
       1.7891528990128982`}}], 
      LineBox[{{5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.812221521247658, 
       1.7891528990128982`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.646685014052404, 2.104257196793243}, {5.59928782324382, 
       2.1553887575668345`}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.257651879114017}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}, {
       5.59928782324382, 2.257651879114017}, {5.587643373298967, 
       2.206520318340426}, {5.59928782324382, 2.1553887575668345`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.764768295559279, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.764768295559279, 
       2.104257196793243}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.764768295559279, 2.3087834398876086`}, {
       5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.764768295559279, 
       2.3087834398876086`}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.646685014052404, 2.104257196793243}, {5.59928782324382, 
       2.1553887575668345`}, {5.59928782324382, 2.1553887575668345`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}}], 
      LineBox[{{5.646685014052404, 2.104257196793243}, {5.59928782324382, 
       2.1553887575668345`}, {5.59928782324382, 2.1553887575668345`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}}], 
      LineBox[{{5.646685014052404, 2.104257196793243}, {5.59928782324382, 
       2.1553887575668345`}, {5.59928782324382, 2.1553887575668345`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}}], 
      LineBox[{{5.646685014052404, 2.104257196793243}, {5.59928782324382, 
       2.1553887575668345`}, {5.59928782324382, 2.1553887575668345`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}}], 
      LineBox[{{5.59928782324382, 2.1553887575668345`}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}}], 
      LineBox[{{5.59928782324382, 2.1553887575668345`}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}}], 
      LineBox[{{5.59928782324382, 2.1553887575668345`}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}}], 
      LineBox[{{5.59928782324382, 2.1553887575668345`}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}}], 
      LineBox[{{5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}], 
      LineBox[{{5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}], 
      LineBox[{{5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}], 
      LineBox[{{5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}], 
      LineBox[{{5.59928782324382, 2.257651879114017}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}}], 
      LineBox[{{5.59928782324382, 2.257651879114017}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}}], 
      LineBox[{{5.59928782324382, 2.257651879114017}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}}], 
      LineBox[{{5.59928782324382, 2.257651879114017}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}], 
      LineBox[{{5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}], 
      LineBox[{{5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}], 
      LineBox[{{5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}], 
      LineBox[{{5.803227301151931, 2.139907366645378}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.803227301151931, 2.139907366645378}, {5.803227301151931, 
       2.139907366645378}}], 
      LineBox[{{5.803227301151931, 2.139907366645378}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.803227301151931, 2.139907366645378}, {5.803227301151931, 
       2.139907366645378}}], 
      LineBox[{{5.803227301151931, 2.139907366645378}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.803227301151931, 2.139907366645378}, {5.803227301151931, 
       2.139907366645378}}], 
      LineBox[{{5.803227301151931, 2.139907366645378}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.803227301151931, 2.139907366645378}, {5.803227301151931, 
       2.139907366645378}}], 
      LineBox[{{5.764768295559279, 2.104257196793243}, {5.714664840021775, 
       2.0887758058717867`}, {5.714664840021775, 2.0887758058717867`}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}}], 
      LineBox[{{5.764768295559279, 2.104257196793243}, {5.714664840021775, 
       2.0887758058717867`}, {5.714664840021775, 2.0887758058717867`}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}}], 
      LineBox[{{5.764768295559279, 2.104257196793243}, {5.714664840021775, 
       2.0887758058717867`}, {5.714664840021775, 2.0887758058717867`}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}}], 
      LineBox[{{5.764768295559279, 2.104257196793243}, {5.714664840021775, 
       2.0887758058717867`}, {5.714664840021775, 2.0887758058717867`}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}}], 
      LineBox[{{5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}}], 
      LineBox[{{5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}}], 
      LineBox[{{5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}}], 
      LineBox[{{5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}], 
      LineBox[{{5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}], 
      LineBox[{{5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}], 
      LineBox[{{5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}], 
      LineBox[{{5.714664840021775, 2.324264830809065}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}}], 
      LineBox[{{5.714664840021775, 2.324264830809065}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}}], 
      LineBox[{{5.714664840021775, 2.324264830809065}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}}], 
      LineBox[{{5.714664840021775, 2.324264830809065}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}}], 
      LineBox[{{5.764768295559279, 2.3087834398876086`}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}], 
      LineBox[{{5.764768295559279, 2.3087834398876086`}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}], 
      LineBox[{{5.764768295559279, 2.3087834398876086`}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}], 
      LineBox[{{5.764768295559279, 2.3087834398876086`}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}], 
      LineBox[{{5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.803227301151931, 
       2.2731332700354736`}}], 
      LineBox[{{5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.803227301151931, 
       2.2731332700354736`}}], 
      LineBox[{{5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.803227301151931, 
       2.2731332700354736`}}], 
      LineBox[{{5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.803227301151931, 
       2.2731332700354736`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.621501308897328, 2.655898410457235}, {5.557895831839386, 
       2.7245152896485725`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.8617490480312484`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}, {
       5.557895831839386, 2.8617490480312484`}, {5.542269361553186, 
       2.7931321688399104`}, {5.557895831839386, 2.7245152896485725`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.779965203585611, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328, 
       2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.779965203585611, 
       2.655898410457235}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.779965203585611, 2.930365927222586}, {
       5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.779965203585611, 
       2.930365927222586}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.621501308897328, 2.655898410457235}, {5.557895831839386, 
       2.7245152896485725`}, {5.557895831839386, 2.7245152896485725`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}}], 
      LineBox[{{5.621501308897328, 2.655898410457235}, {5.557895831839386, 
       2.7245152896485725`}, {5.557895831839386, 2.7245152896485725`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}}], 
      LineBox[{{5.621501308897328, 2.655898410457235}, {5.557895831839386, 
       2.7245152896485725`}, {5.557895831839386, 2.7245152896485725`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}}], 
      LineBox[{{5.621501308897328, 2.655898410457235}, {5.557895831839386, 
       2.7245152896485725`}, {5.557895831839386, 2.7245152896485725`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}}], 
      LineBox[{{5.557895831839386, 2.7245152896485725`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}}], 
      LineBox[{{5.557895831839386, 2.7245152896485725`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}}], 
      LineBox[{{5.557895831839386, 2.7245152896485725`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}}], 
      LineBox[{{5.557895831839386, 2.7245152896485725`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}}], 
      LineBox[{{5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}], 
      LineBox[{{5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}], 
      LineBox[{{5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}], 
      LineBox[{{5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}], 
      LineBox[{{5.557895831839386, 2.8617490480312484`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}}], 
      LineBox[{{5.557895831839386, 2.8617490480312484`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}}], 
      LineBox[{{5.557895831839386, 2.8617490480312484`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}}], 
      LineBox[{{5.557895831839386, 2.8617490480312484`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}], 
      LineBox[{{5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}], 
      LineBox[{{5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}], 
      LineBox[{{5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}], 
      LineBox[{{5.831575928950618, 2.703739770292236}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.831575928950618, 2.703739770292236}, {5.831575928950618, 
       2.703739770292236}}], 
      LineBox[{{5.831575928950618, 2.703739770292236}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.831575928950618, 2.703739770292236}, {5.831575928950618, 
       2.703739770292236}}], 
      LineBox[{{5.831575928950618, 2.703739770292236}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.831575928950618, 2.703739770292236}, {5.831575928950618, 
       2.703739770292236}}], 
      LineBox[{{5.831575928950618, 2.703739770292236}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.831575928950618, 2.703739770292236}, {5.831575928950618, 
       2.703739770292236}}], 
      LineBox[{{5.779965203585611, 2.655898410457235}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}}], 
      LineBox[{{5.779965203585611, 2.655898410457235}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}}], 
      LineBox[{{5.779965203585611, 2.655898410457235}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}}], 
      LineBox[{{5.779965203585611, 2.655898410457235}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}}], 
      LineBox[{{5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328,
        2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}}], 
      LineBox[{{5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328,
        2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}}], 
      LineBox[{{5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328,
        2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}}], 
      LineBox[{{5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328,
        2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}], 
      LineBox[{{5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}], 
      LineBox[{{5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}], 
      LineBox[{{5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}], 
      LineBox[{{5.7127280079344045`, 2.9511414465789225`}, {5.779965203585611,
        2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}}], 
      LineBox[{{5.7127280079344045`, 2.9511414465789225`}, {5.779965203585611,
        2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}}], 
      LineBox[{{5.7127280079344045`, 2.9511414465789225`}, {5.779965203585611,
        2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}}], 
      LineBox[{{5.7127280079344045`, 2.9511414465789225`}, {5.779965203585611,
        2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}}], 
      LineBox[{{5.779965203585611, 2.930365927222586}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}], 
      LineBox[{{5.779965203585611, 2.930365927222586}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}], 
      LineBox[{{5.779965203585611, 2.930365927222586}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}], 
      LineBox[{{5.779965203585611, 2.930365927222586}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}], 
      LineBox[{{5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.831575928950618, 
       2.882524567387585}}], 
      LineBox[{{5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.831575928950618, 
       2.882524567387585}}], 
      LineBox[{{5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.831575928950618, 
       2.882524567387585}}], 
      LineBox[{{5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.831575928950618, 
       2.882524567387585}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.733739775945973, 3.16613761318721}, {5.680717028739826, 
       3.2233379614547464`}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.3377386579898194`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}, {
       5.680717028739826, 3.3377386579898194`}, {5.667690503005968, 
       3.280538309722283}, {5.680717028739826, 3.2233379614547464`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.865838321825984, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.865838321825984, 
       3.16613761318721}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.865838321825984, 3.394939006257356}, {
       5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.865838321825984, 
       3.394939006257356}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.733739775945973, 3.16613761318721}, {5.680717028739826, 
       3.2233379614547464`}, {5.680717028739826, 3.2233379614547464`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}}], 
      LineBox[{{5.733739775945973, 3.16613761318721}, {5.680717028739826, 
       3.2233379614547464`}, {5.680717028739826, 3.2233379614547464`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}}], 
      LineBox[{{5.733739775945973, 3.16613761318721}, {5.680717028739826, 
       3.2233379614547464`}, {5.680717028739826, 3.2233379614547464`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}}], 
      LineBox[{{5.733739775945973, 3.16613761318721}, {5.680717028739826, 
       3.2233379614547464`}, {5.680717028739826, 3.2233379614547464`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}}], 
      LineBox[{{5.680717028739826, 3.2233379614547464`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}}], 
      LineBox[{{5.680717028739826, 3.2233379614547464`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}}], 
      LineBox[{{5.680717028739826, 3.2233379614547464`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}}], 
      LineBox[{{5.680717028739826, 3.2233379614547464`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}}], 
      LineBox[{{5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}], 
      LineBox[{{5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}], 
      LineBox[{{5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}], 
      LineBox[{{5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}], 
      LineBox[{{5.680717028739826, 3.3377386579898194`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}}], 
      LineBox[{{5.680717028739826, 3.3377386579898194`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}}], 
      LineBox[{{5.680717028739826, 3.3377386579898194`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}}], 
      LineBox[{{5.680717028739826, 3.3377386579898194`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}], 
      LineBox[{{5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}], 
      LineBox[{{5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}], 
      LineBox[{{5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}], 
      LineBox[{{5.908862013664058, 3.206019089529551}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.908862013664058, 3.206019089529551}, {5.908862013664058, 
       3.206019089529551}}], 
      LineBox[{{5.908862013664058, 3.206019089529551}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.908862013664058, 3.206019089529551}, {5.908862013664058, 
       3.206019089529551}}], 
      LineBox[{{5.908862013664058, 3.206019089529551}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.908862013664058, 3.206019089529551}, {5.908862013664058, 
       3.206019089529551}}], 
      LineBox[{{5.908862013664058, 3.206019089529551}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.908862013664058, 3.206019089529551}, {5.908862013664058, 
       3.206019089529551}}], 
      LineBox[{{5.865838321825984, 3.16613761318721}, {5.809788104254051, 
       3.1488187412620143`}, {5.809788104254051, 3.1488187412620143`}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}}], 
      LineBox[{{5.865838321825984, 3.16613761318721}, {5.809788104254051, 
       3.1488187412620143`}, {5.809788104254051, 3.1488187412620143`}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}}], 
      LineBox[{{5.865838321825984, 3.16613761318721}, {5.809788104254051, 
       3.1488187412620143`}, {5.809788104254051, 3.1488187412620143`}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}}], 
      LineBox[{{5.865838321825984, 3.16613761318721}, {5.809788104254051, 
       3.1488187412620143`}, {5.809788104254051, 3.1488187412620143`}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}}], 
      LineBox[{{5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}}], 
      LineBox[{{5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}}], 
      LineBox[{{5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}}], 
      LineBox[{{5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}], 
      LineBox[{{5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}], 
      LineBox[{{5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}], 
      LineBox[{{5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}], 
      LineBox[{{5.809788104254051, 3.4122578781825514`}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}}], 
      LineBox[{{5.809788104254051, 3.4122578781825514`}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}}], 
      LineBox[{{5.809788104254051, 3.4122578781825514`}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}}], 
      LineBox[{{5.809788104254051, 3.4122578781825514`}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}}], 
      LineBox[{{5.865838321825984, 3.394939006257356}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}], 
      LineBox[{{5.865838321825984, 3.394939006257356}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}], 
      LineBox[{{5.865838321825984, 3.394939006257356}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}], 
      LineBox[{{5.865838321825984, 3.394939006257356}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}], 
      LineBox[{{5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.908862013664058, 
       3.355057529915015}}], 
      LineBox[{{5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.908862013664058, 
       3.355057529915015}}], 
      LineBox[{{5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.908862013664058, 
       3.355057529915015}}], 
      LineBox[{{5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.908862013664058, 
       3.355057529915015}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.694608372808513, 3.6104560912330017`}, {5.624622011390266, 
       3.6859565972995236`}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.8369576094325684`}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}, {
       5.624622011390266, 3.8369576094325684`}, {5.607427897805593, 
       3.761457103366046}, {5.624622011390266, 3.6859565972995236`}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.86896932281435, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.86896932281435, 
       3.6104560912330017`}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.86896932281435, 3.9124581154990903`}, {
       5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.86896932281435, 
       3.9124581154990903`}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.694608372808513, 3.6104560912330017`}, {5.624622011390266, 
       3.6859565972995236`}, {5.624622011390266, 3.6859565972995236`}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}}], 
      LineBox[{{5.694608372808513, 3.6104560912330017`}, {5.624622011390266, 
       3.6859565972995236`}, {5.624622011390266, 3.6859565972995236`}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}}], 
      LineBox[{{5.694608372808513, 3.6104560912330017`}, {5.624622011390266, 
       3.6859565972995236`}, {5.624622011390266, 3.6859565972995236`}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}}], 
      LineBox[{{5.694608372808513, 3.6104560912330017`}, {5.624622011390266, 
       3.6859565972995236`}, {5.624622011390266, 3.6859565972995236`}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}}], 
      LineBox[{{5.624622011390266, 3.6859565972995236`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}}], 
      LineBox[{{5.624622011390266, 3.6859565972995236`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}}], 
      LineBox[{{5.624622011390266, 3.6859565972995236`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}}], 
      LineBox[{{5.624622011390266, 3.6859565972995236`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}}], 
      LineBox[{{5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}], 
      LineBox[{{5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}], 
      LineBox[{{5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}], 
      LineBox[{{5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}], 
      LineBox[{{5.624622011390266, 3.8369576094325684`}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}}], 
      LineBox[{{5.624622011390266, 3.8369576094325684`}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}}], 
      LineBox[{{5.624622011390266, 3.8369576094325684`}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}}], 
      LineBox[{{5.624622011390266, 3.8369576094325684`}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}], 
      LineBox[{{5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}], 
      LineBox[{{5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}], 
      LineBox[{{5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}], 
      LineBox[{{5.925757622274204, 3.663096883426144}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.925757622274204, 3.663096883426144}, {5.925757622274204, 
       3.663096883426144}}], 
      LineBox[{{5.925757622274204, 3.663096883426144}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.925757622274204, 3.663096883426144}, {5.925757622274204, 
       3.663096883426144}}], 
      LineBox[{{5.925757622274204, 3.663096883426144}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.925757622274204, 3.663096883426144}, {5.925757622274204, 
       3.663096883426144}}], 
      LineBox[{{5.925757622274204, 3.663096883426144}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.925757622274204, 3.663096883426144}, {5.925757622274204, 
       3.663096883426144}}], 
      LineBox[{{5.86896932281435, 3.6104560912330017`}, {5.794986909769825, 
       3.587596377359622}, {5.794986909769825, 3.587596377359622}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}}], 
      LineBox[{{5.86896932281435, 3.6104560912330017`}, {5.794986909769825, 
       3.587596377359622}, {5.794986909769825, 3.587596377359622}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}}], 
      LineBox[{{5.86896932281435, 3.6104560912330017`}, {5.794986909769825, 
       3.587596377359622}, {5.794986909769825, 3.587596377359622}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}}], 
      LineBox[{{5.86896932281435, 3.6104560912330017`}, {5.794986909769825, 
       3.587596377359622}, {5.794986909769825, 3.587596377359622}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}}], 
      LineBox[{{5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}}], 
      LineBox[{{5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}}], 
      LineBox[{{5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}}], 
      LineBox[{{5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}], 
      LineBox[{{5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}], 
      LineBox[{{5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}], 
      LineBox[{{5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}], 
      LineBox[{{5.794986909769825, 3.93531782937247}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}}], 
      LineBox[{{5.794986909769825, 3.93531782937247}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}}], 
      LineBox[{{5.794986909769825, 3.93531782937247}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}}], 
      LineBox[{{5.794986909769825, 3.93531782937247}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}}], 
      LineBox[{{5.86896932281435, 3.9124581154990903`}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}], 
      LineBox[{{5.86896932281435, 3.9124581154990903`}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}], 
      LineBox[{{5.86896932281435, 3.9124581154990903`}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}], 
      LineBox[{{5.86896932281435, 3.9124581154990903`}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}], 
      LineBox[{{5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.925757622274204, 
       3.859817323305948}}], 
      LineBox[{{5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.925757622274204, 
       3.859817323305948}}], 
      LineBox[{{5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.925757622274204, 
       3.859817323305948}}], 
      LineBox[{{5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.925757622274204, 
       3.859817323305948}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}], 
      LineBox[{{5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}], 
      LineBox[{{5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}], 
      LineBox[{{5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}], 
      LineBox[{{5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}], 
      LineBox[{{5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}], 
      LineBox[{{5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}], 
      LineBox[{{5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}], 
      LineBox[{{5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}], 
      LineBox[{{5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}], 
      LineBox[{{5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}], 
      LineBox[{{5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}], 
      LineBox[{{5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}], 
      LineBox[{{5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}], 
      LineBox[{{5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}], 
      LineBox[{{5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}], 
      LineBox[{{6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}], 
      LineBox[{{6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}], 
      LineBox[{{6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}], 
      LineBox[{{6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}], 
      LineBox[{{6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}], 
      LineBox[{{6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}], 
      LineBox[{{6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}], 
      LineBox[{{6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}], 
      LineBox[{{6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}], 
      LineBox[{{6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}], 
      LineBox[{{6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}], 
      LineBox[{{5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}], 
      LineBox[{{5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}], 
      LineBox[{{5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}], 
      LineBox[{{5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}], 
      LineBox[{{5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}], 
      LineBox[{{5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}], 
      LineBox[{{5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}], 
      LineBox[{{5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}], 
      LineBox[{{5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}], 
      LineBox[{{5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}], 
      LineBox[{{5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}], 
      LineBox[{{6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}], 
      LineBox[{{6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}], 
      LineBox[{{6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}], 
      LineBox[{{6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}], 
      LineBox[{{6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}], 
      LineBox[{{6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}], 
      LineBox[{{6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}], 
      LineBox[{{6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.894017592219742, -3.8507944434571098`}, {
       5.894017592219742, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}], 
      LineBox[{{5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}], 
      LineBox[{{5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}], 
      LineBox[{{5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}], 
      LineBox[{{5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}], 
      LineBox[{{5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}], 
      LineBox[{{5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}], 
      LineBox[{{5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}], 
      LineBox[{{5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}], 
      LineBox[{{5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}], 
      LineBox[{{5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}], 
      LineBox[{{5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}], 
      LineBox[{{5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}], 
      LineBox[{{5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}], 
      LineBox[{{5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}], 
      LineBox[{{5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}], 
      LineBox[{{6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}], 
      LineBox[{{6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}], 
      LineBox[{{6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}], 
      LineBox[{{6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}], 
      LineBox[{{6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}], 
      LineBox[{{6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}], 
      LineBox[{{6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}], 
      LineBox[{{6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}], 
      LineBox[{{6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}], 
      LineBox[{{6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}], 
      LineBox[{{6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}], 
      LineBox[{{5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}], 
      LineBox[{{5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}], 
      LineBox[{{5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}], 
      LineBox[{{5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}], 
      LineBox[{{5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}], 
      LineBox[{{5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}], 
      LineBox[{{5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}], 
      LineBox[{{5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}], 
      LineBox[{{5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}], 
      LineBox[{{5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}], 
      LineBox[{{5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}], 
      LineBox[{{6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}], 
      LineBox[{{6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}], 
      LineBox[{{6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}], 
      LineBox[{{6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}], 
      LineBox[{{6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}], 
      LineBox[{{6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}], 
      LineBox[{{6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}], 
      LineBox[{{6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}], 
      LineBox[{{5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}], 
      LineBox[{{5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}], 
      LineBox[{{5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}], 
      LineBox[{{5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}], 
      LineBox[{{5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}], 
      LineBox[{{5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}], 
      LineBox[{{5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}], 
      LineBox[{{5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}], 
      LineBox[{{5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}], 
      LineBox[{{5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}], 
      LineBox[{{5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}], 
      LineBox[{{5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}], 
      LineBox[{{5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}], 
      LineBox[{{5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}], 
      LineBox[{{5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}], 
      LineBox[{{6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}], 
      LineBox[{{6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}], 
      LineBox[{{6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}], 
      LineBox[{{6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}], 
      LineBox[{{6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}], 
      LineBox[{{6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}], 
      LineBox[{{6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}], 
      LineBox[{{6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}], 
      LineBox[{{6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}], 
      LineBox[{{6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}], 
      LineBox[{{6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}], 
      LineBox[{{6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}], 
      LineBox[{{6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}], 
      LineBox[{{6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}], 
      LineBox[{{6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}], 
      LineBox[{{5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}], 
      LineBox[{{5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}], 
      LineBox[{{5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}], 
      LineBox[{{6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}], 
      LineBox[{{6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}], 
      LineBox[{{6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}], 
      LineBox[{{6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}], 
      LineBox[{{6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}], 
      LineBox[{{6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}], 
      LineBox[{{6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}], 
      LineBox[{{6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}], 
      LineBox[{{6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}], 
      LineBox[{{6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}], 
      LineBox[{{6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}], 
      LineBox[{{6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}], 
      LineBox[{{5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}], 
      LineBox[{{5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}], 
      LineBox[{{5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}], 
      LineBox[{{5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}], 
      LineBox[{{5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}], 
      LineBox[{{5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}], 
      LineBox[{{5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}], 
      LineBox[{{5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}], 
      LineBox[{{5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}], 
      LineBox[{{5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}], 
      LineBox[{{5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}], 
      LineBox[{{5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}], 
      LineBox[{{5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}], 
      LineBox[{{5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}], 
      LineBox[{{5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}], 
      LineBox[{{6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}], 
      LineBox[{{6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}], 
      LineBox[{{6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}], 
      LineBox[{{6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}], 
      LineBox[{{6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}], 
      LineBox[{{6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}], 
      LineBox[{{6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}], 
      LineBox[{{6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}], 
      LineBox[{{6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}], 
      LineBox[{{6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}], 
      LineBox[{{6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}], 
      LineBox[{{6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}], 
      LineBox[{{6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}], 
      LineBox[{{6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}], 
      LineBox[{{6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}], 
      LineBox[{{5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}], 
      LineBox[{{5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}], 
      LineBox[{{5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}], 
      LineBox[{{6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}], 
      LineBox[{{6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}], 
      LineBox[{{6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}], 
      LineBox[{{6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}], 
      LineBox[{{6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}], 
      LineBox[{{6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}], 
      LineBox[{{6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}], 
      LineBox[{{6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}], 
      LineBox[{{6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}], 
      LineBox[{{6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}], 
      LineBox[{{6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}], 
      LineBox[{{6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}], 
      LineBox[{{5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}], 
      LineBox[{{5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}], 
      LineBox[{{5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}], 
      LineBox[{{5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}], 
      LineBox[{{5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}], 
      LineBox[{{5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}], 
      LineBox[{{5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}], 
      LineBox[{{5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}], 
      LineBox[{{5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}], 
      LineBox[{{5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}], 
      LineBox[{{5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}], 
      LineBox[{{5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}], 
      LineBox[{{5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}], 
      LineBox[{{5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}], 
      LineBox[{{5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}], 
      LineBox[{{6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}], 
      LineBox[{{6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}], 
      LineBox[{{6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}], 
      LineBox[{{6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}], 
      LineBox[{{6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}], 
      LineBox[{{6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}], 
      LineBox[{{6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}], 
      LineBox[{{6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}], 
      LineBox[{{6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}], 
      LineBox[{{6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}], 
      LineBox[{{6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}], 
      LineBox[{{6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}], 
      LineBox[{{6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}], 
      LineBox[{{6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}], 
      LineBox[{{6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}], 
      LineBox[{{5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}], 
      LineBox[{{5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}], 
      LineBox[{{5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}], 
      LineBox[{{6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}], 
      LineBox[{{6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}], 
      LineBox[{{6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}], 
      LineBox[{{6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}], 
      LineBox[{{6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}], 
      LineBox[{{6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}], 
      LineBox[{{6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}], 
      LineBox[{{6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}], 
      LineBox[{{6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}], 
      LineBox[{{6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}], 
      LineBox[{{6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}], 
      LineBox[{{6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.0186886122810392`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}], 
      LineBox[{{5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}], 
      LineBox[{{5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}], 
      LineBox[{{5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}], 
      LineBox[{{5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}], 
      LineBox[{{5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}], 
      LineBox[{{5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}], 
      LineBox[{{5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}], 
      LineBox[{{5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}], 
      LineBox[{{5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}], 
      LineBox[{{5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}], 
      LineBox[{{5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}], 
      LineBox[{{5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}], 
      LineBox[{{5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}], 
      LineBox[{{5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}], 
      LineBox[{{5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}], 
      LineBox[{{6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}], 
      LineBox[{{6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}], 
      LineBox[{{6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}], 
      LineBox[{{6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}], 
      LineBox[{{6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}], 
      LineBox[{{6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}], 
      LineBox[{{6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}], 
      LineBox[{{6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}], 
      LineBox[{{6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}], 
      LineBox[{{6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}], 
      LineBox[{{6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}], 
      LineBox[{{6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}], 
      LineBox[{{6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}], 
      LineBox[{{6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}], 
      LineBox[{{6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}], 
      LineBox[{{5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}], 
      LineBox[{{5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}], 
      LineBox[{{5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}], 
      LineBox[{{6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}], 
      LineBox[{{6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}], 
      LineBox[{{6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}], 
      LineBox[{{6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}], 
      LineBox[{{6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}], 
      LineBox[{{6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}], 
      LineBox[{{6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}], 
      LineBox[{{6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}], 
      LineBox[{{6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}], 
      LineBox[{{6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}], 
      LineBox[{{6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}], 
      LineBox[{{6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}], 
      LineBox[{{5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}], 
      LineBox[{{5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}], 
      LineBox[{{5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}], 
      LineBox[{{5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}], 
      LineBox[{{5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}], 
      LineBox[{{5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}], 
      LineBox[{{5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}], 
      LineBox[{{5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}], 
      LineBox[{{5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}], 
      LineBox[{{5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}], 
      LineBox[{{5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}], 
      LineBox[{{5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}], 
      LineBox[{{5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}], 
      LineBox[{{5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}], 
      LineBox[{{5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}], 
      LineBox[{{6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}], 
      LineBox[{{6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}], 
      LineBox[{{6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}], 
      LineBox[{{6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}], 
      LineBox[{{6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}], 
      LineBox[{{6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}], 
      LineBox[{{6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}], 
      LineBox[{{6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}], 
      LineBox[{{6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}], 
      LineBox[{{6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}], 
      LineBox[{{6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}], 
      LineBox[{{5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}], 
      LineBox[{{5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}], 
      LineBox[{{5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}], 
      LineBox[{{5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}], 
      LineBox[{{5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}], 
      LineBox[{{5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}], 
      LineBox[{{5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}], 
      LineBox[{{5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}], 
      LineBox[{{5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}], 
      LineBox[{{5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}], 
      LineBox[{{5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}], 
      LineBox[{{6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}], 
      LineBox[{{6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}], 
      LineBox[{{6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}], 
      LineBox[{{6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}], 
      LineBox[{{6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}], 
      LineBox[{{6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}], 
      LineBox[{{6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}], 
      LineBox[{{6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268429}, {
       5.949201054112538, -0.8547672606268429}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}], 
      LineBox[{{5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}], 
      LineBox[{{5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}], 
      LineBox[{{5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}], 
      LineBox[{{5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}], 
      LineBox[{{5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}], 
      LineBox[{{5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}], 
      LineBox[{{5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}], 
      LineBox[{{5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}], 
      LineBox[{{5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}], 
      LineBox[{{5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}], 
      LineBox[{{5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}], 
      LineBox[{{5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}], 
      LineBox[{{5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}], 
      LineBox[{{5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}], 
      LineBox[{{5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}], 
      LineBox[{{6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}], 
      LineBox[{{6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}], 
      LineBox[{{6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}], 
      LineBox[{{6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}], 
      LineBox[{{6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}], 
      LineBox[{{6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}], 
      LineBox[{{6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}], 
      LineBox[{{6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}], 
      LineBox[{{6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}], 
      LineBox[{{6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}], 
      LineBox[{{6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}], 
      LineBox[{{6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}], 
      LineBox[{{6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}], 
      LineBox[{{6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}], 
      LineBox[{{6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}], 
      LineBox[{{5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}], 
      LineBox[{{5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}], 
      LineBox[{{5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}], 
      LineBox[{{6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}], 
      LineBox[{{6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}], 
      LineBox[{{6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}], 
      LineBox[{{6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}], 
      LineBox[{{6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}], 
      LineBox[{{6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}], 
      LineBox[{{6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}], 
      LineBox[{{6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}], 
      LineBox[{{6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}], 
      LineBox[{{6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}], 
      LineBox[{{6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}], 
      LineBox[{{6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.3683182130957874}, {
       5.887887880466244, -0.3683182130957874}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}], 
      LineBox[{{5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}], 
      LineBox[{{5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}], 
      LineBox[{{5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}], 
      LineBox[{{5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}], 
      LineBox[{{5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}], 
      LineBox[{{5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}], 
      LineBox[{{5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}], 
      LineBox[{{5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}], 
      LineBox[{{5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}], 
      LineBox[{{5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}], 
      LineBox[{{5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}], 
      LineBox[{{5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}], 
      LineBox[{{5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}], 
      LineBox[{{5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}], 
      LineBox[{{5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}], 
      LineBox[{{6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}], 
      LineBox[{{6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}], 
      LineBox[{{6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}], 
      LineBox[{{6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}], 
      LineBox[{{6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}], 
      LineBox[{{6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}], 
      LineBox[{{6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}], 
      LineBox[{{6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}], 
      LineBox[{{6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}], 
      LineBox[{{6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}], 
      LineBox[{{6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}], 
      LineBox[{{5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}], 
      LineBox[{{5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}], 
      LineBox[{{5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}], 
      LineBox[{{5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}], 
      LineBox[{{5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}], 
      LineBox[{{5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}], 
      LineBox[{{5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}], 
      LineBox[{{5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}], 
      LineBox[{{5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}], 
      LineBox[{{5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}], 
      LineBox[{{5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}], 
      LineBox[{{6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}], 
      LineBox[{{6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}], 
      LineBox[{{6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}], 
      LineBox[{{6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}], 
      LineBox[{{6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}], 
      LineBox[{{6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}], 
      LineBox[{{6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}], 
      LineBox[{{6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, 0.09524424099391537}, {
       5.937816157286512, 0.1705497532096615}, {5.937816157286512, 
       0.1705497532096615}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, -0.05536678343757695}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.850860841788064, 0.019938728778169212`}, {5.850860841788064,
        0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.1306722956533231}, {
       5.937816157286512, -0.1306722956533231}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.937816157286512, 0.17054975320966154`}, {6.037935448337073, 
       0.19335042769551855`}, {6.1117267882834065`, 0.1705497532096615}, {
       6.168368421584745, 0.1180449154797724}, {6.198682103781854, 
       0.019938728778169233`}, {6.198682103781854, 0.019938728778169233`}, {
       6.168368421584745, 0.1180449154797724}, {6.1117267882834065`, 
       0.1705497532096615}, {6.037935448337073, 0.19335042769551855`}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}], 
      LineBox[{{5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}], 
      LineBox[{{5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}], 
      LineBox[{{5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}], 
      LineBox[{{5.868010548433059, -0.055366783437576936`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}], 
      LineBox[{{5.868010548433059, -0.055366783437576936`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}], 
      LineBox[{{5.868010548433059, -0.055366783437576936`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}], 
      LineBox[{{5.868010548433059, -0.055366783437576936`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}], 
      LineBox[{{5.850860841788064, 0.019938728778169212`}, {5.868010548433059,
        0.09524424099391536}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}}], 
      LineBox[{{5.850860841788064, 0.019938728778169212`}, {5.868010548433059,
        0.09524424099391536}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}}], 
      LineBox[{{5.850860841788064, 0.019938728778169212`}, {5.868010548433059,
        0.09524424099391536}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}}], 
      LineBox[{{5.850860841788064, 0.019938728778169212`}, {5.868010548433059,
        0.09524424099391536}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}}], 
      LineBox[{{5.868010548433059, 0.09524424099391537}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}, {
       5.868010548433059, 0.09524424099391537}, {5.868010548433059, 
       0.09524424099391537}}], 
      LineBox[{{5.868010548433059, 0.09524424099391537}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}, {
       5.868010548433059, 0.09524424099391537}, {5.868010548433059, 
       0.09524424099391537}}], 
      LineBox[{{5.868010548433059, 0.09524424099391537}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}, {
       5.868010548433059, 0.09524424099391537}, {5.868010548433059, 
       0.09524424099391537}}], 
      LineBox[{{5.868010548433059, 0.09524424099391537}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}, {
       5.868010548433059, 0.09524424099391537}, {5.868010548433059, 
       0.09524424099391537}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}], 
      LineBox[{{6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}], 
      LineBox[{{6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}], 
      LineBox[{{6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}], 
      LineBox[{{6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}], 
      LineBox[{{6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}], 
      LineBox[{{6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}], 
      LineBox[{{6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}], 
      LineBox[{{6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}], 
      LineBox[{{6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}], 
      LineBox[{{6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}], 
      LineBox[{{6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}], 
      LineBox[{{6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}], 
      LineBox[{{6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}], 
      LineBox[{{6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}], 
      LineBox[{{6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.937816157286512, 0.17054975320966154`}, {6.037935448337073, 
       0.19335042769551855`}, {6.037935448337073, 0.19335042769551855`}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}}], 
      LineBox[{{5.937816157286512, 0.17054975320966154`}, {6.037935448337073, 
       0.19335042769551855`}, {6.037935448337073, 0.19335042769551855`}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}}], 
      LineBox[{{5.937816157286512, 0.17054975320966154`}, {6.037935448337073, 
       0.19335042769551855`}, {6.037935448337073, 0.19335042769551855`}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}}], 
      LineBox[{{5.937816157286512, 0.17054975320966154`}, {6.037935448337073, 
       0.19335042769551855`}, {6.037935448337073, 0.19335042769551855`}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}}], 
      LineBox[{{6.037935448337073, 0.19335042769551855`}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}}], 
      LineBox[{{6.037935448337073, 0.19335042769551855`}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}}], 
      LineBox[{{6.037935448337073, 0.19335042769551855`}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}}], 
      LineBox[{{6.037935448337073, 0.19335042769551855`}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}}], 
      LineBox[{{6.1117267882834065`, 0.1705497532096615}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}}], 
      LineBox[{{6.1117267882834065`, 0.1705497532096615}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}}], 
      LineBox[{{6.1117267882834065`, 0.1705497532096615}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}}], 
      LineBox[{{6.1117267882834065`, 0.1705497532096615}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}}], 
      LineBox[{{6.168368421584745, 0.1180449154797724}, {6.198682103781854, 
       0.019938728778169185`}, {6.198682103781854, 0.019938728778169185`}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}}], 
      LineBox[{{6.168368421584745, 0.1180449154797724}, {6.198682103781854, 
       0.019938728778169185`}, {6.198682103781854, 0.019938728778169185`}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}}], 
      LineBox[{{6.168368421584745, 0.1180449154797724}, {6.198682103781854, 
       0.019938728778169185`}, {6.198682103781854, 0.019938728778169185`}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}}], 
      LineBox[{{6.168368421584745, 0.1180449154797724}, {6.198682103781854, 
       0.019938728778169185`}, {6.198682103781854, 0.019938728778169185`}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.804316508840108, 
       0.5339415044172112}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.031489878738242, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {6.031489878738242, 
       0.40278289815380874`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.880040965472819, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {6.031489878738242, 0.6651001106806137}, {
       6.0808158673790365`, 0.6193766228766331}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.6193766228766331}, {6.031489878738242, 
       0.6651001106806137}, {5.9672291824299695`, 0.6849559260083343}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}], 
      LineBox[{{5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}], 
      LineBox[{{5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}], 
      LineBox[{{5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}], 
      LineBox[{{5.819251216507586, 0.46836220128551}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.46836220128551}, {5.819251216507586, 
       0.46836220128551}}], 
      LineBox[{{5.819251216507586, 0.46836220128551}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.46836220128551}, {5.819251216507586, 
       0.46836220128551}}], 
      LineBox[{{5.819251216507586, 0.46836220128551}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.46836220128551}, {5.819251216507586, 
       0.46836220128551}}], 
      LineBox[{{5.819251216507586, 0.46836220128551}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.46836220128551}, {5.819251216507586, 
       0.46836220128551}}], 
      LineBox[{{5.804316508840108, 0.5339415044172112}, {5.819251216507586, 
       0.5995208075489125}, {5.819251216507586, 0.5995208075489125}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}}], 
      LineBox[{{5.804316508840108, 0.5339415044172112}, {5.819251216507586, 
       0.5995208075489125}, {5.819251216507586, 0.5995208075489125}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}}], 
      LineBox[{{5.804316508840108, 0.5339415044172112}, {5.819251216507586, 
       0.5995208075489125}, {5.819251216507586, 0.5995208075489125}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}}], 
      LineBox[{{5.804316508840108, 0.5339415044172112}, {5.819251216507586, 
       0.5995208075489125}, {5.819251216507586, 0.5995208075489125}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}}], 
      LineBox[{{5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}}], 
      LineBox[{{5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}}], 
      LineBox[{{5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}}], 
      LineBox[{{5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}}], 
      LineBox[{{6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}}], 
      LineBox[{{6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}}], 
      LineBox[{{6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}}], 
      LineBox[{{6.0808158673790365`, 0.44850638595778936`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.0808158673790365`, 0.44850638595778936`}}], 
      LineBox[{{6.0808158673790365`, 0.44850638595778936`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.0808158673790365`, 0.44850638595778936`}}], 
      LineBox[{{6.0808158673790365`, 0.44850638595778936`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.0808158673790365`, 0.44850638595778936`}}], 
      LineBox[{{6.0808158673790365`, 0.44850638595778936`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.0808158673790365`, 0.44850638595778936`}}], 
      LineBox[{{6.031489878738242, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}}], 
      LineBox[{{6.031489878738242, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}}], 
      LineBox[{{6.031489878738242, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}}], 
      LineBox[{{6.031489878738242, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}}], 
      LineBox[{{5.9672291824299695`, 0.3829270828260881}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}}], 
      LineBox[{{5.9672291824299695`, 0.3829270828260881}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}}], 
      LineBox[{{5.9672291824299695`, 0.3829270828260881}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}}], 
      LineBox[{{5.9672291824299695`, 0.3829270828260881}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.880040965472819, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.9672291824299695`, 0.6849559260083343}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}}], 
      LineBox[{{5.880040965472819, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.9672291824299695`, 0.6849559260083343}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}}], 
      LineBox[{{5.880040965472819, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.9672291824299695`, 0.6849559260083343}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}}], 
      LineBox[{{5.880040965472819, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.9672291824299695`, 0.6849559260083343}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}}], 
      LineBox[{{5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}}], 
      LineBox[{{5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}}], 
      LineBox[{{5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}}], 
      LineBox[{{5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}}], 
      LineBox[{{6.031489878738242, 0.6651001106806137}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}}], 
      LineBox[{{6.031489878738242, 0.6651001106806137}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}}], 
      LineBox[{{6.031489878738242, 0.6651001106806137}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}}], 
      LineBox[{{6.031489878738242, 0.6651001106806137}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}}], 
      LineBox[{{6.0808158673790365`, 0.6193766228766331}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}}], 
      LineBox[{{6.0808158673790365`, 0.6193766228766331}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}}], 
      LineBox[{{6.0808158673790365`, 0.6193766228766331}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}}], 
      LineBox[{{6.0808158673790365`, 0.6193766228766331}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`, 
       1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258065`}, {5.8756536577236975`, 
       0.9584816254121231}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.210311592223357, 0.9584816254121231}, {6.181145134103425, 
       0.8640882763253076}, {6.126647108598442, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.126647108598442, 
       0.8135704889847561}, {6.181145134103426, 0.8640882763253076}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.9593181413486125`, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.126647108598442, 1.10339276183949}, {
       6.181145134103426, 1.0528749744989385`}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}, {
       6.181145134103425, 1.0528749744989385`}, {6.126647108598442, 
       1.10339276183949}, {6.055648408666054, 1.1253305427126221`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}], 
      LineBox[{{5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}], 
      LineBox[{{5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}], 
      LineBox[{{5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}], 
      LineBox[{{5.892154332151104, 0.8860260571984396}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 0.8860260571984396}, {5.892154332151104, 
       0.8860260571984396}}], 
      LineBox[{{5.892154332151104, 0.8860260571984396}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 0.8860260571984396}, {5.892154332151104, 
       0.8860260571984396}}], 
      LineBox[{{5.892154332151104, 0.8860260571984396}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 0.8860260571984396}, {5.892154332151104, 
       0.8860260571984396}}], 
      LineBox[{{5.892154332151104, 0.8860260571984396}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 0.8860260571984396}, {5.892154332151104, 
       0.8860260571984396}}], 
      LineBox[{{5.8756536577236975`, 0.9584816254121231}, {5.892154332151104, 
       1.0309371936258065`}, {5.892154332151104, 1.0309371936258065`}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}}], 
      LineBox[{{5.8756536577236975`, 0.9584816254121231}, {5.892154332151104, 
       1.0309371936258065`}, {5.892154332151104, 1.0309371936258065`}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}}], 
      LineBox[{{5.8756536577236975`, 0.9584816254121231}, {5.892154332151104, 
       1.0309371936258065`}, {5.892154332151104, 1.0309371936258065`}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}}], 
      LineBox[{{5.8756536577236975`, 0.9584816254121231}, {5.892154332151104, 
       1.0309371936258065`}, {5.892154332151104, 1.0309371936258065`}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}}], 
      LineBox[{{5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`,
        1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258067`}, {5.892154332151104, 
       1.0309371936258067`}}], 
      LineBox[{{5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`,
        1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258067`}, {5.892154332151104, 
       1.0309371936258067`}}], 
      LineBox[{{5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`,
        1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258067`}, {5.892154332151104, 
       1.0309371936258067`}}], 
      LineBox[{{5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`,
        1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258067`}, {5.892154332151104, 
       1.0309371936258067`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.210311592223357, 0.9584816254121231}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}}], 
      LineBox[{{6.210311592223357, 0.9584816254121231}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}}], 
      LineBox[{{6.210311592223357, 0.9584816254121231}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}}], 
      LineBox[{{6.210311592223357, 0.9584816254121231}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}}], 
      LineBox[{{6.181145134103425, 0.8640882763253076}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}}], 
      LineBox[{{6.181145134103425, 0.8640882763253076}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}}], 
      LineBox[{{6.181145134103425, 0.8640882763253076}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}}], 
      LineBox[{{6.181145134103425, 0.8640882763253076}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}}], 
      LineBox[{{6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}], 
      LineBox[{{6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}], 
      LineBox[{{6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}], 
      LineBox[{{6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}], 
      LineBox[{{6.055648408666054, 0.7916327081116241}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.055648408666054, 
       0.7916327081116241}}], 
      LineBox[{{6.055648408666054, 0.7916327081116241}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.055648408666054, 
       0.7916327081116241}}], 
      LineBox[{{6.055648408666054, 0.7916327081116241}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.055648408666054, 
       0.7916327081116241}}], 
      LineBox[{{6.055648408666054, 0.7916327081116241}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.055648408666054, 
       0.7916327081116241}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.9593181413486125`, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.055648408666054, 1.1253305427126221`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}}], 
      LineBox[{{5.9593181413486125`, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.055648408666054, 1.1253305427126221`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}}], 
      LineBox[{{5.9593181413486125`, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.055648408666054, 1.1253305427126221`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}}], 
      LineBox[{{5.9593181413486125`, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.055648408666054, 1.1253305427126221`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}}], 
      LineBox[{{6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}}], 
      LineBox[{{6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}}], 
      LineBox[{{6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}}], 
      LineBox[{{6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}}], 
      LineBox[{{6.126647108598442, 1.10339276183949}, {6.181145134103425, 
       1.0528749744989385`}, {6.181145134103425, 1.0528749744989385`}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}}], 
      LineBox[{{6.126647108598442, 1.10339276183949}, {6.181145134103425, 
       1.0528749744989385`}, {6.181145134103425, 1.0528749744989385`}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}}], 
      LineBox[{{6.126647108598442, 1.10339276183949}, {6.181145134103425, 
       1.0528749744989385`}, {6.181145134103425, 1.0528749744989385`}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}}], 
      LineBox[{{6.126647108598442, 1.10339276183949}, {6.181145134103425, 
       1.0528749744989385`}, {6.181145134103425, 1.0528749744989385`}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}}], 
      LineBox[{{6.181145134103426, 1.0528749744989385`}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}, {
       6.181145134103426, 1.0528749744989385`}, {6.181145134103426, 
       1.0528749744989385`}}], 
      LineBox[{{6.181145134103426, 1.0528749744989385`}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}, {
       6.181145134103426, 1.0528749744989385`}, {6.181145134103426, 
       1.0528749744989385`}}], 
      LineBox[{{6.181145134103426, 1.0528749744989385`}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}, {
       6.181145134103426, 1.0528749744989385`}, {6.181145134103426, 
       1.0528749744989385`}}], 
      LineBox[{{6.181145134103426, 1.0528749744989385`}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}, {
       6.181145134103426, 1.0528749744989385`}, {6.181145134103426, 
       1.0528749744989385`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.5895514865834939`}, {5.941490844175088, 
       1.6574462175794573`}, {5.941490844175088, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.863092761740935, 
       1.5216567555875307`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`,
        1.4332051541156223`}, {6.098287009043395, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {5.941490844175089, 
       1.385867293595604}, {5.941490844175089, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.098287009043395, 
       1.385867293595604}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.941490844175089, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.098287009043395, 1.6574462175794573`}, {
       6.1493545649634545`, 1.610108357059439}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.610108357059439}, {6.098287009043395, 
       1.6574462175794573`}, {6.031757441312225, 1.6780030880554022`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}], 
      LineBox[{{5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}], 
      LineBox[{{5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}], 
      LineBox[{{5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}], 
      LineBox[{{5.878554773552046, 1.4537620245915674`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.4537620245915674`}, {5.878554773552046, 
       1.4537620245915674`}}], 
      LineBox[{{5.878554773552046, 1.4537620245915674`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.4537620245915674`}, {5.878554773552046, 
       1.4537620245915674`}}], 
      LineBox[{{5.878554773552046, 1.4537620245915674`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.4537620245915674`}, {5.878554773552046, 
       1.4537620245915674`}}], 
      LineBox[{{5.878554773552046, 1.4537620245915674`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.4537620245915674`}, {5.878554773552046, 
       1.4537620245915674`}}], 
      LineBox[{{5.863092761740935, 1.5216567555875307`}, {5.878554773552046, 
       1.5895514865834939`}, {5.878554773552046, 1.5895514865834939`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}}], 
      LineBox[{{5.863092761740935, 1.5216567555875307`}, {5.878554773552046, 
       1.5895514865834939`}, {5.878554773552046, 1.5895514865834939`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}}], 
      LineBox[{{5.863092761740935, 1.5216567555875307`}, {5.878554773552046, 
       1.5895514865834939`}, {5.878554773552046, 1.5895514865834939`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}}], 
      LineBox[{{5.863092761740935, 1.5216567555875307`}, {5.878554773552046, 
       1.5895514865834939`}, {5.878554773552046, 1.5895514865834939`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}}], 
      LineBox[{{5.878554773552046, 1.5895514865834939`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}}], 
      LineBox[{{5.878554773552046, 1.5895514865834939`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}}], 
      LineBox[{{5.878554773552046, 1.5895514865834939`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}}], 
      LineBox[{{5.878554773552046, 1.5895514865834939`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`,
        1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}}], 
      LineBox[{{6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`,
        1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}}], 
      LineBox[{{6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`,
        1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}}], 
      LineBox[{{6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`,
        1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}}], 
      LineBox[{{6.1493545649634545`, 1.4332051541156223`}, {6.098287009043395,
        1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}}], 
      LineBox[{{6.1493545649634545`, 1.4332051541156223`}, {6.098287009043395,
        1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}}], 
      LineBox[{{6.1493545649634545`, 1.4332051541156223`}, {6.098287009043395,
        1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}}], 
      LineBox[{{6.1493545649634545`, 1.4332051541156223`}, {6.098287009043395,
        1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}}], 
      LineBox[{{6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}], 
      LineBox[{{6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}], 
      LineBox[{{6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}], 
      LineBox[{{6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}], 
      LineBox[{{6.031757441312225, 1.3653104231196591`}, {5.941490844175088, 
       1.385867293595604}, {5.941490844175088, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.031757441312225, 
       1.3653104231196591`}}], 
      LineBox[{{6.031757441312225, 1.3653104231196591`}, {5.941490844175088, 
       1.385867293595604}, {5.941490844175088, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.031757441312225, 
       1.3653104231196591`}}], 
      LineBox[{{6.031757441312225, 1.3653104231196591`}, {5.941490844175088, 
       1.385867293595604}, {5.941490844175088, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.031757441312225, 
       1.3653104231196591`}}], 
      LineBox[{{6.031757441312225, 1.3653104231196591`}, {5.941490844175088, 
       1.385867293595604}, {5.941490844175088, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.031757441312225, 
       1.3653104231196591`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.941490844175089, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.031757441312225, 1.6780030880554022`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}}], 
      LineBox[{{5.941490844175089, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.031757441312225, 1.6780030880554022`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}}], 
      LineBox[{{5.941490844175089, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.031757441312225, 1.6780030880554022`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}}], 
      LineBox[{{5.941490844175089, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.031757441312225, 1.6780030880554022`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}}], 
      LineBox[{{6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}}], 
      LineBox[{{6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}}], 
      LineBox[{{6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}}], 
      LineBox[{{6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}}], 
      LineBox[{{6.098287009043395, 1.6574462175794573`}, {6.1493545649634545`,
        1.610108357059439}, {6.1493545649634545`, 1.610108357059439}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}}], 
      LineBox[{{6.098287009043395, 1.6574462175794573`}, {6.1493545649634545`,
        1.610108357059439}, {6.1493545649634545`, 1.610108357059439}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}}], 
      LineBox[{{6.098287009043395, 1.6574462175794573`}, {6.1493545649634545`,
        1.610108357059439}, {6.1493545649634545`, 1.610108357059439}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}}], 
      LineBox[{{6.098287009043395, 1.6574462175794573`}, {6.1493545649634545`,
        1.610108357059439}, {6.1493545649634545`, 1.610108357059439}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}}], 
      LineBox[{{6.1493545649634545`, 1.610108357059439}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}}], 
      LineBox[{{6.1493545649634545`, 1.610108357059439}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}}], 
      LineBox[{{6.1493545649634545`, 1.610108357059439}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}}], 
      LineBox[{{6.1493545649634545`, 1.610108357059439}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.846153356070333, 
       1.9944753947482339`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       1.8958932734842866`}, {6.108284820309764, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.108284820309764, 
       1.8431337233065277`}, {6.165201234558789, 1.8958932734842866`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.93353051081681, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.108284820309764, 2.1458170661899403`}, {
       6.165201234558789, 2.0930575160121814`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 2.0930575160121814`}, {6.108284820309764, 
       2.1458170661899403`}, {6.0341355024390735`, 2.1687283517330345`}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}], 
      LineBox[{{5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}], 
      LineBox[{{5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}], 
      LineBox[{{5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}], 
      LineBox[{{5.863386259692001, 1.9188045590273808`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 1.9188045590273808`}, {5.863386259692001, 
       1.9188045590273808`}}], 
      LineBox[{{5.863386259692001, 1.9188045590273808`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 1.9188045590273808`}, {5.863386259692001, 
       1.9188045590273808`}}], 
      LineBox[{{5.863386259692001, 1.9188045590273808`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 1.9188045590273808`}, {5.863386259692001, 
       1.9188045590273808`}}], 
      LineBox[{{5.863386259692001, 1.9188045590273808`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 1.9188045590273808`}, {5.863386259692001, 
       1.9188045590273808`}}], 
      LineBox[{{5.846153356070333, 1.9944753947482339`}, {5.863386259692001, 
       2.070146230469087}, {5.863386259692001, 2.070146230469087}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}}], 
      LineBox[{{5.846153356070333, 1.9944753947482339`}, {5.863386259692001, 
       2.070146230469087}, {5.863386259692001, 2.070146230469087}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}}], 
      LineBox[{{5.846153356070333, 1.9944753947482339`}, {5.863386259692001, 
       2.070146230469087}, {5.863386259692001, 2.070146230469087}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}}], 
      LineBox[{{5.846153356070333, 1.9944753947482339`}, {5.863386259692001, 
       2.070146230469087}, {5.863386259692001, 2.070146230469087}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}}], 
      LineBox[{{5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}}], 
      LineBox[{{5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}}], 
      LineBox[{{5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}}], 
      LineBox[{{5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}}], 
      LineBox[{{6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}}], 
      LineBox[{{6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}}], 
      LineBox[{{6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}}], 
      LineBox[{{6.165201234558789, 1.8958932734842866`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}}], 
      LineBox[{{6.165201234558789, 1.8958932734842866`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}}], 
      LineBox[{{6.165201234558789, 1.8958932734842866`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}}], 
      LineBox[{{6.165201234558789, 1.8958932734842866`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}}], 
      LineBox[{{6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`,
        1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}], 
      LineBox[{{6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`,
        1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}], 
      LineBox[{{6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`,
        1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}], 
      LineBox[{{6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`,
        1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}], 
      LineBox[{{6.0341355024390735`, 1.8202224377634333`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.0341355024390735`, 
       1.8202224377634333`}}], 
      LineBox[{{6.0341355024390735`, 1.8202224377634333`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.0341355024390735`, 
       1.8202224377634333`}}], 
      LineBox[{{6.0341355024390735`, 1.8202224377634333`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.0341355024390735`, 
       1.8202224377634333`}}], 
      LineBox[{{6.0341355024390735`, 1.8202224377634333`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.0341355024390735`, 
       1.8202224377634333`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.93353051081681, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.0341355024390735`, 2.1687283517330345`}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}}], 
      LineBox[{{5.93353051081681, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.0341355024390735`, 2.1687283517330345`}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}}], 
      LineBox[{{5.93353051081681, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.0341355024390735`, 2.1687283517330345`}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}}], 
      LineBox[{{5.93353051081681, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.0341355024390735`, 2.1687283517330345`}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}}], 
      LineBox[{{6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764,
        2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}}], 
      LineBox[{{6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764,
        2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}}], 
      LineBox[{{6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764,
        2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}}], 
      LineBox[{{6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764,
        2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}}], 
      LineBox[{{6.108284820309764, 2.1458170661899403`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}}], 
      LineBox[{{6.108284820309764, 2.1458170661899403`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}}], 
      LineBox[{{6.108284820309764, 2.1458170661899403`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}}], 
      LineBox[{{6.108284820309764, 2.1458170661899403`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}}], 
      LineBox[{{6.165201234558789, 2.0930575160121814`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}}], 
      LineBox[{{6.165201234558789, 2.0930575160121814`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}}], 
      LineBox[{{6.165201234558789, 2.0930575160121814`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}}], 
      LineBox[{{6.165201234558789, 2.0930575160121814`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.882287466381099, 
       2.4880860120130475`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.393817447249806}, {6.132949113709388, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.132949113709388, 
       2.343366442452545}, {6.187375094951565, 2.393817447249806}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.965841348823862, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.132949113709388, 2.63280558157355}, {
       6.187375094951565, 2.582354576776289}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.582354576776289}, {6.132949113709388, 
       2.63280558157355}, {6.062044271287421, 2.6547143615565405`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}], 
      LineBox[{{5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}], 
      LineBox[{{5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}], 
      LineBox[{{5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}], 
      LineBox[{{5.898766327560889, 2.4157262272327964`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.4157262272327964`}, {5.898766327560889, 
       2.4157262272327964`}}], 
      LineBox[{{5.898766327560889, 2.4157262272327964`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.4157262272327964`}, {5.898766327560889, 
       2.4157262272327964`}}], 
      LineBox[{{5.898766327560889, 2.4157262272327964`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.4157262272327964`}, {5.898766327560889, 
       2.4157262272327964`}}], 
      LineBox[{{5.898766327560889, 2.4157262272327964`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.4157262272327964`}, {5.898766327560889, 
       2.4157262272327964`}}], 
      LineBox[{{5.882287466381099, 2.4880860120130475`}, {5.898766327560889, 
       2.5604457967932985`}, {5.898766327560889, 2.5604457967932985`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}}], 
      LineBox[{{5.882287466381099, 2.4880860120130475`}, {5.898766327560889, 
       2.5604457967932985`}, {5.898766327560889, 2.5604457967932985`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}}], 
      LineBox[{{5.882287466381099, 2.4880860120130475`}, {5.898766327560889, 
       2.5604457967932985`}, {5.898766327560889, 2.5604457967932985`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}}], 
      LineBox[{{5.882287466381099, 2.4880860120130475`}, {5.898766327560889, 
       2.5604457967932985`}, {5.898766327560889, 2.5604457967932985`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}}], 
      LineBox[{{5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}}], 
      LineBox[{{5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}}], 
      LineBox[{{5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}}], 
      LineBox[{{5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}}], 
      LineBox[{{6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}}], 
      LineBox[{{6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}}], 
      LineBox[{{6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}}], 
      LineBox[{{6.187375094951565, 2.393817447249806}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}}], 
      LineBox[{{6.187375094951565, 2.393817447249806}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}}], 
      LineBox[{{6.187375094951565, 2.393817447249806}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}}], 
      LineBox[{{6.187375094951565, 2.393817447249806}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}}], 
      LineBox[{{6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}], 
      LineBox[{{6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}], 
      LineBox[{{6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}], 
      LineBox[{{6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}], 
      LineBox[{{6.062044271287421, 2.3214576624695544`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.062044271287421, 
       2.3214576624695544`}}], 
      LineBox[{{6.062044271287421, 2.3214576624695544`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.062044271287421, 
       2.3214576624695544`}}], 
      LineBox[{{6.062044271287421, 2.3214576624695544`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.062044271287421, 
       2.3214576624695544`}}], 
      LineBox[{{6.062044271287421, 2.3214576624695544`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.062044271287421, 
       2.3214576624695544`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.965841348823862, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.062044271287421, 2.6547143615565405`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}}], 
      LineBox[{{5.965841348823862, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.062044271287421, 2.6547143615565405`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}}], 
      LineBox[{{5.965841348823862, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.062044271287421, 2.6547143615565405`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}}], 
      LineBox[{{5.965841348823862, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.062044271287421, 2.6547143615565405`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}}], 
      LineBox[{{6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}}], 
      LineBox[{{6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}}], 
      LineBox[{{6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}}], 
      LineBox[{{6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}}], 
      LineBox[{{6.132949113709388, 2.63280558157355}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}}], 
      LineBox[{{6.132949113709388, 2.63280558157355}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}}], 
      LineBox[{{6.132949113709388, 2.63280558157355}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}}], 
      LineBox[{{6.132949113709388, 2.63280558157355}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}}], 
      LineBox[{{6.187375094951565, 2.582354576776289}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}}], 
      LineBox[{{6.187375094951565, 2.582354576776289}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}}], 
      LineBox[{{6.187375094951565, 2.582354576776289}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}}], 
      LineBox[{{6.187375094951565, 2.582354576776289}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.821151533065186, 
       3.0407084168298297`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       2.9581682179432556`}, {6.040627264722669, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {6.040627264722669, 
       2.9139940440767917`}, {6.088281870768799, 2.9581682179432556`}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894310110284348, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {6.040627264722669, 3.1674227895828677`}, {
       6.088281870768799, 3.123248615716404}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 3.123248615716404}, {6.040627264722669, 
       3.1674227895828677`}, {5.978544004940057, 3.186605802092923}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}], 
      LineBox[{{5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}], 
      LineBox[{{5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}], 
      LineBox[{{5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}], 
      LineBox[{{5.83558018680167, 2.9773512304533107`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 2.9773512304533107`}, {5.83558018680167, 
       2.9773512304533107`}}], 
      LineBox[{{5.83558018680167, 2.9773512304533107`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 2.9773512304533107`}, {5.83558018680167, 
       2.9773512304533107`}}], 
      LineBox[{{5.83558018680167, 2.9773512304533107`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 2.9773512304533107`}, {5.83558018680167, 
       2.9773512304533107`}}], 
      LineBox[{{5.83558018680167, 2.9773512304533107`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 2.9773512304533107`}, {5.83558018680167, 
       2.9773512304533107`}}], 
      LineBox[{{5.821151533065186, 3.0407084168298297`}, {5.83558018680167, 
       3.1040656032063487`}, {5.83558018680167, 3.1040656032063487`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}}], 
      LineBox[{{5.821151533065186, 3.0407084168298297`}, {5.83558018680167, 
       3.1040656032063487`}, {5.83558018680167, 3.1040656032063487`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}}], 
      LineBox[{{5.821151533065186, 3.0407084168298297`}, {5.83558018680167, 
       3.1040656032063487`}, {5.83558018680167, 3.1040656032063487`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}}], 
      LineBox[{{5.821151533065186, 3.0407084168298297`}, {5.83558018680167, 
       3.1040656032063487`}, {5.83558018680167, 3.1040656032063487`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}}], 
      LineBox[{{5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}}], 
      LineBox[{{5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}}], 
      LineBox[{{5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}}], 
      LineBox[{{5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}}], 
      LineBox[{{6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}}], 
      LineBox[{{6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}}], 
      LineBox[{{6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}}], 
      LineBox[{{6.088281870768799, 2.9581682179432556`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}}], 
      LineBox[{{6.088281870768799, 2.9581682179432556`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}}], 
      LineBox[{{6.088281870768799, 2.9581682179432556`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}}], 
      LineBox[{{6.088281870768799, 2.9581682179432556`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}}], 
      LineBox[{{6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}], 
      LineBox[{{6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}], 
      LineBox[{{6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}], 
      LineBox[{{6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}], 
      LineBox[{{5.978544004940057, 2.8948110315667366`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.978544004940057, 
       2.8948110315667366`}}], 
      LineBox[{{5.978544004940057, 2.8948110315667366`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.978544004940057, 
       2.8948110315667366`}}], 
      LineBox[{{5.978544004940057, 2.8948110315667366`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.978544004940057, 
       2.8948110315667366`}}], 
      LineBox[{{5.978544004940057, 2.8948110315667366`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.978544004940057, 
       2.8948110315667366`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.894310110284348, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.978544004940057, 3.186605802092923}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}}], 
      LineBox[{{5.894310110284348, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.978544004940057, 3.186605802092923}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}}], 
      LineBox[{{5.894310110284348, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.978544004940057, 3.186605802092923}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}}], 
      LineBox[{{5.894310110284348, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.978544004940057, 3.186605802092923}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}}], 
      LineBox[{{5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}}], 
      LineBox[{{5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}}], 
      LineBox[{{5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}}], 
      LineBox[{{5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}}], 
      LineBox[{{6.040627264722669, 3.1674227895828677`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}}], 
      LineBox[{{6.040627264722669, 3.1674227895828677`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}}], 
      LineBox[{{6.040627264722669, 3.1674227895828677`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}}], 
      LineBox[{{6.040627264722669, 3.1674227895828677`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}}], 
      LineBox[{{6.088281870768799, 3.123248615716404}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}}], 
      LineBox[{{6.088281870768799, 3.123248615716404}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}}], 
      LineBox[{{6.088281870768799, 3.123248615716404}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}}], 
      LineBox[{{6.088281870768799, 3.123248615716404}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.847400887554275, 
       3.4741985301599154`}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.3996793099671834`}, {6.045548706374291, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {6.045548706374291, 
       3.3597978336248424`}, {6.088572398212365, 3.3996793099671834`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.91345016049428, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {6.045548706374291, 3.5885992266949884`}, {
       6.088572398212365, 3.5487177503526475`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.5487177503526475`}, {6.045548706374291, 
       3.5885992266949884`}, {5.989498488802358, 3.605918098620184}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}], 
      LineBox[{{5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}], 
      LineBox[{{5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}], 
      LineBox[{{5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}], 
      LineBox[{{5.860427413288133, 3.416998181892379}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.416998181892379}, {5.860427413288133, 
       3.416998181892379}}], 
      LineBox[{{5.860427413288133, 3.416998181892379}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.416998181892379}, {5.860427413288133, 
       3.416998181892379}}], 
      LineBox[{{5.860427413288133, 3.416998181892379}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.416998181892379}, {5.860427413288133, 
       3.416998181892379}}], 
      LineBox[{{5.860427413288133, 3.416998181892379}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.416998181892379}, {5.860427413288133, 
       3.416998181892379}}], 
      LineBox[{{5.847400887554275, 3.4741985301599154`}, {5.860427413288133, 
       3.531398878427452}, {5.860427413288133, 3.531398878427452}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}}], 
      LineBox[{{5.847400887554275, 3.4741985301599154`}, {5.860427413288133, 
       3.531398878427452}, {5.860427413288133, 3.531398878427452}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}}], 
      LineBox[{{5.847400887554275, 3.4741985301599154`}, {5.860427413288133, 
       3.531398878427452}, {5.860427413288133, 3.531398878427452}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}}], 
      LineBox[{{5.847400887554275, 3.4741985301599154`}, {5.860427413288133, 
       3.531398878427452}, {5.860427413288133, 3.531398878427452}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}}], 
      LineBox[{{5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}}], 
      LineBox[{{5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}}], 
      LineBox[{{5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}}], 
      LineBox[{{5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}}], 
      LineBox[{{6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}}], 
      LineBox[{{6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}}], 
      LineBox[{{6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}}], 
      LineBox[{{6.088572398212365, 3.3996793099671834`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}}], 
      LineBox[{{6.088572398212365, 3.3996793099671834`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}}], 
      LineBox[{{6.088572398212365, 3.3996793099671834`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}}], 
      LineBox[{{6.088572398212365, 3.3996793099671834`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}}], 
      LineBox[{{6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}], 
      LineBox[{{6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}], 
      LineBox[{{6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}], 
      LineBox[{{6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}], 
      LineBox[{{5.989498488802358, 3.342478961699647}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.989498488802358, 
       3.342478961699647}}], 
      LineBox[{{5.989498488802358, 3.342478961699647}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.989498488802358, 
       3.342478961699647}}], 
      LineBox[{{5.989498488802358, 3.342478961699647}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.989498488802358, 
       3.342478961699647}}], 
      LineBox[{{5.989498488802358, 3.342478961699647}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.989498488802358, 
       3.342478961699647}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{5.91345016049428, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.989498488802358, 3.605918098620184}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}}], 
      LineBox[{{5.91345016049428, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.989498488802358, 3.605918098620184}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}}], 
      LineBox[{{5.91345016049428, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.989498488802358, 3.605918098620184}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}}], 
      LineBox[{{5.91345016049428, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.989498488802358, 3.605918098620184}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}}], 
      LineBox[{{5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}}], 
      LineBox[{{5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}}], 
      LineBox[{{5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}}], 
      LineBox[{{5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}}], 
      LineBox[{{6.045548706374291, 3.5885992266949884`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}}], 
      LineBox[{{6.045548706374291, 3.5885992266949884`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}}], 
      LineBox[{{6.045548706374291, 3.5885992266949884`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}}], 
      LineBox[{{6.045548706374291, 3.5885992266949884`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}}], 
      LineBox[{{6.088572398212365, 3.5487177503526475`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}}], 
      LineBox[{{6.088572398212365, 3.5487177503526475`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}}], 
      LineBox[{{6.088572398212365, 3.5487177503526475`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}}], 
      LineBox[{{6.088572398212365, 3.5487177503526475`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}], 
      LineBox[{{6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}], 
      LineBox[{{6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}], 
      LineBox[{{6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}], 
      LineBox[{{6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}], 
      LineBox[{{6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}], 
      LineBox[{{6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}], 
      LineBox[{{6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}], 
      LineBox[{{6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}], 
      LineBox[{{6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}], 
      LineBox[{{6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}], 
      LineBox[{{6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}], 
      LineBox[{{6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}], 
      LineBox[{{6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}], 
      LineBox[{{6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}], 
      LineBox[{{6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}], 
      LineBox[{{6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}], 
      LineBox[{{6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}], 
      LineBox[{{6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}], 
      LineBox[{{6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}], 
      LineBox[{{6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}], 
      LineBox[{{6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}], 
      LineBox[{{6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}], 
      LineBox[{{6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}], 
      LineBox[{{6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}], 
      LineBox[{{6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}], 
      LineBox[{{6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}], 
      LineBox[{{6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}], 
      LineBox[{{6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}], 
      LineBox[{{6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}], 
      LineBox[{{6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}], 
      LineBox[{{6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}], 
      LineBox[{{6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}], 
      LineBox[{{6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}], 
      LineBox[{{6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}], 
      LineBox[{{6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}], 
      LineBox[{{6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}], 
      LineBox[{{6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}], 
      LineBox[{{6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}], 
      LineBox[{{6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}], 
      LineBox[{{6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}], 
      LineBox[{{6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}], 
      LineBox[{{6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}], 
      LineBox[{{6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}], 
      LineBox[{{6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}], 
      LineBox[{{6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.142320992112987, -3.878259608965569}, {
       6.142320992112987, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}], 
      LineBox[{{6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}], 
      LineBox[{{6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}], 
      LineBox[{{6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}], 
      LineBox[{{6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}], 
      LineBox[{{6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}], 
      LineBox[{{6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}], 
      LineBox[{{6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}], 
      LineBox[{{6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}], 
      LineBox[{{6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}], 
      LineBox[{{6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}], 
      LineBox[{{6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}], 
      LineBox[{{6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}], 
      LineBox[{{6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}], 
      LineBox[{{6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}], 
      LineBox[{{6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}], 
      LineBox[{{6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}], 
      LineBox[{{6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}], 
      LineBox[{{6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}], 
      LineBox[{{6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}], 
      LineBox[{{6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}], 
      LineBox[{{6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}], 
      LineBox[{{6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}], 
      LineBox[{{6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}], 
      LineBox[{{6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}], 
      LineBox[{{6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}], 
      LineBox[{{6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}], 
      LineBox[{{6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}], 
      LineBox[{{6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}], 
      LineBox[{{6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}], 
      LineBox[{{6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}], 
      LineBox[{{6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}], 
      LineBox[{{6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}], 
      LineBox[{{6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}], 
      LineBox[{{6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}], 
      LineBox[{{6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}], 
      LineBox[{{6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}], 
      LineBox[{{6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}], 
      LineBox[{{6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}], 
      LineBox[{{6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}], 
      LineBox[{{6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}], 
      LineBox[{{6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}], 
      LineBox[{{6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}], 
      LineBox[{{6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}], 
      LineBox[{{6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}], 
      LineBox[{{6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}], 
      LineBox[{{6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}], 
      LineBox[{{6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}], 
      LineBox[{{6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}], 
      LineBox[{{6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}], 
      LineBox[{{6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}], 
      LineBox[{{6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}], 
      LineBox[{{6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}], 
      LineBox[{{6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}], 
      LineBox[{{6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}], 
      LineBox[{{6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}], 
      LineBox[{{6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}], 
      LineBox[{{6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}], 
      LineBox[{{6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}], 
      LineBox[{{6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}], 
      LineBox[{{6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}], 
      LineBox[{{6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}], 
      LineBox[{{6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}], 
      LineBox[{{6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}], 
      LineBox[{{6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}], 
      LineBox[{{6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}], 
      LineBox[{{6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}], 
      LineBox[{{6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}], 
      LineBox[{{6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}], 
      LineBox[{{6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}], 
      LineBox[{{6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}], 
      LineBox[{{6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}], 
      LineBox[{{6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}], 
      LineBox[{{6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}], 
      LineBox[{{6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}], 
      LineBox[{{6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}], 
      LineBox[{{6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}], 
      LineBox[{{6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}], 
      LineBox[{{6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}], 
      LineBox[{{6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}], 
      LineBox[{{6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}], 
      LineBox[{{6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}], 
      LineBox[{{6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}], 
      LineBox[{{6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}], 
      LineBox[{{6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}], 
      LineBox[{{6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}], 
      LineBox[{{6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}], 
      LineBox[{{6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}], 
      LineBox[{{6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}], 
      LineBox[{{6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}], 
      LineBox[{{6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}], 
      LineBox[{{6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}], 
      LineBox[{{6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}], 
      LineBox[{{6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}], 
      LineBox[{{6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}], 
      LineBox[{{6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}], 
      LineBox[{{6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}], 
      LineBox[{{6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}], 
      LineBox[{{6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}], 
      LineBox[{{6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}], 
      LineBox[{{6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}], 
      LineBox[{{6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}], 
      LineBox[{{6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}], 
      LineBox[{{6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}], 
      LineBox[{{6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}], 
      LineBox[{{6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}], 
      LineBox[{{6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}], 
      LineBox[{{6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}], 
      LineBox[{{6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}], 
      LineBox[{{6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}], 
      LineBox[{{6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}], 
      LineBox[{{6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}], 
      LineBox[{{6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}], 
      LineBox[{{6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}], 
      LineBox[{{6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}], 
      LineBox[{{6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}], 
      LineBox[{{6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}], 
      LineBox[{{6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}], 
      LineBox[{{6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}], 
      LineBox[{{6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}], 
      LineBox[{{6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}], 
      LineBox[{{6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}], 
      LineBox[{{6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}], 
      LineBox[{{6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}], 
      LineBox[{{6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}], 
      LineBox[{{6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}], 
      LineBox[{{6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}], 
      LineBox[{{6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}], 
      LineBox[{{6.277780875373735, -2.5984953969436377`}, {6.320197321201981,
        -2.6378139772084843`}, {6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}], 
      LineBox[{{6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}], 
      LineBox[{{6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}], 
      LineBox[{{6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}], 
      LineBox[{{6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}], 
      LineBox[{{6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}], 
      LineBox[{{6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}], 
      LineBox[{{6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}], 
      LineBox[{{6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}], 
      LineBox[{{6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}], 
      LineBox[{{6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}], 
      LineBox[{{6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}], 
      LineBox[{{6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}], 
      LineBox[{{6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}], 
      LineBox[{{6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}], 
      LineBox[{{6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}], 
      LineBox[{{6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}], 
      LineBox[{{6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}], 
      LineBox[{{6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}], 
      LineBox[{{6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}], 
      LineBox[{{6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}], 
      LineBox[{{6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}], 
      LineBox[{{6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}], 
      LineBox[{{6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}], 
      LineBox[{{6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}], 
      LineBox[{{6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}], 
      LineBox[{{6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}], 
      LineBox[{{6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}], 
      LineBox[{{6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}], 
      LineBox[{{6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}], 
      LineBox[{{6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}], 
      LineBox[{{6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}], 
      LineBox[{{6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}], 
      LineBox[{{6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}], 
      LineBox[{{6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}], 
      LineBox[{{6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}], 
      LineBox[{{6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}], 
      LineBox[{{6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}], 
      LineBox[{{6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}], 
      LineBox[{{6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}], 
      LineBox[{{6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}], 
      LineBox[{{6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}], 
      LineBox[{{6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}], 
      LineBox[{{6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}], 
      LineBox[{{6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}], 
      LineBox[{{6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}], 
      LineBox[{{6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}], 
      LineBox[{{6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}], 
      LineBox[{{6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}], 
      LineBox[{{6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}], 
      LineBox[{{6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}], 
      LineBox[{{6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}], 
      LineBox[{{6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}], 
      LineBox[{{6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}], 
      LineBox[{{6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}], 
      LineBox[{{6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}], 
      LineBox[{{6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}], 
      LineBox[{{6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}], 
      LineBox[{{6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}], 
      LineBox[{{6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}], 
      LineBox[{{6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}], 
      LineBox[{{6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}], 
      LineBox[{{6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}], 
      LineBox[{{6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}], 
      LineBox[{{6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}], 
      LineBox[{{6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}], 
      LineBox[{{6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}], 
      LineBox[{{6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}], 
      LineBox[{{6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}], 
      LineBox[{{6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}], 
      LineBox[{{6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}], 
      LineBox[{{6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}], 
      LineBox[{{6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}], 
      LineBox[{{6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}], 
      LineBox[{{6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}], 
      LineBox[{{6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}], 
      LineBox[{{6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}], 
      LineBox[{{6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}], 
      LineBox[{{6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}], 
      LineBox[{{6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}], 
      LineBox[{{6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}], 
      LineBox[{{6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}], 
      LineBox[{{6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}], 
      LineBox[{{6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}], 
      LineBox[{{6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}], 
      LineBox[{{6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}], 
      LineBox[{{6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}], 
      LineBox[{{6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}], 
      LineBox[{{6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}], 
      LineBox[{{6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}], 
      LineBox[{{6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}], 
      LineBox[{{6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}], 
      LineBox[{{6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}], 
      LineBox[{{6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}], 
      LineBox[{{6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}], 
      LineBox[{{6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}], 
      LineBox[{{6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}], 
      LineBox[{{6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}], 
      LineBox[{{6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}], 
      LineBox[{{6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}], 
      LineBox[{{6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}], 
      LineBox[{{6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}], 
      LineBox[{{6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}], 
      LineBox[{{6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}], 
      LineBox[{{6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}], 
      LineBox[{{6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}], 
      LineBox[{{6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}], 
      LineBox[{{6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}], 
      LineBox[{{6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}], 
      LineBox[{{6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}], 
      LineBox[{{6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}], 
      LineBox[{{6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}], 
      LineBox[{{6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}], 
      LineBox[{{6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}], 
      LineBox[{{6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}], 
      LineBox[{{6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}], 
      LineBox[{{6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}], 
      LineBox[{{6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}], 
      LineBox[{{6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}], 
      LineBox[{{6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}], 
      LineBox[{{6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}], 
      LineBox[{{6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}], 
      LineBox[{{6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}], 
      LineBox[{{6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}], 
      LineBox[{{6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}], 
      LineBox[{{6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}], 
      LineBox[{{6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}], 
      LineBox[{{6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}], 
      LineBox[{{6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}], 
      LineBox[{{6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}], 
      LineBox[{{6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}], 
      LineBox[{{6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}], 
      LineBox[{{6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}], 
      LineBox[{{6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}], 
      LineBox[{{6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}], 
      LineBox[{{6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}], 
      LineBox[{{6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}], 
      LineBox[{{6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}], 
      LineBox[{{6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}], 
      LineBox[{{6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}], 
      LineBox[{{6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}], 
      LineBox[{{6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}], 
      LineBox[{{6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091628}, {
       6.160705813016764, -0.6347178347091628}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193179}, {
       6.160705813016764, -0.8990415182193179}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}], 
      LineBox[{{6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}], 
      LineBox[{{6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}], 
      LineBox[{{6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}], 
      LineBox[{{6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}], 
      LineBox[{{6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}], 
      LineBox[{{6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}], 
      LineBox[{{6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}], 
      LineBox[{{6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}], 
      LineBox[{{6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}], 
      LineBox[{{6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}], 
      LineBox[{{6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}], 
      LineBox[{{6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}], 
      LineBox[{{6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}], 
      LineBox[{{6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}], 
      LineBox[{{6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}], 
      LineBox[{{6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}], 
      LineBox[{{6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}], 
      LineBox[{{6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}], 
      LineBox[{{6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}], 
      LineBox[{{6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}], 
      LineBox[{{6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}], 
      LineBox[{{6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}], 
      LineBox[{{6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}], 
      LineBox[{{6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}], 
      LineBox[{{6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}], 
      LineBox[{{6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}], 
      LineBox[{{6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}], 
      LineBox[{{6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}], 
      LineBox[{{6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}], 
      LineBox[{{6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}], 
      LineBox[{{6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}], 
      LineBox[{{6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}], 
      LineBox[{{6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}], 
      LineBox[{{6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}], 
      LineBox[{{6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}], 
      LineBox[{{6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}], 
      LineBox[{{6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}], 
      LineBox[{{6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}], 
      LineBox[{{6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}], 
      LineBox[{{6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}], 
      LineBox[{{6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}], 
      LineBox[{{6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}], 
      LineBox[{{6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}], 
      LineBox[{{6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}], 
      LineBox[{{6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}], 
      LineBox[{{6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}], 
      LineBox[{{6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}], 
      LineBox[{{6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}], 
      LineBox[{{6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}], 
      LineBox[{{6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}], 
      LineBox[{{6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}], 
      LineBox[{{6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}], 
      LineBox[{{6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}], 
      LineBox[{{6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}], 
      LineBox[{{6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}], 
      LineBox[{{6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}], 
      LineBox[{{6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}], 
      LineBox[{{6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}], 
      LineBox[{{6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}], 
      LineBox[{{6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}], 
      LineBox[{{6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}], 
      LineBox[{{6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}], 
      LineBox[{{6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}], 
      LineBox[{{6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}], 
      LineBox[{{6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}], 
      LineBox[{{6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}], 
      LineBox[{{6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}], 
      LineBox[{{6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}], 
      LineBox[{{6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}], 
      LineBox[{{6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}], 
      LineBox[{{6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}], 
      LineBox[{{6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}], 
      LineBox[{{6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}], 
      LineBox[{{6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}], 
      LineBox[{{6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}], 
      LineBox[{{6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}], 
      LineBox[{{6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}], 
      LineBox[{{6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}], 
      LineBox[{{6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}], 
      LineBox[{{6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}], 
      LineBox[{{6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}], 
      LineBox[{{6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}], 
      LineBox[{{6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}], 
      LineBox[{{6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}], 
      LineBox[{{6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}], 
      LineBox[{{6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}], 
      LineBox[{{6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}], 
      LineBox[{{6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}], 
      LineBox[{{6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}], 
      LineBox[{{6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1551632030793995`, 0.15222489757654997`}, {
       6.088973505956324, 0.22362960454963116`}, {6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.3664390184957935}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}, {6.088973505956324, 0.36643901849579347`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.22362960454963113`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.320065310248659, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.320065310248659, 
       0.15222489757654997`}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.320065310248659, 0.4378437254688746}, {
       6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.320065310248659, 
       0.4378437254688746}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1551632030793995`, 0.15222489757654997`}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}}], 
      LineBox[{{6.1551632030793995`, 0.15222489757654997`}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}}], 
      LineBox[{{6.1551632030793995`, 0.15222489757654997`}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}}], 
      LineBox[{{6.1551632030793995`, 0.15222489757654997`}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}}], 
      LineBox[{{6.088973505956324, 0.22362960454963116`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}}], 
      LineBox[{{6.088973505956324, 0.22362960454963116`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}}], 
      LineBox[{{6.088973505956324, 0.22362960454963116`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}}], 
      LineBox[{{6.088973505956324, 0.22362960454963116`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}}], 
      LineBox[{{6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.36643901849579347`}, {6.088973505956324, 0.36643901849579347`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}}], 
      LineBox[{{6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.36643901849579347`}, {6.088973505956324, 0.36643901849579347`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}}], 
      LineBox[{{6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.36643901849579347`}, {6.088973505956324, 0.36643901849579347`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}}], 
      LineBox[{{6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.36643901849579347`}, {6.088973505956324, 0.36643901849579347`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}}], 
      LineBox[{{6.088973505956324, 0.3664390184957935}, {6.1551632030793995`, 
       0.4378437254688746}, {6.1551632030793995`, 0.4378437254688746}, {
       6.088973505956324, 0.3664390184957935}, {6.088973505956324, 
       0.3664390184957935}}], 
      LineBox[{{6.088973505956324, 0.3664390184957935}, {6.1551632030793995`, 
       0.4378437254688746}, {6.1551632030793995`, 0.4378437254688746}, {
       6.088973505956324, 0.3664390184957935}, {6.088973505956324, 
       0.3664390184957935}}], 
      LineBox[{{6.088973505956324, 0.3664390184957935}, {6.1551632030793995`, 
       0.4378437254688746}, {6.1551632030793995`, 0.4378437254688746}, {
       6.088973505956324, 0.3664390184957935}, {6.088973505956324, 
       0.3664390184957935}}], 
      LineBox[{{6.088973505956324, 0.3664390184957935}, {6.1551632030793995`, 
       0.4378437254688746}, {6.1551632030793995`, 0.4378437254688746}, {
       6.088973505956324, 0.3664390184957935}, {6.088973505956324, 
       0.3664390184957935}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}], 
      LineBox[{{6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}], 
      LineBox[{{6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}], 
      LineBox[{{6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}], 
      LineBox[{{6.373772922206355, 0.2020099988587903}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.373772922206355, 0.2020099988587903}, {6.373772922206355, 
       0.2020099988587903}}], 
      LineBox[{{6.373772922206355, 0.2020099988587903}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.373772922206355, 0.2020099988587903}, {6.373772922206355, 
       0.2020099988587903}}], 
      LineBox[{{6.373772922206355, 0.2020099988587903}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.373772922206355, 0.2020099988587903}, {6.373772922206355, 
       0.2020099988587903}}], 
      LineBox[{{6.373772922206355, 0.2020099988587903}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.373772922206355, 0.2020099988587903}, {6.373772922206355, 
       0.2020099988587903}}], 
      LineBox[{{6.320065310248659, 0.15222489757654997`}, {6.25009634182941, 
       0.13060529188570913`}, {6.25009634182941, 0.13060529188570913`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}}], 
      LineBox[{{6.320065310248659, 0.15222489757654997`}, {6.25009634182941, 
       0.13060529188570913`}, {6.25009634182941, 0.13060529188570913`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}}], 
      LineBox[{{6.320065310248659, 0.15222489757654997`}, {6.25009634182941, 
       0.13060529188570913`}, {6.25009634182941, 0.13060529188570913`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}}], 
      LineBox[{{6.320065310248659, 0.15222489757654997`}, {6.25009634182941, 
       0.13060529188570913`}, {6.25009634182941, 0.13060529188570913`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}}], 
      LineBox[{{6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`,
        0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}}], 
      LineBox[{{6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`,
        0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}}], 
      LineBox[{{6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`,
        0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}}], 
      LineBox[{{6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`,
        0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}], 
      LineBox[{{6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}], 
      LineBox[{{6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}], 
      LineBox[{{6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}], 
      LineBox[{{6.25009634182941, 0.4594633311597155}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}}], 
      LineBox[{{6.25009634182941, 0.4594633311597155}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}}], 
      LineBox[{{6.25009634182941, 0.4594633311597155}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}}], 
      LineBox[{{6.25009634182941, 0.4594633311597155}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}}], 
      LineBox[{{6.320065310248659, 0.4378437254688746}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}], 
      LineBox[{{6.320065310248659, 0.4378437254688746}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}], 
      LineBox[{{6.320065310248659, 0.4378437254688746}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}], 
      LineBox[{{6.320065310248659, 0.4378437254688746}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}], 
      LineBox[{{6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.373772922206355, 
       0.3880586241866343}}], 
      LineBox[{{6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.373772922206355, 
       0.3880586241866343}}], 
      LineBox[{{6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.373772922206355, 
       0.3880586241866343}}], 
      LineBox[{{6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.373772922206355, 
       0.3880586241866343}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.232394970709101, 0.6157192740461499}, {6.1791882695788685`, 
       0.6731180697551582}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.787915661173175}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}, {
       6.1791882695788685`, 0.787915661173175}, {6.166116550401588, 
       0.7305168654641666}, {6.1791882695788685`, 0.6731180697551582}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.364951811324127, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.364951811324127, 
       0.6157192740461499}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.364951811324127, 0.8453144568821833}, {
       6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.364951811324127, 
       0.8453144568821833}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.232394970709101, 0.6157192740461499}, {6.1791882695788685`, 
       0.6731180697551582}, {6.1791882695788685`, 0.6731180697551582}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}}], 
      LineBox[{{6.232394970709101, 0.6157192740461499}, {6.1791882695788685`, 
       0.6731180697551582}, {6.1791882695788685`, 0.6731180697551582}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}}], 
      LineBox[{{6.232394970709101, 0.6157192740461499}, {6.1791882695788685`, 
       0.6731180697551582}, {6.1791882695788685`, 0.6731180697551582}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}}], 
      LineBox[{{6.232394970709101, 0.6157192740461499}, {6.1791882695788685`, 
       0.6731180697551582}, {6.1791882695788685`, 0.6731180697551582}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}}], 
      LineBox[{{6.1791882695788685`, 0.6731180697551582}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}}], 
      LineBox[{{6.1791882695788685`, 0.6731180697551582}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}}], 
      LineBox[{{6.1791882695788685`, 0.6731180697551582}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}}], 
      LineBox[{{6.1791882695788685`, 0.6731180697551582}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}}], 
      LineBox[{{6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}], 
      LineBox[{{6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}], 
      LineBox[{{6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}], 
      LineBox[{{6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}], 
      LineBox[{{6.1791882695788685`, 0.787915661173175}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}}], 
      LineBox[{{6.1791882695788685`, 0.787915661173175}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}}], 
      LineBox[{{6.1791882695788685`, 0.787915661173175}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}}], 
      LineBox[{{6.1791882695788685`, 0.787915661173175}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}], 
      LineBox[{{6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}], 
      LineBox[{{6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}], 
      LineBox[{{6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}], 
      LineBox[{{6.408124766966121, 0.6557391127793147}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.408124766966121, 0.6557391127793147}, {6.408124766966121, 
       0.6557391127793147}}], 
      LineBox[{{6.408124766966121, 0.6557391127793147}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.408124766966121, 0.6557391127793147}, {6.408124766966121, 
       0.6557391127793147}}], 
      LineBox[{{6.408124766966121, 0.6557391127793147}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.408124766966121, 0.6557391127793147}, {6.408124766966121, 
       0.6557391127793147}}], 
      LineBox[{{6.408124766966121, 0.6557391127793147}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.408124766966121, 0.6557391127793147}, {6.408124766966121, 
       0.6557391127793147}}], 
      LineBox[{{6.364951811324127, 0.6157192740461499}, {6.308707136504852, 
       0.5983403170703064}, {6.308707136504852, 0.5983403170703064}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}}], 
      LineBox[{{6.364951811324127, 0.6157192740461499}, {6.308707136504852, 
       0.5983403170703064}, {6.308707136504852, 0.5983403170703064}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}}], 
      LineBox[{{6.364951811324127, 0.6157192740461499}, {6.308707136504852, 
       0.5983403170703064}, {6.308707136504852, 0.5983403170703064}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}}], 
      LineBox[{{6.364951811324127, 0.6157192740461499}, {6.308707136504852, 
       0.5983403170703064}, {6.308707136504852, 0.5983403170703064}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}}], 
      LineBox[{{6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}}], 
      LineBox[{{6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}}], 
      LineBox[{{6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}}], 
      LineBox[{{6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}], 
      LineBox[{{6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}], 
      LineBox[{{6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}], 
      LineBox[{{6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}], 
      LineBox[{{6.308707136504852, 0.8626934138580268}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}}], 
      LineBox[{{6.308707136504852, 0.8626934138580268}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}}], 
      LineBox[{{6.308707136504852, 0.8626934138580268}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}}], 
      LineBox[{{6.308707136504852, 0.8626934138580268}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}}], 
      LineBox[{{6.364951811324127, 0.8453144568821833}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}], 
      LineBox[{{6.364951811324127, 0.8453144568821833}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}], 
      LineBox[{{6.364951811324127, 0.8453144568821833}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}], 
      LineBox[{{6.364951811324127, 0.8453144568821833}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}], 
      LineBox[{{6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.408124766966121, 
       0.8052946181490185}}], 
      LineBox[{{6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.408124766966121, 
       0.8052946181490185}}], 
      LineBox[{{6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.408124766966121, 
       0.8052946181490185}}], 
      LineBox[{{6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.408124766966121, 
       0.8052946181490185}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.12971674079559, 1.1350463193708702`}, {6.066780670172548, 
       1.2029410503668336`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.33873051235876}, {6.12971674079559, 
       1.4066252433547235`}, {6.12971674079559, 1.4066252433547235`}, {
       6.066780670172548, 1.33873051235876}, {6.051318658361438, 
       1.2708357813627968`}, {6.066780670172548, 1.2029410503668336`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.286512905663898, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.129716740795591, 
       1.1350463193708702`}, {6.129716740795591, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.286512905663898, 
       1.1350463193708702`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.286512905663898, 1.4066252433547235`}, {
       6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.286512905663898, 
       1.4066252433547235`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.12971674079559, 1.1350463193708702`}, {6.066780670172548, 
       1.2029410503668336`}, {6.066780670172548, 1.2029410503668336`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}}], 
      LineBox[{{6.12971674079559, 1.1350463193708702`}, {6.066780670172548, 
       1.2029410503668336`}, {6.066780670172548, 1.2029410503668336`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}}], 
      LineBox[{{6.12971674079559, 1.1350463193708702`}, {6.066780670172548, 
       1.2029410503668336`}, {6.066780670172548, 1.2029410503668336`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}}], 
      LineBox[{{6.12971674079559, 1.1350463193708702`}, {6.066780670172548, 
       1.2029410503668336`}, {6.066780670172548, 1.2029410503668336`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}}], 
      LineBox[{{6.066780670172548, 1.2029410503668336`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}}], 
      LineBox[{{6.066780670172548, 1.2029410503668336`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}}], 
      LineBox[{{6.066780670172548, 1.2029410503668336`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}}], 
      LineBox[{{6.066780670172548, 1.2029410503668336`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}}], 
      LineBox[{{6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}], 
      LineBox[{{6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}], 
      LineBox[{{6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}], 
      LineBox[{{6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}], 
      LineBox[{{6.066780670172548, 1.33873051235876}, {6.12971674079559, 
       1.4066252433547235`}, {6.12971674079559, 1.4066252433547235`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}}], 
      LineBox[{{6.066780670172548, 1.33873051235876}, {6.12971674079559, 
       1.4066252433547235`}, {6.12971674079559, 1.4066252433547235`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}}], 
      LineBox[{{6.066780670172548, 1.33873051235876}, {6.12971674079559, 
       1.4066252433547235`}, {6.12971674079559, 1.4066252433547235`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}}], 
      LineBox[{{6.066780670172548, 1.33873051235876}, {6.12971674079559, 
       1.4066252433547235`}, {6.12971674079559, 1.4066252433547235`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}], 
      LineBox[{{6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}], 
      LineBox[{{6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}], 
      LineBox[{{6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}], 
      LineBox[{{6.337580461583957, 1.1823841798908885`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.337580461583957, 1.1823841798908885`}, {6.337580461583957, 
       1.1823841798908885`}}], 
      LineBox[{{6.337580461583957, 1.1823841798908885`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.337580461583957, 1.1823841798908885`}, {6.337580461583957, 
       1.1823841798908885`}}], 
      LineBox[{{6.337580461583957, 1.1823841798908885`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.337580461583957, 1.1823841798908885`}, {6.337580461583957, 
       1.1823841798908885`}}], 
      LineBox[{{6.337580461583957, 1.1823841798908885`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.337580461583957, 1.1823841798908885`}, {6.337580461583957, 
       1.1823841798908885`}}], 
      LineBox[{{6.286512905663898, 1.1350463193708702`}, {6.219983337932727, 
       1.1144894488949253`}, {6.219983337932727, 1.1144894488949253`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}}], 
      LineBox[{{6.286512905663898, 1.1350463193708702`}, {6.219983337932727, 
       1.1144894488949253`}, {6.219983337932727, 1.1144894488949253`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}}], 
      LineBox[{{6.286512905663898, 1.1350463193708702`}, {6.219983337932727, 
       1.1144894488949253`}, {6.219983337932727, 1.1144894488949253`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}}], 
      LineBox[{{6.286512905663898, 1.1350463193708702`}, {6.219983337932727, 
       1.1144894488949253`}, {6.219983337932727, 1.1144894488949253`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}}], 
      LineBox[{{6.219983337932727, 1.1144894488949253`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}}], 
      LineBox[{{6.219983337932727, 1.1144894488949253`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}}], 
      LineBox[{{6.219983337932727, 1.1144894488949253`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}}], 
      LineBox[{{6.219983337932727, 1.1144894488949253`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}], 
      LineBox[{{6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}], 
      LineBox[{{6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}], 
      LineBox[{{6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}], 
      LineBox[{{6.219983337932727, 1.4271821138306684`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}}], 
      LineBox[{{6.219983337932727, 1.4271821138306684`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}}], 
      LineBox[{{6.219983337932727, 1.4271821138306684`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}}], 
      LineBox[{{6.219983337932727, 1.4271821138306684`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}}], 
      LineBox[{{6.286512905663898, 1.4066252433547235`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}], 
      LineBox[{{6.286512905663898, 1.4066252433547235`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}], 
      LineBox[{{6.286512905663898, 1.4066252433547235`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}], 
      LineBox[{{6.286512905663898, 1.4066252433547235`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}], 
      LineBox[{{6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.337580461583957, 
       1.3592873828347052`}}], 
      LineBox[{{6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.337580461583957, 
       1.3592873828347052`}}], 
      LineBox[{{6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.337580461583957, 
       1.3592873828347052`}}], 
      LineBox[{{6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.337580461583957, 
       1.3592873828347052`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.188669742878711, 1.5852890136695272`}, {6.124692476399525, 
       1.654306975141546}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.7923428980855833`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}, {
       6.124692476399525, 1.7923428980855831`}, {6.108974665609133, 
       1.7233249366135646`}, {6.124692476399525, 1.6543069751415458`}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856,
        1.6334100178418933`}, {6.348059897417868, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.348059897417868, 
       1.5852890136695272`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.348059897417868, 1.8613608595576019`}, {
       6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`, 
       1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.348059897417868, 
       1.8613608595576019`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.188669742878711, 1.5852890136695272`}, {6.124692476399525, 
       1.654306975141546}, {6.124692476399525, 1.654306975141546}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}}], 
      LineBox[{{6.188669742878711, 1.5852890136695272`}, {6.124692476399525, 
       1.654306975141546}, {6.124692476399525, 1.654306975141546}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}}], 
      LineBox[{{6.188669742878711, 1.5852890136695272`}, {6.124692476399525, 
       1.654306975141546}, {6.124692476399525, 1.654306975141546}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}}], 
      LineBox[{{6.188669742878711, 1.5852890136695272`}, {6.124692476399525, 
       1.654306975141546}, {6.124692476399525, 1.654306975141546}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}}], 
      LineBox[{{6.124692476399525, 1.654306975141546}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}}], 
      LineBox[{{6.124692476399525, 1.654306975141546}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}}], 
      LineBox[{{6.124692476399525, 1.654306975141546}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}}], 
      LineBox[{{6.124692476399525, 1.654306975141546}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}}], 
      LineBox[{{6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.7923428980855831`}, {6.124692476399525, 1.7923428980855831`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}], 
      LineBox[{{6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.7923428980855831`}, {6.124692476399525, 1.7923428980855831`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}], 
      LineBox[{{6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.7923428980855831`}, {6.124692476399525, 1.7923428980855831`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}], 
      LineBox[{{6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.7923428980855831`}, {6.124692476399525, 1.7923428980855831`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}], 
      LineBox[{{6.124692476399525, 1.7923428980855833`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}, {
       6.124692476399525, 1.7923428980855833`}, {6.124692476399525, 
       1.7923428980855833`}}], 
      LineBox[{{6.124692476399525, 1.7923428980855833`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}, {
       6.124692476399525, 1.7923428980855833`}, {6.124692476399525, 
       1.7923428980855833`}}], 
      LineBox[{{6.124692476399525, 1.7923428980855833`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}, {
       6.124692476399525, 1.7923428980855833`}, {6.124692476399525, 
       1.7923428980855833`}}], 
      LineBox[{{6.124692476399525, 1.7923428980855833`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}, {
       6.124692476399525, 1.7923428980855833`}, {6.124692476399525, 
       1.7923428980855833`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856,
        1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}], 
      LineBox[{{6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856,
        1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}], 
      LineBox[{{6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856,
        1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}], 
      LineBox[{{6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856,
        1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}], 
      LineBox[{{6.399972299974856, 1.6334100178418933`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.399972299974856, 1.6334100178418933`}, {6.399972299974856, 
       1.6334100178418933`}}], 
      LineBox[{{6.399972299974856, 1.6334100178418933`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.399972299974856, 1.6334100178418933`}, {6.399972299974856, 
       1.6334100178418933`}}], 
      LineBox[{{6.399972299974856, 1.6334100178418933`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.399972299974856, 1.6334100178418933`}, {6.399972299974856, 
       1.6334100178418933`}}], 
      LineBox[{{6.399972299974856, 1.6334100178418933`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.399972299974856, 1.6334100178418933`}, {6.399972299974856, 
       1.6334100178418933`}}], 
      LineBox[{{6.348059897417868, 1.5852890136695272`}, {6.280429684070488, 
       1.5643920563698746`}, {6.280429684070488, 1.5643920563698746`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}}], 
      LineBox[{{6.348059897417868, 1.5852890136695272`}, {6.280429684070488, 
       1.5643920563698746`}, {6.280429684070488, 1.5643920563698746`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}}], 
      LineBox[{{6.348059897417868, 1.5852890136695272`}, {6.280429684070488, 
       1.5643920563698746`}, {6.280429684070488, 1.5643920563698746`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}}], 
      LineBox[{{6.348059897417868, 1.5852890136695272`}, {6.280429684070488, 
       1.5643920563698746`}, {6.280429684070488, 1.5643920563698746`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}}], 
      LineBox[{{6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}}], 
      LineBox[{{6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}}], 
      LineBox[{{6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}}], 
      LineBox[{{6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}], 
      LineBox[{{6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}], 
      LineBox[{{6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}], 
      LineBox[{{6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}], 
      LineBox[{{6.280429684070488, 1.8822578168572546`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}}], 
      LineBox[{{6.280429684070488, 1.8822578168572546`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}}], 
      LineBox[{{6.280429684070488, 1.8822578168572546`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}}], 
      LineBox[{{6.280429684070488, 1.8822578168572546`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}}], 
      LineBox[{{6.348059897417868, 1.8613608595576019`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}], 
      LineBox[{{6.348059897417868, 1.8613608595576019`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}], 
      LineBox[{{6.348059897417868, 1.8613608595576019`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}], 
      LineBox[{{6.348059897417868, 1.8613608595576019`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}], 
      LineBox[{{6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`,
        1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.399972299974856, 
       1.8132398553852358`}}], 
      LineBox[{{6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`,
        1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.399972299974856, 
       1.8132398553852358`}}], 
      LineBox[{{6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`,
        1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.399972299974856, 
       1.8132398553852358`}}], 
      LineBox[{{6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`,
        1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.399972299974856, 
       1.8132398553852358`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.209149727284057, 2.077779843784034}, {6.144328172804688, 
       2.1477086137334176`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.287566153632185}, {6.209149727284057, 
       2.357494923581569}, {6.209149727284057, 2.357494923581569}, {
       6.144328172804688, 2.287566153632185}, {6.128402938975304, 
       2.2176373836828014`}, {6.144328172804688, 2.1477086137334176`}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.370643303901561, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.0777798437840334`}, {6.209149727284057, 2.0777798437840334`}, {
       6.302120595755306, 2.056607115866795}, {6.370643303901561, 
       2.077779843784034}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.370643303901561, 2.357494923581569}, {
       6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.370643303901561, 
       2.357494923581569}, {6.302120595755305, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.209149727284057, 2.077779843784034}, {6.144328172804688, 
       2.1477086137334176`}, {6.144328172804688, 2.1477086137334176`}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}}], 
      LineBox[{{6.209149727284057, 2.077779843784034}, {6.144328172804688, 
       2.1477086137334176`}, {6.144328172804688, 2.1477086137334176`}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}}], 
      LineBox[{{6.209149727284057, 2.077779843784034}, {6.144328172804688, 
       2.1477086137334176`}, {6.144328172804688, 2.1477086137334176`}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}}], 
      LineBox[{{6.209149727284057, 2.077779843784034}, {6.144328172804688, 
       2.1477086137334176`}, {6.144328172804688, 2.1477086137334176`}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}}], 
      LineBox[{{6.144328172804688, 2.1477086137334176`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}}], 
      LineBox[{{6.144328172804688, 2.1477086137334176`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}}], 
      LineBox[{{6.144328172804688, 2.1477086137334176`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}}], 
      LineBox[{{6.144328172804688, 2.1477086137334176`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}}], 
      LineBox[{{6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}], 
      LineBox[{{6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}], 
      LineBox[{{6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}], 
      LineBox[{{6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}], 
      LineBox[{{6.144328172804688, 2.287566153632185}, {6.209149727284057, 
       2.3574949235815694`}, {6.209149727284057, 2.3574949235815694`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}}], 
      LineBox[{{6.144328172804688, 2.287566153632185}, {6.209149727284057, 
       2.3574949235815694`}, {6.209149727284057, 2.3574949235815694`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}}], 
      LineBox[{{6.144328172804688, 2.287566153632185}, {6.209149727284057, 
       2.3574949235815694`}, {6.209149727284057, 2.3574949235815694`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}}], 
      LineBox[{{6.144328172804688, 2.287566153632185}, {6.209149727284057, 
       2.3574949235815694`}, {6.209149727284057, 2.3574949235815694`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}], 
      LineBox[{{6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}], 
      LineBox[{{6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}], 
      LineBox[{{6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}], 
      LineBox[{{6.423240778218434, 2.1265358858161787`}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.423240778218434, 2.1265358858161787`}, {6.423240778218434, 
       2.1265358858161787`}}], 
      LineBox[{{6.423240778218434, 2.1265358858161787`}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.423240778218434, 2.1265358858161787`}, {6.423240778218434, 
       2.1265358858161787`}}], 
      LineBox[{{6.423240778218434, 2.1265358858161787`}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.423240778218434, 2.1265358858161787`}, {6.423240778218434, 
       2.1265358858161787`}}], 
      LineBox[{{6.423240778218434, 2.1265358858161787`}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.423240778218434, 2.1265358858161787`}, {6.423240778218434, 
       2.1265358858161787`}}], 
      LineBox[{{6.370643303901561, 2.077779843784034}, {6.302120595755306, 
       2.056607115866795}, {6.302120595755306, 2.056607115866795}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}}], 
      LineBox[{{6.370643303901561, 2.077779843784034}, {6.302120595755306, 
       2.056607115866795}, {6.302120595755306, 2.056607115866795}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}}], 
      LineBox[{{6.370643303901561, 2.077779843784034}, {6.302120595755306, 
       2.056607115866795}, {6.302120595755306, 2.056607115866795}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}}], 
      LineBox[{{6.370643303901561, 2.077779843784034}, {6.302120595755306, 
       2.056607115866795}, {6.302120595755306, 2.056607115866795}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}}], 
      LineBox[{{6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.302120595755305, 
       2.056607115866795}}], 
      LineBox[{{6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.302120595755305, 
       2.056607115866795}}], 
      LineBox[{{6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.302120595755305, 
       2.056607115866795}}], 
      LineBox[{{6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.302120595755305, 
       2.056607115866795}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}], 
      LineBox[{{6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}], 
      LineBox[{{6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}], 
      LineBox[{{6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}], 
      LineBox[{{6.302120595755306, 2.378667651498808}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}}], 
      LineBox[{{6.302120595755306, 2.378667651498808}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}}], 
      LineBox[{{6.302120595755306, 2.378667651498808}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}}], 
      LineBox[{{6.302120595755306, 2.378667651498808}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}}], 
      LineBox[{{6.370643303901561, 2.357494923581569}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}], 
      LineBox[{{6.370643303901561, 2.357494923581569}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}], 
      LineBox[{{6.370643303901561, 2.357494923581569}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}], 
      LineBox[{{6.370643303901561, 2.357494923581569}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}], 
      LineBox[{{6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.423240778218434, 
       2.308738881549424}}], 
      LineBox[{{6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.423240778218434, 
       2.308738881549424}}], 
      LineBox[{{6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.423240778218434, 
       2.308738881549424}}], 
      LineBox[{{6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.423240778218434, 
       2.308738881549424}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.130007095863632, 2.6344843358205394`}, {6.062932074600658, 
       2.706844120600791}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.851563690161293}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}, {
       6.062932074600658, 2.851563690161293}, {6.046453213420868, 
       2.779203905381042}, {6.062932074600658, 2.706844120600791}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.297114860749157, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.297114860749157, 
       2.6344843358205394`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`,
        2.945832254924535}, {6.297114860749157, 2.9239234749415446`}, {
       6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`, 
       2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.297114860749157, 
       2.9239234749415446`}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.130007095863632, 2.6344843358205394`}, {6.062932074600658, 
       2.706844120600791}, {6.062932074600658, 2.706844120600791}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}}], 
      LineBox[{{6.130007095863632, 2.6344843358205394`}, {6.062932074600658, 
       2.706844120600791}, {6.062932074600658, 2.706844120600791}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}}], 
      LineBox[{{6.130007095863632, 2.6344843358205394`}, {6.062932074600658, 
       2.706844120600791}, {6.062932074600658, 2.706844120600791}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}}], 
      LineBox[{{6.130007095863632, 2.6344843358205394`}, {6.062932074600658, 
       2.706844120600791}, {6.062932074600658, 2.706844120600791}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}}], 
      LineBox[{{6.062932074600658, 2.706844120600791}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}}], 
      LineBox[{{6.062932074600658, 2.706844120600791}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}}], 
      LineBox[{{6.062932074600658, 2.706844120600791}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}}], 
      LineBox[{{6.062932074600658, 2.706844120600791}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}}], 
      LineBox[{{6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}], 
      LineBox[{{6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}], 
      LineBox[{{6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}], 
      LineBox[{{6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}], 
      LineBox[{{6.062932074600658, 2.851563690161293}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}}], 
      LineBox[{{6.062932074600658, 2.851563690161293}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}}], 
      LineBox[{{6.062932074600658, 2.851563690161293}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}}], 
      LineBox[{{6.062932074600658, 2.851563690161293}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}], 
      LineBox[{{6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}], 
      LineBox[{{6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}], 
      LineBox[{{6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}], 
      LineBox[{{6.351540841991334, 2.6849353406178005`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.351540841991334, 2.6849353406178005`}, {6.351540841991334, 
       2.6849353406178005`}}], 
      LineBox[{{6.351540841991334, 2.6849353406178005`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.351540841991334, 2.6849353406178005`}, {6.351540841991334, 
       2.6849353406178005`}}], 
      LineBox[{{6.351540841991334, 2.6849353406178005`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.351540841991334, 2.6849353406178005`}, {6.351540841991334, 
       2.6849353406178005`}}], 
      LineBox[{{6.351540841991334, 2.6849353406178005`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.351540841991334, 2.6849353406178005`}, {6.351540841991334, 
       2.6849353406178005`}}], 
      LineBox[{{6.297114860749157, 2.6344843358205394`}, {6.2262100183271905`,
        2.612575555837549}, {6.2262100183271905`, 2.612575555837549}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}}], 
      LineBox[{{6.297114860749157, 2.6344843358205394`}, {6.2262100183271905`,
        2.612575555837549}, {6.2262100183271905`, 2.612575555837549}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}}], 
      LineBox[{{6.297114860749157, 2.6344843358205394`}, {6.2262100183271905`,
        2.612575555837549}, {6.2262100183271905`, 2.612575555837549}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}}], 
      LineBox[{{6.297114860749157, 2.6344843358205394`}, {6.2262100183271905`,
        2.612575555837549}, {6.2262100183271905`, 2.612575555837549}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}}], 
      LineBox[{{6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}}], 
      LineBox[{{6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}}], 
      LineBox[{{6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}}], 
      LineBox[{{6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`,
        2.945832254924535}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}], 
      LineBox[{{6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`,
        2.945832254924535}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}], 
      LineBox[{{6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`,
        2.945832254924535}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}], 
      LineBox[{{6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`,
        2.945832254924535}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}], 
      LineBox[{{6.2262100183271905`, 2.945832254924535}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}}], 
      LineBox[{{6.2262100183271905`, 2.945832254924535}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}}], 
      LineBox[{{6.2262100183271905`, 2.945832254924535}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}}], 
      LineBox[{{6.2262100183271905`, 2.945832254924535}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}}], 
      LineBox[{{6.297114860749157, 2.9239234749415446`}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}], 
      LineBox[{{6.297114860749157, 2.9239234749415446`}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}], 
      LineBox[{{6.297114860749157, 2.9239234749415446`}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}], 
      LineBox[{{6.297114860749157, 2.9239234749415446`}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}], 
      LineBox[{{6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`,
        2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.351540841991334, 
       2.8734724701442835`}}], 
      LineBox[{{6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`,
        2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.351540841991334, 
       2.8734724701442835`}}], 
      LineBox[{{6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`,
        2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.351540841991334, 
       2.8734724701442835`}}], 
      LineBox[{{6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`,
        2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.351540841991334, 
       2.8734724701442835`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.194051610877686, 3.084844964017741}, {6.127275875910808, 
       3.1568818820800204`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.300955718204579}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}, {
       6.127275875910808, 3.300955718204579}, {6.110870542807991, 
       3.2289188001422997`}, {6.127275875910808, 3.1568818820800204`}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.360413747017079, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.360413747017079, 
       3.084844964017741}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.360413747017079, 3.3729926362668583`}, {
       6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.360413747017079, 
       3.3729926362668583`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.194051610877686, 3.084844964017741}, {6.127275875910808, 
       3.1568818820800204`}, {6.127275875910808, 3.1568818820800204`}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}}], 
      LineBox[{{6.194051610877686, 3.084844964017741}, {6.127275875910808, 
       3.1568818820800204`}, {6.127275875910808, 3.1568818820800204`}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}}], 
      LineBox[{{6.194051610877686, 3.084844964017741}, {6.127275875910808, 
       3.1568818820800204`}, {6.127275875910808, 3.1568818820800204`}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}}], 
      LineBox[{{6.194051610877686, 3.084844964017741}, {6.127275875910808, 
       3.1568818820800204`}, {6.127275875910808, 3.1568818820800204`}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}}], 
      LineBox[{{6.127275875910808, 3.1568818820800204`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}}], 
      LineBox[{{6.127275875910808, 3.1568818820800204`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}}], 
      LineBox[{{6.127275875910808, 3.1568818820800204`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}}], 
      LineBox[{{6.127275875910808, 3.1568818820800204`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}}], 
      LineBox[{{6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}], 
      LineBox[{{6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}], 
      LineBox[{{6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}], 
      LineBox[{{6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}], 
      LineBox[{{6.127275875910808, 3.300955718204579}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}}], 
      LineBox[{{6.127275875910808, 3.300955718204579}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}}], 
      LineBox[{{6.127275875910808, 3.300955718204579}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}}], 
      LineBox[{{6.127275875910808, 3.300955718204579}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}], 
      LineBox[{{6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}], 
      LineBox[{{6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}], 
      LineBox[{{6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}], 
      LineBox[{{6.414596881517942, 3.1350708582734663`}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.414596881517942, 3.1350708582734663`}, {6.414596881517942, 
       3.1350708582734663`}}], 
      LineBox[{{6.414596881517942, 3.1350708582734663`}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.414596881517942, 3.1350708582734663`}, {6.414596881517942, 
       3.1350708582734663`}}], 
      LineBox[{{6.414596881517942, 3.1350708582734663`}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.414596881517942, 3.1350708582734663`}, {6.414596881517942, 
       3.1350708582734663`}}], 
      LineBox[{{6.414596881517942, 3.1350708582734663`}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.414596881517942, 3.1350708582734663`}, {6.414596881517942, 
       3.1350708582734663`}}], 
      LineBox[{{6.360413747017079, 3.084844964017741}, {6.289825279413398, 
       3.063033940211187}, {6.289825279413398, 3.063033940211187}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}}], 
      LineBox[{{6.360413747017079, 3.084844964017741}, {6.289825279413398, 
       3.063033940211187}, {6.289825279413398, 3.063033940211187}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}}], 
      LineBox[{{6.360413747017079, 3.084844964017741}, {6.289825279413398, 
       3.063033940211187}, {6.289825279413398, 3.063033940211187}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}}], 
      LineBox[{{6.360413747017079, 3.084844964017741}, {6.289825279413398, 
       3.063033940211187}, {6.289825279413398, 3.063033940211187}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}}], 
      LineBox[{{6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}}], 
      LineBox[{{6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}}], 
      LineBox[{{6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}}], 
      LineBox[{{6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}], 
      LineBox[{{6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}], 
      LineBox[{{6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}], 
      LineBox[{{6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}], 
      LineBox[{{6.289825279413398, 3.3948036600734124`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}}], 
      LineBox[{{6.289825279413398, 3.3948036600734124`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}}], 
      LineBox[{{6.289825279413398, 3.3948036600734124`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}}], 
      LineBox[{{6.289825279413398, 3.3948036600734124`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}}], 
      LineBox[{{6.360413747017079, 3.3729926362668583`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}], 
      LineBox[{{6.360413747017079, 3.3729926362668583`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}], 
      LineBox[{{6.360413747017079, 3.3729926362668583`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}], 
      LineBox[{{6.360413747017079, 3.3729926362668583`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}], 
      LineBox[{{6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.414596881517942, 
       3.322766742011133}}], 
      LineBox[{{6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.414596881517942, 
       3.322766742011133}}], 
      LineBox[{{6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.414596881517942, 
       3.322766742011133}}], 
      LineBox[{{6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.414596881517942, 
       3.322766742011133}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.157855081110001, 3.573951207401159}, {6.09710621629842, 
       3.639486405163924}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.770556800689454}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}, {
       6.09710621629842, 3.770556800689454}, {6.082181552970546, 
       3.705021602926689}, {6.09710621629842, 3.639486405163924}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.309202137388913, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.309202137388913, 
       3.573951207401159}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.309202137388913, 3.836091998452219}, {
       6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.309202137388913, 
       3.836091998452219}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.157855081110001, 3.573951207401159}, {6.09710621629842, 
       3.639486405163924}, {6.09710621629842, 3.639486405163924}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}}], 
      LineBox[{{6.157855081110001, 3.573951207401159}, {6.09710621629842, 
       3.639486405163924}, {6.09710621629842, 3.639486405163924}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}}], 
      LineBox[{{6.157855081110001, 3.573951207401159}, {6.09710621629842, 
       3.639486405163924}, {6.09710621629842, 3.639486405163924}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}}], 
      LineBox[{{6.157855081110001, 3.573951207401159}, {6.09710621629842, 
       3.639486405163924}, {6.09710621629842, 3.639486405163924}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}}], 
      LineBox[{{6.09710621629842, 3.639486405163924}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}}], 
      LineBox[{{6.09710621629842, 3.639486405163924}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}}], 
      LineBox[{{6.09710621629842, 3.639486405163924}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}}], 
      LineBox[{{6.09710621629842, 3.639486405163924}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}}], 
      LineBox[{{6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}], 
      LineBox[{{6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}], 
      LineBox[{{6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}], 
      LineBox[{{6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}], 
      LineBox[{{6.09710621629842, 3.770556800689454}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}}], 
      LineBox[{{6.09710621629842, 3.770556800689454}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}}], 
      LineBox[{{6.09710621629842, 3.770556800689454}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}}], 
      LineBox[{{6.09710621629842, 3.770556800689454}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}], 
      LineBox[{{6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}], 
      LineBox[{{6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}], 
      LineBox[{{6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}], 
      LineBox[{{6.358494951829567, 3.6196439438674104`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.358494951829567, 3.6196439438674104`}, {6.358494951829567, 
       3.6196439438674104`}}], 
      LineBox[{{6.358494951829567, 3.6196439438674104`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.358494951829567, 3.6196439438674104`}, {6.358494951829567, 
       3.6196439438674104`}}], 
      LineBox[{{6.358494951829567, 3.6196439438674104`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.358494951829567, 3.6196439438674104`}, {6.358494951829567, 
       3.6196439438674104`}}], 
      LineBox[{{6.358494951829567, 3.6196439438674104`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.358494951829567, 3.6196439438674104`}, {6.358494951829567, 
       3.6196439438674104`}}], 
      LineBox[{{6.309202137388913, 3.573951207401159}, {6.244984659620384, 
       3.5541087461046454`}, {6.244984659620384, 3.5541087461046454`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}}], 
      LineBox[{{6.309202137388913, 3.573951207401159}, {6.244984659620384, 
       3.5541087461046454`}, {6.244984659620384, 3.5541087461046454`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}}], 
      LineBox[{{6.309202137388913, 3.573951207401159}, {6.244984659620384, 
       3.5541087461046454`}, {6.244984659620384, 3.5541087461046454`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}}], 
      LineBox[{{6.309202137388913, 3.573951207401159}, {6.244984659620384, 
       3.5541087461046454`}, {6.244984659620384, 3.5541087461046454`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}}], 
      LineBox[{{6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}}], 
      LineBox[{{6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}}], 
      LineBox[{{6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}}], 
      LineBox[{{6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}], 
      LineBox[{{6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}], 
      LineBox[{{6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}], 
      LineBox[{{6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}], 
      LineBox[{{6.244984659620384, 3.8559344597487324`}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}}], 
      LineBox[{{6.244984659620384, 3.8559344597487324`}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}}], 
      LineBox[{{6.244984659620384, 3.8559344597487324`}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}}], 
      LineBox[{{6.244984659620384, 3.8559344597487324`}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}}], 
      LineBox[{{6.309202137388913, 3.836091998452219}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}], 
      LineBox[{{6.309202137388913, 3.836091998452219}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}], 
      LineBox[{{6.309202137388913, 3.836091998452219}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}], 
      LineBox[{{6.309202137388913, 3.836091998452219}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}], 
      LineBox[{{6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.358494951829567, 
       3.7903992619859674`}}], 
      LineBox[{{6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.358494951829567, 
       3.7903992619859674`}}], 
      LineBox[{{6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.358494951829567, 
       3.7903992619859674`}}], 
      LineBox[{{6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.358494951829567, 
       3.7903992619859674`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}], 
      LineBox[{{6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}], 
      LineBox[{{6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}], 
      LineBox[{{6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}], 
      LineBox[{{6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}], 
      LineBox[{{6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}], 
      LineBox[{{6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}], 
      LineBox[{{6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}], 
      LineBox[{{6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}], 
      LineBox[{{6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}], 
      LineBox[{{6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}], 
      LineBox[{{6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}], 
      LineBox[{{6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}], 
      LineBox[{{6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}], 
      LineBox[{{6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}], 
      LineBox[{{6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}], 
      LineBox[{{6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}], 
      LineBox[{{6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}], 
      LineBox[{{6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}], 
      LineBox[{{6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}], 
      LineBox[{{6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}], 
      LineBox[{{6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}], 
      LineBox[{{6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}], 
      LineBox[{{6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}], 
      LineBox[{{6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}], 
      LineBox[{{6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}], 
      LineBox[{{6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}], 
      LineBox[{{6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}], 
      LineBox[{{6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}], 
      LineBox[{{6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}], 
      LineBox[{{6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}], 
      LineBox[{{6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}], 
      LineBox[{{6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}], 
      LineBox[{{6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}], 
      LineBox[{{6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}], 
      LineBox[{{6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}], 
      LineBox[{{6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}], 
      LineBox[{{6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}], 
      LineBox[{{6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}], 
      LineBox[{{6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}], 
      LineBox[{{6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}], 
      LineBox[{{6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}], 
      LineBox[{{6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}], 
      LineBox[{{6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}], 
      LineBox[{{6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}], 
      LineBox[{{6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}], 
      LineBox[{{6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}], 
      LineBox[{{6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}], 
      LineBox[{{6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}], 
      LineBox[{{6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}], 
      LineBox[{{6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}], 
      LineBox[{{6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}], 
      LineBox[{{6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}], 
      LineBox[{{6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}], 
      LineBox[{{6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}], 
      LineBox[{{6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}], 
      LineBox[{{6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}], 
      LineBox[{{6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}], 
      LineBox[{{6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}], 
      LineBox[{{6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}], 
      LineBox[{{6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}], 
      LineBox[{{6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}], 
      LineBox[{{6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}], 
      LineBox[{{6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}], 
      LineBox[{{6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}], 
      LineBox[{{6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}], 
      LineBox[{{6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}], 
      LineBox[{{6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}], 
      LineBox[{{6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}], 
      LineBox[{{6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}], 
      LineBox[{{6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}], 
      LineBox[{{6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}], 
      LineBox[{{6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}], 
      LineBox[{{6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}], 
      LineBox[{{6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}], 
      LineBox[{{6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}], 
      LineBox[{{6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}], 
      LineBox[{{6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}], 
      LineBox[{{6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}], 
      LineBox[{{6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}], 
      LineBox[{{6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}], 
      LineBox[{{6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}], 
      LineBox[{{6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}], 
      LineBox[{{6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}], 
      LineBox[{{6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}], 
      LineBox[{{6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}], 
      LineBox[{{6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}], 
      LineBox[{{6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}], 
      LineBox[{{6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}], 
      LineBox[{{6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}], 
      LineBox[{{6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}], 
      LineBox[{{6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}], 
      LineBox[{{6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}], 
      LineBox[{{6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}], 
      LineBox[{{6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}], 
      LineBox[{{6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}], 
      LineBox[{{6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}], 
      LineBox[{{6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}], 
      LineBox[{{6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}], 
      LineBox[{{6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}], 
      LineBox[{{6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}], 
      LineBox[{{6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}], 
      LineBox[{{6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}], 
      LineBox[{{6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}], 
      LineBox[{{6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}], 
      LineBox[{{6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}], 
      LineBox[{{6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}], 
      LineBox[{{6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}], 
      LineBox[{{6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}], 
      LineBox[{{6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}], 
      LineBox[{{6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}], 
      LineBox[{{6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}], 
      LineBox[{{6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}], 
      LineBox[{{6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}], 
      LineBox[{{6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}], 
      LineBox[{{6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}], 
      LineBox[{{6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}], 
      LineBox[{{6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}], 
      LineBox[{{6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}], 
      LineBox[{{6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}], 
      LineBox[{{6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}], 
      LineBox[{{6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}], 
      LineBox[{{6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}], 
      LineBox[{{6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}], 
      LineBox[{{6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}], 
      LineBox[{{6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}], 
      LineBox[{{6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}], 
      LineBox[{{6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}], 
      LineBox[{{6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}], 
      LineBox[{{6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}], 
      LineBox[{{6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}], 
      LineBox[{{6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}], 
      LineBox[{{6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}], 
      LineBox[{{6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}], 
      LineBox[{{6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}], 
      LineBox[{{6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}], 
      LineBox[{{6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}], 
      LineBox[{{6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}], 
      LineBox[{{6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}], 
      LineBox[{{6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}], 
      LineBox[{{6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}], 
      LineBox[{{6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}], 
      LineBox[{{6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}], 
      LineBox[{{6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}], 
      LineBox[{{6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}], 
      LineBox[{{6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}], 
      LineBox[{{6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}], 
      LineBox[{{6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}], 
      LineBox[{{6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}], 
      LineBox[{{6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}], 
      LineBox[{{6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}], 
      LineBox[{{6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}], 
      LineBox[{{6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}], 
      LineBox[{{6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}], 
      LineBox[{{6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}], 
      LineBox[{{6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}], 
      LineBox[{{6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}], 
      LineBox[{{6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}], 
      LineBox[{{6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}], 
      LineBox[{{6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}], 
      LineBox[{{6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}], 
      LineBox[{{6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}], 
      LineBox[{{6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}], 
      LineBox[{{6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}], 
      LineBox[{{6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}], 
      LineBox[{{6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}], 
      LineBox[{{6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}], 
      LineBox[{{6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}], 
      LineBox[{{6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}], 
      LineBox[{{6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}], 
      LineBox[{{6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}], 
      LineBox[{{6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}], 
      LineBox[{{6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}], 
      LineBox[{{6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}], 
      LineBox[{{6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}], 
      LineBox[{{6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}], 
      LineBox[{{6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}], 
      LineBox[{{6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}], 
      LineBox[{{6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}], 
      LineBox[{{6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}], 
      LineBox[{{6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}], 
      LineBox[{{6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}], 
      LineBox[{{6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}], 
      LineBox[{{6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}], 
      LineBox[{{6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}], 
      LineBox[{{6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}], 
      LineBox[{{6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}], 
      LineBox[{{6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}], 
      LineBox[{{6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}], 
      LineBox[{{6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}], 
      LineBox[{{6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}], 
      LineBox[{{6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}], 
      LineBox[{{6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}], 
      LineBox[{{6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}], 
      LineBox[{{6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}], 
      LineBox[{{6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}], 
      LineBox[{{6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}], 
      LineBox[{{6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}], 
      LineBox[{{6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}], 
      LineBox[{{6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}], 
      LineBox[{{6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}], 
      LineBox[{{6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}], 
      LineBox[{{6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}], 
      LineBox[{{6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}], 
      LineBox[{{6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}], 
      LineBox[{{6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}], 
      LineBox[{{6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}], 
      LineBox[{{6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}], 
      LineBox[{{6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}], 
      LineBox[{{6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}], 
      LineBox[{{6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}], 
      LineBox[{{6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}], 
      LineBox[{{6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}], 
      LineBox[{{6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}], 
      LineBox[{{6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}], 
      LineBox[{{6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}], 
      LineBox[{{6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}], 
      LineBox[{{6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}], 
      LineBox[{{6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}], 
      LineBox[{{6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}], 
      LineBox[{{6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}], 
      LineBox[{{6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}], 
      LineBox[{{6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}], 
      LineBox[{{6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}], 
      LineBox[{{6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}], 
      LineBox[{{6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}], 
      LineBox[{{6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}], 
      LineBox[{{6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}], 
      LineBox[{{6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}], 
      LineBox[{{6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}], 
      LineBox[{{6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}], 
      LineBox[{{6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}], 
      LineBox[{{6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}], 
      LineBox[{{6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}], 
      LineBox[{{6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}], 
      LineBox[{{6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}], 
      LineBox[{{6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}], 
      LineBox[{{6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}], 
      LineBox[{{6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}], 
      LineBox[{{6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}], 
      LineBox[{{6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}], 
      LineBox[{{6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}], 
      LineBox[{{6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}], 
      LineBox[{{6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}], 
      LineBox[{{6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}], 
      LineBox[{{6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}], 
      LineBox[{{6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}], 
      LineBox[{{6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}], 
      LineBox[{{6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}], 
      LineBox[{{6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}], 
      LineBox[{{6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}], 
      LineBox[{{6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}], 
      LineBox[{{6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}], 
      LineBox[{{6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}], 
      LineBox[{{6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}], 
      LineBox[{{6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}], 
      LineBox[{{6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}], 
      LineBox[{{6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}], 
      LineBox[{{6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}], 
      LineBox[{{6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}], 
      LineBox[{{6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}], 
      LineBox[{{6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}], 
      LineBox[{{6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}], 
      LineBox[{{6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}], 
      LineBox[{{6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}], 
      LineBox[{{6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}], 
      LineBox[{{6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}], 
      LineBox[{{6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}], 
      LineBox[{{6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}], 
      LineBox[{{6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}], 
      LineBox[{{6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774719`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}], 
      LineBox[{{6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}], 
      LineBox[{{6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}], 
      LineBox[{{6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}], 
      LineBox[{{6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}], 
      LineBox[{{6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}], 
      LineBox[{{6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}], 
      LineBox[{{6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}], 
      LineBox[{{6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}], 
      LineBox[{{6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}], 
      LineBox[{{6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}], 
      LineBox[{{6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}], 
      LineBox[{{6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}], 
      LineBox[{{6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}], 
      LineBox[{{6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}], 
      LineBox[{{6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}], 
      LineBox[{{6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}], 
      LineBox[{{6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}], 
      LineBox[{{6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}], 
      LineBox[{{6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}], 
      LineBox[{{6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}], 
      LineBox[{{6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}], 
      LineBox[{{6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}], 
      LineBox[{{6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}], 
      LineBox[{{6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}], 
      LineBox[{{6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}], 
      LineBox[{{6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}], 
      LineBox[{{6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}], 
      LineBox[{{6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}], 
      LineBox[{{6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}], 
      LineBox[{{6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}], 
      LineBox[{{6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}], 
      LineBox[{{6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}], 
      LineBox[{{6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}], 
      LineBox[{{6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}], 
      LineBox[{{6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}], 
      LineBox[{{6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}], 
      LineBox[{{6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}], 
      LineBox[{{6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}], 
      LineBox[{{6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}], 
      LineBox[{{6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}], 
      LineBox[{{6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}], 
      LineBox[{{6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}], 
      LineBox[{{6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}], 
      LineBox[{{6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}], 
      LineBox[{{6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}], 
      LineBox[{{6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}], 
      LineBox[{{6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}], 
      LineBox[{{6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}], 
      LineBox[{{6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}], 
      LineBox[{{6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}], 
      LineBox[{{6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}], 
      LineBox[{{6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}], 
      LineBox[{{6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}], 
      LineBox[{{6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}], 
      LineBox[{{6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}], 
      LineBox[{{6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}], 
      LineBox[{{6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}], 
      LineBox[{{6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}], 
      LineBox[{{6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}], 
      LineBox[{{6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}], 
      LineBox[{{6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}], 
      LineBox[{{6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}], 
      LineBox[{{6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}], 
      LineBox[{{6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}], 
      LineBox[{{6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}], 
      LineBox[{{6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}], 
      LineBox[{{6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}], 
      LineBox[{{6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}], 
      LineBox[{{6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}], 
      LineBox[{{6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}], 
      LineBox[{{6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}], 
      LineBox[{{6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}], 
      LineBox[{{6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}], 
      LineBox[{{6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}], 
      LineBox[{{6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}], 
      LineBox[{{6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}], 
      LineBox[{{6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}], 
      LineBox[{{6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}], 
      LineBox[{{6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}], 
      LineBox[{{6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}], 
      LineBox[{{6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}], 
      LineBox[{{6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}], 
      LineBox[{{6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}], 
      LineBox[{{6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}], 
      LineBox[{{6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}], 
      LineBox[{{6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}], 
      LineBox[{{6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}], 
      LineBox[{{6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}], 
      LineBox[{{6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}], 
      LineBox[{{6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}], 
      LineBox[{{6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}], 
      LineBox[{{6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}], 
      LineBox[{{6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}], 
      LineBox[{{6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}], 
      LineBox[{{6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}], 
      LineBox[{{6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}], 
      LineBox[{{6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}], 
      LineBox[{{6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}], 
      LineBox[{{6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}], 
      LineBox[{{6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}], 
      LineBox[{{6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}], 
      LineBox[{{6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}], 
      LineBox[{{6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}], 
      LineBox[{{6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}], 
      LineBox[{{6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}], 
      LineBox[{{6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}], 
      LineBox[{{6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}], 
      LineBox[{{6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}], 
      LineBox[{{6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}], 
      LineBox[{{6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}], 
      LineBox[{{6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}], 
      LineBox[{{6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}], 
      LineBox[{{6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}], 
      LineBox[{{6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}], 
      LineBox[{{6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}], 
      LineBox[{{6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}], 
      LineBox[{{6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}], 
      LineBox[{{6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}], 
      LineBox[{{6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}], 
      LineBox[{{6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}], 
      LineBox[{{6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}], 
      LineBox[{{6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}], 
      LineBox[{{6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}], 
      LineBox[{{6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}], 
      LineBox[{{6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}], 
      LineBox[{{6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}], 
      LineBox[{{6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}], 
      LineBox[{{6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}], 
      LineBox[{{6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}], 
      LineBox[{{6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}], 
      LineBox[{{6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}], 
      LineBox[{{6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}], 
      LineBox[{{6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}], 
      LineBox[{{6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}], 
      LineBox[{{6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, 0.10458225215268897`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, -0.03448237988931001}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.419448594430425, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.580026599918834, 0.17411456817368842`}, {
       6.632325878295307, 0.12563494347892964`}, {6.660315602663038, 
       0.0350499361316895}, {6.660315602663038, 0.0350499361316895}, {
       6.632325878295307, 0.12563494347892964`}, {6.580026599918834, 
       0.17411456817368842`}, {6.511892374179, 0.19516725949992914`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}], 
      LineBox[{{6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}], 
      LineBox[{{6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}], 
      LineBox[{{6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}], 
      LineBox[{{6.354994539049581, -0.034482379889309994`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}], 
      LineBox[{{6.354994539049581, -0.034482379889309994`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}], 
      LineBox[{{6.354994539049581, -0.034482379889309994`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}], 
      LineBox[{{6.354994539049581, -0.034482379889309994`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}], 
      LineBox[{{6.3391595916862205`, 0.03504993613168948}, {6.354994539049581,
        0.10458225215268896`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}}], 
      LineBox[{{6.3391595916862205`, 0.03504993613168948}, {6.354994539049581,
        0.10458225215268896`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}}], 
      LineBox[{{6.3391595916862205`, 0.03504993613168948}, {6.354994539049581,
        0.10458225215268896`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}}], 
      LineBox[{{6.3391595916862205`, 0.03504993613168948}, {6.354994539049581,
        0.10458225215268896`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}}], 
      LineBox[{{6.354994539049581, 0.10458225215268897`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}, {
       6.354994539049581, 0.10458225215268897`}, {6.354994539049581, 
       0.10458225215268897`}}], 
      LineBox[{{6.354994539049581, 0.10458225215268897`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}, {
       6.354994539049581, 0.10458225215268897`}, {6.354994539049581, 
       0.10458225215268897`}}], 
      LineBox[{{6.354994539049581, 0.10458225215268897`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}, {
       6.354994539049581, 0.10458225215268897`}, {6.354994539049581, 
       0.10458225215268897`}}], 
      LineBox[{{6.354994539049581, 0.10458225215268897`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}, {
       6.354994539049581, 0.10458225215268897`}, {6.354994539049581, 
       0.10458225215268897`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}], 
      LineBox[{{6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}], 
      LineBox[{{6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}], 
      LineBox[{{6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}], 
      LineBox[{{6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}], 
      LineBox[{{6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}], 
      LineBox[{{6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}], 
      LineBox[{{6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}], 
      LineBox[{{6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}], 
      LineBox[{{6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}], 
      LineBox[{{6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}], 
      LineBox[{{6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}], 
      LineBox[{{6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}], 
      LineBox[{{6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}], 
      LineBox[{{6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}], 
      LineBox[{{6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.419448594430425, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.511892374179, 0.19516725949992914`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}}], 
      LineBox[{{6.419448594430425, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.511892374179, 0.19516725949992914`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}}], 
      LineBox[{{6.419448594430425, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.511892374179, 0.19516725949992914`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}}], 
      LineBox[{{6.419448594430425, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.511892374179, 0.19516725949992914`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}}], 
      LineBox[{{6.511892374179, 0.19516725949992914`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}}], 
      LineBox[{{6.511892374179, 0.19516725949992914`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}}], 
      LineBox[{{6.511892374179, 0.19516725949992914`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}}], 
      LineBox[{{6.511892374179, 0.19516725949992914`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}}], 
      LineBox[{{6.580026599918834, 0.17411456817368842`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}], 
      LineBox[{{6.580026599918834, 0.17411456817368842`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}], 
      LineBox[{{6.580026599918834, 0.17411456817368842`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}], 
      LineBox[{{6.580026599918834, 0.17411456817368842`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}], 
      LineBox[{{6.632325878295307, 0.12563494347892964`}, {6.660315602663038, 
       0.035049936131689455`}, {6.660315602663038, 0.035049936131689455`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}}], 
      LineBox[{{6.632325878295307, 0.12563494347892964`}, {6.660315602663038, 
       0.035049936131689455`}, {6.660315602663038, 0.035049936131689455`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}}], 
      LineBox[{{6.632325878295307, 0.12563494347892964`}, {6.660315602663038, 
       0.035049936131689455`}, {6.660315602663038, 0.035049936131689455`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}}], 
      LineBox[{{6.632325878295307, 0.12563494347892964`}, {6.660315602663038, 
       0.035049936131689455`}, {6.660315602663038, 0.035049936131689455`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.337909661427842, 
       0.5285951207726394}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.45381736808778755`}, {6.53674492235038, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.53674492235038, 
       0.41379752935462266`}, {6.579917877992374, 0.45381736808778755`}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.404188081735354, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.53674492235038, 0.6433927121906561}, {
       6.579917877992374, 0.6033728734574912}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.6033728734574912}, {6.53674492235038, 
       0.6433927121906561}, {6.480500247531105, 0.6607716691664995}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}], 
      LineBox[{{6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}], 
      LineBox[{{6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}], 
      LineBox[{{6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}], 
      LineBox[{{6.350981380605122, 0.471196325063631}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.471196325063631}, {6.350981380605122, 
       0.471196325063631}}], 
      LineBox[{{6.350981380605122, 0.471196325063631}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.471196325063631}, {6.350981380605122, 
       0.471196325063631}}], 
      LineBox[{{6.350981380605122, 0.471196325063631}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.471196325063631}, {6.350981380605122, 
       0.471196325063631}}], 
      LineBox[{{6.350981380605122, 0.471196325063631}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.471196325063631}, {6.350981380605122, 
       0.471196325063631}}], 
      LineBox[{{6.337909661427842, 0.5285951207726394}, {6.350981380605122, 
       0.5859939164816478}, {6.350981380605122, 0.5859939164816478}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}}], 
      LineBox[{{6.337909661427842, 0.5285951207726394}, {6.350981380605122, 
       0.5859939164816478}, {6.350981380605122, 0.5859939164816478}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}}], 
      LineBox[{{6.337909661427842, 0.5285951207726394}, {6.350981380605122, 
       0.5859939164816478}, {6.350981380605122, 0.5859939164816478}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}}], 
      LineBox[{{6.337909661427842, 0.5285951207726394}, {6.350981380605122, 
       0.5859939164816478}, {6.350981380605122, 0.5859939164816478}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}}], 
      LineBox[{{6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}}], 
      LineBox[{{6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}}], 
      LineBox[{{6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}}], 
      LineBox[{{6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}}], 
      LineBox[{{6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}}], 
      LineBox[{{6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}}], 
      LineBox[{{6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}}], 
      LineBox[{{6.579917877992374, 0.45381736808778755`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}}], 
      LineBox[{{6.579917877992374, 0.45381736808778755`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}}], 
      LineBox[{{6.579917877992374, 0.45381736808778755`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}}], 
      LineBox[{{6.579917877992374, 0.45381736808778755`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}}], 
      LineBox[{{6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}], 
      LineBox[{{6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}], 
      LineBox[{{6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}], 
      LineBox[{{6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}], 
      LineBox[{{6.480500247531105, 0.3964185723787792}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.480500247531105, 
       0.3964185723787792}}], 
      LineBox[{{6.480500247531105, 0.3964185723787792}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.480500247531105, 
       0.3964185723787792}}], 
      LineBox[{{6.480500247531105, 0.3964185723787792}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.480500247531105, 
       0.3964185723787792}}], 
      LineBox[{{6.480500247531105, 0.3964185723787792}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.480500247531105, 
       0.3964185723787792}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.404188081735354, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.480500247531105, 0.6607716691664995}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}}], 
      LineBox[{{6.404188081735354, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.480500247531105, 0.6607716691664995}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}}], 
      LineBox[{{6.404188081735354, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.480500247531105, 0.6607716691664995}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}}], 
      LineBox[{{6.404188081735354, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.480500247531105, 0.6607716691664995}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}}], 
      LineBox[{{6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}}], 
      LineBox[{{6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}}], 
      LineBox[{{6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}}], 
      LineBox[{{6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}}], 
      LineBox[{{6.53674492235038, 0.6433927121906561}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}}], 
      LineBox[{{6.53674492235038, 0.6433927121906561}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}}], 
      LineBox[{{6.53674492235038, 0.6433927121906561}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}}], 
      LineBox[{{6.53674492235038, 0.6433927121906561}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}}], 
      LineBox[{{6.579917877992374, 0.6033728734574912}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}}], 
      LineBox[{{6.579917877992374, 0.6033728734574912}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}}], 
      LineBox[{{6.579917877992374, 0.6033728734574912}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}}], 
      LineBox[{{6.579917877992374, 0.6033728734574912}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.1786313880649457`}, {6.380412974199382, 1.1786313880649457`}, {
       6.311538024565798, 1.1043298606349732`}, {6.294616960473593, 
       1.0300283332050004`}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       0.9332301134229565}, {6.552005001650963, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.552005001650963, 
       0.881425278345055}, {6.607891479899203, 0.9332301134229565}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.380412974199382, 1.178631388064946}, {6.479197459310518, 
       1.201128080417017}, {6.552005001650963, 1.1786313880649457`}, {
       6.607891479899203, 1.1268265529870445`}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 1.1268265529870445`}, {6.552005001650963, 
       1.1786313880649457`}, {6.479197459310518, 1.201128080417017}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}], 
      LineBox[{{6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}], 
      LineBox[{{6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}], 
      LineBox[{{6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}], 
      LineBox[{{6.311538024565798, 0.9557268057750277}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 0.9557268057750277}, {6.311538024565798, 
       0.9557268057750277}}], 
      LineBox[{{6.311538024565798, 0.9557268057750277}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 0.9557268057750277}, {6.311538024565798, 
       0.9557268057750277}}], 
      LineBox[{{6.311538024565798, 0.9557268057750277}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 0.9557268057750277}, {6.311538024565798, 
       0.9557268057750277}}], 
      LineBox[{{6.311538024565798, 0.9557268057750277}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 0.9557268057750277}, {6.311538024565798, 
       0.9557268057750277}}], 
      LineBox[{{6.294616960473593, 1.0300283332050004`}, {6.311538024565798, 
       1.1043298606349732`}, {6.311538024565798, 1.1043298606349732`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}}], 
      LineBox[{{6.294616960473593, 1.0300283332050004`}, {6.311538024565798, 
       1.1043298606349732`}, {6.311538024565798, 1.1043298606349732`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}}], 
      LineBox[{{6.294616960473593, 1.0300283332050004`}, {6.311538024565798, 
       1.1043298606349732`}, {6.311538024565798, 1.1043298606349732`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}}], 
      LineBox[{{6.294616960473593, 1.0300283332050004`}, {6.311538024565798, 
       1.1043298606349732`}, {6.311538024565798, 1.1043298606349732`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}}], 
      LineBox[{{6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}}], 
      LineBox[{{6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}}], 
      LineBox[{{6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}}], 
      LineBox[{{6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}}], 
      LineBox[{{6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}}], 
      LineBox[{{6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}}], 
      LineBox[{{6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}}], 
      LineBox[{{6.607891479899203, 0.9332301134229565}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}}], 
      LineBox[{{6.607891479899203, 0.9332301134229565}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}}], 
      LineBox[{{6.607891479899203, 0.9332301134229565}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}}], 
      LineBox[{{6.607891479899203, 0.9332301134229565}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}}], 
      LineBox[{{6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}], 
      LineBox[{{6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}], 
      LineBox[{{6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}], 
      LineBox[{{6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}], 
      LineBox[{{6.479197459310518, 0.8589285859929837}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.479197459310518, 
       0.8589285859929837}}], 
      LineBox[{{6.479197459310518, 0.8589285859929837}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.479197459310518, 
       0.8589285859929837}}], 
      LineBox[{{6.479197459310518, 0.8589285859929837}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.479197459310518, 
       0.8589285859929837}}], 
      LineBox[{{6.479197459310518, 0.8589285859929837}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.479197459310518, 
       0.8589285859929837}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.380412974199382, 1.178631388064946}, {6.479197459310518, 
       1.201128080417017}, {6.479197459310518, 1.201128080417017}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}}], 
      LineBox[{{6.380412974199382, 1.178631388064946}, {6.479197459310518, 
       1.201128080417017}, {6.479197459310518, 1.201128080417017}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}}], 
      LineBox[{{6.380412974199382, 1.178631388064946}, {6.479197459310518, 
       1.201128080417017}, {6.479197459310518, 1.201128080417017}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}}], 
      LineBox[{{6.380412974199382, 1.178631388064946}, {6.479197459310518, 
       1.201128080417017}, {6.479197459310518, 1.201128080417017}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}}], 
      LineBox[{{6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}}], 
      LineBox[{{6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}}], 
      LineBox[{{6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}}], 
      LineBox[{{6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}}], 
      LineBox[{{6.552005001650963, 1.1786313880649457`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}}], 
      LineBox[{{6.552005001650963, 1.1786313880649457`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}}], 
      LineBox[{{6.552005001650963, 1.1786313880649457`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}}], 
      LineBox[{{6.552005001650963, 1.1786313880649457`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}}], 
      LineBox[{{6.607891479899203, 1.1268265529870445`}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}}], 
      LineBox[{{6.607891479899203, 1.1268265529870445`}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}}], 
      LineBox[{{6.607891479899203, 1.1268265529870445`}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}}], 
      LineBox[{{6.607891479899203, 1.1268265529870445`}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`,
        1.4354354382816115`}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802, 
       1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.340742083096224, 
       1.50445339975363}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.4145384809819588`}, {6.579827314904959, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.579827314904959, 
       1.3664174768095927`}, {6.631739717461946, 1.4145384809819588`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.420437160365802, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.579827314904959, 1.6424893226976673`}, {
       6.631739717461946, 1.5943683185253013`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.5943683185253013`}, {6.579827314904959, 
       1.6424893226976673`}, {6.512197101557579, 1.66338627999732}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`,
        1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}], 
      LineBox[{{6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`,
        1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}], 
      LineBox[{{6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`,
        1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}], 
      LineBox[{{6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`,
        1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}], 
      LineBox[{{6.3564598938866155`, 1.4354354382816115`}, {6.340742083096224,
        1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.3564598938866155`, 
       1.4354354382816115`}}], 
      LineBox[{{6.3564598938866155`, 1.4354354382816115`}, {6.340742083096224,
        1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.3564598938866155`, 
       1.4354354382816115`}}], 
      LineBox[{{6.3564598938866155`, 1.4354354382816115`}, {6.340742083096224,
        1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.3564598938866155`, 
       1.4354354382816115`}}], 
      LineBox[{{6.3564598938866155`, 1.4354354382816115`}, {6.340742083096224,
        1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.3564598938866155`, 
       1.4354354382816115`}}], 
      LineBox[{{6.340742083096224, 1.50445339975363}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}}], 
      LineBox[{{6.340742083096224, 1.50445339975363}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}}], 
      LineBox[{{6.340742083096224, 1.50445339975363}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}}], 
      LineBox[{{6.340742083096224, 1.50445339975363}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}}], 
      LineBox[{{6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802,
        1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}}], 
      LineBox[{{6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802,
        1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}}], 
      LineBox[{{6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802,
        1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}}], 
      LineBox[{{6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802,
        1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}}], 
      LineBox[{{6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}}], 
      LineBox[{{6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}}], 
      LineBox[{{6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}}], 
      LineBox[{{6.631739717461946, 1.4145384809819588`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}}], 
      LineBox[{{6.631739717461946, 1.4145384809819588`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}}], 
      LineBox[{{6.631739717461946, 1.4145384809819588`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}}], 
      LineBox[{{6.631739717461946, 1.4145384809819588`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}}], 
      LineBox[{{6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}], 
      LineBox[{{6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}], 
      LineBox[{{6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}], 
      LineBox[{{6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}], 
      LineBox[{{6.512197101557579, 1.34552051950994}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.512197101557579, 
       1.34552051950994}}], 
      LineBox[{{6.512197101557579, 1.34552051950994}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.512197101557579, 
       1.34552051950994}}], 
      LineBox[{{6.512197101557579, 1.34552051950994}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.512197101557579, 
       1.34552051950994}}], 
      LineBox[{{6.512197101557579, 1.34552051950994}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.512197101557579, 
       1.34552051950994}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.420437160365802, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.512197101557579, 1.66338627999732}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}}], 
      LineBox[{{6.420437160365802, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.512197101557579, 1.66338627999732}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}}], 
      LineBox[{{6.420437160365802, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.512197101557579, 1.66338627999732}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}}], 
      LineBox[{{6.420437160365802, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.512197101557579, 1.66338627999732}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}}], 
      LineBox[{{6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}}], 
      LineBox[{{6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}}], 
      LineBox[{{6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}}], 
      LineBox[{{6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}}], 
      LineBox[{{6.579827314904959, 1.6424893226976673`}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}}], 
      LineBox[{{6.579827314904959, 1.6424893226976673`}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}}], 
      LineBox[{{6.579827314904959, 1.6424893226976673`}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}}], 
      LineBox[{{6.579827314904959, 1.6424893226976673`}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}}], 
      LineBox[{{6.631739717461946, 1.5943683185253013`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}}], 
      LineBox[{{6.631739717461946, 1.5943683185253013`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}}], 
      LineBox[{{6.631739717461946, 1.5943683185253013`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}}], 
      LineBox[{{6.631739717461946, 1.5943683185253013`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.1305649472193093`}, {6.438983334450372, 2.1305649472193093`}, {
       6.374161779971002, 2.0606361772699255`}, {6.358236546141619, 
       1.9907074073205417`}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       1.8996059094539193`}, {6.600476911067876, 1.850849867421774}, {
       6.53195420292162, 1.8296771395045353`}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}, {
       6.531954202921621, 1.8296771395045353`}, {6.600476911067876, 
       1.850849867421774}, {6.653074385384749, 1.8996059094539193`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.438983334450372, 2.13056494721931}, {6.531954202921621, 
       2.1517376751365482`}, {6.600476911067876, 2.1305649472193093`}, {
       6.653074385384749, 2.0818089051871644`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 2.0818089051871644`}, {6.600476911067876, 
       2.1305649472193093`}, {6.53195420292162, 2.1517376751365482`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}], 
      LineBox[{{6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}], 
      LineBox[{{6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}], 
      LineBox[{{6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}], 
      LineBox[{{6.374161779971002, 1.920778637371158}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 1.920778637371158}, {6.374161779971002, 
       1.920778637371158}}], 
      LineBox[{{6.374161779971002, 1.920778637371158}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 1.920778637371158}, {6.374161779971002, 
       1.920778637371158}}], 
      LineBox[{{6.374161779971002, 1.920778637371158}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 1.920778637371158}, {6.374161779971002, 
       1.920778637371158}}], 
      LineBox[{{6.374161779971002, 1.920778637371158}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 1.920778637371158}, {6.374161779971002, 
       1.920778637371158}}], 
      LineBox[{{6.358236546141619, 1.9907074073205417`}, {6.374161779971002, 
       2.0606361772699255`}, {6.374161779971002, 2.0606361772699255`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}}], 
      LineBox[{{6.358236546141619, 1.9907074073205417`}, {6.374161779971002, 
       2.0606361772699255`}, {6.374161779971002, 2.0606361772699255`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}}], 
      LineBox[{{6.358236546141619, 1.9907074073205417`}, {6.374161779971002, 
       2.0606361772699255`}, {6.374161779971002, 2.0606361772699255`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}}], 
      LineBox[{{6.358236546141619, 1.9907074073205417`}, {6.374161779971002, 
       2.0606361772699255`}, {6.374161779971002, 2.0606361772699255`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}}], 
      LineBox[{{6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}}], 
      LineBox[{{6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}}], 
      LineBox[{{6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}}], 
      LineBox[{{6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}}], 
      LineBox[{{6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}}], 
      LineBox[{{6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}}], 
      LineBox[{{6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}}], 
      LineBox[{{6.653074385384749, 1.8996059094539193`}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}}], 
      LineBox[{{6.653074385384749, 1.8996059094539193`}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}}], 
      LineBox[{{6.653074385384749, 1.8996059094539193`}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}}], 
      LineBox[{{6.653074385384749, 1.8996059094539193`}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}}], 
      LineBox[{{6.600476911067876, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.531954202921621, 1.8296771395045353`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}], 
      LineBox[{{6.600476911067876, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.531954202921621, 1.8296771395045353`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}], 
      LineBox[{{6.600476911067876, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.531954202921621, 1.8296771395045353`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}], 
      LineBox[{{6.600476911067876, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.531954202921621, 1.8296771395045353`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}], 
      LineBox[{{6.53195420292162, 1.8296771395045353`}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}, {
       6.53195420292162, 1.8296771395045353`}, {6.53195420292162, 
       1.8296771395045353`}}], 
      LineBox[{{6.53195420292162, 1.8296771395045353`}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}, {
       6.53195420292162, 1.8296771395045353`}, {6.53195420292162, 
       1.8296771395045353`}}], 
      LineBox[{{6.53195420292162, 1.8296771395045353`}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}, {
       6.53195420292162, 1.8296771395045353`}, {6.53195420292162, 
       1.8296771395045353`}}], 
      LineBox[{{6.53195420292162, 1.8296771395045353`}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}, {
       6.53195420292162, 1.8296771395045353`}, {6.53195420292162, 
       1.8296771395045353`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.438983334450372, 2.13056494721931}, {6.531954202921621, 
       2.1517376751365482`}, {6.531954202921621, 2.1517376751365482`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}}], 
      LineBox[{{6.438983334450372, 2.13056494721931}, {6.531954202921621, 
       2.1517376751365482`}, {6.531954202921621, 2.1517376751365482`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}}], 
      LineBox[{{6.438983334450372, 2.13056494721931}, {6.531954202921621, 
       2.1517376751365482`}, {6.531954202921621, 2.1517376751365482`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}}], 
      LineBox[{{6.438983334450372, 2.13056494721931}, {6.531954202921621, 
       2.1517376751365482`}, {6.531954202921621, 2.1517376751365482`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}}], 
      LineBox[{{6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}}], 
      LineBox[{{6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}}], 
      LineBox[{{6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}}], 
      LineBox[{{6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}}], 
      LineBox[{{6.600476911067876, 2.1305649472193093`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}}], 
      LineBox[{{6.600476911067876, 2.1305649472193093`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}}], 
      LineBox[{{6.600476911067876, 2.1305649472193093`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}}], 
      LineBox[{{6.600476911067876, 2.1305649472193093`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}}], 
      LineBox[{{6.653074385384749, 2.0818089051871644`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}}], 
      LineBox[{{6.653074385384749, 2.0818089051871644`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}}], 
      LineBox[{{6.653074385384749, 2.0818089051871644`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}}], 
      LineBox[{{6.653074385384749, 2.0818089051871644`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.299112196457192, 
       2.51343200227038}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.4188320180517047`}, {6.550655093509228, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.550655093509228, 
       2.368203642944649}, {6.605272419863214, 2.4188320180517047`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.38295982880787, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.550655093509228, 2.6586603615961115`}, {
       6.605272419863214, 2.6080319864890558`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.6080319864890558`}, {6.550655093509228, 
       2.6586603615961115`}, {6.479500971337196, 2.6806461661519214`}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}], 
      LineBox[{{6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}], 
      LineBox[{{6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}], 
      LineBox[{{6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}], 
      LineBox[{{6.315648992275237, 2.4408178226075146`}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.4408178226075146`}, {6.315648992275237, 
       2.4408178226075146`}}], 
      LineBox[{{6.315648992275237, 2.4408178226075146`}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.4408178226075146`}, {6.315648992275237, 
       2.4408178226075146`}}], 
      LineBox[{{6.315648992275237, 2.4408178226075146`}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.4408178226075146`}, {6.315648992275237, 
       2.4408178226075146`}}], 
      LineBox[{{6.315648992275237, 2.4408178226075146`}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.4408178226075146`}, {6.315648992275237, 
       2.4408178226075146`}}], 
      LineBox[{{6.299112196457192, 2.51343200227038}, {6.315648992275237, 
       2.586046181933246}, {6.315648992275237, 2.586046181933246}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}}], 
      LineBox[{{6.299112196457192, 2.51343200227038}, {6.315648992275237, 
       2.586046181933246}, {6.315648992275237, 2.586046181933246}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}}], 
      LineBox[{{6.299112196457192, 2.51343200227038}, {6.315648992275237, 
       2.586046181933246}, {6.315648992275237, 2.586046181933246}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}}], 
      LineBox[{{6.299112196457192, 2.51343200227038}, {6.315648992275237, 
       2.586046181933246}, {6.315648992275237, 2.586046181933246}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}}], 
      LineBox[{{6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}}], 
      LineBox[{{6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}}], 
      LineBox[{{6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}}], 
      LineBox[{{6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}}], 
      LineBox[{{6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}}], 
      LineBox[{{6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}}], 
      LineBox[{{6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}}], 
      LineBox[{{6.605272419863214, 2.4188320180517047`}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}}], 
      LineBox[{{6.605272419863214, 2.4188320180517047`}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}}], 
      LineBox[{{6.605272419863214, 2.4188320180517047`}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}}], 
      LineBox[{{6.605272419863214, 2.4188320180517047`}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}}], 
      LineBox[{{6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}], 
      LineBox[{{6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}], 
      LineBox[{{6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}], 
      LineBox[{{6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}], 
      LineBox[{{6.479500971337196, 2.346217838388839}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.479500971337196, 
       2.346217838388839}}], 
      LineBox[{{6.479500971337196, 2.346217838388839}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.479500971337196, 
       2.346217838388839}}], 
      LineBox[{{6.479500971337196, 2.346217838388839}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.479500971337196, 
       2.346217838388839}}], 
      LineBox[{{6.479500971337196, 2.346217838388839}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.479500971337196, 
       2.346217838388839}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.38295982880787, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.479500971337196, 2.6806461661519214`}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}}], 
      LineBox[{{6.38295982880787, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.479500971337196, 2.6806461661519214`}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}}], 
      LineBox[{{6.38295982880787, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.479500971337196, 2.6806461661519214`}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}}], 
      LineBox[{{6.38295982880787, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.479500971337196, 2.6806461661519214`}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}}], 
      LineBox[{{6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}}], 
      LineBox[{{6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}}], 
      LineBox[{{6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}}], 
      LineBox[{{6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}}], 
      LineBox[{{6.550655093509228, 2.6586603615961115`}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}}], 
      LineBox[{{6.550655093509228, 2.6586603615961115`}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}}], 
      LineBox[{{6.550655093509228, 2.6586603615961115`}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}}], 
      LineBox[{{6.550655093509228, 2.6586603615961115`}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}}], 
      LineBox[{{6.605272419863214, 2.6080319864890558`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}}], 
      LineBox[{{6.605272419863214, 2.6080319864890558`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}}], 
      LineBox[{{6.605272419863214, 2.6080319864890558`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}}], 
      LineBox[{{6.605272419863214, 2.6080319864890558`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.325372149584101, 
       2.972611763730079}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       2.8800843946072026`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.624824630848246, 2.8800843946072026`}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.407382742848649, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.5714039293777455`, 3.114658278023142}, {
       6.624824630848246, 3.065139132852955}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 3.065139132852955}, {6.5714039293777455`, 
       3.114658278023142}, {6.501808740951424, 3.1361623899994866`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`,
        3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}], 
      LineBox[{{6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}], 
      LineBox[{{6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}], 
      LineBox[{{6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}], 
      LineBox[{{6.341546636539922, 2.901588506583547}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 2.901588506583547}, {6.341546636539922, 
       2.901588506583547}}], 
      LineBox[{{6.341546636539922, 2.901588506583547}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 2.901588506583547}, {6.341546636539922, 
       2.901588506583547}}], 
      LineBox[{{6.341546636539922, 2.901588506583547}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 2.901588506583547}, {6.341546636539922, 
       2.901588506583547}}], 
      LineBox[{{6.341546636539922, 2.901588506583547}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 2.901588506583547}, {6.341546636539922, 
       2.901588506583547}}], 
      LineBox[{{6.325372149584101, 2.972611763730079}, {6.341546636539922, 
       3.0436350208766108`}, {6.341546636539922, 3.0436350208766108`}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}}], 
      LineBox[{{6.325372149584101, 2.972611763730079}, {6.341546636539922, 
       3.0436350208766108`}, {6.341546636539922, 3.0436350208766108`}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}}], 
      LineBox[{{6.325372149584101, 2.972611763730079}, {6.341546636539922, 
       3.0436350208766108`}, {6.341546636539922, 3.0436350208766108`}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}}], 
      LineBox[{{6.325372149584101, 2.972611763730079}, {6.341546636539922, 
       3.0436350208766108`}, {6.341546636539922, 3.0436350208766108`}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}}], 
      LineBox[{{6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}}], 
      LineBox[{{6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}}], 
      LineBox[{{6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}}], 
      LineBox[{{6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}}], 
      LineBox[{{6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}}], 
      LineBox[{{6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}}], 
      LineBox[{{6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}}], 
      LineBox[{{6.624824630848246, 2.8800843946072026`}, {6.5714039293777455`,
        2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}}], 
      LineBox[{{6.624824630848246, 2.8800843946072026`}, {6.5714039293777455`,
        2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}}], 
      LineBox[{{6.624824630848246, 2.8800843946072026`}, {6.5714039293777455`,
        2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}}], 
      LineBox[{{6.624824630848246, 2.8800843946072026`}, {6.5714039293777455`,
        2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}}], 
      LineBox[{{6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424,
        2.809061137460671}, {6.501808740951424, 2.809061137460671}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}], 
      LineBox[{{6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424,
        2.809061137460671}, {6.501808740951424, 2.809061137460671}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}], 
      LineBox[{{6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424,
        2.809061137460671}, {6.501808740951424, 2.809061137460671}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}], 
      LineBox[{{6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424,
        2.809061137460671}, {6.501808740951424, 2.809061137460671}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}], 
      LineBox[{{6.501808740951424, 2.809061137460671}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.501808740951424, 
       2.809061137460671}}], 
      LineBox[{{6.501808740951424, 2.809061137460671}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.501808740951424, 
       2.809061137460671}}], 
      LineBox[{{6.501808740951424, 2.809061137460671}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.501808740951424, 
       2.809061137460671}}], 
      LineBox[{{6.501808740951424, 2.809061137460671}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.501808740951424, 
       2.809061137460671}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.407382742848649, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.501808740951424, 3.1361623899994866`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}}], 
      LineBox[{{6.407382742848649, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.501808740951424, 3.1361623899994866`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}}], 
      LineBox[{{6.407382742848649, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.501808740951424, 3.1361623899994866`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}}], 
      LineBox[{{6.407382742848649, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.501808740951424, 3.1361623899994866`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}}], 
      LineBox[{{6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`,
        3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}}], 
      LineBox[{{6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`,
        3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}}], 
      LineBox[{{6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`,
        3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}}], 
      LineBox[{{6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`,
        3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}}], 
      LineBox[{{6.5714039293777455`, 3.114658278023142}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}}], 
      LineBox[{{6.5714039293777455`, 3.114658278023142}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}}], 
      LineBox[{{6.5714039293777455`, 3.114658278023142}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}}], 
      LineBox[{{6.5714039293777455`, 3.114658278023142}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}}], 
      LineBox[{{6.624824630848246, 3.065139132852955}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}}], 
      LineBox[{{6.624824630848246, 3.065139132852955}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}}], 
      LineBox[{{6.624824630848246, 3.065139132852955}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}}], 
      LineBox[{{6.624824630848246, 3.065139132852955}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.319749885066836, 
       3.517444916309843}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.4320672572505644`}, {6.546770469485202, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.546770469485202, 
       3.386374520784313}, {6.596063283925856, 3.4320672572505644`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.395423413206291, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.546770469485202, 3.648515311835373}, {
       6.596063283925856, 3.6028225753691214`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.6028225753691214`}, {6.546770469485202, 
       3.648515311835373}, {6.482552991716673, 3.6683577731318864`}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}], 
      LineBox[{{6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}], 
      LineBox[{{6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}], 
      LineBox[{{6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}], 
      LineBox[{{6.33467454839471, 3.451909718547078}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.451909718547078}, {6.33467454839471, 
       3.451909718547078}}], 
      LineBox[{{6.33467454839471, 3.451909718547078}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.451909718547078}, {6.33467454839471, 
       3.451909718547078}}], 
      LineBox[{{6.33467454839471, 3.451909718547078}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.451909718547078}, {6.33467454839471, 
       3.451909718547078}}], 
      LineBox[{{6.33467454839471, 3.451909718547078}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.451909718547078}, {6.33467454839471, 
       3.451909718547078}}], 
      LineBox[{{6.319749885066836, 3.517444916309843}, {6.33467454839471, 
       3.582980114072608}, {6.33467454839471, 3.582980114072608}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}}], 
      LineBox[{{6.319749885066836, 3.517444916309843}, {6.33467454839471, 
       3.582980114072608}, {6.33467454839471, 3.582980114072608}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}}], 
      LineBox[{{6.319749885066836, 3.517444916309843}, {6.33467454839471, 
       3.582980114072608}, {6.33467454839471, 3.582980114072608}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}}], 
      LineBox[{{6.319749885066836, 3.517444916309843}, {6.33467454839471, 
       3.582980114072608}, {6.33467454839471, 3.582980114072608}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}}], 
      LineBox[{{6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}}], 
      LineBox[{{6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}}], 
      LineBox[{{6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}}], 
      LineBox[{{6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}}], 
      LineBox[{{6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}}], 
      LineBox[{{6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}}], 
      LineBox[{{6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}}], 
      LineBox[{{6.596063283925856, 3.4320672572505644`}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}}], 
      LineBox[{{6.596063283925856, 3.4320672572505644`}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}}], 
      LineBox[{{6.596063283925856, 3.4320672572505644`}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}}], 
      LineBox[{{6.596063283925856, 3.4320672572505644`}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}}], 
      LineBox[{{6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}], 
      LineBox[{{6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}], 
      LineBox[{{6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}], 
      LineBox[{{6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}], 
      LineBox[{{6.482552991716673, 3.3665320594877994`}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.482552991716673, 
       3.3665320594877994`}}], 
      LineBox[{{6.482552991716673, 3.3665320594877994`}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.482552991716673, 
       3.3665320594877994`}}], 
      LineBox[{{6.482552991716673, 3.3665320594877994`}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.482552991716673, 
       3.3665320594877994`}}], 
      LineBox[{{6.482552991716673, 3.3665320594877994`}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.482552991716673, 
       3.3665320594877994`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.395423413206291, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.482552991716673, 3.6683577731318864`}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}}], 
      LineBox[{{6.395423413206291, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.482552991716673, 3.6683577731318864`}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}}], 
      LineBox[{{6.395423413206291, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.482552991716673, 3.6683577731318864`}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}}], 
      LineBox[{{6.395423413206291, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.482552991716673, 3.6683577731318864`}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}}], 
      LineBox[{{6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}}], 
      LineBox[{{6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}}], 
      LineBox[{{6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}}], 
      LineBox[{{6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}}], 
      LineBox[{{6.546770469485202, 3.648515311835373}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}}], 
      LineBox[{{6.546770469485202, 3.648515311835373}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}}], 
      LineBox[{{6.546770469485202, 3.648515311835373}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}}], 
      LineBox[{{6.546770469485202, 3.648515311835373}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}}], 
      LineBox[{{6.596063283925856, 3.6028225753691214`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}}], 
      LineBox[{{6.596063283925856, 3.6028225753691214`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}}], 
      LineBox[{{6.596063283925856, 3.6028225753691214`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}}], 
      LineBox[{{6.596063283925856, 3.6028225753691214`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}], 
      LineBox[{{6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}], 
      LineBox[{{6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}], 
      LineBox[{{6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}], 
      LineBox[{{6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}], 
      LineBox[{{6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}], 
      LineBox[{{6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}], 
      LineBox[{{6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}], 
      LineBox[{{6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}], 
      LineBox[{{6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}], 
      LineBox[{{6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}], 
      LineBox[{{6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}], 
      LineBox[{{6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}], 
      LineBox[{{6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}], 
      LineBox[{{6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}], 
      LineBox[{{6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}], 
      LineBox[{{6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}], 
      LineBox[{{6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}], 
      LineBox[{{6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}], 
      LineBox[{{6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}], 
      LineBox[{{6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}], 
      LineBox[{{6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}], 
      LineBox[{{6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}], 
      LineBox[{{6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}], 
      LineBox[{{6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}], 
      LineBox[{{6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}], 
      LineBox[{{6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}], 
      LineBox[{{6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}], 
      LineBox[{{6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}], 
      LineBox[{{6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}], 
      LineBox[{{6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}], 
      LineBox[{{6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}], 
      LineBox[{{6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}], 
      LineBox[{{6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}], 
      LineBox[{{6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}], 
      LineBox[{{6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}], 
      LineBox[{{6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}], 
      LineBox[{{6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}], 
      LineBox[{{6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}], 
      LineBox[{{6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}], 
      LineBox[{{6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}], 
      LineBox[{{6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}], 
      LineBox[{{6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}], 
      LineBox[{{6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}], 
      LineBox[{{6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}], 
      LineBox[{{6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.6075971854109765`}, {
       6.646835656073857, -3.6075971854109765`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.907815591164819}, {
       6.646835656073857, -3.907815591164819}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}], 
      LineBox[{{6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}], 
      LineBox[{{6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}], 
      LineBox[{{6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}], 
      LineBox[{{6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}], 
      LineBox[{{6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}], 
      LineBox[{{6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}], 
      LineBox[{{6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}], 
      LineBox[{{6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}], 
      LineBox[{{6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}], 
      LineBox[{{6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}], 
      LineBox[{{6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}], 
      LineBox[{{6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}], 
      LineBox[{{6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}], 
      LineBox[{{6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}], 
      LineBox[{{6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}], 
      LineBox[{{6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}], 
      LineBox[{{6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}], 
      LineBox[{{6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}], 
      LineBox[{{6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}], 
      LineBox[{{6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}], 
      LineBox[{{6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}], 
      LineBox[{{6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}], 
      LineBox[{{6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}], 
      LineBox[{{6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}], 
      LineBox[{{6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}], 
      LineBox[{{6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}], 
      LineBox[{{6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}], 
      LineBox[{{6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}], 
      LineBox[{{6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}], 
      LineBox[{{6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}], 
      LineBox[{{6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}], 
      LineBox[{{6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}], 
      LineBox[{{6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}], 
      LineBox[{{6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}], 
      LineBox[{{6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}], 
      LineBox[{{6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}], 
      LineBox[{{6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}], 
      LineBox[{{6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}], 
      LineBox[{{6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}], 
      LineBox[{{6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}], 
      LineBox[{{6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}], 
      LineBox[{{6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}], 
      LineBox[{{6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}], 
      LineBox[{{6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}], 
      LineBox[{{6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}], 
      LineBox[{{6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}], 
      LineBox[{{6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}], 
      LineBox[{{6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}], 
      LineBox[{{6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}], 
      LineBox[{{6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}], 
      LineBox[{{6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}], 
      LineBox[{{6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}], 
      LineBox[{{6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}], 
      LineBox[{{6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}], 
      LineBox[{{6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}], 
      LineBox[{{6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}], 
      LineBox[{{6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}], 
      LineBox[{{6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}], 
      LineBox[{{6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}], 
      LineBox[{{6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}], 
      LineBox[{{6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}], 
      LineBox[{{6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}], 
      LineBox[{{6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}], 
      LineBox[{{6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}], 
      LineBox[{{6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}], 
      LineBox[{{6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}], 
      LineBox[{{6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}], 
      LineBox[{{6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}], 
      LineBox[{{6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}], 
      LineBox[{{6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}], 
      LineBox[{{6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}], 
      LineBox[{{6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}], 
      LineBox[{{6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}], 
      LineBox[{{6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}], 
      LineBox[{{6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}], 
      LineBox[{{6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}], 
      LineBox[{{6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}], 
      LineBox[{{6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}], 
      LineBox[{{6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}], 
      LineBox[{{6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}], 
      LineBox[{{6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}], 
      LineBox[{{6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}], 
      LineBox[{{6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}], 
      LineBox[{{6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}], 
      LineBox[{{6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}], 
      LineBox[{{6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}], 
      LineBox[{{6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}], 
      LineBox[{{6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}], 
      LineBox[{{6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}], 
      LineBox[{{6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}], 
      LineBox[{{6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}], 
      LineBox[{{6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}], 
      LineBox[{{6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}], 
      LineBox[{{6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}], 
      LineBox[{{6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}], 
      LineBox[{{6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}], 
      LineBox[{{6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}], 
      LineBox[{{6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}], 
      LineBox[{{6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}], 
      LineBox[{{6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}], 
      LineBox[{{6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}], 
      LineBox[{{6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}], 
      LineBox[{{6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}], 
      LineBox[{{6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}], 
      LineBox[{{6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}], 
      LineBox[{{6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}], 
      LineBox[{{6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}], 
      LineBox[{{6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}], 
      LineBox[{{6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}], 
      LineBox[{{6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}], 
      LineBox[{{6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}], 
      LineBox[{{6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}], 
      LineBox[{{6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}], 
      LineBox[{{6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}], 
      LineBox[{{6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}], 
      LineBox[{{6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}], 
      LineBox[{{6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}], 
      LineBox[{{6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}], 
      LineBox[{{6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}], 
      LineBox[{{6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}], 
      LineBox[{{6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}], 
      LineBox[{{6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}], 
      LineBox[{{6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}], 
      LineBox[{{6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}], 
      LineBox[{{6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}], 
      LineBox[{{6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}], 
      LineBox[{{6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}], 
      LineBox[{{6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}], 
      LineBox[{{6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}], 
      LineBox[{{6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}], 
      LineBox[{{6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}], 
      LineBox[{{6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}], 
      LineBox[{{6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}], 
      LineBox[{{6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}], 
      LineBox[{{6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}], 
      LineBox[{{6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}], 
      LineBox[{{6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}], 
      LineBox[{{6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}], 
      LineBox[{{6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}], 
      LineBox[{{6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}], 
      LineBox[{{6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}], 
      LineBox[{{6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}], 
      LineBox[{{6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}], 
      LineBox[{{6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}], 
      LineBox[{{6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}], 
      LineBox[{{6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}], 
      LineBox[{{6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}], 
      LineBox[{{6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}], 
      LineBox[{{6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}], 
      LineBox[{{6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}], 
      LineBox[{{6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}], 
      LineBox[{{6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}], 
      LineBox[{{6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}], 
      LineBox[{{6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}], 
      LineBox[{{6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}], 
      LineBox[{{6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}], 
      LineBox[{{6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}], 
      LineBox[{{6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}], 
      LineBox[{{6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}], 
      LineBox[{{6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}], 
      LineBox[{{6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}], 
      LineBox[{{6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}], 
      LineBox[{{6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}], 
      LineBox[{{6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}], 
      LineBox[{{6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}], 
      LineBox[{{6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}], 
      LineBox[{{6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}], 
      LineBox[{{6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}], 
      LineBox[{{6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}], 
      LineBox[{{6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}], 
      LineBox[{{6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}], 
      LineBox[{{6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}], 
      LineBox[{{6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}], 
      LineBox[{{6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}], 
      LineBox[{{6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}], 
      LineBox[{{6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}], 
      LineBox[{{6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}], 
      LineBox[{{6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}], 
      LineBox[{{6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}], 
      LineBox[{{6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506884`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}], 
      LineBox[{{6.644829404856591, -1.8659356759259005`}, {6.588228779808851,
        -1.8048755529506881`}, {6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}], 
      LineBox[{{6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}], 
      LineBox[{{6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}], 
      LineBox[{{6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}], 
      LineBox[{{6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}], 
      LineBox[{{6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}], 
      LineBox[{{6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}], 
      LineBox[{{6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}], 
      LineBox[{{6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}], 
      LineBox[{{6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}], 
      LineBox[{{6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}], 
      LineBox[{{6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}], 
      LineBox[{{6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}], 
      LineBox[{{6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}], 
      LineBox[{{6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}], 
      LineBox[{{6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}], 
      LineBox[{{6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}], 
      LineBox[{{6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}], 
      LineBox[{{6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}], 
      LineBox[{{6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}], 
      LineBox[{{6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}], 
      LineBox[{{6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}], 
      LineBox[{{6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}], 
      LineBox[{{6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}], 
      LineBox[{{6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}], 
      LineBox[{{6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}], 
      LineBox[{{6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}], 
      LineBox[{{6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}], 
      LineBox[{{6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}], 
      LineBox[{{6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}], 
      LineBox[{{6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}], 
      LineBox[{{6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}], 
      LineBox[{{6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}], 
      LineBox[{{6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}], 
      LineBox[{{6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}], 
      LineBox[{{6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}], 
      LineBox[{{6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}], 
      LineBox[{{6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}], 
      LineBox[{{6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}], 
      LineBox[{{6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}], 
      LineBox[{{6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}], 
      LineBox[{{6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}], 
      LineBox[{{6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}], 
      LineBox[{{6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}], 
      LineBox[{{6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}], 
      LineBox[{{6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}], 
      LineBox[{{6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}], 
      LineBox[{{6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}], 
      LineBox[{{6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}], 
      LineBox[{{6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}], 
      LineBox[{{6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}], 
      LineBox[{{6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}], 
      LineBox[{{6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}], 
      LineBox[{{6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}], 
      LineBox[{{6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}], 
      LineBox[{{6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}], 
      LineBox[{{6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}], 
      LineBox[{{6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}], 
      LineBox[{{6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}], 
      LineBox[{{6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}], 
      LineBox[{{6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}], 
      LineBox[{{6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}], 
      LineBox[{{6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}], 
      LineBox[{{6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}], 
      LineBox[{{6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}], 
      LineBox[{{6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}], 
      LineBox[{{6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}], 
      LineBox[{{6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}], 
      LineBox[{{6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}], 
      LineBox[{{6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}], 
      LineBox[{{6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}], 
      LineBox[{{6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}], 
      LineBox[{{6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}], 
      LineBox[{{6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}], 
      LineBox[{{6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}], 
      LineBox[{{6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}], 
      LineBox[{{6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}], 
      LineBox[{{6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}], 
      LineBox[{{6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}], 
      LineBox[{{6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}], 
      LineBox[{{6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}], 
      LineBox[{{6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}], 
      LineBox[{{6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}], 
      LineBox[{{6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}], 
      LineBox[{{6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}], 
      LineBox[{{6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}], 
      LineBox[{{6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}], 
      LineBox[{{6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}], 
      LineBox[{{6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}], 
      LineBox[{{6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}], 
      LineBox[{{6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}], 
      LineBox[{{6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}], 
      LineBox[{{6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}], 
      LineBox[{{6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}], 
      LineBox[{{6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}], 
      LineBox[{{6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}], 
      LineBox[{{6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}], 
      LineBox[{{6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}], 
      LineBox[{{6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}], 
      LineBox[{{6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}], 
      LineBox[{{6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}], 
      LineBox[{{6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}], 
      LineBox[{{6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}], 
      LineBox[{{6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}], 
      LineBox[{{6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}], 
      LineBox[{{6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}], 
      LineBox[{{6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}], 
      LineBox[{{6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}], 
      LineBox[{{6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}], 
      LineBox[{{6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}], 
      LineBox[{{6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}], 
      LineBox[{{6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}], 
      LineBox[{{6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}], 
      LineBox[{{6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}], 
      LineBox[{{6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}], 
      LineBox[{{6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}], 
      LineBox[{{6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}], 
      LineBox[{{6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}], 
      LineBox[{{6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}], 
      LineBox[{{6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}], 
      LineBox[{{6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}], 
      LineBox[{{6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}], 
      LineBox[{{6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}], 
      LineBox[{{6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}], 
      LineBox[{{6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}], 
      LineBox[{{6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}], 
      LineBox[{{6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}], 
      LineBox[{{6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}], 
      LineBox[{{6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}], 
      LineBox[{{6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}], 
      LineBox[{{6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}], 
      LineBox[{{6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}], 
      LineBox[{{6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}], 
      LineBox[{{6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}], 
      LineBox[{{6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947431}, {
       6.626169087862926, -0.09196413059947431}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495338}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618056`}, {
       6.873925795705952, -0.23500653256618056`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}], 
      LineBox[{{6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}], 
      LineBox[{{6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}], 
      LineBox[{{6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}], 
      LineBox[{{6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}], 
      LineBox[{{6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}], 
      LineBox[{{6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}], 
      LineBox[{{6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}], 
      LineBox[{{6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}], 
      LineBox[{{6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}], 
      LineBox[{{6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}], 
      LineBox[{{6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}], 
      LineBox[{{6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}], 
      LineBox[{{6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}], 
      LineBox[{{6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}], 
      LineBox[{{6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}], 
      LineBox[{{6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}], 
      LineBox[{{6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}], 
      LineBox[{{6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}], 
      LineBox[{{6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}], 
      LineBox[{{6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}], 
      LineBox[{{6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}], 
      LineBox[{{6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}], 
      LineBox[{{6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}], 
      LineBox[{{6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}], 
      LineBox[{{6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}], 
      LineBox[{{6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}], 
      LineBox[{{6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}], 
      LineBox[{{6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}], 
      LineBox[{{6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}], 
      LineBox[{{6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}], 
      LineBox[{{6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}], 
      LineBox[{{6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}], 
      LineBox[{{6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}], 
      LineBox[{{6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}], 
      LineBox[{{6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}], 
      LineBox[{{6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}], 
      LineBox[{{6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}], 
      LineBox[{{6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}], 
      LineBox[{{6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}], 
      LineBox[{{6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}], 
      LineBox[{{6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}], 
      LineBox[{{6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}], 
      LineBox[{{6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}], 
      LineBox[{{6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}], 
      LineBox[{{6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.668106860191438, 0.09923453595851475}, {6.603652804810594, 
       0.16876685197951424`}, {6.5878178574472335`, 0.2382991680005137}, {
       6.603652804810594, 0.30783148402151317`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}, {
       6.603652804810594, 0.30783148402151317`}, {6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.16876685197951422`}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.828684865679847, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.828684865679847, 
       0.09923453595851475}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.828684865679847, 0.3773638000425127}, {
       6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051373`}, {6.908973868424051, 0.23829916800051373`}, {
       6.88098414405632, 0.3288841753477539}, {6.828684865679847, 
       0.3773638000425127}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.668106860191438, 0.09923453595851475}, {6.603652804810594, 
       0.16876685197951424`}, {6.603652804810594, 0.16876685197951424`}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}}], 
      LineBox[{{6.668106860191438, 0.09923453595851475}, {6.603652804810594, 
       0.16876685197951424`}, {6.603652804810594, 0.16876685197951424`}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}}], 
      LineBox[{{6.668106860191438, 0.09923453595851475}, {6.603652804810594, 
       0.16876685197951424`}, {6.603652804810594, 0.16876685197951424`}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}}], 
      LineBox[{{6.668106860191438, 0.09923453595851475}, {6.603652804810594, 
       0.16876685197951424`}, {6.603652804810594, 0.16876685197951424`}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}}], 
      LineBox[{{6.603652804810594, 0.16876685197951424`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}}], 
      LineBox[{{6.603652804810594, 0.16876685197951424`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}}], 
      LineBox[{{6.603652804810594, 0.16876685197951424`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}}], 
      LineBox[{{6.603652804810594, 0.16876685197951424`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}}], 
      LineBox[{{6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}}], 
      LineBox[{{6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}}], 
      LineBox[{{6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}}], 
      LineBox[{{6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}}], 
      LineBox[{{6.603652804810594, 0.30783148402151317`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}}], 
      LineBox[{{6.603652804810594, 0.30783148402151317`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}}], 
      LineBox[{{6.603652804810594, 0.30783148402151317`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}}], 
      LineBox[{{6.603652804810594, 0.30783148402151317`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}], 
      LineBox[{{6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}], 
      LineBox[{{6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}], 
      LineBox[{{6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}], 
      LineBox[{{6.88098414405632, 0.14771416065327353`}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.88098414405632, 0.14771416065327353`}, {6.88098414405632, 
       0.14771416065327353`}}], 
      LineBox[{{6.88098414405632, 0.14771416065327353`}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.88098414405632, 0.14771416065327353`}, {6.88098414405632, 
       0.14771416065327353`}}], 
      LineBox[{{6.88098414405632, 0.14771416065327353`}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.88098414405632, 0.14771416065327353`}, {6.88098414405632, 
       0.14771416065327353`}}], 
      LineBox[{{6.88098414405632, 0.14771416065327353`}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.88098414405632, 0.14771416065327353`}, {6.88098414405632, 
       0.14771416065327353`}}], 
      LineBox[{{6.828684865679847, 0.09923453595851475}, {6.760550639940013, 
       0.07818184463227407}, {6.760550639940013, 0.07818184463227407}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}}], 
      LineBox[{{6.828684865679847, 0.09923453595851475}, {6.760550639940013, 
       0.07818184463227407}, {6.760550639940013, 0.07818184463227407}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}}], 
      LineBox[{{6.828684865679847, 0.09923453595851475}, {6.760550639940013, 
       0.07818184463227407}, {6.760550639940013, 0.07818184463227407}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}}], 
      LineBox[{{6.828684865679847, 0.09923453595851475}, {6.760550639940013, 
       0.07818184463227407}, {6.760550639940013, 0.07818184463227407}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}}], 
      LineBox[{{6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}}], 
      LineBox[{{6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}}], 
      LineBox[{{6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}}], 
      LineBox[{{6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}], 
      LineBox[{{6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}], 
      LineBox[{{6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}], 
      LineBox[{{6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}], 
      LineBox[{{6.760550639940013, 0.39841649136875334`}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}}], 
      LineBox[{{6.760550639940013, 0.39841649136875334`}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}}], 
      LineBox[{{6.760550639940013, 0.39841649136875334`}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}}], 
      LineBox[{{6.760550639940013, 0.39841649136875334`}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}}], 
      LineBox[{{6.828684865679847, 0.3773638000425127}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}], 
      LineBox[{{6.828684865679847, 0.3773638000425127}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}], 
      LineBox[{{6.828684865679847, 0.3773638000425127}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}], 
      LineBox[{{6.828684865679847, 0.3773638000425127}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}], 
      LineBox[{{6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051368`}, {6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.3288841753477539}, {6.88098414405632, 
       0.3288841753477539}}], 
      LineBox[{{6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051368`}, {6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.3288841753477539}, {6.88098414405632, 
       0.3288841753477539}}], 
      LineBox[{{6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051368`}, {6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.3288841753477539}, {6.88098414405632, 
       0.3288841753477539}}], 
      LineBox[{{6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051368`}, {6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.3288841753477539}, {6.88098414405632, 
       0.3288841753477539}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.681704815183866, 0.5905561819630012}, {6.6113363078012855`, 
       0.6664689428333709}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.8182944645741103}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}, {
       6.6113363078012855`, 0.8182944645741103}, {6.594048309336994, 
       0.7423817037037406}, {6.6113363078012855`, 0.6664689428333709}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.857017826877608, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.857017826877608, 
       0.5905561819630012}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.857017826877608, 0.89420722544448}, {
       6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.857017826877608, 
       0.89420722544448}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.681704815183866, 0.5905561819630012}, {6.6113363078012855`, 
       0.6664689428333709}, {6.6113363078012855`, 0.6664689428333709}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}}], 
      LineBox[{{6.681704815183866, 0.5905561819630012}, {6.6113363078012855`, 
       0.6664689428333709}, {6.6113363078012855`, 0.6664689428333709}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}}], 
      LineBox[{{6.681704815183866, 0.5905561819630012}, {6.6113363078012855`, 
       0.6664689428333709}, {6.6113363078012855`, 0.6664689428333709}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}}], 
      LineBox[{{6.681704815183866, 0.5905561819630012}, {6.6113363078012855`, 
       0.6664689428333709}, {6.6113363078012855`, 0.6664689428333709}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}}], 
      LineBox[{{6.6113363078012855`, 0.6664689428333709}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}}], 
      LineBox[{{6.6113363078012855`, 0.6664689428333709}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}}], 
      LineBox[{{6.6113363078012855`, 0.6664689428333709}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}}], 
      LineBox[{{6.6113363078012855`, 0.6664689428333709}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}}], 
      LineBox[{{6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}], 
      LineBox[{{6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}], 
      LineBox[{{6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}], 
      LineBox[{{6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}], 
      LineBox[{{6.6113363078012855`, 0.8182944645741103}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}}], 
      LineBox[{{6.6113363078012855`, 0.8182944645741103}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}}], 
      LineBox[{{6.6113363078012855`, 0.8182944645741103}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}}], 
      LineBox[{{6.6113363078012855`, 0.8182944645741103}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}], 
      LineBox[{{6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}], 
      LineBox[{{6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}], 
      LineBox[{{6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}], 
      LineBox[{{6.914116207030617, 0.6434844082488482}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.914116207030617, 0.6434844082488482}, {6.914116207030617, 
       0.6434844082488482}}], 
      LineBox[{{6.914116207030617, 0.6434844082488482}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.914116207030617, 0.6434844082488482}, {6.914116207030617, 
       0.6434844082488482}}], 
      LineBox[{{6.914116207030617, 0.6434844082488482}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.914116207030617, 0.6434844082488482}, {6.914116207030617, 
       0.6434844082488482}}], 
      LineBox[{{6.914116207030617, 0.6434844082488482}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.914116207030617, 0.6434844082488482}, {6.914116207030617, 
       0.6434844082488482}}], 
      LineBox[{{6.857017826877608, 0.5905561819630012}, {6.782631448260309, 
       0.5675716473784785}, {6.782631448260309, 0.5675716473784785}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}}], 
      LineBox[{{6.857017826877608, 0.5905561819630012}, {6.782631448260309, 
       0.5675716473784785}, {6.782631448260309, 0.5675716473784785}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}}], 
      LineBox[{{6.857017826877608, 0.5905561819630012}, {6.782631448260309, 
       0.5675716473784785}, {6.782631448260309, 0.5675716473784785}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}}], 
      LineBox[{{6.857017826877608, 0.5905561819630012}, {6.782631448260309, 
       0.5675716473784785}, {6.782631448260309, 0.5675716473784785}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}}], 
      LineBox[{{6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}}], 
      LineBox[{{6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}}], 
      LineBox[{{6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}}], 
      LineBox[{{6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}], 
      LineBox[{{6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}], 
      LineBox[{{6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}], 
      LineBox[{{6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}], 
      LineBox[{{6.782631448260309, 0.9171917600290026}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}}], 
      LineBox[{{6.782631448260309, 0.9171917600290026}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}}], 
      LineBox[{{6.782631448260309, 0.9171917600290026}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}}], 
      LineBox[{{6.782631448260309, 0.9171917600290026}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}}], 
      LineBox[{{6.857017826877608, 0.89420722544448}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}], 
      LineBox[{{6.857017826877608, 0.89420722544448}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}], 
      LineBox[{{6.857017826877608, 0.89420722544448}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}], 
      LineBox[{{6.857017826877608, 0.89420722544448}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}], 
      LineBox[{{6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.914116207030617, 
       0.8412789991586329}}], 
      LineBox[{{6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.914116207030617, 
       0.8412789991586329}}], 
      LineBox[{{6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.914116207030617, 
       0.8412789991586329}}], 
      LineBox[{{6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.914116207030617, 
       0.8412789991586329}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.645838323647305, 1.1297603572391623`}, {6.580443740183912, 
       1.2003073044649166`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.3414011989164247`}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}, {
       6.580443740183912, 1.3414011989164247`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.580443740183912, 1.2003073044649166`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.8087595195324875`, 1.411948146142179}, {
       6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.8087595195324875`, 
       1.411948146142179}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`,
        1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.645838323647305, 1.1297603572391623`}, {6.580443740183912, 
       1.2003073044649166`}, {6.580443740183912, 1.2003073044649166`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}}], 
      LineBox[{{6.645838323647305, 1.1297603572391623`}, {6.580443740183912, 
       1.2003073044649166`}, {6.580443740183912, 1.2003073044649166`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}}], 
      LineBox[{{6.645838323647305, 1.1297603572391623`}, {6.580443740183912, 
       1.2003073044649166`}, {6.580443740183912, 1.2003073044649166`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}}], 
      LineBox[{{6.645838323647305, 1.1297603572391623`}, {6.580443740183912, 
       1.2003073044649166`}, {6.580443740183912, 1.2003073044649166`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}}], 
      LineBox[{{6.580443740183912, 1.2003073044649166`}, {6.5643777257047145`,
        1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}}], 
      LineBox[{{6.580443740183912, 1.2003073044649166`}, {6.5643777257047145`,
        1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}}], 
      LineBox[{{6.580443740183912, 1.2003073044649166`}, {6.5643777257047145`,
        1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}}], 
      LineBox[{{6.580443740183912, 1.2003073044649166`}, {6.5643777257047145`,
        1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}}], 
      LineBox[{{6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912,
        1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}}], 
      LineBox[{{6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912,
        1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}}], 
      LineBox[{{6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912,
        1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}}], 
      LineBox[{{6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912,
        1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}}], 
      LineBox[{{6.580443740183912, 1.3414011989164247`}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}}], 
      LineBox[{{6.580443740183912, 1.3414011989164247`}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}}], 
      LineBox[{{6.580443740183912, 1.3414011989164247`}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}}], 
      LineBox[{{6.580443740183912, 1.3414011989164247`}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}], 
      LineBox[{{6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}], 
      LineBox[{{6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}], 
      LineBox[{{6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}], 
      LineBox[{{6.861821960749832, 1.1789474075285935`}, {6.8087595195324875`,
        1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.861821960749832, 1.1789474075285935`}, {6.861821960749832, 
       1.1789474075285935`}}], 
      LineBox[{{6.861821960749832, 1.1789474075285935`}, {6.8087595195324875`,
        1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.861821960749832, 1.1789474075285935`}, {6.861821960749832, 
       1.1789474075285935`}}], 
      LineBox[{{6.861821960749832, 1.1789474075285935`}, {6.8087595195324875`,
        1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.861821960749832, 1.1789474075285935`}, {6.861821960749832, 
       1.1789474075285935`}}], 
      LineBox[{{6.861821960749832, 1.1789474075285935`}, {6.8087595195324875`,
        1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.861821960749832, 1.1789474075285935`}, {6.861821960749832, 
       1.1789474075285935`}}], 
      LineBox[{{6.8087595195324875`, 1.1297603572391623`}, {6.739631063835945,
        1.1084004603028395`}, {6.739631063835945, 1.1084004603028395`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}}], 
      LineBox[{{6.8087595195324875`, 1.1297603572391623`}, {6.739631063835945,
        1.1084004603028395`}, {6.739631063835945, 1.1084004603028395`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}}], 
      LineBox[{{6.8087595195324875`, 1.1297603572391623`}, {6.739631063835945,
        1.1084004603028395`}, {6.739631063835945, 1.1084004603028395`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}}], 
      LineBox[{{6.8087595195324875`, 1.1297603572391623`}, {6.739631063835945,
        1.1084004603028395`}, {6.739631063835945, 1.1084004603028395`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}}], 
      LineBox[{{6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}}], 
      LineBox[{{6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}}], 
      LineBox[{{6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}}], 
      LineBox[{{6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}], 
      LineBox[{{6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}], 
      LineBox[{{6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}], 
      LineBox[{{6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}], 
      LineBox[{{6.739631063835945, 1.433308043078502}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}}], 
      LineBox[{{6.739631063835945, 1.433308043078502}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}}], 
      LineBox[{{6.739631063835945, 1.433308043078502}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}}], 
      LineBox[{{6.739631063835945, 1.433308043078502}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}}], 
      LineBox[{{6.8087595195324875`, 1.411948146142179}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}], 
      LineBox[{{6.8087595195324875`, 1.411948146142179}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}], 
      LineBox[{{6.8087595195324875`, 1.411948146142179}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}], 
      LineBox[{{6.8087595195324875`, 1.411948146142179}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}], 
      LineBox[{{6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.861821960749832, 
       1.3627610958527479`}}], 
      LineBox[{{6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.861821960749832, 
       1.3627610958527479`}}], 
      LineBox[{{6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.861821960749832, 
       1.3627610958527479`}}], 
      LineBox[{{6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.861821960749832, 
       1.3627610958527479`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6933450503580545`, 1.5890733247505344`}, {6.638526448092365,
        1.6482110214252461`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.7664864147746695`}, {6.6933450503580545`, 
       1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.638526448092365, 1.7664864147746695`}, {6.625058720169256, 
       1.7073487180999578`}, {6.638526448092365, 1.6482110214252461`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.829917710735652, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.829917710735652, 
       1.5890733247505344`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499,
        1.8435295652740682`}, {6.829917710735652, 1.8256241114493812`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.829917710735652, 
       1.8256241114493812`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6933450503580545`, 1.5890733247505344`}, {6.638526448092365,
        1.6482110214252461`}, {6.638526448092365, 1.6482110214252461`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}}], 
      LineBox[{{6.6933450503580545`, 1.5890733247505344`}, {6.638526448092365,
        1.6482110214252461`}, {6.638526448092365, 1.6482110214252461`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}}], 
      LineBox[{{6.6933450503580545`, 1.5890733247505344`}, {6.638526448092365,
        1.6482110214252461`}, {6.638526448092365, 1.6482110214252461`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}}], 
      LineBox[{{6.6933450503580545`, 1.5890733247505344`}, {6.638526448092365,
        1.6482110214252461`}, {6.638526448092365, 1.6482110214252461`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}}], 
      LineBox[{{6.638526448092365, 1.6482110214252461`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}}], 
      LineBox[{{6.638526448092365, 1.6482110214252461`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}}], 
      LineBox[{{6.638526448092365, 1.6482110214252461`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}}], 
      LineBox[{{6.638526448092365, 1.6482110214252461`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}}], 
      LineBox[{{6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}], 
      LineBox[{{6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}], 
      LineBox[{{6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}], 
      LineBox[{{6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}], 
      LineBox[{{6.638526448092365, 1.7664864147746695`}, {6.6933450503580545`,
        1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}}], 
      LineBox[{{6.638526448092365, 1.7664864147746695`}, {6.6933450503580545`,
        1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}}], 
      LineBox[{{6.638526448092365, 1.7664864147746695`}, {6.6933450503580545`,
        1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}}], 
      LineBox[{{6.638526448092365, 1.7664864147746695`}, {6.6933450503580545`,
        1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}], 
      LineBox[{{6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}], 
      LineBox[{{6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}], 
      LineBox[{{6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}], 
      LineBox[{{6.8743985944156965`, 1.6303055676005591`}, {6.829917710735652,
        1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.8743985944156965`, 
       1.6303055676005591`}}], 
      LineBox[{{6.8743985944156965`, 1.6303055676005591`}, {6.829917710735652,
        1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.8743985944156965`, 
       1.6303055676005591`}}], 
      LineBox[{{6.8743985944156965`, 1.6303055676005591`}, {6.829917710735652,
        1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.8743985944156965`, 
       1.6303055676005591`}}], 
      LineBox[{{6.8743985944156965`, 1.6303055676005591`}, {6.829917710735652,
        1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.8743985944156965`, 
       1.6303055676005591`}}], 
      LineBox[{{6.829917710735652, 1.5890733247505344`}, {6.771969099132499, 
       1.5711678709258474`}, {6.771969099132499, 1.5711678709258474`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}}], 
      LineBox[{{6.829917710735652, 1.5890733247505344`}, {6.771969099132499, 
       1.5711678709258474`}, {6.771969099132499, 1.5711678709258474`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}}], 
      LineBox[{{6.829917710735652, 1.5890733247505344`}, {6.771969099132499, 
       1.5711678709258474`}, {6.771969099132499, 1.5711678709258474`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}}], 
      LineBox[{{6.829917710735652, 1.5890733247505344`}, {6.771969099132499, 
       1.5711678709258474`}, {6.771969099132499, 1.5711678709258474`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}}], 
      LineBox[{{6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`,
        1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}}], 
      LineBox[{{6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`,
        1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}}], 
      LineBox[{{6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`,
        1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}}], 
      LineBox[{{6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`,
        1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499,
        1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}], 
      LineBox[{{6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499,
        1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}], 
      LineBox[{{6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499,
        1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}], 
      LineBox[{{6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499,
        1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}], 
      LineBox[{{6.771969099132499, 1.8435295652740682`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}}], 
      LineBox[{{6.771969099132499, 1.8435295652740682`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}}], 
      LineBox[{{6.771969099132499, 1.8435295652740682`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}}], 
      LineBox[{{6.771969099132499, 1.8435295652740682`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}}], 
      LineBox[{{6.829917710735652, 1.8256241114493812`}, {6.8743985944156965`,
        1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}], 
      LineBox[{{6.829917710735652, 1.8256241114493812`}, {6.8743985944156965`,
        1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}], 
      LineBox[{{6.829917710735652, 1.8256241114493812`}, {6.8743985944156965`,
        1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}], 
      LineBox[{{6.829917710735652, 1.8256241114493812`}, {6.8743985944156965`,
        1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}], 
      LineBox[{{6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.8743985944156965`, 
       1.7843918685993565`}}], 
      LineBox[{{6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.8743985944156965`, 
       1.7843918685993565`}}], 
      LineBox[{{6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.8743985944156965`, 
       1.7843918685993565`}}], 
      LineBox[{{6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.8743985944156965`, 
       1.7843918685993565`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.730606204598308, 2.119109799473035}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.283286060231335}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}, {
       6.6798776301805285`, 2.283286060231335}, {6.667414732369407, 
       2.2285606399785682`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.856989149056108, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.856989149056108, 
       2.119109799473035}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.856989149056108, 2.3380114804841017`}, {
       6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.856989149056108, 
       2.3380114804841017`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.730606204598308, 2.119109799473035}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}}], 
      LineBox[{{6.730606204598308, 2.119109799473035}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}}], 
      LineBox[{{6.730606204598308, 2.119109799473035}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}}], 
      LineBox[{{6.730606204598308, 2.119109799473035}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}}], 
      LineBox[{{6.6798776301805285`, 2.1738352197258015`}, {6.667414732369407,
        2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}}], 
      LineBox[{{6.6798776301805285`, 2.1738352197258015`}, {6.667414732369407,
        2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}}], 
      LineBox[{{6.6798776301805285`, 2.1738352197258015`}, {6.667414732369407,
        2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}}], 
      LineBox[{{6.6798776301805285`, 2.1738352197258015`}, {6.667414732369407,
        2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}}], 
      LineBox[{{6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`,
        2.283286060231335}, {6.6798776301805285`, 2.283286060231335}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}], 
      LineBox[{{6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`,
        2.283286060231335}, {6.6798776301805285`, 2.283286060231335}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}], 
      LineBox[{{6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`,
        2.283286060231335}, {6.6798776301805285`, 2.283286060231335}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}], 
      LineBox[{{6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`,
        2.283286060231335}, {6.6798776301805285`, 2.283286060231335}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}], 
      LineBox[{{6.6798776301805285`, 2.283286060231335}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}}], 
      LineBox[{{6.6798776301805285`, 2.283286060231335}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}}], 
      LineBox[{{6.6798776301805285`, 2.283286060231335}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}}], 
      LineBox[{{6.6798776301805285`, 2.283286060231335}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}], 
      LineBox[{{6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}], 
      LineBox[{{6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}], 
      LineBox[{{6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}], 
      LineBox[{{6.898151304322223, 2.157265695708619}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.898151304322223, 2.157265695708619}, {6.898151304322223, 
       2.157265695708619}}], 
      LineBox[{{6.898151304322223, 2.157265695708619}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.898151304322223, 2.157265695708619}, {6.898151304322223, 
       2.157265695708619}}], 
      LineBox[{{6.898151304322223, 2.157265695708619}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.898151304322223, 2.157265695708619}, {6.898151304322223, 
       2.157265695708619}}], 
      LineBox[{{6.898151304322223, 2.157265695708619}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.898151304322223, 2.157265695708619}, {6.898151304322223, 
       2.157265695708619}}], 
      LineBox[{{6.856989149056108, 2.119109799473035}, {6.803364095978873, 
       2.102540275455852}, {6.803364095978873, 2.102540275455852}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}}], 
      LineBox[{{6.856989149056108, 2.119109799473035}, {6.803364095978873, 
       2.102540275455852}, {6.803364095978873, 2.102540275455852}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}}], 
      LineBox[{{6.856989149056108, 2.119109799473035}, {6.803364095978873, 
       2.102540275455852}, {6.803364095978873, 2.102540275455852}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}}], 
      LineBox[{{6.856989149056108, 2.119109799473035}, {6.803364095978873, 
       2.102540275455852}, {6.803364095978873, 2.102540275455852}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}}], 
      LineBox[{{6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}}], 
      LineBox[{{6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}}], 
      LineBox[{{6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}}], 
      LineBox[{{6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}], 
      LineBox[{{6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}], 
      LineBox[{{6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}], 
      LineBox[{{6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}], 
      LineBox[{{6.803364095978873, 2.3545810045012843`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}}], 
      LineBox[{{6.803364095978873, 2.3545810045012843`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}}], 
      LineBox[{{6.803364095978873, 2.3545810045012843`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}}], 
      LineBox[{{6.803364095978873, 2.3545810045012843`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}}], 
      LineBox[{{6.856989149056108, 2.3380114804841017`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}], 
      LineBox[{{6.856989149056108, 2.3380114804841017`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}], 
      LineBox[{{6.856989149056108, 2.3380114804841017`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}], 
      LineBox[{{6.856989149056108, 2.3380114804841017`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}], 
      LineBox[{{6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.898151304322223, 
       2.2998555842485175`}}], 
      LineBox[{{6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.898151304322223, 
       2.2998555842485175`}}], 
      LineBox[{{6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.898151304322223, 
       2.2998555842485175`}}], 
      LineBox[{{6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.898151304322223, 
       2.2998555842485175`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.635189422279444, 2.5945230597158435`}, {6.569353315970717, 
       2.665546316862375}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.807592831155439}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}, {
       6.569353315970717, 2.807592831155439}, {6.553178829014896, 
       2.736569574008907}, {6.569353315970717, 2.665546316862375}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.79921060880854, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.79921060880854, 
       2.5945230597158435`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.79921060880854, 2.8786160883019702`}, {
       6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.79921060880854, 
       2.8786160883019702`}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.635189422279444, 2.5945230597158435`}, {6.569353315970717, 
       2.665546316862375}, {6.569353315970717, 2.665546316862375}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}}], 
      LineBox[{{6.635189422279444, 2.5945230597158435`}, {6.569353315970717, 
       2.665546316862375}, {6.569353315970717, 2.665546316862375}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}}], 
      LineBox[{{6.635189422279444, 2.5945230597158435`}, {6.569353315970717, 
       2.665546316862375}, {6.569353315970717, 2.665546316862375}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}}], 
      LineBox[{{6.635189422279444, 2.5945230597158435`}, {6.569353315970717, 
       2.665546316862375}, {6.569353315970717, 2.665546316862375}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}}], 
      LineBox[{{6.569353315970717, 2.665546316862375}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}}], 
      LineBox[{{6.569353315970717, 2.665546316862375}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}}], 
      LineBox[{{6.569353315970717, 2.665546316862375}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}}], 
      LineBox[{{6.569353315970717, 2.665546316862375}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}}], 
      LineBox[{{6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}], 
      LineBox[{{6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}], 
      LineBox[{{6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}], 
      LineBox[{{6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}], 
      LineBox[{{6.569353315970717, 2.807592831155439}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}}], 
      LineBox[{{6.569353315970717, 2.807592831155439}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}}], 
      LineBox[{{6.569353315970717, 2.807592831155439}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}}], 
      LineBox[{{6.569353315970717, 2.807592831155439}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}], 
      LineBox[{{6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}], 
      LineBox[{{6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}], 
      LineBox[{{6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}], 
      LineBox[{{6.85263131027904, 2.6440422048860306`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.85263131027904, 2.6440422048860306`}, {6.85263131027904, 
       2.6440422048860306`}}], 
      LineBox[{{6.85263131027904, 2.6440422048860306`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.85263131027904, 2.6440422048860306`}, {6.85263131027904, 
       2.6440422048860306`}}], 
      LineBox[{{6.85263131027904, 2.6440422048860306`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.85263131027904, 2.6440422048860306`}, {6.85263131027904, 
       2.6440422048860306`}}], 
      LineBox[{{6.85263131027904, 2.6440422048860306`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.85263131027904, 2.6440422048860306`}, {6.85263131027904, 
       2.6440422048860306`}}], 
      LineBox[{{6.79921060880854, 2.5945230597158435`}, {6.729615420382219, 
       2.5730189477394987`}, {6.729615420382219, 2.5730189477394987`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}}], 
      LineBox[{{6.79921060880854, 2.5945230597158435`}, {6.729615420382219, 
       2.5730189477394987`}, {6.729615420382219, 2.5730189477394987`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}}], 
      LineBox[{{6.79921060880854, 2.5945230597158435`}, {6.729615420382219, 
       2.5730189477394987`}, {6.729615420382219, 2.5730189477394987`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}}], 
      LineBox[{{6.79921060880854, 2.5945230597158435`}, {6.729615420382219, 
       2.5730189477394987`}, {6.729615420382219, 2.5730189477394987`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}}], 
      LineBox[{{6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}}], 
      LineBox[{{6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}}], 
      LineBox[{{6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}}], 
      LineBox[{{6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}], 
      LineBox[{{6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}], 
      LineBox[{{6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}], 
      LineBox[{{6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}], 
      LineBox[{{6.729615420382219, 2.900120200278315}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}}], 
      LineBox[{{6.729615420382219, 2.900120200278315}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}}], 
      LineBox[{{6.729615420382219, 2.900120200278315}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}}], 
      LineBox[{{6.729615420382219, 2.900120200278315}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}}], 
      LineBox[{{6.79921060880854, 2.8786160883019702`}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}], 
      LineBox[{{6.79921060880854, 2.8786160883019702`}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}], 
      LineBox[{{6.79921060880854, 2.8786160883019702`}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}], 
      LineBox[{{6.79921060880854, 2.8786160883019702`}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}], 
      LineBox[{{6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.85263131027904, 
       2.829096943131783}}], 
      LineBox[{{6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.85263131027904, 
       2.829096943131783}}], 
      LineBox[{{6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.85263131027904, 
       2.829096943131783}}], 
      LineBox[{{6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.85263131027904, 
       2.829096943131783}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.690401385500142, 3.1767043127584165`}, {6.636138386367973, 
       3.2352426309699105`}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.3523192673928994`}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}, {
       6.636138386367973, 3.3523192673928994`}, {6.622807157945513, 
       3.293780949181405}, {6.636138386367973, 3.2352426309699105`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.825589840609398, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.825589840609398, 
       3.1767043127584165`}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.825589840609398, 3.4108575856043934`}, {
       6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.825589840609398, 
       3.4108575856043934`}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.690401385500142, 3.1767043127584165`}, {6.636138386367973, 
       3.2352426309699105`}, {6.636138386367973, 3.2352426309699105`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}}], 
      LineBox[{{6.690401385500142, 3.1767043127584165`}, {6.636138386367973, 
       3.2352426309699105`}, {6.636138386367973, 3.2352426309699105`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}}], 
      LineBox[{{6.690401385500142, 3.1767043127584165`}, {6.636138386367973, 
       3.2352426309699105`}, {6.636138386367973, 3.2352426309699105`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}}], 
      LineBox[{{6.690401385500142, 3.1767043127584165`}, {6.636138386367973, 
       3.2352426309699105`}, {6.636138386367973, 3.2352426309699105`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}}], 
      LineBox[{{6.636138386367973, 3.2352426309699105`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}}], 
      LineBox[{{6.636138386367973, 3.2352426309699105`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}}], 
      LineBox[{{6.636138386367973, 3.2352426309699105`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}}], 
      LineBox[{{6.636138386367973, 3.2352426309699105`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}}], 
      LineBox[{{6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}], 
      LineBox[{{6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}], 
      LineBox[{{6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}], 
      LineBox[{{6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}], 
      LineBox[{{6.636138386367973, 3.3523192673928994`}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}}], 
      LineBox[{{6.636138386367973, 3.3523192673928994`}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}}], 
      LineBox[{{6.636138386367973, 3.3523192673928994`}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}}], 
      LineBox[{{6.636138386367973, 3.3523192673928994`}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}], 
      LineBox[{{6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}], 
      LineBox[{{6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}], 
      LineBox[{{6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}], 
      LineBox[{{6.86961989706414, 3.217518654341667}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.86961989706414, 3.217518654341667}, {6.86961989706414, 
       3.217518654341667}}], 
      LineBox[{{6.86961989706414, 3.217518654341667}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.86961989706414, 3.217518654341667}, {6.86961989706414, 
       3.217518654341667}}], 
      LineBox[{{6.86961989706414, 3.217518654341667}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.86961989706414, 3.217518654341667}, {6.86961989706414, 
       3.217518654341667}}], 
      LineBox[{{6.86961989706414, 3.217518654341667}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.86961989706414, 3.217518654341667}, {6.86961989706414, 
       3.217518654341667}}], 
      LineBox[{{6.825589840609398, 3.1767043127584165`}, {6.768228555732197, 
       3.1589803361301727`}, {6.768228555732197, 3.1589803361301727`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}}], 
      LineBox[{{6.825589840609398, 3.1767043127584165`}, {6.768228555732197, 
       3.1589803361301727`}, {6.768228555732197, 3.1589803361301727`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}}], 
      LineBox[{{6.825589840609398, 3.1767043127584165`}, {6.768228555732197, 
       3.1589803361301727`}, {6.768228555732197, 3.1589803361301727`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}}], 
      LineBox[{{6.825589840609398, 3.1767043127584165`}, {6.768228555732197, 
       3.1589803361301727`}, {6.768228555732197, 3.1589803361301727`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}}], 
      LineBox[{{6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}}], 
      LineBox[{{6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}}], 
      LineBox[{{6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}}], 
      LineBox[{{6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}], 
      LineBox[{{6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}], 
      LineBox[{{6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}], 
      LineBox[{{6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}], 
      LineBox[{{6.768228555732197, 3.428581562232637}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}}], 
      LineBox[{{6.768228555732197, 3.428581562232637}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}}], 
      LineBox[{{6.768228555732197, 3.428581562232637}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}}], 
      LineBox[{{6.768228555732197, 3.428581562232637}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}}], 
      LineBox[{{6.825589840609398, 3.4108575856043934`}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}], 
      LineBox[{{6.825589840609398, 3.4108575856043934`}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}], 
      LineBox[{{6.825589840609398, 3.4108575856043934`}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}], 
      LineBox[{{6.825589840609398, 3.4108575856043934`}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}], 
      LineBox[{{6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.86961989706414, 
       3.3700432440211427`}}], 
      LineBox[{{6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.86961989706414, 
       3.3700432440211427`}}], 
      LineBox[{{6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.86961989706414, 
       3.3700432440211427`}}], 
      LineBox[{{6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.86961989706414, 
       3.3700432440211427`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.636744923649835, 3.6022973954429838`}, {6.567897822030072, 
       3.6765688807462644`}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.8251118513528257`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}, {
       6.567897822030072, 3.8251118513528257`}, {6.55098359958391, 
       3.750840366049545}, {6.567897822030072, 3.6765688807462644`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.808267571781685, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835, 
       3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.808267571781685, 
       3.6022973954429838`}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`,
        3.9218709329841097`}, {6.808267571781685, 3.8993833366561064`}, {
       6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.808267571781685, 
       3.8993833366561064`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.636744923649835, 3.6022973954429838`}, {6.567897822030072, 
       3.6765688807462644`}, {6.567897822030072, 3.6765688807462644`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}}], 
      LineBox[{{6.636744923649835, 3.6022973954429838`}, {6.567897822030072, 
       3.6765688807462644`}, {6.567897822030072, 3.6765688807462644`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}}], 
      LineBox[{{6.636744923649835, 3.6022973954429838`}, {6.567897822030072, 
       3.6765688807462644`}, {6.567897822030072, 3.6765688807462644`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}}], 
      LineBox[{{6.636744923649835, 3.6022973954429838`}, {6.567897822030072, 
       3.6765688807462644`}, {6.567897822030072, 3.6765688807462644`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}}], 
      LineBox[{{6.567897822030072, 3.6765688807462644`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}}], 
      LineBox[{{6.567897822030072, 3.6765688807462644`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}}], 
      LineBox[{{6.567897822030072, 3.6765688807462644`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}}], 
      LineBox[{{6.567897822030072, 3.6765688807462644`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}}], 
      LineBox[{{6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}], 
      LineBox[{{6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}], 
      LineBox[{{6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}], 
      LineBox[{{6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}], 
      LineBox[{{6.567897822030072, 3.8251118513528257`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}}], 
      LineBox[{{6.567897822030072, 3.8251118513528257`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}}], 
      LineBox[{{6.567897822030072, 3.8251118513528257`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}}], 
      LineBox[{{6.567897822030072, 3.8251118513528257`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}], 
      LineBox[{{6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}], 
      LineBox[{{6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}], 
      LineBox[{{6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}], 
      LineBox[{{6.8641314536080476`, 3.654081284418261}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.8641314536080476`, 3.654081284418261}, {6.8641314536080476`, 
       3.654081284418261}}], 
      LineBox[{{6.8641314536080476`, 3.654081284418261}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.8641314536080476`, 3.654081284418261}, {6.8641314536080476`, 
       3.654081284418261}}], 
      LineBox[{{6.8641314536080476`, 3.654081284418261}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.8641314536080476`, 3.654081284418261}, {6.8641314536080476`, 
       3.654081284418261}}], 
      LineBox[{{6.8641314536080476`, 3.654081284418261}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.8641314536080476`, 3.654081284418261}, {6.8641314536080476`, 
       3.654081284418261}}], 
      LineBox[{{6.808267571781685, 3.6022973954429838`}, {6.7354894675091606`,
        3.5798097991149804`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}}], 
      LineBox[{{6.808267571781685, 3.6022973954429838`}, {6.7354894675091606`,
        3.5798097991149804`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}}], 
      LineBox[{{6.808267571781685, 3.6022973954429838`}, {6.7354894675091606`,
        3.5798097991149804`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}}], 
      LineBox[{{6.808267571781685, 3.6022973954429838`}, {6.7354894675091606`,
        3.5798097991149804`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}}], 
      LineBox[{{6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835,
        3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}}], 
      LineBox[{{6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835,
        3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}}], 
      LineBox[{{6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835,
        3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}}], 
      LineBox[{{6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835,
        3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`,
        3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}], 
      LineBox[{{6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`,
        3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}], 
      LineBox[{{6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`,
        3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}], 
      LineBox[{{6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`,
        3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}], 
      LineBox[{{6.7354894675091606`, 3.9218709329841097`}, {6.808267571781685,
        3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}}], 
      LineBox[{{6.7354894675091606`, 3.9218709329841097`}, {6.808267571781685,
        3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}}], 
      LineBox[{{6.7354894675091606`, 3.9218709329841097`}, {6.808267571781685,
        3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}}], 
      LineBox[{{6.7354894675091606`, 3.9218709329841097`}, {6.808267571781685,
        3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}}], 
      LineBox[{{6.808267571781685, 3.8993833366561064`}, {6.8641314536080476`,
        3.847599447680829}, {6.8641314536080476`, 3.847599447680829}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}], 
      LineBox[{{6.808267571781685, 3.8993833366561064`}, {6.8641314536080476`,
        3.847599447680829}, {6.8641314536080476`, 3.847599447680829}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}], 
      LineBox[{{6.808267571781685, 3.8993833366561064`}, {6.8641314536080476`,
        3.847599447680829}, {6.8641314536080476`, 3.847599447680829}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}], 
      LineBox[{{6.808267571781685, 3.8993833366561064`}, {6.8641314536080476`,
        3.847599447680829}, {6.8641314536080476`, 3.847599447680829}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}], 
      LineBox[{{6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.8641314536080476`, 
       3.847599447680829}}], 
      LineBox[{{6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.8641314536080476`, 
       3.847599447680829}}], 
      LineBox[{{6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.8641314536080476`, 
       3.847599447680829}}], 
      LineBox[{{6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.8641314536080476`, 
       3.847599447680829}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}], 
      LineBox[{{6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}], 
      LineBox[{{6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}], 
      LineBox[{{6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}], 
      LineBox[{{6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}], 
      LineBox[{{6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}], 
      LineBox[{{6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}], 
      LineBox[{{6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}], 
      LineBox[{{6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}], 
      LineBox[{{6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}], 
      LineBox[{{6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}], 
      LineBox[{{6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}], 
      LineBox[{{6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}], 
      LineBox[{{6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}], 
      LineBox[{{6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}], 
      LineBox[{{6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}], 
      LineBox[{{7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}], 
      LineBox[{{7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}], 
      LineBox[{{7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}], 
      LineBox[{{7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}], 
      LineBox[{{7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}], 
      LineBox[{{7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}], 
      LineBox[{{7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}], 
      LineBox[{{7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}], 
      LineBox[{{7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}], 
      LineBox[{{7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}], 
      LineBox[{{7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}], 
      LineBox[{{7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}], 
      LineBox[{{7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}], 
      LineBox[{{7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}], 
      LineBox[{{7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}], 
      LineBox[{{6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}], 
      LineBox[{{6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}], 
      LineBox[{{6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}], 
      LineBox[{{7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}], 
      LineBox[{{7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}], 
      LineBox[{{7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}], 
      LineBox[{{7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}], 
      LineBox[{{7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}], 
      LineBox[{{7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}], 
      LineBox[{{7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}], 
      LineBox[{{7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}], 
      LineBox[{{7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}], 
      LineBox[{{7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}], 
      LineBox[{{7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}], 
      LineBox[{{7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}], 
      LineBox[{{6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}], 
      LineBox[{{6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}], 
      LineBox[{{6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}], 
      LineBox[{{6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}], 
      LineBox[{{6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}], 
      LineBox[{{6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}], 
      LineBox[{{6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}], 
      LineBox[{{6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}], 
      LineBox[{{6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}], 
      LineBox[{{6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}], 
      LineBox[{{6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}], 
      LineBox[{{6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}], 
      LineBox[{{6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}], 
      LineBox[{{6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}], 
      LineBox[{{6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}], 
      LineBox[{{7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}], 
      LineBox[{{7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}], 
      LineBox[{{7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}], 
      LineBox[{{7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}], 
      LineBox[{{7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}], 
      LineBox[{{7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}], 
      LineBox[{{7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}], 
      LineBox[{{7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}], 
      LineBox[{{7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}], 
      LineBox[{{7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}], 
      LineBox[{{7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}], 
      LineBox[{{7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}], 
      LineBox[{{7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}], 
      LineBox[{{7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}], 
      LineBox[{{7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}], 
      LineBox[{{6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}], 
      LineBox[{{6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}], 
      LineBox[{{6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}], 
      LineBox[{{7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}], 
      LineBox[{{7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}], 
      LineBox[{{7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}], 
      LineBox[{{7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}], 
      LineBox[{{7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}], 
      LineBox[{{7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}], 
      LineBox[{{7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}], 
      LineBox[{{7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}], 
      LineBox[{{7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}], 
      LineBox[{{7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}], 
      LineBox[{{7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}], 
      LineBox[{{7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}], 
      LineBox[{{6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}], 
      LineBox[{{6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}], 
      LineBox[{{6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}], 
      LineBox[{{6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}], 
      LineBox[{{6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}], 
      LineBox[{{6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}], 
      LineBox[{{6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}], 
      LineBox[{{6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}], 
      LineBox[{{6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}], 
      LineBox[{{6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}], 
      LineBox[{{6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}], 
      LineBox[{{6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}], 
      LineBox[{{6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}], 
      LineBox[{{6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}], 
      LineBox[{{6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}], 
      LineBox[{{7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}], 
      LineBox[{{7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}], 
      LineBox[{{7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}], 
      LineBox[{{7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}], 
      LineBox[{{7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}], 
      LineBox[{{7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}], 
      LineBox[{{7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}], 
      LineBox[{{7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}], 
      LineBox[{{7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}], 
      LineBox[{{7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}], 
      LineBox[{{7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}], 
      LineBox[{{7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}], 
      LineBox[{{7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}], 
      LineBox[{{7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}], 
      LineBox[{{7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}], 
      LineBox[{{6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}], 
      LineBox[{{6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}], 
      LineBox[{{6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}], 
      LineBox[{{7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}], 
      LineBox[{{7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}], 
      LineBox[{{7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}], 
      LineBox[{{7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}], 
      LineBox[{{7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}], 
      LineBox[{{7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}], 
      LineBox[{{7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}], 
      LineBox[{{7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}], 
      LineBox[{{7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}], 
      LineBox[{{7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}], 
      LineBox[{{7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}], 
      LineBox[{{7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}], 
      LineBox[{{6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}], 
      LineBox[{{6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}], 
      LineBox[{{6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}], 
      LineBox[{{6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}], 
      LineBox[{{6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}], 
      LineBox[{{6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}], 
      LineBox[{{6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}], 
      LineBox[{{6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}], 
      LineBox[{{6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}], 
      LineBox[{{6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}], 
      LineBox[{{6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}], 
      LineBox[{{6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}], 
      LineBox[{{6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}], 
      LineBox[{{6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}], 
      LineBox[{{6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}], 
      LineBox[{{7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}], 
      LineBox[{{7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}], 
      LineBox[{{7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}], 
      LineBox[{{7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}], 
      LineBox[{{7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}], 
      LineBox[{{7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}], 
      LineBox[{{7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}], 
      LineBox[{{7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}], 
      LineBox[{{7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}], 
      LineBox[{{7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}], 
      LineBox[{{7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}], 
      LineBox[{{6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}], 
      LineBox[{{6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}], 
      LineBox[{{6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}], 
      LineBox[{{6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}], 
      LineBox[{{6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}], 
      LineBox[{{6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}], 
      LineBox[{{6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}], 
      LineBox[{{6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}], 
      LineBox[{{6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}], 
      LineBox[{{6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}], 
      LineBox[{{6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}], 
      LineBox[{{7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}], 
      LineBox[{{7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}], 
      LineBox[{{7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}], 
      LineBox[{{7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}], 
      LineBox[{{7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}], 
      LineBox[{{7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}], 
      LineBox[{{7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}], 
      LineBox[{{7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}], 
      LineBox[{{6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}], 
      LineBox[{{6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}], 
      LineBox[{{6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}], 
      LineBox[{{6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}], 
      LineBox[{{6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}], 
      LineBox[{{6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}], 
      LineBox[{{6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}], 
      LineBox[{{6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}], 
      LineBox[{{6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}], 
      LineBox[{{6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}], 
      LineBox[{{6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}], 
      LineBox[{{6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}], 
      LineBox[{{6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}], 
      LineBox[{{6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}], 
      LineBox[{{6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}], 
      LineBox[{{7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}], 
      LineBox[{{7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}], 
      LineBox[{{7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}], 
      LineBox[{{7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}], 
      LineBox[{{7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}], 
      LineBox[{{7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}], 
      LineBox[{{7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}], 
      LineBox[{{7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}], 
      LineBox[{{7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}], 
      LineBox[{{7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}], 
      LineBox[{{7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}], 
      LineBox[{{6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}], 
      LineBox[{{6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}], 
      LineBox[{{6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}], 
      LineBox[{{6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}], 
      LineBox[{{6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}], 
      LineBox[{{6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}], 
      LineBox[{{6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}], 
      LineBox[{{6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}], 
      LineBox[{{6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}], 
      LineBox[{{6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}], 
      LineBox[{{6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}], 
      LineBox[{{7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}], 
      LineBox[{{7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}], 
      LineBox[{{7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}], 
      LineBox[{{7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}], 
      LineBox[{{7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}], 
      LineBox[{{7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}], 
      LineBox[{{7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}], 
      LineBox[{{7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}], 
      LineBox[{{6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}], 
      LineBox[{{6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}], 
      LineBox[{{6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}], 
      LineBox[{{6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}], 
      LineBox[{{6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}], 
      LineBox[{{6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}], 
      LineBox[{{6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}], 
      LineBox[{{6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}], 
      LineBox[{{6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}], 
      LineBox[{{6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}], 
      LineBox[{{6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}], 
      LineBox[{{6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}], 
      LineBox[{{6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}], 
      LineBox[{{6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}], 
      LineBox[{{6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}], 
      LineBox[{{7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}], 
      LineBox[{{7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}], 
      LineBox[{{7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}], 
      LineBox[{{7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}], 
      LineBox[{{7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}], 
      LineBox[{{7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}], 
      LineBox[{{7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}], 
      LineBox[{{7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}], 
      LineBox[{{7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}], 
      LineBox[{{7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}], 
      LineBox[{{7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}], 
      LineBox[{{7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}], 
      LineBox[{{7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}], 
      LineBox[{{7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}], 
      LineBox[{{7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}], 
      LineBox[{{6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}], 
      LineBox[{{6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}], 
      LineBox[{{6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}], 
      LineBox[{{7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}], 
      LineBox[{{7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}], 
      LineBox[{{7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}], 
      LineBox[{{7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}], 
      LineBox[{{7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}], 
      LineBox[{{7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}], 
      LineBox[{{7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}], 
      LineBox[{{7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}], 
      LineBox[{{7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}], 
      LineBox[{{7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}], 
      LineBox[{{7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}], 
      LineBox[{{7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}], 
      LineBox[{{6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}], 
      LineBox[{{6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}], 
      LineBox[{{6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}], 
      LineBox[{{6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}], 
      LineBox[{{6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}], 
      LineBox[{{6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}], 
      LineBox[{{6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}], 
      LineBox[{{6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}], 
      LineBox[{{6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}], 
      LineBox[{{6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}], 
      LineBox[{{6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}], 
      LineBox[{{6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}], 
      LineBox[{{6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}], 
      LineBox[{{6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}], 
      LineBox[{{6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}], 
      LineBox[{{7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}], 
      LineBox[{{7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}], 
      LineBox[{{7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}], 
      LineBox[{{7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}], 
      LineBox[{{7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}], 
      LineBox[{{7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}], 
      LineBox[{{7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}], 
      LineBox[{{7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}], 
      LineBox[{{7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}], 
      LineBox[{{7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}], 
      LineBox[{{7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}], 
      LineBox[{{6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}], 
      LineBox[{{6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}], 
      LineBox[{{6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}], 
      LineBox[{{6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}], 
      LineBox[{{6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}], 
      LineBox[{{6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}], 
      LineBox[{{6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}], 
      LineBox[{{6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}], 
      LineBox[{{6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}], 
      LineBox[{{6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}], 
      LineBox[{{6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}], 
      LineBox[{{7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}], 
      LineBox[{{7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}], 
      LineBox[{{7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}], 
      LineBox[{{7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}], 
      LineBox[{{7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}], 
      LineBox[{{7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}], 
      LineBox[{{7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}], 
      LineBox[{{7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}], 
      LineBox[{{6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}], 
      LineBox[{{6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}], 
      LineBox[{{6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}], 
      LineBox[{{6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}], 
      LineBox[{{6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}], 
      LineBox[{{6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}], 
      LineBox[{{6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}], 
      LineBox[{{6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}], 
      LineBox[{{6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}], 
      LineBox[{{6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}], 
      LineBox[{{6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}], 
      LineBox[{{6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}], 
      LineBox[{{6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}], 
      LineBox[{{6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}], 
      LineBox[{{6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}], 
      LineBox[{{7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}], 
      LineBox[{{7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}], 
      LineBox[{{7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}], 
      LineBox[{{7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}], 
      LineBox[{{7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}], 
      LineBox[{{7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}], 
      LineBox[{{7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}], 
      LineBox[{{7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}], 
      LineBox[{{7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}], 
      LineBox[{{7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}], 
      LineBox[{{7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}], 
      LineBox[{{6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}], 
      LineBox[{{6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}], 
      LineBox[{{6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}], 
      LineBox[{{6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}], 
      LineBox[{{6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}], 
      LineBox[{{6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}], 
      LineBox[{{6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}], 
      LineBox[{{6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}], 
      LineBox[{{6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}], 
      LineBox[{{6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}], 
      LineBox[{{6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}], 
      LineBox[{{7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}], 
      LineBox[{{7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}], 
      LineBox[{{7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}], 
      LineBox[{{7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}], 
      LineBox[{{7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}], 
      LineBox[{{7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}], 
      LineBox[{{7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}], 
      LineBox[{{7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.30890591666472045`}, {
       6.875436124385875, -0.30890591666472045`}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028113}, {
       6.875436124385875, -0.5947917849028113}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}], 
      LineBox[{{6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}], 
      LineBox[{{6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}], 
      LineBox[{{6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}], 
      LineBox[{{6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}], 
      LineBox[{{6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}], 
      LineBox[{{6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}], 
      LineBox[{{6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}], 
      LineBox[{{6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}], 
      LineBox[{{6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}], 
      LineBox[{{6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}], 
      LineBox[{{6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}], 
      LineBox[{{6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}], 
      LineBox[{{6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}], 
      LineBox[{{6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}], 
      LineBox[{{6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}], 
      LineBox[{{7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}], 
      LineBox[{{7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}], 
      LineBox[{{7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}], 
      LineBox[{{7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}], 
      LineBox[{{7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}], 
      LineBox[{{7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}], 
      LineBox[{{7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}], 
      LineBox[{{7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}], 
      LineBox[{{7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}], 
      LineBox[{{7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}], 
      LineBox[{{7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}], 
      LineBox[{{6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}], 
      LineBox[{{6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}], 
      LineBox[{{6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}], 
      LineBox[{{6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}], 
      LineBox[{{6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}], 
      LineBox[{{6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}], 
      LineBox[{{6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}], 
      LineBox[{{6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}], 
      LineBox[{{6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}], 
      LineBox[{{6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}], 
      LineBox[{{6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}], 
      LineBox[{{7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}], 
      LineBox[{{7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}], 
      LineBox[{{7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}], 
      LineBox[{{7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}], 
      LineBox[{{7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}], 
      LineBox[{{7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}], 
      LineBox[{{7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}], 
      LineBox[{{7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {6.920588730729565, 
       0.043846028048759644`}, {6.932075606427196, 0.09428566973331229}, {
       6.9788314121383745`, 0.1447253114178649}, {6.9788314121383745`, 
       0.1447253114178649}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635793}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.920588730729565, 0.043846028048759644`}, {6.920588730729565,
        0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.05703325532034563}, {
       6.9788314121383745`, -0.05703325532034563}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9788314121383745`, 0.14472531141786493`}, {
       7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.133255348163785, 0.10955756441132598`}, {
       7.153559456364802, 0.04384602804875966}, {7.153559456364802, 
       0.04384602804875966}, {7.133255348163785, 0.10955756441132598`}, {
       7.095316774955993, 0.1447253114178649}, {7.045891326050571, 
       0.15999720609587864`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}], 
      LineBox[{{6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}], 
      LineBox[{{6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}], 
      LineBox[{{6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}], 
      LineBox[{{6.932075606427196, -0.006593613635792986}, {6.920588730729565,
        0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}], 
      LineBox[{{6.932075606427196, -0.006593613635792986}, {6.920588730729565,
        0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}], 
      LineBox[{{6.932075606427196, -0.006593613635792986}, {6.920588730729565,
        0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}], 
      LineBox[{{6.932075606427196, -0.006593613635792986}, {6.920588730729565,
        0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}], 
      LineBox[{{6.920588730729565, 0.043846028048759644`}, {6.932075606427196,
        0.09428566973331227}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}}], 
      LineBox[{{6.920588730729565, 0.043846028048759644`}, {6.932075606427196,
        0.09428566973331227}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}}], 
      LineBox[{{6.920588730729565, 0.043846028048759644`}, {6.932075606427196,
        0.09428566973331227}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}}], 
      LineBox[{{6.920588730729565, 0.043846028048759644`}, {6.932075606427196,
        0.09428566973331227}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}}], 
      LineBox[{{6.932075606427196, 0.09428566973331229}, {6.9788314121383745`,
        0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.932075606427196, 0.09428566973331229}, {6.932075606427196, 
       0.09428566973331229}}], 
      LineBox[{{6.932075606427196, 0.09428566973331229}, {6.9788314121383745`,
        0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.932075606427196, 0.09428566973331229}, {6.932075606427196, 
       0.09428566973331229}}], 
      LineBox[{{6.932075606427196, 0.09428566973331229}, {6.9788314121383745`,
        0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.932075606427196, 0.09428566973331229}, {6.932075606427196, 
       0.09428566973331229}}], 
      LineBox[{{6.932075606427196, 0.09428566973331229}, {6.9788314121383745`,
        0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.932075606427196, 0.09428566973331229}, {6.932075606427196, 
       0.09428566973331229}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}], 
      LineBox[{{7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}], 
      LineBox[{{7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}], 
      LineBox[{{7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}], 
      LineBox[{{7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}], 
      LineBox[{{7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}], 
      LineBox[{{7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}], 
      LineBox[{{7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}], 
      LineBox[{{7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}], 
      LineBox[{{7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}], 
      LineBox[{{7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}], 
      LineBox[{{7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}], 
      LineBox[{{7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}], 
      LineBox[{{7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}], 
      LineBox[{{7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}], 
      LineBox[{{7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9788314121383745`, 0.14472531141786493`}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}}], 
      LineBox[{{6.9788314121383745`, 0.14472531141786493`}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}}], 
      LineBox[{{6.9788314121383745`, 0.14472531141786493`}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}}], 
      LineBox[{{6.9788314121383745`, 0.14472531141786493`}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}}], 
      LineBox[{{7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}}], 
      LineBox[{{7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}}], 
      LineBox[{{7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}}], 
      LineBox[{{7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}}], 
      LineBox[{{7.095316774955993, 0.1447253114178649}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}], 
      LineBox[{{7.095316774955993, 0.1447253114178649}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}], 
      LineBox[{{7.095316774955993, 0.1447253114178649}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}], 
      LineBox[{{7.095316774955993, 0.1447253114178649}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}], 
      LineBox[{{7.133255348163785, 0.10955756441132598`}, {7.153559456364802, 
       0.043846028048759624`}, {7.153559456364802, 0.043846028048759624`}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}}], 
      LineBox[{{7.133255348163785, 0.10955756441132598`}, {7.153559456364802, 
       0.043846028048759624`}, {7.153559456364802, 0.043846028048759624`}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}}], 
      LineBox[{{7.133255348163785, 0.10955756441132598`}, {7.153559456364802, 
       0.043846028048759624`}, {7.153559456364802, 0.043846028048759624`}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}}], 
      LineBox[{{7.133255348163785, 0.10955756441132598`}, {7.153559456364802, 
       0.043846028048759624`}, {7.153559456364802, 0.043846028048759624`}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.839439546595807, 
       0.45437020003482936`}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.3638127776602549}, {7.080233205937332, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.080233205937332, 
       0.31534791599484513`}, {7.132516558122411, 0.3638127776602549}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.919704099709649, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.080233205937332, 0.5933924840748136}, {
       7.132516558122411, 0.5449276224094038}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.5449276224094038}, {7.080233205937332, 
       0.5933924840748136}, {7.0121197284516485`, 0.6144387644293959}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}], 
      LineBox[{{6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}], 
      LineBox[{{6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}], 
      LineBox[{{6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}], 
      LineBox[{{6.855269671896411, 0.3848590580148372}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.3848590580148372}, {6.855269671896411, 
       0.3848590580148372}}], 
      LineBox[{{6.855269671896411, 0.3848590580148372}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.3848590580148372}, {6.855269671896411, 
       0.3848590580148372}}], 
      LineBox[{{6.855269671896411, 0.3848590580148372}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.3848590580148372}, {6.855269671896411, 
       0.3848590580148372}}], 
      LineBox[{{6.855269671896411, 0.3848590580148372}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.3848590580148372}, {6.855269671896411, 
       0.3848590580148372}}], 
      LineBox[{{6.839439546595807, 0.45437020003482936`}, {6.855269671896411, 
       0.5238813420548215}, {6.855269671896411, 0.5238813420548215}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}}], 
      LineBox[{{6.839439546595807, 0.45437020003482936`}, {6.855269671896411, 
       0.5238813420548215}, {6.855269671896411, 0.5238813420548215}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}}], 
      LineBox[{{6.839439546595807, 0.45437020003482936`}, {6.855269671896411, 
       0.5238813420548215}, {6.855269671896411, 0.5238813420548215}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}}], 
      LineBox[{{6.839439546595807, 0.45437020003482936`}, {6.855269671896411, 
       0.5238813420548215}, {6.855269671896411, 0.5238813420548215}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}}], 
      LineBox[{{6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}}], 
      LineBox[{{6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}}], 
      LineBox[{{6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}}], 
      LineBox[{{6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}}], 
      LineBox[{{7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}}], 
      LineBox[{{7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}}], 
      LineBox[{{7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}}], 
      LineBox[{{7.132516558122411, 0.3638127776602549}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}}], 
      LineBox[{{7.132516558122411, 0.3638127776602549}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}}], 
      LineBox[{{7.132516558122411, 0.3638127776602549}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}}], 
      LineBox[{{7.132516558122411, 0.3638127776602549}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}}], 
      LineBox[{{7.080233205937332, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}}], 
      LineBox[{{7.080233205937332, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}}], 
      LineBox[{{7.080233205937332, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}}], 
      LineBox[{{7.080233205937332, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}}], 
      LineBox[{{7.0121197284516485`, 0.2943016356402628}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}}], 
      LineBox[{{7.0121197284516485`, 0.2943016356402628}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}}], 
      LineBox[{{7.0121197284516485`, 0.2943016356402628}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}}], 
      LineBox[{{7.0121197284516485`, 0.2943016356402628}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.919704099709649, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.0121197284516485`, 0.6144387644293959}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}}], 
      LineBox[{{6.919704099709649, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.0121197284516485`, 0.6144387644293959}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}}], 
      LineBox[{{6.919704099709649, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.0121197284516485`, 0.6144387644293959}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}}], 
      LineBox[{{6.919704099709649, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.0121197284516485`, 0.6144387644293959}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}}], 
      LineBox[{{7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}}], 
      LineBox[{{7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}}], 
      LineBox[{{7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}}], 
      LineBox[{{7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}}], 
      LineBox[{{7.080233205937332, 0.5933924840748136}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}}], 
      LineBox[{{7.080233205937332, 0.5933924840748136}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}}], 
      LineBox[{{7.080233205937332, 0.5933924840748136}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}}], 
      LineBox[{{7.080233205937332, 0.5933924840748136}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}}], 
      LineBox[{{7.132516558122411, 0.5449276224094038}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}}], 
      LineBox[{{7.132516558122411, 0.5449276224094038}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}}], 
      LineBox[{{7.132516558122411, 0.5449276224094038}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}}], 
      LineBox[{{7.132516558122411, 0.5449276224094038}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.8584762192425, 
       0.9930056619992144}, {6.873868754997188, 0.9254160050271929}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       0.9049515035334025}, {7.092613659125886, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.092613659125886, 
       0.8578263480551716}, {7.143451751219389, 0.9049515035334025}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.936522032536962, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.092613659125886, 1.1281849759432572`}, {
       7.143451751219389, 1.0810598204650264`}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 1.0810598204650264`}, {7.092613659125886, 
       1.1281849759432572`}, {7.026383031277695, 1.1486494774370477`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}], 
      LineBox[{{6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}], 
      LineBox[{{6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}], 
      LineBox[{{6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}], 
      LineBox[{{6.873868754997188, 0.925416005027193}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 0.925416005027193}, {6.873868754997188, 
       0.925416005027193}}], 
      LineBox[{{6.873868754997188, 0.925416005027193}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 0.925416005027193}, {6.873868754997188, 
       0.925416005027193}}], 
      LineBox[{{6.873868754997188, 0.925416005027193}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 0.925416005027193}, {6.873868754997188, 
       0.925416005027193}}], 
      LineBox[{{6.873868754997188, 0.925416005027193}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 0.925416005027193}, {6.873868754997188, 
       0.925416005027193}}], 
      LineBox[{{6.8584762192425, 0.9930056619992144}, {6.873868754997188, 
       1.0605953189712358`}, {6.873868754997188, 1.0605953189712358`}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}}], 
      LineBox[{{6.8584762192425, 0.9930056619992144}, {6.873868754997188, 
       1.0605953189712358`}, {6.873868754997188, 1.0605953189712358`}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}}], 
      LineBox[{{6.8584762192425, 0.9930056619992144}, {6.873868754997188, 
       1.0605953189712358`}, {6.873868754997188, 1.0605953189712358`}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}}], 
      LineBox[{{6.8584762192425, 0.9930056619992144}, {6.873868754997188, 
       1.0605953189712358`}, {6.873868754997188, 1.0605953189712358`}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}}], 
      LineBox[{{6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}}], 
      LineBox[{{6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}}], 
      LineBox[{{6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}}], 
      LineBox[{{6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}}], 
      LineBox[{{7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}}], 
      LineBox[{{7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}}], 
      LineBox[{{7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}}], 
      LineBox[{{7.143451751219389, 0.9049515035334025}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}}], 
      LineBox[{{7.143451751219389, 0.9049515035334025}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}}], 
      LineBox[{{7.143451751219389, 0.9049515035334025}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}}], 
      LineBox[{{7.143451751219389, 0.9049515035334025}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}}], 
      LineBox[{{7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}], 
      LineBox[{{7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}], 
      LineBox[{{7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}], 
      LineBox[{{7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}], 
      LineBox[{{7.026383031277695, 0.837361846561381}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.026383031277695, 
       0.837361846561381}}], 
      LineBox[{{7.026383031277695, 0.837361846561381}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.026383031277695, 
       0.837361846561381}}], 
      LineBox[{{7.026383031277695, 0.837361846561381}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.026383031277695, 
       0.837361846561381}}], 
      LineBox[{{7.026383031277695, 0.837361846561381}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.026383031277695, 
       0.837361846561381}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.936522032536962, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.026383031277695, 1.1486494774370477`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}}], 
      LineBox[{{6.936522032536962, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.026383031277695, 1.1486494774370477`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}}], 
      LineBox[{{6.936522032536962, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.026383031277695, 1.1486494774370477`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}}], 
      LineBox[{{6.936522032536962, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.026383031277695, 1.1486494774370477`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}}], 
      LineBox[{{7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}}], 
      LineBox[{{7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}}], 
      LineBox[{{7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}}], 
      LineBox[{{7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}}], 
      LineBox[{{7.092613659125886, 1.1281849759432572`}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}}], 
      LineBox[{{7.092613659125886, 1.1281849759432572`}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}}], 
      LineBox[{{7.092613659125886, 1.1281849759432572`}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}}], 
      LineBox[{{7.092613659125886, 1.1281849759432572`}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}}], 
      LineBox[{{7.143451751219389, 1.0810598204650264`}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}}], 
      LineBox[{{7.143451751219389, 1.0810598204650264`}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}}], 
      LineBox[{{7.143451751219389, 1.0810598204650264`}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}}], 
      LineBox[{{7.143451751219389, 1.0810598204650264`}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.820735941120695, 
       1.5167738208779487`}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136,
        1.43973067037855}, {7.025594931687091, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {7.025594931687091, 
       1.3984984275285253`}, {7.070075815367136, 1.43973067037855}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.889022271309494, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {7.025594931687091, 1.635049214227372}, {
       7.070075815367136, 1.5938169713773473`}, {7.0938812618758895`, 
       1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.5938169713773473`}, {7.025594931687091, 
       1.635049214227372}, {6.967646320083938, 1.652954668052059}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}], 
      LineBox[{{6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}], 
      LineBox[{{6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}], 
      LineBox[{{6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}], 
      LineBox[{{6.834203669043804, 1.457636124203237}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.457636124203237}, {6.834203669043804, 
       1.457636124203237}}], 
      LineBox[{{6.834203669043804, 1.457636124203237}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.457636124203237}, {6.834203669043804, 
       1.457636124203237}}], 
      LineBox[{{6.834203669043804, 1.457636124203237}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.457636124203237}, {6.834203669043804, 
       1.457636124203237}}], 
      LineBox[{{6.834203669043804, 1.457636124203237}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.457636124203237}, {6.834203669043804, 
       1.457636124203237}}], 
      LineBox[{{6.820735941120695, 1.5167738208779487`}, {6.834203669043804, 
       1.5759115175526603`}, {6.834203669043804, 1.5759115175526603`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}}], 
      LineBox[{{6.820735941120695, 1.5167738208779487`}, {6.834203669043804, 
       1.5759115175526603`}, {6.834203669043804, 1.5759115175526603`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}}], 
      LineBox[{{6.820735941120695, 1.5167738208779487`}, {6.834203669043804, 
       1.5759115175526603`}, {6.834203669043804, 1.5759115175526603`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}}], 
      LineBox[{{6.820735941120695, 1.5167738208779487`}, {6.834203669043804, 
       1.5759115175526603`}, {6.834203669043804, 1.5759115175526603`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}}], 
      LineBox[{{6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}}], 
      LineBox[{{6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}}], 
      LineBox[{{6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}}], 
      LineBox[{{6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136,
        1.43973067037855}, {7.070075815367136, 1.43973067037855}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}}], 
      LineBox[{{7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136,
        1.43973067037855}, {7.070075815367136, 1.43973067037855}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}}], 
      LineBox[{{7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136,
        1.43973067037855}, {7.070075815367136, 1.43973067037855}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}}], 
      LineBox[{{7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136,
        1.43973067037855}, {7.070075815367136, 1.43973067037855}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}}], 
      LineBox[{{7.070075815367136, 1.43973067037855}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}}], 
      LineBox[{{7.070075815367136, 1.43973067037855}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}}], 
      LineBox[{{7.070075815367136, 1.43973067037855}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}}], 
      LineBox[{{7.070075815367136, 1.43973067037855}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}}], 
      LineBox[{{7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}], 
      LineBox[{{7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}], 
      LineBox[{{7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}], 
      LineBox[{{7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}], 
      LineBox[{{6.967646320083938, 1.3805929737038383`}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.967646320083938, 
       1.3805929737038383`}}], 
      LineBox[{{6.967646320083938, 1.3805929737038383`}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.967646320083938, 
       1.3805929737038383`}}], 
      LineBox[{{6.967646320083938, 1.3805929737038383`}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.967646320083938, 
       1.3805929737038383`}}], 
      LineBox[{{6.967646320083938, 1.3805929737038383`}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.967646320083938, 
       1.3805929737038383`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.889022271309494, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.967646320083938, 1.652954668052059}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}}], 
      LineBox[{{6.889022271309494, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.967646320083938, 1.652954668052059}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}}], 
      LineBox[{{6.889022271309494, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.967646320083938, 1.652954668052059}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}}], 
      LineBox[{{6.889022271309494, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.967646320083938, 1.652954668052059}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}}], 
      LineBox[{{6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}}], 
      LineBox[{{6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}}], 
      LineBox[{{6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}}], 
      LineBox[{{6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}}], 
      LineBox[{{7.025594931687091, 1.635049214227372}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}}], 
      LineBox[{{7.025594931687091, 1.635049214227372}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}}], 
      LineBox[{{7.025594931687091, 1.635049214227372}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}}], 
      LineBox[{{7.025594931687091, 1.635049214227372}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}}], 
      LineBox[{{7.070075815367136, 1.5938169713773473`}, {7.0938812618758895`,
        1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}}], 
      LineBox[{{7.070075815367136, 1.5938169713773473`}, {7.0938812618758895`,
        1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}}], 
      LineBox[{{7.070075815367136, 1.5938169713773473`}, {7.0938812618758895`,
        1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}}], 
      LineBox[{{7.070075815367136, 1.5938169713773473`}, {7.0938812618758895`,
        1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043,
        1.9931407504512633`}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.844163433560921, 
       2.04786617070403}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       1.9765712264340805`}, {7.033737850247623, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {7.033737850247623, 
       1.9384153301984968`}, {7.074900005513737, 1.9765712264340805`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9073549057898225`, 2.1573170112095634`}, {6.980112797170388,
        2.173886535226746}, {7.033737850247623, 2.1573170112095634`}, {
       7.074900005513737, 2.1191611149739793`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 2.1191611149739793`}, {7.033737850247623, 
       2.1573170112095634`}, {6.980112797170388, 2.173886535226746}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043,
        1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}], 
      LineBox[{{6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043,
        1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}], 
      LineBox[{{6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043,
        1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}], 
      LineBox[{{6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043,
        1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}], 
      LineBox[{{6.856626331372043, 1.9931407504512633`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 1.9931407504512633`}, {6.856626331372043, 
       1.9931407504512633`}}], 
      LineBox[{{6.856626331372043, 1.9931407504512633`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 1.9931407504512633`}, {6.856626331372043, 
       1.9931407504512633`}}], 
      LineBox[{{6.856626331372043, 1.9931407504512633`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 1.9931407504512633`}, {6.856626331372043, 
       1.9931407504512633`}}], 
      LineBox[{{6.856626331372043, 1.9931407504512633`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 1.9931407504512633`}, {6.856626331372043, 
       1.9931407504512633`}}], 
      LineBox[{{6.844163433560921, 2.04786617070403}, {6.856626331372043, 
       2.1025915909567967`}, {6.856626331372043, 2.1025915909567967`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}}], 
      LineBox[{{6.844163433560921, 2.04786617070403}, {6.856626331372043, 
       2.1025915909567967`}, {6.856626331372043, 2.1025915909567967`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}}], 
      LineBox[{{6.844163433560921, 2.04786617070403}, {6.856626331372043, 
       2.1025915909567967`}, {6.856626331372043, 2.1025915909567967`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}}], 
      LineBox[{{6.844163433560921, 2.04786617070403}, {6.856626331372043, 
       2.1025915909567967`}, {6.856626331372043, 2.1025915909567967`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}}], 
      LineBox[{{6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`,
        2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}}], 
      LineBox[{{6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`,
        2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}}], 
      LineBox[{{6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`,
        2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}}], 
      LineBox[{{6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`,
        2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}}], 
      LineBox[{{7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}}], 
      LineBox[{{7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}}], 
      LineBox[{{7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}}], 
      LineBox[{{7.074900005513737, 1.9765712264340805`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}}], 
      LineBox[{{7.074900005513737, 1.9765712264340805`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}}], 
      LineBox[{{7.074900005513737, 1.9765712264340805`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}}], 
      LineBox[{{7.074900005513737, 1.9765712264340805`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}}], 
      LineBox[{{7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}], 
      LineBox[{{7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}], 
      LineBox[{{7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}], 
      LineBox[{{7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}], 
      LineBox[{{6.980112797170388, 1.921845806181314}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.980112797170388, 
       1.921845806181314}}], 
      LineBox[{{6.980112797170388, 1.921845806181314}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.980112797170388, 
       1.921845806181314}}], 
      LineBox[{{6.980112797170388, 1.921845806181314}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.980112797170388, 
       1.921845806181314}}], 
      LineBox[{{6.980112797170388, 1.921845806181314}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.980112797170388, 
       1.921845806181314}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.9073549057898225`, 2.1573170112095634`}, {6.980112797170388,
        2.173886535226746}, {6.980112797170388, 2.173886535226746}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}}], 
      LineBox[{{6.9073549057898225`, 2.1573170112095634`}, {6.980112797170388,
        2.173886535226746}, {6.980112797170388, 2.173886535226746}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}}], 
      LineBox[{{6.9073549057898225`, 2.1573170112095634`}, {6.980112797170388,
        2.173886535226746}, {6.980112797170388, 2.173886535226746}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}}], 
      LineBox[{{6.9073549057898225`, 2.1573170112095634`}, {6.980112797170388,
        2.173886535226746}, {6.980112797170388, 2.173886535226746}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}}], 
      LineBox[{{6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}}], 
      LineBox[{{6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}}], 
      LineBox[{{6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}}], 
      LineBox[{{6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}}], 
      LineBox[{{7.033737850247623, 2.1573170112095634`}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}}], 
      LineBox[{{7.033737850247623, 2.1573170112095634`}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}}], 
      LineBox[{{7.033737850247623, 2.1573170112095634`}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}}], 
      LineBox[{{7.033737850247623, 2.1573170112095634`}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}}], 
      LineBox[{{7.074900005513737, 2.1191611149739793`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}}], 
      LineBox[{{7.074900005513737, 2.1191611149739793`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}}], 
      LineBox[{{7.074900005513737, 2.1191611149739793`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}}], 
      LineBox[{{7.074900005513737, 2.1191611149739793`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.824702632571057, 
       2.480908611991962}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.3933860701829213`}, {7.0574264951154, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {7.0574264951154, 
       2.3465454273051365`}, {7.107957658189009, 2.3933860701829213`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.902277253419171, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {7.0574264951154, 2.6152717966787873`}, {
       7.107957658189009, 2.5684311538010025`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.5684311538010025`}, {7.0574264951154, 
       2.6152717966787873`}, {6.991595726916838, 2.635612746144415}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}], 
      LineBox[{{6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}], 
      LineBox[{{6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}], 
      LineBox[{{6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}], 
      LineBox[{{6.840002237696009, 2.413727019648549}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.413727019648549}, {6.840002237696009, 
       2.413727019648549}}], 
      LineBox[{{6.840002237696009, 2.413727019648549}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.413727019648549}, {6.840002237696009, 
       2.413727019648549}}], 
      LineBox[{{6.840002237696009, 2.413727019648549}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.413727019648549}, {6.840002237696009, 
       2.413727019648549}}], 
      LineBox[{{6.840002237696009, 2.413727019648549}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.413727019648549}, {6.840002237696009, 
       2.413727019648549}}], 
      LineBox[{{6.824702632571057, 2.480908611991962}, {6.840002237696009, 
       2.5480902043353746`}, {6.840002237696009, 2.5480902043353746`}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}}], 
      LineBox[{{6.824702632571057, 2.480908611991962}, {6.840002237696009, 
       2.5480902043353746`}, {6.840002237696009, 2.5480902043353746`}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}}], 
      LineBox[{{6.824702632571057, 2.480908611991962}, {6.840002237696009, 
       2.5480902043353746`}, {6.840002237696009, 2.5480902043353746`}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}}], 
      LineBox[{{6.824702632571057, 2.480908611991962}, {6.840002237696009, 
       2.5480902043353746`}, {6.840002237696009, 2.5480902043353746`}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}}], 
      LineBox[{{6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}}], 
      LineBox[{{6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}}], 
      LineBox[{{6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}}], 
      LineBox[{{6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}}], 
      LineBox[{{7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}}], 
      LineBox[{{7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}}], 
      LineBox[{{7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}}], 
      LineBox[{{7.107957658189009, 2.3933860701829213`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}}], 
      LineBox[{{7.107957658189009, 2.3933860701829213`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}}], 
      LineBox[{{7.107957658189009, 2.3933860701829213`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}}], 
      LineBox[{{7.107957658189009, 2.3933860701829213`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}}], 
      LineBox[{{7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}], 
      LineBox[{{7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}], 
      LineBox[{{7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}], 
      LineBox[{{7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}], 
      LineBox[{{6.991595726916838, 2.3262044778395086`}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.991595726916838, 
       2.3262044778395086`}}], 
      LineBox[{{6.991595726916838, 2.3262044778395086`}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.991595726916838, 
       2.3262044778395086`}}], 
      LineBox[{{6.991595726916838, 2.3262044778395086`}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.991595726916838, 
       2.3262044778395086`}}], 
      LineBox[{{6.991595726916838, 2.3262044778395086`}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.991595726916838, 
       2.3262044778395086`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.902277253419171, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.991595726916838, 2.635612746144415}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}}], 
      LineBox[{{6.902277253419171, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.991595726916838, 2.635612746144415}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}}], 
      LineBox[{{6.902277253419171, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.991595726916838, 2.635612746144415}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}}], 
      LineBox[{{6.902277253419171, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.991595726916838, 2.635612746144415}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}}], 
      LineBox[{{6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}}], 
      LineBox[{{6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}}], 
      LineBox[{{6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}}], 
      LineBox[{{6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}}], 
      LineBox[{{7.0574264951154, 2.6152717966787873`}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}}], 
      LineBox[{{7.0574264951154, 2.6152717966787873`}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}}], 
      LineBox[{{7.0574264951154, 2.6152717966787873`}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}}], 
      LineBox[{{7.0574264951154, 2.6152717966787873`}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}}], 
      LineBox[{{7.107957658189009, 2.5684311538010025`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}}], 
      LineBox[{{7.107957658189009, 2.5684311538010025`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}}], 
      LineBox[{{7.107957658189009, 2.5684311538010025`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}}], 
      LineBox[{{7.107957658189009, 2.5684311538010025`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.898035327942713, 
       2.9677201468426655`}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284,
        2.890298146256358}, {7.10390168705358, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.10390168705358, 
       2.848863148992918}, {7.148601299933284, 2.890298146256358}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.966657447646335, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.10390168705358, 3.086577144692413}, {
       7.148601299933284, 3.045142147428973}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 3.045142147428973}, {7.10390168705358, 
       3.086577144692413}, {7.04566812037785, 3.1045706463538463`}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}], 
      LineBox[{{6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}], 
      LineBox[{{6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}], 
      LineBox[{{6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}], 
      LineBox[{{6.911569281738738, 2.908291647917792}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 2.908291647917792}, {6.911569281738738, 
       2.908291647917792}}], 
      LineBox[{{6.911569281738738, 2.908291647917792}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 2.908291647917792}, {6.911569281738738, 
       2.908291647917792}}], 
      LineBox[{{6.911569281738738, 2.908291647917792}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 2.908291647917792}, {6.911569281738738, 
       2.908291647917792}}], 
      LineBox[{{6.911569281738738, 2.908291647917792}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 2.908291647917792}, {6.911569281738738, 
       2.908291647917792}}], 
      LineBox[{{6.898035327942713, 2.9677201468426655`}, {6.911569281738738, 
       3.027148645767539}, {6.911569281738738, 3.027148645767539}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}}], 
      LineBox[{{6.898035327942713, 2.9677201468426655`}, {6.911569281738738, 
       3.027148645767539}, {6.911569281738738, 3.027148645767539}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}}], 
      LineBox[{{6.898035327942713, 2.9677201468426655`}, {6.911569281738738, 
       3.027148645767539}, {6.911569281738738, 3.027148645767539}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}}], 
      LineBox[{{6.898035327942713, 2.9677201468426655`}, {6.911569281738738, 
       3.027148645767539}, {6.911569281738738, 3.027148645767539}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}}], 
      LineBox[{{6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}}], 
      LineBox[{{6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}}], 
      LineBox[{{6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}}], 
      LineBox[{{6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284,
        2.890298146256358}, {7.148601299933284, 2.890298146256358}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}}], 
      LineBox[{{7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284,
        2.890298146256358}, {7.148601299933284, 2.890298146256358}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}}], 
      LineBox[{{7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284,
        2.890298146256358}, {7.148601299933284, 2.890298146256358}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}}], 
      LineBox[{{7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284,
        2.890298146256358}, {7.148601299933284, 2.890298146256358}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}}], 
      LineBox[{{7.148601299933284, 2.890298146256358}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}}], 
      LineBox[{{7.148601299933284, 2.890298146256358}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}}], 
      LineBox[{{7.148601299933284, 2.890298146256358}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}}], 
      LineBox[{{7.148601299933284, 2.890298146256358}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}}], 
      LineBox[{{7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}], 
      LineBox[{{7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}], 
      LineBox[{{7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}], 
      LineBox[{{7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}], 
      LineBox[{{7.04566812037785, 2.8308696473314847`}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.04566812037785, 
       2.8308696473314847`}}], 
      LineBox[{{7.04566812037785, 2.8308696473314847`}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.04566812037785, 
       2.8308696473314847`}}], 
      LineBox[{{7.04566812037785, 2.8308696473314847`}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.04566812037785, 
       2.8308696473314847`}}], 
      LineBox[{{7.04566812037785, 2.8308696473314847`}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.04566812037785, 
       2.8308696473314847`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.966657447646335, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.04566812037785, 3.1045706463538463`}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}}], 
      LineBox[{{6.966657447646335, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.04566812037785, 3.1045706463538463`}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}}], 
      LineBox[{{6.966657447646335, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.04566812037785, 3.1045706463538463`}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}}], 
      LineBox[{{6.966657447646335, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.04566812037785, 3.1045706463538463`}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}}], 
      LineBox[{{7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}}], 
      LineBox[{{7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}}], 
      LineBox[{{7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}}], 
      LineBox[{{7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}}], 
      LineBox[{{7.10390168705358, 3.086577144692413}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}}], 
      LineBox[{{7.10390168705358, 3.086577144692413}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}}], 
      LineBox[{{7.10390168705358, 3.086577144692413}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}}], 
      LineBox[{{7.10390168705358, 3.086577144692413}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}}], 
      LineBox[{{7.148601299933284, 3.045142147428973}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}}], 
      LineBox[{{7.148601299933284, 3.045142147428973}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}}], 
      LineBox[{{7.148601299933284, 3.045142147428973}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}}], 
      LineBox[{{7.148601299933284, 3.045142147428973}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.815602554862664, 
       3.4833425711064887`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`,
        3.407080276266751}, {7.018385237526549, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {7.018385237526549, 
       3.3662659346835}, {7.0624152939812905`, 3.407080276266751}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.883196782417293, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {7.018385237526549, 3.600419207529477}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.085979465081177, 
       3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.018385237526549, 
       3.600419207529477}, {6.961023952649348, 3.618143184157721}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}], 
      LineBox[{{6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}], 
      LineBox[{{6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}], 
      LineBox[{{6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}], 
      LineBox[{{6.828933783285124, 3.4248042528949942`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.4248042528949942`}, {6.828933783285124, 
       3.4248042528949942`}}], 
      LineBox[{{6.828933783285124, 3.4248042528949942`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.4248042528949942`}, {6.828933783285124, 
       3.4248042528949942`}}], 
      LineBox[{{6.828933783285124, 3.4248042528949942`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.4248042528949942`}, {6.828933783285124, 
       3.4248042528949942`}}], 
      LineBox[{{6.828933783285124, 3.4248042528949942`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.4248042528949942`}, {6.828933783285124, 
       3.4248042528949942`}}], 
      LineBox[{{6.815602554862664, 3.4833425711064887`}, {6.828933783285124, 
       3.541880889317983}, {6.828933783285124, 3.541880889317983}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}}], 
      LineBox[{{6.815602554862664, 3.4833425711064887`}, {6.828933783285124, 
       3.541880889317983}, {6.828933783285124, 3.541880889317983}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}}], 
      LineBox[{{6.815602554862664, 3.4833425711064887`}, {6.828933783285124, 
       3.541880889317983}, {6.828933783285124, 3.541880889317983}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}}], 
      LineBox[{{6.815602554862664, 3.4833425711064887`}, {6.828933783285124, 
       3.541880889317983}, {6.828933783285124, 3.541880889317983}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}}], 
      LineBox[{{6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}}], 
      LineBox[{{6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}}], 
      LineBox[{{6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}}], 
      LineBox[{{6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`,
        3.407080276266751}, {7.0624152939812905`, 3.407080276266751}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}}], 
      LineBox[{{7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`,
        3.407080276266751}, {7.0624152939812905`, 3.407080276266751}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}}], 
      LineBox[{{7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`,
        3.407080276266751}, {7.0624152939812905`, 3.407080276266751}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}}], 
      LineBox[{{7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`,
        3.407080276266751}, {7.0624152939812905`, 3.407080276266751}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}}], 
      LineBox[{{7.0624152939812905`, 3.407080276266751}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}}], 
      LineBox[{{7.0624152939812905`, 3.407080276266751}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}}], 
      LineBox[{{7.0624152939812905`, 3.407080276266751}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}}], 
      LineBox[{{7.0624152939812905`, 3.407080276266751}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}}], 
      LineBox[{{7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}], 
      LineBox[{{7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}], 
      LineBox[{{7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}], 
      LineBox[{{7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}], 
      LineBox[{{6.961023952649348, 3.3485419580552565`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.961023952649348, 
       3.3485419580552565`}}], 
      LineBox[{{6.961023952649348, 3.3485419580552565`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.961023952649348, 
       3.3485419580552565`}}], 
      LineBox[{{6.961023952649348, 3.3485419580552565`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.961023952649348, 
       3.3485419580552565`}}], 
      LineBox[{{6.961023952649348, 3.3485419580552565`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.961023952649348, 
       3.3485419580552565`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{6.883196782417293, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.961023952649348, 3.618143184157721}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}}], 
      LineBox[{{6.883196782417293, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.961023952649348, 3.618143184157721}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}}], 
      LineBox[{{6.883196782417293, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.961023952649348, 3.618143184157721}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}}], 
      LineBox[{{6.883196782417293, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.961023952649348, 3.618143184157721}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}}], 
      LineBox[{{6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}}], 
      LineBox[{{6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}}], 
      LineBox[{{6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}}], 
      LineBox[{{6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}}], 
      LineBox[{{7.018385237526549, 3.600419207529477}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}}], 
      LineBox[{{7.018385237526549, 3.600419207529477}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}}], 
      LineBox[{{7.018385237526549, 3.600419207529477}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}}], 
      LineBox[{{7.018385237526549, 3.600419207529477}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}}], 
      LineBox[{{7.0624152939812905`, 3.5596048659462265`}, {7.085979465081177,
        3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}}], 
      LineBox[{{7.0624152939812905`, 3.5596048659462265`}, {7.085979465081177,
        3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}}], 
      LineBox[{{7.0624152939812905`, 3.5596048659462265`}, {7.085979465081177,
        3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}}], 
      LineBox[{{7.0624152939812905`, 3.5596048659462265`}, {7.085979465081177,
        3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}], 
      LineBox[{{7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}], 
      LineBox[{{7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}], 
      LineBox[{{7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}], 
      LineBox[{{7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}], 
      LineBox[{{7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}], 
      LineBox[{{7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}], 
      LineBox[{{7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}], 
      LineBox[{{7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}], 
      LineBox[{{7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}], 
      LineBox[{{7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}], 
      LineBox[{{7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}], 
      LineBox[{{7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}], 
      LineBox[{{7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}], 
      LineBox[{{7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}], 
      LineBox[{{7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}], 
      LineBox[{{7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}], 
      LineBox[{{7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}], 
      LineBox[{{7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}], 
      LineBox[{{7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}], 
      LineBox[{{7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}], 
      LineBox[{{7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}], 
      LineBox[{{7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}], 
      LineBox[{{7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}], 
      LineBox[{{7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}], 
      LineBox[{{7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}], 
      LineBox[{{7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}], 
      LineBox[{{7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}], 
      LineBox[{{7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}], 
      LineBox[{{7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}], 
      LineBox[{{7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}], 
      LineBox[{{7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}], 
      LineBox[{{7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}], 
      LineBox[{{7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}], 
      LineBox[{{7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}], 
      LineBox[{{7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}], 
      LineBox[{{7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}], 
      LineBox[{{7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}], 
      LineBox[{{7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}], 
      LineBox[{{7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}], 
      LineBox[{{7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}], 
      LineBox[{{7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}], 
      LineBox[{{7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}], 
      LineBox[{{7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}], 
      LineBox[{{7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}], 
      LineBox[{{7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}], 
      LineBox[{{7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}], 
      LineBox[{{7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}], 
      LineBox[{{7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}], 
      LineBox[{{7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}], 
      LineBox[{{7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}], 
      LineBox[{{7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}], 
      LineBox[{{7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}], 
      LineBox[{{7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}], 
      LineBox[{{7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}], 
      LineBox[{{7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}], 
      LineBox[{{7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}], 
      LineBox[{{7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}], 
      LineBox[{{7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}], 
      LineBox[{{7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}], 
      LineBox[{{7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}], 
      LineBox[{{7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}], 
      LineBox[{{7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}], 
      LineBox[{{7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}], 
      LineBox[{{7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}], 
      LineBox[{{7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}], 
      LineBox[{{7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}], 
      LineBox[{{7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}], 
      LineBox[{{7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}], 
      LineBox[{{7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}], 
      LineBox[{{7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}], 
      LineBox[{{7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}], 
      LineBox[{{7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}], 
      LineBox[{{7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}], 
      LineBox[{{7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}], 
      LineBox[{{7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}], 
      LineBox[{{7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}], 
      LineBox[{{7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}], 
      LineBox[{{7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}], 
      LineBox[{{7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}], 
      LineBox[{{7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}], 
      LineBox[{{7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}], 
      LineBox[{{7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}], 
      LineBox[{{7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}], 
      LineBox[{{7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}], 
      LineBox[{{7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}], 
      LineBox[{{7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}], 
      LineBox[{{7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}], 
      LineBox[{{7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}], 
      LineBox[{{7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}], 
      LineBox[{{7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}], 
      LineBox[{{7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}], 
      LineBox[{{7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}], 
      LineBox[{{7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}], 
      LineBox[{{7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}], 
      LineBox[{{7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}], 
      LineBox[{{7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}], 
      LineBox[{{7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}], 
      LineBox[{{7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}], 
      LineBox[{{7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}], 
      LineBox[{{7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}], 
      LineBox[{{7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}], 
      LineBox[{{7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}], 
      LineBox[{{7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}], 
      LineBox[{{7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}], 
      LineBox[{{7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}], 
      LineBox[{{7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}], 
      LineBox[{{7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}], 
      LineBox[{{7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}], 
      LineBox[{{7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}], 
      LineBox[{{7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}], 
      LineBox[{{7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}], 
      LineBox[{{7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}], 
      LineBox[{{7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}], 
      LineBox[{{7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}], 
      LineBox[{{7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}], 
      LineBox[{{7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}], 
      LineBox[{{7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}], 
      LineBox[{{7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}], 
      LineBox[{{7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}], 
      LineBox[{{7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}], 
      LineBox[{{7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}], 
      LineBox[{{7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}], 
      LineBox[{{7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}], 
      LineBox[{{7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}], 
      LineBox[{{7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}], 
      LineBox[{{7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}], 
      LineBox[{{7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}], 
      LineBox[{{7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}], 
      LineBox[{{7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}], 
      LineBox[{{7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}], 
      LineBox[{{7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}], 
      LineBox[{{7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}], 
      LineBox[{{7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}], 
      LineBox[{{7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}], 
      LineBox[{{7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}], 
      LineBox[{{7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}], 
      LineBox[{{7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}], 
      LineBox[{{7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}], 
      LineBox[{{7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}], 
      LineBox[{{7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}], 
      LineBox[{{7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}], 
      LineBox[{{7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}], 
      LineBox[{{7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}], 
      LineBox[{{7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}], 
      LineBox[{{7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}], 
      LineBox[{{7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}], 
      LineBox[{{7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}], 
      LineBox[{{7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}], 
      LineBox[{{7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}], 
      LineBox[{{7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}], 
      LineBox[{{7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}], 
      LineBox[{{7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}], 
      LineBox[{{7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}], 
      LineBox[{{7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}], 
      LineBox[{{7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}], 
      LineBox[{{7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}], 
      LineBox[{{7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}], 
      LineBox[{{7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}], 
      LineBox[{{7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}], 
      LineBox[{{7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}], 
      LineBox[{{7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}], 
      LineBox[{{7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}], 
      LineBox[{{7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}], 
      LineBox[{{7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}], 
      LineBox[{{7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}], 
      LineBox[{{7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}], 
      LineBox[{{7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}], 
      LineBox[{{7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}], 
      LineBox[{{7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}], 
      LineBox[{{7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}], 
      LineBox[{{7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}], 
      LineBox[{{7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}], 
      LineBox[{{7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}], 
      LineBox[{{7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}], 
      LineBox[{{7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}], 
      LineBox[{{7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}], 
      LineBox[{{7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}], 
      LineBox[{{7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}], 
      LineBox[{{7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}], 
      LineBox[{{7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}], 
      LineBox[{{7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}], 
      LineBox[{{7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}], 
      LineBox[{{7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}], 
      LineBox[{{7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}], 
      LineBox[{{7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}], 
      LineBox[{{7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}], 
      LineBox[{{7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}], 
      LineBox[{{7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}], 
      LineBox[{{7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}], 
      LineBox[{{7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}], 
      LineBox[{{7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}], 
      LineBox[{{7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}], 
      LineBox[{{7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}], 
      LineBox[{{7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}], 
      LineBox[{{7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}], 
      LineBox[{{7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}], 
      LineBox[{{7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}], 
      LineBox[{{7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}], 
      LineBox[{{7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}], 
      LineBox[{{7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}], 
      LineBox[{{7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}], 
      LineBox[{{7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}], 
      LineBox[{{7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}], 
      LineBox[{{7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}], 
      LineBox[{{7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}], 
      LineBox[{{7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}], 
      LineBox[{{7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}], 
      LineBox[{{7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}], 
      LineBox[{{7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}], 
      LineBox[{{7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}], 
      LineBox[{{7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}], 
      LineBox[{{7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}], 
      LineBox[{{7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}], 
      LineBox[{{7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}], 
      LineBox[{{7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}], 
      LineBox[{{7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}], 
      LineBox[{{7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}], 
      LineBox[{{7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}], 
      LineBox[{{7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}], 
      LineBox[{{7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}], 
      LineBox[{{7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}], 
      LineBox[{{7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}], 
      LineBox[{{7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}], 
      LineBox[{{7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}], 
      LineBox[{{7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}], 
      LineBox[{{7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}], 
      LineBox[{{7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}], 
      LineBox[{{7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}], 
      LineBox[{{7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}], 
      LineBox[{{7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}], 
      LineBox[{{7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}], 
      LineBox[{{7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}], 
      LineBox[{{7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}], 
      LineBox[{{7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}], 
      LineBox[{{7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}], 
      LineBox[{{7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}], 
      LineBox[{{7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}], 
      LineBox[{{7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}], 
      LineBox[{{7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}], 
      LineBox[{{7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}], 
      LineBox[{{7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}], 
      LineBox[{{7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}], 
      LineBox[{{7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}], 
      LineBox[{{7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}], 
      LineBox[{{7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}], 
      LineBox[{{7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}], 
      LineBox[{{7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}], 
      LineBox[{{7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}], 
      LineBox[{{7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}], 
      LineBox[{{7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}], 
      LineBox[{{7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}], 
      LineBox[{{7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}], 
      LineBox[{{7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}], 
      LineBox[{{7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}], 
      LineBox[{{7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}], 
      LineBox[{{7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}], 
      LineBox[{{7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}], 
      LineBox[{{7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}], 
      LineBox[{{7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}], 
      LineBox[{{7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}], 
      LineBox[{{7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}], 
      LineBox[{{7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}], 
      LineBox[{{7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}], 
      LineBox[{{7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}], 
      LineBox[{{7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}], 
      LineBox[{{7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}], 
      LineBox[{{7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}], 
      LineBox[{{7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}], 
      LineBox[{{7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}], 
      LineBox[{{7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}], 
      LineBox[{{7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}], 
      LineBox[{{7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}], 
      LineBox[{{7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}], 
      LineBox[{{7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}], 
      LineBox[{{7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}], 
      LineBox[{{7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}], 
      LineBox[{{7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}], 
      LineBox[{{7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}], 
      LineBox[{{7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}], 
      LineBox[{{7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}], 
      LineBox[{{7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}], 
      LineBox[{{7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}], 
      LineBox[{{7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}], 
      LineBox[{{7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}], 
      LineBox[{{7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}], 
      LineBox[{{7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}], 
      LineBox[{{7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}], 
      LineBox[{{7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}], 
      LineBox[{{7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}], 
      LineBox[{{7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}], 
      LineBox[{{7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}], 
      LineBox[{{7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}], 
      LineBox[{{7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}], 
      LineBox[{{7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}], 
      LineBox[{{7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}], 
      LineBox[{{7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}], 
      LineBox[{{7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}], 
      LineBox[{{7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}], 
      LineBox[{{7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}], 
      LineBox[{{7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}], 
      LineBox[{{7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}], 
      LineBox[{{7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}], 
      LineBox[{{7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}], 
      LineBox[{{7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}], 
      LineBox[{{7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}], 
      LineBox[{{7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}], 
      LineBox[{{7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}], 
      LineBox[{{7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}], 
      LineBox[{{7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}], 
      LineBox[{{7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}], 
      LineBox[{{7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}], 
      LineBox[{{7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}], 
      LineBox[{{7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}], 
      LineBox[{{7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}], 
      LineBox[{{7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217376}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}], 
      LineBox[{{7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}], 
      LineBox[{{7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}], 
      LineBox[{{7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}], 
      LineBox[{{7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}], 
      LineBox[{{7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}], 
      LineBox[{{7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}], 
      LineBox[{{7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}], 
      LineBox[{{7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}], 
      LineBox[{{7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}], 
      LineBox[{{7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}], 
      LineBox[{{7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}], 
      LineBox[{{7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}], 
      LineBox[{{7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}], 
      LineBox[{{7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}], 
      LineBox[{{7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}], 
      LineBox[{{7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}], 
      LineBox[{{7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}], 
      LineBox[{{7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}], 
      LineBox[{{7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}], 
      LineBox[{{7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}], 
      LineBox[{{7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}], 
      LineBox[{{7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}], 
      LineBox[{{7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}], 
      LineBox[{{7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}], 
      LineBox[{{7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}], 
      LineBox[{{7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}], 
      LineBox[{{7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}], 
      LineBox[{{7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}], 
      LineBox[{{7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}], 
      LineBox[{{7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}], 
      LineBox[{{7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}], 
      LineBox[{{7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}], 
      LineBox[{{7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}], 
      LineBox[{{7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}], 
      LineBox[{{7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}], 
      LineBox[{{7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}], 
      LineBox[{{7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}], 
      LineBox[{{7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}], 
      LineBox[{{7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}], 
      LineBox[{{7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}], 
      LineBox[{{7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}], 
      LineBox[{{7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}], 
      LineBox[{{7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}], 
      LineBox[{{7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}], 
      LineBox[{{7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.3510326651394864}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}], 
      LineBox[{{7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}], 
      LineBox[{{7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}], 
      LineBox[{{7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}], 
      LineBox[{{7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}], 
      LineBox[{{7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}], 
      LineBox[{{7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}], 
      LineBox[{{7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}], 
      LineBox[{{7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}], 
      LineBox[{{7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}], 
      LineBox[{{7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}], 
      LineBox[{{7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}], 
      LineBox[{{7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}], 
      LineBox[{{7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}], 
      LineBox[{{7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}], 
      LineBox[{{7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}], 
      LineBox[{{7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}], 
      LineBox[{{7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}], 
      LineBox[{{7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}], 
      LineBox[{{7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}], 
      LineBox[{{7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}], 
      LineBox[{{7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}], 
      LineBox[{{7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}], 
      LineBox[{{7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}], 
      LineBox[{{7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}], 
      LineBox[{{7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}], 
      LineBox[{{7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}], 
      LineBox[{{7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}], 
      LineBox[{{7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}], 
      LineBox[{{7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}], 
      LineBox[{{7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}], 
      LineBox[{{7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}], 
      LineBox[{{7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}], 
      LineBox[{{7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}], 
      LineBox[{{7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}], 
      LineBox[{{7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}], 
      LineBox[{{7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}], 
      LineBox[{{7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}], 
      LineBox[{{7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}], 
      LineBox[{{7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}], 
      LineBox[{{7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}], 
      LineBox[{{7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}], 
      LineBox[{{7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}], 
      LineBox[{{7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}], 
      LineBox[{{7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}], 
      LineBox[{{7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.145692991390315, 0.10554771642160712`}, {7.098937185679136, 
       0.15598735810615977`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.25686664147526506`}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}, {
       7.098937185679136, 0.256866641475265}, {7.087450309981506, 
       0.20642699979071238`}, {7.098937185679136, 0.15598735810615974`}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.262178354207934, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160711`}, {7.145692991390315, 0.10554771642160711`}, {
       7.212752905302511, 0.0902758217435934}, {7.262178354207934, 
       0.10554771642160712`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.262178354207934, 0.3073062831598177}, {
       7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071238`}, {7.320421035616743, 0.20642699979071238`}, {
       7.300116927415726, 0.2721385361532787}, {7.262178354207934, 
       0.3073062831598177}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.145692991390315, 0.10554771642160712`}, {7.098937185679136, 
       0.15598735810615977`}, {7.098937185679136, 0.15598735810615977`}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}}], 
      LineBox[{{7.145692991390315, 0.10554771642160712`}, {7.098937185679136, 
       0.15598735810615977`}, {7.098937185679136, 0.15598735810615977`}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}}], 
      LineBox[{{7.145692991390315, 0.10554771642160712`}, {7.098937185679136, 
       0.15598735810615977`}, {7.098937185679136, 0.15598735810615977`}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}}], 
      LineBox[{{7.145692991390315, 0.10554771642160712`}, {7.098937185679136, 
       0.15598735810615977`}, {7.098937185679136, 0.15598735810615977`}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}}], 
      LineBox[{{7.098937185679136, 0.15598735810615977`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}}], 
      LineBox[{{7.098937185679136, 0.15598735810615977`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}}], 
      LineBox[{{7.098937185679136, 0.15598735810615977`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}}], 
      LineBox[{{7.098937185679136, 0.15598735810615977`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}}], 
      LineBox[{{7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.256866641475265}, {7.098937185679136, 0.256866641475265}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}], 
      LineBox[{{7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.256866641475265}, {7.098937185679136, 0.256866641475265}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}], 
      LineBox[{{7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.256866641475265}, {7.098937185679136, 0.256866641475265}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}], 
      LineBox[{{7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.256866641475265}, {7.098937185679136, 0.256866641475265}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}], 
      LineBox[{{7.098937185679136, 0.25686664147526506`}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}, {
       7.098937185679136, 0.25686664147526506`}, {7.098937185679136, 
       0.25686664147526506`}}], 
      LineBox[{{7.098937185679136, 0.25686664147526506`}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}, {
       7.098937185679136, 0.25686664147526506`}, {7.098937185679136, 
       0.25686664147526506`}}], 
      LineBox[{{7.098937185679136, 0.25686664147526506`}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}, {
       7.098937185679136, 0.25686664147526506`}, {7.098937185679136, 
       0.25686664147526506`}}], 
      LineBox[{{7.098937185679136, 0.25686664147526506`}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}, {
       7.098937185679136, 0.25686664147526506`}, {7.098937185679136, 
       0.25686664147526506`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}], 
      LineBox[{{7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}], 
      LineBox[{{7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}], 
      LineBox[{{7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}], 
      LineBox[{{7.300116927415726, 0.14071546342814606`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.300116927415726, 0.14071546342814606`}, {7.300116927415726, 
       0.14071546342814606`}}], 
      LineBox[{{7.300116927415726, 0.14071546342814606`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.300116927415726, 0.14071546342814606`}, {7.300116927415726, 
       0.14071546342814606`}}], 
      LineBox[{{7.300116927415726, 0.14071546342814606`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.300116927415726, 0.14071546342814606`}, {7.300116927415726, 
       0.14071546342814606`}}], 
      LineBox[{{7.300116927415726, 0.14071546342814606`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.300116927415726, 0.14071546342814606`}, {7.300116927415726, 
       0.14071546342814606`}}], 
      LineBox[{{7.262178354207934, 0.10554771642160712`}, {7.212752905302511, 
       0.0902758217435934}, {7.212752905302511, 0.0902758217435934}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}}], 
      LineBox[{{7.262178354207934, 0.10554771642160712`}, {7.212752905302511, 
       0.0902758217435934}, {7.212752905302511, 0.0902758217435934}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}}], 
      LineBox[{{7.262178354207934, 0.10554771642160712`}, {7.212752905302511, 
       0.0902758217435934}, {7.212752905302511, 0.0902758217435934}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}}], 
      LineBox[{{7.262178354207934, 0.10554771642160712`}, {7.212752905302511, 
       0.0902758217435934}, {7.212752905302511, 0.0902758217435934}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}}], 
      LineBox[{{7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}}], 
      LineBox[{{7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}}], 
      LineBox[{{7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}}], 
      LineBox[{{7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}], 
      LineBox[{{7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}], 
      LineBox[{{7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}], 
      LineBox[{{7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}], 
      LineBox[{{7.212752905302511, 0.3225781778378314}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}}], 
      LineBox[{{7.212752905302511, 0.3225781778378314}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}}], 
      LineBox[{{7.212752905302511, 0.3225781778378314}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}}], 
      LineBox[{{7.212752905302511, 0.3225781778378314}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}}], 
      LineBox[{{7.262178354207934, 0.3073062831598177}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}], 
      LineBox[{{7.262178354207934, 0.3073062831598177}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}], 
      LineBox[{{7.262178354207934, 0.3073062831598177}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}], 
      LineBox[{{7.262178354207934, 0.3073062831598177}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}], 
      LineBox[{{7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071236`}, {7.320421035616743, 0.20642699979071236`}, {
       7.300116927415726, 0.2721385361532787}, {7.300116927415726, 
       0.2721385361532787}}], 
      LineBox[{{7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071236`}, {7.320421035616743, 0.20642699979071236`}, {
       7.300116927415726, 0.2721385361532787}, {7.300116927415726, 
       0.2721385361532787}}], 
      LineBox[{{7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071236`}, {7.320421035616743, 0.20642699979071236`}, {
       7.300116927415726, 0.2721385361532787}, {7.300116927415726, 
       0.2721385361532787}}], 
      LineBox[{{7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071236`}, {7.320421035616743, 0.20642699979071236`}, {
       7.300116927415726, 0.2721385361532787}, {7.300116927415726, 
       0.2721385361532787}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.179586270579003, 0.6619229030886622}, {7.11693299303923, 
       0.7295125600606837}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.8646918740047265}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}, {
       7.11693299303923, 0.8646918740047264}, {7.101540457284542, 
       0.797102217032705}, {7.11693299303923, 0.7295125600606835}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.335677897167928, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.335677897167928, 
       0.6619229030886622}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.335677897167928, 0.9322815309767478}, {
       7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.335677897167928, 
       0.9322815309767478}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.179586270579003, 0.6619229030886622}, {7.11693299303923, 
       0.7295125600606837}, {7.11693299303923, 0.7295125600606837}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}}], 
      LineBox[{{7.179586270579003, 0.6619229030886622}, {7.11693299303923, 
       0.7295125600606837}, {7.11693299303923, 0.7295125600606837}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}}], 
      LineBox[{{7.179586270579003, 0.6619229030886622}, {7.11693299303923, 
       0.7295125600606837}, {7.11693299303923, 0.7295125600606837}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}}], 
      LineBox[{{7.179586270579003, 0.6619229030886622}, {7.11693299303923, 
       0.7295125600606837}, {7.11693299303923, 0.7295125600606837}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}}], 
      LineBox[{{7.11693299303923, 0.7295125600606837}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}}], 
      LineBox[{{7.11693299303923, 0.7295125600606837}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}}], 
      LineBox[{{7.11693299303923, 0.7295125600606837}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}}], 
      LineBox[{{7.11693299303923, 0.7295125600606837}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}}], 
      LineBox[{{7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.8646918740047264}, {7.11693299303923, 0.8646918740047264}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}], 
      LineBox[{{7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.8646918740047264}, {7.11693299303923, 0.8646918740047264}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}], 
      LineBox[{{7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.8646918740047264}, {7.11693299303923, 0.8646918740047264}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}], 
      LineBox[{{7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.8646918740047264}, {7.11693299303923, 0.8646918740047264}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}], 
      LineBox[{{7.11693299303923, 0.8646918740047265}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}, {
       7.11693299303923, 0.8646918740047265}, {7.11693299303923, 
       0.8646918740047265}}], 
      LineBox[{{7.11693299303923, 0.8646918740047265}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}, {
       7.11693299303923, 0.8646918740047265}, {7.11693299303923, 
       0.8646918740047265}}], 
      LineBox[{{7.11693299303923, 0.8646918740047265}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}, {
       7.11693299303923, 0.8646918740047265}, {7.11693299303923, 
       0.8646918740047265}}], 
      LineBox[{{7.11693299303923, 0.8646918740047265}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}, {
       7.11693299303923, 0.8646918740047265}, {7.11693299303923, 
       0.8646918740047265}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}], 
      LineBox[{{7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}], 
      LineBox[{{7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}], 
      LineBox[{{7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}], 
      LineBox[{{7.38651598926143, 0.7090480585668931}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.38651598926143, 0.7090480585668931}, {7.38651598926143, 
       0.7090480585668931}}], 
      LineBox[{{7.38651598926143, 0.7090480585668931}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.38651598926143, 0.7090480585668931}, {7.38651598926143, 
       0.7090480585668931}}], 
      LineBox[{{7.38651598926143, 0.7090480585668931}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.38651598926143, 0.7090480585668931}, {7.38651598926143, 
       0.7090480585668931}}], 
      LineBox[{{7.38651598926143, 0.7090480585668931}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.38651598926143, 0.7090480585668931}, {7.38651598926143, 
       0.7090480585668931}}], 
      LineBox[{{7.335677897167928, 0.6619229030886622}, {7.269447269319737, 
       0.6414584015948717}, {7.269447269319737, 0.6414584015948717}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}}], 
      LineBox[{{7.335677897167928, 0.6619229030886622}, {7.269447269319737, 
       0.6414584015948717}, {7.269447269319737, 0.6414584015948717}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}}], 
      LineBox[{{7.335677897167928, 0.6619229030886622}, {7.269447269319737, 
       0.6414584015948717}, {7.269447269319737, 0.6414584015948717}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}}], 
      LineBox[{{7.335677897167928, 0.6619229030886622}, {7.269447269319737, 
       0.6414584015948717}, {7.269447269319737, 0.6414584015948717}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}}], 
      LineBox[{{7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}}], 
      LineBox[{{7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}}], 
      LineBox[{{7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}}], 
      LineBox[{{7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}], 
      LineBox[{{7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}], 
      LineBox[{{7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}], 
      LineBox[{{7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}], 
      LineBox[{{7.269447269319737, 0.9527460324705384}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}}], 
      LineBox[{{7.269447269319737, 0.9527460324705384}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}}], 
      LineBox[{{7.269447269319737, 0.9527460324705384}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}}], 
      LineBox[{{7.269447269319737, 0.9527460324705384}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}}], 
      LineBox[{{7.335677897167928, 0.9322815309767478}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}], 
      LineBox[{{7.335677897167928, 0.9322815309767478}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}], 
      LineBox[{{7.335677897167928, 0.9322815309767478}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}], 
      LineBox[{{7.335677897167928, 0.9322815309767478}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}], 
      LineBox[{{7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.38651598926143, 
       0.8851563754985169}}], 
      LineBox[{{7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.38651598926143, 
       0.8851563754985169}}], 
      LineBox[{{7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.38651598926143, 
       0.8851563754985169}}], 
      LineBox[{{7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.38651598926143, 
       0.8851563754985169}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.118732973968354, 1.1268790948279976`}, {7.0509693266126545`,
        1.1999817617561108`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.118732973968354, 
       1.41928976254045}, {7.118732973968354, 1.41928976254045}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.287556351686056, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.287556351686056, 
       1.1268790948279976`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.287556351686056, 1.41928976254045}, {
       7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.287556351686056, 
       1.41928976254045}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.118732973968354, 1.1268790948279976`}, {7.0509693266126545`,
        1.1999817617561108`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}}], 
      LineBox[{{7.118732973968354, 1.1268790948279976`}, {7.0509693266126545`,
        1.1999817617561108`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}}], 
      LineBox[{{7.118732973968354, 1.1268790948279976`}, {7.0509693266126545`,
        1.1999817617561108`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}}], 
      LineBox[{{7.118732973968354, 1.1268790948279976`}, {7.0509693266126545`,
        1.1999817617561108`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}}], 
      LineBox[{{7.0509693266126545`, 1.1999817617561108`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}}], 
      LineBox[{{7.0509693266126545`, 1.1999817617561108`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}}], 
      LineBox[{{7.0509693266126545`, 1.1999817617561108`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}}], 
      LineBox[{{7.0509693266126545`, 1.1999817617561108`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}}], 
      LineBox[{{7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}], 
      LineBox[{{7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}], 
      LineBox[{{7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}], 
      LineBox[{{7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}], 
      LineBox[{{7.0509693266126545`, 1.3461870956123367`}, {7.118732973968354,
        1.41928976254045}, {7.118732973968354, 1.41928976254045}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}}], 
      LineBox[{{7.0509693266126545`, 1.3461870956123367`}, {7.118732973968354,
        1.41928976254045}, {7.118732973968354, 1.41928976254045}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}}], 
      LineBox[{{7.0509693266126545`, 1.3461870956123367`}, {7.118732973968354,
        1.41928976254045}, {7.118732973968354, 1.41928976254045}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}}], 
      LineBox[{{7.0509693266126545`, 1.3461870956123367`}, {7.118732973968354,
        1.41928976254045}, {7.118732973968354, 1.41928976254045}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}], 
      LineBox[{{7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}], 
      LineBox[{{7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}], 
      LineBox[{{7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}], 
      LineBox[{{7.342541097578618, 1.1778480551570418`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.342541097578618, 1.1778480551570418`}, {7.342541097578618, 
       1.1778480551570418`}}], 
      LineBox[{{7.342541097578618, 1.1778480551570418`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.342541097578618, 1.1778480551570418`}, {7.342541097578618, 
       1.1778480551570418`}}], 
      LineBox[{{7.342541097578618, 1.1778480551570418`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.342541097578618, 1.1778480551570418`}, {7.342541097578618, 
       1.1778480551570418`}}], 
      LineBox[{{7.342541097578618, 1.1778480551570418`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.342541097578618, 1.1778480551570418`}, {7.342541097578618, 
       1.1778480551570418`}}], 
      LineBox[{{7.287556351686056, 1.1268790948279976`}, {7.215923564290342, 
       1.1047453882289286`}, {7.215923564290342, 1.1047453882289286`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}}], 
      LineBox[{{7.287556351686056, 1.1268790948279976`}, {7.215923564290342, 
       1.1047453882289286`}, {7.215923564290342, 1.1047453882289286`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}}], 
      LineBox[{{7.287556351686056, 1.1268790948279976`}, {7.215923564290342, 
       1.1047453882289286`}, {7.215923564290342, 1.1047453882289286`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}}], 
      LineBox[{{7.287556351686056, 1.1268790948279976`}, {7.215923564290342, 
       1.1047453882289286`}, {7.215923564290342, 1.1047453882289286`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}}], 
      LineBox[{{7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}}], 
      LineBox[{{7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}}], 
      LineBox[{{7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}}], 
      LineBox[{{7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}], 
      LineBox[{{7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}], 
      LineBox[{{7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}], 
      LineBox[{{7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}], 
      LineBox[{{7.215923564290342, 1.441423469139519}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}}], 
      LineBox[{{7.215923564290342, 1.441423469139519}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}}], 
      LineBox[{{7.215923564290342, 1.441423469139519}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}}], 
      LineBox[{{7.215923564290342, 1.441423469139519}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}}], 
      LineBox[{{7.287556351686056, 1.41928976254045}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}], 
      LineBox[{{7.287556351686056, 1.41928976254045}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}], 
      LineBox[{{7.287556351686056, 1.41928976254045}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}], 
      LineBox[{{7.287556351686056, 1.41928976254045}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}], 
      LineBox[{{7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.342541097578618, 
       1.3683208022114057`}}], 
      LineBox[{{7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.342541097578618, 
       1.3683208022114057`}}], 
      LineBox[{{7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.342541097578618, 
       1.3683208022114057`}}], 
      LineBox[{{7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.342541097578618, 
       1.3683208022114057`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.156173080905918, 1.5749711292694386`}, {7.090277302685656, 
       1.6460587598085512`}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.7882340208867769`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}, {
       7.090277302685656, 1.7882340208867769`}, {7.0740881556502995`, 
       1.717146390347664}, {7.090277302685656, 1.6460587598085512`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`,
        1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.320342931417156, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.320342931417156, 
       1.5749711292694386`}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.320342931417156, 1.8593216514258895`}, {
       7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.320342931417156, 
       1.8593216514258895`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.156173080905918, 1.5749711292694386`}, {7.090277302685656, 
       1.6460587598085512`}, {7.090277302685656, 1.6460587598085512`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}}], 
      LineBox[{{7.156173080905918, 1.5749711292694386`}, {7.090277302685656, 
       1.6460587598085512`}, {7.090277302685656, 1.6460587598085512`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}}], 
      LineBox[{{7.156173080905918, 1.5749711292694386`}, {7.090277302685656, 
       1.6460587598085512`}, {7.090277302685656, 1.6460587598085512`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}}], 
      LineBox[{{7.156173080905918, 1.5749711292694386`}, {7.090277302685656, 
       1.6460587598085512`}, {7.090277302685656, 1.6460587598085512`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}}], 
      LineBox[{{7.090277302685656, 1.6460587598085512`}, {7.0740881556502995`,
        1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}}], 
      LineBox[{{7.090277302685656, 1.6460587598085512`}, {7.0740881556502995`,
        1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}}], 
      LineBox[{{7.090277302685656, 1.6460587598085512`}, {7.0740881556502995`,
        1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}}], 
      LineBox[{{7.090277302685656, 1.6460587598085512`}, {7.0740881556502995`,
        1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}}], 
      LineBox[{{7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}], 
      LineBox[{{7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}], 
      LineBox[{{7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}], 
      LineBox[{{7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}], 
      LineBox[{{7.090277302685656, 1.7882340208867769`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}}], 
      LineBox[{{7.090277302685656, 1.7882340208867769`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}}], 
      LineBox[{{7.090277302685656, 1.7882340208867769`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}}], 
      LineBox[{{7.090277302685656, 1.7882340208867769`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}], 
      LineBox[{{7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}], 
      LineBox[{{7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}], 
      LineBox[{{7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}], 
      LineBox[{{7.373812051841192, 1.624535157137215}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.373812051841192, 1.624535157137215}, {7.373812051841192, 
       1.624535157137215}}], 
      LineBox[{{7.373812051841192, 1.624535157137215}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.373812051841192, 1.624535157137215}, {7.373812051841192, 
       1.624535157137215}}], 
      LineBox[{{7.373812051841192, 1.624535157137215}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.373812051841192, 1.624535157137215}, {7.373812051841192, 
       1.624535157137215}}], 
      LineBox[{{7.373812051841192, 1.624535157137215}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.373812051841192, 1.624535157137215}, {7.373812051841192, 
       1.624535157137215}}], 
      LineBox[{{7.320342931417156, 1.5749711292694386`}, {7.250684663957764, 
       1.5534475265981023`}, {7.250684663957764, 1.5534475265981023`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}}], 
      LineBox[{{7.320342931417156, 1.5749711292694386`}, {7.250684663957764, 
       1.5534475265981023`}, {7.250684663957764, 1.5534475265981023`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}}], 
      LineBox[{{7.320342931417156, 1.5749711292694386`}, {7.250684663957764, 
       1.5534475265981023`}, {7.250684663957764, 1.5534475265981023`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}}], 
      LineBox[{{7.320342931417156, 1.5749711292694386`}, {7.250684663957764, 
       1.5534475265981023`}, {7.250684663957764, 1.5534475265981023`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}}], 
      LineBox[{{7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}}], 
      LineBox[{{7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}}], 
      LineBox[{{7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}}], 
      LineBox[{{7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}], 
      LineBox[{{7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}], 
      LineBox[{{7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}], 
      LineBox[{{7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}], 
      LineBox[{{7.250684663957764, 1.8808452540972258`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}}], 
      LineBox[{{7.250684663957764, 1.8808452540972258`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}}], 
      LineBox[{{7.250684663957764, 1.8808452540972258`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}}], 
      LineBox[{{7.250684663957764, 1.8808452540972258`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}}], 
      LineBox[{{7.320342931417156, 1.8593216514258895`}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}], 
      LineBox[{{7.320342931417156, 1.8593216514258895`}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}], 
      LineBox[{{7.320342931417156, 1.8593216514258895`}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}], 
      LineBox[{{7.320342931417156, 1.8593216514258895`}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}], 
      LineBox[{{7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.373812051841192, 
       1.809757623558113}}], 
      LineBox[{{7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.373812051841192, 
       1.809757623558113}}], 
      LineBox[{{7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.373812051841192, 
       1.809757623558113}}], 
      LineBox[{{7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.373812051841192, 
       1.809757623558113}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.126540974712638, 2.1320904620857117`}, {7.064265958989476, 
       2.1992720544291244`}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.33363523911595}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}, {
       7.064265958989476, 2.33363523911595}, {7.048966353864524, 
       2.266453646772537}, {7.064265958989476, 2.1992720544291244`}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.281690216408867, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.281690216408867, 
       2.1320904620857117`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.281690216408867, 2.4008168314593625`}, {
       7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.281690216408867, 
       2.4008168314593625`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.126540974712638, 2.1320904620857117`}, {7.064265958989476, 
       2.1992720544291244`}, {7.064265958989476, 2.1992720544291244`}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}}], 
      LineBox[{{7.126540974712638, 2.1320904620857117`}, {7.064265958989476, 
       2.1992720544291244`}, {7.064265958989476, 2.1992720544291244`}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}}], 
      LineBox[{{7.126540974712638, 2.1320904620857117`}, {7.064265958989476, 
       2.1992720544291244`}, {7.064265958989476, 2.1992720544291244`}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}}], 
      LineBox[{{7.126540974712638, 2.1320904620857117`}, {7.064265958989476, 
       2.1992720544291244`}, {7.064265958989476, 2.1992720544291244`}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}}], 
      LineBox[{{7.064265958989476, 2.1992720544291244`}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}}], 
      LineBox[{{7.064265958989476, 2.1992720544291244`}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}}], 
      LineBox[{{7.064265958989476, 2.1992720544291244`}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}}], 
      LineBox[{{7.064265958989476, 2.1992720544291244`}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}}], 
      LineBox[{{7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}], 
      LineBox[{{7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}], 
      LineBox[{{7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}], 
      LineBox[{{7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}], 
      LineBox[{{7.064265958989476, 2.33363523911595}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}}], 
      LineBox[{{7.064265958989476, 2.33363523911595}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}}], 
      LineBox[{{7.064265958989476, 2.33363523911595}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}}], 
      LineBox[{{7.064265958989476, 2.33363523911595}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}], 
      LineBox[{{7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}], 
      LineBox[{{7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}], 
      LineBox[{{7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}], 
      LineBox[{{7.332221379482476, 2.1789311049634965`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.332221379482476, 2.1789311049634965`}, {7.332221379482476, 
       2.1789311049634965`}}], 
      LineBox[{{7.332221379482476, 2.1789311049634965`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.332221379482476, 2.1789311049634965`}, {7.332221379482476, 
       2.1789311049634965`}}], 
      LineBox[{{7.332221379482476, 2.1789311049634965`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.332221379482476, 2.1789311049634965`}, {7.332221379482476, 
       2.1789311049634965`}}], 
      LineBox[{{7.332221379482476, 2.1789311049634965`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.332221379482476, 2.1789311049634965`}, {7.332221379482476, 
       2.1789311049634965`}}], 
      LineBox[{{7.281690216408867, 2.1320904620857117`}, {7.215859448210305, 
       2.111749512620084}, {7.215859448210305, 2.111749512620084}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}}], 
      LineBox[{{7.281690216408867, 2.1320904620857117`}, {7.215859448210305, 
       2.111749512620084}, {7.215859448210305, 2.111749512620084}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}}], 
      LineBox[{{7.281690216408867, 2.1320904620857117`}, {7.215859448210305, 
       2.111749512620084}, {7.215859448210305, 2.111749512620084}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}}], 
      LineBox[{{7.281690216408867, 2.1320904620857117`}, {7.215859448210305, 
       2.111749512620084}, {7.215859448210305, 2.111749512620084}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}}], 
      LineBox[{{7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}}], 
      LineBox[{{7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}}], 
      LineBox[{{7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}}], 
      LineBox[{{7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}], 
      LineBox[{{7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}], 
      LineBox[{{7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}], 
      LineBox[{{7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}], 
      LineBox[{{7.215859448210305, 2.4211577809249905`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}}], 
      LineBox[{{7.215859448210305, 2.4211577809249905`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}}], 
      LineBox[{{7.215859448210305, 2.4211577809249905`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}}], 
      LineBox[{{7.215859448210305, 2.4211577809249905`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}}], 
      LineBox[{{7.281690216408867, 2.4008168314593625`}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}], 
      LineBox[{{7.281690216408867, 2.4008168314593625`}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}], 
      LineBox[{{7.281690216408867, 2.4008168314593625`}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}], 
      LineBox[{{7.281690216408867, 2.4008168314593625`}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}], 
      LineBox[{{7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.332221379482476, 
       2.3539761885815778`}}], 
      LineBox[{{7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.332221379482476, 
       2.3539761885815778`}}], 
      LineBox[{{7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.332221379482476, 
       2.3539761885815778`}}], 
      LineBox[{{7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.332221379482476, 
       2.3539761885815778`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.154535917837162, 2.648749167870542}, {7.099447751929565, 
       2.708177666795416}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.8270346646451627`}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}, {
       7.099447751929565, 2.8270346646451627`}, {7.08591379813354, 
       2.7676061657202893`}, {7.099447751929565, 2.708177666795416}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.291780157244407, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.291780157244407, 
       2.648749167870542}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.291780157244407, 2.8864631635700366`}, {
       7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.291780157244407, 
       2.8864631635700366`}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.154535917837162, 2.648749167870542}, {7.099447751929565, 
       2.708177666795416}, {7.099447751929565, 2.708177666795416}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}}], 
      LineBox[{{7.154535917837162, 2.648749167870542}, {7.099447751929565, 
       2.708177666795416}, {7.099447751929565, 2.708177666795416}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}}], 
      LineBox[{{7.154535917837162, 2.648749167870542}, {7.099447751929565, 
       2.708177666795416}, {7.099447751929565, 2.708177666795416}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}}], 
      LineBox[{{7.154535917837162, 2.648749167870542}, {7.099447751929565, 
       2.708177666795416}, {7.099447751929565, 2.708177666795416}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}}], 
      LineBox[{{7.099447751929565, 2.708177666795416}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}}], 
      LineBox[{{7.099447751929565, 2.708177666795416}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}}], 
      LineBox[{{7.099447751929565, 2.708177666795416}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}}], 
      LineBox[{{7.099447751929565, 2.708177666795416}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}}], 
      LineBox[{{7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}], 
      LineBox[{{7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}], 
      LineBox[{{7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}], 
      LineBox[{{7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}], 
      LineBox[{{7.099447751929565, 2.8270346646451627`}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}}], 
      LineBox[{{7.099447751929565, 2.8270346646451627`}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}}], 
      LineBox[{{7.099447751929565, 2.8270346646451627`}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}}], 
      LineBox[{{7.099447751929565, 2.8270346646451627`}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}], 
      LineBox[{{7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}], 
      LineBox[{{7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}], 
      LineBox[{{7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}], 
      LineBox[{{7.336479770124111, 2.690184165133982}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.336479770124111, 2.690184165133982}, {7.336479770124111, 
       2.690184165133982}}], 
      LineBox[{{7.336479770124111, 2.690184165133982}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.336479770124111, 2.690184165133982}, {7.336479770124111, 
       2.690184165133982}}], 
      LineBox[{{7.336479770124111, 2.690184165133982}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.336479770124111, 2.690184165133982}, {7.336479770124111, 
       2.690184165133982}}], 
      LineBox[{{7.336479770124111, 2.690184165133982}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.336479770124111, 2.690184165133982}, {7.336479770124111, 
       2.690184165133982}}], 
      LineBox[{{7.291780157244407, 2.648749167870542}, {7.233546590568677, 
       2.6307556662091085`}, {7.233546590568677, 2.6307556662091085`}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}}], 
      LineBox[{{7.291780157244407, 2.648749167870542}, {7.233546590568677, 
       2.6307556662091085`}, {7.233546590568677, 2.6307556662091085`}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}}], 
      LineBox[{{7.291780157244407, 2.648749167870542}, {7.233546590568677, 
       2.6307556662091085`}, {7.233546590568677, 2.6307556662091085`}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}}], 
      LineBox[{{7.291780157244407, 2.648749167870542}, {7.233546590568677, 
       2.6307556662091085`}, {7.233546590568677, 2.6307556662091085`}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}}], 
      LineBox[{{7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}}], 
      LineBox[{{7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}}], 
      LineBox[{{7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}}], 
      LineBox[{{7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}], 
      LineBox[{{7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}], 
      LineBox[{{7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}], 
      LineBox[{{7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}], 
      LineBox[{{7.233546590568677, 2.90445666523147}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}}], 
      LineBox[{{7.233546590568677, 2.90445666523147}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}}], 
      LineBox[{{7.233546590568677, 2.90445666523147}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}}], 
      LineBox[{{7.233546590568677, 2.90445666523147}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}}], 
      LineBox[{{7.291780157244407, 2.8864631635700366`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}], 
      LineBox[{{7.291780157244407, 2.8864631635700366`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}], 
      LineBox[{{7.291780157244407, 2.8864631635700366`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}], 
      LineBox[{{7.291780157244407, 2.8864631635700366`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}], 
      LineBox[{{7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.336479770124111, 
       2.8450281663065966`}}], 
      LineBox[{{7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.336479770124111, 
       2.8450281663065966`}}], 
      LineBox[{{7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.336479770124111, 
       2.8450281663065966`}}], 
      LineBox[{{7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.336479770124111, 
       2.8450281663065966`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.127958962701148, 3.1105906386595095`}, {7.059649313425901, 
       3.1842823263682973`}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.331665701785873}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}, {
       7.059649313425901, 3.331665701785873}, {7.042867131229735, 
       3.257974014077085}, {7.059649313425901, 3.1842823263682973`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.298142625643973, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.298142625643973, 
       3.1105906386595095`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.298142625643973, 3.405357389494661}, {
       7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.298142625643973, 
       3.405357389494661}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.127958962701148, 3.1105906386595095`}, {7.059649313425901, 
       3.1842823263682973`}, {7.059649313425901, 3.1842823263682973`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}}], 
      LineBox[{{7.127958962701148, 3.1105906386595095`}, {7.059649313425901, 
       3.1842823263682973`}, {7.059649313425901, 3.1842823263682973`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}}], 
      LineBox[{{7.127958962701148, 3.1105906386595095`}, {7.059649313425901, 
       3.1842823263682973`}, {7.059649313425901, 3.1842823263682973`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}}], 
      LineBox[{{7.127958962701148, 3.1105906386595095`}, {7.059649313425901, 
       3.1842823263682973`}, {7.059649313425901, 3.1842823263682973`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}}], 
      LineBox[{{7.059649313425901, 3.1842823263682973`}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}}], 
      LineBox[{{7.059649313425901, 3.1842823263682973`}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}}], 
      LineBox[{{7.059649313425901, 3.1842823263682973`}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}}], 
      LineBox[{{7.059649313425901, 3.1842823263682973`}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}}], 
      LineBox[{{7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}], 
      LineBox[{{7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}], 
      LineBox[{{7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}], 
      LineBox[{{7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}], 
      LineBox[{{7.059649313425901, 3.331665701785873}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}}], 
      LineBox[{{7.059649313425901, 3.331665701785873}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}}], 
      LineBox[{{7.059649313425901, 3.331665701785873}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}}], 
      LineBox[{{7.059649313425901, 3.331665701785873}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}], 
      LineBox[{{7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}], 
      LineBox[{{7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}], 
      LineBox[{{7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}], 
      LineBox[{{7.353570408149451, 3.1619702786267223`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.353570408149451, 3.1619702786267223`}, {7.353570408149451, 
       3.1619702786267223`}}], 
      LineBox[{{7.353570408149451, 3.1619702786267223`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.353570408149451, 3.1619702786267223`}, {7.353570408149451, 
       3.1619702786267223`}}], 
      LineBox[{{7.353570408149451, 3.1619702786267223`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.353570408149451, 3.1619702786267223`}, {7.353570408149451, 
       3.1619702786267223`}}], 
      LineBox[{{7.353570408149451, 3.1619702786267223`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.353570408149451, 3.1619702786267223`}, {7.353570408149451, 
       3.1619702786267223`}}], 
      LineBox[{{7.298142625643973, 3.1105906386595095`}, {7.22593266094233, 
       3.0882785909179344`}, {7.22593266094233, 3.0882785909179344`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}}], 
      LineBox[{{7.298142625643973, 3.1105906386595095`}, {7.22593266094233, 
       3.0882785909179344`}, {7.22593266094233, 3.0882785909179344`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}}], 
      LineBox[{{7.298142625643973, 3.1105906386595095`}, {7.22593266094233, 
       3.0882785909179344`}, {7.22593266094233, 3.0882785909179344`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}}], 
      LineBox[{{7.298142625643973, 3.1105906386595095`}, {7.22593266094233, 
       3.0882785909179344`}, {7.22593266094233, 3.0882785909179344`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}}], 
      LineBox[{{7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}}], 
      LineBox[{{7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}}], 
      LineBox[{{7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}}], 
      LineBox[{{7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}], 
      LineBox[{{7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}], 
      LineBox[{{7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}], 
      LineBox[{{7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}], 
      LineBox[{{7.22593266094233, 3.427669437236236}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}}], 
      LineBox[{{7.22593266094233, 3.427669437236236}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}}], 
      LineBox[{{7.22593266094233, 3.427669437236236}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}}], 
      LineBox[{{7.22593266094233, 3.427669437236236}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}}], 
      LineBox[{{7.298142625643973, 3.405357389494661}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}], 
      LineBox[{{7.298142625643973, 3.405357389494661}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}], 
      LineBox[{{7.298142625643973, 3.405357389494661}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}], 
      LineBox[{{7.298142625643973, 3.405357389494661}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}], 
      LineBox[{{7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.353570408149451, 
       3.353977749527448}}], 
      LineBox[{{7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.353570408149451, 
       3.353977749527448}}], 
      LineBox[{{7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.353570408149451, 
       3.353977749527448}}], 
      LineBox[{{7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.353570408149451, 
       3.353977749527448}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.214825242898728, 3.5728163042497076`}, {7.150356804327845, 
       3.642364136695691}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.7814598015876575`}, {7.214825242898728, 
       3.8510076340336408`}, {7.214825242898728, 3.8510076340336408`}, {
       7.150356804327845, 3.7814598015876575`}, {7.134518323330242, 
       3.711911969141674}, {7.150356804327845, 3.642364136695691}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.375439082035703, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.214825242898729, 
       3.5728163042497076`}, {7.214825242898729, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.375439082035703, 
       3.5728163042497076`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.375439082035703, 3.8510076340336408`}, {
       7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.375439082035703, 
       3.8510076340336408`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.214825242898728, 3.5728163042497076`}, {7.150356804327845, 
       3.642364136695691}, {7.150356804327845, 3.642364136695691}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}}], 
      LineBox[{{7.214825242898728, 3.5728163042497076`}, {7.150356804327845, 
       3.642364136695691}, {7.150356804327845, 3.642364136695691}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}}], 
      LineBox[{{7.214825242898728, 3.5728163042497076`}, {7.150356804327845, 
       3.642364136695691}, {7.150356804327845, 3.642364136695691}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}}], 
      LineBox[{{7.214825242898728, 3.5728163042497076`}, {7.150356804327845, 
       3.642364136695691}, {7.150356804327845, 3.642364136695691}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}}], 
      LineBox[{{7.150356804327845, 3.642364136695691}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}}], 
      LineBox[{{7.150356804327845, 3.642364136695691}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}}], 
      LineBox[{{7.150356804327845, 3.642364136695691}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}}], 
      LineBox[{{7.150356804327845, 3.642364136695691}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}}], 
      LineBox[{{7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}], 
      LineBox[{{7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}], 
      LineBox[{{7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}], 
      LineBox[{{7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}], 
      LineBox[{{7.150356804327845, 3.7814598015876575`}, {7.214825242898728, 
       3.8510076340336408`}, {7.214825242898728, 3.8510076340336408`}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}}], 
      LineBox[{{7.150356804327845, 3.7814598015876575`}, {7.214825242898728, 
       3.8510076340336408`}, {7.214825242898728, 3.8510076340336408`}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}}], 
      LineBox[{{7.150356804327845, 3.7814598015876575`}, {7.214825242898728, 
       3.8510076340336408`}, {7.214825242898728, 3.8510076340336408`}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}}], 
      LineBox[{{7.150356804327845, 3.7814598015876575`}, {7.214825242898728, 
       3.8510076340336408`}, {7.214825242898728, 3.8510076340336408`}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}], 
      LineBox[{{7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}], 
      LineBox[{{7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}], 
      LineBox[{{7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}], 
      LineBox[{{7.427750031213266, 3.6213067473739806`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.427750031213266, 3.6213067473739806`}, {7.427750031213266, 
       3.6213067473739806`}}], 
      LineBox[{{7.427750031213266, 3.6213067473739806`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.427750031213266, 3.6213067473739806`}, {7.427750031213266, 
       3.6213067473739806`}}], 
      LineBox[{{7.427750031213266, 3.6213067473739806`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.427750031213266, 3.6213067473739806`}, {7.427750031213266, 
       3.6213067473739806`}}], 
      LineBox[{{7.427750031213266, 3.6213067473739806`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.427750031213266, 3.6213067473739806`}, {7.427750031213266, 
       3.6213067473739806`}}], 
      LineBox[{{7.375439082035703, 3.5728163042497076`}, {7.307289651860536, 
       3.551758914927997}, {7.307289651860536, 3.551758914927997}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}}], 
      LineBox[{{7.375439082035703, 3.5728163042497076`}, {7.307289651860536, 
       3.551758914927997}, {7.307289651860536, 3.551758914927997}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}}], 
      LineBox[{{7.375439082035703, 3.5728163042497076`}, {7.307289651860536, 
       3.551758914927997}, {7.307289651860536, 3.551758914927997}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}}], 
      LineBox[{{7.375439082035703, 3.5728163042497076`}, {7.307289651860536, 
       3.551758914927997}, {7.307289651860536, 3.551758914927997}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}}], 
      LineBox[{{7.307289651860536, 3.551758914927997}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}}], 
      LineBox[{{7.307289651860536, 3.551758914927997}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}}], 
      LineBox[{{7.307289651860536, 3.551758914927997}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}}], 
      LineBox[{{7.307289651860536, 3.551758914927997}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}], 
      LineBox[{{7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}], 
      LineBox[{{7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}], 
      LineBox[{{7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}], 
      LineBox[{{7.307289651860536, 3.8720650233553515`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}}], 
      LineBox[{{7.307289651860536, 3.8720650233553515`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}}], 
      LineBox[{{7.307289651860536, 3.8720650233553515`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}}], 
      LineBox[{{7.307289651860536, 3.8720650233553515`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}}], 
      LineBox[{{7.375439082035703, 3.8510076340336408`}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}], 
      LineBox[{{7.375439082035703, 3.8510076340336408`}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}], 
      LineBox[{{7.375439082035703, 3.8510076340336408`}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}], 
      LineBox[{{7.375439082035703, 3.8510076340336408`}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}], 
      LineBox[{{7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.427750031213266, 
       3.802517190909368}}], 
      LineBox[{{7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.427750031213266, 
       3.802517190909368}}], 
      LineBox[{{7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.427750031213266, 
       3.802517190909368}}], 
      LineBox[{{7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.427750031213266, 
       3.802517190909368}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}], 
      LineBox[{{7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}], 
      LineBox[{{7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}], 
      LineBox[{{7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}], 
      LineBox[{{7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}], 
      LineBox[{{7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}], 
      LineBox[{{7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}], 
      LineBox[{{7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}], 
      LineBox[{{7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}], 
      LineBox[{{7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}], 
      LineBox[{{7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}], 
      LineBox[{{7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}], 
      LineBox[{{7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}], 
      LineBox[{{7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}], 
      LineBox[{{7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}], 
      LineBox[{{7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}], 
      LineBox[{{7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}], 
      LineBox[{{7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}], 
      LineBox[{{7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}], 
      LineBox[{{7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}], 
      LineBox[{{7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}], 
      LineBox[{{7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}], 
      LineBox[{{7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}], 
      LineBox[{{7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}], 
      LineBox[{{7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}], 
      LineBox[{{7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}], 
      LineBox[{{7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}], 
      LineBox[{{7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}], 
      LineBox[{{7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}], 
      LineBox[{{7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}], 
      LineBox[{{7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}], 
      LineBox[{{7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}], 
      LineBox[{{7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}], 
      LineBox[{{7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}], 
      LineBox[{{7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}], 
      LineBox[{{7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}], 
      LineBox[{{7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}], 
      LineBox[{{7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}], 
      LineBox[{{7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}], 
      LineBox[{{7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}], 
      LineBox[{{7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}], 
      LineBox[{{7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}], 
      LineBox[{{7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}], 
      LineBox[{{7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}], 
      LineBox[{{7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}], 
      LineBox[{{7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}], 
      LineBox[{{7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}], 
      LineBox[{{7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}], 
      LineBox[{{7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}], 
      LineBox[{{7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}], 
      LineBox[{{7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}], 
      LineBox[{{7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}], 
      LineBox[{{7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}], 
      LineBox[{{7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}], 
      LineBox[{{7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}], 
      LineBox[{{7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}], 
      LineBox[{{7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}], 
      LineBox[{{7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}], 
      LineBox[{{7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}], 
      LineBox[{{7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}], 
      LineBox[{{7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}], 
      LineBox[{{7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}], 
      LineBox[{{7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}], 
      LineBox[{{7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}], 
      LineBox[{{7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}], 
      LineBox[{{7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}], 
      LineBox[{{7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}], 
      LineBox[{{7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}], 
      LineBox[{{7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}], 
      LineBox[{{7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}], 
      LineBox[{{7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}], 
      LineBox[{{7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}], 
      LineBox[{{7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}], 
      LineBox[{{7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}], 
      LineBox[{{7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}], 
      LineBox[{{7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}], 
      LineBox[{{7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}], 
      LineBox[{{7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}], 
      LineBox[{{7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}], 
      LineBox[{{7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}], 
      LineBox[{{7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}], 
      LineBox[{{7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}], 
      LineBox[{{7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}], 
      LineBox[{{7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}], 
      LineBox[{{7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}], 
      LineBox[{{7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}], 
      LineBox[{{7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}], 
      LineBox[{{7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}], 
      LineBox[{{7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}], 
      LineBox[{{7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}], 
      LineBox[{{7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}], 
      LineBox[{{7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}], 
      LineBox[{{7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}], 
      LineBox[{{7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}], 
      LineBox[{{7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}], 
      LineBox[{{7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}], 
      LineBox[{{7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}], 
      LineBox[{{7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}], 
      LineBox[{{7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}], 
      LineBox[{{7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}], 
      LineBox[{{7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}], 
      LineBox[{{7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}], 
      LineBox[{{7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}], 
      LineBox[{{7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}], 
      LineBox[{{7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}], 
      LineBox[{{7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}], 
      LineBox[{{7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}], 
      LineBox[{{7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}], 
      LineBox[{{7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}], 
      LineBox[{{7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}], 
      LineBox[{{7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}], 
      LineBox[{{7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}], 
      LineBox[{{7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}], 
      LineBox[{{7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}], 
      LineBox[{{7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}], 
      LineBox[{{7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}], 
      LineBox[{{7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}], 
      LineBox[{{7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}], 
      LineBox[{{7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}], 
      LineBox[{{7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}], 
      LineBox[{{7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}], 
      LineBox[{{7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}], 
      LineBox[{{7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}], 
      LineBox[{{7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}], 
      LineBox[{{7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}], 
      LineBox[{{7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}], 
      LineBox[{{7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}], 
      LineBox[{{7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}], 
      LineBox[{{7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}], 
      LineBox[{{7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}], 
      LineBox[{{7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}], 
      LineBox[{{7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}], 
      LineBox[{{7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}], 
      LineBox[{{7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}], 
      LineBox[{{7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}], 
      LineBox[{{7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}], 
      LineBox[{{7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}], 
      LineBox[{{7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}], 
      LineBox[{{7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}], 
      LineBox[{{7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}], 
      LineBox[{{7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}], 
      LineBox[{{7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}], 
      LineBox[{{7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}], 
      LineBox[{{7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}], 
      LineBox[{{7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}], 
      LineBox[{{7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}], 
      LineBox[{{7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}], 
      LineBox[{{7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}], 
      LineBox[{{7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}], 
      LineBox[{{7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}], 
      LineBox[{{7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}], 
      LineBox[{{7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}], 
      LineBox[{{7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}], 
      LineBox[{{7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}], 
      LineBox[{{7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}], 
      LineBox[{{7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}], 
      LineBox[{{7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}], 
      LineBox[{{7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}], 
      LineBox[{{7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}], 
      LineBox[{{7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}], 
      LineBox[{{7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}], 
      LineBox[{{7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}], 
      LineBox[{{7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}], 
      LineBox[{{7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}], 
      LineBox[{{7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}], 
      LineBox[{{7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}], 
      LineBox[{{7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}], 
      LineBox[{{7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}], 
      LineBox[{{7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}], 
      LineBox[{{7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}], 
      LineBox[{{7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}], 
      LineBox[{{7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}], 
      LineBox[{{7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}], 
      LineBox[{{7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}], 
      LineBox[{{7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}], 
      LineBox[{{7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}], 
      LineBox[{{7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}], 
      LineBox[{{7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}], 
      LineBox[{{7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}], 
      LineBox[{{7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}], 
      LineBox[{{7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}], 
      LineBox[{{7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}], 
      LineBox[{{7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}], 
      LineBox[{{7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}], 
      LineBox[{{7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}], 
      LineBox[{{7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}], 
      LineBox[{{7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}], 
      LineBox[{{7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}], 
      LineBox[{{7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}], 
      LineBox[{{7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}], 
      LineBox[{{7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}], 
      LineBox[{{7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}], 
      LineBox[{{7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}], 
      LineBox[{{7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}], 
      LineBox[{{7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}], 
      LineBox[{{7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}], 
      LineBox[{{7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}], 
      LineBox[{{7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}], 
      LineBox[{{7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}], 
      LineBox[{{7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}], 
      LineBox[{{7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}], 
      LineBox[{{7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}], 
      LineBox[{{7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}], 
      LineBox[{{7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}], 
      LineBox[{{7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}], 
      LineBox[{{7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}], 
      LineBox[{{7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}], 
      LineBox[{{7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}], 
      LineBox[{{7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}], 
      LineBox[{{7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}], 
      LineBox[{{7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}], 
      LineBox[{{7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}], 
      LineBox[{{7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}], 
      LineBox[{{7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}], 
      LineBox[{{7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}], 
      LineBox[{{7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}], 
      LineBox[{{7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}], 
      LineBox[{{7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}], 
      LineBox[{{7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}], 
      LineBox[{{7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}], 
      LineBox[{{7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}], 
      LineBox[{{7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}], 
      LineBox[{{7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}], 
      LineBox[{{7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}], 
      LineBox[{{7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}], 
      LineBox[{{7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}], 
      LineBox[{{7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}], 
      LineBox[{{7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}], 
      LineBox[{{7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}], 
      LineBox[{{7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}], 
      LineBox[{{7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}], 
      LineBox[{{7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}], 
      LineBox[{{7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}], 
      LineBox[{{7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}], 
      LineBox[{{7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}], 
      LineBox[{{7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}], 
      LineBox[{{7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}], 
      LineBox[{{7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}], 
      LineBox[{{7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}], 
      LineBox[{{7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}], 
      LineBox[{{7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}], 
      LineBox[{{7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}], 
      LineBox[{{7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}], 
      LineBox[{{7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}], 
      LineBox[{{7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}], 
      LineBox[{{7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}], 
      LineBox[{{7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}], 
      LineBox[{{7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}], 
      LineBox[{{7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}], 
      LineBox[{{7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}], 
      LineBox[{{7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}], 
      LineBox[{{7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}], 
      LineBox[{{7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}], 
      LineBox[{{7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}], 
      LineBox[{{7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}], 
      LineBox[{{7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}], 
      LineBox[{{7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}], 
      LineBox[{{7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}], 
      LineBox[{{7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}], 
      LineBox[{{7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}], 
      LineBox[{{7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}], 
      LineBox[{{7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}], 
      LineBox[{{7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}], 
      LineBox[{{7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}], 
      LineBox[{{7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}], 
      LineBox[{{7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}], 
      LineBox[{{7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}], 
      LineBox[{{7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}], 
      LineBox[{{7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}], 
      LineBox[{{7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}], 
      LineBox[{{7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}], 
      LineBox[{{7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}], 
      LineBox[{{7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}], 
      LineBox[{{7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}], 
      LineBox[{{7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}], 
      LineBox[{{7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}], 
      LineBox[{{7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}], 
      LineBox[{{7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}], 
      LineBox[{{7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}], 
      LineBox[{{7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}], 
      LineBox[{{7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}], 
      LineBox[{{7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}], 
      LineBox[{{7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}], 
      LineBox[{{7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}], 
      LineBox[{{7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}], 
      LineBox[{{7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}], 
      LineBox[{{7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}], 
      LineBox[{{7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}], 
      LineBox[{{7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}], 
      LineBox[{{7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}], 
      LineBox[{{7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}], 
      LineBox[{{7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}], 
      LineBox[{{7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}], 
      LineBox[{{7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}], 
      LineBox[{{7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}], 
      LineBox[{{7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}], 
      LineBox[{{7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}], 
      LineBox[{{7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}], 
      LineBox[{{7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}], 
      LineBox[{{7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}], 
      LineBox[{{7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}], 
      LineBox[{{7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}], 
      LineBox[{{7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}], 
      LineBox[{{7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}], 
      LineBox[{{7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}], 
      LineBox[{{7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}], 
      LineBox[{{7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}], 
      LineBox[{{7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}], 
      LineBox[{{7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}], 
      LineBox[{{7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}], 
      LineBox[{{7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}], 
      LineBox[{{7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}], 
      LineBox[{{7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}], 
      LineBox[{{7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}], 
      LineBox[{{7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}], 
      LineBox[{{7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}], 
      LineBox[{{7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}], 
      LineBox[{{7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}], 
      LineBox[{{7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}], 
      LineBox[{{7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}], 
      LineBox[{{7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}], 
      LineBox[{{7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}], 
      LineBox[{{7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}], 
      LineBox[{{7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}], 
      LineBox[{{7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}], 
      LineBox[{{7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}], 
      LineBox[{{7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}], 
      LineBox[{{7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}], 
      LineBox[{{7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}], 
      LineBox[{{7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}], 
      LineBox[{{7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}], 
      LineBox[{{7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}], 
      LineBox[{{7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}], 
      LineBox[{{7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}], 
      LineBox[{{7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}], 
      LineBox[{{7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}], 
      LineBox[{{7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}], 
      LineBox[{{7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}], 
      LineBox[{{7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}], 
      LineBox[{{7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}], 
      LineBox[{{7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}], 
      LineBox[{{7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}], 
      LineBox[{{7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}], 
      LineBox[{{7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}], 
      LineBox[{{7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}], 
      LineBox[{{7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}], 
      LineBox[{{7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}], 
      LineBox[{{7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}], 
      LineBox[{{7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}], 
      LineBox[{{7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}], 
      LineBox[{{7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}], 
      LineBox[{{7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}], 
      LineBox[{{7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}], 
      LineBox[{{7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}], 
      LineBox[{{7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}], 
      LineBox[{{7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}], 
      LineBox[{{7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}], 
      LineBox[{{7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}], 
      LineBox[{{7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}], 
      LineBox[{{7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}], 
      LineBox[{{7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}], 
      LineBox[{{7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}], 
      LineBox[{{7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}], 
      LineBox[{{7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}], 
      LineBox[{{7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}], 
      LineBox[{{7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}], 
      LineBox[{{7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}], 
      LineBox[{{7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}], 
      LineBox[{{7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}], 
      LineBox[{{7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}], 
      LineBox[{{7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}], 
      LineBox[{{7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}], 
      LineBox[{{7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}], 
      LineBox[{{7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}], 
      LineBox[{{7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}], 
      LineBox[{{7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}], 
      LineBox[{{7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}], 
      LineBox[{{7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}], 
      LineBox[{{7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}], 
      LineBox[{{7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}], 
      LineBox[{{7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}], 
      LineBox[{{7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}], 
      LineBox[{{7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}], 
      LineBox[{{7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}], 
      LineBox[{{7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}], 
      LineBox[{{7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}], 
      LineBox[{{7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}], 
      LineBox[{{7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}], 
      LineBox[{{7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}], 
      LineBox[{{7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}], 
      LineBox[{{7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}], 
      LineBox[{{7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}], 
      LineBox[{{7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}], 
      LineBox[{{7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}], 
      LineBox[{{7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}], 
      LineBox[{{7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}], 
      LineBox[{{7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}], 
      LineBox[{{7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}], 
      LineBox[{{7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}], 
      LineBox[{{7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}], 
      LineBox[{{7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}], 
      LineBox[{{7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}], 
      LineBox[{{7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}], 
      LineBox[{{7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}], 
      LineBox[{{7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}], 
      LineBox[{{7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.01567372637491203}, {7.446821078417088, 0.07880115516357909}, {
       7.446821078417088, 0.07880115516357909}, {7.388304132282772, 
       0.015673726374912017`}, {7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242215`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.17370855999108925`}, {
       7.446821078417088, -0.17370855999108925`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.446821078417088, 0.07880115516357912}, {7.530749508490825, 
       0.09791460267344886}, {7.592607630434632, 0.07880115516357909}, {
       7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.047453702413755044`}, {
       7.665500906443404, -0.047453702413755044`}, {7.640089422503983, 
       0.03478717388478175}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}], 
      LineBox[{{7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}], 
      LineBox[{{7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}], 
      LineBox[{{7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}], 
      LineBox[{{7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}], 
      LineBox[{{7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}], 
      LineBox[{{7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}], 
      LineBox[{{7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}], 
      LineBox[{{7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}], 
      LineBox[{{7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}], 
      LineBox[{{7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}], 
      LineBox[{{7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}], 
      LineBox[{{7.388304132282772, 0.01567372637491203}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}, {
       7.388304132282772, 0.01567372637491203}, {7.388304132282772, 
       0.01567372637491203}}], 
      LineBox[{{7.388304132282772, 0.01567372637491203}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}, {
       7.388304132282772, 0.01567372637491203}, {7.388304132282772, 
       0.01567372637491203}}], 
      LineBox[{{7.388304132282772, 0.01567372637491203}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}, {
       7.388304132282772, 0.01567372637491203}, {7.388304132282772, 
       0.01567372637491203}}], 
      LineBox[{{7.388304132282772, 0.01567372637491203}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}, {
       7.388304132282772, 0.01567372637491203}, {7.388304132282772, 
       0.01567372637491203}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}], 
      LineBox[{{7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}], 
      LineBox[{{7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}], 
      LineBox[{{7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}], 
      LineBox[{{7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}], 
      LineBox[{{7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}], 
      LineBox[{{7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}], 
      LineBox[{{7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}], 
      LineBox[{{7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}], 
      LineBox[{{7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}], 
      LineBox[{{7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}], 
      LineBox[{{7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}], 
      LineBox[{{7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}], 
      LineBox[{{7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}], 
      LineBox[{{7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}], 
      LineBox[{{7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.446821078417088, 0.07880115516357912}, {7.530749508490825, 
       0.09791460267344886}, {7.530749508490825, 0.09791460267344886}, {
       7.446821078417088, 0.07880115516357912}, {7.446821078417088, 
       0.07880115516357912}}], 
      LineBox[{{7.446821078417088, 0.07880115516357912}, {7.530749508490825, 
       0.09791460267344886}, {7.530749508490825, 0.09791460267344886}, {
       7.446821078417088, 0.07880115516357912}, {7.446821078417088, 
       0.07880115516357912}}], 
      LineBox[{{7.446821078417088, 0.07880115516357912}, {7.530749508490825, 
       0.09791460267344886}, {7.530749508490825, 0.09791460267344886}, {
       7.446821078417088, 0.07880115516357912}, {7.446821078417088, 
       0.07880115516357912}}], 
      LineBox[{{7.446821078417088, 0.07880115516357912}, {7.530749508490825, 
       0.09791460267344886}, {7.530749508490825, 0.09791460267344886}, {
       7.446821078417088, 0.07880115516357912}, {7.446821078417088, 
       0.07880115516357912}}], 
      LineBox[{{7.530749508490825, 0.09791460267344886}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}}], 
      LineBox[{{7.530749508490825, 0.09791460267344886}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}}], 
      LineBox[{{7.530749508490825, 0.09791460267344886}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}}], 
      LineBox[{{7.530749508490825, 0.09791460267344886}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}}], 
      LineBox[{{7.592607630434632, 0.07880115516357909}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}], 
      LineBox[{{7.592607630434632, 0.07880115516357909}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}], 
      LineBox[{{7.592607630434632, 0.07880115516357909}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}], 
      LineBox[{{7.592607630434632, 0.07880115516357909}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}], 
      LineBox[{{7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}], 
      LineBox[{{7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}], 
      LineBox[{{7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}], 
      LineBox[{{7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.2814296434250485`, 
       0.4625898803092296}, {7.299425452323098, 0.3835690763469726}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.646411102938566, 0.4625898803092296}, {7.614601857269946, 
       0.3596435020332054}, {7.555165738060187, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.555165738060187, 
       0.3045482723847157}, {7.614601857269946, 0.3596435020332054}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.372675008303427, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.555165738060187, 0.6206314882337435}, {
       7.614601857269946, 0.5655362585852538}, {7.646411102938566, 
       0.4625898803092296}, {7.646411102938566, 0.4625898803092296}, {
       7.614601857269946, 0.5655362585852538}, {7.555165738060187, 
       0.6206314882337435}, {7.477733809952377, 0.6445570625475108}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}], 
      LineBox[{{7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}], 
      LineBox[{{7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}], 
      LineBox[{{7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}], 
      LineBox[{{7.299425452323098, 0.3835690763469727}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.3835690763469727}, {7.299425452323098, 
       0.3835690763469727}}], 
      LineBox[{{7.299425452323098, 0.3835690763469727}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.3835690763469727}, {7.299425452323098, 
       0.3835690763469727}}], 
      LineBox[{{7.299425452323098, 0.3835690763469727}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.3835690763469727}, {7.299425452323098, 
       0.3835690763469727}}], 
      LineBox[{{7.299425452323098, 0.3835690763469727}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.3835690763469727}, {7.299425452323098, 
       0.3835690763469727}}], 
      LineBox[{{7.2814296434250485`, 0.4625898803092296}, {7.299425452323098, 
       0.5416106842714865}, {7.299425452323098, 0.5416106842714865}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}}], 
      LineBox[{{7.2814296434250485`, 0.4625898803092296}, {7.299425452323098, 
       0.5416106842714865}, {7.299425452323098, 0.5416106842714865}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}}], 
      LineBox[{{7.2814296434250485`, 0.4625898803092296}, {7.299425452323098, 
       0.5416106842714865}, {7.299425452323098, 0.5416106842714865}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}}], 
      LineBox[{{7.2814296434250485`, 0.4625898803092296}, {7.299425452323098, 
       0.5416106842714865}, {7.299425452323098, 0.5416106842714865}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}}], 
      LineBox[{{7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}}], 
      LineBox[{{7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}}], 
      LineBox[{{7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}}], 
      LineBox[{{7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.646411102938566, 0.4625898803092296}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}}], 
      LineBox[{{7.646411102938566, 0.4625898803092296}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}}], 
      LineBox[{{7.646411102938566, 0.4625898803092296}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}}], 
      LineBox[{{7.646411102938566, 0.4625898803092296}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}}], 
      LineBox[{{7.614601857269946, 0.3596435020332054}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}}], 
      LineBox[{{7.614601857269946, 0.3596435020332054}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}}], 
      LineBox[{{7.614601857269946, 0.3596435020332054}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}}], 
      LineBox[{{7.614601857269946, 0.3596435020332054}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}}], 
      LineBox[{{7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}], 
      LineBox[{{7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}], 
      LineBox[{{7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}], 
      LineBox[{{7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}], 
      LineBox[{{7.477733809952377, 0.2806226980709484}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.477733809952377, 
       0.2806226980709484}}], 
      LineBox[{{7.477733809952377, 0.2806226980709484}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.477733809952377, 
       0.2806226980709484}}], 
      LineBox[{{7.477733809952377, 0.2806226980709484}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.477733809952377, 
       0.2806226980709484}}], 
      LineBox[{{7.477733809952377, 0.2806226980709484}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.477733809952377, 
       0.2806226980709484}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.372675008303427, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.477733809952377, 0.6445570625475108}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}}], 
      LineBox[{{7.372675008303427, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.477733809952377, 0.6445570625475108}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}}], 
      LineBox[{{7.372675008303427, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.477733809952377, 0.6445570625475108}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}}], 
      LineBox[{{7.372675008303427, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.477733809952377, 0.6445570625475108}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}}], 
      LineBox[{{7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}}], 
      LineBox[{{7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}}], 
      LineBox[{{7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}}], 
      LineBox[{{7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}}], 
      LineBox[{{7.555165738060187, 0.6206314882337435}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}}], 
      LineBox[{{7.555165738060187, 0.6206314882337435}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}}], 
      LineBox[{{7.555165738060187, 0.6206314882337435}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}}], 
      LineBox[{{7.555165738060187, 0.6206314882337435}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}}], 
      LineBox[{{7.614601857269946, 0.5655362585852538}, {7.646411102938566, 
       0.46258988030922954`}, {7.646411102938566, 0.46258988030922954`}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}}], 
      LineBox[{{7.614601857269946, 0.5655362585852538}, {7.646411102938566, 
       0.46258988030922954`}, {7.646411102938566, 0.46258988030922954`}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}}], 
      LineBox[{{7.614601857269946, 0.5655362585852538}, {7.646411102938566, 
       0.46258988030922954`}, {7.646411102938566, 0.46258988030922954`}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}}], 
      LineBox[{{7.614601857269946, 0.5655362585852538}, {7.646411102938566, 
       0.46258988030922954`}, {7.646411102938566, 0.46258988030922954`}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       0.9416438553114584}, {7.612321284792937, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.612321284792937, 
       0.8886657618455744}, {7.669473461103548, 0.9416438553114584}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.436843099124353, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.612321284792937, 1.192602895043567}, {
       7.669473461103548, 1.1396248015776829`}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 1.1396248015776829`}, {7.612321284792937, 
       1.192602895043567}, {7.53786482185211, 1.215609084877181}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}], 
      LineBox[{{7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}], 
      LineBox[{{7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}], 
      LineBox[{{7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}], 
      LineBox[{{7.366408292920277, 0.9646500451450726}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 0.9646500451450726}, {7.366408292920277, 
       0.9646500451450726}}], 
      LineBox[{{7.366408292920277, 0.9646500451450726}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 0.9646500451450726}, {7.366408292920277, 
       0.9646500451450726}}], 
      LineBox[{{7.366408292920277, 0.9646500451450726}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 0.9646500451450726}, {7.366408292920277, 
       0.9646500451450726}}], 
      LineBox[{{7.366408292920277, 0.9646500451450726}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 0.9646500451450726}, {7.366408292920277, 
       0.9646500451450726}}], 
      LineBox[{{7.3491040062900606`, 1.0406343284445707`}, {7.366408292920277,
        1.1166186117440688`}, {7.366408292920277, 1.1166186117440688`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}}], 
      LineBox[{{7.3491040062900606`, 1.0406343284445707`}, {7.366408292920277,
        1.1166186117440688`}, {7.366408292920277, 1.1166186117440688`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}}], 
      LineBox[{{7.3491040062900606`, 1.0406343284445707`}, {7.366408292920277,
        1.1166186117440688`}, {7.366408292920277, 1.1166186117440688`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}}], 
      LineBox[{{7.3491040062900606`, 1.0406343284445707`}, {7.366408292920277,
        1.1166186117440688`}, {7.366408292920277, 1.1166186117440688`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}}], 
      LineBox[{{7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}}], 
      LineBox[{{7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}}], 
      LineBox[{{7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}}], 
      LineBox[{{7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}}], 
      LineBox[{{7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}}], 
      LineBox[{{7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}}], 
      LineBox[{{7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}}], 
      LineBox[{{7.669473461103548, 0.9416438553114584}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}}], 
      LineBox[{{7.669473461103548, 0.9416438553114584}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}}], 
      LineBox[{{7.669473461103548, 0.9416438553114584}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}}], 
      LineBox[{{7.669473461103548, 0.9416438553114584}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}}], 
      LineBox[{{7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}], 
      LineBox[{{7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}], 
      LineBox[{{7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}], 
      LineBox[{{7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}], 
      LineBox[{{7.53786482185211, 0.8656595720119603}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.53786482185211, 
       0.8656595720119603}}], 
      LineBox[{{7.53786482185211, 0.8656595720119603}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.53786482185211, 
       0.8656595720119603}}], 
      LineBox[{{7.53786482185211, 0.8656595720119603}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.53786482185211, 
       0.8656595720119603}}], 
      LineBox[{{7.53786482185211, 0.8656595720119603}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.53786482185211, 
       0.8656595720119603}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.436843099124353, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.53786482185211, 1.215609084877181}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}}], 
      LineBox[{{7.436843099124353, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.53786482185211, 1.215609084877181}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}}], 
      LineBox[{{7.436843099124353, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.53786482185211, 1.215609084877181}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}}], 
      LineBox[{{7.436843099124353, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.53786482185211, 1.215609084877181}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}}], 
      LineBox[{{7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}}], 
      LineBox[{{7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}}], 
      LineBox[{{7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}}], 
      LineBox[{{7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}}], 
      LineBox[{{7.612321284792937, 1.192602895043567}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}}], 
      LineBox[{{7.612321284792937, 1.192602895043567}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}}], 
      LineBox[{{7.612321284792937, 1.192602895043567}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}}], 
      LineBox[{{7.612321284792937, 1.192602895043567}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}}], 
      LineBox[{{7.669473461103548, 1.1396248015776829`}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}}], 
      LineBox[{{7.669473461103548, 1.1396248015776829`}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}}], 
      LineBox[{{7.669473461103548, 1.1396248015776829`}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}}], 
      LineBox[{{7.669473461103548, 1.1396248015776829`}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.327795877062711, 
       1.5087252988927673`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.4161140656823183`}, {7.574050652829568, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.574050652829568, 
       1.3665500378145419`}, {7.627519773253604, 1.4161140656823183`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.40988080231833, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.574050652829568, 1.6509005599709927`}, {
       7.627519773253604, 1.6013365321032162`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.6013365321032162`}, {7.574050652829568, 
       1.6509005599709927`}, {7.504392385370176, 1.672424162642329}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}], 
      LineBox[{{7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}], 
      LineBox[{{7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}], 
      LineBox[{{7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}], 
      LineBox[{{7.3439850240980675`, 1.4376376683536545`}, {7.327795877062711,
        1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.3439850240980675`, 
       1.4376376683536545`}}], 
      LineBox[{{7.3439850240980675`, 1.4376376683536545`}, {7.327795877062711,
        1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.3439850240980675`, 
       1.4376376683536545`}}], 
      LineBox[{{7.3439850240980675`, 1.4376376683536545`}, {7.327795877062711,
        1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.3439850240980675`, 
       1.4376376683536545`}}], 
      LineBox[{{7.3439850240980675`, 1.4376376683536545`}, {7.327795877062711,
        1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.3439850240980675`, 
       1.4376376683536545`}}], 
      LineBox[{{7.327795877062711, 1.5087252988927673`}, {7.3439850240980675`,
        1.5798129294318801`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}}], 
      LineBox[{{7.327795877062711, 1.5087252988927673`}, {7.3439850240980675`,
        1.5798129294318801`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}}], 
      LineBox[{{7.327795877062711, 1.5087252988927673`}, {7.3439850240980675`,
        1.5798129294318801`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}}], 
      LineBox[{{7.327795877062711, 1.5087252988927673`}, {7.3439850240980675`,
        1.5798129294318801`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}}], 
      LineBox[{{7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}}], 
      LineBox[{{7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}}], 
      LineBox[{{7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}}], 
      LineBox[{{7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}}], 
      LineBox[{{7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}}], 
      LineBox[{{7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}}], 
      LineBox[{{7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}}], 
      LineBox[{{7.627519773253604, 1.4161140656823183`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}}], 
      LineBox[{{7.627519773253604, 1.4161140656823183`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}}], 
      LineBox[{{7.627519773253604, 1.4161140656823183`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}}], 
      LineBox[{{7.627519773253604, 1.4161140656823183`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}}], 
      LineBox[{{7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}], 
      LineBox[{{7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}], 
      LineBox[{{7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}], 
      LineBox[{{7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}], 
      LineBox[{{7.504392385370176, 1.3450264351432055`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.504392385370176, 
       1.3450264351432055`}}], 
      LineBox[{{7.504392385370176, 1.3450264351432055`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.504392385370176, 
       1.3450264351432055`}}], 
      LineBox[{{7.504392385370176, 1.3450264351432055`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.504392385370176, 
       1.3450264351432055`}}], 
      LineBox[{{7.504392385370176, 1.3450264351432055`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.504392385370176, 
       1.3450264351432055`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.40988080231833, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.504392385370176, 1.672424162642329}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}}], 
      LineBox[{{7.40988080231833, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.504392385370176, 1.672424162642329}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}}], 
      LineBox[{{7.40988080231833, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.504392385370176, 1.672424162642329}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}}], 
      LineBox[{{7.40988080231833, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.504392385370176, 1.672424162642329}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}}], 
      LineBox[{{7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}}], 
      LineBox[{{7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}}], 
      LineBox[{{7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}}], 
      LineBox[{{7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}}], 
      LineBox[{{7.574050652829568, 1.6509005599709927`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}}], 
      LineBox[{{7.574050652829568, 1.6509005599709927`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}}], 
      LineBox[{{7.574050652829568, 1.6509005599709927`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}}], 
      LineBox[{{7.574050652829568, 1.6509005599709927`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}}], 
      LineBox[{{7.627519773253604, 1.6013365321032162`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}}], 
      LineBox[{{7.627519773253604, 1.6013365321032162`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}}], 
      LineBox[{{7.627519773253604, 1.6013365321032162`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}}], 
      LineBox[{{7.627519773253604, 1.6013365321032162`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.318478765339333, 
       2.041410893882297}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       1.943012120179557}, {7.580122705430695, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.580122705430695, 
       1.8903506946387147`}, {7.6369332639159015`, 1.943012120179557}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.405693412036453, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.580122705430695, 2.1924710931258793`}, {
       7.6369332639159015`, 2.139809667585037}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 2.139809667585037}, {7.580122705430695, 
       2.1924710931258793`}, {7.50611129387022, 2.215339767206828}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}], 
      LineBox[{{7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}], 
      LineBox[{{7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}], 
      LineBox[{{7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}], 
      LineBox[{{7.335679618414602, 1.9658807942605059`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 1.9658807942605059`}, {7.335679618414602, 
       1.9658807942605059`}}], 
      LineBox[{{7.335679618414602, 1.9658807942605059`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 1.9658807942605059`}, {7.335679618414602, 
       1.9658807942605059`}}], 
      LineBox[{{7.335679618414602, 1.9658807942605059`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 1.9658807942605059`}, {7.335679618414602, 
       1.9658807942605059`}}], 
      LineBox[{{7.335679618414602, 1.9658807942605059`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 1.9658807942605059`}, {7.335679618414602, 
       1.9658807942605059`}}], 
      LineBox[{{7.318478765339333, 2.041410893882297}, {7.335679618414602, 
       2.1169409935040884`}, {7.335679618414602, 2.1169409935040884`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}}], 
      LineBox[{{7.318478765339333, 2.041410893882297}, {7.335679618414602, 
       2.1169409935040884`}, {7.335679618414602, 2.1169409935040884`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}}], 
      LineBox[{{7.318478765339333, 2.041410893882297}, {7.335679618414602, 
       2.1169409935040884`}, {7.335679618414602, 2.1169409935040884`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}}], 
      LineBox[{{7.318478765339333, 2.041410893882297}, {7.335679618414602, 
       2.1169409935040884`}, {7.335679618414602, 2.1169409935040884`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}}], 
      LineBox[{{7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}}], 
      LineBox[{{7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}}], 
      LineBox[{{7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}}], 
      LineBox[{{7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}}], 
      LineBox[{{7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}}], 
      LineBox[{{7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}}], 
      LineBox[{{7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}}], 
      LineBox[{{7.6369332639159015`, 1.943012120179557}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}}], 
      LineBox[{{7.6369332639159015`, 1.943012120179557}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}}], 
      LineBox[{{7.6369332639159015`, 1.943012120179557}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}}], 
      LineBox[{{7.6369332639159015`, 1.943012120179557}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}}], 
      LineBox[{{7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}], 
      LineBox[{{7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}], 
      LineBox[{{7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}], 
      LineBox[{{7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}], 
      LineBox[{{7.50611129387022, 1.8674820205577658`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.50611129387022, 
       1.8674820205577658`}}], 
      LineBox[{{7.50611129387022, 1.8674820205577658`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.50611129387022, 
       1.8674820205577658`}}], 
      LineBox[{{7.50611129387022, 1.8674820205577658`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.50611129387022, 
       1.8674820205577658`}}], 
      LineBox[{{7.50611129387022, 1.8674820205577658`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.50611129387022, 
       1.8674820205577658`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.405693412036453, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.50611129387022, 2.215339767206828}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}}], 
      LineBox[{{7.405693412036453, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.50611129387022, 2.215339767206828}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}}], 
      LineBox[{{7.405693412036453, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.50611129387022, 2.215339767206828}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}}], 
      LineBox[{{7.405693412036453, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.50611129387022, 2.215339767206828}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}}], 
      LineBox[{{7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}}], 
      LineBox[{{7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}}], 
      LineBox[{{7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}}], 
      LineBox[{{7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}}], 
      LineBox[{{7.580122705430695, 2.1924710931258793`}, {7.6369332639159015`,
        2.139809667585037}, {7.6369332639159015`, 2.139809667585037}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}}], 
      LineBox[{{7.580122705430695, 2.1924710931258793`}, {7.6369332639159015`,
        2.139809667585037}, {7.6369332639159015`, 2.139809667585037}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}}], 
      LineBox[{{7.580122705430695, 2.1924710931258793`}, {7.6369332639159015`,
        2.139809667585037}, {7.6369332639159015`, 2.139809667585037}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}}], 
      LineBox[{{7.580122705430695, 2.1924710931258793`}, {7.6369332639159015`,
        2.139809667585037}, {7.6369332639159015`, 2.139809667585037}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}}], 
      LineBox[{{7.6369332639159015`, 2.139809667585037}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}}], 
      LineBox[{{7.6369332639159015`, 2.139809667585037}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}}], 
      LineBox[{{7.6369332639159015`, 2.139809667585037}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}}], 
      LineBox[{{7.6369332639159015`, 2.139809667585037}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.285497280330366, 
       2.492196329258979}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.397254441904215}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.59276402760521, 2.397254441904215}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.369647954681433, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.59276402760521, 2.587138216613743}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.587138216613743}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.46653801607861, 2.660014838347358}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}], 
      LineBox[{{7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}], 
      LineBox[{{7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}], 
      LineBox[{{7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}], 
      LineBox[{{7.302093843413679, 2.419319707525364}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.419319707525364}, {7.302093843413679, 
       2.419319707525364}}], 
      LineBox[{{7.302093843413679, 2.419319707525364}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.419319707525364}, {7.302093843413679, 
       2.419319707525364}}], 
      LineBox[{{7.302093843413679, 2.419319707525364}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.419319707525364}, {7.302093843413679, 
       2.419319707525364}}], 
      LineBox[{{7.302093843413679, 2.419319707525364}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.419319707525364}, {7.302093843413679, 
       2.419319707525364}}], 
      LineBox[{{7.285497280330366, 2.492196329258979}, {7.302093843413679, 
       2.5650729509925942`}, {7.302093843413679, 2.5650729509925942`}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}}], 
      LineBox[{{7.285497280330366, 2.492196329258979}, {7.302093843413679, 
       2.5650729509925942`}, {7.302093843413679, 2.5650729509925942`}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}}], 
      LineBox[{{7.285497280330366, 2.492196329258979}, {7.302093843413679, 
       2.5650729509925942`}, {7.302093843413679, 2.5650729509925942`}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}}], 
      LineBox[{{7.285497280330366, 2.492196329258979}, {7.302093843413679, 
       2.5650729509925942`}, {7.302093843413679, 2.5650729509925942`}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}}], 
      LineBox[{{7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}}], 
      LineBox[{{7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}}], 
      LineBox[{{7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}}], 
      LineBox[{{7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}}], 
      LineBox[{{7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}}], 
      LineBox[{{7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}}], 
      LineBox[{{7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}}], 
      LineBox[{{7.59276402760521, 2.397254441904215}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}}], 
      LineBox[{{7.59276402760521, 2.397254441904215}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}}], 
      LineBox[{{7.59276402760521, 2.397254441904215}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}}], 
      LineBox[{{7.59276402760521, 2.397254441904215}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}}], 
      LineBox[{{7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}], 
      LineBox[{{7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}], 
      LineBox[{{7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}], 
      LineBox[{{7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}], 
      LineBox[{{7.46653801607861, 2.3243778201706}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.46653801607861, 
       2.3243778201706}}], 
      LineBox[{{7.46653801607861, 2.3243778201706}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.46653801607861, 
       2.3243778201706}}], 
      LineBox[{{7.46653801607861, 2.3243778201706}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.46653801607861, 
       2.3243778201706}}], 
      LineBox[{{7.46653801607861, 2.3243778201706}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.46653801607861, 
       2.3243778201706}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.369647954681433, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.46653801607861, 2.660014838347358}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}}], 
      LineBox[{{7.369647954681433, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.46653801607861, 2.660014838347358}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}}], 
      LineBox[{{7.369647954681433, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.46653801607861, 2.660014838347358}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}}], 
      LineBox[{{7.369647954681433, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.46653801607861, 2.660014838347358}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}}], 
      LineBox[{{7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}}], 
      LineBox[{{7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}}], 
      LineBox[{{7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}}], 
      LineBox[{{7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}}], 
      LineBox[{{7.5379493033835665`, 2.6379495727262094`}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}}], 
      LineBox[{{7.5379493033835665`, 2.6379495727262094`}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}}], 
      LineBox[{{7.5379493033835665`, 2.6379495727262094`}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}}], 
      LineBox[{{7.5379493033835665`, 2.6379495727262094`}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}}], 
      LineBox[{{7.59276402760521, 2.587138216613743}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}}], 
      LineBox[{{7.59276402760521, 2.587138216613743}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}}], 
      LineBox[{{7.59276402760521, 2.587138216613743}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}}], 
      LineBox[{{7.59276402760521, 2.587138216613743}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.361037638781139, 
       2.957009823195394}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       2.8762800023753416`}, {7.575699545707322, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.575699545707322, 
       2.8330747134468037`}, {7.622308929489409, 2.8762800023753416`}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.432591607756533, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.575699545707322, 3.080944932943984}, {
       7.622308929489409, 3.037739644015446}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 3.037739644015446}, {7.575699545707322, 
       3.080944932943984}, {7.514977976026318, 3.099707198889741}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}], 
      LineBox[{{7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}], 
      LineBox[{{7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}], 
      LineBox[{{7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}], 
      LineBox[{{7.375149824680055, 2.895042268321099}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 2.895042268321099}, {7.375149824680055, 
       2.895042268321099}}], 
      LineBox[{{7.375149824680055, 2.895042268321099}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 2.895042268321099}, {7.375149824680055, 
       2.895042268321099}}], 
      LineBox[{{7.375149824680055, 2.895042268321099}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 2.895042268321099}, {7.375149824680055, 
       2.895042268321099}}], 
      LineBox[{{7.375149824680055, 2.895042268321099}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 2.895042268321099}, {7.375149824680055, 
       2.895042268321099}}], 
      LineBox[{{7.361037638781139, 2.957009823195394}, {7.375149824680055, 
       3.018977378069689}, {7.375149824680055, 3.018977378069689}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}}], 
      LineBox[{{7.361037638781139, 2.957009823195394}, {7.375149824680055, 
       3.018977378069689}, {7.375149824680055, 3.018977378069689}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}}], 
      LineBox[{{7.361037638781139, 2.957009823195394}, {7.375149824680055, 
       3.018977378069689}, {7.375149824680055, 3.018977378069689}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}}], 
      LineBox[{{7.361037638781139, 2.957009823195394}, {7.375149824680055, 
       3.018977378069689}, {7.375149824680055, 3.018977378069689}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}}], 
      LineBox[{{7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}}], 
      LineBox[{{7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}}], 
      LineBox[{{7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}}], 
      LineBox[{{7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}}], 
      LineBox[{{7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}}], 
      LineBox[{{7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}}], 
      LineBox[{{7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}}], 
      LineBox[{{7.622308929489409, 2.8762800023753416`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}}], 
      LineBox[{{7.622308929489409, 2.8762800023753416`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}}], 
      LineBox[{{7.622308929489409, 2.8762800023753416`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}}], 
      LineBox[{{7.622308929489409, 2.8762800023753416`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}}], 
      LineBox[{{7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}], 
      LineBox[{{7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}], 
      LineBox[{{7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}], 
      LineBox[{{7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}], 
      LineBox[{{7.514977976026318, 2.8143124475010466`}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.514977976026318, 
       2.8143124475010466`}}], 
      LineBox[{{7.514977976026318, 2.8143124475010466`}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.514977976026318, 
       2.8143124475010466`}}], 
      LineBox[{{7.514977976026318, 2.8143124475010466`}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.514977976026318, 
       2.8143124475010466`}}], 
      LineBox[{{7.514977976026318, 2.8143124475010466`}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.514977976026318, 
       2.8143124475010466`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.432591607756533, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.514977976026318, 3.099707198889741}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}}], 
      LineBox[{{7.432591607756533, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.514977976026318, 3.099707198889741}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}}], 
      LineBox[{{7.432591607756533, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.514977976026318, 3.099707198889741}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}}], 
      LineBox[{{7.432591607756533, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.514977976026318, 3.099707198889741}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}}], 
      LineBox[{{7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}}], 
      LineBox[{{7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}}], 
      LineBox[{{7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}}], 
      LineBox[{{7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}}], 
      LineBox[{{7.575699545707322, 3.080944932943984}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}}], 
      LineBox[{{7.575699545707322, 3.080944932943984}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}}], 
      LineBox[{{7.575699545707322, 3.080944932943984}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}}], 
      LineBox[{{7.575699545707322, 3.080944932943984}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}}], 
      LineBox[{{7.622308929489409, 3.037739644015446}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}}], 
      LineBox[{{7.622308929489409, 3.037739644015446}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}}], 
      LineBox[{{7.622308929489409, 3.037739644015446}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}}], 
      LineBox[{{7.622308929489409, 3.037739644015446}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.365561454958063, 
       3.4820943594159033`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674,
        3.395216883252527}, {7.596570077456233, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.596570077456233, 
       3.34872146903146}, {7.646728811705674, 3.395216883252527}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.442564329124119, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.596570077456233, 3.6154672498003464`}, {
       7.646728811705674, 3.5689718355792794`}, {7.6735729516222895`, 
       3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.5689718355792794`}, {7.596570077456233, 
       3.6154672498003464`}, {7.531224500456588, 3.635658280771501}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}], 
      LineBox[{{7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}], 
      LineBox[{{7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}], 
      LineBox[{{7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}], 
      LineBox[{{7.380748297708267, 3.4154079142236817`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.4154079142236817`}, {7.380748297708267, 
       3.4154079142236817`}}], 
      LineBox[{{7.380748297708267, 3.4154079142236817`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.4154079142236817`}, {7.380748297708267, 
       3.4154079142236817`}}], 
      LineBox[{{7.380748297708267, 3.4154079142236817`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.4154079142236817`}, {7.380748297708267, 
       3.4154079142236817`}}], 
      LineBox[{{7.380748297708267, 3.4154079142236817`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.4154079142236817`}, {7.380748297708267, 
       3.4154079142236817`}}], 
      LineBox[{{7.365561454958063, 3.4820943594159033`}, {7.380748297708267, 
       3.548780804608125}, {7.380748297708267, 3.548780804608125}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}}], 
      LineBox[{{7.365561454958063, 3.4820943594159033`}, {7.380748297708267, 
       3.548780804608125}, {7.380748297708267, 3.548780804608125}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}}], 
      LineBox[{{7.365561454958063, 3.4820943594159033`}, {7.380748297708267, 
       3.548780804608125}, {7.380748297708267, 3.548780804608125}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}}], 
      LineBox[{{7.365561454958063, 3.4820943594159033`}, {7.380748297708267, 
       3.548780804608125}, {7.380748297708267, 3.548780804608125}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}}], 
      LineBox[{{7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}}], 
      LineBox[{{7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}}], 
      LineBox[{{7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}}], 
      LineBox[{{7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674,
        3.395216883252527}, {7.646728811705674, 3.395216883252527}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}}], 
      LineBox[{{7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674,
        3.395216883252527}, {7.646728811705674, 3.395216883252527}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}}], 
      LineBox[{{7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674,
        3.395216883252527}, {7.646728811705674, 3.395216883252527}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}}], 
      LineBox[{{7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674,
        3.395216883252527}, {7.646728811705674, 3.395216883252527}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}}], 
      LineBox[{{7.646728811705674, 3.395216883252527}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}}], 
      LineBox[{{7.646728811705674, 3.395216883252527}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}}], 
      LineBox[{{7.646728811705674, 3.395216883252527}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}}], 
      LineBox[{{7.646728811705674, 3.395216883252527}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}}], 
      LineBox[{{7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}], 
      LineBox[{{7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}], 
      LineBox[{{7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}], 
      LineBox[{{7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}], 
      LineBox[{{7.531224500456588, 3.3285304380603056`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.531224500456588, 
       3.3285304380603056`}}], 
      LineBox[{{7.531224500456588, 3.3285304380603056`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.531224500456588, 
       3.3285304380603056`}}], 
      LineBox[{{7.531224500456588, 3.3285304380603056`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.531224500456588, 
       3.3285304380603056`}}], 
      LineBox[{{7.531224500456588, 3.3285304380603056`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.531224500456588, 
       3.3285304380603056`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.442564329124119, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.531224500456588, 3.635658280771501}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}}], 
      LineBox[{{7.442564329124119, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.531224500456588, 3.635658280771501}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}}], 
      LineBox[{{7.442564329124119, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.531224500456588, 3.635658280771501}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}}], 
      LineBox[{{7.442564329124119, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.531224500456588, 3.635658280771501}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}}], 
      LineBox[{{7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}}], 
      LineBox[{{7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}}], 
      LineBox[{{7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}}], 
      LineBox[{{7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}}], 
      LineBox[{{7.596570077456233, 3.6154672498003464`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}}], 
      LineBox[{{7.596570077456233, 3.6154672498003464`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}}], 
      LineBox[{{7.596570077456233, 3.6154672498003464`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}}], 
      LineBox[{{7.596570077456233, 3.6154672498003464`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}}], 
      LineBox[{{7.646728811705674, 3.5689718355792794`}, {7.6735729516222895`,
        3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}}], 
      LineBox[{{7.646728811705674, 3.5689718355792794`}, {7.6735729516222895`,
        3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}}], 
      LineBox[{{7.646728811705674, 3.5689718355792794`}, {7.6735729516222895`,
        3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}}], 
      LineBox[{{7.646728811705674, 3.5689718355792794`}, {7.6735729516222895`,
        3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}], 
      LineBox[{{7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}], 
      LineBox[{{7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}], 
      LineBox[{{7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}], 
      LineBox[{{7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}], 
      LineBox[{{7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}], 
      LineBox[{{7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}], 
      LineBox[{{7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}], 
      LineBox[{{7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}], 
      LineBox[{{7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}], 
      LineBox[{{7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}], 
      LineBox[{{7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}], 
      LineBox[{{7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}], 
      LineBox[{{7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}], 
      LineBox[{{7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}], 
      LineBox[{{7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}], 
      LineBox[{{7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}], 
      LineBox[{{7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}], 
      LineBox[{{7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}], 
      LineBox[{{7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}], 
      LineBox[{{7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}], 
      LineBox[{{7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}], 
      LineBox[{{7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}], 
      LineBox[{{7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}], 
      LineBox[{{7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}], 
      LineBox[{{7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}], 
      LineBox[{{7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}], 
      LineBox[{{7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}], 
      LineBox[{{7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}], 
      LineBox[{{7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}], 
      LineBox[{{7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}], 
      LineBox[{{7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}], 
      LineBox[{{7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}], 
      LineBox[{{7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}], 
      LineBox[{{7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}], 
      LineBox[{{7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}], 
      LineBox[{{7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}], 
      LineBox[{{7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}], 
      LineBox[{{7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}], 
      LineBox[{{7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}], 
      LineBox[{{7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}], 
      LineBox[{{7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}], 
      LineBox[{{7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}], 
      LineBox[{{7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}], 
      LineBox[{{7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}], 
      LineBox[{{7.844798033474368, -4.1970863468582635`}, {7.870506704796848,
        -4.280289030458804}, {7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}], 
      LineBox[{{7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}], 
      LineBox[{{7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}], 
      LineBox[{{7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}], 
      LineBox[{{7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}], 
      LineBox[{{7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}], 
      LineBox[{{7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}], 
      LineBox[{{7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}], 
      LineBox[{{7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}], 
      LineBox[{{7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}], 
      LineBox[{{7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}], 
      LineBox[{{7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}], 
      LineBox[{{7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}], 
      LineBox[{{7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}], 
      LineBox[{{7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}], 
      LineBox[{{7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}], 
      LineBox[{{7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}], 
      LineBox[{{7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}], 
      LineBox[{{7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}], 
      LineBox[{{7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}], 
      LineBox[{{7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}], 
      LineBox[{{7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}], 
      LineBox[{{7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}], 
      LineBox[{{7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}], 
      LineBox[{{7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}], 
      LineBox[{{7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}], 
      LineBox[{{7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}], 
      LineBox[{{7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}], 
      LineBox[{{7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}], 
      LineBox[{{7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}], 
      LineBox[{{7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}], 
      LineBox[{{7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}], 
      LineBox[{{7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}], 
      LineBox[{{7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}], 
      LineBox[{{7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}], 
      LineBox[{{7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}], 
      LineBox[{{7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}], 
      LineBox[{{7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}], 
      LineBox[{{7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}], 
      LineBox[{{7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}], 
      LineBox[{{7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}], 
      LineBox[{{7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}], 
      LineBox[{{7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}], 
      LineBox[{{7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}], 
      LineBox[{{7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}], 
      LineBox[{{7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}], 
      LineBox[{{7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}], 
      LineBox[{{7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}], 
      LineBox[{{7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}], 
      LineBox[{{7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}], 
      LineBox[{{7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}], 
      LineBox[{{7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}], 
      LineBox[{{7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}], 
      LineBox[{{7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}], 
      LineBox[{{7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}], 
      LineBox[{{7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}], 
      LineBox[{{7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}], 
      LineBox[{{7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}], 
      LineBox[{{7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}], 
      LineBox[{{7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}], 
      LineBox[{{7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}], 
      LineBox[{{7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}], 
      LineBox[{{7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}], 
      LineBox[{{7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}], 
      LineBox[{{7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}], 
      LineBox[{{7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}], 
      LineBox[{{7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}], 
      LineBox[{{7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}], 
      LineBox[{{7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}], 
      LineBox[{{7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}], 
      LineBox[{{7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}], 
      LineBox[{{7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}], 
      LineBox[{{7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}], 
      LineBox[{{7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}], 
      LineBox[{{7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}], 
      LineBox[{{7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}], 
      LineBox[{{7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}], 
      LineBox[{{7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}], 
      LineBox[{{7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}], 
      LineBox[{{7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}], 
      LineBox[{{7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}], 
      LineBox[{{7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}], 
      LineBox[{{7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}], 
      LineBox[{{7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}], 
      LineBox[{{7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}], 
      LineBox[{{7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}], 
      LineBox[{{7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}], 
      LineBox[{{7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}], 
      LineBox[{{7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}], 
      LineBox[{{7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}], 
      LineBox[{{7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}], 
      LineBox[{{7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}], 
      LineBox[{{7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}], 
      LineBox[{{7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}], 
      LineBox[{{7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}], 
      LineBox[{{7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}], 
      LineBox[{{7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}], 
      LineBox[{{7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}], 
      LineBox[{{7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}], 
      LineBox[{{7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}], 
      LineBox[{{7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}], 
      LineBox[{{7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}], 
      LineBox[{{7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}], 
      LineBox[{{7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}], 
      LineBox[{{7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}], 
      LineBox[{{7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}], 
      LineBox[{{7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}], 
      LineBox[{{7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}], 
      LineBox[{{7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}], 
      LineBox[{{7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}], 
      LineBox[{{7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}], 
      LineBox[{{7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}], 
      LineBox[{{7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}], 
      LineBox[{{7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}], 
      LineBox[{{7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}], 
      LineBox[{{7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}], 
      LineBox[{{7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}], 
      LineBox[{{7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}], 
      LineBox[{{7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}], 
      LineBox[{{7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}], 
      LineBox[{{7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}], 
      LineBox[{{7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}], 
      LineBox[{{7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}], 
      LineBox[{{7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}], 
      LineBox[{{7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}], 
      LineBox[{{7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}], 
      LineBox[{{7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}], 
      LineBox[{{7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}], 
      LineBox[{{7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}], 
      LineBox[{{7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}], 
      LineBox[{{7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}], 
      LineBox[{{7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}], 
      LineBox[{{7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}], 
      LineBox[{{7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}], 
      LineBox[{{7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}], 
      LineBox[{{7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}], 
      LineBox[{{7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}], 
      LineBox[{{7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}], 
      LineBox[{{7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}], 
      LineBox[{{7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}], 
      LineBox[{{7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}], 
      LineBox[{{7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}], 
      LineBox[{{7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}], 
      LineBox[{{7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}], 
      LineBox[{{7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}], 
      LineBox[{{7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}], 
      LineBox[{{7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}], 
      LineBox[{{7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}], 
      LineBox[{{7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}], 
      LineBox[{{7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}], 
      LineBox[{{7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}], 
      LineBox[{{7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}], 
      LineBox[{{7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}], 
      LineBox[{{7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}], 
      LineBox[{{7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}], 
      LineBox[{{7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}], 
      LineBox[{{7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}], 
      LineBox[{{7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}], 
      LineBox[{{7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}], 
      LineBox[{{7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}], 
      LineBox[{{7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}], 
      LineBox[{{7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}], 
      LineBox[{{7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}], 
      LineBox[{{7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}], 
      LineBox[{{7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}], 
      LineBox[{{7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}], 
      LineBox[{{7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}], 
      LineBox[{{7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}], 
      LineBox[{{7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}], 
      LineBox[{{7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}], 
      LineBox[{{7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}], 
      LineBox[{{7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}], 
      LineBox[{{7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}], 
      LineBox[{{7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}], 
      LineBox[{{7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}], 
      LineBox[{{7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}], 
      LineBox[{{7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}], 
      LineBox[{{7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}], 
      LineBox[{{7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}], 
      LineBox[{{7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}], 
      LineBox[{{7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}], 
      LineBox[{{7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}], 
      LineBox[{{7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}], 
      LineBox[{{7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}], 
      LineBox[{{7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}], 
      LineBox[{{7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}], 
      LineBox[{{7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}], 
      LineBox[{{7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}], 
      LineBox[{{7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}], 
      LineBox[{{7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}], 
      LineBox[{{7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}], 
      LineBox[{{7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}], 
      LineBox[{{7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}], 
      LineBox[{{7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}], 
      LineBox[{{7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}], 
      LineBox[{{7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}], 
      LineBox[{{7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}], 
      LineBox[{{7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}], 
      LineBox[{{7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}], 
      LineBox[{{7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}], 
      LineBox[{{7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}], 
      LineBox[{{7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}], 
      LineBox[{{7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}], 
      LineBox[{{7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}], 
      LineBox[{{7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}], 
      LineBox[{{7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}], 
      LineBox[{{7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}], 
      LineBox[{{7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}], 
      LineBox[{{7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}], 
      LineBox[{{7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}], 
      LineBox[{{7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}], 
      LineBox[{{7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}], 
      LineBox[{{7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}], 
      LineBox[{{7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}], 
      LineBox[{{7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}], 
      LineBox[{{7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}], 
      LineBox[{{7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}], 
      LineBox[{{7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}], 
      LineBox[{{7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}], 
      LineBox[{{7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}], 
      LineBox[{{7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}], 
      LineBox[{{7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}], 
      LineBox[{{7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}], 
      LineBox[{{7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}], 
      LineBox[{{7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}], 
      LineBox[{{7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}], 
      LineBox[{{7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}], 
      LineBox[{{7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}], 
      LineBox[{{7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}], 
      LineBox[{{7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}], 
      LineBox[{{7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}], 
      LineBox[{{7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}], 
      LineBox[{{7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}], 
      LineBox[{{7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}], 
      LineBox[{{7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}], 
      LineBox[{{7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}], 
      LineBox[{{7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}], 
      LineBox[{{7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}], 
      LineBox[{{7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}], 
      LineBox[{{7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}], 
      LineBox[{{7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}], 
      LineBox[{{7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}], 
      LineBox[{{7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}], 
      LineBox[{{7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}], 
      LineBox[{{7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}], 
      LineBox[{{7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}], 
      LineBox[{{7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}], 
      LineBox[{{7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}], 
      LineBox[{{7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}], 
      LineBox[{{7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}], 
      LineBox[{{7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}], 
      LineBox[{{7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}], 
      LineBox[{{7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}], 
      LineBox[{{7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}], 
      LineBox[{{7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}], 
      LineBox[{{7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}], 
      LineBox[{{7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}], 
      LineBox[{{7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}], 
      LineBox[{{7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}], 
      LineBox[{{7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}], 
      LineBox[{{7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}], 
      LineBox[{{7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}], 
      LineBox[{{7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}], 
      LineBox[{{7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}], 
      LineBox[{{7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}], 
      LineBox[{{7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}], 
      LineBox[{{7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}], 
      LineBox[{{7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}], 
      LineBox[{{7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}], 
      LineBox[{{7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}], 
      LineBox[{{7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368931, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}], 
      LineBox[{{7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}], 
      LineBox[{{7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}], 
      LineBox[{{7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}], 
      LineBox[{{7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}], 
      LineBox[{{7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}], 
      LineBox[{{7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}], 
      LineBox[{{7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}], 
      LineBox[{{7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}], 
      LineBox[{{7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}], 
      LineBox[{{7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}], 
      LineBox[{{7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}], 
      LineBox[{{7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}], 
      LineBox[{{7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}], 
      LineBox[{{7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}], 
      LineBox[{{7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}], 
      LineBox[{{7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}], 
      LineBox[{{7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}], 
      LineBox[{{7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}], 
      LineBox[{{7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}], 
      LineBox[{{7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}], 
      LineBox[{{7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}], 
      LineBox[{{7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}], 
      LineBox[{{7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}], 
      LineBox[{{7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}], 
      LineBox[{{7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}], 
      LineBox[{{7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}], 
      LineBox[{{7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}], 
      LineBox[{{7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}], 
      LineBox[{{7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}], 
      LineBox[{{7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}], 
      LineBox[{{7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}], 
      LineBox[{{7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}], 
      LineBox[{{7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}], 
      LineBox[{{7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}], 
      LineBox[{{7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}], 
      LineBox[{{7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}], 
      LineBox[{{7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}], 
      LineBox[{{7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}], 
      LineBox[{{7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}], 
      LineBox[{{7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}], 
      LineBox[{{7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}], 
      LineBox[{{7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}], 
      LineBox[{{7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}], 
      LineBox[{{7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}], 
      LineBox[{{7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111716`}, {
       7.67004490551025, -0.10877815610111716`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.3612878712557855}, {
       7.67004490551025, -0.3612878712557855}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845128`}, {
       7.888724733536566, -0.23503301367845128`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}], 
      LineBox[{{7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}], 
      LineBox[{{7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}], 
      LineBox[{{7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}], 
      LineBox[{{7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}], 
      LineBox[{{7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}], 
      LineBox[{{7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}], 
      LineBox[{{7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}], 
      LineBox[{{7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}], 
      LineBox[{{7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}], 
      LineBox[{{7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}], 
      LineBox[{{7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}], 
      LineBox[{{7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}], 
      LineBox[{{7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}], 
      LineBox[{{7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}], 
      LineBox[{{7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}], 
      LineBox[{{7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}], 
      LineBox[{{7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}], 
      LineBox[{{7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}], 
      LineBox[{{7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}], 
      LineBox[{{7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}], 
      LineBox[{{7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}], 
      LineBox[{{7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}], 
      LineBox[{{7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}], 
      LineBox[{{7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}], 
      LineBox[{{7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}], 
      LineBox[{{7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}], 
      LineBox[{{7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}], 
      LineBox[{{7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}], 
      LineBox[{{7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}], 
      LineBox[{{7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}], 
      LineBox[{{7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}], 
      LineBox[{{7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}], 
      LineBox[{{7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}], 
      LineBox[{{7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}], 
      LineBox[{{7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}], 
      LineBox[{{7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}], 
      LineBox[{{7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}], 
      LineBox[{{7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}], 
      LineBox[{{7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}], 
      LineBox[{{7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}], 
      LineBox[{{7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}], 
      LineBox[{{7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}], 
      LineBox[{{7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}], 
      LineBox[{{7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}], 
      LineBox[{{7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.666826849311777, 0.06378109101299881}, {7.598592771368875, 
       0.13739125321137974`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.2846115776081416}, {7.666826849311777, 
       0.3582217398065225}, {7.666826849311777, 0.3582217398065225}, {
       7.598592771368875, 0.2846115776081416}, {7.581829155391122, 
       0.21100141540976067`}, {7.598592771368875, 0.1373912532113797}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.836822237153086, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299878}, {7.666826849311777, 0.06378109101299878}, {
       7.764692158723719, 0.04149372720982844}, {7.836822237153086, 
       0.06378109101299881}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.836822237153086, 0.3582217398065225}, {
       7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.2110014154097607}, {7.921819931073741, 0.2110014154097607}, {
       7.8921886996047, 0.3068989414113119}, {7.836822237153086, 
       0.3582217398065225}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.666826849311777, 0.06378109101299881}, {7.598592771368875, 
       0.13739125321137974`}, {7.598592771368875, 0.13739125321137974`}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}}], 
      LineBox[{{7.666826849311777, 0.06378109101299881}, {7.598592771368875, 
       0.13739125321137974`}, {7.598592771368875, 0.13739125321137974`}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}}], 
      LineBox[{{7.666826849311777, 0.06378109101299881}, {7.598592771368875, 
       0.13739125321137974`}, {7.598592771368875, 0.13739125321137974`}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}}], 
      LineBox[{{7.666826849311777, 0.06378109101299881}, {7.598592771368875, 
       0.13739125321137974`}, {7.598592771368875, 0.13739125321137974`}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}}], 
      LineBox[{{7.598592771368875, 0.13739125321137974`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}}], 
      LineBox[{{7.598592771368875, 0.13739125321137974`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}}], 
      LineBox[{{7.598592771368875, 0.13739125321137974`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}}], 
      LineBox[{{7.598592771368875, 0.13739125321137974`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}}], 
      LineBox[{{7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}], 
      LineBox[{{7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}], 
      LineBox[{{7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}], 
      LineBox[{{7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}], 
      LineBox[{{7.598592771368875, 0.2846115776081416}, {7.666826849311777, 
       0.35822173980652255`}, {7.666826849311777, 0.35822173980652255`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}}], 
      LineBox[{{7.598592771368875, 0.2846115776081416}, {7.666826849311777, 
       0.35822173980652255`}, {7.666826849311777, 0.35822173980652255`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}}], 
      LineBox[{{7.598592771368875, 0.2846115776081416}, {7.666826849311777, 
       0.35822173980652255`}, {7.666826849311777, 0.35822173980652255`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}}], 
      LineBox[{{7.598592771368875, 0.2846115776081416}, {7.666826849311777, 
       0.35822173980652255`}, {7.666826849311777, 0.35822173980652255`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}], 
      LineBox[{{7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}], 
      LineBox[{{7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}], 
      LineBox[{{7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}], 
      LineBox[{{7.8921886996047, 0.1151038894082094}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.8921886996047, 0.1151038894082094}, {7.8921886996047, 
       0.1151038894082094}}], 
      LineBox[{{7.8921886996047, 0.1151038894082094}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.8921886996047, 0.1151038894082094}, {7.8921886996047, 
       0.1151038894082094}}], 
      LineBox[{{7.8921886996047, 0.1151038894082094}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.8921886996047, 0.1151038894082094}, {7.8921886996047, 
       0.1151038894082094}}], 
      LineBox[{{7.8921886996047, 0.1151038894082094}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.8921886996047, 0.1151038894082094}, {7.8921886996047, 
       0.1151038894082094}}], 
      LineBox[{{7.836822237153086, 0.06378109101299881}, {7.764692158723719, 
       0.04149372720982844}, {7.764692158723719, 0.04149372720982844}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}}], 
      LineBox[{{7.836822237153086, 0.06378109101299881}, {7.764692158723719, 
       0.04149372720982844}, {7.764692158723719, 0.04149372720982844}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}}], 
      LineBox[{{7.836822237153086, 0.06378109101299881}, {7.764692158723719, 
       0.04149372720982844}, {7.764692158723719, 0.04149372720982844}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}}], 
      LineBox[{{7.836822237153086, 0.06378109101299881}, {7.764692158723719, 
       0.04149372720982844}, {7.764692158723719, 0.04149372720982844}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}}], 
      LineBox[{{7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}}], 
      LineBox[{{7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}}], 
      LineBox[{{7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}}], 
      LineBox[{{7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}], 
      LineBox[{{7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}], 
      LineBox[{{7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}], 
      LineBox[{{7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}], 
      LineBox[{{7.764692158723719, 0.3805091036096929}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}}], 
      LineBox[{{7.764692158723719, 0.3805091036096929}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}}], 
      LineBox[{{7.764692158723719, 0.3805091036096929}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}}], 
      LineBox[{{7.764692158723719, 0.3805091036096929}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}}], 
      LineBox[{{7.836822237153086, 0.3582217398065225}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}], 
      LineBox[{{7.836822237153086, 0.3582217398065225}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}], 
      LineBox[{{7.836822237153086, 0.3582217398065225}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}], 
      LineBox[{{7.836822237153086, 0.3582217398065225}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}], 
      LineBox[{{7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.21100141540976064`}, {7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.3068989414113119}, {7.8921886996047, 
       0.3068989414113119}}], 
      LineBox[{{7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.21100141540976064`}, {7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.3068989414113119}, {7.8921886996047, 
       0.3068989414113119}}], 
      LineBox[{{7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.21100141540976064`}, {7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.3068989414113119}, {7.8921886996047, 
       0.3068989414113119}}], 
      LineBox[{{7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.21100141540976064`}, {7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.3068989414113119}, {7.8921886996047, 
       0.3068989414113119}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.704426849326499, 0.6118313882494719}, {7.636700076183877, 
       0.6848942756878135}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.8310200505644966}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}, {
       7.636700076183877, 0.8310200505644966}, {7.620061093865903, 
       0.757957163126155}, {7.636700076183877, 0.6848942756878135}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.87315836024769, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.87315836024769, 
       0.6118313882494719}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.87315836024769, 0.9040829380028381}, {
       7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.87315836024769, 
       0.9040829380028381}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.704426849326499, 0.6118313882494719}, {7.636700076183877, 
       0.6848942756878135}, {7.636700076183877, 0.6848942756878135}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}}], 
      LineBox[{{7.704426849326499, 0.6118313882494719}, {7.636700076183877, 
       0.6848942756878135}, {7.636700076183877, 0.6848942756878135}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}}], 
      LineBox[{{7.704426849326499, 0.6118313882494719}, {7.636700076183877, 
       0.6848942756878135}, {7.636700076183877, 0.6848942756878135}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}}], 
      LineBox[{{7.704426849326499, 0.6118313882494719}, {7.636700076183877, 
       0.6848942756878135}, {7.636700076183877, 0.6848942756878135}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}}], 
      LineBox[{{7.636700076183877, 0.6848942756878135}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}}], 
      LineBox[{{7.636700076183877, 0.6848942756878135}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}}], 
      LineBox[{{7.636700076183877, 0.6848942756878135}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}}], 
      LineBox[{{7.636700076183877, 0.6848942756878135}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}}], 
      LineBox[{{7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}], 
      LineBox[{{7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}], 
      LineBox[{{7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}], 
      LineBox[{{7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}], 
      LineBox[{{7.636700076183877, 0.8310200505644966}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}}], 
      LineBox[{{7.636700076183877, 0.8310200505644966}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}}], 
      LineBox[{{7.636700076183877, 0.8310200505644966}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}}], 
      LineBox[{{7.636700076183877, 0.8310200505644966}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}], 
      LineBox[{{7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}], 
      LineBox[{{7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}], 
      LineBox[{{7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}], 
      LineBox[{{7.92811318568415, 0.6627726133491287}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.92811318568415, 0.6627726133491287}, {7.92811318568415, 
       0.6627726133491287}}], 
      LineBox[{{7.92811318568415, 0.6627726133491287}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.92811318568415, 0.6627726133491287}, {7.92811318568415, 
       0.6627726133491287}}], 
      LineBox[{{7.92811318568415, 0.6627726133491287}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.92811318568415, 0.6627726133491287}, {7.92811318568415, 
       0.6627726133491287}}], 
      LineBox[{{7.92811318568415, 0.6627726133491287}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.92811318568415, 0.6627726133491287}, {7.92811318568415, 
       0.6627726133491287}}], 
      LineBox[{{7.87315836024769, 0.6118313882494719}, {7.8015645524932555`, 
       0.5897097259107871}, {7.8015645524932555`, 0.5897097259107871}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}}], 
      LineBox[{{7.87315836024769, 0.6118313882494719}, {7.8015645524932555`, 
       0.5897097259107871}, {7.8015645524932555`, 0.5897097259107871}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}}], 
      LineBox[{{7.87315836024769, 0.6118313882494719}, {7.8015645524932555`, 
       0.5897097259107871}, {7.8015645524932555`, 0.5897097259107871}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}}], 
      LineBox[{{7.87315836024769, 0.6118313882494719}, {7.8015645524932555`, 
       0.5897097259107871}, {7.8015645524932555`, 0.5897097259107871}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}}], 
      LineBox[{{7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}}], 
      LineBox[{{7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}}], 
      LineBox[{{7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}}], 
      LineBox[{{7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}], 
      LineBox[{{7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}], 
      LineBox[{{7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}], 
      LineBox[{{7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}], 
      LineBox[{{7.8015645524932555`, 0.926204600341523}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}}], 
      LineBox[{{7.8015645524932555`, 0.926204600341523}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}}], 
      LineBox[{{7.8015645524932555`, 0.926204600341523}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}}], 
      LineBox[{{7.8015645524932555`, 0.926204600341523}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}}], 
      LineBox[{{7.87315836024769, 0.9040829380028381}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}], 
      LineBox[{{7.87315836024769, 0.9040829380028381}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}], 
      LineBox[{{7.87315836024769, 0.9040829380028381}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}], 
      LineBox[{{7.87315836024769, 0.9040829380028381}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}], 
      LineBox[{{7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.92811318568415, 
       0.8531417129031813}}], 
      LineBox[{{7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.92811318568415, 
       0.8531417129031813}}], 
      LineBox[{{7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.92811318568415, 
       0.8531417129031813}}], 
      LineBox[{{7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.92811318568415, 
       0.8531417129031813}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.713807209888335, 1.160347952955769}, {7.658857113081461, 
       1.2196275044748133`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.3381866075129014`}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}, {
       7.658857113081461, 1.3381866075129014`}, {7.645357079834414, 
       1.2789070559938573`}, {7.658857113081461, 1.2196275044748133`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.850707469996177, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.850707469996177, 
       1.160347952955769}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.850707469996177, 1.3974661590319457`}, {
       7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.850707469996177, 
       1.3974661590319457`}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.713807209888335, 1.160347952955769}, {7.658857113081461, 
       1.2196275044748133`}, {7.658857113081461, 1.2196275044748133`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}}], 
      LineBox[{{7.713807209888335, 1.160347952955769}, {7.658857113081461, 
       1.2196275044748133`}, {7.658857113081461, 1.2196275044748133`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}}], 
      LineBox[{{7.713807209888335, 1.160347952955769}, {7.658857113081461, 
       1.2196275044748133`}, {7.658857113081461, 1.2196275044748133`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}}], 
      LineBox[{{7.713807209888335, 1.160347952955769}, {7.658857113081461, 
       1.2196275044748133`}, {7.658857113081461, 1.2196275044748133`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}}], 
      LineBox[{{7.658857113081461, 1.2196275044748133`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}}], 
      LineBox[{{7.658857113081461, 1.2196275044748133`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}}], 
      LineBox[{{7.658857113081461, 1.2196275044748133`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}}], 
      LineBox[{{7.658857113081461, 1.2196275044748133`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}}], 
      LineBox[{{7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}], 
      LineBox[{{7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}], 
      LineBox[{{7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}], 
      LineBox[{{7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}], 
      LineBox[{{7.658857113081461, 1.3381866075129014`}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}}], 
      LineBox[{{7.658857113081461, 1.3381866075129014`}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}}], 
      LineBox[{{7.658857113081461, 1.3381866075129014`}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}}], 
      LineBox[{{7.658857113081461, 1.3381866075129014`}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}], 
      LineBox[{{7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}], 
      LineBox[{{7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}], 
      LineBox[{{7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}], 
      LineBox[{{7.895295050913094, 1.201679100459168}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.895295050913094, 1.201679100459168}, {7.895295050913094, 
       1.201679100459168}}], 
      LineBox[{{7.895295050913094, 1.201679100459168}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.895295050913094, 1.201679100459168}, {7.895295050913094, 
       1.201679100459168}}], 
      LineBox[{{7.895295050913094, 1.201679100459168}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.895295050913094, 1.201679100459168}, {7.895295050913094, 
       1.201679100459168}}], 
      LineBox[{{7.895295050913094, 1.201679100459168}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.895295050913094, 1.201679100459168}, {7.895295050913094, 
       1.201679100459168}}], 
      LineBox[{{7.850707469996177, 1.160347952955769}, {7.792619855832213, 
       1.1423995489401237`}, {7.792619855832213, 1.1423995489401237`}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}}], 
      LineBox[{{7.850707469996177, 1.160347952955769}, {7.792619855832213, 
       1.1423995489401237`}, {7.792619855832213, 1.1423995489401237`}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}}], 
      LineBox[{{7.850707469996177, 1.160347952955769}, {7.792619855832213, 
       1.1423995489401237`}, {7.792619855832213, 1.1423995489401237`}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}}], 
      LineBox[{{7.850707469996177, 1.160347952955769}, {7.792619855832213, 
       1.1423995489401237`}, {7.792619855832213, 1.1423995489401237`}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}}], 
      LineBox[{{7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}}], 
      LineBox[{{7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}}], 
      LineBox[{{7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}}], 
      LineBox[{{7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}], 
      LineBox[{{7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}], 
      LineBox[{{7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}], 
      LineBox[{{7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}], 
      LineBox[{{7.792619855832213, 1.415414563047591}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}}], 
      LineBox[{{7.792619855832213, 1.415414563047591}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}}], 
      LineBox[{{7.792619855832213, 1.415414563047591}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}}], 
      LineBox[{{7.792619855832213, 1.415414563047591}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}}], 
      LineBox[{{7.850707469996177, 1.3974661590319457`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}], 
      LineBox[{{7.850707469996177, 1.3974661590319457`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}], 
      LineBox[{{7.850707469996177, 1.3974661590319457`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}], 
      LineBox[{{7.850707469996177, 1.3974661590319457`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}], 
      LineBox[{{7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.895295050913094, 
       1.3561350115285467`}}], 
      LineBox[{{7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.895295050913094, 
       1.3561350115285467`}}], 
      LineBox[{{7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.895295050913094, 
       1.3561350115285467`}}], 
      LineBox[{{7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.895295050913094, 
       1.3561350115285467`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.678070286693334, 1.5863329718017225`}, {7.607661131855588, 
       1.662289582693341}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.8142028044765781`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}, {
       7.607661131855588, 1.8142028044765781`}, {7.590363147203319, 
       1.7382461935849596`}, {7.607661131855588, 1.662289582693341}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`,
        1.6392917713906703`}, {7.853484565673364, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.853484565673364, 
       1.5863329718017225`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.853484565673364, 1.8901594153681966`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379, 
       1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.853484565673364, 
       1.8901594153681966`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.678070286693334, 1.5863329718017225`}, {7.607661131855588, 
       1.662289582693341}, {7.607661131855588, 1.662289582693341}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}}], 
      LineBox[{{7.678070286693334, 1.5863329718017225`}, {7.607661131855588, 
       1.662289582693341}, {7.607661131855588, 1.662289582693341}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}}], 
      LineBox[{{7.678070286693334, 1.5863329718017225`}, {7.607661131855588, 
       1.662289582693341}, {7.607661131855588, 1.662289582693341}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}}], 
      LineBox[{{7.678070286693334, 1.5863329718017225`}, {7.607661131855588, 
       1.662289582693341}, {7.607661131855588, 1.662289582693341}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}}], 
      LineBox[{{7.607661131855588, 1.662289582693341}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}}], 
      LineBox[{{7.607661131855588, 1.662289582693341}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}}], 
      LineBox[{{7.607661131855588, 1.662289582693341}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}}], 
      LineBox[{{7.607661131855588, 1.662289582693341}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}}], 
      LineBox[{{7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}], 
      LineBox[{{7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}], 
      LineBox[{{7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}], 
      LineBox[{{7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}], 
      LineBox[{{7.607661131855588, 1.8142028044765781`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}}], 
      LineBox[{{7.607661131855588, 1.8142028044765781`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}}], 
      LineBox[{{7.607661131855588, 1.8142028044765781`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}}], 
      LineBox[{{7.607661131855588, 1.8142028044765781`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`,
        1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}], 
      LineBox[{{7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`,
        1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}], 
      LineBox[{{7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`,
        1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}], 
      LineBox[{{7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`,
        1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}], 
      LineBox[{{7.9106159279647414`, 1.6392917713906703`}, {7.853484565673364,
        1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.9106159279647414`, 
       1.6392917713906703`}}], 
      LineBox[{{7.9106159279647414`, 1.6392917713906703`}, {7.853484565673364,
        1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.9106159279647414`, 
       1.6392917713906703`}}], 
      LineBox[{{7.9106159279647414`, 1.6392917713906703`}, {7.853484565673364,
        1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.9106159279647414`, 
       1.6392917713906703`}}], 
      LineBox[{{7.9106159279647414`, 1.6392917713906703`}, {7.853484565673364,
        1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.9106159279647414`, 
       1.6392917713906703`}}], 
      LineBox[{{7.853484565673364, 1.5863329718017225`}, {7.779055218729718, 
       1.5633351604990517`}, {7.779055218729718, 1.5633351604990517`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}}], 
      LineBox[{{7.853484565673364, 1.5863329718017225`}, {7.779055218729718, 
       1.5633351604990517`}, {7.779055218729718, 1.5633351604990517`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}}], 
      LineBox[{{7.853484565673364, 1.5863329718017225`}, {7.779055218729718, 
       1.5633351604990517`}, {7.779055218729718, 1.5633351604990517`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}}], 
      LineBox[{{7.853484565673364, 1.5863329718017225`}, {7.779055218729718, 
       1.5633351604990517`}, {7.779055218729718, 1.5633351604990517`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}}], 
      LineBox[{{7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}}], 
      LineBox[{{7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}}], 
      LineBox[{{7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}}], 
      LineBox[{{7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}], 
      LineBox[{{7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}], 
      LineBox[{{7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}], 
      LineBox[{{7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}], 
      LineBox[{{7.779055218729718, 1.9131572266708674`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}}], 
      LineBox[{{7.779055218729718, 1.9131572266708674`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}}], 
      LineBox[{{7.779055218729718, 1.9131572266708674`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}}], 
      LineBox[{{7.779055218729718, 1.9131572266708674`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}}], 
      LineBox[{{7.853484565673364, 1.8901594153681966`}, {7.9106159279647414`,
        1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}], 
      LineBox[{{7.853484565673364, 1.8901594153681966`}, {7.9106159279647414`,
        1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}], 
      LineBox[{{7.853484565673364, 1.8901594153681966`}, {7.9106159279647414`,
        1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}], 
      LineBox[{{7.853484565673364, 1.8901594153681966`}, {7.9106159279647414`,
        1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}], 
      LineBox[{{7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379,
        1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.9106159279647414`, 
       1.8372006157792489`}}], 
      LineBox[{{7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379,
        1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.9106159279647414`, 
       1.8372006157792489`}}], 
      LineBox[{{7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379,
        1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.9106159279647414`, 
       1.8372006157792489`}}], 
      LineBox[{{7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379,
        1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.9106159279647414`, 
       1.8372006157792489`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.663608688411636, 2.14497482286346}, {7.5992516015753955`, 
       2.214402530300133}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.663608688411636, 
       2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.583440477256073, 
       2.283830237736806}, {7.5992516015753955`, 2.214402530300133}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.8239451107227636`, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.8239451107227636`, 
       2.14497482286346}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`,
        2.4437066710055606`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.663608688411636, 2.14497482286346}, {7.5992516015753955`, 
       2.214402530300133}, {7.5992516015753955`, 2.214402530300133}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}}], 
      LineBox[{{7.663608688411636, 2.14497482286346}, {7.5992516015753955`, 
       2.214402530300133}, {7.5992516015753955`, 2.214402530300133}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}}], 
      LineBox[{{7.663608688411636, 2.14497482286346}, {7.5992516015753955`, 
       2.214402530300133}, {7.5992516015753955`, 2.214402530300133}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}}], 
      LineBox[{{7.663608688411636, 2.14497482286346}, {7.5992516015753955`, 
       2.214402530300133}, {7.5992516015753955`, 2.214402530300133}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}}], 
      LineBox[{{7.5992516015753955`, 2.214402530300133}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}}], 
      LineBox[{{7.5992516015753955`, 2.214402530300133}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}}], 
      LineBox[{{7.5992516015753955`, 2.214402530300133}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}}], 
      LineBox[{{7.5992516015753955`, 2.214402530300133}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}}], 
      LineBox[{{7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}], 
      LineBox[{{7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}], 
      LineBox[{{7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}], 
      LineBox[{{7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}], 
      LineBox[{{7.5992516015753955`, 2.3532579451734787`}, {7.663608688411636,
        2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}}], 
      LineBox[{{7.5992516015753955`, 2.3532579451734787`}, {7.663608688411636,
        2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}}], 
      LineBox[{{7.5992516015753955`, 2.3532579451734787`}, {7.663608688411636,
        2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}}], 
      LineBox[{{7.5992516015753955`, 2.3532579451734787`}, {7.663608688411636,
        2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}], 
      LineBox[{{7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}], 
      LineBox[{{7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}], 
      LineBox[{{7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}], 
      LineBox[{{7.876165706929775, 2.193381511904724}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.876165706929775, 2.193381511904724}, {7.876165706929775, 
       2.193381511904724}}], 
      LineBox[{{7.876165706929775, 2.193381511904724}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.876165706929775, 2.193381511904724}, {7.876165706929775, 
       2.193381511904724}}], 
      LineBox[{{7.876165706929775, 2.193381511904724}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.876165706929775, 2.193381511904724}, {7.876165706929775, 
       2.193381511904724}}], 
      LineBox[{{7.876165706929775, 2.193381511904724}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.876165706929775, 2.193381511904724}, {7.876165706929775, 
       2.193381511904724}}], 
      LineBox[{{7.8239451107227636`, 2.14497482286346}, {7.7559133901964294`, 
       2.123953804468051}, {7.7559133901964294`, 2.123953804468051}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}}], 
      LineBox[{{7.8239451107227636`, 2.14497482286346}, {7.7559133901964294`, 
       2.123953804468051}, {7.7559133901964294`, 2.123953804468051}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}}], 
      LineBox[{{7.8239451107227636`, 2.14497482286346}, {7.7559133901964294`, 
       2.123953804468051}, {7.7559133901964294`, 2.123953804468051}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}}], 
      LineBox[{{7.8239451107227636`, 2.14497482286346}, {7.7559133901964294`, 
       2.123953804468051}, {7.7559133901964294`, 2.123953804468051}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}}], 
      LineBox[{{7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}}], 
      LineBox[{{7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}}], 
      LineBox[{{7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}}], 
      LineBox[{{7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`,
        2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}], 
      LineBox[{{7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`,
        2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}], 
      LineBox[{{7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`,
        2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}], 
      LineBox[{{7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`,
        2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}], 
      LineBox[{{7.7559133901964294`, 2.4437066710055606`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.7559133901964294`, 2.4437066710055606`}}], 
      LineBox[{{7.7559133901964294`, 2.4437066710055606`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.7559133901964294`, 2.4437066710055606`}}], 
      LineBox[{{7.7559133901964294`, 2.4437066710055606`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.7559133901964294`, 2.4437066710055606`}}], 
      LineBox[{{7.7559133901964294`, 2.4437066710055606`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.7559133901964294`, 2.4437066710055606`}}], 
      LineBox[{{7.8239451107227636`, 2.4226856526101517`}, {7.876165706929775,
        2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}}], 
      LineBox[{{7.8239451107227636`, 2.4226856526101517`}, {7.876165706929775,
        2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}}], 
      LineBox[{{7.8239451107227636`, 2.4226856526101517`}, {7.876165706929775,
        2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}}], 
      LineBox[{{7.8239451107227636`, 2.4226856526101517`}, {7.876165706929775,
        2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}}], 
      LineBox[{{7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.876165706929775, 
       2.3742789635688877`}}], 
      LineBox[{{7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.876165706929775, 
       2.3742789635688877`}}], 
      LineBox[{{7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.876165706929775, 
       2.3742789635688877`}}], 
      LineBox[{{7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.876165706929775, 
       2.3742789635688877`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.664080670570853, 2.6647525776017082`}, {7.606638887494376, 
       2.7267201324760033`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.8506552422245934`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}, {
       7.606638887494376, 2.8506552422245934`}, {7.592526701595459, 
       2.7886876873502984`}, {7.606638887494376, 2.7267201324760033`}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.807188608521643, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.807188608521643, 
       2.6647525776017082`}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.807188608521643, 2.9126227970988885`}, {
       7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.807188608521643, 
       2.9126227970988885`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.664080670570853, 2.6647525776017082`}, {7.606638887494376, 
       2.7267201324760033`}, {7.606638887494376, 2.7267201324760033`}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}}], 
      LineBox[{{7.664080670570853, 2.6647525776017082`}, {7.606638887494376, 
       2.7267201324760033`}, {7.606638887494376, 2.7267201324760033`}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}}], 
      LineBox[{{7.664080670570853, 2.6647525776017082`}, {7.606638887494376, 
       2.7267201324760033`}, {7.606638887494376, 2.7267201324760033`}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}}], 
      LineBox[{{7.664080670570853, 2.6647525776017082`}, {7.606638887494376, 
       2.7267201324760033`}, {7.606638887494376, 2.7267201324760033`}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}}], 
      LineBox[{{7.606638887494376, 2.7267201324760033`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}}], 
      LineBox[{{7.606638887494376, 2.7267201324760033`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}}], 
      LineBox[{{7.606638887494376, 2.7267201324760033`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}}], 
      LineBox[{{7.606638887494376, 2.7267201324760033`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}}], 
      LineBox[{{7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}], 
      LineBox[{{7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}], 
      LineBox[{{7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}], 
      LineBox[{{7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}], 
      LineBox[{{7.606638887494376, 2.8506552422245934`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}}], 
      LineBox[{{7.606638887494376, 2.8506552422245934`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}}], 
      LineBox[{{7.606638887494376, 2.8506552422245934`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}}], 
      LineBox[{{7.606638887494376, 2.8506552422245934`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}], 
      LineBox[{{7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}], 
      LineBox[{{7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}], 
      LineBox[{{7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}], 
      LineBox[{{7.85379799230373, 2.707957866530246}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.85379799230373, 2.707957866530246}, {7.85379799230373, 
       2.707957866530246}}], 
      LineBox[{{7.85379799230373, 2.707957866530246}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.85379799230373, 2.707957866530246}, {7.85379799230373, 
       2.707957866530246}}], 
      LineBox[{{7.85379799230373, 2.707957866530246}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.85379799230373, 2.707957866530246}, {7.85379799230373, 
       2.707957866530246}}], 
      LineBox[{{7.85379799230373, 2.707957866530246}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.85379799230373, 2.707957866530246}, {7.85379799230373, 
       2.707957866530246}}], 
      LineBox[{{7.807188608521643, 2.6647525776017082`}, {7.746467038840638, 
       2.645990311655951}, {7.746467038840638, 2.645990311655951}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}}], 
      LineBox[{{7.807188608521643, 2.6647525776017082`}, {7.746467038840638, 
       2.645990311655951}, {7.746467038840638, 2.645990311655951}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}}], 
      LineBox[{{7.807188608521643, 2.6647525776017082`}, {7.746467038840638, 
       2.645990311655951}, {7.746467038840638, 2.645990311655951}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}}], 
      LineBox[{{7.807188608521643, 2.6647525776017082`}, {7.746467038840638, 
       2.645990311655951}, {7.746467038840638, 2.645990311655951}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}}], 
      LineBox[{{7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}}], 
      LineBox[{{7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}}], 
      LineBox[{{7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}}], 
      LineBox[{{7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}], 
      LineBox[{{7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}], 
      LineBox[{{7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}], 
      LineBox[{{7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}], 
      LineBox[{{7.746467038840638, 2.9313850630446456`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}}], 
      LineBox[{{7.746467038840638, 2.9313850630446456`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}}], 
      LineBox[{{7.746467038840638, 2.9313850630446456`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}}], 
      LineBox[{{7.746467038840638, 2.9313850630446456`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}}], 
      LineBox[{{7.807188608521643, 2.9126227970988885`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}], 
      LineBox[{{7.807188608521643, 2.9126227970988885`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}], 
      LineBox[{{7.807188608521643, 2.9126227970988885`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}], 
      LineBox[{{7.807188608521643, 2.9126227970988885`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}], 
      LineBox[{{7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.85379799230373, 
       2.8694175081703506`}}], 
      LineBox[{{7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.85379799230373, 
       2.8694175081703506`}}], 
      LineBox[{{7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.85379799230373, 
       2.8694175081703506`}}], 
      LineBox[{{7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.85379799230373, 
       2.8694175081703506`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.655264752380455, 3.1259444234816263`}, {7.593448720964602, 
       3.192630868673848}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.326003759058291}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}, {
       7.593448720964602, 3.326003759058291}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.593448720964602, 3.192630868673848}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.809270500712569, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.809270500712569, 
       3.1259444234816263`}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.809270500712569, 3.3926902042505125`}, {
       7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.809270500712569, 
       3.3926902042505125`}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.655264752380455, 3.1259444234816263`}, {7.593448720964602, 
       3.192630868673848}, {7.593448720964602, 3.192630868673848}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}}], 
      LineBox[{{7.655264752380455, 3.1259444234816263`}, {7.593448720964602, 
       3.192630868673848}, {7.593448720964602, 3.192630868673848}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}}], 
      LineBox[{{7.655264752380455, 3.1259444234816263`}, {7.593448720964602, 
       3.192630868673848}, {7.593448720964602, 3.192630868673848}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}}], 
      LineBox[{{7.655264752380455, 3.1259444234816263`}, {7.593448720964602, 
       3.192630868673848}, {7.593448720964602, 3.192630868673848}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}}], 
      LineBox[{{7.593448720964602, 3.192630868673848}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}}], 
      LineBox[{{7.593448720964602, 3.192630868673848}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}}], 
      LineBox[{{7.593448720964602, 3.192630868673848}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}}], 
      LineBox[{{7.593448720964602, 3.192630868673848}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}}], 
      LineBox[{{7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602,
        3.326003759058291}, {7.593448720964602, 3.326003759058291}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}}], 
      LineBox[{{7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602,
        3.326003759058291}, {7.593448720964602, 3.326003759058291}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}}], 
      LineBox[{{7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602,
        3.326003759058291}, {7.593448720964602, 3.326003759058291}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}}], 
      LineBox[{{7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602,
        3.326003759058291}, {7.593448720964602, 3.326003759058291}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}}], 
      LineBox[{{7.593448720964602, 3.326003759058291}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}}], 
      LineBox[{{7.593448720964602, 3.326003759058291}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}}], 
      LineBox[{{7.593448720964602, 3.326003759058291}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}}], 
      LineBox[{{7.593448720964602, 3.326003759058291}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}], 
      LineBox[{{7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}], 
      LineBox[{{7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}], 
      LineBox[{{7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}], 
      LineBox[{{7.859429234962009, 3.172439837702693}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.859429234962009, 3.172439837702693}, {7.859429234962009, 
       3.172439837702693}}], 
      LineBox[{{7.859429234962009, 3.172439837702693}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.859429234962009, 3.172439837702693}, {7.859429234962009, 
       3.172439837702693}}], 
      LineBox[{{7.859429234962009, 3.172439837702693}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.859429234962009, 3.172439837702693}, {7.859429234962009, 
       3.172439837702693}}], 
      LineBox[{{7.859429234962009, 3.172439837702693}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.859429234962009, 3.172439837702693}, {7.859429234962009, 
       3.172439837702693}}], 
      LineBox[{{7.809270500712569, 3.1259444234816263`}, {7.743924923712924, 
       3.1057533925104717`}, {7.743924923712924, 3.1057533925104717`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}}], 
      LineBox[{{7.809270500712569, 3.1259444234816263`}, {7.743924923712924, 
       3.1057533925104717`}, {7.743924923712924, 3.1057533925104717`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}}], 
      LineBox[{{7.809270500712569, 3.1259444234816263`}, {7.743924923712924, 
       3.1057533925104717`}, {7.743924923712924, 3.1057533925104717`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}}], 
      LineBox[{{7.809270500712569, 3.1259444234816263`}, {7.743924923712924, 
       3.1057533925104717`}, {7.743924923712924, 3.1057533925104717`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}}], 
      LineBox[{{7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}}], 
      LineBox[{{7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}}], 
      LineBox[{{7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}}], 
      LineBox[{{7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}], 
      LineBox[{{7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}], 
      LineBox[{{7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}], 
      LineBox[{{7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}], 
      LineBox[{{7.743924923712924, 3.412881235221667}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}}], 
      LineBox[{{7.743924923712924, 3.412881235221667}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}}], 
      LineBox[{{7.743924923712924, 3.412881235221667}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}}], 
      LineBox[{{7.743924923712924, 3.412881235221667}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}}], 
      LineBox[{{7.809270500712569, 3.3926902042505125`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}], 
      LineBox[{{7.809270500712569, 3.3926902042505125`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}], 
      LineBox[{{7.809270500712569, 3.3926902042505125`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}], 
      LineBox[{{7.809270500712569, 3.3926902042505125`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}], 
      LineBox[{{7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.859429234962009, 
       3.3461947900294455`}}], 
      LineBox[{{7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.859429234962009, 
       3.3461947900294455`}}], 
      LineBox[{{7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.859429234962009, 
       3.3461947900294455`}}], 
      LineBox[{{7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.859429234962009, 
       3.3461947900294455`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.693697229417213, 3.6004977876752533`}, {7.628263807688373, 
       3.6710866331885676`}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.8122643242151963`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}, {
       7.628263807688373, 3.8122643242151963`}, {7.612188251499419, 
       3.741675478701882}, {7.628263807688373, 3.6710866331885676`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.856715185252801, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.856715185252801, 
       3.6004977876752533`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.856715185252801, 3.8828531697285107`}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594, 
       3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.856715185252801, 
       3.8828531697285107`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.693697229417213, 3.6004977876752533`}, {7.628263807688373, 
       3.6710866331885676`}, {7.628263807688373, 3.6710866331885676`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}}], 
      LineBox[{{7.693697229417213, 3.6004977876752533`}, {7.628263807688373, 
       3.6710866331885676`}, {7.628263807688373, 3.6710866331885676`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}}], 
      LineBox[{{7.693697229417213, 3.6004977876752533`}, {7.628263807688373, 
       3.6710866331885676`}, {7.628263807688373, 3.6710866331885676`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}}], 
      LineBox[{{7.693697229417213, 3.6004977876752533`}, {7.628263807688373, 
       3.6710866331885676`}, {7.628263807688373, 3.6710866331885676`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}}], 
      LineBox[{{7.628263807688373, 3.6710866331885676`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}}], 
      LineBox[{{7.628263807688373, 3.6710866331885676`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}}], 
      LineBox[{{7.628263807688373, 3.6710866331885676`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}}], 
      LineBox[{{7.628263807688373, 3.6710866331885676`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}}], 
      LineBox[{{7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}], 
      LineBox[{{7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}], 
      LineBox[{{7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}], 
      LineBox[{{7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}], 
      LineBox[{{7.628263807688373, 3.8122643242151963`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}}], 
      LineBox[{{7.628263807688373, 3.8122643242151963`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}}], 
      LineBox[{{7.628263807688373, 3.8122643242151963`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}}], 
      LineBox[{{7.628263807688373, 3.8122643242151963`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}], 
      LineBox[{{7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}], 
      LineBox[{{7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}], 
      LineBox[{{7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}], 
      LineBox[{{7.9098091405966695`, 3.6497140504715087`}, {7.856715185252801,
        3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.9098091405966695`, 
       3.6497140504715087`}}], 
      LineBox[{{7.9098091405966695`, 3.6497140504715087`}, {7.856715185252801,
        3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.9098091405966695`, 
       3.6497140504715087`}}], 
      LineBox[{{7.9098091405966695`, 3.6497140504715087`}, {7.856715185252801,
        3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.9098091405966695`, 
       3.6497140504715087`}}], 
      LineBox[{{7.9098091405966695`, 3.6497140504715087`}, {7.856715185252801,
        3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.9098091405966695`, 
       3.6497140504715087`}}], 
      LineBox[{{7.856715185252801, 3.6004977876752533`}, {7.787545673719978, 
       3.5791252049581943`}, {7.787545673719978, 3.5791252049581943`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}}], 
      LineBox[{{7.856715185252801, 3.6004977876752533`}, {7.787545673719978, 
       3.5791252049581943`}, {7.787545673719978, 3.5791252049581943`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}}], 
      LineBox[{{7.856715185252801, 3.6004977876752533`}, {7.787545673719978, 
       3.5791252049581943`}, {7.787545673719978, 3.5791252049581943`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}}], 
      LineBox[{{7.856715185252801, 3.6004977876752533`}, {7.787545673719978, 
       3.5791252049581943`}, {7.787545673719978, 3.5791252049581943`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}}], 
      LineBox[{{7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}}], 
      LineBox[{{7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}}], 
      LineBox[{{7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}}], 
      LineBox[{{7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}], 
      LineBox[{{7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}], 
      LineBox[{{7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}], 
      LineBox[{{7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}], 
      LineBox[{{7.787545673719978, 3.9042257524455697`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}}], 
      LineBox[{{7.787545673719978, 3.9042257524455697`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}}], 
      LineBox[{{7.787545673719978, 3.9042257524455697`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}}], 
      LineBox[{{7.787545673719978, 3.9042257524455697`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}}], 
      LineBox[{{7.856715185252801, 3.8828531697285107`}, {7.9098091405966695`,
        3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}], 
      LineBox[{{7.856715185252801, 3.8828531697285107`}, {7.9098091405966695`,
        3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}], 
      LineBox[{{7.856715185252801, 3.8828531697285107`}, {7.9098091405966695`,
        3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}], 
      LineBox[{{7.856715185252801, 3.8828531697285107`}, {7.9098091405966695`,
        3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}], 
      LineBox[{{7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594,
        3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.9098091405966695`, 
       3.8336369069322553`}}], 
      LineBox[{{7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594,
        3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.9098091405966695`, 
       3.8336369069322553`}}], 
      LineBox[{{7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594,
        3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.9098091405966695`, 
       3.8336369069322553`}}], 
      LineBox[{{7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594,
        3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.9098091405966695`, 
       3.8336369069322553`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       7.9976736607424375`, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}], 
      LineBox[{{7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}], 
      LineBox[{{7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}], 
      LineBox[{{7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}], 
      LineBox[{{7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}], 
      LineBox[{{7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}], 
      LineBox[{{7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}], 
      LineBox[{{7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}], 
      LineBox[{{7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}], 
      LineBox[{{7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}], 
      LineBox[{{7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}], 
      LineBox[{{7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}], 
      LineBox[{{7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}], 
      LineBox[{{7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}], 
      LineBox[{{7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}], 
      LineBox[{{7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}], 
      LineBox[{{8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}], 
      LineBox[{{8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}], 
      LineBox[{{8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}], 
      LineBox[{{8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}], 
      LineBox[{{8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}], 
      LineBox[{{8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}], 
      LineBox[{{8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}], 
      LineBox[{{8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}], 
      LineBox[{{8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}], 
      LineBox[{{8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}], 
      LineBox[{{8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}], 
      LineBox[{{7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}], 
      LineBox[{{7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}], 
      LineBox[{{7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}], 
      LineBox[{{7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}], 
      LineBox[{{7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}], 
      LineBox[{{7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}], 
      LineBox[{{7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}], 
      LineBox[{{7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}], 
      LineBox[{{7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}], 
      LineBox[{{7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}], 
      LineBox[{{7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}], 
      LineBox[{{8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}], 
      LineBox[{{8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}], 
      LineBox[{{8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}], 
      LineBox[{{8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}], 
      LineBox[{{8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}], 
      LineBox[{{8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}], 
      LineBox[{{8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}], 
      LineBox[{{8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}], 
      LineBox[{{7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}], 
      LineBox[{{7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}], 
      LineBox[{{7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}], 
      LineBox[{{7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}], 
      LineBox[{{7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}], 
      LineBox[{{7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}], 
      LineBox[{{7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}], 
      LineBox[{{7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}], 
      LineBox[{{7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}], 
      LineBox[{{7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}], 
      LineBox[{{7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}], 
      LineBox[{{7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}], 
      LineBox[{{7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}], 
      LineBox[{{7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}], 
      LineBox[{{7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}], 
      LineBox[{{8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}], 
      LineBox[{{8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}], 
      LineBox[{{8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}], 
      LineBox[{{8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}], 
      LineBox[{{8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}], 
      LineBox[{{8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}], 
      LineBox[{{8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}], 
      LineBox[{{8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}], 
      LineBox[{{8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}], 
      LineBox[{{8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}], 
      LineBox[{{8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}], 
      LineBox[{{8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}], 
      LineBox[{{8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}], 
      LineBox[{{8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}], 
      LineBox[{{8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}], 
      LineBox[{{7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}], 
      LineBox[{{7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}], 
      LineBox[{{7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}], 
      LineBox[{{8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}], 
      LineBox[{{8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}], 
      LineBox[{{8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}], 
      LineBox[{{8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}], 
      LineBox[{{8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}], 
      LineBox[{{8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}], 
      LineBox[{{8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}], 
      LineBox[{{8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}], 
      LineBox[{{8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}], 
      LineBox[{{8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}], 
      LineBox[{{8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}], 
      LineBox[{{8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}], 
      LineBox[{{7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}], 
      LineBox[{{7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}], 
      LineBox[{{7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}], 
      LineBox[{{7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}], 
      LineBox[{{7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}], 
      LineBox[{{7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}], 
      LineBox[{{7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}], 
      LineBox[{{7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}], 
      LineBox[{{7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}], 
      LineBox[{{7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}], 
      LineBox[{{7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}], 
      LineBox[{{7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}], 
      LineBox[{{7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}], 
      LineBox[{{7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}], 
      LineBox[{{7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}], 
      LineBox[{{8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}], 
      LineBox[{{8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}], 
      LineBox[{{8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}], 
      LineBox[{{8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}], 
      LineBox[{{8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}], 
      LineBox[{{8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}], 
      LineBox[{{8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}], 
      LineBox[{{8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}], 
      LineBox[{{8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}], 
      LineBox[{{8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}], 
      LineBox[{{8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}], 
      LineBox[{{8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}], 
      LineBox[{{8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}], 
      LineBox[{{8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}], 
      LineBox[{{8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}], 
      LineBox[{{7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}], 
      LineBox[{{7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}], 
      LineBox[{{7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}], 
      LineBox[{{8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}], 
      LineBox[{{8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}], 
      LineBox[{{8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}], 
      LineBox[{{8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}], 
      LineBox[{{8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}], 
      LineBox[{{8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}], 
      LineBox[{{8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}], 
      LineBox[{{8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}], 
      LineBox[{{8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}], 
      LineBox[{{8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}], 
      LineBox[{{8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}], 
      LineBox[{{8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}], 
      LineBox[{{7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}], 
      LineBox[{{7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}], 
      LineBox[{{7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}], 
      LineBox[{{7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}], 
      LineBox[{{7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}], 
      LineBox[{{7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}], 
      LineBox[{{7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}], 
      LineBox[{{7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}], 
      LineBox[{{7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}], 
      LineBox[{{7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}], 
      LineBox[{{7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}], 
      LineBox[{{7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}], 
      LineBox[{{7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}], 
      LineBox[{{7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}], 
      LineBox[{{7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}], 
      LineBox[{{8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}], 
      LineBox[{{8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}], 
      LineBox[{{8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}], 
      LineBox[{{8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}], 
      LineBox[{{8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}], 
      LineBox[{{8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}], 
      LineBox[{{8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}], 
      LineBox[{{8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}], 
      LineBox[{{8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}], 
      LineBox[{{8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}], 
      LineBox[{{8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}], 
      LineBox[{{8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}], 
      LineBox[{{8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}], 
      LineBox[{{8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}], 
      LineBox[{{8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}], 
      LineBox[{{7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}], 
      LineBox[{{7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}], 
      LineBox[{{7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}], 
      LineBox[{{8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}], 
      LineBox[{{8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}], 
      LineBox[{{8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}], 
      LineBox[{{8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}], 
      LineBox[{{8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}], 
      LineBox[{{8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}], 
      LineBox[{{8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}], 
      LineBox[{{8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}], 
      LineBox[{{8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}], 
      LineBox[{{8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}], 
      LineBox[{{8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}], 
      LineBox[{{8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}], 
      LineBox[{{7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}], 
      LineBox[{{7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}], 
      LineBox[{{7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}], 
      LineBox[{{7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}], 
      LineBox[{{7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}], 
      LineBox[{{7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}], 
      LineBox[{{7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}], 
      LineBox[{{7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}], 
      LineBox[{{7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}], 
      LineBox[{{7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}], 
      LineBox[{{7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}], 
      LineBox[{{7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}], 
      LineBox[{{7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}], 
      LineBox[{{7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}], 
      LineBox[{{7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}], 
      LineBox[{{8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}], 
      LineBox[{{8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}], 
      LineBox[{{8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}], 
      LineBox[{{8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}], 
      LineBox[{{8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}], 
      LineBox[{{8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}], 
      LineBox[{{8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}], 
      LineBox[{{8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}], 
      LineBox[{{8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}], 
      LineBox[{{8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}], 
      LineBox[{{8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}], 
      LineBox[{{7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}], 
      LineBox[{{7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}], 
      LineBox[{{7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}], 
      LineBox[{{7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}], 
      LineBox[{{7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}], 
      LineBox[{{7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}], 
      LineBox[{{7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}], 
      LineBox[{{7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}], 
      LineBox[{{7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}], 
      LineBox[{{7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}], 
      LineBox[{{7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}], 
      LineBox[{{8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}], 
      LineBox[{{8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}], 
      LineBox[{{8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}], 
      LineBox[{{8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}], 
      LineBox[{{8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}], 
      LineBox[{{8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}], 
      LineBox[{{8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}], 
      LineBox[{{8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}], 
      LineBox[{{7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}], 
      LineBox[{{7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}], 
      LineBox[{{7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}], 
      LineBox[{{7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}], 
      LineBox[{{7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}], 
      LineBox[{{7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}], 
      LineBox[{{7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}], 
      LineBox[{{7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}], 
      LineBox[{{7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}], 
      LineBox[{{7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}], 
      LineBox[{{7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}], 
      LineBox[{{7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}], 
      LineBox[{{7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}], 
      LineBox[{{7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}], 
      LineBox[{{7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}], 
      LineBox[{{8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}], 
      LineBox[{{8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}], 
      LineBox[{{8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}], 
      LineBox[{{8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}], 
      LineBox[{{8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}], 
      LineBox[{{8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}], 
      LineBox[{{8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}], 
      LineBox[{{8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}], 
      LineBox[{{8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}], 
      LineBox[{{8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}], 
      LineBox[{{8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}], 
      LineBox[{{8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}], 
      LineBox[{{8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}], 
      LineBox[{{8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}], 
      LineBox[{{8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}], 
      LineBox[{{7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}], 
      LineBox[{{7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}], 
      LineBox[{{7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}], 
      LineBox[{{8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}], 
      LineBox[{{8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}], 
      LineBox[{{8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}], 
      LineBox[{{8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}], 
      LineBox[{{8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}], 
      LineBox[{{8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}], 
      LineBox[{{8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}], 
      LineBox[{{8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}], 
      LineBox[{{8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}], 
      LineBox[{{8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}], 
      LineBox[{{8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}], 
      LineBox[{{8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}], 
      LineBox[{{7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}], 
      LineBox[{{7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}], 
      LineBox[{{7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}], 
      LineBox[{{7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}], 
      LineBox[{{7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}], 
      LineBox[{{7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}], 
      LineBox[{{7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}], 
      LineBox[{{7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}], 
      LineBox[{{7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}], 
      LineBox[{{7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}], 
      LineBox[{{7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}], 
      LineBox[{{7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}], 
      LineBox[{{7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}], 
      LineBox[{{7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}], 
      LineBox[{{7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}], 
      LineBox[{{8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}], 
      LineBox[{{8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}], 
      LineBox[{{8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}], 
      LineBox[{{8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}], 
      LineBox[{{8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}], 
      LineBox[{{8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}], 
      LineBox[{{8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}], 
      LineBox[{{8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}], 
      LineBox[{{8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}], 
      LineBox[{{8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}], 
      LineBox[{{8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}], 
      LineBox[{{8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}], 
      LineBox[{{8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}], 
      LineBox[{{8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}], 
      LineBox[{{8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}], 
      LineBox[{{7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}], 
      LineBox[{{7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}], 
      LineBox[{{7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}], 
      LineBox[{{8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}], 
      LineBox[{{8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}], 
      LineBox[{{8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}], 
      LineBox[{{8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}], 
      LineBox[{{8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}], 
      LineBox[{{8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}], 
      LineBox[{{8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}], 
      LineBox[{{8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}], 
      LineBox[{{8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}], 
      LineBox[{{8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}], 
      LineBox[{{8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}], 
      LineBox[{{8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}], 
      LineBox[{{7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}], 
      LineBox[{{7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}], 
      LineBox[{{7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}], 
      LineBox[{{7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}], 
      LineBox[{{7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}], 
      LineBox[{{7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}], 
      LineBox[{{7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}], 
      LineBox[{{7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}], 
      LineBox[{{7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}], 
      LineBox[{{7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}], 
      LineBox[{{7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}], 
      LineBox[{{7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}], 
      LineBox[{{7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}], 
      LineBox[{{7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}], 
      LineBox[{{7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}], 
      LineBox[{{8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}], 
      LineBox[{{8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}], 
      LineBox[{{8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}], 
      LineBox[{{8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}], 
      LineBox[{{8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}], 
      LineBox[{{8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}], 
      LineBox[{{8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}], 
      LineBox[{{8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}], 
      LineBox[{{8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}], 
      LineBox[{{8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}], 
      LineBox[{{8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}], 
      LineBox[{{8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}], 
      LineBox[{{8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}], 
      LineBox[{{8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}], 
      LineBox[{{8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}], 
      LineBox[{{7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}], 
      LineBox[{{7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}], 
      LineBox[{{7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}], 
      LineBox[{{8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}], 
      LineBox[{{8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}], 
      LineBox[{{8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}], 
      LineBox[{{8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}], 
      LineBox[{{8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}], 
      LineBox[{{8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}], 
      LineBox[{{8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}], 
      LineBox[{{8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}], 
      LineBox[{{8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}], 
      LineBox[{{8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}], 
      LineBox[{{8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}], 
      LineBox[{{8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804813, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}], 
      LineBox[{{7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}], 
      LineBox[{{7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}], 
      LineBox[{{7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}], 
      LineBox[{{7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}], 
      LineBox[{{7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}], 
      LineBox[{{7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}], 
      LineBox[{{7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}], 
      LineBox[{{7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}], 
      LineBox[{{7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}], 
      LineBox[{{7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}], 
      LineBox[{{7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}], 
      LineBox[{{7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}], 
      LineBox[{{7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}], 
      LineBox[{{7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}], 
      LineBox[{{7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}], 
      LineBox[{{8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}], 
      LineBox[{{8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}], 
      LineBox[{{8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}], 
      LineBox[{{8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}], 
      LineBox[{{8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}], 
      LineBox[{{8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}], 
      LineBox[{{8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}], 
      LineBox[{{8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}], 
      LineBox[{{8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}], 
      LineBox[{{8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}], 
      LineBox[{{8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}], 
      LineBox[{{7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}], 
      LineBox[{{7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}], 
      LineBox[{{7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}], 
      LineBox[{{7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}], 
      LineBox[{{7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}], 
      LineBox[{{7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}], 
      LineBox[{{7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}], 
      LineBox[{{7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}], 
      LineBox[{{7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}], 
      LineBox[{{7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}], 
      LineBox[{{7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}], 
      LineBox[{{8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}], 
      LineBox[{{8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}], 
      LineBox[{{8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}], 
      LineBox[{{8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}], 
      LineBox[{{8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}], 
      LineBox[{{8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}], 
      LineBox[{{8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}], 
      LineBox[{{8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {7.863071803395718, 
       0.054204351556651174`}, {7.926814382585178, 0.1229691349982274}, {
       7.926814382585178, 0.1229691349982274}, {7.863071803395718, 
       0.05420435155665115}, {7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650139}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807766`}, {
       7.926814382585178, -0.15208999876807766`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.926814382585178, 0.12296913499822743`}, {8.018237721526049, 
       0.14378943615825315`}, {8.08561984750822, 0.1229691349982274}, {
       8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925094`}, {
       8.16502257996974, -0.014560431884925094`}, {8.13734182021833, 
       0.07502465271667688}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {7.926814382585178, 
       0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}], 
      LineBox[{{7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}], 
      LineBox[{{7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}], 
      LineBox[{{7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}], 
      LineBox[{{7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}], 
      LineBox[{{7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}], 
      LineBox[{{7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}], 
      LineBox[{{7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}], 
      LineBox[{{7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, 0.05420435155665115}, {7.863071803395718, 
       0.05420435155665115}, {7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}], 
      LineBox[{{7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, 0.05420435155665115}, {7.863071803395718, 
       0.05420435155665115}, {7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}], 
      LineBox[{{7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, 0.05420435155665115}, {7.863071803395718, 
       0.05420435155665115}, {7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}], 
      LineBox[{{7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, 0.05420435155665115}, {7.863071803395718, 
       0.05420435155665115}, {7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}], 
      LineBox[{{7.863071803395718, 0.054204351556651174`}, {7.926814382585178,
        0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}, {
       7.863071803395718, 0.054204351556651174`}, {7.863071803395718, 
       0.054204351556651174`}}], 
      LineBox[{{7.863071803395718, 0.054204351556651174`}, {7.926814382585178,
        0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}, {
       7.863071803395718, 0.054204351556651174`}, {7.863071803395718, 
       0.054204351556651174`}}], 
      LineBox[{{7.863071803395718, 0.054204351556651174`}, {7.926814382585178,
        0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}, {
       7.863071803395718, 0.054204351556651174`}, {7.863071803395718, 
       0.054204351556651174`}}], 
      LineBox[{{7.863071803395718, 0.054204351556651174`}, {7.926814382585178,
        0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}, {
       7.863071803395718, 0.054204351556651174`}, {7.863071803395718, 
       0.054204351556651174`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}], 
      LineBox[{{8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}], 
      LineBox[{{8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}], 
      LineBox[{{8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}], 
      LineBox[{{8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}], 
      LineBox[{{8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}], 
      LineBox[{{8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}], 
      LineBox[{{8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}], 
      LineBox[{{8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}], 
      LineBox[{{8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}], 
      LineBox[{{8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}], 
      LineBox[{{8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}], 
      LineBox[{{8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}], 
      LineBox[{{8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}], 
      LineBox[{{8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}], 
      LineBox[{{8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.926814382585178, 0.12296913499822743`}, {8.018237721526049, 
       0.14378943615825315`}, {8.018237721526049, 0.14378943615825315`}, {
       7.926814382585178, 0.12296913499822743`}, {7.926814382585178, 
       0.12296913499822743`}}], 
      LineBox[{{7.926814382585178, 0.12296913499822743`}, {8.018237721526049, 
       0.14378943615825315`}, {8.018237721526049, 0.14378943615825315`}, {
       7.926814382585178, 0.12296913499822743`}, {7.926814382585178, 
       0.12296913499822743`}}], 
      LineBox[{{7.926814382585178, 0.12296913499822743`}, {8.018237721526049, 
       0.14378943615825315`}, {8.018237721526049, 0.14378943615825315`}, {
       7.926814382585178, 0.12296913499822743`}, {7.926814382585178, 
       0.12296913499822743`}}], 
      LineBox[{{7.926814382585178, 0.12296913499822743`}, {8.018237721526049, 
       0.14378943615825315`}, {8.018237721526049, 0.14378943615825315`}, {
       7.926814382585178, 0.12296913499822743`}, {7.926814382585178, 
       0.12296913499822743`}}], 
      LineBox[{{8.018237721526049, 0.14378943615825315`}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}}], 
      LineBox[{{8.018237721526049, 0.14378943615825315`}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}}], 
      LineBox[{{8.018237721526049, 0.14378943615825315`}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}}], 
      LineBox[{{8.018237721526049, 0.14378943615825315`}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}}], 
      LineBox[{{8.08561984750822, 0.1229691349982274}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}], 
      LineBox[{{8.08561984750822, 0.1229691349982274}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}], 
      LineBox[{{8.08561984750822, 0.1229691349982274}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}], 
      LineBox[{{8.08561984750822, 0.1229691349982274}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}], 
      LineBox[{{8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}], 
      LineBox[{{8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}], 
      LineBox[{{8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}], 
      LineBox[{{8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393822}, {7.9355805510604105`, 0.6555045023393822}, {
       7.868670330282623, 0.5833225024843558}, {7.852231956966521, 
       0.5111405026293293}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.41710355173542646`}, {8.10227773924819, 0.3667765029192764}, {
       8.031547107019723, 0.34492155188039997`}, {7.9355805510604105`, 
       0.3667765029192763}, {7.9355805510604105`, 0.3667765029192763}, {
       8.031547107019723, 0.34492155188039997`}, {8.10227773924819, 
       0.3667765029192764}, {8.156569998160558, 0.41710355173542646`}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9355805510604105`, 0.6555045023393823}, {8.031547107019723, 
       0.6773594533782586}, {8.10227773924819, 0.6555045023393822}, {
       8.156569998160558, 0.6051774535232322}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.6051774535232322}, {8.10227773924819, 
       0.6555045023393822}, {8.031547107019723, 0.6773594533782586}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}], 
      LineBox[{{7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}], 
      LineBox[{{7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}], 
      LineBox[{{7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}], 
      LineBox[{{7.868670330282623, 0.4389585027743028}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.4389585027743028}, {7.868670330282623, 
       0.4389585027743028}}], 
      LineBox[{{7.868670330282623, 0.4389585027743028}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.4389585027743028}, {7.868670330282623, 
       0.4389585027743028}}], 
      LineBox[{{7.868670330282623, 0.4389585027743028}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.4389585027743028}, {7.868670330282623, 
       0.4389585027743028}}], 
      LineBox[{{7.868670330282623, 0.4389585027743028}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.4389585027743028}, {7.868670330282623, 
       0.4389585027743028}}], 
      LineBox[{{7.852231956966521, 0.5111405026293293}, {7.868670330282623, 
       0.5833225024843558}, {7.868670330282623, 0.5833225024843558}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}}], 
      LineBox[{{7.852231956966521, 0.5111405026293293}, {7.868670330282623, 
       0.5833225024843558}, {7.868670330282623, 0.5833225024843558}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}}], 
      LineBox[{{7.852231956966521, 0.5111405026293293}, {7.868670330282623, 
       0.5833225024843558}, {7.868670330282623, 0.5833225024843558}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}}], 
      LineBox[{{7.852231956966521, 0.5111405026293293}, {7.868670330282623, 
       0.5833225024843558}, {7.868670330282623, 0.5833225024843558}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}}], 
      LineBox[{{7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}}], 
      LineBox[{{7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}}], 
      LineBox[{{7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}}], 
      LineBox[{{7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}}], 
      LineBox[{{8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}}], 
      LineBox[{{8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}}], 
      LineBox[{{8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}}], 
      LineBox[{{8.156569998160558, 0.41710355173542646`}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}}], 
      LineBox[{{8.156569998160558, 0.41710355173542646`}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}}], 
      LineBox[{{8.156569998160558, 0.41710355173542646`}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}}], 
      LineBox[{{8.156569998160558, 0.41710355173542646`}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}}], 
      LineBox[{{8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}], 
      LineBox[{{8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}], 
      LineBox[{{8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}], 
      LineBox[{{8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}], 
      LineBox[{{8.031547107019723, 0.34492155188039997`}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}}], 
      LineBox[{{8.031547107019723, 0.34492155188039997`}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}}], 
      LineBox[{{8.031547107019723, 0.34492155188039997`}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}}], 
      LineBox[{{8.031547107019723, 0.34492155188039997`}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9355805510604105`, 0.6555045023393823}, {8.031547107019723, 
       0.6773594533782586}, {8.031547107019723, 0.6773594533782586}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}}], 
      LineBox[{{7.9355805510604105`, 0.6555045023393823}, {8.031547107019723, 
       0.6773594533782586}, {8.031547107019723, 0.6773594533782586}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}}], 
      LineBox[{{7.9355805510604105`, 0.6555045023393823}, {8.031547107019723, 
       0.6773594533782586}, {8.031547107019723, 0.6773594533782586}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}}], 
      LineBox[{{7.9355805510604105`, 0.6555045023393823}, {8.031547107019723, 
       0.6773594533782586}, {8.031547107019723, 0.6773594533782586}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}}], 
      LineBox[{{8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}}], 
      LineBox[{{8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}}], 
      LineBox[{{8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}}], 
      LineBox[{{8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}}], 
      LineBox[{{8.10227773924819, 0.6555045023393822}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}}], 
      LineBox[{{8.10227773924819, 0.6555045023393822}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}}], 
      LineBox[{{8.10227773924819, 0.6555045023393822}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}}], 
      LineBox[{{8.10227773924819, 0.6555045023393822}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}}], 
      LineBox[{{8.156569998160558, 0.6051774535232322}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}}], 
      LineBox[{{8.156569998160558, 0.6051774535232322}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}}], 
      LineBox[{{8.156569998160558, 0.6051774535232322}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}}], 
      LineBox[{{8.156569998160558, 0.6051774535232322}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.866596322918788, 
       1.043764089413193}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       0.9510147970916263}, {8.113218200108143, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {7.9488036153152395`, 
       0.9013768822298682}, {7.9488036153152395`, 0.9013768822298682}, {
       8.043456090402469, 0.8798211934999639}, {8.113218200108143, 
       0.9013768822298683}, {8.166767028997146, 0.9510147970916263}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9488036153152395`, 1.1861512965965177`}, {8.043456090402469,
        1.2077069853264222`}, {8.113218200108143, 1.1861512965965177`}, {
       8.166767028997146, 1.1365133817347597`}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 1.1365133817347597`}, {8.113218200108143, 
       1.1861512965965177`}, {8.043456090402469, 1.2077069853264222`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}], 
      LineBox[{{7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}], 
      LineBox[{{7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}], 
      LineBox[{{7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}], 
      LineBox[{{7.882809603735457, 0.9725704858215306}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 0.9725704858215306}, {7.882809603735457, 
       0.9725704858215306}}], 
      LineBox[{{7.882809603735457, 0.9725704858215306}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 0.9725704858215306}, {7.882809603735457, 
       0.9725704858215306}}], 
      LineBox[{{7.882809603735457, 0.9725704858215306}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 0.9725704858215306}, {7.882809603735457, 
       0.9725704858215306}}], 
      LineBox[{{7.882809603735457, 0.9725704858215306}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 0.9725704858215306}, {7.882809603735457, 
       0.9725704858215306}}], 
      LineBox[{{7.866596322918788, 1.043764089413193}, {7.882809603735457, 
       1.1149576930048553`}, {7.882809603735457, 1.1149576930048553`}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}}], 
      LineBox[{{7.866596322918788, 1.043764089413193}, {7.882809603735457, 
       1.1149576930048553`}, {7.882809603735457, 1.1149576930048553`}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}}], 
      LineBox[{{7.866596322918788, 1.043764089413193}, {7.882809603735457, 
       1.1149576930048553`}, {7.882809603735457, 1.1149576930048553`}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}}], 
      LineBox[{{7.866596322918788, 1.043764089413193}, {7.882809603735457, 
       1.1149576930048553`}, {7.882809603735457, 1.1149576930048553`}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}}], 
      LineBox[{{7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`,
        1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}}], 
      LineBox[{{7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`,
        1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}}], 
      LineBox[{{7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`,
        1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}}], 
      LineBox[{{7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`,
        1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}}], 
      LineBox[{{8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}}], 
      LineBox[{{8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}}], 
      LineBox[{{8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}}], 
      LineBox[{{8.166767028997146, 0.9510147970916263}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}}], 
      LineBox[{{8.166767028997146, 0.9510147970916263}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}}], 
      LineBox[{{8.166767028997146, 0.9510147970916263}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}}], 
      LineBox[{{8.166767028997146, 0.9510147970916263}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}}], 
      LineBox[{{8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}], 
      LineBox[{{8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}], 
      LineBox[{{8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}], 
      LineBox[{{8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}], 
      LineBox[{{8.043456090402469, 0.8798211934999639}, {7.9488036153152395`, 
       0.9013768822298683}, {7.9488036153152395`, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {8.043456090402469, 
       0.8798211934999639}}], 
      LineBox[{{8.043456090402469, 0.8798211934999639}, {7.9488036153152395`, 
       0.9013768822298683}, {7.9488036153152395`, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {8.043456090402469, 
       0.8798211934999639}}], 
      LineBox[{{8.043456090402469, 0.8798211934999639}, {7.9488036153152395`, 
       0.9013768822298683}, {7.9488036153152395`, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {8.043456090402469, 
       0.8798211934999639}}], 
      LineBox[{{8.043456090402469, 0.8798211934999639}, {7.9488036153152395`, 
       0.9013768822298683}, {7.9488036153152395`, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {8.043456090402469, 
       0.8798211934999639}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9488036153152395`, 1.1861512965965177`}, {8.043456090402469,
        1.2077069853264222`}, {8.043456090402469, 1.2077069853264222`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}}], 
      LineBox[{{7.9488036153152395`, 1.1861512965965177`}, {8.043456090402469,
        1.2077069853264222`}, {8.043456090402469, 1.2077069853264222`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}}], 
      LineBox[{{7.9488036153152395`, 1.1861512965965177`}, {8.043456090402469,
        1.2077069853264222`}, {8.043456090402469, 1.2077069853264222`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}}], 
      LineBox[{{7.9488036153152395`, 1.1861512965965177`}, {8.043456090402469,
        1.2077069853264222`}, {8.043456090402469, 1.2077069853264222`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}}], 
      LineBox[{{8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}}], 
      LineBox[{{8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}}], 
      LineBox[{{8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}}], 
      LineBox[{{8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}}], 
      LineBox[{{8.113218200108143, 1.1861512965965177`}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}}], 
      LineBox[{{8.113218200108143, 1.1861512965965177`}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}}], 
      LineBox[{{8.113218200108143, 1.1861512965965177`}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}}], 
      LineBox[{{8.113218200108143, 1.1861512965965177`}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}}], 
      LineBox[{{8.166767028997146, 1.1365133817347597`}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}}], 
      LineBox[{{8.166767028997146, 1.1365133817347597`}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}}], 
      LineBox[{{8.166767028997146, 1.1365133817347597`}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}}], 
      LineBox[{{8.166767028997146, 1.1365133817347597`}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`,
        1.404466680805723}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.847350158338827, 
       1.463746232324767}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.3865182767900777`}, {8.052700548500589, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {8.052700548500589, 
       1.3451871292866786`}, {8.097288129417507, 1.3865182767900777`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.915800288392748, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {8.052700548500589, 1.5823053353628553`}, {
       8.097288129417507, 1.5409741878594563`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.5409741878594563`}, {8.052700548500589, 
       1.5823053353628553`}, {7.994612934336626, 1.6002537393785006`}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`,
        1.404466680805723}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}], 
      LineBox[{{7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`,
        1.404466680805723}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}], 
      LineBox[{{7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`,
        1.404466680805723}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}], 
      LineBox[{{7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`,
        1.404466680805723}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}], 
      LineBox[{{7.8608501915858735`, 1.404466680805723}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.404466680805723}, {7.8608501915858735`, 
       1.404466680805723}}], 
      LineBox[{{7.8608501915858735`, 1.404466680805723}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.404466680805723}, {7.8608501915858735`, 
       1.404466680805723}}], 
      LineBox[{{7.8608501915858735`, 1.404466680805723}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.404466680805723}, {7.8608501915858735`, 
       1.404466680805723}}], 
      LineBox[{{7.8608501915858735`, 1.404466680805723}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.404466680805723}, {7.8608501915858735`, 
       1.404466680805723}}], 
      LineBox[{{7.847350158338827, 1.463746232324767}, {7.8608501915858735`, 
       1.523025783843811}, {7.8608501915858735`, 1.523025783843811}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}}], 
      LineBox[{{7.847350158338827, 1.463746232324767}, {7.8608501915858735`, 
       1.523025783843811}, {7.8608501915858735`, 1.523025783843811}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}}], 
      LineBox[{{7.847350158338827, 1.463746232324767}, {7.8608501915858735`, 
       1.523025783843811}, {7.8608501915858735`, 1.523025783843811}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}}], 
      LineBox[{{7.847350158338827, 1.463746232324767}, {7.8608501915858735`, 
       1.523025783843811}, {7.8608501915858735`, 1.523025783843811}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}}], 
      LineBox[{{7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}}], 
      LineBox[{{7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}}], 
      LineBox[{{7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}}], 
      LineBox[{{7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}}], 
      LineBox[{{8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}}], 
      LineBox[{{8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}}], 
      LineBox[{{8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}}], 
      LineBox[{{8.097288129417507, 1.3865182767900777`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}}], 
      LineBox[{{8.097288129417507, 1.3865182767900777`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}}], 
      LineBox[{{8.097288129417507, 1.3865182767900777`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}}], 
      LineBox[{{8.097288129417507, 1.3865182767900777`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}}], 
      LineBox[{{8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}], 
      LineBox[{{8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}], 
      LineBox[{{8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}], 
      LineBox[{{8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}], 
      LineBox[{{7.994612934336626, 1.3272387252710334`}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.994612934336626, 
       1.3272387252710334`}}], 
      LineBox[{{7.994612934336626, 1.3272387252710334`}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.994612934336626, 
       1.3272387252710334`}}], 
      LineBox[{{7.994612934336626, 1.3272387252710334`}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.994612934336626, 
       1.3272387252710334`}}], 
      LineBox[{{7.994612934336626, 1.3272387252710334`}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.994612934336626, 
       1.3272387252710334`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.915800288392748, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.994612934336626, 1.6002537393785006`}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}}], 
      LineBox[{{7.915800288392748, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.994612934336626, 1.6002537393785006`}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}}], 
      LineBox[{{7.915800288392748, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.994612934336626, 1.6002537393785006`}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}}], 
      LineBox[{{7.915800288392748, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.994612934336626, 1.6002537393785006`}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}}], 
      LineBox[{{7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}}], 
      LineBox[{{7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}}], 
      LineBox[{{7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}}], 
      LineBox[{{7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}}], 
      LineBox[{{8.052700548500589, 1.5823053353628553`}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}}], 
      LineBox[{{8.052700548500589, 1.5823053353628553`}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}}], 
      LineBox[{{8.052700548500589, 1.5823053353628553`}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}}], 
      LineBox[{{8.052700548500589, 1.5823053353628553`}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}}], 
      LineBox[{{8.097288129417507, 1.5409741878594563`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}}], 
      LineBox[{{8.097288129417507, 1.5409741878594563`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}}], 
      LineBox[{{8.097288129417507, 1.5409741878594563`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}}], 
      LineBox[{{8.097288129417507, 1.5409741878594563`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.899837626166705, 
       1.9584664909151566`}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       1.8784669910243939`}, {8.112557597860567, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.112557597860567, 
       1.8356525579956955`}, {8.158745330657535, 1.8784669910243939`}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.970744283397993, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.112557597860567, 2.0812804238346176`}, {
       8.158745330657535, 2.038465990805919}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 2.038465990805919}, {8.112557597860567, 
       2.0812804238346176`}, {8.052385344810604, 2.09987295726565}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}], 
      LineBox[{{7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}], 
      LineBox[{{7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}], 
      LineBox[{{7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}], 
      LineBox[{{7.913822146419702, 1.897059524455426}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 1.897059524455426}, {7.913822146419702, 
       1.897059524455426}}], 
      LineBox[{{7.913822146419702, 1.897059524455426}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 1.897059524455426}, {7.913822146419702, 
       1.897059524455426}}], 
      LineBox[{{7.913822146419702, 1.897059524455426}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 1.897059524455426}, {7.913822146419702, 
       1.897059524455426}}], 
      LineBox[{{7.913822146419702, 1.897059524455426}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 1.897059524455426}, {7.913822146419702, 
       1.897059524455426}}], 
      LineBox[{{7.899837626166705, 1.9584664909151566`}, {7.913822146419702, 
       2.019873457374887}, {7.913822146419702, 2.019873457374887}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}}], 
      LineBox[{{7.899837626166705, 1.9584664909151566`}, {7.913822146419702, 
       2.019873457374887}, {7.913822146419702, 2.019873457374887}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}}], 
      LineBox[{{7.899837626166705, 1.9584664909151566`}, {7.913822146419702, 
       2.019873457374887}, {7.913822146419702, 2.019873457374887}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}}], 
      LineBox[{{7.899837626166705, 1.9584664909151566`}, {7.913822146419702, 
       2.019873457374887}, {7.913822146419702, 2.019873457374887}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}}], 
      LineBox[{{7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}}], 
      LineBox[{{7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}}], 
      LineBox[{{7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}}], 
      LineBox[{{7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}}], 
      LineBox[{{8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}}], 
      LineBox[{{8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}}], 
      LineBox[{{8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}}], 
      LineBox[{{8.158745330657535, 1.8784669910243939`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}}], 
      LineBox[{{8.158745330657535, 1.8784669910243939`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}}], 
      LineBox[{{8.158745330657535, 1.8784669910243939`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}}], 
      LineBox[{{8.158745330657535, 1.8784669910243939`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}}], 
      LineBox[{{8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}], 
      LineBox[{{8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}], 
      LineBox[{{8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}], 
      LineBox[{{8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}], 
      LineBox[{{8.052385344810604, 1.8170600245646633`}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.052385344810604, 
       1.8170600245646633`}}], 
      LineBox[{{8.052385344810604, 1.8170600245646633`}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.052385344810604, 
       1.8170600245646633`}}], 
      LineBox[{{8.052385344810604, 1.8170600245646633`}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.052385344810604, 
       1.8170600245646633`}}], 
      LineBox[{{8.052385344810604, 1.8170600245646633`}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.052385344810604, 
       1.8170600245646633`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.970744283397993, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.052385344810604, 2.09987295726565}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}}], 
      LineBox[{{7.970744283397993, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.052385344810604, 2.09987295726565}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}}], 
      LineBox[{{7.970744283397993, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.052385344810604, 2.09987295726565}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}}], 
      LineBox[{{7.970744283397993, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.052385344810604, 2.09987295726565}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}}], 
      LineBox[{{8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}}], 
      LineBox[{{8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}}], 
      LineBox[{{8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}}], 
      LineBox[{{8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}}], 
      LineBox[{{8.112557597860567, 2.0812804238346176`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}}], 
      LineBox[{{8.112557597860567, 2.0812804238346176`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}}], 
      LineBox[{{8.112557597860567, 2.0812804238346176`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}}], 
      LineBox[{{8.112557597860567, 2.0812804238346176`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}}], 
      LineBox[{{8.158745330657535, 2.038465990805919}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}}], 
      LineBox[{{8.158745330657535, 2.038465990805919}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}}], 
      LineBox[{{8.158745330657535, 2.038465990805919}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}}], 
      LineBox[{{8.158745330657535, 2.038465990805919}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9294845227575665`, 2.3384155489917986`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.853774181511164, 
       2.4695497066889445`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.384130513727771}, {8.080905205250371, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {7.9294845227575665`, 
       2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.080905205250371, 
       2.3384155489917986`}, {8.130221999300465, 2.384130513727771}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9294845227575665`, 2.6006838643860903`}, {8.016656487430861,
        2.6205359784986912`}, {8.080905205250371, 2.6006838643860903`}, {
       8.130221999300465, 2.554968899650118}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.554968899650118}, {8.080905205250371, 
       2.6006838643860903`}, {8.016656487430861, 2.6205359784986912`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9294845227575665`, 2.3384155489917986`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}}], 
      LineBox[{{7.9294845227575665`, 2.3384155489917986`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}}], 
      LineBox[{{7.9294845227575665`, 2.3384155489917986`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}}], 
      LineBox[{{7.9294845227575665`, 2.3384155489917986`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}}], 
      LineBox[{{7.8687061052805785`, 2.4039826278403713`}, {7.853774181511164,
        2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}}], 
      LineBox[{{7.8687061052805785`, 2.4039826278403713`}, {7.853774181511164,
        2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}}], 
      LineBox[{{7.8687061052805785`, 2.4039826278403713`}, {7.853774181511164,
        2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}}], 
      LineBox[{{7.8687061052805785`, 2.4039826278403713`}, {7.853774181511164,
        2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}}], 
      LineBox[{{7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`,
        2.5351167855375176`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}}], 
      LineBox[{{7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`,
        2.5351167855375176`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}}], 
      LineBox[{{7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`,
        2.5351167855375176`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}}], 
      LineBox[{{7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`,
        2.5351167855375176`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}}], 
      LineBox[{{7.8687061052805785`, 2.5351167855375176`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}}], 
      LineBox[{{7.8687061052805785`, 2.5351167855375176`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}}], 
      LineBox[{{7.8687061052805785`, 2.5351167855375176`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}}], 
      LineBox[{{7.8687061052805785`, 2.5351167855375176`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}}], 
      LineBox[{{8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}}], 
      LineBox[{{8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}}], 
      LineBox[{{8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}}], 
      LineBox[{{8.130221999300465, 2.384130513727771}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}}], 
      LineBox[{{8.130221999300465, 2.384130513727771}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}}], 
      LineBox[{{8.130221999300465, 2.384130513727771}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}}], 
      LineBox[{{8.130221999300465, 2.384130513727771}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}}], 
      LineBox[{{8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}], 
      LineBox[{{8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}], 
      LineBox[{{8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}], 
      LineBox[{{8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}], 
      LineBox[{{8.016656487430861, 2.3185634348791977`}, {7.9294845227575665`,
        2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.016656487430861, 
       2.3185634348791977`}}], 
      LineBox[{{8.016656487430861, 2.3185634348791977`}, {7.9294845227575665`,
        2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.016656487430861, 
       2.3185634348791977`}}], 
      LineBox[{{8.016656487430861, 2.3185634348791977`}, {7.9294845227575665`,
        2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.016656487430861, 
       2.3185634348791977`}}], 
      LineBox[{{8.016656487430861, 2.3185634348791977`}, {7.9294845227575665`,
        2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.016656487430861, 
       2.3185634348791977`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.9294845227575665`, 2.6006838643860903`}, {8.016656487430861,
        2.6205359784986912`}, {8.016656487430861, 2.6205359784986912`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}}], 
      LineBox[{{7.9294845227575665`, 2.6006838643860903`}, {8.016656487430861,
        2.6205359784986912`}, {8.016656487430861, 2.6205359784986912`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}}], 
      LineBox[{{7.9294845227575665`, 2.6006838643860903`}, {8.016656487430861,
        2.6205359784986912`}, {8.016656487430861, 2.6205359784986912`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}}], 
      LineBox[{{7.9294845227575665`, 2.6006838643860903`}, {8.016656487430861,
        2.6205359784986912`}, {8.016656487430861, 2.6205359784986912`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}}], 
      LineBox[{{8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}}], 
      LineBox[{{8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}}], 
      LineBox[{{8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}}], 
      LineBox[{{8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}}], 
      LineBox[{{8.080905205250371, 2.6006838643860903`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}}], 
      LineBox[{{8.080905205250371, 2.6006838643860903`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}}], 
      LineBox[{{8.080905205250371, 2.6006838643860903`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}}], 
      LineBox[{{8.080905205250371, 2.6006838643860903`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}}], 
      LineBox[{{8.130221999300465, 2.554968899650118}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}}], 
      LineBox[{{8.130221999300465, 2.554968899650118}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}}], 
      LineBox[{{8.130221999300465, 2.554968899650118}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}}], 
      LineBox[{{8.130221999300465, 2.554968899650118}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.841089024788153, 
       3.038135878738669}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       2.9511825952472925`}, {8.07229922020476, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.07229922020476, 
       2.9046466101755053`}, {8.122501721835429, 2.9511825952472925`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.918159089927022, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.07229922020476, 3.1716251473018326`}, {
       8.122501721835429, 3.1250891622300454`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 3.1250891622300454`}, {8.07229922020476, 
       3.1716251473018326`}, {8.006896624127124, 3.1918337965116272`}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}], 
      LineBox[{{7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}], 
      LineBox[{{7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}], 
      LineBox[{{7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}], 
      LineBox[{{7.85628911923512, 2.971391244457087}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 2.971391244457087}, {7.85628911923512, 
       2.971391244457087}}], 
      LineBox[{{7.85628911923512, 2.971391244457087}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 2.971391244457087}, {7.85628911923512, 
       2.971391244457087}}], 
      LineBox[{{7.85628911923512, 2.971391244457087}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 2.971391244457087}, {7.85628911923512, 
       2.971391244457087}}], 
      LineBox[{{7.85628911923512, 2.971391244457087}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 2.971391244457087}, {7.85628911923512, 
       2.971391244457087}}], 
      LineBox[{{7.841089024788153, 3.038135878738669}, {7.85628911923512, 
       3.104880513020251}, {7.85628911923512, 3.104880513020251}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}}], 
      LineBox[{{7.841089024788153, 3.038135878738669}, {7.85628911923512, 
       3.104880513020251}, {7.85628911923512, 3.104880513020251}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}}], 
      LineBox[{{7.841089024788153, 3.038135878738669}, {7.85628911923512, 
       3.104880513020251}, {7.85628911923512, 3.104880513020251}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}}], 
      LineBox[{{7.841089024788153, 3.038135878738669}, {7.85628911923512, 
       3.104880513020251}, {7.85628911923512, 3.104880513020251}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}}], 
      LineBox[{{7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}}], 
      LineBox[{{7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}}], 
      LineBox[{{7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}}], 
      LineBox[{{7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}}], 
      LineBox[{{8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}}], 
      LineBox[{{8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}}], 
      LineBox[{{8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}}], 
      LineBox[{{8.122501721835429, 2.9511825952472925`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}}], 
      LineBox[{{8.122501721835429, 2.9511825952472925`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}}], 
      LineBox[{{8.122501721835429, 2.9511825952472925`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}}], 
      LineBox[{{8.122501721835429, 2.9511825952472925`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}}], 
      LineBox[{{8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}], 
      LineBox[{{8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}], 
      LineBox[{{8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}], 
      LineBox[{{8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}], 
      LineBox[{{8.006896624127124, 2.8844379609657107`}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.006896624127124, 
       2.8844379609657107`}}], 
      LineBox[{{8.006896624127124, 2.8844379609657107`}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.006896624127124, 
       2.8844379609657107`}}], 
      LineBox[{{8.006896624127124, 2.8844379609657107`}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.006896624127124, 
       2.8844379609657107`}}], 
      LineBox[{{8.006896624127124, 2.8844379609657107`}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.006896624127124, 
       2.8844379609657107`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.918159089927022, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.006896624127124, 3.1918337965116272`}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}}], 
      LineBox[{{7.918159089927022, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.006896624127124, 3.1918337965116272`}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}}], 
      LineBox[{{7.918159089927022, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.006896624127124, 3.1918337965116272`}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}}], 
      LineBox[{{7.918159089927022, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.006896624127124, 3.1918337965116272`}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}}], 
      LineBox[{{8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}}], 
      LineBox[{{8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}}], 
      LineBox[{{8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}}], 
      LineBox[{{8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}}], 
      LineBox[{{8.07229922020476, 3.1716251473018326`}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}}], 
      LineBox[{{8.07229922020476, 3.1716251473018326`}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}}], 
      LineBox[{{8.07229922020476, 3.1716251473018326`}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}}], 
      LineBox[{{8.07229922020476, 3.1716251473018326`}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}}], 
      LineBox[{{8.122501721835429, 3.1250891622300454`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}}], 
      LineBox[{{8.122501721835429, 3.1250891622300454`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}}], 
      LineBox[{{8.122501721835429, 3.1250891622300454`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}}], 
      LineBox[{{8.122501721835429, 3.1250891622300454`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.814945896958113, 
       3.486354596462882}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.394393168232509}, {8.059472830711494, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {8.059472830711494, 
       3.3451769054362535`}, {8.112566786055362, 3.394393168232509}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.896454874875906, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {8.059472830711494, 3.627532287489511}, {
       8.112566786055362, 3.5783160246932555`}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.5783160246932555`}, {8.059472830711494, 
       3.627532287489511}, {7.990303319178672, 3.64890487020657}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}], 
      LineBox[{{7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}], 
      LineBox[{{7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}], 
      LineBox[{{7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}], 
      LineBox[{{7.831021453147066, 3.415765750949568}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.415765750949568}, {7.831021453147066, 
       3.415765750949568}}], 
      LineBox[{{7.831021453147066, 3.415765750949568}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.415765750949568}, {7.831021453147066, 
       3.415765750949568}}], 
      LineBox[{{7.831021453147066, 3.415765750949568}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.415765750949568}, {7.831021453147066, 
       3.415765750949568}}], 
      LineBox[{{7.831021453147066, 3.415765750949568}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.415765750949568}, {7.831021453147066, 
       3.415765750949568}}], 
      LineBox[{{7.814945896958113, 3.486354596462882}, {7.831021453147066, 
       3.5569434419761965`}, {7.831021453147066, 3.5569434419761965`}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}}], 
      LineBox[{{7.814945896958113, 3.486354596462882}, {7.831021453147066, 
       3.5569434419761965`}, {7.831021453147066, 3.5569434419761965`}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}}], 
      LineBox[{{7.814945896958113, 3.486354596462882}, {7.831021453147066, 
       3.5569434419761965`}, {7.831021453147066, 3.5569434419761965`}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}}], 
      LineBox[{{7.814945896958113, 3.486354596462882}, {7.831021453147066, 
       3.5569434419761965`}, {7.831021453147066, 3.5569434419761965`}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}}], 
      LineBox[{{7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}}], 
      LineBox[{{7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}}], 
      LineBox[{{7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}}], 
      LineBox[{{7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}}], 
      LineBox[{{8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}}], 
      LineBox[{{8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}}], 
      LineBox[{{8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}}], 
      LineBox[{{8.112566786055362, 3.394393168232509}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}}], 
      LineBox[{{8.112566786055362, 3.394393168232509}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}}], 
      LineBox[{{8.112566786055362, 3.394393168232509}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}}], 
      LineBox[{{8.112566786055362, 3.394393168232509}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}}], 
      LineBox[{{8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}], 
      LineBox[{{8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}], 
      LineBox[{{8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}], 
      LineBox[{{8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}], 
      LineBox[{{7.990303319178672, 3.3238043227191945`}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.990303319178672, 
       3.3238043227191945`}}], 
      LineBox[{{7.990303319178672, 3.3238043227191945`}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.990303319178672, 
       3.3238043227191945`}}], 
      LineBox[{{7.990303319178672, 3.3238043227191945`}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.990303319178672, 
       3.3238043227191945`}}], 
      LineBox[{{7.990303319178672, 3.3238043227191945`}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.990303319178672, 
       3.3238043227191945`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{7.896454874875906, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.990303319178672, 3.64890487020657}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}}], 
      LineBox[{{7.896454874875906, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.990303319178672, 3.64890487020657}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}}], 
      LineBox[{{7.896454874875906, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.990303319178672, 3.64890487020657}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}}], 
      LineBox[{{7.896454874875906, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.990303319178672, 3.64890487020657}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}}], 
      LineBox[{{7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}}], 
      LineBox[{{7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}}], 
      LineBox[{{7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}}], 
      LineBox[{{7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}}], 
      LineBox[{{8.059472830711494, 3.627532287489511}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}}], 
      LineBox[{{8.059472830711494, 3.627532287489511}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}}], 
      LineBox[{{8.059472830711494, 3.627532287489511}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}}], 
      LineBox[{{8.059472830711494, 3.627532287489511}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}}], 
      LineBox[{{8.112566786055362, 3.5783160246932555`}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}}], 
      LineBox[{{8.112566786055362, 3.5783160246932555`}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}}], 
      LineBox[{{8.112566786055362, 3.5783160246932555`}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}}], 
      LineBox[{{8.112566786055362, 3.5783160246932555`}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.192760208613171, -4.109970277582169}, {
       8.192760208613171, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.192760208613173, -4.4385048630411585`}, {
       8.192760208613173, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}], 
      LineBox[{{8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}], 
      LineBox[{{8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}], 
      LineBox[{{8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}], 
      LineBox[{{8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}], 
      LineBox[{{8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}], 
      LineBox[{{8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}], 
      LineBox[{{8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}], 
      LineBox[{{8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}], 
      LineBox[{{8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}], 
      LineBox[{{8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}], 
      LineBox[{{8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}], 
      LineBox[{{8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}], 
      LineBox[{{8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}], 
      LineBox[{{8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}], 
      LineBox[{{8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}], 
      LineBox[{{8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}], 
      LineBox[{{8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}], 
      LineBox[{{8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}], 
      LineBox[{{8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}], 
      LineBox[{{8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}], 
      LineBox[{{8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}], 
      LineBox[{{8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}], 
      LineBox[{{8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}], 
      LineBox[{{8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}], 
      LineBox[{{8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}], 
      LineBox[{{8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}], 
      LineBox[{{8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}], 
      LineBox[{{8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}], 
      LineBox[{{8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}], 
      LineBox[{{8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}], 
      LineBox[{{8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}], 
      LineBox[{{8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}], 
      LineBox[{{8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}], 
      LineBox[{{8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}], 
      LineBox[{{8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}], 
      LineBox[{{8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}], 
      LineBox[{{8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}], 
      LineBox[{{8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}], 
      LineBox[{{8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}], 
      LineBox[{{8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}], 
      LineBox[{{8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}], 
      LineBox[{{8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}], 
      LineBox[{{8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}], 
      LineBox[{{8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}], 
      LineBox[{{8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}], 
      LineBox[{{8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}], 
      LineBox[{{8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}], 
      LineBox[{{8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}], 
      LineBox[{{8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}], 
      LineBox[{{8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}], 
      LineBox[{{8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}], 
      LineBox[{{8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}], 
      LineBox[{{8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}], 
      LineBox[{{8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}], 
      LineBox[{{8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}], 
      LineBox[{{8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}], 
      LineBox[{{8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}], 
      LineBox[{{8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}], 
      LineBox[{{8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}], 
      LineBox[{{8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}], 
      LineBox[{{8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}], 
      LineBox[{{8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}], 
      LineBox[{{8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}], 
      LineBox[{{8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}], 
      LineBox[{{8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}], 
      LineBox[{{8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}], 
      LineBox[{{8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}], 
      LineBox[{{8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}], 
      LineBox[{{8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}], 
      LineBox[{{8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}], 
      LineBox[{{8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}], 
      LineBox[{{8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}], 
      LineBox[{{8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}], 
      LineBox[{{8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}], 
      LineBox[{{8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}], 
      LineBox[{{8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}], 
      LineBox[{{8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}], 
      LineBox[{{8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}], 
      LineBox[{{8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}], 
      LineBox[{{8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}], 
      LineBox[{{8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}], 
      LineBox[{{8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}], 
      LineBox[{{8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}], 
      LineBox[{{8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}], 
      LineBox[{{8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}], 
      LineBox[{{8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}], 
      LineBox[{{8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}], 
      LineBox[{{8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}], 
      LineBox[{{8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}], 
      LineBox[{{8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}], 
      LineBox[{{8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}], 
      LineBox[{{8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}], 
      LineBox[{{8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}], 
      LineBox[{{8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}], 
      LineBox[{{8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}], 
      LineBox[{{8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}], 
      LineBox[{{8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}], 
      LineBox[{{8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}], 
      LineBox[{{8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}], 
      LineBox[{{8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}], 
      LineBox[{{8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}], 
      LineBox[{{8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}], 
      LineBox[{{8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}], 
      LineBox[{{8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}], 
      LineBox[{{8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}], 
      LineBox[{{8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}], 
      LineBox[{{8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}], 
      LineBox[{{8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}], 
      LineBox[{{8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}], 
      LineBox[{{8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}], 
      LineBox[{{8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}], 
      LineBox[{{8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}], 
      LineBox[{{8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}], 
      LineBox[{{8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}], 
      LineBox[{{8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}], 
      LineBox[{{8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}], 
      LineBox[{{8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}], 
      LineBox[{{8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}], 
      LineBox[{{8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}], 
      LineBox[{{8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}], 
      LineBox[{{8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}], 
      LineBox[{{8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}], 
      LineBox[{{8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}], 
      LineBox[{{8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}], 
      LineBox[{{8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}], 
      LineBox[{{8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}], 
      LineBox[{{8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}], 
      LineBox[{{8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}], 
      LineBox[{{8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}], 
      LineBox[{{8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}], 
      LineBox[{{8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}], 
      LineBox[{{8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}], 
      LineBox[{{8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}], 
      LineBox[{{8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}], 
      LineBox[{{8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}], 
      LineBox[{{8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}], 
      LineBox[{{8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}], 
      LineBox[{{8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}], 
      LineBox[{{8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}], 
      LineBox[{{8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}], 
      LineBox[{{8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}], 
      LineBox[{{8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}], 
      LineBox[{{8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}], 
      LineBox[{{8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}], 
      LineBox[{{8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}], 
      LineBox[{{8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}], 
      LineBox[{{8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}], 
      LineBox[{{8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}], 
      LineBox[{{8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}], 
      LineBox[{{8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}], 
      LineBox[{{8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}], 
      LineBox[{{8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}], 
      LineBox[{{8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}], 
      LineBox[{{8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}], 
      LineBox[{{8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}], 
      LineBox[{{8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}], 
      LineBox[{{8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}], 
      LineBox[{{8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}], 
      LineBox[{{8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}], 
      LineBox[{{8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}], 
      LineBox[{{8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}], 
      LineBox[{{8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}], 
      LineBox[{{8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}], 
      LineBox[{{8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}], 
      LineBox[{{8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}], 
      LineBox[{{8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}], 
      LineBox[{{8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}], 
      LineBox[{{8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}], 
      LineBox[{{8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}], 
      LineBox[{{8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}], 
      LineBox[{{8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}], 
      LineBox[{{8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}], 
      LineBox[{{8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}], 
      LineBox[{{8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}], 
      LineBox[{{8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}], 
      LineBox[{{8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}], 
      LineBox[{{8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}], 
      LineBox[{{8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}], 
      LineBox[{{8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}], 
      LineBox[{{8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}], 
      LineBox[{{8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}], 
      LineBox[{{8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}], 
      LineBox[{{8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}], 
      LineBox[{{8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}], 
      LineBox[{{8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}], 
      LineBox[{{8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}], 
      LineBox[{{8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}], 
      LineBox[{{8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}], 
      LineBox[{{8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}], 
      LineBox[{{8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}], 
      LineBox[{{8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}], 
      LineBox[{{8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}], 
      LineBox[{{8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}], 
      LineBox[{{8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}], 
      LineBox[{{8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}], 
      LineBox[{{8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}], 
      LineBox[{{8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}], 
      LineBox[{{8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}], 
      LineBox[{{8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}], 
      LineBox[{{8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}], 
      LineBox[{{8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}], 
      LineBox[{{8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}], 
      LineBox[{{8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}], 
      LineBox[{{8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}], 
      LineBox[{{8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}], 
      LineBox[{{8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}], 
      LineBox[{{8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}], 
      LineBox[{{8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}], 
      LineBox[{{8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}], 
      LineBox[{{8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}], 
      LineBox[{{8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}], 
      LineBox[{{8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}], 
      LineBox[{{8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}], 
      LineBox[{{8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}], 
      LineBox[{{8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}], 
      LineBox[{{8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}], 
      LineBox[{{8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}], 
      LineBox[{{8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}], 
      LineBox[{{8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}], 
      LineBox[{{8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}], 
      LineBox[{{8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}], 
      LineBox[{{8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}], 
      LineBox[{{8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}], 
      LineBox[{{8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}], 
      LineBox[{{8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}], 
      LineBox[{{8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}], 
      LineBox[{{8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}], 
      LineBox[{{8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}], 
      LineBox[{{8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}], 
      LineBox[{{8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}], 
      LineBox[{{8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}], 
      LineBox[{{8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}], 
      LineBox[{{8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}], 
      LineBox[{{8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}], 
      LineBox[{{8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}], 
      LineBox[{{8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}], 
      LineBox[{{8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}], 
      LineBox[{{8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}], 
      LineBox[{{8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}], 
      LineBox[{{8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}], 
      LineBox[{{8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}], 
      LineBox[{{8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}], 
      LineBox[{{8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}], 
      LineBox[{{8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}], 
      LineBox[{{8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}], 
      LineBox[{{8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}], 
      LineBox[{{8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}], 
      LineBox[{{8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}], 
      LineBox[{{8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}], 
      LineBox[{{8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}], 
      LineBox[{{8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}], 
      LineBox[{{8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}], 
      LineBox[{{8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}], 
      LineBox[{{8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}], 
      LineBox[{{8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}], 
      LineBox[{{8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}], 
      LineBox[{{8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}], 
      LineBox[{{8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}], 
      LineBox[{{8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}], 
      LineBox[{{8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}], 
      LineBox[{{8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}], 
      LineBox[{{8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}], 
      LineBox[{{8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}], 
      LineBox[{{8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}], 
      LineBox[{{8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}], 
      LineBox[{{8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}], 
      LineBox[{{8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}], 
      LineBox[{{8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}], 
      LineBox[{{8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}], 
      LineBox[{{8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}], 
      LineBox[{{8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}], 
      LineBox[{{8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}], 
      LineBox[{{8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}], 
      LineBox[{{8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}], 
      LineBox[{{8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}], 
      LineBox[{{8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}], 
      LineBox[{{8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}], 
      LineBox[{{8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}], 
      LineBox[{{8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}], 
      LineBox[{{8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}], 
      LineBox[{{8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}], 
      LineBox[{{8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}], 
      LineBox[{{8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}], 
      LineBox[{{8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}], 
      LineBox[{{8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}], 
      LineBox[{{8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}], 
      LineBox[{{8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}], 
      LineBox[{{8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}], 
      LineBox[{{8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}], 
      LineBox[{{8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}], 
      LineBox[{{8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}], 
      LineBox[{{8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}], 
      LineBox[{{8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}], 
      LineBox[{{8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}], 
      LineBox[{{8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}], 
      LineBox[{{8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}], 
      LineBox[{{8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}], 
      LineBox[{{8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}], 
      LineBox[{{8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}], 
      LineBox[{{8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}], 
      LineBox[{{8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}], 
      LineBox[{{8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}], 
      LineBox[{{8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}], 
      LineBox[{{8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}], 
      LineBox[{{8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}], 
      LineBox[{{8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}], 
      LineBox[{{8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}], 
      LineBox[{{8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}], 
      LineBox[{{8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}], 
      LineBox[{{8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}], 
      LineBox[{{8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}], 
      LineBox[{{8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}], 
      LineBox[{{8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}], 
      LineBox[{{8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}], 
      LineBox[{{8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}], 
      LineBox[{{8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}], 
      LineBox[{{8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}], 
      LineBox[{{8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}], 
      LineBox[{{8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}], 
      LineBox[{{8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}], 
      LineBox[{{8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}], 
      LineBox[{{8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}], 
      LineBox[{{8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}], 
      LineBox[{{8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}], 
      LineBox[{{8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}], 
      LineBox[{{8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}], 
      LineBox[{{8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}], 
      LineBox[{{8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}], 
      LineBox[{{8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}], 
      LineBox[{{8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}], 
      LineBox[{{8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}], 
      LineBox[{{8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}], 
      LineBox[{{8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}], 
      LineBox[{{8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}], 
      LineBox[{{8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}], 
      LineBox[{{8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}], 
      LineBox[{{8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}], 
      LineBox[{{8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}], 
      LineBox[{{8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}], 
      LineBox[{{8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}], 
      LineBox[{{8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}], 
      LineBox[{{8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}], 
      LineBox[{{8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}], 
      LineBox[{{8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}], 
      LineBox[{{8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}], 
      LineBox[{{8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}], 
      LineBox[{{8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}], 
      LineBox[{{8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}], 
      LineBox[{{8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}], 
      LineBox[{{8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}], 
      LineBox[{{8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}], 
      LineBox[{{8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}], 
      LineBox[{{8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}], 
      LineBox[{{8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}], 
      LineBox[{{8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}], 
      LineBox[{{8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}], 
      LineBox[{{8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}], 
      LineBox[{{8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}], 
      LineBox[{{8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}], 
      LineBox[{{8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.0879278476739053}, {
       8.181359566928423, -0.0879278476739053}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937394}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.2360349742204613}, {
       8.437888635070092, -0.2360349742204613}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}], 
      LineBox[{{8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}], 
      LineBox[{{8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}], 
      LineBox[{{8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}], 
      LineBox[{{8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}], 
      LineBox[{{8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}], 
      LineBox[{{8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}], 
      LineBox[{{8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}], 
      LineBox[{{8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}], 
      LineBox[{{8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}], 
      LineBox[{{8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}], 
      LineBox[{{8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}], 
      LineBox[{{8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}], 
      LineBox[{{8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}], 
      LineBox[{{8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}], 
      LineBox[{{8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}], 
      LineBox[{{8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}], 
      LineBox[{{8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}], 
      LineBox[{{8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}], 
      LineBox[{{8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}], 
      LineBox[{{8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}], 
      LineBox[{{8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}], 
      LineBox[{{8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}], 
      LineBox[{{8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}], 
      LineBox[{{8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}], 
      LineBox[{{8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}], 
      LineBox[{{8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}], 
      LineBox[{{8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}], 
      LineBox[{{8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}], 
      LineBox[{{8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}], 
      LineBox[{{8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}], 
      LineBox[{{8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}], 
      LineBox[{{8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}], 
      LineBox[{{8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}], 
      LineBox[{{8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}], 
      LineBox[{{8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}], 
      LineBox[{{8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}], 
      LineBox[{{8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}], 
      LineBox[{{8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}], 
      LineBox[{{8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}], 
      LineBox[{{8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}], 
      LineBox[{{8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}], 
      LineBox[{{8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}], 
      LineBox[{{8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}], 
      LineBox[{{8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}], 
      LineBox[{{8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.144016249758415, 0.07964271720908606}, {8.080273670568955, 
       0.14840750065066233`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.28593706753381487`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}, {
       8.080273670568955, 0.2859370675338148}, {8.064613517296895, 
       0.21717228409223857`}, {8.080273670568955, 0.14840750065066227`}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.302821714681457, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908603}, {8.144016249758415, 0.07964271720908603}, {
       8.235439588699286, 0.0588224160490603}, {8.302821714681457, 
       0.07964271720908606}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.302821714681457, 0.3547018509753911}, {
       8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.2171722840922386}, {8.382224447142978, 0.2171722840922386}, {
       8.354543687391567, 0.30675736869384057`}, {8.302821714681457, 
       0.3547018509753911}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.144016249758415, 0.07964271720908606}, {8.080273670568955, 
       0.14840750065066233`}, {8.080273670568955, 0.14840750065066233`}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}}], 
      LineBox[{{8.144016249758415, 0.07964271720908606}, {8.080273670568955, 
       0.14840750065066233`}, {8.080273670568955, 0.14840750065066233`}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}}], 
      LineBox[{{8.144016249758415, 0.07964271720908606}, {8.080273670568955, 
       0.14840750065066233`}, {8.080273670568955, 0.14840750065066233`}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}}], 
      LineBox[{{8.144016249758415, 0.07964271720908606}, {8.080273670568955, 
       0.14840750065066233`}, {8.080273670568955, 0.14840750065066233`}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}}], 
      LineBox[{{8.080273670568955, 0.14840750065066233`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}}], 
      LineBox[{{8.080273670568955, 0.14840750065066233`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}}], 
      LineBox[{{8.080273670568955, 0.14840750065066233`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}}], 
      LineBox[{{8.080273670568955, 0.14840750065066233`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}}], 
      LineBox[{{8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.2859370675338148}, {8.080273670568955, 0.2859370675338148}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}], 
      LineBox[{{8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.2859370675338148}, {8.080273670568955, 0.2859370675338148}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}], 
      LineBox[{{8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.2859370675338148}, {8.080273670568955, 0.2859370675338148}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}], 
      LineBox[{{8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.2859370675338148}, {8.080273670568955, 0.2859370675338148}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}], 
      LineBox[{{8.080273670568955, 0.28593706753381487`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}, {
       8.080273670568955, 0.28593706753381487`}, {8.080273670568955, 
       0.28593706753381487`}}], 
      LineBox[{{8.080273670568955, 0.28593706753381487`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}, {
       8.080273670568955, 0.28593706753381487`}, {8.080273670568955, 
       0.28593706753381487`}}], 
      LineBox[{{8.080273670568955, 0.28593706753381487`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}, {
       8.080273670568955, 0.28593706753381487`}, {8.080273670568955, 
       0.28593706753381487`}}], 
      LineBox[{{8.080273670568955, 0.28593706753381487`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}, {
       8.080273670568955, 0.28593706753381487`}, {8.080273670568955, 
       0.28593706753381487`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}], 
      LineBox[{{8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}], 
      LineBox[{{8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}], 
      LineBox[{{8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}], 
      LineBox[{{8.354543687391567, 0.12758719949063657`}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.354543687391567, 0.12758719949063657`}, {8.354543687391567, 
       0.12758719949063657`}}], 
      LineBox[{{8.354543687391567, 0.12758719949063657`}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.354543687391567, 0.12758719949063657`}, {8.354543687391567, 
       0.12758719949063657`}}], 
      LineBox[{{8.354543687391567, 0.12758719949063657`}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.354543687391567, 0.12758719949063657`}, {8.354543687391567, 
       0.12758719949063657`}}], 
      LineBox[{{8.354543687391567, 0.12758719949063657`}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.354543687391567, 0.12758719949063657`}, {8.354543687391567, 
       0.12758719949063657`}}], 
      LineBox[{{8.302821714681457, 0.07964271720908606}, {8.235439588699286, 
       0.0588224160490603}, {8.235439588699286, 0.0588224160490603}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}}], 
      LineBox[{{8.302821714681457, 0.07964271720908606}, {8.235439588699286, 
       0.0588224160490603}, {8.235439588699286, 0.0588224160490603}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}}], 
      LineBox[{{8.302821714681457, 0.07964271720908606}, {8.235439588699286, 
       0.0588224160490603}, {8.235439588699286, 0.0588224160490603}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}}], 
      LineBox[{{8.302821714681457, 0.07964271720908606}, {8.235439588699286, 
       0.0588224160490603}, {8.235439588699286, 0.0588224160490603}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}}], 
      LineBox[{{8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}}], 
      LineBox[{{8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}}], 
      LineBox[{{8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}}], 
      LineBox[{{8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}], 
      LineBox[{{8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}], 
      LineBox[{{8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}], 
      LineBox[{{8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}], 
      LineBox[{{8.235439588699286, 0.37552215213541684`}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}}], 
      LineBox[{{8.235439588699286, 0.37552215213541684`}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}}], 
      LineBox[{{8.235439588699286, 0.37552215213541684`}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}}], 
      LineBox[{{8.235439588699286, 0.37552215213541684`}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}}], 
      LineBox[{{8.302821714681457, 0.3547018509753911}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}], 
      LineBox[{{8.302821714681457, 0.3547018509753911}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}], 
      LineBox[{{8.302821714681457, 0.3547018509753911}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}], 
      LineBox[{{8.302821714681457, 0.3547018509753911}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}], 
      LineBox[{{8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.21717228409223854`}, {8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.30675736869384057`}, {8.354543687391567, 
       0.30675736869384057`}}], 
      LineBox[{{8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.21717228409223854`}, {8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.30675736869384057`}, {8.354543687391567, 
       0.30675736869384057`}}], 
      LineBox[{{8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.21717228409223854`}, {8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.30675736869384057`}, {8.354543687391567, 
       0.30675736869384057`}}], 
      LineBox[{{8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.21717228409223854`}, {8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.30675736869384057`}, {8.354543687391567, 
       0.30675736869384057`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.139432808846635, 0.6334419398575452}, {8.073438797266855, 
       0.7046355434492074}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.8470227506325322}, {8.139432808846635, 
       0.9182163542241945}, {8.139432808846635, 0.9182163542241945}, {
       8.073438797266855, 0.8470227506325322}, {8.057225516450185, 
       0.7758291470408698}, {8.073438797266855, 0.7046355434492074}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.30384739363954, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.633441939857545}, {8.139432808846635, 0.633441939857545}, {
       8.234085283933865, 0.6118862511276407}, {8.30384739363954, 
       0.6334419398575452}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.30384739363954, 0.9182163542241945}, {
       8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.30384739363954, 
       0.9182163542241945}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.139432808846635, 0.6334419398575452}, {8.073438797266855, 
       0.7046355434492074}, {8.073438797266855, 0.7046355434492074}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}}], 
      LineBox[{{8.139432808846635, 0.6334419398575452}, {8.073438797266855, 
       0.7046355434492074}, {8.073438797266855, 0.7046355434492074}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}}], 
      LineBox[{{8.139432808846635, 0.6334419398575452}, {8.073438797266855, 
       0.7046355434492074}, {8.073438797266855, 0.7046355434492074}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}}], 
      LineBox[{{8.139432808846635, 0.6334419398575452}, {8.073438797266855, 
       0.7046355434492074}, {8.073438797266855, 0.7046355434492074}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}}], 
      LineBox[{{8.073438797266855, 0.7046355434492074}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}}], 
      LineBox[{{8.073438797266855, 0.7046355434492074}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}}], 
      LineBox[{{8.073438797266855, 0.7046355434492074}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}}], 
      LineBox[{{8.073438797266855, 0.7046355434492074}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}}], 
      LineBox[{{8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}], 
      LineBox[{{8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}], 
      LineBox[{{8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}], 
      LineBox[{{8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}], 
      LineBox[{{8.073438797266855, 0.8470227506325322}, {8.139432808846635, 
       0.9182163542241946}, {8.139432808846635, 0.9182163542241946}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}}], 
      LineBox[{{8.073438797266855, 0.8470227506325322}, {8.139432808846635, 
       0.9182163542241946}, {8.139432808846635, 0.9182163542241946}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}}], 
      LineBox[{{8.073438797266855, 0.8470227506325322}, {8.139432808846635, 
       0.9182163542241946}, {8.139432808846635, 0.9182163542241946}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}}], 
      LineBox[{{8.073438797266855, 0.8470227506325322}, {8.139432808846635, 
       0.9182163542241946}, {8.139432808846635, 0.9182163542241946}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}], 
      LineBox[{{8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}], 
      LineBox[{{8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}], 
      LineBox[{{8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}], 
      LineBox[{{8.357396222528543, 0.6830798547193031}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.357396222528543, 0.6830798547193031}, {8.357396222528543, 
       0.6830798547193031}}], 
      LineBox[{{8.357396222528543, 0.6830798547193031}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.357396222528543, 0.6830798547193031}, {8.357396222528543, 
       0.6830798547193031}}], 
      LineBox[{{8.357396222528543, 0.6830798547193031}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.357396222528543, 0.6830798547193031}, {8.357396222528543, 
       0.6830798547193031}}], 
      LineBox[{{8.357396222528543, 0.6830798547193031}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.357396222528543, 0.6830798547193031}, {8.357396222528543, 
       0.6830798547193031}}], 
      LineBox[{{8.30384739363954, 0.6334419398575452}, {8.234085283933865, 
       0.6118862511276407}, {8.234085283933865, 0.6118862511276407}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}}], 
      LineBox[{{8.30384739363954, 0.6334419398575452}, {8.234085283933865, 
       0.6118862511276407}, {8.234085283933865, 0.6118862511276407}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}}], 
      LineBox[{{8.30384739363954, 0.6334419398575452}, {8.234085283933865, 
       0.6118862511276407}, {8.234085283933865, 0.6118862511276407}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}}], 
      LineBox[{{8.30384739363954, 0.6334419398575452}, {8.234085283933865, 
       0.6118862511276407}, {8.234085283933865, 0.6118862511276407}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}}], 
      LineBox[{{8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}}], 
      LineBox[{{8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}}], 
      LineBox[{{8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}}], 
      LineBox[{{8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}], 
      LineBox[{{8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}], 
      LineBox[{{8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}], 
      LineBox[{{8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}], 
      LineBox[{{8.234085283933865, 0.9397720429540989}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}}], 
      LineBox[{{8.234085283933865, 0.9397720429540989}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}}], 
      LineBox[{{8.234085283933865, 0.9397720429540989}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}}], 
      LineBox[{{8.234085283933865, 0.9397720429540989}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}}], 
      LineBox[{{8.30384739363954, 0.9182163542241945}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}], 
      LineBox[{{8.30384739363954, 0.9182163542241945}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}], 
      LineBox[{{8.30384739363954, 0.9182163542241945}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}], 
      LineBox[{{8.30384739363954, 0.9182163542241945}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}], 
      LineBox[{{8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.357396222528543, 
       0.8685784393624365}}], 
      LineBox[{{8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.357396222528543, 
       0.8685784393624365}}], 
      LineBox[{{8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.357396222528543, 
       0.8685784393624365}}], 
      LineBox[{{8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.357396222528543, 
       0.8685784393624365}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.206669870646468, 1.12703710845965}, {8.135395227908342, 
       1.203927398044503}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.3577079772142093`}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}, {
       8.135395227908342, 1.3577079772142093`}, {8.117884611866703, 
       1.2808176876293562`}, {8.135395227908342, 1.203927398044503}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.384240388206003, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.384240388206003, 
       1.12703710845965}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.384240388206003, 1.4345982667990624`}, {
       8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.384240388206003, 
       1.4345982667990624`}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.206669870646468, 1.12703710845965}, {8.135395227908342, 
       1.203927398044503}, {8.135395227908342, 1.203927398044503}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}}], 
      LineBox[{{8.206669870646468, 1.12703710845965}, {8.135395227908342, 
       1.203927398044503}, {8.135395227908342, 1.203927398044503}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}}], 
      LineBox[{{8.206669870646468, 1.12703710845965}, {8.135395227908342, 
       1.203927398044503}, {8.135395227908342, 1.203927398044503}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}}], 
      LineBox[{{8.206669870646468, 1.12703710845965}, {8.135395227908342, 
       1.203927398044503}, {8.135395227908342, 1.203927398044503}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}}], 
      LineBox[{{8.135395227908342, 1.203927398044503}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}}], 
      LineBox[{{8.135395227908342, 1.203927398044503}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}}], 
      LineBox[{{8.135395227908342, 1.203927398044503}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}}], 
      LineBox[{{8.135395227908342, 1.203927398044503}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}}], 
      LineBox[{{8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}], 
      LineBox[{{8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}], 
      LineBox[{{8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}], 
      LineBox[{{8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}], 
      LineBox[{{8.135395227908342, 1.3577079772142093`}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}}], 
      LineBox[{{8.135395227908342, 1.3577079772142093`}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}}], 
      LineBox[{{8.135395227908342, 1.3577079772142093`}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}}], 
      LineBox[{{8.135395227908342, 1.3577079772142093`}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}], 
      LineBox[{{8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}], 
      LineBox[{{8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}], 
      LineBox[{{8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}], 
      LineBox[{{8.442074024270006, 1.1806468915800514`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.442074024270006, 1.1806468915800514`}, {8.442074024270006, 
       1.1806468915800514`}}], 
      LineBox[{{8.442074024270006, 1.1806468915800514`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.442074024270006, 1.1806468915800514`}, {8.442074024270006, 
       1.1806468915800514`}}], 
      LineBox[{{8.442074024270006, 1.1806468915800514`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.442074024270006, 1.1806468915800514`}, {8.442074024270006, 
       1.1806468915800514`}}], 
      LineBox[{{8.442074024270006, 1.1806468915800514`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.442074024270006, 1.1806468915800514`}, {8.442074024270006, 
       1.1806468915800514`}}], 
      LineBox[{{8.384240388206003, 1.12703710845965}, {8.308896136100358, 
       1.1037566019951985`}, {8.308896136100358, 1.1037566019951985`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}}], 
      LineBox[{{8.384240388206003, 1.12703710845965}, {8.308896136100358, 
       1.1037566019951985`}, {8.308896136100358, 1.1037566019951985`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}}], 
      LineBox[{{8.384240388206003, 1.12703710845965}, {8.308896136100358, 
       1.1037566019951985`}, {8.308896136100358, 1.1037566019951985`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}}], 
      LineBox[{{8.384240388206003, 1.12703710845965}, {8.308896136100358, 
       1.1037566019951985`}, {8.308896136100358, 1.1037566019951985`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}}], 
      LineBox[{{8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}}], 
      LineBox[{{8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}}], 
      LineBox[{{8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}}], 
      LineBox[{{8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}], 
      LineBox[{{8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}], 
      LineBox[{{8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}], 
      LineBox[{{8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}], 
      LineBox[{{8.308896136100358, 1.457878773263514}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}}], 
      LineBox[{{8.308896136100358, 1.457878773263514}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}}], 
      LineBox[{{8.308896136100358, 1.457878773263514}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}}], 
      LineBox[{{8.308896136100358, 1.457878773263514}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}}], 
      LineBox[{{8.384240388206003, 1.4345982667990624`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}], 
      LineBox[{{8.384240388206003, 1.4345982667990624`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}], 
      LineBox[{{8.384240388206003, 1.4345982667990624`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}], 
      LineBox[{{8.384240388206003, 1.4345982667990624`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}], 
      LineBox[{{8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.442074024270006, 
       1.380988483678661}}], 
      LineBox[{{8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.442074024270006, 
       1.380988483678661}}], 
      LineBox[{{8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.442074024270006, 
       1.380988483678661}}], 
      LineBox[{{8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.442074024270006, 
       1.380988483678661}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.163133469722204, 1.6272527844330726`}, {8.106211332743912, 
       1.6886597508928032`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.8114736838122643`}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}, {
       8.106211332743912, 1.8114736838122643`}, {8.092226812490917, 
       1.7500667173525337`}, {8.106211332743912, 1.6886597508928032`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.304946784184779, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.304946784184779, 
       1.6272527844330726`}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.304946784184779, 1.8728806502719948`}, {
       8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.304946784184779, 
       1.8728806502719948`}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.163133469722204, 1.6272527844330726`}, {8.106211332743912, 
       1.6886597508928032`}, {8.106211332743912, 1.6886597508928032`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}}], 
      LineBox[{{8.163133469722204, 1.6272527844330726`}, {8.106211332743912, 
       1.6886597508928032`}, {8.106211332743912, 1.6886597508928032`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}}], 
      LineBox[{{8.163133469722204, 1.6272527844330726`}, {8.106211332743912, 
       1.6886597508928032`}, {8.106211332743912, 1.6886597508928032`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}}], 
      LineBox[{{8.163133469722204, 1.6272527844330726`}, {8.106211332743912, 
       1.6886597508928032`}, {8.106211332743912, 1.6886597508928032`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}}], 
      LineBox[{{8.106211332743912, 1.6886597508928032`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}}], 
      LineBox[{{8.106211332743912, 1.6886597508928032`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}}], 
      LineBox[{{8.106211332743912, 1.6886597508928032`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}}], 
      LineBox[{{8.106211332743912, 1.6886597508928032`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}}], 
      LineBox[{{8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}], 
      LineBox[{{8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}], 
      LineBox[{{8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}], 
      LineBox[{{8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}], 
      LineBox[{{8.106211332743912, 1.8114736838122643`}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}}], 
      LineBox[{{8.106211332743912, 1.8114736838122643`}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}}], 
      LineBox[{{8.106211332743912, 1.8114736838122643`}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}}], 
      LineBox[{{8.106211332743912, 1.8114736838122643`}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}], 
      LineBox[{{8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}], 
      LineBox[{{8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}], 
      LineBox[{{8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}], 
      LineBox[{{8.351134516981746, 1.670067217461771}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.351134516981746, 1.670067217461771}, {8.351134516981746, 
       1.670067217461771}}], 
      LineBox[{{8.351134516981746, 1.670067217461771}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.351134516981746, 1.670067217461771}, {8.351134516981746, 
       1.670067217461771}}], 
      LineBox[{{8.351134516981746, 1.670067217461771}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.351134516981746, 1.670067217461771}, {8.351134516981746, 
       1.670067217461771}}], 
      LineBox[{{8.351134516981746, 1.670067217461771}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.351134516981746, 1.670067217461771}, {8.351134516981746, 
       1.670067217461771}}], 
      LineBox[{{8.304946784184779, 1.6272527844330726`}, {8.244774531134816, 
       1.6086602510020405`}, {8.244774531134816, 1.6086602510020405`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}}], 
      LineBox[{{8.304946784184779, 1.6272527844330726`}, {8.244774531134816, 
       1.6086602510020405`}, {8.244774531134816, 1.6086602510020405`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}}], 
      LineBox[{{8.304946784184779, 1.6272527844330726`}, {8.244774531134816, 
       1.6086602510020405`}, {8.244774531134816, 1.6086602510020405`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}}], 
      LineBox[{{8.304946784184779, 1.6272527844330726`}, {8.244774531134816, 
       1.6086602510020405`}, {8.244774531134816, 1.6086602510020405`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}}], 
      LineBox[{{8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}}], 
      LineBox[{{8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}}], 
      LineBox[{{8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}}], 
      LineBox[{{8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}], 
      LineBox[{{8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}], 
      LineBox[{{8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}], 
      LineBox[{{8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}], 
      LineBox[{{8.244774531134816, 1.891473183703027}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}}], 
      LineBox[{{8.244774531134816, 1.891473183703027}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}}], 
      LineBox[{{8.244774531134816, 1.891473183703027}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}}], 
      LineBox[{{8.244774531134816, 1.891473183703027}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}}], 
      LineBox[{{8.304946784184779, 1.8728806502719948`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}], 
      LineBox[{{8.304946784184779, 1.8728806502719948`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}], 
      LineBox[{{8.304946784184779, 1.8728806502719948`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}], 
      LineBox[{{8.304946784184779, 1.8728806502719948`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}], 
      LineBox[{{8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.351134516981746, 
       1.8300662172432964`}}], 
      LineBox[{{8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.351134516981746, 
       1.8300662172432964`}}], 
      LineBox[{{8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.351134516981746, 
       1.8300662172432964`}}], 
      LineBox[{{8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.351134516981746, 
       1.8300662172432964`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.136754606654145, 2.117616987701533}, {8.075976189177158, 
       2.1831840665501057`}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.314318224247252}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}, {
       8.075976189177158, 2.314318224247252}, {8.061044265407745, 
       2.248751145398679}, {8.075976189177158, 2.1831840665501057`}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.28817528914695, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.28817528914695, 
       2.117616987701533}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.28817528914695, 2.3798853030958247`}, {
       8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.28817528914695, 
       2.3798853030958247`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.136754606654145, 2.117616987701533}, {8.075976189177158, 
       2.1831840665501057`}, {8.075976189177158, 2.1831840665501057`}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}}], 
      LineBox[{{8.136754606654145, 2.117616987701533}, {8.075976189177158, 
       2.1831840665501057`}, {8.075976189177158, 2.1831840665501057`}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}}], 
      LineBox[{{8.136754606654145, 2.117616987701533}, {8.075976189177158, 
       2.1831840665501057`}, {8.075976189177158, 2.1831840665501057`}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}}], 
      LineBox[{{8.136754606654145, 2.117616987701533}, {8.075976189177158, 
       2.1831840665501057`}, {8.075976189177158, 2.1831840665501057`}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}}], 
      LineBox[{{8.075976189177158, 2.1831840665501057`}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}}], 
      LineBox[{{8.075976189177158, 2.1831840665501057`}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}}], 
      LineBox[{{8.075976189177158, 2.1831840665501057`}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}}], 
      LineBox[{{8.075976189177158, 2.1831840665501057`}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}}], 
      LineBox[{{8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}], 
      LineBox[{{8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}], 
      LineBox[{{8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}], 
      LineBox[{{8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}], 
      LineBox[{{8.075976189177158, 2.314318224247252}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}}], 
      LineBox[{{8.075976189177158, 2.314318224247252}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}}], 
      LineBox[{{8.075976189177158, 2.314318224247252}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}}], 
      LineBox[{{8.075976189177158, 2.314318224247252}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}], 
      LineBox[{{8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}], 
      LineBox[{{8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}], 
      LineBox[{{8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}], 
      LineBox[{{8.337492083197045, 2.163331952437505}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.337492083197045, 2.163331952437505}, {8.337492083197045, 
       2.163331952437505}}], 
      LineBox[{{8.337492083197045, 2.163331952437505}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.337492083197045, 2.163331952437505}, {8.337492083197045, 
       2.163331952437505}}], 
      LineBox[{{8.337492083197045, 2.163331952437505}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.337492083197045, 2.163331952437505}, {8.337492083197045, 
       2.163331952437505}}], 
      LineBox[{{8.337492083197045, 2.163331952437505}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.337492083197045, 2.163331952437505}, {8.337492083197045, 
       2.163331952437505}}], 
      LineBox[{{8.28817528914695, 2.117616987701533}, {8.223926571327441, 
       2.097764873588932}, {8.223926571327441, 2.097764873588932}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}}], 
      LineBox[{{8.28817528914695, 2.117616987701533}, {8.223926571327441, 
       2.097764873588932}, {8.223926571327441, 2.097764873588932}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}}], 
      LineBox[{{8.28817528914695, 2.117616987701533}, {8.223926571327441, 
       2.097764873588932}, {8.223926571327441, 2.097764873588932}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}}], 
      LineBox[{{8.28817528914695, 2.117616987701533}, {8.223926571327441, 
       2.097764873588932}, {8.223926571327441, 2.097764873588932}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}}], 
      LineBox[{{8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}}], 
      LineBox[{{8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}}], 
      LineBox[{{8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}}], 
      LineBox[{{8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}], 
      LineBox[{{8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}], 
      LineBox[{{8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}], 
      LineBox[{{8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}], 
      LineBox[{{8.223926571327441, 2.3997374172084256`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}}], 
      LineBox[{{8.223926571327441, 2.3997374172084256`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}}], 
      LineBox[{{8.223926571327441, 2.3997374172084256`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}}], 
      LineBox[{{8.223926571327441, 2.3997374172084256`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}}], 
      LineBox[{{8.28817528914695, 2.3798853030958247`}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}], 
      LineBox[{{8.28817528914695, 2.3798853030958247`}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}], 
      LineBox[{{8.28817528914695, 2.3798853030958247`}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}], 
      LineBox[{{8.28817528914695, 2.3798853030958247`}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}], 
      LineBox[{{8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.337492083197045, 
       2.3341703383598524`}}], 
      LineBox[{{8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.337492083197045, 
       2.3341703383598524`}}], 
      LineBox[{{8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.337492083197045, 
       2.3341703383598524`}}], 
      LineBox[{{8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.337492083197045, 
       2.3341703383598524`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.147424796089721, 2.591045089851107}, {8.074478892973671, 
       2.669738316490339}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.827124769768803}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}, {
       8.074478892973671, 2.8271247697688024`}, {8.056557684922598, 
       2.7484315431295707`}, {8.074478892973671, 2.6697383164903385`}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.329159018423963, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.329159018423963, 
       2.591045089851107}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.329159018423963, 2.9058179964080346`}, {
       8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.329159018423963, 
       2.9058179964080346`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.147424796089721, 2.591045089851107}, {8.074478892973671, 
       2.669738316490339}, {8.074478892973671, 2.669738316490339}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}}], 
      LineBox[{{8.147424796089721, 2.591045089851107}, {8.074478892973671, 
       2.669738316490339}, {8.074478892973671, 2.669738316490339}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}}], 
      LineBox[{{8.147424796089721, 2.591045089851107}, {8.074478892973671, 
       2.669738316490339}, {8.074478892973671, 2.669738316490339}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}}], 
      LineBox[{{8.147424796089721, 2.591045089851107}, {8.074478892973671, 
       2.669738316490339}, {8.074478892973671, 2.669738316490339}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}}], 
      LineBox[{{8.074478892973671, 2.669738316490339}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}}], 
      LineBox[{{8.074478892973671, 2.669738316490339}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}}], 
      LineBox[{{8.074478892973671, 2.669738316490339}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}}], 
      LineBox[{{8.074478892973671, 2.669738316490339}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}}], 
      LineBox[{{8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.8271247697688024`}, {8.074478892973671, 2.8271247697688024`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}], 
      LineBox[{{8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.8271247697688024`}, {8.074478892973671, 2.8271247697688024`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}], 
      LineBox[{{8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.8271247697688024`}, {8.074478892973671, 2.8271247697688024`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}], 
      LineBox[{{8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.8271247697688024`}, {8.074478892973671, 2.8271247697688024`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}], 
      LineBox[{{8.074478892973671, 2.827124769768803}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}, {
       8.074478892973671, 2.827124769768803}, {8.074478892973671, 
       2.827124769768803}}], 
      LineBox[{{8.074478892973671, 2.827124769768803}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}, {
       8.074478892973671, 2.827124769768803}, {8.074478892973671, 
       2.827124769768803}}], 
      LineBox[{{8.074478892973671, 2.827124769768803}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}, {
       8.074478892973671, 2.827124769768803}, {8.074478892973671, 
       2.827124769768803}}], 
      LineBox[{{8.074478892973671, 2.827124769768803}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}, {
       8.074478892973671, 2.827124769768803}, {8.074478892973671, 
       2.827124769768803}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}], 
      LineBox[{{8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}], 
      LineBox[{{8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}], 
      LineBox[{{8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}], 
      LineBox[{{8.388348747773769, 2.645911924609457}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.388348747773769, 2.645911924609457}, {8.388348747773769, 
       2.645911924609457}}], 
      LineBox[{{8.388348747773769, 2.645911924609457}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.388348747773769, 2.645911924609457}, {8.388348747773769, 
       2.645911924609457}}], 
      LineBox[{{8.388348747773769, 2.645911924609457}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.388348747773769, 2.645911924609457}, {8.388348747773769, 
       2.645911924609457}}], 
      LineBox[{{8.388348747773769, 2.645911924609457}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.388348747773769, 2.645911924609457}, {8.388348747773769, 
       2.645911924609457}}], 
      LineBox[{{8.329159018423963, 2.591045089851107}, {8.252048081023087, 
       2.567218697970225}, {8.252048081023087, 2.567218697970225}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}}], 
      LineBox[{{8.329159018423963, 2.591045089851107}, {8.252048081023087, 
       2.567218697970225}, {8.252048081023087, 2.567218697970225}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}}], 
      LineBox[{{8.329159018423963, 2.591045089851107}, {8.252048081023087, 
       2.567218697970225}, {8.252048081023087, 2.567218697970225}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}}], 
      LineBox[{{8.329159018423963, 2.591045089851107}, {8.252048081023087, 
       2.567218697970225}, {8.252048081023087, 2.567218697970225}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}}], 
      LineBox[{{8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}}], 
      LineBox[{{8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}}], 
      LineBox[{{8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}}], 
      LineBox[{{8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}], 
      LineBox[{{8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}], 
      LineBox[{{8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}], 
      LineBox[{{8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}], 
      LineBox[{{8.252048081023087, 2.9296443882889163`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}}], 
      LineBox[{{8.252048081023087, 2.9296443882889163`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}}], 
      LineBox[{{8.252048081023087, 2.9296443882889163`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}}], 
      LineBox[{{8.252048081023087, 2.9296443882889163`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}}], 
      LineBox[{{8.329159018423963, 2.9058179964080346`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}], 
      LineBox[{{8.329159018423963, 2.9058179964080346`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}], 
      LineBox[{{8.329159018423963, 2.9058179964080346`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}], 
      LineBox[{{8.329159018423963, 2.9058179964080346`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}], 
      LineBox[{{8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.388348747773769, 
       2.8509511616496845`}}], 
      LineBox[{{8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.388348747773769, 
       2.8509511616496845`}}], 
      LineBox[{{8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.388348747773769, 
       2.8509511616496845`}}], 
      LineBox[{{8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.388348747773769, 
       2.8509511616496845`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.153601472936804, 3.103653151100236}, {8.091731502244903, 
       3.1703977853818177`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.3038870539449814`}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}, {
       8.091731502244903, 3.3038870539449814`}, {8.076531407797937, 
       3.2371424196633996`}, {8.091731502244903, 3.1703977853818177`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.307741603214543, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.307741603214543, 
       3.103653151100236}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.307741603214543, 3.3706316882265632`}, {
       8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.307741603214543, 
       3.3706316882265632`}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.153601472936804, 3.103653151100236}, {8.091731502244903, 
       3.1703977853818177`}, {8.091731502244903, 3.1703977853818177`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}}], 
      LineBox[{{8.153601472936804, 3.103653151100236}, {8.091731502244903, 
       3.1703977853818177`}, {8.091731502244903, 3.1703977853818177`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}}], 
      LineBox[{{8.153601472936804, 3.103653151100236}, {8.091731502244903, 
       3.1703977853818177`}, {8.091731502244903, 3.1703977853818177`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}}], 
      LineBox[{{8.153601472936804, 3.103653151100236}, {8.091731502244903, 
       3.1703977853818177`}, {8.091731502244903, 3.1703977853818177`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}}], 
      LineBox[{{8.091731502244903, 3.1703977853818177`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}}], 
      LineBox[{{8.091731502244903, 3.1703977853818177`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}}], 
      LineBox[{{8.091731502244903, 3.1703977853818177`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}}], 
      LineBox[{{8.091731502244903, 3.1703977853818177`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}}], 
      LineBox[{{8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}], 
      LineBox[{{8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}], 
      LineBox[{{8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}], 
      LineBox[{{8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}], 
      LineBox[{{8.091731502244903, 3.3038870539449814`}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}}], 
      LineBox[{{8.091731502244903, 3.3038870539449814`}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}}], 
      LineBox[{{8.091731502244903, 3.3038870539449814`}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}}], 
      LineBox[{{8.091731502244903, 3.3038870539449814`}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}], 
      LineBox[{{8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}], 
      LineBox[{{8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}], 
      LineBox[{{8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}], 
      LineBox[{{8.357944104845211, 3.150189136172023}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.357944104845211, 3.150189136172023}, {8.357944104845211, 
       3.150189136172023}}], 
      LineBox[{{8.357944104845211, 3.150189136172023}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.357944104845211, 3.150189136172023}, {8.357944104845211, 
       3.150189136172023}}], 
      LineBox[{{8.357944104845211, 3.150189136172023}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.357944104845211, 3.150189136172023}, {8.357944104845211, 
       3.150189136172023}}], 
      LineBox[{{8.357944104845211, 3.150189136172023}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.357944104845211, 3.150189136172023}, {8.357944104845211, 
       3.150189136172023}}], 
      LineBox[{{8.307741603214543, 3.103653151100236}, {8.242339007136907, 
       3.0834445018904413`}, {8.242339007136907, 3.0834445018904413`}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}}], 
      LineBox[{{8.307741603214543, 3.103653151100236}, {8.242339007136907, 
       3.0834445018904413`}, {8.242339007136907, 3.0834445018904413`}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}}], 
      LineBox[{{8.307741603214543, 3.103653151100236}, {8.242339007136907, 
       3.0834445018904413`}, {8.242339007136907, 3.0834445018904413`}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}}], 
      LineBox[{{8.307741603214543, 3.103653151100236}, {8.242339007136907, 
       3.0834445018904413`}, {8.242339007136907, 3.0834445018904413`}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}}], 
      LineBox[{{8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}}], 
      LineBox[{{8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}}], 
      LineBox[{{8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}}], 
      LineBox[{{8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}], 
      LineBox[{{8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}], 
      LineBox[{{8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}], 
      LineBox[{{8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}], 
      LineBox[{{8.242339007136907, 3.390840337436358}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}}], 
      LineBox[{{8.242339007136907, 3.390840337436358}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}}], 
      LineBox[{{8.242339007136907, 3.390840337436358}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}}], 
      LineBox[{{8.242339007136907, 3.390840337436358}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}}], 
      LineBox[{{8.307741603214543, 3.3706316882265632`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}], 
      LineBox[{{8.307741603214543, 3.3706316882265632`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}], 
      LineBox[{{8.307741603214543, 3.3706316882265632`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}], 
      LineBox[{{8.307741603214543, 3.3706316882265632`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}], 
      LineBox[{{8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.357944104845211, 
       3.324095703154776}}], 
      LineBox[{{8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.357944104845211, 
       3.324095703154776}}], 
      LineBox[{{8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.357944104845211, 
       3.324095703154776}}], 
      LineBox[{{8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.357944104845211, 
       3.324095703154776}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.18965751132395, 3.5932634932466447`}, {8.10207204708563, 
       3.6877497151341636`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.8767221589092014`}, {8.18965751132395, 
       3.9712083807967202`}, {8.18965751132395, 3.9712083807967202`}, {
       8.10207204708563, 3.8767221589092014`}, {8.080554220041012, 
       3.7822359370216825`}, {8.10207204708563, 3.6877497151341636`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.407864093889831, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466443`}, {8.18965751132395, 3.5932634932466443`}, {
       8.315277711905317, 3.5646553671577643`}, {8.407864093889831, 
       3.5932634932466447`}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.407864093889831, 3.9712083807967202`}, {
       8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.407864093889831, 
       3.9712083807967202`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.18965751132395, 3.5932634932466447`}, {8.10207204708563, 
       3.6877497151341636`}, {8.10207204708563, 3.6877497151341636`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}}], 
      LineBox[{{8.18965751132395, 3.5932634932466447`}, {8.10207204708563, 
       3.6877497151341636`}, {8.10207204708563, 3.6877497151341636`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}}], 
      LineBox[{{8.18965751132395, 3.5932634932466447`}, {8.10207204708563, 
       3.6877497151341636`}, {8.10207204708563, 3.6877497151341636`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}}], 
      LineBox[{{8.18965751132395, 3.5932634932466447`}, {8.10207204708563, 
       3.6877497151341636`}, {8.10207204708563, 3.6877497151341636`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}}], 
      LineBox[{{8.10207204708563, 3.6877497151341636`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}}], 
      LineBox[{{8.10207204708563, 3.6877497151341636`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}}], 
      LineBox[{{8.10207204708563, 3.6877497151341636`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}}], 
      LineBox[{{8.10207204708563, 3.6877497151341636`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}}], 
      LineBox[{{8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}], 
      LineBox[{{8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}], 
      LineBox[{{8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}], 
      LineBox[{{8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}], 
      LineBox[{{8.10207204708563, 3.8767221589092014`}, {8.18965751132395, 
       3.9712083807967207`}, {8.18965751132395, 3.9712083807967207`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}}], 
      LineBox[{{8.10207204708563, 3.8767221589092014`}, {8.18965751132395, 
       3.9712083807967207`}, {8.18965751132395, 3.9712083807967207`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}}], 
      LineBox[{{8.10207204708563, 3.8767221589092014`}, {8.18965751132395, 
       3.9712083807967207`}, {8.18965751132395, 3.9712083807967207`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}}], 
      LineBox[{{8.10207204708563, 3.8767221589092014`}, {8.18965751132395, 
       3.9712083807967207`}, {8.18965751132395, 3.9712083807967207`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}], 
      LineBox[{{8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}], 
      LineBox[{{8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}], 
      LineBox[{{8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}], 
      LineBox[{{8.478932648829726, 3.659141589045283}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.478932648829726, 3.659141589045283}, {8.478932648829726, 
       3.659141589045283}}], 
      LineBox[{{8.478932648829726, 3.659141589045283}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.478932648829726, 3.659141589045283}, {8.478932648829726, 
       3.659141589045283}}], 
      LineBox[{{8.478932648829726, 3.659141589045283}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.478932648829726, 3.659141589045283}, {8.478932648829726, 
       3.659141589045283}}], 
      LineBox[{{8.478932648829726, 3.659141589045283}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.478932648829726, 3.659141589045283}, {8.478932648829726, 
       3.659141589045283}}], 
      LineBox[{{8.407864093889831, 3.5932634932466447`}, {8.315277711905317, 
       3.5646553671577643`}, {8.315277711905317, 3.5646553671577643`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}}], 
      LineBox[{{8.407864093889831, 3.5932634932466447`}, {8.315277711905317, 
       3.5646553671577643`}, {8.315277711905317, 3.5646553671577643`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}}], 
      LineBox[{{8.407864093889831, 3.5932634932466447`}, {8.315277711905317, 
       3.5646553671577643`}, {8.315277711905317, 3.5646553671577643`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}}], 
      LineBox[{{8.407864093889831, 3.5932634932466447`}, {8.315277711905317, 
       3.5646553671577643`}, {8.315277711905317, 3.5646553671577643`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}}], 
      LineBox[{{8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}}], 
      LineBox[{{8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}}], 
      LineBox[{{8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}}], 
      LineBox[{{8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}], 
      LineBox[{{8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}], 
      LineBox[{{8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}], 
      LineBox[{{8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}], 
      LineBox[{{8.315277711905317, 3.9998165068856006`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}}], 
      LineBox[{{8.315277711905317, 3.9998165068856006`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}}], 
      LineBox[{{8.315277711905317, 3.9998165068856006`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}}], 
      LineBox[{{8.315277711905317, 3.9998165068856006`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}}], 
      LineBox[{{8.407864093889831, 3.9712083807967202`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}], 
      LineBox[{{8.407864093889831, 3.9712083807967202`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}], 
      LineBox[{{8.407864093889831, 3.9712083807967202`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}], 
      LineBox[{{8.407864093889831, 3.9712083807967202`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}], 
      LineBox[{{8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.478932648829726, 
       3.9053302849980818`}}], 
      LineBox[{{8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.478932648829726, 
       3.9053302849980818`}}], 
      LineBox[{{8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.478932648829726, 
       3.9053302849980818`}}], 
      LineBox[{{8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.478932648829726, 
       3.9053302849980818`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, 4.6}, {9.75, -5.4}, {9.75, -5.4}, {9.75, 4.6}, {9.75, 
       4.6}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, -5.4}, {0.75, -5.4}, {0.75, -5.4}, {9.75, -5.4}, {
       9.75, -5.4}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.75, -5.4}, {0.75, 4.6}, {0.75, 4.6}, {0.75, -5.4}, {
       0.75, -5.4}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.75, 4.6}, {9.75, 4.6}, {9.75, 4.6}, {0.75, 4.6}, {0.75, 
       4.6}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, -5.4}, {9.75, 4.6}, {0.75, 4.6}, {0.75, -5.4}, {
       9.75, -5.4}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, 4.6}, {9.75, -5.4}, {0.75, -5.4}, {0.75, 4.6}, {9.75, 
       4.6}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5634048176478567`*^9, 3.566101391046442*^9, 
  3.614727859261428*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[277]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[TurboPlot[
\t{Move[SingleRay[IntrinsicMedium->1.34],{0,-3}, 50],
\trodlens,
\tMove[ClearBoundary[9,10],{.75,-.4}]},
\tPlotType->TopView, ThresholdIntensity->.1, ColorView->Log[Intensity], 
\tCreateClones -> randomclonedata, ShowClones->False,
\tRunningCommentary->TurboTrace, ShowArrows->True]][[1]]\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[278]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278596635427`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859666395*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859668507*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859670454*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.1`"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "False"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"ShowArrows", "\[Rule]", "True"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.1`"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "False"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"ShowArrows", "\[Rule]", "True"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`ReportedSurfaces -> All, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`PlotType -> 
     Optica`Optica`TopView, Optica`Optica`ThresholdIntensity -> 0.1, 
     Optica`Optica`ColorView -> Log[Optica`Optica`Intensity], 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`ShowClones -> False, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`ShowArrows -> True, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`ReportedSurfaces -> 
     All, Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`PlotType -> Optica`Optica`TopView, 
     Optica`Optica`ThresholdIntensity -> 0.1, Optica`Optica`ColorView -> 
     Log[Optica`Optica`Intensity], 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`ShowClones -> False, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`ShowArrows -> True, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.61472785971248*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278597748957`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859777273*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.01117600000000000017019718967503649765`4.06888630638575", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.01117600000000000017019718967503649765`4.06888630638575, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.61472785977956*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859781686*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.61472785978379*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.61472785978585*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859789515*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859792048*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859794203*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859798037*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727859801298*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727860306876*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727860309394*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727860311756*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727860313979*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"SingleRay", "[", 
              RowBox[{"IntrinsicMedium", "\[Rule]", "1.34`"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "3.`"}]}], "}"}], ",", "50.00000000000001`"}], 
            "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "3.`"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "0.6427876096865393`", ",", "0.766044443118978`", ",", "0"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.766044443118978`"}], ",", "0.6427876096865393`",
               ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}], 
       "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`SingleRay[{
           Optica`Optica`Ray[]}, 1, Optica`Optica`IntrinsicMedium -> 1.34, 
          Optica`Optica`SourceTransformation -> {{
            0, -3., 0}, {{
             0.6427876096865393, 0.766044443118978, 0}, {-0.766044443118978, 
              0.6427876096865393, 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, -3, 0}, {{
              Sin[40 Degree], 
              Cos[40 Degree], 0}, {-Cos[40 Degree], 
              Sin[40 Degree], 0}, {
             0, 0, Cos[40 Degree]^2 + Sin[40 Degree]^2}}}]], 
       Optica`Optica`SourceTransformation :> {{
         0, -3., 0}, {{
          0.6427876096865393, 0.766044443118978, 0}, {-0.766044443118978, 
           0.6427876096865393, 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{0, -3, 0}, {{
           Sin[40 Degree], 
           Cos[40 Degree], 0}, {-Cos[40 Degree], 
           Sin[40 Degree], 0}, {0, 0, Cos[40 Degree]^2 + Sin[40 Degree]^2}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 1, 
       Optica`Optica`BirthPoint :> {0, 0, 0}, Optica`Optica`CoordinateSystem :> 
       Optica`Optica`CartesianCoordinates, Optica`Optica`StartAtBirthPoint :> 
       True, Optica`Optica`MonteCarlo :> False, Optica`Optica`SourceID :> 
       76680, Optica`Optica`SourceFraction :> 1, Optica`Optica`SourceOffset :> 
       0, Optica`Optica`GridSpacing :> (#& ), Optica`Optica`PowerOutput :> 
       Optica`Optica`PowerOutput, Optica`Optica`SymbolicValues -> {}, 
       Optica`Optica`IntrinsicMedium :> 1.34], False, False, False, 
      False, {{0, -3., 0}, {{
        0.6427876096865393, 0.766044443118978, 0}, {-0.766044443118978, 
         0.6427876096865393, 0}, {0, 0, 1.}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.61472786031673*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278610966797`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861099131*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861101597*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861349963*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861392137*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861396347*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861399609*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861401773*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "10"}],
  SequenceForm["maximum used clone sort position = ", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278619001713`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "212", ",", "104", ",", "32", ",", "12", ",", "3", ",", "1", ",", "0", 
     ",", "2", ",", "0", ",", "1"}], "}"}]}],
  SequenceForm[
  "Histogram of used sort positions: ", {212, 104, 32, 12, 3, 1, 0, 2, 0, 1}],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727861902808*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({212, 104, 32, 12, 3, 1, \
0, 2, 0, 1}\\)\\), \\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \
\[Rule] All\\)\\)\\)\\)]\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/optx\\\", \
ButtonNote -> \\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6147278619420557`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You may wish to set CloneSortLength -> \"\>", 
   "\[InvisibleSpace]", "11"}],
  SequenceForm["You may wish to set CloneSortLength -> ", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278619469233`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "0.58079300000000000370192765331012196839`5.7846212866746685", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "786", 
   "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   0.58079300000000000370192765331012196839`5.7846212866746685, 
   " seconds with ", 786, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278619740353`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862025272*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862027561*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862030045*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862032329*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278620345917`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862037217*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862039939*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862042144*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278620443*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862046617*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278620498133`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862053912*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278620571203`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862059224*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278620631332`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.6147278621774197`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.25000000000000006`, 
       0.4330127018922193}, {-0.25000000000000006`, 
       0.4330127018922193}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.2165063509461097}, \
{-0.25000000000000006`, -0.4330127018922193}, {-0.25000000000000006`, \
-0.4330127018922193}}, {{-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5,
        0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.5, 0.}}, {{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {-0.24999999999999992`, \
-0.43301270189221935`}, {-0.24999999999999992`, -0.43301270189221935`}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {
       0.41284695471649935`, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.41284695471649935`, 0.282059199426845}, {
       0.5, 5.551115123125783*^-17}, {0.5, 5.551115123125783*^-17}, {
       0.4128469547164993, 0.282059199426845}, {0.25, 0.4330127018922193}, {
       0.03784695471649929, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 
       0.4330127018922193}}, {{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}, {{-0.25000000000000006`, \
-0.4330127018922193}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.25000000000000006`, \
-0.4330127018922193}, {-0.25000000000000006`, -0.4330127018922193}}, \
{{-0.25000000000000006`, -0.4330127018922193}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.25000000000000006`, -0.4330127018922193}, {-0.25000000000000006`, \
-0.4330127018922193}}, {{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 
       0.2165063509461097}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 
       0.2165063509461097}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 
       0.2165063509461097}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 0.2165063509461097}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.25, 0.4330127018922193}, {0.4128469547164993,
        0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}, {{0.25, 
       0.4330127018922193}, {0.4128469547164993, 0.282059199426845}, {
       0.4128469547164993, 0.282059199426845}, {0.25, 0.4330127018922193}, {
       0.25, 0.4330127018922193}}, {{0.25, 0.4330127018922193}, {
       0.4128469547164993, 0.282059199426845}, {0.4128469547164993, 
       0.282059199426845}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}}, {{0.25, 0.4330127018922193}, {0.4128469547164993,
        0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}, {{
       0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}, {{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}, {{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}, {{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIIGZYc0MBBygPFnzQQB0QO4+Ojq8epneGGP
l0/IPiz6UezDwidJPyH/ELKPUPgQch8R4UuufwAQKIsK
      "]],
     FontColor->GrayLevel[0.]]}, 
   {Hue[0.], AbsoluteThickness[0.5], Arrowheads[Small], 
    ArrowBox[{{0., -3.}, {2.0057595224970246`, -0.6096288831841234}}], 
    {Hue[0.0006984182416297057], AbsoluteThickness[0.5], 
     LineBox[{{2.0057595224970246`, -0.6096288831841234}, {
      2.1524536851099523`, -0.4027414486582509}}]}, 
    {Hue[0.5054472814508388], AbsoluteThickness[0.5], 
     LineBox[{{2.1524536851099523`, -0.4027414486582509}, {
      1.9131901082507714`, -0.31863123109850405`}}]}, 
    {Hue[0.5047488632092489], AbsoluteThickness[0.5], 
     LineBox[{{2.0057595224970246`, -0.6096288831841234}, {
      2.0572524925149565`, -0.664171640311366}}]}, 
    {Hue[0.5052383171154798], AbsoluteThickness[0.5], 
     LineBox[{{2.0572524925149565`, -0.664171640311366}, {
      2.2655808876167085`, -0.8587988848431776}}]}, 
    {Hue[0.0013968364832597224`], AbsoluteThickness[0.5], 
     LineBox[{{2.1524536851099523`, -0.4027414486582509}, {
      2.1578986754883775`, -0.3935627672172498}}]}, 
    {Hue[0.0016739550214530884`], AbsoluteThickness[0.5], 
     LineBox[{{2.1578986754883775`, -0.3935627672172498}, {
      2.322288077237414, -0.1303204583266191}}]}, 
    {Hue[0.5998864615134317], AbsoluteThickness[0.5], 
     LineBox[{{2.322288077237414, -0.1303204583266191}, {
      2.2822116035470477`, -0.43807728579600586`}}]}, 
    {Hue[0.5057277710217108], AbsoluteThickness[0.5], 
     LineBox[{{2.2655808876167085`, -0.8587988848431776}, {
      2.3449662871755557`, -0.9241408299053153}}]}, 
    {Hue[0.5059786160627212], AbsoluteThickness[0.5], 
     LineBox[{{2.3449662871755557`, -0.9241408299053153}, {
      2.6222671111118836`, -1.1505767793820691`}}]}, 
    {Hue[0.5996093429752403], AbsoluteThickness[0.5], 
     LineBox[{{2.1578986754883775`, -0.3935627672172498}, {
      2.150858144595424, -0.39798697870710065`}}]}, 
    {Hue[0.5998828196221528], AbsoluteThickness[0.5], 
     LineBox[{{2.150858144595424, -0.39798697870710065`}, {
      1.8838360125468592`, -0.5579698938587627}}]}, 
    {Hue[0.0019510735596464544`], AbsoluteThickness[0.5], 
     LineBox[{{2.322288077237414, -0.1303204583266191}, {
      2.3399671150659884`, -0.10339700167155635`}}]}, 
    {Hue[0.0023044424296712273`], AbsoluteThickness[0.5], 
     LineBox[{{2.3399671150659884`, -0.10339700167155635`}, {
      2.526592142567949, 0.15571556587566326`}}]}, 
    {Hue[0.5759231091733608], AbsoluteThickness[0.5], 
     LineBox[{{2.526592142567949, 0.15571556587566326`}, {
      2.5751936803682303`, -0.1598887973300248}}]}, 
    {Hue[0.6001635800516251], AbsoluteThickness[0.5], 
     LineBox[{{2.2822116035470477`, -0.43807728579600586`}, {
      2.2663110500633756`, -0.5416736740948835}}]}, 
    {Hue[0.6004226376985863], AbsoluteThickness[0.5], 
     LineBox[{{2.2663110500633756`, -0.5416736740948835}, {
      2.2122149384715875`, -0.8654399415947518}}]}, 
    {Hue[0.5062294611037316], AbsoluteThickness[0.5], 
     LineBox[{{2.6222671111118836`, -1.1505767793820691`}, {
      2.657899719724758, -1.1794422816641232`}}]}, 
    {Hue[0.5065250267816214], AbsoluteThickness[0.5], 
     LineBox[{{2.657899719724758, -1.1794422816641232`}, {
      2.8857464297549953`, -1.353203343150097}}]}, 
    {Hue[0.5755697403033384], AbsoluteThickness[0.5], 
     LineBox[{{2.3399671150659884`, -0.10339700167155635`}, {
      2.117080480472663, -0.13173761788651203`}}]}, 
    {Hue[0.5762824732658735], AbsoluteThickness[0.5], 
     LineBox[{{2.117080480472663, -0.13173761788651203`}, {
      1.8103828445111985`, -0.14526970950124324`}}]}, 
    {Hue[0.002657811299696233], AbsoluteThickness[0.5], 
     LineBox[{{2.526592142567949, 0.15571556587566326`}, {2.562331689370879, 
      0.20107396171199415`}}]}, 
    {Hue[0.0032614238393702142`], AbsoluteThickness[0.5], 
     LineBox[{{2.562331689370879, 0.20107396171199415`}, {2.759695913748811, 
      0.4166873362596596}}]}, 
    {Hue[0.5227466977949582], AbsoluteThickness[0.5], 
     LineBox[{{2.759695913748811, 0.4166873362596596}, {2.890747432631562, 
      0.15540728775488238`}}]}, 
    {Hue[0.5762764780433858], AbsoluteThickness[0.5], 
     LineBox[{{2.5751936803682303`, -0.1598887973300248}, {
      2.598224218864824, -0.3691050724683141}}]}, 
    {Hue[0.5766188496545851], AbsoluteThickness[0.5], 
     LineBox[{{2.598224218864824, -0.3691050724683141}, {
      2.619885658132518, -0.6840564592920978}}]}, 
    {Hue[0.6006816953455474], AbsoluteThickness[0.5], 
     LineBox[{{2.2122149384715875`, -0.8654399415947518}, {
      2.1609640884490977`, -1.1489972660245826`}}]}, 
    {Hue[0.6012894381191202], AbsoluteThickness[0.5], 
     LineBox[{{2.1609640884490977`, -1.1489972660245826`}, {
      2.133774164976964, -1.4080821214719481`}}]}, 
    {Hue[0.5068205924595112], AbsoluteThickness[0.5], 
     LineBox[{{2.8857464297549953`, -1.353203343150097}, {
      2.919671199113701, -1.3775354117154697`}}]}, 
    {Hue[0.507123030429096], AbsoluteThickness[0.5], 
     LineBox[{{2.919671199113701, -1.3775354117154697`}, {
      3.1668606381265754`, -1.5668476191667187`}}]}, 
    {Hue[0.5221430852552855], AbsoluteThickness[0.5], 
     LineBox[{{2.562331689370879, 0.20107396171199415`}, {2.315053113289803, 
      0.3206700433792277}}]}, 
    {Hue[0.523074863619754], AbsoluteThickness[0.5], 
     LineBox[{{2.315053113289803, 0.3206700433792277}, {2.145301204605659, 
      0.3835451026245137}}]}, 
    {Hue[0.0038650363790441954`], AbsoluteThickness[0.5], 
     LineBox[{{2.759695913748811, 0.4166873362596596}, {2.884959687765593, 
      0.5347146380840315}}]}, 
    {Hue[0.004570305927167495], AbsoluteThickness[0.5], 
     LineBox[{{2.884959687765593, 0.5347146380840315}, {3.0719563301840584`, 
      0.6840278035828851}}]}, 
    {Hue[0.508333334558453], AbsoluteThickness[0.5], 
     LineBox[{{3.0719563301840584`, 0.6840278035828851}, {3.1652586420829425`,
       0.4636716276735388}}]}, 
    {Hue[0.5233503103346321], AbsoluteThickness[0.5], 
     LineBox[{{2.890747432631562, 0.15540728775488236`}, {2.926674019757295, 
      0.06825700326385231}}]}, 
    {Hue[0.5236879655691472], AbsoluteThickness[0.5], 
     LineBox[{{2.926674019757295, 0.06825700326385231}, {
      3.053158462193541, -0.20681336942297165`}}]}, 
    {Hue[0.5769612212657845], AbsoluteThickness[0.5], 
     LineBox[{{2.619885658132518, -0.6840564592920978}, {
      2.626384788551293, -0.9186282110858862}}]}, 
    {Hue[0.5783075892637058], AbsoluteThickness[0.5], 
     LineBox[{{2.626384788551293, -0.9186282110858862}, {
      2.6048183394469935`, -1.1678424339120792`}}]}, 
    {Hue[0.6018971808926928], AbsoluteThickness[0.5], 
     LineBox[{{2.133774164976964, -1.4080821214719481`}, {
      2.133472656793686, -1.4180250752287131`}}]}, 
    {Hue[0.6049267837289336], AbsoluteThickness[0.5], 
     LineBox[{{2.133472656793686, -1.4180250752287131`}, {
      2.0982491467979005`, -1.6049025442929639`}}]}, 
    {Hue[0.5074254683986807], AbsoluteThickness[0.5], 
     LineBox[{{3.1668606381265754`, -1.5668476191667187`}, {
      3.186294739365268, -1.5827228782597558`}}]}, 
    {Hue[0.5078018458462533], AbsoluteThickness[0.5], 
     LineBox[{{3.186294739365268, -1.5827228782597558`}, {
      3.4068474628655636`, -1.7809977290467776`}}]}, 
    {Hue[0.5240066419842225], AbsoluteThickness[0.5], 
     LineBox[{{2.145301204605659, 0.3835451026245137}, {2.1388768873800896`, 
      0.38524703259711673`}}]}, 
    {Hue[0.5243363186546364], AbsoluteThickness[0.5], 
     LineBox[{{2.1388768873800896`, 0.38524703259711673`}, {
      1.9225372764660171`, 0.4515086228717923}}]}, 
    {Hue[0.507628065010331], AbsoluteThickness[0.5], 
     LineBox[{{2.884959687765593, 0.5347146380840315}, {2.8387901747001596`, 
      0.5740424715130942}}]}, 
    {Hue[0.5079443494430121], AbsoluteThickness[0.5], 
     LineBox[{{2.8387901747001596`, 0.5740424715130942}, {2.6079754353798683`,
       0.7850581245776878}}]}, 
    {Hue[0.005275575475290717], AbsoluteThickness[0.5], 
     LineBox[{{3.0719563301840584`, 0.6840278035828851}, {3.1192976245265713`,
       0.7158603125897975}}]}, 
    {Hue[0.005690574810235815], AbsoluteThickness[0.5], 
     LineBox[{{3.1192976245265713`, 0.7158603125897975}, {3.3495594464842493`,
       0.8534593070643108}}]}, 
    {Hue[0.5630484833320478], AbsoluteThickness[0.5], 
     LineBox[{{3.3495594464842493`, 0.8534593070643108}, {3.3229078296137677`,
       0.586544187129423}}]}, 
    {Hue[0.5090386041065764], AbsoluteThickness[0.5], 
     LineBox[{{3.1652586420829425`, 0.46367162767353887`}, {3.180275373749244,
       0.4181558971516055}}]}, 
    {Hue[0.5092891029666765], AbsoluteThickness[0.5], 
     LineBox[{{3.180275373749244, 0.4181558971516055}, {3.2840522160329475`, 
      0.10664712006415028`}}]}, 
    {Hue[0.5240256208036622], AbsoluteThickness[0.5], 
     LineBox[{{3.053158462193541, -0.20681336942297165`}, {
      3.1075070467475716`, -0.3135470700997336}}]}, 
    {Hue[0.5361604338605724], AbsoluteThickness[0.5], 
     LineBox[{{3.1075070467475716`, -0.3135470700997336}, {
      3.2086546059783285`, -0.4311580826759991}}]}, 
    {Hue[0.5796539572616272], AbsoluteThickness[0.5], 
     LineBox[{{2.6048183394469935`, -1.1678424339120792`}, {
      2.562124487837752, -1.3780855304786805`}}]}, 
    {Hue[0.5799831051919531], AbsoluteThickness[0.5], 
     LineBox[{{2.562124487837752, -1.3780855304786808`}, {
      2.4960778137729345`, -1.6497783337188168`}}]}, 
    {Hue[0.6079563865651745], AbsoluteThickness[0.5], 
     LineBox[{{2.0982491467979005`, -1.6049025442929639`}, {
      2.035825571359303, -1.7800981572509627`}}]}, 
    {Hue[0.6082465460417661], AbsoluteThickness[0.5], 
     LineBox[{{2.035825571359303, -1.7800981572509627`}, {
      1.9339456040502492`, -2.0930931048322563`}}]}, 
    {Hue[0.5081782232938257], AbsoluteThickness[0.5], 
     LineBox[{{3.4068474628655636`, -1.7809977290467776`}, {
      3.4841357052850315`, -1.857389879180337}}]}, 
    {Hue[0.5086104497711691], AbsoluteThickness[0.5], 
     LineBox[{{3.4841357052850315`, -1.857389879180337}, {
      3.6442254350001297`, -2.0343075535321256`}}]}, 
    {Hue[0.5082606338756932], AbsoluteThickness[0.5], 
     LineBox[{{2.6079754353798683`, 0.7850581245776878}, {2.5262122235272906`,
       0.8652485350415453}}]}, 
    {Hue[0.5085432846311001], AbsoluteThickness[0.5], 
     LineBox[{{2.5262122235272906`, 0.8652485350415453}, {2.3595564071635504`,
       1.0370677310232241`}}]}, 
    {Hue[0.562633483997103], AbsoluteThickness[0.5], 
     LineBox[{{3.1192976245265713`, 0.7158603125897975}, {2.878105302061931, 
      0.831577436122447}}]}, 
    {Hue[0.568985710431421], AbsoluteThickness[0.5], 
     LineBox[{{2.878105302061931, 0.831577436122447}, {2.7078234378874186`, 
      0.8748856225899269}}]}, 
    {Hue[0.006105574145180759], AbsoluteThickness[0.5], 
     LineBox[{{3.3495594464842493`, 0.8534593070643108}, {3.434771488581592, 
      0.898397925981593}}]}, 
    {Hue[0.00642150503379375], AbsoluteThickness[0.5], 
     LineBox[{{3.434771488581592, 0.898397925981593}, {3.6935617283990547`, 
      1.0466703619730766`}}]}, 
    {Hue[0.5913702073416345], AbsoluteThickness[0.5], 
     LineBox[{{3.6935617283990547`, 1.0466703619730766`}, {3.397531617632724, 
      1.0830472367605362`}}]}, 
    {Hue[0.5634634826669929], AbsoluteThickness[0.5], 
     LineBox[{{3.3229078296137677`, 0.586544187129423}, {3.2967317354914045`, 
      0.4166262597602889}}]}, 
    {Hue[0.5637372443819719], AbsoluteThickness[0.5], 
     LineBox[{{3.2967317354914045`, 0.4166262597602889}, {3.240943984663697, 
      0.09966878177752483}}]}, 
    {Hue[0.5095396018267765], AbsoluteThickness[0.5], 
     LineBox[{{3.2840522160329475`, 0.1066471200641503}, {3.3037815204379273`,
       0.04799309088020727}}]}, 
    {Hue[0.5104793862554748], AbsoluteThickness[0.5], 
     LineBox[{{3.3037815204379273`, 0.04799309088020727}, {
      3.402876861217091, -0.1735172436366787}}]}, 
    {Hue[0.5482952469174828], AbsoluteThickness[0.5], 
     LineBox[{{3.2086546059783285`, -0.4311580826759991}, {
      3.3621328400631714`, -0.5410088229182005}}]}, 
    {Hue[0.5489099758182514], AbsoluteThickness[0.5], 
     LineBox[{{3.3621328400631714`, -0.5410088229182005}, {
      3.5930234001406385`, -0.681419516580333}}]}, 
    {Hue[0.580312253122279], AbsoluteThickness[0.5], 
     LineBox[{{2.4960778137729345`, -1.6497783337188168`}, {
      2.4529500674139535`, -1.8017079734883679`}}]}, 
    {Hue[0.5806610650091881], AbsoluteThickness[0.5], 
     LineBox[{{2.4529500674139535`, -1.8017079734883679`}, {
      2.3835651345106648`, -2.0923772938207934`}}]}, 
    {Hue[0.5090426762485125], AbsoluteThickness[0.5], 
     LineBox[{{3.6442254350001297`, -2.0343075535321256`}, {
      3.7063099664022916`, -2.111116037091862}}]}, 
    {Hue[0.5092929942764977], AbsoluteThickness[0.5], 
     LineBox[{{3.7063099664022916`, -2.111116037091862}, {
      3.874759576808256, -2.3204557397705634`}}]}, 
    {Hue[0.5088259353865069], AbsoluteThickness[0.5], 
     LineBox[{{2.3595564071635504`, 1.0370677310232241`}, {2.324064739293538, 
      1.0755355372213158`}}]}, 
    {Hue[0.5091088241892707], AbsoluteThickness[0.5], 
     LineBox[{{2.324064739293538, 1.0755355372213158`}, {2.1112499724252753`, 
      1.3181169909155468`}}]}, 
    {Hue[0.5753379368657391], AbsoluteThickness[0.5], 
     LineBox[{{2.7078234378874186`, 0.8748856225899269}, {2.5492637390996893`,
       0.8829426230425576}}]}, 
    {Hue[0.576079807406188], AbsoluteThickness[0.5], 
     LineBox[{{2.5492637390996893`, 0.8829426230425576}, {2.3570365433542526`,
       0.9090849426453752}}]}, 
    {Hue[0.591054276453022], AbsoluteThickness[0.5], 
     LineBox[{{3.434771488581592, 0.898397925981593}, {3.397817859335394, 
      0.8039556211645178}}]}, 
    {Hue[0.5916267690072754], AbsoluteThickness[0.5], 
     LineBox[{{3.397817859335394, 0.8039556211645178}, {3.290340568477714, 
      0.5780718594597383}}]}, 
    {Hue[0.00673743592240682], AbsoluteThickness[0.5], 
     LineBox[{{3.6935617283990547`, 1.0466703619730766`}, {4.09778113032579, 
      1.2974398878257305`}}]}, 
    {Hue[0.007443177497119645], AbsoluteThickness[0.5], 
     LineBox[{{4.09778113032579, 1.2974398878257305`}, {4.322339227582955, 
      1.4124662394387297`}}]}, 
    {Hue[0.5111386404877363], AbsoluteThickness[0.5], 
     LineBox[{{4.322339227582955, 1.4124662394387297`}, {4.372581401440376, 
      1.1652151027876794`}}]}, 
    {Hue[0.5916861382302475], AbsoluteThickness[0.5], 
     LineBox[{{3.397531617632724, 1.0830472367605362`}, {3.155478576023977, 
      1.1042292706599504`}}]}, 
    {Hue[0.5925582456318244], AbsoluteThickness[0.5], 
     LineBox[{{3.155478576023977, 1.1042292706599504`}, {2.8881206173645815`, 
      1.1028432980780056`}}]}, 
    {Hue[0.564011006096951], AbsoluteThickness[0.5], 
     LineBox[{{3.240943984663697, 0.09966878177752486}, {
      3.1935225576149433`, -0.1396703132236858}}]}, 
    {Hue[0.5645702362859336], AbsoluteThickness[0.5], 
     LineBox[{{3.1935225576149433`, -0.1396703132236858}, {
      3.1602476648612527`, -0.40300219196227094`}}]}, 
    {Hue[0.5114191706841731], AbsoluteThickness[0.5], 
     LineBox[{{3.402876861217091, -0.1735172436366787}, {
      3.5126419992775526`, -0.3666398651512959}}]}, 
    {Hue[0.511773056393962], AbsoluteThickness[0.5], 
     LineBox[{{3.5126419992775526`, -0.3666398651512959}, {
      3.6516307889607824`, -0.6378478460211757}}]}, 
    {Hue[0.54952470471902], AbsoluteThickness[0.5], 
     LineBox[{{3.5930234001406385`, -0.681419516580333}, {
      3.6371702539592277`, -0.7039298902161868}}]}, 
    {Hue[0.5498161020134159], AbsoluteThickness[0.5], 
     LineBox[{{3.6371702539592277`, -0.7039298902161868}, {
      3.9040058465995213`, -0.8307028828131623}}]}, 
    {Hue[0.5810098768960973], AbsoluteThickness[0.5], 
     LineBox[{{2.3835651345106648`, -2.0923772938207934`}, {
      2.3816789559153757`, -2.102077311626115}}]}, 
    {Hue[0.5813807127078275], AbsoluteThickness[0.5], 
     LineBox[{{2.3816789559153757`, -2.102077311626115}, {
      2.3082072592650524`, -2.404390344792868}}]}, 
    {Hue[0.5095433123044829], AbsoluteThickness[0.5], 
     LineBox[{{3.874759576808256, -2.3204557397705634`}, {
      3.8935429556334253`, -2.3439041284756716`}}]}, 
    {Hue[0.5098014305062537], AbsoluteThickness[0.5], 
     LineBox[{{3.8935429556334253`, -2.3439041284756716`}, {
      4.093305908826973, -2.599796826317024}}]}, 
    {Hue[0.5093917129920346], AbsoluteThickness[0.5], 
     LineBox[{{2.111249972425276, 1.3181169909155468`}, {2.071913095859471, 
      1.3652890752709912`}}]}, 
    {Hue[0.5096892601341962], AbsoluteThickness[0.5], 
     LineBox[{{2.071913095859471, 1.3652890752709912`}, {1.8520985852590892`, 
      1.6455325677180772`}}]}, 
    {Hue[0.576821677946637], AbsoluteThickness[0.5], 
     LineBox[{{2.3570365433542526`, 0.9090849426453752}, {2.1539696830887394`,
       0.9544019959572525}}]}, 
    {Hue[0.5770733338951188], AbsoluteThickness[0.5], 
     LineBox[{{2.1539696830887394`, 0.9544019959572525}, {1.8252061047451482`,
       1.0297001744715277`}}]}, 
    {Hue[0.5921992615615289], AbsoluteThickness[0.5], 
     LineBox[{{3.290340568477714, 0.5780718594597383}, {3.2035081745924443`, 
      0.42472986346914665`}}]}, 
    {Hue[0.5928771126561931], AbsoluteThickness[0.5], 
     LineBox[{{3.2035081745924443`, 0.42472986346914665`}, {
      3.0921862004706124`, 0.18541994994391708`}}]}, 
    {Hue[0.5104328989130236], AbsoluteThickness[0.5], 
     LineBox[{{4.09778113032579, 1.2974398878257305`}, {4.056248075475014, 
      1.350469295756881}}]}, 
    {Hue[0.5107658651122815], AbsoluteThickness[0.5], 
     LineBox[{{4.056248075475014, 1.350469295756881}, {3.8929300337950536`, 
      1.5766207784671864`}}]}, 
    {Hue[0.008148919071832472], AbsoluteThickness[0.5], 
     LineBox[{{4.322339227582955, 1.4124662394387297`}, {4.401946300678768, 
      1.4453291751734867`}}]}, 
    {Hue[0.00844586761477043], AbsoluteThickness[0.5], 
     LineBox[{{4.401946300678768, 1.4453291751734867`}, {4.639027104771191, 
      1.5350408947108012`}}]}, 
    {Hue[0.5996644561122245], AbsoluteThickness[0.5], 
     LineBox[{{4.639027104771191, 1.5350408947108012`}, {4.484322272687586, 
      1.3342377193837285`}}]}, 
    {Hue[0.5118443820624491], AbsoluteThickness[0.5], 
     LineBox[{{4.372581401440376, 1.1652151027876794`}, {4.377205806847783, 
      1.1264033529970723`}}]}, 
    {Hue[0.5125831247740936], AbsoluteThickness[0.5], 
     LineBox[{{4.377205806847783, 1.1264033529970723`}, {4.4337968371013785`, 
      0.8511574427761879}}]}, 
    {Hue[0.5934303530334012], AbsoluteThickness[0.5], 
     LineBox[{{2.8881206173645815`, 1.1028432980780056`}, {2.887952201065457, 
      1.1028267988437523`}}]}, 
    {Hue[0.5944772053651027], AbsoluteThickness[0.5], 
     LineBox[{{2.887952201065457, 1.1028267988437523`}, {2.63041074531098, 
      1.1038229970616666`}}]}, 
    {Hue[0.5651294664749162], AbsoluteThickness[0.5], 
     LineBox[{{3.1602476648612527`, -0.403002191962271}, {
      3.1575195364227686`, -0.4518529719779685}}]}, 
    {Hue[0.6139476110468971], AbsoluteThickness[0.5], 
     LineBox[{{3.1575195364227686`, -0.4518529719779685}, {
      3.1049712786497565`, -0.5783033143222391}}]}, 
    {Hue[0.512126942103751], AbsoluteThickness[0.5], 
     LineBox[{{3.6516307889607824`, -0.6378478460211757}, {
      3.657663175401423, -0.6509898317253643}}]}, 
    {Hue[0.512604339376677], AbsoluteThickness[0.5], 
     LineBox[{{3.657663175401423, -0.6509898317253643}, {
      3.7827229899629944`, -0.884500781808272}}]}, 
    {Hue[0.5501074993078117], AbsoluteThickness[0.5], 
     LineBox[{{3.9040058465995213`, -0.8307028828131623}, {
      3.9590736494704477`, -0.8549994634341331}}]}, 
    {Hue[0.5511320671221298], AbsoluteThickness[0.5], 
     LineBox[{{3.9590736494704477`, -0.8549994634341331}, {
      4.165566362097177, -0.9721295441292566}}]}, 
    {Hue[0.5817515485195577], AbsoluteThickness[0.5], 
     LineBox[{{2.3082072592650524`, -2.404390344792868}, {
      2.2682929331120336`, -2.5407467680039284`}}]}, 
    {Hue[0.5820333092826582], AbsoluteThickness[0.5], 
     LineBox[{{2.2682929331120336`, -2.5407467680039284`}, {
      2.185664890153586, -2.851186344944465}}]}, 
    {Hue[0.5100595487080243], AbsoluteThickness[0.5], 
     LineBox[{{4.093305908826973, -2.599796826317024}, {
      4.151465678249319, -2.67625780693059}}]}, 
    {Hue[0.5104590504970612], AbsoluteThickness[0.5], 
     LineBox[{{4.151465678249319, -2.67625780693059}, {
      4.322245232521425, -2.878474488428985}}]}, 
    {Hue[0.5935549637508575], AbsoluteThickness[0.5], 
     LineBox[{{3.0921862004706124`, 0.18541994994391706`}, {3.065995509630361,
       0.11489102366003237`}}]}, 
    {Hue[0.5938254907703033], AbsoluteThickness[0.5], 
     LineBox[{{3.065995509630361, 0.11489102366003237`}, {
      2.9611949450666817`, -0.18550602667593305`}}]}, 
    {Hue[0.5110988313115393], AbsoluteThickness[0.5], 
     LineBox[{{3.8929300337950536`, 1.5766207784671864`}, {3.85176580778695, 
      1.6385721677206893`}}]}, 
    {Hue[0.5113508008509164], AbsoluteThickness[0.5], 
     LineBox[{{3.85176580778695, 1.6385721677206893`}, {3.6736378446791274`, 
      1.9102396054982829`}}]}, 
    {Hue[0.5993675075692856], AbsoluteThickness[0.5], 
     LineBox[{{4.401946300678768, 1.4453291751734867`}, {4.165111682215218, 
      1.4984400782922525`}}]}, 
    {Hue[0.5996483380076668], AbsoluteThickness[0.5], 
     LineBox[{{4.165111682215218, 1.4984400782922525`}, {3.880892514534948, 
      1.5549678069179746`}}]}, 
    {Hue[0.008742816157708232], AbsoluteThickness[0.5], 
     LineBox[{{4.639027104771191, 1.5350408947108012`}, {4.690402334154036, 
      1.552752769373349}}]}, 
    {Hue[0.011522424060997925`], AbsoluteThickness[0.5], 
     LineBox[{{4.690402334154036, 1.552752769373349}, {4.857078604958443, 
      1.640235252655255}}]}, 
    {Hue[0.37733604035103746`], AbsoluteThickness[0.5], 
     LineBox[{{4.857078604958443, 1.640235252655255}, {4.815379860125142, 
      1.8237982631169498`}}]}, 
    {Hue[0.5999614046551623], AbsoluteThickness[0.5], 
     LineBox[{{4.484322272687586, 1.3342377193837285`}, {4.409779724145657, 
      1.2432182104078344`}}]}, 
    {Hue[0.6025511994881575], AbsoluteThickness[0.5], 
     LineBox[{{4.409779724145657, 1.2432182104078344`}, {4.265048727539498, 
      1.1118551698327606`}}]}, 
    {Hue[0.5133218674857383], AbsoluteThickness[0.5], 
     LineBox[{{4.4337968371013785`, 0.8511574427761879}, {4.507220549774859, 
      0.6023534043302959}}]}, 
    {Hue[0.5135721603838945], AbsoluteThickness[0.5], 
     LineBox[{{4.507220549774859, 0.6023534043302959}, {4.584281929210271, 
      0.34321424667544764`}}]}, 
    {Hue[0.5955240576968044], AbsoluteThickness[0.5], 
     LineBox[{{2.63041074531098, 1.1038229970616666`}, {2.384421795662814, 
      1.129844562814681}}]}, 
    {Hue[0.595912405890139], AbsoluteThickness[0.5], 
     LineBox[{{2.384421795662814, 1.129844562814681}, {2.0872857489267846`, 
      1.1761752005146207`}}]}, 
    {Hue[0.6625737624859763], AbsoluteThickness[0.5], 
     LineBox[{{3.1575195364227686`, -0.45185297197796853`}, {
      3.1881655411724616`, -0.6279252255437815}}]}, 
    {Hue[0.6628238620076692], AbsoluteThickness[0.5], 
     LineBox[{{3.1881655411724616`, -0.6279252255437815}, {
      3.2428156339487058`, -0.9432701895219495}}]}, 
    {Hue[0.6627657556188804], AbsoluteThickness[0.5], 
     LineBox[{{3.1049712786497565`, -0.5783033143222391}, {
      2.9322504268366436`, -0.770563182991037}}]}, 
    {Hue[0.6637875899053528], AbsoluteThickness[0.5], 
     LineBox[{{2.9322504268366436`, -0.770563182991037}, {
      2.7741870462480316`, -0.9144711919203071}}]}, 
    {Hue[0.5130817366496031], AbsoluteThickness[0.5], 
     LineBox[{{3.7827229899629944`, -0.884500781808272}, {
      3.8486266664624913`, -0.991258733427973}}]}, 
    {Hue[0.5144334360463964], AbsoluteThickness[0.5], 
     LineBox[{{3.8486266664624913`, -0.991258733427973}, {
      3.9876097945624047`, -1.1676713670292798`}}]}, 
    {Hue[0.5521566349364481], AbsoluteThickness[0.5], 
     LineBox[{{4.165566362097177, -0.9721295441292566}, {
      4.2855558386027734`, -1.0571474471857623`}}]}, 
    {Hue[0.5564561712606058], AbsoluteThickness[0.5], 
     LineBox[{{4.2855558386027734`, -1.0571474471857623`}, {
      4.413559188371867, -1.1868132865489185`}}]}, 
    {Hue[0.5823150700457588], AbsoluteThickness[0.5], 
     LineBox[{{2.185664890153586, -2.851186344944465}, {
      2.1772094809357454`, -2.886423857286903}}]}, 
    {Hue[0.5830052679788669], AbsoluteThickness[0.5], 
     LineBox[{{2.1772094809357454`, -2.886423857286903}, {
      2.093854922310317, -3.141142055098796}}]}, 
    {Hue[0.510858552286098], AbsoluteThickness[0.5], 
     LineBox[{{4.322245232521425, -2.878474488428985}, {
      4.336259927609953, -2.893447573783807}}]}, 
    {Hue[0.5111384764653408], AbsoluteThickness[0.5], 
     LineBox[{{4.336259927609953, -2.893447573783807}, {
      4.536974286384927, -3.0978578583771914`}}]}, 
    {Hue[0.5940960177897491], AbsoluteThickness[0.5], 
     LineBox[{{2.9611949450666817`, -0.18550602667593308`}, {
      2.91370407915002, -0.33086694872873623`}}]}, 
    {Hue[0.5954159130308965], AbsoluteThickness[0.5], 
     LineBox[{{2.9137040791500204`, -0.33086694872873623`}, {
      2.869462482917449, -0.546080146008283}}]}, 
    {Hue[0.5116027703902937], AbsoluteThickness[0.5], 
     LineBox[{{3.6736378446791274`, 1.9102396054982829`}, {3.653201644779335, 
      1.9418267806722693`}}]}, 
    {Hue[0.5119747513310338], AbsoluteThickness[0.5], 
     LineBox[{{3.653201644779335, 1.9418267806722693`}, {3.5129175912493507`, 
      2.1379949850517783`}}]}, 
    {Hue[0.5999291684460482], AbsoluteThickness[0.5], 
     LineBox[{{3.880892514534948, 1.5549678069179746`}, {3.5268130045874777`, 
      1.6164949021185344`}}]}, 
    {Hue[0.6099464428281186], AbsoluteThickness[0.5], 
     LineBox[{{3.5268130045874777`, 1.6164949021185344`}, {3.386623758344888, 
      1.608820183043115}}]}, 
    {Hue[0.37455643244774767`], AbsoluteThickness[0.5], 
     LineBox[{{4.690402334154036, 1.552752769373349}, {4.8482580927697025`, 
      1.4261053727649216`}}]}, 
    {Hue[0.3780341572100907], AbsoluteThickness[0.5], 
     LineBox[{{4.8482580927697025`, 1.4261053727649216`}, {5.020868945221469, 
      1.3289605808045484`}}]}, 
    {Hue[0.014302031964287542`], AbsoluteThickness[0.5], 
     LineBox[{{4.857078604958443, 1.640235252655255}, {5.079518299633321, 
      1.8040216364606694`}}]}, 
    {Hue[0.015686247433292822`], AbsoluteThickness[0.5], 
     LineBox[{{5.079518299633321, 1.8040216364606694`}, {5.235914376607862, 
      1.8934186160185054`}}]}, 
    {Hue[0.45145504008651893`], AbsoluteThickness[0.5], 
     LineBox[{{5.235914376607862, 1.8934186160185054`}, {5.3308119784895664`, 
      1.7402977552444332`}}]}, 
    {Hue[0.38011564825432714`], AbsoluteThickness[0.5], 
     LineBox[{{4.815379860125142, 1.8237982631169498`}, {4.704968410826926, 
      2.1045280286377457`}}]}, 
    {Hue[0.38055059193490703`], AbsoluteThickness[0.5], 
     LineBox[{{4.704968410826926, 2.1045280286377457`}, {4.61744044815143, 
      2.3698675239156}}]}, 
    {Hue[0.6051409943211526], AbsoluteThickness[0.5], 
     LineBox[{{4.265048727539498, 1.1118551698327606`}, {4.191006447728154, 
      1.0623394781541469`}}]}, 
    {Hue[0.6055108938735394], AbsoluteThickness[0.5], 
     LineBox[{{4.191006447728154, 1.0623394781541469`}, {3.9426486256570685`, 
      0.9123666428044666}}]}, 
    {Hue[0.5138224532820508], AbsoluteThickness[0.5], 
     LineBox[{{4.584281929210271, 0.34321424667544764`}, {4.598042245538953, 
      0.2972922203574837}}]}, 
    {Hue[0.5173394387387933], AbsoluteThickness[0.5], 
     LineBox[{{4.598042245538953, 0.2972922203574837}, {4.667619659074758, 
      0.1551758546767747}}]}, 
    {Hue[0.6630739615293619], AbsoluteThickness[0.5], 
     LineBox[{{3.2428156339487058`, -0.9432701895219495}, {
      3.2672401740993666`, -1.0848192555319773`}}]}, 
    {Hue[0.6634827436403169], AbsoluteThickness[0.5], 
     LineBox[{{3.2672401740993666`, -1.0848192555319773`}, {
      3.302423722577122, -1.3804782455114837`}}]}, 
    {Hue[0.6648094241918253], AbsoluteThickness[0.5], 
     LineBox[{{2.7741870462480316`, -0.9144711919203071}, {
      2.6634137144804533`, -0.9966424944432735}}]}, 
    {Hue[0.6651668318960517], AbsoluteThickness[0.5], 
     LineBox[{{2.6634137144804533`, -0.9966424944432735}, {
      2.389395151973833, -1.1818272549535742`}}]}, 
    {Hue[0.5157851354431897], AbsoluteThickness[0.5], 
     LineBox[{{3.9876097945624047`, -1.1676713670292798`}, {
      4.117418951062059, -1.2984977737291599`}}]}, 
    {Hue[0.5316611251050058], AbsoluteThickness[0.5], 
     LineBox[{{4.117418951062059, -1.2984977737291599`}, {
      4.249196829209725, -1.3760337788472405`}}]}, 
    {Hue[0.5607557075847636], AbsoluteThickness[0.5], 
     LineBox[{{4.413559188371867, -1.1868132865489185`}, {
      4.520687658894766, -1.3422212394170174`}}]}, 
    {Hue[0.5611328359262774], AbsoluteThickness[0.5], 
     LineBox[{{4.520687658894766, -1.3422212394170174`}, {
      4.665944662141629, -1.5759320171915738`}}]}, 
    {Hue[0.5836954659119749], AbsoluteThickness[0.5], 
     LineBox[{{2.093854922310317, -3.141142055098796}, {
      2.015073567382969, -3.329039238471807}}]}, 
    {Hue[0.5839669538010898], AbsoluteThickness[0.5], 
     LineBox[{{2.015073567382969, -3.329039238471807}, {
      1.9001977368547118`, -3.619455579289954}}]}, 
    {Hue[0.5114184006445837], AbsoluteThickness[0.5], 
     LineBox[{{4.536974286384927, -3.0978578583771914`}, {
      4.625636876800455, -3.1839333552388043`}}]}, 
    {Hue[0.5116934437708162], AbsoluteThickness[0.5], 
     LineBox[{{4.625636876800455, -3.1839333552388043`}, {
      4.859848789732709, -3.4015390447426364`}}]}, 
    {Hue[0.5967358082720439], AbsoluteThickness[0.5], 
     LineBox[{{2.869462482917449, -0.546080146008283}, {
      2.8605450271013546`, -0.6452105965613067}}]}, 
    {Hue[0.5970938637642148], AbsoluteThickness[0.5], 
     LineBox[{{2.8605450271013546`, -0.6452105965613067}, {
      2.8248949924384474`, -0.9101405802514051}}]}, 
    {Hue[0.5123467322717739], AbsoluteThickness[0.5], 
     LineBox[{{3.5129175912493507`, 2.1379949850517783`}, {
      3.4555409370353796`, 2.2108115237801984`}}]}, 
    {Hue[0.5131764871129567], AbsoluteThickness[0.5], 
     LineBox[{{3.4555409370353796`, 2.2108115237801984`}, {
      3.2842800095888456`, 2.3919584300683443`}}]}, 
    {Hue[0.6199637172101895], AbsoluteThickness[0.5], 
     LineBox[{{3.386623758344888, 1.608820183043115}, {3.1559906912543387`, 
      1.5421434109361416`}}]}, 
    {Hue[0.6202155109806631], AbsoluteThickness[0.5], 
     LineBox[{{3.1559906912543387`, 1.5421434109361416`}, {
      2.8247909919150596`, 1.4484788790159686`}}]}, 
    {Hue[0.38151188197243363`], AbsoluteThickness[0.5], 
     LineBox[{{5.020868945221469, 1.3289605808045484`}, {5.080827942751603, 
      1.3071357408753943`}}]}, 
    {Hue[0.3817633180930618], AbsoluteThickness[0.5], 
     LineBox[{{5.080827942751603, 1.3071357408753943`}, {5.392300601042003, 
      1.1919288347385042`}}]}, 
    {Hue[0.4500708246175139], AbsoluteThickness[0.5], 
     LineBox[{{5.079518299633321, 1.8040216364606694`}, {5.0661489990133335`, 
      1.8386618650983477`}}]}, 
    {Hue[0.4503283453123157], AbsoluteThickness[0.5], 
     LineBox[{{5.0661489990133335`, 1.8386618650983477`}, {4.976273040463918, 
      2.0801780988890197`}}]}, 
    {Hue[0.017070462902297943`], AbsoluteThickness[0.5], 
     LineBox[{{5.235914376607862, 1.8934186160185054`}, {5.437919403936263, 
      1.9797487223042358`}}]}, 
    {Hue[0.017325528763851582`], AbsoluteThickness[0.5], 
     LineBox[{{5.437919403936263, 1.9797487223042358`}, {5.653191871277956, 
      2.0742807499260687`}}]}, 
    {Hue[0.623930324495393], AbsoluteThickness[0.5], 
     LineBox[{{5.653191871277956, 2.0742807499260687`}, {5.423997420755815, 
      2.021855152251565}}]}, 
    {Hue[0.4528392555555241], AbsoluteThickness[0.5], 
     LineBox[{{5.3308119784895664`, 1.7402977552444332`}, {5.426781450380375, 
      1.5361348164380844`}}]}, 
    {Hue[0.4575398404633701], AbsoluteThickness[0.5], 
     LineBox[{{5.426781450380375, 1.5361348164380844`}, {5.505750913455063, 
      1.4255035421844615`}}]}, 
    {Hue[0.38098553561548704`], AbsoluteThickness[0.5], 
     LineBox[{{4.61744044815143, 2.3698675239156}, {4.617224016915646, 
      2.3706728539984163`}}]}, 
    {Hue[0.3815842740992117], AbsoluteThickness[0.5], 
     LineBox[{{4.617224016915646, 2.3706728539984163`}, {4.531250291526616, 
      2.6168285017838073`}}]}, 
    {Hue[0.6058807934259263], AbsoluteThickness[0.5], 
     LineBox[{{3.9426486256570685`, 0.9123666428044666}, {3.88312196019943, 
      0.8800739531676112}}]}, 
    {Hue[0.6061388270606511], AbsoluteThickness[0.5], 
     LineBox[{{3.88312196019943, 0.8800739531676112}, {3.610648696611938, 
      0.727826244460162}}]}, 
    {Hue[0.5208564241955356], AbsoluteThickness[0.5], 
     LineBox[{{4.667619659074758, 0.15517585467677475`}, {
      5.040549823280207, -0.3678392318845586}}]}, 
    {Hue[0.521951449947933], AbsoluteThickness[0.5], 
     LineBox[{{5.040549823280207, -0.3678392318845586}, {
      5.14973969558237, -0.5604722446892797}}]}, 
    {Hue[0.663891525751272], AbsoluteThickness[0.5], 
     LineBox[{{3.302423722577122, -1.3804782455114837`}, {
      3.31572827414038, -1.5817155151203544`}}]}, 
    {Hue[0.6642675893746577], AbsoluteThickness[0.5], 
     LineBox[{{3.31572827414038, -1.5817155151203544`}, {
      3.321292978541032, -1.878292443625834}}]}, 
    {Hue[0.6655242396002781], AbsoluteThickness[0.5], 
     LineBox[{{2.389395151973833, -1.1818272549535742`}, {
      2.3660529091821334`, -1.196150805001842}}]}, 
    {Hue[0.66577640716604], AbsoluteThickness[0.5], 
     LineBox[{{2.3660529091821334`, -1.196150805001842}, {
      2.0976421304674826`, -1.363239012774903}}]}, 
    {Hue[0.5475371147668223], AbsoluteThickness[0.5], 
     LineBox[{{4.249196829209725, -1.3760337788472405`}, {
      4.407788708244867, -1.4206720828036763`}}]}, 
    {Hue[0.5478093750328443], AbsoluteThickness[0.5], 
     LineBox[{{4.407788708244867, -1.4206720828036763`}, {
      4.69091343784774, -1.506725778958439}}]}, 
    {Hue[0.5615099642677912], AbsoluteThickness[0.5], 
     LineBox[{{4.665944662141629, -1.5759320171915738`}, {
      4.668589727575173, -1.5806756855235102`}}]}, 
    {Hue[0.561764337368967], AbsoluteThickness[0.5], 
     LineBox[{{4.668589727575173, -1.5806756855235102`}, {
      4.817333074760893, -1.841760431485601}}]}, 
    {Hue[0.5119684868970488], AbsoluteThickness[0.5], 
     LineBox[{{4.859848789732709, -3.4015390447426364`}, {
      4.8645778977413805`, -3.4057434145633048`}}]}, 
    {Hue[0.5122313893277834], AbsoluteThickness[0.5], 
     LineBox[{{4.8645778977413805`, -3.4057434145633048`}, {
      5.1093104629644275`, -3.6164876063722495`}}]}, 
    {Hue[0.5974519192563857], AbsoluteThickness[0.5], 
     LineBox[{{2.8248949924384474`, -0.9101405802514051}, {
      2.7933395456863996`, -1.0857379054575265`}}]}, 
    {Hue[0.5977202015925596], AbsoluteThickness[0.5], 
     LineBox[{{2.7933395456863996`, -1.0857379054575265`}, {
      2.7469683188727525`, -1.3748897125490647`}}]}, 
    {Hue[0.5140062419541397], AbsoluteThickness[0.5], 
     LineBox[{{3.2842800095888456`, 2.3919584300683443`}, {3.210583085876549, 
      2.457046579755229}}]}, 
    {Hue[0.5143983408393326], AbsoluteThickness[0.5], 
     LineBox[{{3.210583085876549, 2.457046579755229}, {2.945139672358949, 
      2.6688893857093956`}}]}, 
    {Hue[0.6204673047511365], AbsoluteThickness[0.5], 
     LineBox[{{2.8247909919150596`, 1.4484788790159686`}, {
      2.6253553748399594`, 1.3933299365203249`}}]}, 
    {Hue[0.6215058482870905], AbsoluteThickness[0.5], 
     LineBox[{{2.6253553748399594`, 1.3933299365203249`}, {2.376322480736169, 
      1.350926564271315}}]}, 
    {Hue[0.3820147542136898], AbsoluteThickness[0.5], 
     LineBox[{{5.392300601042003, 1.1919288347385042`}, {5.500609646698591, 
      1.1512281728816611`}}]}, 
    {Hue[0.3867274607523016], AbsoluteThickness[0.5], 
     LineBox[{{5.500609646698591, 1.1512281728816611`}, {5.660602093081537, 
      1.055296660725877}}]}, 
    {Hue[0.7], AbsoluteThickness[0.5], 
     LineBox[{{5.660602093081537, 1.055296660725877}, {5.632221101857507, 
      0.8709194461324342}}]}, 
    {Hue[0.45058586600711736`], AbsoluteThickness[0.5], 
     LineBox[{{4.976273040463918, 2.0801780988890197`}, {4.783374112059171, 
      2.618339382326352}}]}, 
    {Hue[0.4508449955944049], AbsoluteThickness[0.5], 
     LineBox[{{4.783374112059171, 2.618339382326352}, {4.681505257425449, 
      2.9149084578051956`}}]}, 
    {Hue[0.6236752586338387], AbsoluteThickness[0.5], 
     LineBox[{{5.437919403936263, 1.9797487223042358`}, {5.282804539547909, 
      1.8707384261037263`}}]}, 
    {Hue[0.6239720326147975], AbsoluteThickness[0.5], 
     LineBox[{{5.282804539547909, 1.8707384261037263`}, {5.082938494081481, 
      1.7212182958338793`}}]}, 
    {Hue[0.017580594625405375`], AbsoluteThickness[0.5], 
     LineBox[{{5.653191871277956, 2.0742807499260687`}, {5.687662867870529, 
      2.0898268696254814`}}]}, 
    {Hue[0.019510587321188155`], AbsoluteThickness[0.5], 
     LineBox[{{5.687662867870529, 2.0898268696254814`}, {5.818345793527576, 
      2.171015516341165}}]}, 
    {Hue[0.4218685151020484], AbsoluteThickness[0.5], 
     LineBox[{{5.818345793527576, 2.171015516341165}, {5.75785564550453, 
      2.312474221997478}}]}, 
    {Hue[0.6241853903569465], AbsoluteThickness[0.5], 
     LineBox[{{5.423997420755815, 2.021855152251565}, {5.1647811419405105`, 
      1.9598550041442642`}}]}, 
    {Hue[0.6244715566536094], AbsoluteThickness[0.5], 
     LineBox[{{5.1647811419405105`, 1.9598550041442642`}, {4.918582475143306, 
      1.907756022586314}}]}, 
    {Hue[0.4622404253712159], AbsoluteThickness[0.5], 
     LineBox[{{5.505750913455063, 1.4255035421844615`}, {5.602440809947026, 
      1.331682032571302}}]}, 
    {Hue[0.46252162338334046`], AbsoluteThickness[0.5], 
     LineBox[{{5.602440809947026, 1.331682032571302}, {5.859449336069214, 
      1.094202644400494}}]}, 
    {Hue[0.3821830125829365], AbsoluteThickness[0.5], 
     LineBox[{{4.531250291526616, 2.6168285017838073`}, {4.414849510379934, 
      2.885013190839214}}]}, 
    {Hue[0.3882851238422978], AbsoluteThickness[0.5], 
     LineBox[{{4.414849510379934, 2.885013190839214}, {4.378920738116869, 
      3.0506285478942594`}}]}, 
    {Hue[0.6760632311317333], AbsoluteThickness[0.5], 
     LineBox[{{4.378920738116869, 3.0506285478942594`}, {4.513545138404422, 
      3.153563449730411}}]}, 
    {Hue[0.606396860695376], AbsoluteThickness[0.5], 
     LineBox[{{3.610648696611938, 0.727826244460162}, {3.4728341012479786`, 
      0.6485468143916471}}]}, 
    {Hue[0.6086167247042409], AbsoluteThickness[0.5], 
     LineBox[{{3.4728341012479786`, 0.6485468143916471}, {3.31998438172539, 
      0.529551656279023}}]}, 
    {Hue[0.5230464757003304], AbsoluteThickness[0.5], 
     LineBox[{{5.14973969558237, -0.5604722446892797}, {
      5.174981741338908, -0.6182455823162792}}]}, 
    {Hue[0.5233109022908534], AbsoluteThickness[0.5], 
     LineBox[{{5.174981741338908, -0.6182455823162792}, {
      5.287674359820943, -0.8883918910120296}}]}, 
    {Hue[0.6646436529980433], AbsoluteThickness[0.5], 
     LineBox[{{3.321292978541032, -1.878292443625834}, {
      3.3162612831098905`, -2.054820957702231}}]}, 
    {Hue[0.6649103506599087], AbsoluteThickness[0.5], 
     LineBox[{{3.3162612831098905`, -2.054820957702231}, {
      3.3025274854814857`, -2.3501933658434235`}}]}, 
    {Hue[0.666028574731802], AbsoluteThickness[0.5], 
     LineBox[{{2.0976421304674826`, -1.363239012774903}, {
      2.0927670428568663`, -1.3663174247124696`}}]}, 
    {Hue[0.6663278847848868], AbsoluteThickness[0.5], 
     LineBox[{{2.0927670428568663`, -1.3663174247124696`}, {
      1.8406124114493334`, -1.5365010136935358`}}]}, 
    {Hue[0.5480816352988664], AbsoluteThickness[0.5], 
     LineBox[{{4.69091343784774, -1.506725778958439}, {
      5.107787750249674, -1.642920106458676}}]}, 
    {Hue[0.5483389921232567], AbsoluteThickness[0.5], 
     LineBox[{{5.107787750249674, -1.642920106458676}, {
      5.4274924017266715`, -1.7516126562831047`}}]}, 
    {Hue[0.5620187104701428], AbsoluteThickness[0.5], 
     LineBox[{{4.817333074760893, -1.841760431485601}, {
      4.842660771314266, -1.8852822349558254`}}]}, 
    {Hue[0.5622982828259784], AbsoluteThickness[0.5], 
     LineBox[{{4.842660771314266, -1.8852822349558254`}, {
      5.001575001824253, -2.1439932216793123`}}]}, 
    {Hue[0.5124942917585182], AbsoluteThickness[0.5], 
     LineBox[{{5.1093104629644275`, -3.6164876063722495`}, {
      5.181971878490463, -3.6770836032939838`}}]}, 
    {Hue[0.5127487063881196], AbsoluteThickness[0.5], 
     LineBox[{{5.181971878490463, -3.6770836032939838`}, {
      5.418947212294324, -3.8784494750408323`}}]}, 
    {Hue[0.5979884839287334], AbsoluteThickness[0.5], 
     LineBox[{{2.7469683188727525`, -1.3748897125490647`}, {
      2.719817573614388, -1.5672403062394185`}}]}, 
    {Hue[0.5982467982099176], AbsoluteThickness[0.5], 
     LineBox[{{2.719817573614388, -1.5672403062394185`}, {
      2.6778626492883095`, -1.894450779391143}}]}, 
    {Hue[0.5147904397245254], AbsoluteThickness[0.5], 
     LineBox[{{2.945139672358949, 2.6688893857093956`}, {2.8804796038590825`, 
      2.715410939316134}}]}, 
    {Hue[0.5151222135169746], AbsoluteThickness[0.5], 
     LineBox[{{2.8804796038590825`, 2.715410939316134}, {2.637196266542002, 
      2.87653639987107}}]}, 
    {Hue[0.6225443918230443], AbsoluteThickness[0.5], 
     LineBox[{{2.376322480736169, 1.350926564271315}, {2.35326450061459, 
      1.349367183228459}}]}, 
    {Hue[0.6234435350366467], AbsoluteThickness[0.5], 
     LineBox[{{2.35326450061459, 1.349367183228459}, {2.105205953681314, 
      1.3089504386517101`}}]}, 
    {Hue[0.6952872934613858], AbsoluteThickness[0.5], 
     LineBox[{{5.500609646698591, 1.1512281728816611`}, {5.585821031671754, 
      1.1937230451094445`}}]}, 
    {Hue[0.6955535178907849], AbsoluteThickness[0.5], 
     LineBox[{{5.585821031671754, 1.1937230451094445`}, {5.9055993709120385`, 
      1.346184344778414}}]}, 
    {Hue[0.3914401672909134], AbsoluteThickness[0.5], 
     LineBox[{{5.660602093081537, 1.055296660725877}, {5.827287846370574, 
      0.908867505796318}}]}, 
    {Hue[0.4008697615416103], AbsoluteThickness[0.5], 
     LineBox[{{5.827287846370574, 0.908867505796318}, {5.916999308804771, 
      0.785086933946996}}]}, 
    {Hue[0.6461861989904059], AbsoluteThickness[0.5], 
     LineBox[{{5.916999308804771, 0.785086933946996}, {5.853145005358394, 
      0.6461898339383721}}]}, 
    {Hue[0.45110412518169235`], AbsoluteThickness[0.5], 
     LineBox[{{4.681505257425449, 2.9149084578051956`}, {4.67407027104502, 
      2.937529364040488}}]}, 
    {Hue[0.4522589882198693], AbsoluteThickness[0.5], 
     LineBox[{{4.67407027104502, 2.937529364040488}, {4.580462570682055, 
      3.1449418712265773`}}]}, 
    {Hue[0.6242688065957563], AbsoluteThickness[0.5], 
     LineBox[{{5.082938494081481, 1.7212182958338793`}, {5.012704843762185, 
      1.6653479302269216`}}]}, 
    {Hue[0.6252624032645474], AbsoluteThickness[0.5], 
     LineBox[{{5.012704843762185, 1.6653479302269216`}, {4.832870793261389, 
      1.4906457028107196`}}]}, 
    {Hue[0.4199385224062643], AbsoluteThickness[0.5], 
     LineBox[{{5.687662867870529, 2.0898268696254814`}, {5.854885620723593, 
      1.9399249656609605`}}]}, 
    {Hue[0.4224640578615228], AbsoluteThickness[0.5], 
     LineBox[{{5.854885620723593, 1.9399249656609605`}, {6.035596731198306, 
      1.8203395281465218`}}]}, 
    {Hue[0.021440580016971165`], AbsoluteThickness[0.5], 
     LineBox[{{5.818345793527576, 2.171015516341165}, {6.007291818190744, 
      2.326369260585133}}]}, 
    {Hue[0.021970933950866266`], AbsoluteThickness[0.5], 
     LineBox[{{6.007291818190744, 2.326369260585133}, {6.213356467531074, 
      2.5203616698323628`}}]}, 
    {Hue[0.5545315306462786], AbsoluteThickness[0.5], 
     LineBox[{{6.213356467531074, 2.5203616698323628`}, {5.949140482779213, 
      2.6217796561804567`}}]}, 
    {Hue[0.42379850779783135`], AbsoluteThickness[0.5], 
     LineBox[{{5.75785564550453, 2.312474221997478}, {5.674775886516028, 
      2.4522373671932924`}}]}, 
    {Hue[0.42443055137958674`], AbsoluteThickness[0.5], 
     LineBox[{{5.674775886516028, 2.4522373671932924`}, {5.515552897263065, 
      2.6788012141727564`}}]}, 
    {Hue[0.6247577229502723], AbsoluteThickness[0.5], 
     LineBox[{{4.918582475143306, 1.907756022586314}, {4.650616384890328, 
      1.8583568547090352`}}]}, 
    {Hue[0.6265274788749875], AbsoluteThickness[0.5], 
     LineBox[{{4.650616384890328, 1.8583568547090352`}, {4.437030219304963, 
      1.8467040660743477`}}]}, 
    {Hue[0.4628028213954649], AbsoluteThickness[0.5], 
     LineBox[{{5.859449336069214, 1.094202644400494}, {5.905425782748287, 
      1.0537554331344703`}}]}, 
    {Hue[0.4630590537802301], AbsoluteThickness[0.5], 
     LineBox[{{5.905425782748287, 1.0537554331344703`}, {6.157714439383523, 
      0.8366801720419561}}]}, 
    {Hue[0.6699611198723692], AbsoluteThickness[0.5], 
     LineBox[{{4.414849510379934, 2.885013190839214}, {4.403888521877016, 
      2.889926336669342}}]}, 
    {Hue[0.6721343253307482], AbsoluteThickness[0.5], 
     LineBox[{{4.403888521877016, 2.889926336669342}, {4.205331688354061, 
      2.947673230755316}}]}, 
    {Hue[0.39438723510165896`], AbsoluteThickness[0.5], 
     LineBox[{{4.378920738116869, 3.0506285478942594`}, {4.377141826018596, 
      3.150751445226249}}]}, 
    {Hue[0.3950806243298942], AbsoluteThickness[0.5], 
     LineBox[{{4.377141826018596, 3.150751445226249}, {4.348300768032922, 
      3.4418467493456752`}}]}, 
    {Hue[0.6821653423910944], AbsoluteThickness[0.5], 
     LineBox[{{4.513545138404422, 3.153563449730411}, {4.619790411157448, 
      3.2057955439812207`}}]}, 
    {Hue[0.6824421731727963], AbsoluteThickness[0.5], 
     LineBox[{{4.619790411157448, 3.2057955439812207`}, {4.908333392573309, 
      3.339608845761093}}]}, 
    {Hue[0.6108365887131056], AbsoluteThickness[0.5], 
     LineBox[{{3.31998438172539, 0.529551656279023}, {3.220901170677886, 
      0.4273338267278477}}]}, 
    {Hue[0.611953420069331], AbsoluteThickness[0.5], 
     LineBox[{{3.220901170677886, 0.4273338267278477}, {3.0739900774303, 
      0.24002054332665868`}}]}, 
    {Hue[0.5235753288813764], AbsoluteThickness[0.5], 
     LineBox[{{5.287674359820943, -0.8883918910120296}, {
      5.335579271001131, -1.0088569120138358`}}]}, 
    {Hue[0.526477993815554], AbsoluteThickness[0.5], 
     LineBox[{{5.335579271001131, -1.0088569120138358`}, {
      5.4333082826909305`, -1.1748284132169031`}}]}, 
    {Hue[0.6651770483217742], AbsoluteThickness[0.5], 
     LineBox[{{3.3025274854814857`, -2.3501933658434235`}, {
      3.287395305609046, -2.584729518382705}}]}, 
    {Hue[0.6654555687654311], AbsoluteThickness[0.5], 
     LineBox[{{3.287395305609046, -2.584729518382705}, {
      3.2590130751834177`, -2.90714655608338}}]}, 
    {Hue[0.5485963489476469], AbsoluteThickness[0.5], 
     LineBox[{{5.4274924017266715`, -1.7516126562831047`}, {
      5.636720137889198, -1.825545518845617}}]}, 
    {Hue[0.5503681587132283], AbsoluteThickness[0.5], 
     LineBox[{{5.636720137889198, -1.825545518845617}, {
      5.841305106037779, -1.869538204881696}}]}, 
    {Hue[0.5625778551818139], AbsoluteThickness[0.5], 
     LineBox[{{5.001575001824253, -2.1439932216793123`}, {
      5.049962533411066, -2.21872164507514}}]}, 
    {Hue[0.5638745821560339], AbsoluteThickness[0.5], 
     LineBox[{{5.049962533411066, -2.21872164507514}, {
      5.2013862357944145`, -2.403401690170491}}]}, 
    {Hue[0.5130031210177209], AbsoluteThickness[0.5], 
     LineBox[{{5.418947212294324, -3.8784494750408323`}, {
      5.42135352872971, -3.880532783293427}}]}, 
    {Hue[0.5132698734720152], AbsoluteThickness[0.5], 
     LineBox[{{5.42135352872971, -3.880532783293427}, {
      5.6502987804676925`, -4.086069272011319}}]}, 
    {Hue[0.5985051124911016], AbsoluteThickness[0.5], 
     LineBox[{{2.6778626492883095`, -1.894450779391143}, {
      2.658755669647669, -2.0601235149313406`}}]}, 
    {Hue[0.5988599428494267], AbsoluteThickness[0.5], 
     LineBox[{{2.658755669647669, -2.0601235149313406`}, {
      2.637452407436484, -2.358038594197197}}]}, 
    {Hue[0.5154539873094238], AbsoluteThickness[0.5], 
     LineBox[{{2.637196266542002, 2.87653639987107}, {2.5970029783257624`, 
      2.900972804317139}}]}, 
    {Hue[0.5157041637854468], AbsoluteThickness[0.5], 
     LineBox[{{2.5970029783257624`, 2.900972804317139}, {2.3255515591577742`, 
      3.065475878148557}}]}, 
    {Hue[0.6958197423201841], AbsoluteThickness[0.5], 
     LineBox[{{5.9055993709120385`, 1.346184344778414}, {5.966895853934747, 
      1.3740872073537407`}}]}, 
    {Hue[0.6966990643324651], AbsoluteThickness[0.5], 
     LineBox[{{5.966895853934747, 1.3740872073537407`}, {6.1739831728662375`, 
      1.4926739919529588`}}]}, 
    {Hue[0.6367566047397045], AbsoluteThickness[0.5], 
     LineBox[{{5.827287846370574, 0.908867505796318}, {5.885276590783813, 
      0.9025549764775841}}]}, 
    {Hue[0.6371205414170722], AbsoluteThickness[0.5], 
     LineBox[{{5.885276590783813, 0.9025549764775841}, {6.1923646790152205`, 
      0.8830894161914126}}]}, 
    {Hue[0.41029935579230675`], AbsoluteThickness[0.5], 
     LineBox[{{5.916999308804771, 0.785086933946996}, {5.959678494820941, 
      0.6853398570872504}}]}, 
    {Hue[0.4106518560219795], AbsoluteThickness[0.5], 
     LineBox[{{5.959678494820941, 0.6853398570872504}, {6.0588289610006205`, 
      0.422969975277085}}]}, 
    {Hue[0.6556157932411025], AbsoluteThickness[0.5], 
     LineBox[{{5.853145005358394, 0.6461898339383721}, {5.850761393406947, 
      0.6430786992059025}}]}, 
    {Hue[0.6893547933620194], AbsoluteThickness[0.5], 
     LineBox[{{5.850761393406947, 0.6430786992059025}, {5.805397180905357, 
      0.5158814554791795}}]}, 
    {Hue[0.4534138512580461], AbsoluteThickness[0.5], 
     LineBox[{{4.580462570682055, 3.1449418712265773`}, {4.313500176720454, 
      3.600225059842444}}]}, 
    {Hue[0.4536659577163953], AbsoluteThickness[0.5], 
     LineBox[{{4.313500176720454, 3.600225059842444}, {4.162901024900379, 
      3.8533742675267373`}}]}, 
    {Hue[0.6262559999333385], AbsoluteThickness[0.5], 
     LineBox[{{4.832870793261389, 1.4906457028107196`}, {4.769543074228847, 
      1.41560276223457}}]}, 
    {Hue[0.6266159028281362], AbsoluteThickness[0.5], 
     LineBox[{{4.769543074228847, 1.41560276223457}, {4.621306580051852, 
      1.2232336216918}}]}, 
    {Hue[0.4249895933167814], AbsoluteThickness[0.5], 
     LineBox[{{6.035596731198306, 1.8203395281465218`}, {6.119735949356594, 
      1.7808981954339722`}}]}, 
    {Hue[0.42524182139485894`], AbsoluteThickness[0.5], 
     LineBox[{{6.119735949356594, 1.7808981954339722`}, {6.408691354990524, 
      1.6477360155788825`}}]}, 
    {Hue[0.5540011767123814], AbsoluteThickness[0.5], 
     LineBox[{{6.007291818190744, 2.326369260585133}, {6.071796562502036, 
      2.161656101932755}}]}, 
    {Hue[0.5545913298869327], AbsoluteThickness[0.5], 
     LineBox[{{6.071796562502036, 2.161656101932755}, {6.157422268740234, 
      1.8853752948133582`}}]}, 
    {Hue[0.022501287884761287`], AbsoluteThickness[0.5], 
     LineBox[{{6.213356467531074, 2.5203616698323628`}, {6.48123719439638, 
      2.8087934894664675`}}]}, 
    {Hue[0.023143078600733245`], AbsoluteThickness[0.5], 
     LineBox[{{6.48123719439638, 2.8087934894664675`}, {6.647130458070667, 
      3.0175778619262417`}}]}, 
    {Hue[0.5364323843325132], AbsoluteThickness[0.5], 
     LineBox[{{6.647130458070667, 3.0175778619262417`}, {6.396083505696071, 
      3.10750514821553}}]}, 
    {Hue[0.5550618845801736], AbsoluteThickness[0.5], 
     LineBox[{{5.949140482779213, 2.6217796561804567`}, {5.7983702345529355`, 
      2.6683210059337594`}}]}, 
    {Hue[0.5555661603009302], AbsoluteThickness[0.5], 
     LineBox[{{5.7983702345529355`, 2.6683210059337594`}, {5.54481221697136, 
      2.76485787958786}}]}, 
    {Hue[0.42506259496134197`], AbsoluteThickness[0.5], 
     LineBox[{{5.515552897263065, 2.6788012141727564`}, {5.371566875386932, 
      2.853666562460514}}]}, 
    {Hue[0.4321666759421748], AbsoluteThickness[0.5], 
     LineBox[{{5.371566875386932, 2.853666562460514}, {5.294262451210661, 
      3.000799944222265}}]}, 
    {Hue[0.6282972347997029], AbsoluteThickness[0.5], 
     LineBox[{{4.437030219304963, 1.8467040660743477`}, {4.421213526475926, 
      1.847865420241204}}]}, 
    {Hue[0.628934288634765], AbsoluteThickness[0.5], 
     LineBox[{{4.421213526475926, 1.847865420241204}, {4.1502002556544255`, 
      1.8469494469852346`}}]}, 
    {Hue[0.46331528616499534`], AbsoluteThickness[0.5], 
     LineBox[{{6.157714439383523, 0.8366801720419561}, {6.191376498211608, 
      0.8083544706960103}}]}, 
    {Hue[0.46356771680421816`], AbsoluteThickness[0.5], 
     LineBox[{{6.191376498211608, 0.8083544706960103}, {6.394954210390352, 
      0.6394052865372326}}]}, 
    {Hue[0.6743075307891272], AbsoluteThickness[0.5], 
     LineBox[{{4.205331688354061, 2.947673230755316}, {4.086222323756878, 
      2.965025116636303}}]}, 
    {Hue[0.6745668643484133], AbsoluteThickness[0.5], 
     LineBox[{{4.086222323756878, 2.965025116636303}, {3.8269303801522256`, 
      2.999242078418428}}]}, 
    {Hue[0.3957740135581294], AbsoluteThickness[0.5], 
     LineBox[{{4.348300768032922, 3.4418467493456752`}, {4.318831730301638, 
      3.6040260491265856`}}]}, 
    {Hue[0.39614599889852387`], AbsoluteThickness[0.5], 
     LineBox[{{4.318831730301638, 3.6040260491265856`}, {4.25824591918048, 
      3.8671623687594585`}}]}, 
    {Hue[0.6827190039544981], AbsoluteThickness[0.5], 
     LineBox[{{4.908333392573309, 3.339608845761093}, {4.939806890003544, 
      3.3533461641275477`}}]}, 
    {Hue[0.683087238712852], AbsoluteThickness[0.5], 
     LineBox[{{4.939806890003544, 3.3533461641275477`}, {5.162281811781705, 
      3.4628641939869107`}}]}, 
    {Hue[0.6130702514255565], AbsoluteThickness[0.5], 
     LineBox[{{3.0739900774303, 0.2400205433266587}, {2.9914856850464813`, 
      0.10853190412188163`}}]}, 
    {Hue[0.6142476472375986], AbsoluteThickness[0.5], 
     LineBox[{{2.9914856850464813`, 0.10853190412188163`}, {
      2.889843409486294, -0.10027080328631954`}}]}, 
    {Hue[0.5293806587497317], AbsoluteThickness[0.5], 
     LineBox[{{5.4333082826909305`, -1.1748284132169031`}, {
      5.583010034318628, -1.3577565410854928`}}]}, 
    {Hue[0.5310918109994485], AbsoluteThickness[0.5], 
     LineBox[{{5.583010034318628, -1.3577565410854928`}, {
      5.694863325804298, -1.536263279949235}}]}, 
    {Hue[0.6657340892090879], AbsoluteThickness[0.5], 
     LineBox[{{3.2590130751834177`, -2.90714655608338}, {
      3.2321944306689567`, -3.1473784653608003`}}]}, 
    {Hue[0.6660691726446945], AbsoluteThickness[0.5], 
     LineBox[{{3.2321944306689567`, -3.1473784653608003`}, {
      3.2113095143471937`, -3.437986026412408}}]}, 
    {Hue[0.5521399684788096], AbsoluteThickness[0.5], 
     LineBox[{{5.841305106037779, -1.869538204881696}, {
      5.954165361983262, -1.8790352949782403`}}]}, 
    {Hue[0.552838770909985], AbsoluteThickness[0.5], 
     LineBox[{{5.954165361983262, -1.8790352949782403`}, {
      6.144051020274942, -1.9107192341833732`}}]}, 
    {Hue[0.5651713091302538], AbsoluteThickness[0.5], 
     LineBox[{{5.2013862357944145`, -2.403401690170491}, {
      5.324389169094216, -2.52312210377927}}]}, 
    {Hue[0.5690930680930014], AbsoluteThickness[0.5], 
     LineBox[{{5.324389169094216, -2.52312210377927}, {
      5.474459209813506, -2.6261568206998294`}}]}, 
    {Hue[0.5135366259263096], AbsoluteThickness[0.5], 
     LineBox[{{5.6502987804676925`, -4.086069272011319}, {
      5.668103876235374, -4.102642111066752}}]}, 
    {Hue[0.5138286354135211], AbsoluteThickness[0.5], 
     LineBox[{{5.668103876235374, -4.102642111066752}, {
      5.903478494345008, -4.334454867193587}}]}, 
    {Hue[0.5992147732077517], AbsoluteThickness[0.5], 
     LineBox[{{2.637452407436484, -2.358038594197197}, {
      2.6373362849893187`, -2.362192119570128}}]}, 
    {Hue[0.5999145813399501], AbsoluteThickness[0.5], 
     LineBox[{{2.6373362849893187`, -2.362192119570128}, {
      2.6091857226768385`, -2.618467133040838}}]}, 
    {Hue[0.5159543402614699], AbsoluteThickness[0.5], 
     LineBox[{{2.3255515591577742`, 3.065475878148557}, {2.3024468566420757`, 
      3.079432435944355}}]}, 
    {Hue[0.5168764585282194], AbsoluteThickness[0.5], 
     LineBox[{{2.3024468566420757`, 3.079432435944355}, {2.110383733265406, 
      3.2220250394436794`}}]}, 
    {Hue[0.697578386344746], AbsoluteThickness[0.5], 
     LineBox[{{6.1739831728662375`, 1.4926739919529588`}, {6.275535373119698, 
      1.5640961561305737`}}]}, 
    {Hue[0.6995954934862855], AbsoluteThickness[0.5], 
     LineBox[{{6.275535373119698, 1.5640961561305737`}, {6.426591269990949, 
      1.7040996424882517`}}]}, 
    {Hue[0.6374844780944396], AbsoluteThickness[0.5], 
     LineBox[{{6.1923646790152205`, 0.8830894161914126}, {6.383631829803685, 
      0.8796127859981953}}]}, 
    {Hue[0.6405813976592352], AbsoluteThickness[0.5], 
     LineBox[{{6.383631829803685, 0.8796127859981953}, {6.586895063394399, 
      0.9080500766476118}}]}, 
    {Hue[0.4110043562516522], AbsoluteThickness[0.5], 
     LineBox[{{6.0588289610006205`, 0.422969975277085}, {6.082523520290696, 
      0.3510661635360006}}]}, 
    {Hue[0.4123173149650192], AbsoluteThickness[0.5], 
     LineBox[{{6.082523520290696, 0.3510661635360006}, {6.179227668257601, 
      0.14081462651745705`}}]}, 
    {Hue[0.6269758057229338], AbsoluteThickness[0.5], 
     LineBox[{{4.621306580051852, 1.2232336216918}, {4.586049158596227, 
      1.1730188606546714`}}]}, 
    {Hue[0.6272423453289208], AbsoluteThickness[0.5], 
     LineBox[{{4.586049158596227, 1.1730188606546714`}, {4.389512408543295, 
      0.8821815616586304}}]}, 
    {Hue[0.4254940494729367], AbsoluteThickness[0.5], 
     LineBox[{{6.408691354990524, 1.6477360155788825`}, {6.420365614418269, 
      1.6424479908960208`}}]}, 
    {Hue[0.4260157183817748], AbsoluteThickness[0.5], 
     LineBox[{{6.420365614418269, 1.6424479908960208`}, {6.659199800323091, 
      1.5145890726275741`}}]}, 
    {Hue[0.5551814830614841], AbsoluteThickness[0.5], 
     LineBox[{{6.157422268740234, 1.8853752948133582`}, {6.166558781284912, 
      1.8459656794968522`}}]}, 
    {Hue[0.5555556086844303], AbsoluteThickness[0.5], 
     LineBox[{{6.166558781284912, 1.8459656794968522`}, {6.24559196436545, 
      1.5655700051422783`}}]}, 
    {Hue[0.5357905936165388], AbsoluteThickness[0.5], 
     LineBox[{{6.48123719439638, 2.8087934894664675`}, {6.555122020759756, 
      2.711396706926796}}]}, 
    {Hue[0.5387089739302258], AbsoluteThickness[0.5], 
     LineBox[{{6.555122020759756, 2.711396706926796}, {6.6977289220871485`, 
      2.573708203051864}}]}, 
    {Hue[0.023784869316705124`], AbsoluteThickness[0.5], 
     LineBox[{{6.647130458070667, 3.0175778619262417`}, {6.743005349342832, 
      3.159426156231268}}]}, 
    {Hue[0.02417160976837448], AbsoluteThickness[0.5], 
     LineBox[{{6.743005349342832, 3.159426156231268}, {6.870236380829555, 
      3.3691329793077016`}}]}, 
    {Hue[0.5886620725650188], AbsoluteThickness[0.5], 
     LineBox[{{6.870236380829555, 3.3691329793077016`}, {6.627968571385821, 
      3.330779419820731}}]}, 
    {Hue[0.537074175048485], AbsoluteThickness[0.5], 
     LineBox[{{6.396083505696071, 3.10750514821553}, {6.392113186582835, 
      3.108590792985685}}]}, 
    {Hue[0.5375084673587314], AbsoluteThickness[0.5], 
     LineBox[{{6.392113186582835, 3.108590792985685}, {6.113068237539892, 
      3.2019670558902438`}}]}, 
    {Hue[0.5560704360216867], AbsoluteThickness[0.5], 
     LineBox[{{5.54481221697136, 2.76485787958786}, {5.143713659545865, 
      2.9479161806110485`}}]}, 
    {Hue[0.5563305344345839], AbsoluteThickness[0.5], 
     LineBox[{{5.143713659545865, 2.9479161806110485`}, {4.8504311220175405`, 
      3.076839050675112}}]}, 
    {Hue[0.697929360111723], AbsoluteThickness[0.5], 
     LineBox[{{5.371566875386932, 2.853666562460514}, {5.121642007291394, 
      2.9012244201865007`}}]}, 
    {Hue[0.6982728747744903], AbsoluteThickness[0.5], 
     LineBox[{{5.121642007291394, 2.9012244201865007`}, {4.828494716892069, 
      2.9696293390170814`}}]}, 
    {Hue[0.43927075692300743`], AbsoluteThickness[0.5], 
     LineBox[{{5.294262451210661, 3.000799944222265}, {5.257802525469749, 
      3.1282294990859345`}}]}, 
    {Hue[0.4395278163088812], AbsoluteThickness[0.5], 
     LineBox[{{5.257802525469749, 3.1282294990859345`}, {5.180866273705958, 
      3.385695111684324}}]}, 
    {Hue[0.6295713424698269], AbsoluteThickness[0.5], 
     LineBox[{{4.1502002556544255`, 1.8469494469852346`}, {4.145538358502291, 
      1.8465754445684204`}}]}, 
    {Hue[0.6312274342785091], AbsoluteThickness[0.5], 
     LineBox[{{4.145538358502291, 1.8465754445684204`}, {3.9229052700237093`, 
      1.856460856158855}}]}, 
    {Hue[0.46382014744344097`], AbsoluteThickness[0.5], 
     LineBox[{{6.394954210390352, 0.6394052865372326}, {6.396194394307083, 
      0.6383902481978644}}]}, 
    {Hue[0.4641119225308132], AbsoluteThickness[0.5], 
     LineBox[{{6.396194394307083, 0.6383902481978644}, {6.589711119764846, 
      0.47069834073975514`}}]}, 
    {Hue[0.6748261979076992], AbsoluteThickness[0.5], 
     LineBox[{{3.8269303801522256`, 2.999242078418428}, {3.6679500511223733`, 
      3.018048577274786}}]}, 
    {Hue[0.6750813136786591], AbsoluteThickness[0.5], 
     LineBox[{{3.6679500511223733`, 3.018048577274786}, {3.341500215339184, 
      3.0533754102536497`}}]}, 
    {Hue[0.6834554734712058], AbsoluteThickness[0.5], 
     LineBox[{{5.162281811781705, 3.4628641939869107`}, {5.318568647279882, 
      3.5489238095699025`}}]}, 
    {Hue[0.6839889160967274], AbsoluteThickness[0.5], 
     LineBox[{{5.318568647279882, 3.5489238095699025`}, {5.58661605647694, 
      3.6737887253110886`}}]}, 
    {Hue[0.6154250430496407], AbsoluteThickness[0.5], 
     LineBox[{{2.889843409486294, -0.10027080328631954`}, {
      2.8766424432636972`, -0.13692672331571887`}}]}, 
    {Hue[0.6157684440604291], AbsoluteThickness[0.5], 
     LineBox[{{2.8766424432636972`, -0.13692672331571887`}, {
      2.7665035006206065`, -0.4072852424398593}}]}, 
    {Hue[0.5328029632491652], AbsoluteThickness[0.5], 
     LineBox[{{5.694863325804298, -1.536263279949235}, {
      5.715692409011292, -1.5812439620622916`}}]}, 
    {Hue[0.5330600732969578], AbsoluteThickness[0.5], 
     LineBox[{{5.715692409011292, -1.5812439620622916`}, {
      5.84432195773474, -1.8677997581167494`}}]}, 
    {Hue[0.666404256080301], AbsoluteThickness[0.5], 
     LineBox[{{3.2113095143471937`, -3.437986026412408}, {
      3.206050163448984, -3.600707474812714}}]}, 
    {Hue[0.6668241796965114], AbsoluteThickness[0.5], 
     LineBox[{{3.206050163448984, -3.6007074748127135`}, {
      3.2127736944018714`, -3.910223361320562}}]}, 
    {Hue[0.5535375733411605], AbsoluteThickness[0.5], 
     LineBox[{{6.144051020274942, -1.9107192341833732`}, {
      6.3218204849187, -1.9554903300899489`}}]}, 
    {Hue[0.553807225239602], AbsoluteThickness[0.5], 
     LineBox[{{6.3218204849187, -1.9554903300899489`}, {
      6.628322250633668, -2.0263663046727043`}}]}, 
    {Hue[0.5730148270557492], AbsoluteThickness[0.5], 
     LineBox[{{5.474459209813506, -2.6261568206998294`}, {
      5.597520364524873, -2.682810780946799}}]}, 
    {Hue[0.5732999971245709], AbsoluteThickness[0.5], 
     LineBox[{{5.597520364524873, -2.682810780946799}, {
      5.844347232206611, -2.8042806551477453`}}]}, 
    {Hue[0.5141206449007326], AbsoluteThickness[0.5], 
     LineBox[{{5.903478494345008, -4.334454867193587}, {
      5.938780848242651, -4.371241104276933}}]}, 
    {Hue[0.5145116546483628], AbsoluteThickness[0.5], 
     LineBox[{{5.938780848242651, -4.371241104276933}, {
      6.144109016922892, -4.607673172359417}}]}, 
    {Hue[0.6006143894721486], AbsoluteThickness[0.5], 
     LineBox[{{2.6091857226768385`, -2.618467133040838}, {
      2.6020822651431432`, -2.6552317283083933`}}]}, 
    {Hue[0.606368921462451], AbsoluteThickness[0.5], 
     LineBox[{{2.6020822651431432`, -2.6552317283083933`}, {
      2.6023634415219066`, -2.842583477921545}}]}, 
    {Hue[0.5177985767949689], AbsoluteThickness[0.5], 
     LineBox[{{2.110383733265406, 3.2220250394436794`}, {1.9539262869733336`, 
      3.3631370587794045`}}]}, 
    {Hue[0.5233998551746364], AbsoluteThickness[0.5], 
     LineBox[{{1.9539262869733336`, 3.3631370587794045`}, {
      1.8548429588315567`, 3.494519077401773}}]}, 
    {Hue[0.6436783172240307], AbsoluteThickness[0.5], 
     LineBox[{{6.586895063394399, 0.9080500766476118}, {6.858490044568136, 
      0.990928201050445}}]}, 
    {Hue[0.6439678486931897], AbsoluteThickness[0.5], 
     LineBox[{{6.858490044568136, 0.990928201050445}, {7.1496949592812715`, 
      1.0711418194545705`}}]}, 
    {Hue[0.4136302736783863], AbsoluteThickness[0.5], 
     LineBox[{{6.179227668257601, 0.14081462651745702`}, {
      6.495859955601913, -0.3828116864613821}}]}, 
    {Hue[0.4139056778452649], AbsoluteThickness[0.5], 
     LineBox[{{6.495859955601913, -0.3828116864613821}, {
      6.6596057703003, -0.6676265290506701}}]}, 
    {Hue[0.6275088849349078], AbsoluteThickness[0.5], 
     LineBox[{{4.389512408543295, 0.8821815616586304}, {4.376864142042201, 
      0.8627233156197663}}]}, 
    {Hue[0.6277777762053142], AbsoluteThickness[0.5], 
     LineBox[{{4.376864142042201, 0.8627233156197663}, {4.194406889972308, 
      0.5934257036608273}}]}, 
    {Hue[0.4265373872906129], AbsoluteThickness[0.5], 
     LineBox[{{6.659199800323091, 1.5145890726275741`}, {7.03448380166078, 
      1.2804902895129273`}}]}, 
    {Hue[0.42694758814023964`], AbsoluteThickness[0.5], 
     LineBox[{{7.03448380166078, 1.2804902895129273`}, {7.299093719694063, 
      1.1341775845390394`}}]}, 
    {Hue[0.5559297343073766], AbsoluteThickness[0.5], 
     LineBox[{{6.24559196436545, 1.5655700051422783`}, {6.301946046068588, 
      1.3964571925074594`}}]}, 
    {Hue[0.5576087134229354], AbsoluteThickness[0.5], 
     LineBox[{{6.301946046068588, 1.3964571925074594`}, {6.342907063208428, 
      1.1907352859901839`}}]}, 
    {Hue[0.5416273542439126], AbsoluteThickness[0.5], 
     LineBox[{{6.6977289220871485`, 2.573708203051864}, {6.82473759505839, 
      2.4842021791188875`}}]}, 
    {Hue[0.5421140359591189], AbsoluteThickness[0.5], 
     LineBox[{{6.82473759505839, 2.4842021791188875`}, {7.052746961436152, 
      2.3439502480065597`}}]}, 
    {Hue[0.5882753321133464], AbsoluteThickness[0.5], 
     LineBox[{{6.743005349342832, 3.159426156231268}, {6.948536888329114, 
      2.6328647203081683`}}]}, 
    {Hue[0.5885387280413795], AbsoluteThickness[0.5], 
     LineBox[{{6.948536888329114, 2.6328647203081683`}, {7.055433350052246, 
      2.3454142293885414`}}]}, 
    {Hue[0.024558350220043833`], AbsoluteThickness[0.5], 
     LineBox[{{6.870236380829555, 3.3691329793077016`}, {6.8724290746151055`, 
      3.373182117757921}}]}, 
    {Hue[0.024815274373162232`], AbsoluteThickness[0.5], 
     LineBox[{{6.8724290746151055`, 3.373182117757921}, {7.003124398212361, 
      3.6079906150947636`}}]}, 
    {Hue[0.6306853733796587], AbsoluteThickness[0.5], 
     LineBox[{{7.003124398212361, 3.6079906150947636`}, {6.92702718309627, 
      3.350259142660075}}]}, 
    {Hue[0.5890488130166882], AbsoluteThickness[0.5], 
     LineBox[{{6.627968571385821, 3.330779419820731}, {6.432042587954802, 
      3.289830641470368}}]}, 
    {Hue[0.5893121952481882], AbsoluteThickness[0.5], 
     LineBox[{{6.432042587954802, 3.289830641470368}, {6.111271205088368, 
      3.217379756186872}}]}, 
    {Hue[0.5379427596689776], AbsoluteThickness[0.5], 
     LineBox[{{6.113068237539892, 3.2019670558902438`}, {5.931733824065761, 
      3.274166329938119}}]}, 
    {Hue[0.5382484855805013], AbsoluteThickness[0.5], 
     LineBox[{{5.931733824065761, 3.274166329938119}, {5.694227571827875, 
      3.35995367589864}}]}, 
    {Hue[0.5565906328474811], AbsoluteThickness[0.5], 
     LineBox[{{4.8504311220175405`, 3.076839050675112}, {4.8278581052002485`, 
      3.0863870995410028`}}]}, 
    {Hue[0.5576986065753923], AbsoluteThickness[0.5], 
     LineBox[{{4.8278581052002485`, 3.0863870995410028`}, {4.621053742438632, 
      3.2005754479059645`}}]}, 
    {Hue[0.6986163894372575], AbsoluteThickness[0.5], 
     LineBox[{{4.828494716892069, 2.9696293390170814`}, {4.684759557337465, 
      3.0094786263111604`}}]}, 
    {Hue[0.6989318535301052], AbsoluteThickness[0.5], 
     LineBox[{{4.684759557337465, 3.0094786263111604`}, {4.3930155230578745`, 
      3.0795092363184278`}}]}, 
    {Hue[0.43978487569475505`], AbsoluteThickness[0.5], 
     LineBox[{{5.180866273705958, 3.385695111684324}, {5.162036682857166, 
      3.446121160217095}}]}, 
    {Hue[0.445553024819607], AbsoluteThickness[0.5], 
     LineBox[{{5.162036682857166, 3.446121160217095}, {5.092648922647153, 
      3.5747868106971747`}}]}, 
    {Hue[0.6328835260871913], AbsoluteThickness[0.5], 
     LineBox[{{3.9229052700237093`, 1.856460856158855}, {3.9131623670005466`, 
      1.8581212598072754`}}]}, 
    {Hue[0.6334794401183663], AbsoluteThickness[0.5], 
     LineBox[{{3.9131623670005466`, 1.8581212598072754`}, {3.645643041027082, 
      1.8837662214640098`}}]}, 
    {Hue[0.4644036976181855], AbsoluteThickness[0.5], 
     LineBox[{{6.589711119764846, 0.47069834073975514`}, {6.6831399289177345`,
       0.38501985134845174`}}]}, 
    {Hue[0.4647451537700455], AbsoluteThickness[0.5], 
     LineBox[{{6.6831399289177345`, 0.38501985134845174`}, {6.895436373076653,
       0.17376712770961072`}}]}, 
    {Hue[0.675336429449619], AbsoluteThickness[0.5], 
     LineBox[{{3.341500215339184, 3.0533754102536497`}, {3.1994578617691314`, 
      3.0673179434367857`}}]}, 
    {Hue[0.6756207301057421], AbsoluteThickness[0.5], 
     LineBox[{{3.1994578617691314`, 3.0673179434367857`}, {
      2.8936289769586008`, 3.089460062787396}}]}, 
    {Hue[0.6845223587222489], AbsoluteThickness[0.5], 
     LineBox[{{5.58661605647694, 3.6737887253110886`}, {5.623619963971119, 
      3.6880790066910305`}}]}, 
    {Hue[0.6847744050834879], AbsoluteThickness[0.5], 
     LineBox[{{5.623619963971119, 3.6880790066910305`}, {5.9475610692372065`, 
      3.8155062614584927`}}]}, 
    {Hue[0.6161118450712174], AbsoluteThickness[0.5], 
     LineBox[{{2.7665035006206065`, -0.4072852424398593}, {
      2.7165882371266443`, -0.5166901079563464}}]}, 
    {Hue[0.6187865953702254], AbsoluteThickness[0.5], 
     LineBox[{{2.7165882371266443`, -0.5166901079563464}, {
      2.6031384129271653`, -0.6908657694886711}}]}, 
    {Hue[0.5333171833447504], AbsoluteThickness[0.5], 
     LineBox[{{5.84432195773474, -1.8677997581167494`}, {
      6.0861881636418715`, -2.4240132890400123`}}]}, 
    {Hue[0.53486127810203], AbsoluteThickness[0.5], 
     LineBox[{{6.0861881636418715`, -2.4240132890400123`}, {
      6.136698045527754, -2.5937159022859544`}}]}, 
    {Hue[0.667244103312722], AbsoluteThickness[0.5], 
     LineBox[{{3.2127736944018714`, -3.910223361320562}, {
      3.2269456487753896`, -4.096957411180845}}]}, 
    {Hue[0.6675709731256649], AbsoluteThickness[0.5], 
     LineBox[{{3.2269456487753896`, -4.096957411180845}, {
      3.261042946640137, -4.396473607339735}}]}, 
    {Hue[0.5540768771380437], AbsoluteThickness[0.5], 
     LineBox[{{6.628322250633668, -2.0263663046727043`}, {
      6.817065682926989, -2.06615698268591}}]}, 
    {Hue[0.6498476584826389], AbsoluteThickness[0.5], 
     LineBox[{{6.817065682926989, -2.06615698268591}, {
      6.923415448488757, -2.137661836724144}}]}, 
    {Hue[0.6997155280893075], AbsoluteThickness[0.5], 
     LineBox[{{6.923415448488757, -2.137661836724144}, {
      6.935549823606941, -2.2652391612240854`}}]}, 
    {Hue[0.5735851671933926], AbsoluteThickness[0.5], 
     LineBox[{{5.844347232206611, -2.8042806551477453`}, {
      5.91667951410321, -2.8422333137598987`}}]}, 
    {Hue[0.5740519064222888], AbsoluteThickness[0.5], 
     LineBox[{{5.91667951410321, -2.8422333137598987`}, {
      6.1801224370569114`, -3.0013389075099517`}}]}, 
    {Hue[0.6121234534527537], AbsoluteThickness[0.5], 
     LineBox[{{2.6023634415219066`, -2.842583477921545}, {
      2.6614281871771297`, -3.1434275704451102`}}]}, 
    {Hue[0.6124473429416015], AbsoluteThickness[0.5], 
     LineBox[{{2.6614281871771297`, -3.1434275704451102`}, {
      2.7290707615050587`, -3.4313132170334897`}}]}, 
    {Hue[0.6442573801623486], AbsoluteThickness[0.5], 
     LineBox[{{7.1496949592812715`, 1.0711418194545705`}, {7.371070381721035, 
      1.1256444323329329`}}]}, 
    {Hue[0.6449995807847905], AbsoluteThickness[0.5], 
     LineBox[{{7.371070381721035, 1.1256444323329329`}, {7.64433688702123, 
      1.1688973654271924`}}]}, 
    {Hue[0.41418108201214354`], AbsoluteThickness[0.5], 
     LineBox[{{6.6596057703003, -0.6676265290506701}, {
      6.670563830481701, -0.6877000643972937}}]}, 
    {Hue[0.41445172341438863`], AbsoluteThickness[0.5], 
     LineBox[{{6.670563830481701, -0.6877000643972937}, {
      6.812549246369549, -0.9358931344943826}}]}, 
    {Hue[0.6280466674757206], AbsoluteThickness[0.5], 
     LineBox[{{4.194406889972308, 0.5934257036608273}, {4.162600514418944, 
      0.5483589022990003}}]}, 
    {Hue[0.6295486291130821], AbsoluteThickness[0.5], 
     LineBox[{{4.162600514418944, 0.5483589022990003}, {4.011213447202338, 
      0.38057863846769757`}}]}, 
    {Hue[0.4273577889898665], AbsoluteThickness[0.5], 
     LineBox[{{7.299093719694063, 1.1341775845390394`}, {7.360980870679488, 
      1.1040945626172576`}}]}, 
    {Hue[0.4276109641779825], AbsoluteThickness[0.5], 
     LineBox[{{7.360980870679488, 1.1040945626172576`}, {7.676929213313557, 
      0.9535540279752687}}]}, 
    {Hue[0.5592876925384942], AbsoluteThickness[0.5], 
     LineBox[{{6.342907063208428, 1.1907352859901839`}, {6.345667404705263, 
      1.1521493821678286`}}]}, 
    {Hue[0.5599459575740209], AbsoluteThickness[0.5], 
     LineBox[{{6.345667404705263, 1.1521493821678286`}, {6.387068825009909, 
      0.877776375914825}}]}, 
    {Hue[0.542600717674325], AbsoluteThickness[0.5], 
     LineBox[{{7.052746961436152, 2.3439502480065597`}, {7.065906076418897, 
      2.336947731754838}}]}, 
    {Hue[0.5428509271401882], AbsoluteThickness[0.5], 
     LineBox[{{7.065906076418897, 2.336947731754838}, {7.34003953718945, 
      2.191647435191994}}]}, 
    {Hue[0.5888021239694124], AbsoluteThickness[0.5], 
     LineBox[{{7.055433350052246, 2.3454142293885414`}, {7.061638768552272, 
      2.3278673338830678`}}]}, 
    {Hue[0.5897619648580426], AbsoluteThickness[0.5], 
     LineBox[{{7.061638768552272, 2.3278673338830678`}, {7.15982092894483, 
      2.117761785165054}}]}, 
    {Hue[0.6304284492265392], AbsoluteThickness[0.5], 
     LineBox[{{6.8724290746151055`, 3.373182117757921}, {6.869594842047726, 
      3.3700799038466247`}}]}, 
    {Hue[0.6307040572840495], AbsoluteThickness[0.5], 
     LineBox[{{6.869594842047726, 3.3700799038466247`}, {6.686894621530799, 
      3.1788002229742016`}}]}, 
    {Hue[0.630942297532777], AbsoluteThickness[0.5], 
     LineBox[{{6.92702718309627, 3.350259142660075}, {6.784172165166792, 
      2.88629492525349}}]}, 
    {Hue[0.6311992135189725], AbsoluteThickness[0.5], 
     LineBox[{{6.784172165166792, 2.88629492525349}, {6.68462415261774, 
      2.5758158406618312`}}]}, 
    {Hue[0.5895755774796883], AbsoluteThickness[0.5], 
     LineBox[{{6.111271205088368, 3.217379756186872}, {5.982913983300251, 
      3.1862080818489593`}}]}, 
    {Hue[0.5968226146836707], AbsoluteThickness[0.5], 
     LineBox[{{5.982913983300251, 3.1862080818489593`}, {5.844754583379574, 
      3.1203950426335867`}}]}, 
    {Hue[0.5385542114920251], AbsoluteThickness[0.5], 
     LineBox[{{5.694227571827875, 3.35995367589864}, {5.601117383627474, 
      3.3902236044282628`}}]}, 
    {Hue[0.5390292914590205], AbsoluteThickness[0.5], 
     LineBox[{{5.601117383627474, 3.3902236044282628`}, {5.3190168548229195`, 
      3.501401141439642}}]}, 
    {Hue[0.5588065803033032], AbsoluteThickness[0.5], 
     LineBox[{{4.621053742438632, 3.2005754479059645`}, {4.4298106726995155`, 
      3.333906567194469}}]}, 
    {Hue[0.5599762957266499], AbsoluteThickness[0.5], 
     LineBox[{{4.4298106726995155`, 3.333906567194469}, {4.199543334953024, 
      3.4602433436092532`}}]}, 
    {Hue[0.699247317622953], AbsoluteThickness[0.5], 
     LineBox[{{4.3930155230578745`, 3.0795092363184278`}, {4.273960686841216, 
      3.103732040392748}}]}, 
    {Hue[0.45132117394445914`], AbsoluteThickness[0.5], 
     LineBox[{{5.092648922647153, 3.5747868106971747`}, {4.9097173396343186`, 
      3.797752322592934}}]}, 
    {Hue[0.4781538709735189], AbsoluteThickness[0.5], 
     LineBox[{{4.9097173396343186`, 3.797752322592934}, {4.79674534374431, 
      3.873256607225478}}]}, 
    {Hue[0.6259364633890808], AbsoluteThickness[0.5], 
     LineBox[{{4.79674534374431, 3.873256607225478}, {4.6691616939227005`, 
      3.826502129884358}}]}, 
    {Hue[0.6340753541495414], AbsoluteThickness[0.5], 
     LineBox[{{3.645643041027082, 1.8837662214640098`}, {3.584813152169185, 
      1.8851253856181935`}}]}, 
    {Hue[0.640144710219586], AbsoluteThickness[0.5], 
     LineBox[{{3.584813152169185, 1.8851253856181935`}, {3.4467447558277486`, 
      1.9156933404346077`}}]}, 
    {Hue[0.4650866099219055], AbsoluteThickness[0.5], 
     LineBox[{{6.895436373076653, 0.17376712770961072`}, {6.947167706986339, 
      0.11791141406897969`}}]}, 
    {Hue[0.4653450552997929], AbsoluteThickness[0.5], 
     LineBox[{{6.947167706986339, 0.11791141406897969`}, {
      7.1064571513223385`, -0.04972122607639848}}]}, 
    {Hue[0.6759050307618651], AbsoluteThickness[0.5], 
     LineBox[{{2.8936289769586008`, 3.089460062787396}, {2.881920455173306, 
      3.0900072996828576`}}]}, 
    {Hue[0.6765778635303872], AbsoluteThickness[0.5], 
     LineBox[{{2.881920455173306, 3.0900072996828576`}, {2.6261519685902845`, 
      3.1224493543441443`}}]}, 
    {Hue[0.6214613456692333], AbsoluteThickness[0.5], 
     LineBox[{{2.6031384129271653`, -0.6908657694886711}, {
      2.4565284794276554`, -0.8558101918633646}}]}, 
    {Hue[0.6227560920247062], AbsoluteThickness[0.5], 
     LineBox[{{2.4565284794276554`, -0.8558101918633646}, {
      2.3111790465977604`, -1.061773381735684}}]}, 
    {Hue[0.5364053728593094], AbsoluteThickness[0.5], 
     LineBox[{{6.136698045527754, -2.5937159022859544`}, {
      6.138486591994569, -2.6042363263946897`}}]}, 
    {Hue[0.5367622256700312], AbsoluteThickness[0.5], 
     LineBox[{{6.138486591994569, -2.6042363263946897`}, {
      6.189149744484542, -2.839375141523709}}]}, 
    {Hue[0.6678978429386079], AbsoluteThickness[0.5], 
     LineBox[{{3.261042946640137, -4.396473607339735}, {
      3.283803897308345, -4.546103334829277}}]}, 
    {Hue[0.6039447467447127], AbsoluteThickness[0.5], 
     LineBox[{{6.817065682926989, -2.06615698268591}, {
      6.878474607379338, -2.071825575868066}}]}, 
    {Hue[0.6043448673136913], AbsoluteThickness[0.5], 
     LineBox[{{6.878474607379338, -2.071825575868066}, {
      7.148005065713931, -2.0828607823720144`}}]}, 
    {Hue[0.5745186456511848], AbsoluteThickness[0.5], 
     LineBox[{{6.1801224370569114`, -3.0013389075099517`}, {
      6.344733031199407, -3.1147841220463763`}}]}, 
    {Hue[0.5790156769577491], AbsoluteThickness[0.5], 
     LineBox[{{6.344733031199407, -3.1147841220463763`}, {
      6.507427251398332, -3.1885042949877995`}}]}, 
    {Hue[0.6127712324304493], AbsoluteThickness[0.5], 
     LineBox[{{2.7290707615050587`, -3.4313132170334897`}, {
      2.7682221520554373`, -3.5740593174933197`}}]}, 
    {Hue[0.6131133646091393], AbsoluteThickness[0.5], 
     LineBox[{{2.7682221520554373`, -3.5740593174933197`}, {
      2.8340463324913787`, -3.8593353012462646`}}]}, 
    {Hue[0.6457417814072323], AbsoluteThickness[0.5], 
     LineBox[{{7.64433688702123, 1.1688973654271924`}, {7.695939705342266, 
      1.1726481873067818`}}]}, 
    {Hue[0.6466751629447927], AbsoluteThickness[0.5], 
     LineBox[{{7.695939705342266, 1.1726481873067818`}, {7.898840508279788, 
      1.207143234482058}}]}, 
    {Hue[0.4147223648166337], AbsoluteThickness[0.5], 
     LineBox[{{6.812549246369549, -0.9358931344943826}, {
      6.823913107143619, -0.954868906833488}}]}, 
    {Hue[0.41518479786288637`], AbsoluteThickness[0.5], 
     LineBox[{{6.823913107143619, -0.954868906833488}, {
      6.967112790907602, -1.164557684679741}}]}, 
    {Hue[0.6310505907504436], AbsoluteThickness[0.5], 
     LineBox[{{4.011213447202338, 0.38057863846769757`}, {3.909314503171563, 
      0.29170698005358225`}}]}, 
    {Hue[0.6313281976249056], AbsoluteThickness[0.5], 
     LineBox[{{3.909314503171563, 0.29170698005358225`}, {3.6657460842840828`,
       0.08895039112309869}}]}, 
    {Hue[0.42786413936609863`], AbsoluteThickness[0.5], 
     LineBox[{{7.676929213313557, 0.9535540279752687}, {7.746180307750265, 
      0.9212192680954135}}]}, 
    {Hue[0.4290421134430155], AbsoluteThickness[0.5], 
     LineBox[{{7.746180307750265, 0.9212192680954135}, {7.953192816365677, 
      0.795942597316979}}]}, 
    {Hue[0.5606042226095475], AbsoluteThickness[0.5], 
     LineBox[{{6.387068825009909, 0.877776375914825}, {6.40197001329752, 
      0.8135898684145415}}]}, 
    {Hue[0.5643644078993909], AbsoluteThickness[0.5], 
     LineBox[{{6.40197001329752, 0.8135898684145415}, {6.411207619952745, 
      0.6604642901254433}}]}, 
    {Hue[0.5431011366060513], AbsoluteThickness[0.5], 
     LineBox[{{7.34003953718945, 2.191647435191994}, {7.377264814408799, 
      2.1719950370086916`}}]}, 
    {Hue[0.5434187671337295], AbsoluteThickness[0.5], 
     LineBox[{{7.377264814408799, 2.1719950370086916`}, {7.6639877033527535`, 
      2.0073912879029545`}}]}, 
    {Hue[0.5907218057466725], AbsoluteThickness[0.5], 
     LineBox[{{7.15982092894483, 2.117761785165054}, {7.309325877947913, 
      1.86513658399791}}]}, 
    {Hue[0.5925513379010237], AbsoluteThickness[0.5], 
     LineBox[{{7.309325877947913, 1.86513658399791}, {7.394434421365845, 
      1.6665433553515911`}}]}, 
    {Hue[0.6309796653415598], AbsoluteThickness[0.5], 
     LineBox[{{6.686894621530799, 3.1788002229742016`}, {6.601016874146933, 
      3.0927913601150054`}}]}, 
    {Hue[0.631230330622965], AbsoluteThickness[0.5], 
     LineBox[{{6.601016874146933, 3.0927913601150054`}, {6.370151532423797, 
      2.859986980119582}}]}, 
    {Hue[0.6314561295051678], AbsoluteThickness[0.5], 
     LineBox[{{6.68462415261774, 2.5758158406618312`}, {6.54281742853237, 
      2.1505421707509247`}}]}, 
    {Hue[0.6317211167341545], AbsoluteThickness[0.5], 
     LineBox[{{6.54281742853237, 2.1505421707509247`}, {6.44714077861506, 
      1.8464473560053958`}}]}, 
    {Hue[0.6040696518876529], AbsoluteThickness[0.5], 
     LineBox[{{5.844754583379574, 3.1203950426335867`}, {5.600838324902705, 
      2.934634109086809}}]}, 
    {Hue[0.6061342425983952], AbsoluteThickness[0.5], 
     LineBox[{{5.600838324902705, 2.934634109086809}, {5.423422985520643, 
      2.834188821259464}}]}, 
    {Hue[0.5395043714260158], AbsoluteThickness[0.5], 
     LineBox[{{5.3190168548229195`, 3.501401141439642}, {4.923848756689937, 
      3.6857564350598766`}}]}, 
    {Hue[0.5397689674306281], AbsoluteThickness[0.5], 
     LineBox[{{4.923848756689937, 3.6857564350598766`}, {4.653438827889254, 
      3.8064166920639053`}}]}, 
    {Hue[0.5611460111499965], AbsoluteThickness[0.5], 
     LineBox[{{4.199543334953024, 3.4602433436092532`}, {4.131627770924193, 
      3.488540968468756}}]}, 
    {Hue[0.5613961037175722], AbsoluteThickness[0.5], 
     LineBox[{{4.131627770924193, 3.488540968468756}, {3.8591624457977622`, 
      3.6018653547679746`}}]}, 
    {Hue[0.6527691604181409], AbsoluteThickness[0.5], 
     LineBox[{{4.6691616939227005`, 3.826502129884358}, {4.159378778323914, 
      3.4423218331074192`}}]}, 
    {Hue[0.6462140662896304], AbsoluteThickness[0.5], 
     LineBox[{{3.4467447558277486`, 1.9156933404346077`}, {3.142589105985879, 
      2.049129331948768}}]}, 
    {Hue[0.6470919923003748], AbsoluteThickness[0.5], 
     LineBox[{{3.142589105985879, 2.049129331948768}, {2.9183445766281695`, 
      2.1235967957908164`}}]}, 
    {Hue[0.4656035006776805], AbsoluteThickness[0.5], 
     LineBox[{{7.1064571513223385`, -0.049721226076398506`}, {
      7.195214764426184, -0.1407648267732008}}]}, 
    {Hue[0.46597024644181867`], AbsoluteThickness[0.5], 
     LineBox[{{7.195214764426184, -0.1407648267732008}, {
      7.380789063238402, -0.3493638633931968}}]}, 
    {Hue[0.6772506962989092], AbsoluteThickness[0.5], 
     LineBox[{{2.6261519685902845`, 3.1224493543441443`}, {
      2.4122865310735837`, 3.1670572589411505`}}]}, 
    {Hue[0.6775268791153337], AbsoluteThickness[0.5], 
     LineBox[{{2.4122865310735837`, 3.1670572589411505`}, {
      2.1099160340483705`, 3.2372328195376054`}}]}, 
    {Hue[0.6240508383801789], AbsoluteThickness[0.5], 
     LineBox[{{2.3111790465977604`, -1.061773381735684}, {
      2.271799391313008, -1.1334356053217842`}}]}, 
    {Hue[0.6243397576124241], AbsoluteThickness[0.5], 
     LineBox[{{2.271799391313008, -1.1334356053217842`}, {
      2.131486941001946, -1.4060787236812051`}}]}, 
    {Hue[0.537119078480753], AbsoluteThickness[0.5], 
     LineBox[{{6.189149744484542, -2.839375141523709}, {
      6.258175063960805, -3.1030507823609663`}}]}, 
    {Hue[0.5374071790802737], AbsoluteThickness[0.5], 
     LineBox[{{6.258175063960805, -3.1030507823609663`}, {
      6.325436669366079, -3.391447487881678}}]}, 
    {Hue[0.60474498788267], AbsoluteThickness[0.5], 
     LineBox[{{7.148005065713931, -2.0828607823720144`}, {
      7.3944098763444135`, -2.080345116270067}}]}, 
    {Hue[0.6061692091022701], AbsoluteThickness[0.5], 
     LineBox[{{7.3944098763444135`, -2.080345116270067}, {
      7.594637500409776, -2.0547700894787924`}}]}, 
    {Hue[0.5835127082643137], AbsoluteThickness[0.5], 
     LineBox[{{6.507427251398332, -3.1885042949877995`}, {
      6.581087422998029, -3.2071144443191195`}}]}, 
    {Hue[0.5837686418957913], AbsoluteThickness[0.5], 
     LineBox[{{6.581087422998029, -3.2071144443191195`}, {
      6.8998848695485355`, -3.2840309347952745`}}]}, 
    {Hue[0.6134554967878294], AbsoluteThickness[0.5], 
     LineBox[{{2.8340463324913787`, -3.8593353012462646`}, {
      2.836254073664531, -3.8710774108300923`}}]}, 
    {Hue[0.6145478755900454], AbsoluteThickness[0.5], 
     LineBox[{{2.836254073664531, -3.8710774108300923`}, {
      2.902274549453628, -4.092735537422182}}]}, 
    {Hue[0.647608544482353], AbsoluteThickness[0.5], 
     LineBox[{{7.898840508279788, 1.207143234482058}, {8.11845758982266, 
      1.2665642781901794`}}]}, 
    {Hue[0.6478744955725907], AbsoluteThickness[0.5], 
     LineBox[{{8.11845758982266, 1.2665642781901794`}, {8.458096143696963, 
      1.3520861181112278`}}]}, 
    {Hue[0.415647230909139], AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{6.967112790907602, -1.164557684679741}, {
      7.472043551924691, -1.8168314038216429`}}], 
     {Hue[0.4161383887865473], AbsoluteThickness[0.5], 
      LineBox[{{7.472043551924691, -1.8168314038216429`}, {
       7.613276642245896, -2.0251344925925925`}}]}, 
     {Hue[0.6316058044993674], AbsoluteThickness[0.5], 
      LineBox[{{3.6657460842840828`, 0.08895039112309869}, {3.601920810139242,
        0.03825896276590701}}]}, 
     {Hue[0.6319034543937501], AbsoluteThickness[0.5], 
      LineBox[{{3.601920810139242, 0.03825896276590701}, {
       3.352814973709669, -0.14769201953112554`}}]}, 
     {Hue[0.43022008751993257`], AbsoluteThickness[0.5], 
      LineBox[{{7.953192816365677, 0.795942597316979}, {8.073748447252859, 
       0.7039945149150131}}]}, 
     {Hue[0.43361844896154317`], AbsoluteThickness[0.5], 
      LineBox[{{8.073748447252859, 0.7039945149150131}, {8.244579678764612, 
       0.6130227237162458}}]}, 
     {Hue[0.5681245931892343], AbsoluteThickness[0.5], 
      LineBox[{{6.411207619952745, 0.6604642901254433}, {6.4096880340628015`, 
       0.6463970470040612}}]}, 
     {Hue[0.5686014673116557], AbsoluteThickness[0.5], 
      LineBox[{{6.4096880340628015`, 0.6463970470040612}, {6.399055190369889, 
       0.41691817346934823`}}]}, 
     {Hue[0.5437363976614076], AbsoluteThickness[0.5], 
      LineBox[{{7.6639877033527535`, 2.0073912879029545`}, {7.845186540461246,
        1.894657068653427}}]}, 
     {Hue[0.6098983262239017], AbsoluteThickness[0.5], 
      LineBox[{{7.845186540461246, 1.894657068653427}, {7.937404463189062, 
       1.7744998753114223`}}]}, 
     {Hue[0.6843919531045859], AbsoluteThickness[0.5], 
      LineBox[{{7.937404463189062, 1.7744998753114223`}, {7.901659173718475, 
       1.6273123396138465`}}]}, 
     {Hue[0.5943808700553747], AbsoluteThickness[0.5], 
      LineBox[{{7.394434421365845, 1.6665433553515911`}, {7.400505331129355, 
       1.64505847790316}}]}, 
     {Hue[0.5946810784274484], AbsoluteThickness[0.5], 
      LineBox[{{7.400505331129355, 1.64505847790316}, {7.495467306899358, 
       1.3445927952284717`}}]}, 
     {Hue[0.6314809959043701], AbsoluteThickness[0.5], 
      LineBox[{{6.370151532423797, 2.859986980119582}, {6.363417575723727, 
       2.8531498673771902`}}]}, 
     {Hue[0.6317882225228579], AbsoluteThickness[0.5], 
      LineBox[{{6.363417575723727, 2.8531498673771902`}, {6.132186252315493, 
       2.633247887845136}}]}, 
     {Hue[0.6319861039631413], AbsoluteThickness[0.5], 
      LineBox[{{6.44714077861506, 1.8464473560053958`}, {6.422598891174611, 
       1.7635377790729578`}}]}, 
     {Hue[0.6342653814301198], AbsoluteThickness[0.5], 
      LineBox[{{6.422598891174611, 1.7635377790729578`}, {6.338907515057685, 
       1.5803950602442898`}}]}, 
     {Hue[0.6081988333091374], AbsoluteThickness[0.5], 
      LineBox[{{5.423422985520643, 2.834188821259464}, {5.362189451703542, 
       2.8097696897745297`}}]}, 
     {Hue[0.6084830183207579], AbsoluteThickness[0.5], 
      LineBox[{{5.362189451703542, 2.8097696897745297`}, {5.115501654555927, 
       2.7040182023562425`}}]}, 
     {Hue[0.561646196285148], AbsoluteThickness[0.5], 
      LineBox[{{3.8591624457977622`, 3.6018653547679746`}, {3.79781733451961, 
       3.6273349824534367`}}]}, 
     {Hue[0.566024953189596], AbsoluteThickness[0.5], 
      LineBox[{{3.79781733451961, 3.6273349824534367`}, {3.648984401631715, 
       3.72272832346326}}]}, 
     {Hue[0.6479699183111193], AbsoluteThickness[0.5], 
      LineBox[{{2.9183445766281695`, 2.1235967957908164`}, {2.851979455412283,
        2.1389833421440163`}}]}, 
     {Hue[0.6483391164862606], AbsoluteThickness[0.5], 
      LineBox[{{2.851979455412283, 2.1389833421440163`}, {2.5372686934968134`,
        2.227401456306575}}]}, 
     {Hue[0.46633699220595687`], AbsoluteThickness[0.5], 
      LineBox[{{7.380789063238402, -0.3493638633931968}, {
       7.386896156885301, -0.35689409239406217`}}]}, 
     {Hue[0.4665880923846645], AbsoluteThickness[0.5], 
      LineBox[{{7.386896156885301, -0.3568940923940622}, {
       7.577250490989564, -0.5937781790870492}}]}, 
     {Hue[0.6246286768446692], AbsoluteThickness[0.5], 
      LineBox[{{2.131486941001946, -1.4060787236812051`}, {
       2.1294309556098607`, -1.4103556056718418`}}]}, 
     {Hue[0.6251363574583987], AbsoluteThickness[0.5], 
      LineBox[{{2.1294309556098607`, -1.4103556056718418`}, {
       1.996570713589239, -1.6463004345920698`}}]}, 
     {Hue[0.5376952796797945], AbsoluteThickness[0.5], 
      LineBox[{{6.325436669366079, -3.391447487881678}, {
       6.333284610649777, -3.429725084139155}}]}, 
     {Hue[0.5429050292271012], AbsoluteThickness[0.5], 
      LineBox[{{6.333284610649777, -3.429725084139155}, {
       6.396909614364865, -3.585074754147325}}]}, 
     {Hue[0.6075934303218703], AbsoluteThickness[0.5], 
      LineBox[{{7.594637500409776, -2.0547700894787924`}, {
       7.862770423206938, -1.9880513178537393`}}]}, 
     {Hue[0.607871469275151], AbsoluteThickness[0.5], 
      LineBox[{{7.862770423206938, -1.9880513178537393`}, {
       8.138785934526915, -1.9261273963452372`}}]}, 
     {Hue[0.5840245755272689], AbsoluteThickness[0.5], 
      LineBox[{{6.8998848695485355`, -3.2840309347952745`}, {
       7.070601717050063, -3.3232875192919686`}}]}, 
     {Hue[0.5846557038725141], AbsoluteThickness[0.5], 
      LineBox[{{7.070601717050063, -3.3232875192919686`}, {
       7.331661041955528, -3.3626967620321624`}}]}, 
     {Hue[0.6156402543922613], AbsoluteThickness[0.5], 
      LineBox[{{2.902274549453628, -4.092735537422182}, {
       3.0084609378174423`, -4.348791884725749}}]}, 
     {Hue[0.616010955165381], AbsoluteThickness[0.5], 
      LineBox[{{3.0084609378174423`, -4.348791884725749}, {
       3.11281219185615, -4.637544924284592}}]}, 
     {Hue[0.4166295466639558], AbsoluteThickness[0.5], 
      LineBox[{{7.613276642245896, -2.0251344925925925`}, {
       7.673814098749379, -2.1277750336207784`}}]}, 
     {Hue[0.41688200027213834`], AbsoluteThickness[0.5], 
      LineBox[{{7.673814098749379, -2.1277750336207784`}, {
       7.829964722013148, -2.3884314396344815`}}]}, 
     {Hue[0.6322011042881327], AbsoluteThickness[0.5], 
      LineBox[{{3.352814973709669, -0.14769201953112554`}, {
       3.3499343880344807`, -0.14971077961280854`}}]}, 
     {Hue[0.6325267842334633], AbsoluteThickness[0.5], 
      LineBox[{{3.3499343880344807`, -0.14971077961280854`}, {
       3.11181891815503, -0.3302031424239867}}]}, 
     {Hue[0.5690783414340773], AbsoluteThickness[0.5], 
      LineBox[{{6.399055190369889, 0.41691817346934823`}, {6.400497973811012, 
       0.3207558907363526}}]}, 
     {Hue[0.6059886765856479], AbsoluteThickness[0.5], 
      LineBox[{{6.400497973811012, 0.3207558907363526}, {6.35690496847559, 
       0.18118163907119234`}}]}, 
     {Hue[0.6182300245420785], AbsoluteThickness[0.5], 
      LineBox[{{7.845186540461246, 1.894657068653427}, {7.945475262842104, 
       1.8542491451370262`}}]}, 
     {Hue[0.6246461221736989], AbsoluteThickness[0.5], 
      LineBox[{{7.945475262842104, 1.8542491451370262`}, {8.093860689373118, 
       1.82661370067177}}]}, 
     {Hue[0.6760602547863838], AbsoluteThickness[0.5], 
      LineBox[{{7.937404463189062, 1.7744998753114223`}, {7.990261836845268, 
       1.600514445248793}}]}, 
     {Hue[0.6763691288691176], AbsoluteThickness[0.5], 
      LineBox[{{7.990261836845268, 1.600514445248793}, {8.057838173976824, 
       1.348305669897045}}]}, 
     {Hue[0.5949812867995223], AbsoluteThickness[0.5], 
      LineBox[{{7.495467306899358, 1.3445927952284717`}, {7.540720092606828, 
       1.2153688751381408`}}]}, 
     {Hue[0.5953330951547485], AbsoluteThickness[0.5], 
      LineBox[{{7.540720092606828, 1.2153688751381408`}, {7.634931474926061, 
       0.9041952233679278}}]}, 
     {Hue[0.6320954491413459], AbsoluteThickness[0.5], 
      LineBox[{{6.132186252315493, 2.633247887845136}, {5.895653792058798, 
       2.422598799861801}}]}, 
     {Hue[0.6365446588970984], AbsoluteThickness[0.5], 
      LineBox[{{6.338907515057685, 1.5803950602442898`}, {6.239119767275378, 
       1.4245359139656553`}}]}, 
     {Hue[0.6368667457250918], AbsoluteThickness[0.5], 
      LineBox[{{6.239119767275378, 1.4245359139656553`}, {6.088580323600351, 
       1.1693639098132889`}}]}, 
     {Hue[0.6087672033323785], AbsoluteThickness[0.5], 
      LineBox[{{5.115501654555927, 2.7040182023562425`}, {5.0572578316209835`,
        2.6772699644896436`}}]}, 
     {Hue[0.6117355017481816], AbsoluteThickness[0.5], 
      LineBox[{{5.0572578316209835`, 2.6772699644896436`}, {4.918535752145572,
        2.5853102116589803`}}]}, 
     {Hue[0.648708314661402], AbsoluteThickness[0.5], 
      LineBox[{{2.5372686934968134`, 2.227401456306575}, {2.362350028338312, 
       2.2853594589822794`}}]}, 
     {Hue[0.6494109962001581], AbsoluteThickness[0.5], 
      LineBox[{{2.362350028338312, 2.2853594589822794`}, {2.142251552429286, 
       2.3388235262998447`}}]}, 
     {Hue[0.466839192563372], AbsoluteThickness[0.5], 
      LineBox[{{7.577250490989564, -0.5937781790870492}, {
       7.634250516159993, -0.6653687164689441}}]}, 
     {Hue[0.4671366053707605], AbsoluteThickness[0.5], 
      LineBox[{{7.634250516159993, -0.6653687164689441}, {
       7.815858907091821, -0.8799728194641517}}]}, 
     {Hue[0.5481147787744082], AbsoluteThickness[0.5], 
      LineBox[{{6.396909614364865, -3.585074754147325}, {
       6.580597256231429, -3.8683890898111133`}}]}, 
     {Hue[0.5516172571588075], AbsoluteThickness[0.5], 
      LineBox[{{6.580597256231429, -3.8683890898111133`}, {
       6.657992790763941, -4.045830108051133}}]}, 
     {Hue[0.5852868322177595], AbsoluteThickness[0.5], 
      LineBox[{{7.331661041955528, -3.3626967620321624`}, {
       7.622626653313782, -3.384160258180527}}]}, 
     {Hue[0.5869964943688805], AbsoluteThickness[0.5], 
      LineBox[{{7.622626653313782, -3.384160258180527}, {
       7.851059126118891, -3.3721775431831134`}}]}, 
     {Hue[0.417134453880321], AbsoluteThickness[0.5], 
      LineBox[{{7.829964722013148, -2.3884314396344815`}, {
       7.838923142264546, -2.403155766863336}}]}, 
     {Hue[0.4176214265850243], AbsoluteThickness[0.5], 
      LineBox[{{7.838923142264546, -2.403155766863336}, {
       7.989184433633879, -2.6185856301593993`}}]}, 
     {Hue[0.6328524641787938], AbsoluteThickness[0.5], 
      LineBox[{{3.11181891815503, -0.3302031424239867}, {
       3.100270655880693, -0.33965566594909047`}}]}, 
     {Hue[0.6331213300038846], AbsoluteThickness[0.5], 
      LineBox[{{3.100270655880693, -0.33965566594909047`}, {
       2.865425447276905, -0.5394858651631779}}]}, 
     {Hue[0.689322371633379], AbsoluteThickness[0.5], 
      LineBox[{{6.400497973811012, 0.3207558907363526}, {6.442236546305124, 
       0.18497966965889207`}}]}, 
     {Hue[0.6895745495408684], AbsoluteThickness[0.5], 
      LineBox[{{6.442236546305124, 0.18497966965889207`}, {
       6.538396334409575, -0.12080511794752492`}}]}, 
     {Hue[0.6428990117372153], AbsoluteThickness[0.5], 
      LineBox[{{6.35690496847559, 0.18118163907119234`}, {
       6.129802884342204, -0.13662008007963117`}}]}, 
     {Hue[0.6478033619572376], AbsoluteThickness[0.5], 
      LineBox[{{6.129802884342204, -0.13662008007963117`}, {
       6.051689813710369, -0.3036313073538353}}]}, 
     {Hue[0.6310622198053188], AbsoluteThickness[0.5], 
      LineBox[{{8.093860689373118, 1.82661370067177}, {8.114859412553642, 
       1.8269235548753118`}}]}, 
     {Hue[0.631543087366097], AbsoluteThickness[0.5], 
      LineBox[{{8.114859412553642, 1.8269235548753118`}, {8.359910116098247, 
       1.8153948276233836`}}]}, 
     {Hue[0.6766780029518515], AbsoluteThickness[0.5], 
      LineBox[{{8.057838173976824, 1.348305669897045}, {8.093298227489985, 
       1.195923366118425}}]}, 
     {Hue[0.6771942962332361], AbsoluteThickness[0.5], 
      LineBox[{{8.093298227489985, 1.195923366118425}, {8.138744308167237, 
       0.9195639681616101}}]}, 
     {Hue[0.5956849035099748], AbsoluteThickness[0.5], 
      LineBox[{{7.634931474926061, 0.9041952233679278}, {7.648426531562739, 
       0.8515930978164389}}]}, 
     {Hue[0.5963918224880174], AbsoluteThickness[0.5], 
      LineBox[{{7.648426531562739, 0.8515930978164389}, {7.736307680533997, 
       0.5975961469660709}}]}, 
     {Hue[0.6323990332442144], AbsoluteThickness[0.5], 
      LineBox[{{5.895653792058798, 2.422598799861801}, {5.761542557909216, 
       2.310579178281262}}]}, 
     {Hue[0.6327486026463169], AbsoluteThickness[0.5], 
      LineBox[{{5.761542557909216, 2.310579178281262}, {5.590711774492368, 
       2.1797763717747256`}}]}, 
     {Hue[0.6371888325530853], AbsoluteThickness[0.5], 
      LineBox[{{6.088580323600351, 1.1693639098132889`}, {6.064248751581963, 
       1.1244537168611635`}}]}, 
     {Hue[0.6375103135633582], AbsoluteThickness[0.5], 
      LineBox[{{6.064248751581963, 1.1244537168611635`}, {5.923778308628391, 
       0.8410537145664334}}]}, 
     {Hue[0.6147038001639846], AbsoluteThickness[0.5], 
      LineBox[{{4.918535752145572, 2.5853102116589803`}, {4.735716654693296, 
       2.418288311638862}}]}, 
     {Hue[0.6155950575325724], AbsoluteThickness[0.5], 
      LineBox[{{4.735716654693296, 2.418288311638862}, {4.574539778475723, 
       2.240693486107626}}]}, 
     {Hue[0.6501136777389143], AbsoluteThickness[0.5], 
      LineBox[{{2.142251552429286, 2.3388235262998447`}, {2.095101168276021, 
       2.346269734621504}}]}, 
     {Hue[0.6506293628390886], AbsoluteThickness[0.5], 
      LineBox[{{2.095101168276021, 2.346269734621504}, {1.7955415459025563`, 
       2.4139544990959685`}}]}, 
     {Hue[0.46743401817814906`], AbsoluteThickness[0.5], 
      LineBox[{{7.815858907091821, -0.8799728194641517}, {
       7.902407439457966, -0.9762554167832733}}]}, 
     {Hue[0.46783072857517255`], AbsoluteThickness[0.5], 
      LineBox[{{7.902407439457966, -0.9762554167832733}, {
       8.090747303273506, -1.1655717837434763`}}]}, 
     {Hue[0.555119735543207], AbsoluteThickness[0.5], 
      LineBox[{{6.657992790763941, -4.045830108051133}, {
       6.673695374532744, -4.108005247848721}}]}, 
     {Hue[0.5553703283514367], AbsoluteThickness[0.5], 
      LineBox[{{6.673695374532744, -4.108005247848721}, {
       6.7513162166877425`, -4.419548980886083}}]}, 
     {Hue[0.5887061565200015], AbsoluteThickness[0.5], 
      LineBox[{{7.851059126118891, -3.3721775431831134`}, {
       7.905593897144802, -3.362341205936984}}]}, 
     {Hue[0.589674722367168], AbsoluteThickness[0.5], 
      LineBox[{{7.905593897144802, -3.362341205936984}, {
       8.1358762885746, -3.343699472643357}}]}, 
     {Hue[0.4181083992897276], AbsoluteThickness[0.5], 
      LineBox[{{7.989184433633879, -2.6185856301593993`}, {
       8.097884866821433, -2.755365968597964}}]}, 
     {Hue[0.4187947720304817], AbsoluteThickness[0.5], 
      LineBox[{{8.097884866821433, -2.755365968597964}, {
       8.302462564269772, -2.9740948258154787`}}]}, 
     {Hue[0.6333901958289755], AbsoluteThickness[0.5], 
      LineBox[{{2.865425447276905, -0.5394858651631779}, {
       2.766587101878663, -0.6268934620577788}}]}, 
     {Hue[0.635296775689011], AbsoluteThickness[0.5], 
      LineBox[{{2.766587101878663, -0.6268934620577788}, {
       2.642565200647696, -0.7697065791220935}}]}, 
     {Hue[0.689826727448358], AbsoluteThickness[0.5], 
      LineBox[{{6.538396334409575, -0.12080511794752492`}, {
       6.55539507341012, -0.17366859087537986`}}]}, 
     {Hue[0.6910072637310497], AbsoluteThickness[0.5], 
      LineBox[{{6.55539507341012, -0.17366859087537986`}, {
       6.651632737238417, -0.3899858578975961}}]}, 
     {Hue[0.6527077121772594], AbsoluteThickness[0.5], 
      LineBox[{{6.051689813710369, -0.3036313073538353}, {
       6.033206092354772, -0.3746811332079668}}]}, 
     {Hue[0.6530237882916559], AbsoluteThickness[0.5], 
      LineBox[{{6.033206092354772, -0.3746811332079668}, {
       5.959892316964358, -0.620783828372349}}]}, 
     {Hue[0.6777105895146207], AbsoluteThickness[0.5], 
      LineBox[{{8.138744308167237, 0.9195639681616101}, {8.138905739810978, 
       0.9179107472959476}}]}, 
     {Hue[0.6780629880307423], AbsoluteThickness[0.5], 
      LineBox[{{8.138905739810978, 0.9179107472959476}, {8.181490830233685, 
       0.6163920380290837}}]}, 
     {Hue[0.5970987414660601], AbsoluteThickness[0.5], 
      LineBox[{{7.736307680533997, 0.5975961469660709}, {7.843615820486535, 
       0.3540845846064808}}]}, 
     {Hue[0.5989572239408675], AbsoluteThickness[0.5], 
      LineBox[{{7.843615820486535, 0.35408458460648073`}, {7.906283684035554, 
       0.14000278366464727`}}]}, 
     {Hue[0.6330981720484194], AbsoluteThickness[0.5], 
      LineBox[{{5.590711774492368, 2.1797763717747256`}, {5.554645712400338, 
       2.1545128391721047`}}]}, 
     {Hue[0.6348424543944946], AbsoluteThickness[0.5], 
      LineBox[{{5.554645712400338, 2.1545128391721047`}, {5.436759762881569, 
       2.092541414539102}}]}, 
     {Hue[0.6378317945736309], AbsoluteThickness[0.5], 
      LineBox[{{5.923778308628391, 0.8410537145664334}, {5.911391499007574, 
       0.8135990278959359}}]}, 
     {Hue[0.6389144307710974], AbsoluteThickness[0.5], 
      LineBox[{{5.911391499007574, 0.8135990278959359}, {5.800286082691915, 
       0.6226690472339603}}]}, 
     {Hue[0.6164863149011602], AbsoluteThickness[0.5], 
      LineBox[{{4.574539778475723, 2.240693486107626}, {4.489869966561864, 
       2.127782006615319}}]}, 
     {Hue[0.6180091493898828], AbsoluteThickness[0.5], 
      LineBox[{{4.489869966561864, 2.127782006615319}, {4.3798549000950695`, 
       1.9370678196028828`}}]}, 
     {Hue[0.46822743897219604`], AbsoluteThickness[0.5], 
      LineBox[{{8.090747303273506, -1.1655717837434763`}, {
       8.115806590593929, -1.1883330044520575`}}]}, 
     {Hue[0.4686042897264884], AbsoluteThickness[0.5], 
      LineBox[{{8.115806590593929, -1.1883330044520575`}, {
       8.324111057466014, -1.3602501898509973`}}]}, 
     {Hue[0.5906432882143345], AbsoluteThickness[0.5], 
      LineBox[{{8.1358762885746, -3.343699472643357}, {
       8.147746473129228, -3.343900080858048}}]}, 
     {Hue[0.5909434479808976], AbsoluteThickness[0.5], 
      LineBox[{{8.147746473129228, -3.343900080858048}, {
       8.444951468766515, -3.3397938845316837`}}]}, 
     {Hue[0.6372033555490466], AbsoluteThickness[0.5], 
      LineBox[{{2.642565200647696, -0.7697065791220936}, {
       2.573241274151232, -0.8747166752528607}}]}, 
     {Hue[0.6374568515440285], AbsoluteThickness[0.5], 
      LineBox[{{2.573241274151232, -0.8747166752528607}, {
       2.3789221540677463`, -1.1743857470518662`}}]}, 
     {Hue[0.6921878000137414], AbsoluteThickness[0.5], 
      LineBox[{{6.651632737238417, -0.3899858578975961}, {
       6.680702489549853, -0.4400490893752774}}]}, 
     {Hue[0.6533398644060522], AbsoluteThickness[0.5], 
      LineBox[{{5.959892316964358, -0.6207838283723489}, {
       5.814462852328486, -1.0530398534026482`}}]}, 
     {Hue[0.653590255118556], AbsoluteThickness[0.5], 
      LineBox[{{5.814462852328486, -1.0530398534026482`}, {
       5.712193680926692, -1.3545106418775588`}}]}, 
     {Hue[0.6784153865468638], AbsoluteThickness[0.5], 
      LineBox[{{8.181490830233685, 0.6163920380290837}, {8.226057244089962, 
       0.37595583255910137`}}]}, 
     {Hue[0.6786843434439773], AbsoluteThickness[0.5], 
      LineBox[{{8.226057244089962, 0.37595583255910137`}, {8.277112962483969, 
       0.06771950836415405}}]}, 
     {Hue[0.6008157064156748], AbsoluteThickness[0.5], 
      LineBox[{{7.906283684035554, 0.14000278366464727`}, {7.910607119566029, 
       0.11223824497571741`}}]}, 
     {Hue[0.6012085506340132], AbsoluteThickness[0.5], 
      LineBox[{{7.910607119566029, 0.11223824497571741`}, {
       7.968913427601454, -0.16892237859592932`}}]}, 
     {Hue[0.6365867367405696], AbsoluteThickness[0.5], 
      LineBox[{{5.436759762881569, 2.092541414539102}, {5.16231881926197, 
       1.9902026803354738`}}]}, 
     {Hue[0.6368511476297873], AbsoluteThickness[0.5], 
      LineBox[{{5.16231881926197, 1.9902026803354738`}, {4.924494840608668, 
       1.8969645362410954`}}]}, 
     {Hue[0.6399970669685641], AbsoluteThickness[0.5], Arrowheads[Small], 
      ArrowBox[{{5.800286082691915, 0.6226690472339603}, {
       5.326636014781927, -0.026674293656156783`}}], 
      {Hue[0.6403165822488438], AbsoluteThickness[0.5], 
       LineBox[{{5.326636014781927, -0.026674293656156783`}, {
        5.136013853612387, -0.3087195500767111}}]}, 
      {Hue[0.6195319838786055], AbsoluteThickness[0.5], 
       LineBox[{{4.3798549000950695`, 1.9370678196028828`}, {
        4.3632811221059224`, 1.898196657007209}}]}, 
      {Hue[0.6197849497756532], AbsoluteThickness[0.5], 
       LineBox[{{4.3632811221059224`, 1.898196657007209}, {4.230764956798872, 
        1.5937882799443601`}}]}, 
      {Hue[0.6377103475390103], AbsoluteThickness[0.5], 
       LineBox[{{2.3789221540677463`, -1.1743857470518662`}, {
        2.3655281443750127`, -1.1954173676417008`}}]}, 
      {Hue[0.6380367261425031], AbsoluteThickness[0.5], 
       LineBox[{{2.3655281443750127`, -1.1954173676417008`}, {
        2.195924356136675, -1.4409126869101498`}}]}, 
      {Hue[0.6538406458310597], AbsoluteThickness[0.5], 
       LineBox[{{5.712193680926692, -1.3545106418775588`}, {
        5.682139423618865, -1.4423808636695912`}}]}, 
      {Hue[0.6547298597596017], AbsoluteThickness[0.5], 
       LineBox[{{5.682139423618865, -1.4423808636695912`}, {
        5.583632229640845, -1.6612043328755821`}}]}, 
      {Hue[0.6789533003410908], AbsoluteThickness[0.5], 
       LineBox[{{8.277112962483969, 0.06771950836415402}, {
        8.29688591829324, -0.06767040575322286}}]}, 
      {Hue[0.6792556269041045], AbsoluteThickness[0.5], 
       LineBox[{{8.29688591829324, -0.06767040575322286}, {
        8.33406317609322, -0.3933010069670969}}]}, 
      {Hue[0.6016013948523516], AbsoluteThickness[0.5], 
       LineBox[{{7.968913427601454, -0.1689223785959293}, {
        8.03083864945951, -0.4069864239146226}}]}, 
      {Hue[0.602585143987095], AbsoluteThickness[0.5], 
       LineBox[{{8.03083864945951, -0.40698642391462253`}, {
        8.064620340164055, -0.6217258969179386}}]}, 
      {Hue[0.6371155585190051], AbsoluteThickness[0.5], 
       LineBox[{{4.924494840608668, 1.8969645362410954`}, {
        4.7892243311476665`, 1.8413078559149847`}}]}, 
      {Hue[0.6379484983754546], AbsoluteThickness[0.5], 
       LineBox[{{4.7892243311476665`, 1.8413078559149847`}, {
        4.580060468748022, 1.7765716645052394`}}]}, 
      {Hue[0.6406360975291236], AbsoluteThickness[0.5], 
       LineBox[{{5.136013853612387, -0.3087195500767111}, {
        5.086682200198773, -0.38767281989049884`}}]}, 
      {Hue[0.6408862507736908], AbsoluteThickness[0.5], 
       LineBox[{{5.086682200198773, -0.38767281989049884`}, {
        4.925115912417168, -0.6455285030694189}}]}, 
      {Hue[0.6200379156727011], AbsoluteThickness[0.5], 
       LineBox[{{4.230764956798872, 1.5937882799443601`}, {4.131603219941443, 
        1.370616429771757}}]}, 
      {Hue[0.6321484472937067], AbsoluteThickness[0.5], 
       LineBox[{{4.131603219941443, 1.370616429771757}, {4.104016248767022, 
        1.2181127976235193`}}]}, 
      {Hue[0.6383631047459957], AbsoluteThickness[0.5], 
       LineBox[{{2.195924356136675, -1.4409126869101498`}, {
        2.1489924599066255`, -1.5036768382837358`}}]}, 
      {Hue[0.6406413222683596], AbsoluteThickness[0.5], 
       LineBox[{{2.1489924599066255`, -1.5036768382837358`}, {
        2.0078541579710123`, -1.6455269193332813`}}]}, 
      {Hue[0.6556190736881436], AbsoluteThickness[0.5], 
       LineBox[{{5.583632229640845, -1.6612043328755821`}, {
        5.510302366364285, -1.790344842341172}}]}, 
      {Hue[0.6559788168441318], AbsoluteThickness[0.5], 
       LineBox[{{5.510302366364285, -1.790344842341172}, {
        5.367833975826103, -2.069381496374668}}]}, 
      {Hue[0.6795579534671181], AbsoluteThickness[0.5], 
       LineBox[{{8.33406317609322, -0.39330100696709697`}, {
        8.351295917311349, -0.602124705483829}}]}, 
      {Hue[0.6799618715772633], AbsoluteThickness[0.5], 
       LineBox[{{8.351295917311349, -0.602124705483829}, {
        8.361026689393826, -0.9196787574360545}}]}, 
      {Hue[0.6035688931218384], AbsoluteThickness[0.5], 
       LineBox[{{8.064620340164055, -0.6217258969179387}, {
        8.079671323263012, -0.8827774040714981}}]}, 
      {Hue[0.6038692660973314], AbsoluteThickness[0.5], 
       LineBox[{{8.079671323263012, -0.8827774040714981}, {
        8.087287557697428, -1.1667350320103715`}}]}, 
      {Hue[0.6387814382319041], AbsoluteThickness[0.5], 
       LineBox[{{4.580060468748022, 1.7765716645052394`}, {4.452460509486324, 
        1.7493796210075987`}}]}, 
      {Hue[0.6390596398106265], AbsoluteThickness[0.5], 
       LineBox[{{4.452460509486324, 1.7493796210075987`}, {
        4.1380114101994065`, 1.6746885657587527`}}]}, 
      {Hue[0.6411364040182579], AbsoluteThickness[0.5], 
       LineBox[{{4.925115912417168, -0.6455285030694189}, {
        4.91504873105992, -0.6615505077730289}}]}, 
      {Hue[0.641740180973274], AbsoluteThickness[0.5], 
       LineBox[{{4.91504873105992, -0.6615505077730289}, {
        4.766407734725325, -0.8633295950631821}}]}, 
      {Hue[0.6442589789147122], AbsoluteThickness[0.5], 
       LineBox[{{4.104016248767022, 1.2181127976235193`}, {4.106155048196667, 
        1.182633841566192}}]}, 
      {Hue[0.6446856706797695], AbsoluteThickness[0.5], 
       LineBox[{{4.106155048196667, 1.182633841566192}, {4.107628336817089, 
        0.9014910254891096}}]}, 
      {Hue[0.6563385600001199], AbsoluteThickness[0.5], 
       LineBox[{{5.367833975826103, -2.069381496374668}, {
        5.3445881201754, -2.120375757149182}}]}, 
      {Hue[0.656677473107645], AbsoluteThickness[0.5], 
       LineBox[{{5.3445881201754, -2.120375757149182}, {
        5.201538231611966, -2.403417456268768}}]}, 
      {Hue[0.6803657896874088], AbsoluteThickness[0.5], 
       LineBox[{{8.361026689393826, -0.9196787574360545}, {
        8.356869387191244, -1.1169609202129416`}}]}, 
      {Hue[0.6810207184153237], AbsoluteThickness[0.5], 
       LineBox[{{8.356869387191244, -1.1169609202129416`}, {
        8.3331496067494, -1.3553849432308156`}}]}, 
      {Hue[0.6041696390728243], AbsoluteThickness[0.5], 
       LineBox[{{8.087287557697428, -1.1667350320103715`}, {
        8.086253834454359, -1.4277177070436622`}}]}, 
      {Hue[0.6047376046294866], AbsoluteThickness[0.5], 
       LineBox[{{8.086253834454359, -1.4277177070436622`}, {
        8.067678638255492, -1.6759758944979153`}}]}, 
      {Hue[0.6393378413893491], AbsoluteThickness[0.5], 
       LineBox[{{4.1380114101994065`, 1.6746885657587527`}, {
        4.015278160778296, 1.6425045730816625`}}]}, 
      {Hue[0.6423439579282902], AbsoluteThickness[0.5], 
       LineBox[{{4.766407734725325, -0.8633295950631821}, {
        4.666800878819203, -0.979493568679668}}]}, 
      {Hue[0.6438278761503012], AbsoluteThickness[0.5], 
       LineBox[{{4.666800878819203, -0.979493568679668}, {
        4.511067994876999, -1.1225768052381664`}}]}, 
      {Hue[0.6451123624448267], AbsoluteThickness[0.5], 
       LineBox[{{4.107628336817089, 0.9014910254891096}, {4.102082783346229, 
        0.7900700009426607}}]}, 
      {Hue[0.6622337858847857], AbsoluteThickness[0.5], 
       LineBox[{{4.102082783346229, 0.7900700009426607}, {4.135022317262081, 
        0.6377346029315639}}]}, 
      {Hue[0.65701638621517], AbsoluteThickness[0.5], 
       LineBox[{{5.201538231611966, -2.403417456268768}, {
        4.967176376558998, -2.824166619843273}}]}, 
      {Hue[0.6576564160194339], AbsoluteThickness[0.5], 
       LineBox[{{4.967176376558998, -2.824166619843273}, {
        4.86055521827355, -3.055855217231052}}]}, 
      {Hue[0.6816756471432387], AbsoluteThickness[0.5], 
       LineBox[{{8.3331496067494, -1.3553849432308156`}, {
        8.285852186043018, -1.619426158655853}}]}, 
      {Hue[0.6819826375743265], AbsoluteThickness[0.5], 
       LineBox[{{8.285852186043018, -1.619426158655853}, {
        8.226488429426166, -1.8980884687599042`}}]}, 
      {Hue[0.6053055701861486], AbsoluteThickness[0.5], 
       LineBox[{{8.067678638255492, -1.6759758944979153`}, {
        8.042625620141692, -1.8470581003527977`}}]}, 
      {Hue[0.6055600949129192], AbsoluteThickness[0.5], 
       LineBox[{{8.042625620141692, -1.8470581003527977`}, {
        7.998145808755412, -2.132175178499617}}]}, 
      {Hue[0.6393378413893492], AbsoluteThickness[0.5], 
       LineBox[{{4.015278160778296, 1.6425045730816625`}, {
        3.8931081887394305`, 1.672485488419063}}]}, 
      {Hue[0.639764362552927], AbsoluteThickness[0.5], 
       LineBox[{{3.8931081887394305`, 1.672485488419063}, {3.61765689728089, 
        1.7242331967727527`}}]}, 
      {Hue[0.645311794372312], AbsoluteThickness[0.5], 
       LineBox[{{4.511067994876999, -1.1225768052381664`}, {
        4.414427840052262, -1.1921835285281666`}}]}, 
      {Hue[0.6456967348892804], AbsoluteThickness[0.5], 
       LineBox[{{4.414427840052262, -1.1921835285281666`}, {
        4.169184940768119, -1.3512735128394084`}}]}, 
      {Hue[0.6793552093247444], AbsoluteThickness[0.5], 
       LineBox[{{4.135022317262081, 0.6377346029315639}, {4.137449258031072, 
        0.6330227717293573}}]}, 
      {Hue[0.6582964458236978], AbsoluteThickness[0.5], 
       LineBox[{{4.86055521827355, -3.055855217231052}, {
        4.836421374049932, -3.121081019964857}}]}, 
      {Hue[0.6585506156200234], AbsoluteThickness[0.5], 
       LineBox[{{4.836421374049932, -3.121081019964857}, {
        4.7207559192084485`, -3.4252705494347433`}}]}, 
      {Hue[0.6822896280054144], AbsoluteThickness[0.5], 
       LineBox[{{8.226488429426166, -1.8980884687599042`}, {
        8.182846179899906, -2.074486072694874}}]}, 
      {Hue[0.6827669931352063], AbsoluteThickness[0.5], 
       LineBox[{{8.182846179899906, -2.074486072694874}, {
        8.130052498397331, -2.3626839614581483`}}]}, 
      {Hue[0.6058146196396896], AbsoluteThickness[0.5], 
       LineBox[{{7.998145808755412, -2.132175178499617}, {
        7.967896351950779, -2.3148406124055203`}}]}, 
      {Hue[0.606088993735975], AbsoluteThickness[0.5], 
       LineBox[{{7.967896351950779, -2.3148406124055203`}, {
        7.925556519810391, -2.610018102845079}}]}, 
      {Hue[0.6401908837165048], AbsoluteThickness[0.5], 
       LineBox[{{3.61765689728089, 1.7242331967727527`}, {3.438376757813521, 
        1.747809250490434}}]}, 
      {Hue[0.6404410690309634], AbsoluteThickness[0.5], 
       LineBox[{{3.438376757813521, 1.747809250490434}, {3.105394699014644, 
        1.7921030336262633`}}]}, 
      {Hue[0.6460816754062485], AbsoluteThickness[0.5], 
       LineBox[{{4.169184940768119, -1.3512735128394084`}, {
        4.087849831814967, -1.398572319606802}}]}, 
      {Hue[0.6463361934001416], AbsoluteThickness[0.5], 
       LineBox[{{4.087849831814967, -1.398572319606802}, {
        3.860955713474017, -1.5333713095807189`}}]}, 
      {Hue[0.6588047854163488], AbsoluteThickness[0.5], 
       LineBox[{{4.7207559192084485`, -3.4252705494347433`}, {
        4.637718658562586, -3.6378876508853946`}}]}, 
      {Hue[0.6598017251704669], AbsoluteThickness[0.5], 
       LineBox[{{4.637718658562586, -3.6378876508853946`}, {
        4.577708467468324, -3.8520290528606225`}}]}, 
      {Hue[0.6832443582649981], AbsoluteThickness[0.5], 
       LineBox[{{8.130052498397331, -2.3626839614581483`}, {
        8.122862923720078, -2.422401922324327}}]}, 
      {Hue[0.6878237052353654], AbsoluteThickness[0.5], 
       LineBox[{{8.122862923720078, -2.422401922324327}, {
        8.072631808778445, -2.5854597054492907`}}]}, 
      {Hue[0.6063633678322605], AbsoluteThickness[0.5], 
       LineBox[{{7.925556519810391, -2.610018102845079}, {
        7.891277125048646, -2.892352938069547}}]}, 
      {Hue[0.6071731774188085], AbsoluteThickness[0.5], 
       LineBox[{{7.891277125048646, -2.892352938069547}, {
        7.882699779157654, -3.1599710081773957`}}]}, 
      {Hue[0.6406912543454221], AbsoluteThickness[0.5], 
       LineBox[{{3.105394699014644, 1.7921030336262633`}, {2.924749898322001, 
        1.8164069260872877`}}]}, 
      {Hue[0.6410515781322539], AbsoluteThickness[0.5], 
       LineBox[{{2.924749898322001, 1.8164069260872877`}, {2.648800816380164, 
        1.8661092930023264`}}]}, 
      {Hue[0.6465907113940346], AbsoluteThickness[0.5], 
       LineBox[{{3.860955713474017, -1.5333713095807189`}, {
        3.3880458823786785`, -1.820342901631111}}]}, 
      {Hue[0.6504429213870698], AbsoluteThickness[0.5], 
       LineBox[{{3.3880458823786785`, -1.820342901631111}, {
        3.2138651025026257`, -1.8891483094595127`}}]}, 
      {Hue[0.6607986649245849], AbsoluteThickness[0.5], 
       LineBox[{{4.577708467468324, -3.8520290528606225`}, {
        4.574395809888162, -3.87086113568067}}]}, 
      {Hue[0.661060467006774], AbsoluteThickness[0.5], 
       LineBox[{{4.574395809888162, -3.87086113568067}, {
        4.518563787713083, -4.1623464859427415`}}]}, 
      {Hue[0.6924030522057325], AbsoluteThickness[0.5], 
       LineBox[{{8.072631808778445, -2.5854597054492907`}, {
        7.923895208414474, -2.8726626917406497`}}]}, 
      {Hue[0.6937421433885425], AbsoluteThickness[0.5], 
       LineBox[{{7.923895208414474, -2.8726626917406497`}, {
        7.837798000396288, -3.098587468085916}}]}, 
      {Hue[0.6079829870053565], AbsoluteThickness[0.5], 
       LineBox[{{7.882699779157654, -3.1599710081773957`}, {
        7.883463403589657, -3.1734141265585465`}}]}, 
      {Hue[0.6127597991827726], AbsoluteThickness[0.5], 
       LineBox[{{7.883463403589657, -3.1734141265585465`}, {
        7.85970637138522, -3.3629301793685547`}}]}, 
      {Hue[0.6414119019190857], AbsoluteThickness[0.5], 
       LineBox[{{2.648800816380164, 1.8661092930023264`}, {2.5829871198267, 
        1.881011177219142}}]}, 
      {Hue[0.641816915148118], AbsoluteThickness[0.5], 
       LineBox[{{2.5829871198267, 1.881011177219142}, {2.349359471890209, 
        1.9213082575088039`}}]}, 
      {Hue[0.6542951313801051], AbsoluteThickness[0.5], 
       LineBox[{{3.2138651025026257`, -1.8891483094595127`}, {
        3.1434135696576995`, -1.9039434953706034`}}]}, 
      {Hue[0.6548712623347336], AbsoluteThickness[0.5], 
       LineBox[{{3.1434135696576995`, -1.9039434953706034`}, {
        2.903457190188319, -1.9725459966563026`}}]}, 
      {Hue[0.6613222690889631], AbsoluteThickness[0.5], 
       LineBox[{{4.518563787713083, -4.1623464859427415`}, {
        4.479004209146214, -4.353204595251902}}]}, 
      {Hue[0.6615798226104781], AbsoluteThickness[0.5], 
       LineBox[{{4.479004209146214, -4.353204595251902}, {
        4.410535650814702, -4.704907631988199}}]}, 
      {Hue[0.6950812345713525], AbsoluteThickness[0.5], 
       LineBox[{{7.837798000396288, -3.098587468085916}, {
        7.833909808862865, -3.1137929226790666`}}]}, 
      {Hue[0.6954169836160154], AbsoluteThickness[0.5], 
       LineBox[{{7.833909808862865, -3.1137929226790666`}, {
        7.742079894080053, -3.4216078816673376`}}]}, 
      {Hue[0.6175366113601886], AbsoluteThickness[0.5], 
       LineBox[{{7.85970637138522, -3.3629301793685547`}, {
        7.795978580442563, -3.5645411450834024`}}]}, 
      {Hue[0.6177897980988674], AbsoluteThickness[0.5], 
       LineBox[{{7.795978580442563, -3.5645411450834024`}, {
        7.702535094878998, -3.852303928331755}}]}, 
      {Hue[0.6422219283771502], AbsoluteThickness[0.5], 
       LineBox[{{2.349359471890209, 1.9213082575088039`}, {2.124896580766944, 
        1.9481317031726484`}}]}, 
      {Hue[0.6428237999630276], AbsoluteThickness[0.5], 
       LineBox[{{2.124896580766944, 1.9481317031726484`}, {
        1.9035442849739976`, 1.958141519989878}}]}, 
      {Hue[0.6554473932893621], AbsoluteThickness[0.5], 
       LineBox[{{2.903457190188319, -1.9725459966563026`}, {
        2.676619243148466, -2.055332280116653}}]}, 
      {Hue[0.6911027086400537], AbsoluteThickness[0.5], 
       LineBox[{{2.676619243148466, -2.055332280116653}, {
        2.56369670200151, -2.1439066797609883`}}]}, 
      {Hue[0.6957527326606784], AbsoluteThickness[0.5], 
       LineBox[{{7.742079894080053, -3.4216078816673376`}, {
        7.694883940382591, -3.5596217794224203`}}]}, 
      {Hue[0.6962739238124742], AbsoluteThickness[0.5], 
       LineBox[{{7.694883940382591, -3.5596217794224203`}, {
        7.62775365407357, -3.808618558319004}}]}, 
      {Hue[0.6180429848375462], AbsoluteThickness[0.5], 
       LineBox[{{7.702535094878998, -3.852303928331755}, {
        7.53680586351982, -4.349393496743518}}]}, 
      {Hue[0.6183163460531721], AbsoluteThickness[0.5], 
       LineBox[{{7.53680586351982, -4.349393496743518}, {
        7.451196867245875, -4.625545955635383}}]}, 
      {Hue[0.6967951149642702], AbsoluteThickness[0.5], 
       LineBox[{{7.62775365407357, -3.808618558319004}, {
        7.601671647018604, -3.939171826620226}}]}, 
      {Hue[0.5061456996924688], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.9131901082507714`, -0.31863123109850405`}, {
        0.7499999999999998, -0.013318415347151003`}}]}, 
      {Hue[0.6001562962690652], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.8838360125468592`, -0.5579698938587627}, {
        0.75, -1.2049576704550358`}}]}, 
      {Hue[0.5769952062284084], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.8103828445111985`, -0.14526970950124324`}, {
        0.75, -0.10465071221406586`}}]}, 
      {Hue[0.52466599532505], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.9225372764660171`, 0.4515086228717923}, {
        0.7499999999999998, 0.8602916066455141}}]}, 
      {Hue[0.6085367055183577], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.9339456040502492`, -2.0930931048322563`}, {
        0.9576092197918946, -5.4}}]}, 
      {Hue[0.5099868072763579], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.8520985852590892`, 1.6455325677180772`}, {0.75, 
        3.140691626579084}}]}, 
      {Hue[0.5773249898436007], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.8252061047451482`, 1.0297001744715277`}, {0.75, 
        1.2822883295918825`}}]}, 
      {Hue[0.5963007540834737], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{2.0872857489267846`, 1.1761752005146207`}, {
        0.7499999999999998, 1.452781749353817}}]}, 
      {Hue[0.5842384416902046], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.9001977368547118`, -3.619455579289954}, {
        1.2374592873019123`, -5.4}}]}, 
      {Hue[0.6666271948379716], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.8406124114493334`, -1.5365010136935358`}, {
        0.75, -2.3219628407059947`}}]}, 
      {Hue[0.624342678250249], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{2.105205953681314, 1.3089504386517101`}, {0.75, 
        0.9549584090747788}}]}, 
      {Hue[0.4539180641747445], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{4.162901024900379, 3.8533742675267373`}, {
        3.7123091228027443`, 4.6}}]}, 
      {Hue[0.3965179842389182], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{4.25824591918048, 3.8671623687594585`}, {4.053171554570863, 
        4.6}}]}, 
      {Hue[0.514902664395993], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{6.144109016922892, -4.607673172359417}, {
        6.765913958873266, -5.4}}]}, 
      {Hue[0.5290011335543037], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.8548429588315567`, 3.494519077401773}, {
        1.3134567302292623`, 4.6}}]}, 
      {Hue[0.02507219852628063], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{7.003124398212361, 3.6079906150947636`}, {7.57043727582348, 
        4.6}}]}, 
      {Hue[0.6850264514447268], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{5.9475610692372065`, 3.8155062614584927`}, {
        7.905939695928558, 4.6}}]}, 
      {Hue[0.5991037663600199], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{4.9097173396343186`, 3.797752322592934}, {4.629761157830248,
         4.6}}]}, 
      {Hue[0.5049865680025785], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{4.79674534374431, 3.873256607225478}, {2.4017884969007777`, 
        4.6}}]}, 
      {Hue[0.5400335634352403], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{4.653438827889254, 3.8064166920639053`}, {2.791456648837001,
         4.6}}]}, 
      {Hue[0.6778030619317583], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{2.1099160340483705`, 3.2372328195376054`}, {0.75, 
        3.5851482305493323`}}]}, 
      {Hue[0.6481404466628284], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.458096143696963, 1.3520861181112278`}, {9.75, 
        1.6533628856516764`}}]}, 
      {Hue[0.4370168104031539], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.244579678764612, 0.6130227237162458}, {9.75, 
        0.10229674081832119`}}]}, 
      {Hue[0.570403710094044], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{3.648984401631715, 3.72272832346326}, {2.7005395339972926`, 
        4.6}}]}, 
      {Hue[0.6256440380721281], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.996570713589239, -1.6463004345920698`}, {
        0.7500000000000002, -3.559042299326211}}]}, 
      {Hue[0.6081495082284316], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.138785934526915, -1.9261273963452374`}, {
        9.75, -1.6036832837456552`}}]}, 
      {Hue[0.6163816559385006], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{3.11281219185615, -4.637544924284592}, {
        3.3490432656016456`, -5.4}}]}, 
      {Hue[0.632023954926875], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.359910116098247, 1.8153948276233836`}, {9.75, 
        1.663584318015467}}]}, 
      {Hue[0.6511450479392628], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.7955415459025563`, 2.4139544990959685`}, {0.75, 
        2.723455493009071}}]}, 
      {Hue[0.5556209211596663], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{6.7513162166877425`, -4.419548980886083}, {
        6.992261646429693, -5.4}}]}, 
      {Hue[0.41948114477123577`], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.302462564269772, -2.9740948258154787`}, {
        9.75, -4.291429127352204}}]}, 
      {Hue[0.4689811404807807], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.324111057466014, -1.3602501898509973`}, {
        9.75, -2.4276563331792884`}}]}, 
      {Hue[0.5912436077474607], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{8.444951468766515, -3.3397938845316837`}, {
        9.75, -3.2816430809641446`}}]}, 
      {Hue[0.6429195397907232], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{2.0078541579710123`, -1.6455269193332813`}, {
        0.75, -2.5959902231124645`}}]}, 
      {Hue[0.6618373761319932], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{4.410535650814702, -4.704907631988199}, {
        4.28393054336464, -5.4}}]}, 
      {Hue[0.6434256715489051], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{1.9035442849739976`, 1.958141519989878}, {0.75, 
        1.925192255430526}}]}, 
      {Hue[0.6185897072687981], AbsoluteThickness[0.5], Arrowheads[Small], 
       ArrowBox[{{7.451196867245875, -4.625545955635383}, {
        7.228991348138198, -5.4}}], 
       {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxld3k0le/X/nEMZzCdY57PyVCiKBEa3Ls0USJUCkmRQhIpGRKJSJmiTA3K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         "]]}}}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563404818081695*^9, 3.566101392217369*^9, 
  3.614727862355088*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[278]:="],

Cell[BoxData["2.80615300000000011948486644541844725609`6.468711259674121"], \
"Output",
 CellChangeTimes->{3.563404819925156*^9, 3.566101406679796*^9, 
  3.614727862380336*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"Out[278]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[AnalyzeSystem[
\t{Move[SingleRay[IntrinsicMedium->1.34],-2],
\trodlens,
\tMove[ClearBoundary[9,10],{.75,-.4}]},
\tPlotType->TopView, ThresholdIntensity->.008, ShowLabels->False,
\tCreateClones -> randomclonedata, ShowClones->False, \
ColorView->Log[Intensity],
\tRunningCommentary->TurboTrace]][[1]]\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[279]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278627196608`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278627219477`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862723447*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862724708*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "OpticalSystem"}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.008`"}], ",", 
       RowBox[{"ShowLabels", "\[Rule]", "False"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "False"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "False"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "OpticalSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"OutputType", "\[Rule]", "OpticalSystem"}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.008`"}], ",", 
       RowBox[{"ShowLabels", "\[Rule]", "False"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "False"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`OutputType -> Optica`Optica`OpticalSystem, 
     Optica`Optica`ReportedParameters -> All, Optica`Optica`PlotType -> 
     Optica`Optica`TopView, Optica`Optica`ThresholdIntensity -> 0.008, 
     Optica`Optica`ShowLabels -> False, 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`ShowClones -> False, 
     Optica`Optica`ColorView -> Log[Optica`Optica`Intensity], 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, Messages -> 
     Automatic, Optica`Optica`MinimumRayLength -> 0.0001, 
     Optica`Optica`RayHistory -> False, Optica`Optica`WaveFrontID -> False, 
     Optica`Optica`ModularSystem -> False, MemoryConstrained -> False, 
     Optica`Optica`ReportedSurfaces -> All, Optica`Optica`RayLimit -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, 
     Optica`Optica`FilterTrace -> False, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`SequentialTrace -> Automatic, 
     Optica`Optica`InterceptHole -> Automatic, 
     Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`OpticalSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`OutputType -> 
     Optica`Optica`OpticalSystem, Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`PlotType -> Optica`Optica`TopView, 
     Optica`Optica`ThresholdIntensity -> 0.008, Optica`Optica`ShowLabels -> 
     False, Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`ShowClones -> False, 
     Optica`Optica`ColorView -> Log[Optica`Optica`Intensity], 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     RuntimeAttributes -> {Listable}, Parallelization -> False, 
     CompilationTarget -> "MVM", RuntimeOptions -> "Speed", 
     Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedSurfaces -> Automatic, 
     Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`CustomParameters -> {}, 
     Optica`Optica`IntrinsicMedium -> Automatic, Optica`Optica`SpatialScale -> 
     1, Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862766871*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862829447*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862831376*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.01057800000000000059663385343355912482`4.04500347596259", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.01057800000000000059663385343355912482`4.04500347596259, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278628331957`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862835146*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278628367033`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.61472786283829*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862840664*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862842328*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278628438063`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727862845283*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.61472786284665*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727863399473*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727863402536*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727863405037*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.61472786340731*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"SingleRay", "[", 
              RowBox[{"IntrinsicMedium", "\[Rule]", "1.34`"}], "]"}], ",", 
             RowBox[{"-", "2.`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}], 
       "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`SingleRay[{
           Optica`Optica`Ray[]}, 1, Optica`Optica`IntrinsicMedium -> 1.34, 
          Optica`Optica`SourceTransformation -> {{-2., 0, 0}, {{1., 0, 0}, {
             0, 1., 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{-2, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-2., 0, 0}, {{1., 0, 0}, {
          0, 1., 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-2, 0, 0}, {{1, 0, 
         0}, {0, 1, 0}, {0, 0, 1}}}, Optica`Optica`SourceLevel :> {1, 1}, 
       Optica`Optica`NumberOfRays :> 1, Optica`Optica`BirthPoint :> {0, 0, 0},
        Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 79735, Optica`Optica`SourceFraction :> 
       1, Optica`Optica`SourceOffset :> 0, Optica`Optica`GridSpacing :> (#& ),
        Optica`Optica`PowerOutput :> Optica`Optica`PowerOutput, 
       Optica`Optica`SymbolicValues -> {}, Optica`Optica`IntrinsicMedium :> 
       1.34], False, False, False, 
      False, {{-2., 0, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727863409679*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864202182*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864204731*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864207308*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864507443*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "OpticalSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`OpticalSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864509405*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864511104*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.61472786451268*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727864514317*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "9"}],
  SequenceForm["maximum used clone sort position = ", 9],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727867426387*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "826", ",", "366", ",", "148", ",", "50", ",", "16", ",", "9", ",", "2", 
     ",", "1", ",", "2", ",", "0"}], "}"}]}],
  SequenceForm[
  "Histogram of used sort positions: ", {826, 366, 148, 50, 16, 9, 2, 1, 2, 
   0}],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278674295073`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({826, 366, 148, 50, 16, 9, \
2, 1, 2, 0}\\)\\), \\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \
\[Rule] All\\)\\)\\)\\)]\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/optx\\\", \
ButtonNote -> \\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727867471959*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "3.05458000000000007290168468898627907038`6.505551417147252", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "3104",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   3.05458000000000007290168468898627907038`6.505551417147252, 
   " seconds with ", 3104, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278675380697`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"No changes to numeric parameters have been made for \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Hold", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{"RaySlot", "\[RuleDelayed]", "1"}], "]"}], ",", 
            RowBox[{"-", "1.9999999999999996`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "99.74789199320458`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            "1.7667114977152143`", ",", 
            RowBox[{"-", "0.607633832936629`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2514724223244908`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.150842225822762`", ",", 
              RowBox[{"-", "0.004073940169013586`"}]}], "}"}], ",", 
            RowBox[{"-", "169.02190060923866`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "99.49641957088005`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.150842225822762`", ",", 
              RowBox[{"-", "0.004073940169013586`"}]}], "}"}], ",", 
            RowBox[{"-", "1.215267665872658`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "99.25118366957307`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.313846576425795`", ",", 
              RowBox[{"-", "0.007531849809321051`"}]}], "}"}], ",", 
            RowBox[{"-", "1.2417262087554972`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24463145094031025`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6587982155668994`", ",", 
              RowBox[{"-", "0.015008885084780993`"}]}], "}"}], ",", 
            "179.26476206466464`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24523590130695874`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.313846576425795`", ",", 
              RowBox[{"-", "0.007531849809321053`"}]}], "}"}], ",", 
            "178.22532697493847`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24461271838368367`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1506905823677744`", ",", 
              RowBox[{"-", "0.0024766576922289896`"}]}], "}"}], ",", 
            "178.93216410177473`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "99.00655221863269`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6587982155668994`", ",", 
              RowBox[{"-", "0.015008885084780998`"}]}], "}"}], ",", 
            RowBox[{"-", "1.2681847516383364`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "98.75435028932107`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.88220483912467`", ",", 
              RowBox[{"-", "0.01995457484591291`"}]}], "}"}], ",", 
            RowBox[{"-", "2.0027464545939337`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2515594888698206`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.203448398313732`", ",", 
              RowBox[{"-", "0.03118806463673083`"}]}], "}"}], ",", 
            RowBox[{"-", "168.02235282588882`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24402849040546773`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3137939589293546`", ",", 
              RowBox[{"-", "0.010581436087871`"}]}], "}"}], ",", 
            "179.2383035217818`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24341980978631647`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1511871633859885`", ",", 
              RowBox[{"-", "0.008419595868123391`"}]}], "}"}], ",", 
            "179.67930458531467`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25220192931161994`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.88220483912467`", ",", 
              RowBox[{"-", "0.019954574845912905`"}]}], "}"}], ",", 
            "163.28229821374552`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2507567532837804`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6470204120697653`", ",", "0.05068334347140578`"}], 
             "}"}], ",", "167.40944608071263`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "98.50279080045121`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.203448398313732`", ",", 
              RowBox[{"-", "0.03118806463673083`"}]}], "}"}], ",", 
            RowBox[{"-", "2.73730815755102`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "98.25016212424417`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.289988407633029`", ",", 
              RowBox[{"-", "0.03532566548370465`"}]}], "}"}], ",", 
            RowBox[{"-", "1.929976871267179`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2519807631121969`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6101936044655933`", ",", 
              RowBox[{"-", "0.046115682956667625`"}]}], "}"}], ",", 
            "162.72299863031571`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25091868493303154`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8890066728387804`", ",", 
              RowBox[{"-", "0.09789651158066667`"}]}], "}"}], ",", 
            RowBox[{"-", "168.7569145288464`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24723671810648565`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8351104353765613`", ",", 
              RowBox[{"-", "0.10861037831299702`"}]}], "}"}], ",", 
            RowBox[{"-", "161.91763282222166`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2526286762070828`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.289988407633029`", ",", 
              RowBox[{"-", "0.03532566548370465`"}]}], "}"}], ",", 
            RowBox[{"-", "165.7756210865662`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2518754848342481`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2036196140900715`", ",", 
              RowBox[{"-", "0.057219436555797455`"}]}], "}"}], ",", 
            RowBox[{"-", "167.57554260639716`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "97.99818136113194`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6101936044655933`", ",", 
              RowBox[{"-", "0.046115682956667625`"}]}], "}"}], ",", 
            RowBox[{"-", "1.1226455849842414`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "97.60177509251764`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.884424114220212`", ",", 
              RowBox[{"-", "0.05148960539899354`"}]}], "}"}], ",", 
            "1.8976295039709503`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.39480279059446854`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.174745282155764`", ",", 
              RowBox[{"-", "0.04187068499412144`"}]}], "}"}], ",", 
            "128.9790045759383`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2513345117106132`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.304262492718633`", ",", "0.049036549917380684`"}], 
             "}"}], ",", "163.5303299165991`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2506962929360381`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8975987417994986`", ",", "0.16926171893825742`"}], 
             "}"}], ",", "162.831967912781`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24360878025636062`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.631370047670223`", ",", 
              RowBox[{"-", "0.17513360904866818`"}]}], "}"}], ",", 
            RowBox[{"-", "155.078351115597`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.242833156181243`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4272549118351114`", ",", 
              RowBox[{"-", "0.2699744584069052`"}]}], "}"}], ",", 
            RowBox[{"-", "157.1835172333889`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25112453903880644`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9006298519039526`", ",", 
              RowBox[{"-", "0.1239716558766005`"}]}], "}"}], ",", 
            RowBox[{"-", "169.3754641262283`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24956482069046557`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.868778330669892`", ",", 
              RowBox[{"-", "0.12994662473065313`"}]}], "}"}], ",", 
            RowBox[{"-", "165.0087239958643`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.39640626861431016`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.884424114220212`", ",", 
              RowBox[{"-", "0.051489605398993554`"}]}], "}"}], ",", 
            RowBox[{"-", "122.1634704790412`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3952797393161795`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8360941866799445`", ",", 
              RowBox[{"-", "0.12834485163359455`"}]}], "}"}], ",", 
            RowBox[{"-", "123.71085787350205`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "97.20697230192317`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.174745282155764`", ",", 
              RowBox[{"-", "0.04187068499412144`"}]}], "}"}], ",", 
            "4.917904592926143`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "96.92895544545073`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.400554302185327`", ",", 
              RowBox[{"-", "0.022440938596222378`"}]}], "}"}], ",", 
            "6.500867277806664`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2772217142037861`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6946057131986`", ",", "0.011066496590403974`"}], 
             "}"}], ",", "156.98322601508963`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3932057987025339`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9920227327644295`", ",", "0.18394201200307905`"}], 
             "}"}], ",", "131.99927966489335`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.37864452946942234`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9208762860103477`", ",", "0.26296014394196404`"}], 
             "}"}], ",", "141.6708223127207`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014022033641014977`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.774007014814893`", ",", "0.3790719956019406`"}], 
             "}"}], ",", 
            RowBox[{"-", "147.84734321007406`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2500596948032183`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.560781759415158`", ",", "0.27331809425780756`"}], 
             "}"}], ",", "162.13360590896346`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24309711641608542`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.289831266060674`", ",", "0.36065725145027167`"}], 
             "}"}], ",", "170.89452742746315`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.242060001609504`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1508630265649438`", ",", 
              RowBox[{"-", "0.38625248209328467`"}]}], "}"}], ",", 
            RowBox[{"-", "159.2886833511811`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24146099159531187`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1468470929130756`", ",", 
              RowBox[{"-", "0.38777088348810573`"}]}], "}"}], ",", 
            RowBox[{"-", "159.03265085589672`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24801478965239496`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.621793917817546`", ",", 
              RowBox[{"-", "0.19608559386754337`"}]}], "}"}], ",", 
            RowBox[{"-", "160.64198386550044`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24733481050217856`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4268272613564683`", ",", 
              RowBox[{"-", "0.26458365317247373`"}]}], "}"}], ",", 
            RowBox[{"-", "161.97422181508202`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.39415641145142666`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6527301356231905`", ",", 
              RowBox[{"-", "0.40317480552400664`"}]}], "}"}], ",", 
            RowBox[{"-", "125.25824526796242`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.39312627612022405`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6440775948960247`", ",", 
              RowBox[{"-", "0.4154141300939811`"}]}], "}"}], ",", 
            RowBox[{"-", "126.24079112951352`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27801685647241575`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.400554302185327`", ",", 
              RowBox[{"-", "0.02244093859622237`"}]}], "}"}], ",", 
            RowBox[{"-", "142.39852877459577`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.276861944470144`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.332719604913328`", ",", 
              RowBox[{"-", "0.07468346298845327`"}]}], "}"}], ",", 
            RowBox[{"-", "139.28742479020295`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "96.65173373124696`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6946057131986`", ",", "0.011066496590403974`"}], 
             "}"}], ",", "8.083829962687416`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "96.40120163838044`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8241048464905125`", ",", "0.02945966646765053`"}], 
             "}"}], ",", "7.1737310651719275`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24988268568952332`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.136587594956282`", ",", "0.06878987295939468`"}], 
             "}"}], ",", 
            RowBox[{"-", "155.55802920113624`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27642884608225426`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.422212158743575`", ",", "0.12678482713072758`"}], 
             "}"}], ",", "158.56618869997016`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2752680041887159`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.399096479845423`", ",", "0.13585950227795887`"}], 
             "}"}], ",", "155.41845935963823`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014561269233111584`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9208762860103477`", ",", "0.26296014394196404`"}], 
             "}"}], ",", "80.86053048334276`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014523045470901708`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9412780345169445`", ",", "0.3897730672871572`"}], 
             "}"}], ",", "79.84127104818344`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3646224958284075`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.774007014814893`", ",", "0.3790719956019406`"}], 
             "}"}], ",", "151.34236496054803`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.36357353990223545`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.618102085979958`", ",", "0.46427768108364853`"}], 
             "}"}], ",", "152.95733839070454`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013502767120235534`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.615497598354153`", ",", "0.27943610944304614`"}], 
             "}"}], ",", 
            RowBox[{"-", "138.1758005622468`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01339630247316773`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4620287086386394`", ",", "0.14210240451730616`"}], 
             "}"}], ",", 
            RowBox[{"-", "133.11596986466407`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2363284017295186`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1456962410064944`", ",", "0.3837580623745752`"}], 
             "}"}], ",", "179.65544894596277`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23500628659526143`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.137773631112005`", ",", "0.3838057059622634`"}], 
             "}"}], ",", "175.60045386734876`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24665669564257717`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.131967869541339`", ",", 
              RowBox[{"-", "0.36053596551370937`"}]}], "}"}], ",", 
            RowBox[{"-", "163.30645976466417`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24592891512772325`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1317647742058625`", ",", 
              RowBox[{"-", "0.3605968720764497`"}]}], "}"}], ",", 
            RowBox[{"-", "161.55869657428724`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.39209883306744114`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4519109865691275`", ",", 
              RowBox[{"-", "0.6775846688198423`"}]}], "}"}], ",", 
            RowBox[{"-", "127.22333699106424`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.38748365083341024`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3743027929427307`", ",", 
              RowBox[{"-", "0.7797432585536458`"}]}], "}"}], ",", 
            RowBox[{"-", "133.4277386313638`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2757118300968718`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.092110418388803`", ",", 
              RowBox[{"-", "0.2817319083055005`"}]}], "}"}], ",", 
            RowBox[{"-", "136.1763208058099`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27461136868058705`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.023924522203216`", ",", 
              RowBox[{"-", "0.3471739477614017`"}]}], "}"}], ",", 
            RowBox[{"-", "133.2022377107233`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2505320928665387`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8241048464905125`", ",", "0.02945966646765053`"}], 
             "}"}], ",", "168.99539243396458`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24977465691115894`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.69466225720908`", ",", "0.05463155987304365`"}], 
             "}"}], ",", "170.8634348756775`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "96.15131895269093`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.136587594956282`", ",", "0.06878987295939468`"}], 
             "}"}], ",", "6.263632167656039`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "95.67368665723663`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.438567307187545`", ",", "0.1019347427665358`"}], 
             "}"}], ",", "2.5729950956717045`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.47525965395389297`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.639921896520204`", ",", "0.11098310414783293`"}], 
             "}"}], ",", 
            RowBox[{"-", "115.15347791773203`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24923496184846966`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.849864850132244`", ",", 
              RowBox[{"-", "0.06152666793996342`"}]}], "}"}], ",", 
            RowBox[{"-", "156.46812809865094`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24746780161251128`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.788657960453038`", ",", 
              RowBox[{"-", "0.08818067542507849`"}]}], "}"}], ",", 
            RowBox[{"-", "151.71443020697316`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2741120371623301`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1360406816166115`", ",", "0.2561933497483976`"}], 
             "}"}], ",", "152.27073001930643`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27238082007958386`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6179271192659637`", ",", "0.5285467804054872`"}], 
             "}"}], ",", "156.6867818016237`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014484922047197642`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9987729664076967`", ",", "0.7106424299902512`"}], 
             "}"}], ",", "78.82201161302413`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014446851157553332`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.032900255712351`", ",", "0.8833460304798999`"}], 
             "}"}], ",", "79.85148546262442`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3625276016410393`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3555961043193907`", ",", "0.5982774551320276`"}], 
             "}"}], ",", "154.57231182086173`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3609400849938371`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3506237843433677`", ",", "0.6006414315659845`"}], 
             "}"}], ",", "151.28524819024466`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013290677263007516`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.290651511409753`", ",", 
              RowBox[{"-", "0.04093297677543392`"}]}], "}"}], ",", 
            RowBox[{"-", "128.0561391670814`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013103198876517008`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.221579882986132`", ",", 
              RowBox[{"-", "0.12916230350309768`"}]}], "}"}], ",", 
            RowBox[{"-", "121.33118128631894`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3829227914008192`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2171263394543335`", ",", 
              RowBox[{"-", "0.945791594974529`"}]}], "}"}], ",", 
            RowBox[{"-", "139.63214027166347`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3752210699497621`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.109609326425071`", ",", 
              RowBox[{"-", "1.037191798066271`"}]}], "}"}], ",", 
            RowBox[{"-", "147.39938220624856`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2735152995869976`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8359760786024566`", ",", 
              RowBox[{"-", "0.547303048019383`"}]}], "}"}], ",", 
            RowBox[{"-", "130.22815461563647`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2722801779361296`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8081445731435055`", ",", 
              RowBox[{"-", "0.5802043795349205`"}]}], "}"}], ",", 
            RowBox[{"-", "126.84067409247707`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24901951091879346`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.40607822076775`", ",", "0.10104414681572732`"}], 
             "}"}], ",", "172.73147731739024`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23874988737056477`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.34698126031897`", ",", "0.10858164471908821`"}], 
             "}"}], ",", "162.70520433808244`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009846101843310104`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.170700334701458`", ",", "0.1634694739701575`"}], 
             "}"}], ",", "93.6631263170981`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.47763229545424635`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.438567307187545`", ",", "0.1019347427665358`"}], 
             "}"}], ",", "116.60883103709111`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4659181433095814`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.369947045855445`", ",", "0.2389135007740329`"}], 
             "}"}], ",", "124.9769160742884`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01142685716529616`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.256652686999513`", ",", "0.4008534369572916`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.33107958450853`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "95.19842700328273`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.639921896520204`", ",", "0.11098310414783293`"}], 
             "}"}], ",", 
            RowBox[{"-", "1.117641976312827`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "89.56221790895778`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.656117764920519`", ",", "0.11066713884056857`"}], 
             "}"}], ",", "10.150828986860738`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.302518150525389`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.780139413390965`", ",", "0.1328722918237478`"}], 
             "}"}], ",", "74.844806786469`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3139348197610793`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.813078531240988`", ",", "0.25448418525360783`"}], 
             "}"}], ",", "139.53878458607724`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018586465573654988`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.717216724786908`", ",", "0.33624574206176727`"}], 
             "}"}], ",", 
            RowBox[{"-", "155.76723761431447`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.47289879856545575`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.554250872733547`", ",", 
              RowBox[{"-", "0.07146146050772645`"}]}], "}"}], ",", 
            RowBox[{"-", "118.84411498971656`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29646093220014913`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.446013302160968`", ",", 
              RowBox[{"-", "0.26798629236588783`"}]}], "}"}], ",", 
            RowBox[{"-", "138.0847197244957`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11060915040751881`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3289129465642615`", ",", 
              RowBox[{"-", "0.373110817031439`"}]}], "}"}], ",", 
            "170.02511806440685`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04126811604846847`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.173926973483606`", ",", 
              RowBox[{"-", "0.3458526601738012`"}]}], "}"}], ",", 
            "118.13495585330932`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015397075159833136`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.099721637990405`", ",", 
              RowBox[{"-", "0.2070822485170844`"}]}], "}"}], ",", 
            "66.24479364221179`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24571317114074157`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.563160363805937`", ",", 
              RowBox[{"-", "0.2095253732610226`"}]}], "}"}], ",", 
            RowBox[{"-", "146.9607323152954`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24290961227306532`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.435873312302021`", ",", 
              RowBox[{"-", "0.29231063265284085`"}]}], "}"}], ",", 
            RowBox[{"-", "153.07612787808435`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27066053689313274`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3901148833251633`", ",", "0.6267205401047594`"}], 
             "}"}], ",", "161.10283358394096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26979268882356827`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3831584032670334`", ",", "0.629101891221183`"}], 
             "}"}], ",", "158.96697054004673`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014408880330072529`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.087894069184557`", ",", "1.190572550681726`"}], "}"}],
             ",", "80.88095931222436`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013097169104803217`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.096974615643519`", ",", "1.2471439068332988`"}], 
             "}"}], ",", "68.01907193036958`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.35935952011828964`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1189077061664916`", ",", "0.7275798313596082`"}], 
             "}"}], ",", "147.9981845596276`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29663190931406896`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.962953264961906`", ",", "0.8250378530382365`"}], 
             "}"}], ",", "132.43938067102897`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.051778260816468594`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8527497331871134`", ",", "0.9455596562108208`"}], 
             "}"}], ",", "76.93912426559548`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009038098090585665`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.88965565168125`", ",", "1.1046454086706592`"}], "}"}],
             ",", "21.438867860162002`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012918365061458454`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1079744812692307`", ",", 
              RowBox[{"-", "0.31578149969126973`"}]}], "}"}], ",", 
            RowBox[{"-", "114.60622340555649`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012883102638388119`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0979082551464243`", ",", 
              RowBox[{"-", "0.3377617363851812`"}]}], "}"}], ",", 
            RowBox[{"-", "115.909892656742`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3676742531286771`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9525382644923193`", ",", 
              RowBox[{"-", "1.1376453192431852`"}]}], "}"}], ",", 
            RowBox[{"-", "155.16662414083362`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.36673044716996733`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9202939341265974`", ",", 
              RowBox[{"-", "1.15256709084685`"}]}], "}"}], ",", 
            RowBox[{"-", "154.35024686425535`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27105063376299215`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6479267674466245`", ",", 
              RowBox[{"-", "0.7940552712029678`"}]}], "}"}], ",", 
            RowBox[{"-", "123.45319356931758`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2703818851158309`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.63352257300137`", ",", 
              RowBox[{"-", "0.8158563100177105`"}]}], "}"}], ",", 
            RowBox[{"-", "123.3228623472928`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010269623548228695`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.34698126031897`", ",", "0.10858164471908821`"}], 
             "}"}], ",", 
            RowBox[{"-", "138.27899062024093`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009694321865884491`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.172131662576525`", ",", 
              RowBox[{"-", "0.04731871164326101`"}]}], "}"}], ",", 
            RowBox[{"-", "149.35212883120582`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2289037855272547`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.170700334701458`", ",", "0.1634694739701575`"}], 
             "}"}], ",", "152.67893135877455`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22394480345779205`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9039351419317736`", ",", "0.3012815070009306`"}], 
             "}"}], ",", "160.66945350391038`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009440046273707401`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.158904414755697`", ",", "0.34772064712543155`"}], 
             "}"}], ",", "83.63685333779014`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009410693493085256`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.186709549300818`", ",", "0.5970566748280117`"}], 
             "}"}], ",", "81.63744350236784`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01171415214466485`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.369947045855445`", ",", "0.2389135007740329`"}], 
             "}"}], ",", "56.65299677028256`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011681430313760297`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.4363474180854485`", ",", "0.33981791682190754`"}], 
             "}"}], ",", "58.1006967434753`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.45449128614428513`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.256652686999513`", ",", "0.4008534369572916`"}], 
             "}"}], ",", "133.34500111148574`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.45276369280189577`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.169280136629371`", ",", "0.4934251559499546`"}], 
             "}"}], ",", "136.1466207244527`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01114660822768542`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.072982639363519`", ",", "0.3278776308226116`"}], 
             "}"}], ",", 
            RowBox[{"-", "149.9629945473111`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0105900679858363`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8388393340441525`", ",", "0.1924932213145497`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.63594447027515`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.636209094324948`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.656117764920519`", ",", "0.11066713884056856`"}], 
             "}"}], ",", 
            RowBox[{"-", "43.27467784957392`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.60526256904622`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.050783306785948`", ",", 
              RowBox[{"-", "0.26091767258249676`"}]}], "}"}], ",", 
            RowBox[{"-", "39.27626490589177`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03077660833441297`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.266462557308947`", ",", 
              RowBox[{"-", "0.4372999424005015`"}]}], "}"}], ",", 
            "74.49814414737492`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "84.25969975843235`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.780139413390965`", ",", "0.1328722918237478`"}], 
             "}"}], ",", "21.4192999500343`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "84.04839455874071`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.078954373256245`", ",", "0.2500927233677525`"}], 
             "}"}], ",", "20.887716596406044`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21077529171018483`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.385877384362597`", ",", "0.3672198357910872`"}], 
             "}"}], ",", 
            RowBox[{"-", "148.96718464193205`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.988583330764308`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.813078531240988`", ",", "0.25448418525360783`"}], 
             "}"}], ",", "86.11327774964256`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.9103689088356735`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.826683256183537`", ",", "0.45472933508594915`"}], 
             "}"}], ",", "79.08137506106505`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07698812271861409`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.865410312505054`", ",", "0.6554846140465254`"}], 
             "}"}], ",", 
            RowBox[{"-", "5.827173037930592`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2953483541874244`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.717216724786908`", ",", "0.33624574206176727`"}], 
             "}"}], ",", "150.80725554925078`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29454855432140103`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.623040498948695`", ",", "0.3888634059114886`"}], 
             "}"}], ",", "149.5567004019632`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017486056569061072`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.602324795163315`", ",", "0.28453227557864835`"}], 
             "}"}], ",", 
            RowBox[{"-", "144.49876665114095`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01646435116614683`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.11645815730649`", ",", 
              RowBox[{"-", "0.0620488094172342`"}]}], "}"}], ",", 
            RowBox[{"-", "155.7205016576415`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17643786636530676`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.446013302160968`", ",", 
              RowBox[{"-", "0.26798629236588783`"}]}], "}"}], ",", 
            RowBox[{"-", "105.43516224817738`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17463190914910087`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.408512329344934`", ",", 
              RowBox[{"-", "0.4038070907651124`"}]}], "}"}], ",", 
            RowBox[{"-", "99.62983024723385`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18585178179263037`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3289129465642615`", ",", 
              RowBox[{"-", "0.373110817031439`"}]}], "}"}], ",", 
            RowBox[{"-", "157.32532445927447`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18539225864127637`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.142156563325427`", ",", 
              RowBox[{"-", "0.4511357329145888`"}]}], "}"}], ",", 
            RowBox[{"-", "157.0979639125431`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0693410343590504`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.173926973483606`", ",", 
              RowBox[{"-", "0.3458526601738012`"}]}], "}"}], ",", 
            "150.78451332962814`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06854912906343096`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.873260489996408`", ",", 
              RowBox[{"-", "0.17770917402864797`"}]}], "}"}], ",", 
            "156.90255342611383`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02587104088863533`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.099721637990405`", ",", 
              RowBox[{"-", "0.2070822485170844`"}]}], "}"}], ",", 
            "98.89435111853062`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025765386163769534`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.082806838587439`", ",", 
              RowBox[{"-", "0.0989968810419743`"}]}], "}"}], ",", 
            "101.94743782844047`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009652448407327154`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.163112851191095`", ",", 
              RowBox[{"-", "0.0630502622918786`"}]}], "}"}], ",", 
            "47.00418890743301`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00946646097670723`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5353880389761905`", ",", "0.33622452132097363`"}], 
             "}"}], ",", "54.64338610223961`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24013804168785682`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.2072759558879405`", ",", 
              RowBox[{"-", "0.40840447476237973`"}]}], "}"}], ",", 
            RowBox[{"-", "159.19152344087348`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2395460462025737`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.122525323515495`", ",", 
              RowBox[{"-", "0.44061256833959456`"}]}], "}"}], ",", 
            RowBox[{"-", "159.25251202485632`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26892762342886484`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.118958057251666`", ",", "0.730693687402561`"}], "}"}],
             ",", "156.83110749615233`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2536702204654676`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.874401641472924`", ",", "0.8353535702065428`"}], 
             "}"}], ",", "167.94883365120558`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014391785879441892`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.700765721031118`", ",", "0.872423121498889`"}], "}"}],
             ",", 
            RowBox[{"-", "126.88176117854904`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011904869402086862`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1566020874311045`", ",", "1.3948686334667941`"}], 
             "}"}], ",", "55.15718454851467`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01184349004149321`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.288513573205669`", ",", "1.5843620745615243`"}], 
             "}"}], ",", "58.9632777752423`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06272761080422067`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.962953264961906`", ",", "0.8250378530382365`"}], 
             "}"}], ",", "172.38083318786389`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06179549669042663`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.872577200713656`", ",", "0.8371273671687086`"}], 
             "}"}], ",", "179.2566230082061`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2448536484976005`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8527497331871134`", ",", "0.9455596562108208`"}], 
             "}"}], ",", "116.88057678243038`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24418185216005425`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.799054144884693`", ",", "1.0514884273813996`"}], 
             "}"}], ",", "115.5437171841801`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04274016272588291`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.88965565168125`", ",", "1.1046454086706592`"}], "}"}],
             ",", "61.38032037699672`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.036462914946855426`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8897054905365716`", ",", "1.104736744939623`"}], 
             "}"}], ",", "76.18653664302838`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012847936468866497`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.964069326973405`", ",", 
              RowBox[{"-", "0.6132710566160591`"}]}], "}"}], ",", 
            RowBox[{"-", "117.2135619079281`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012780536450395506`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9168138999373223`", ",", 
              RowBox[{"-", "0.7051666635248719`"}]}], "}"}], ",", 
            RowBox[{"-", "121.0729872252619`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3657890639256037`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6545398615910583`", ",", 
              RowBox[{"-", "1.280178969740208`"}]}], "}"}], ",", 
            RowBox[{"-", "153.53386958767712`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.36018625998912585`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.503822008840952`", ",", 
              RowBox[{"-", "1.3552129096803736`"}]}], "}"}], ",", 
            RowBox[{"-", "146.56996031241633`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26971478643623065`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4528534018009265`", ",", 
              RowBox[{"-", "1.0906598151282794`"}]}], "}"}], ",", 
            RowBox[{"-", "123.19253112527082`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26736266828727917`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3747794230132278`", ",", 
              RowBox[{"-", "1.2100033118374303`"}]}], "}"}], ",", 
            RowBox[{"-", "128.54092226365026`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009151248436518955`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.0215053031803265`", ",", 
              RowBox[{"-", "0.1365688422437436`"}]}], "}"}], ",", 
            RowBox[{"-", "160.4252670421708`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00912865539563651`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8714170205849907`", ",", 
              RowBox[{"-", "0.1899383071354556`"}]}], "}"}], ",", 
            RowBox[{"-", "160.59116279077304`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21909325300248375`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7095927179649006`", ",", "0.3694555953323202`"}], 
             "}"}], ",", "168.6599756490462`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.218184456874832`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5830711532181354`", ",", "0.39482902294536726`"}], 
             "}"}], ",", "165.55386651645475`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009381431981690535`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.232349480833086`", ",", "0.9075335520499725`"}], 
             "}"}], ",", "79.63803366694611`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009354671397241844`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.269784719445412`", ",", "1.1122674644837052`"}], 
             "}"}], ",", "81.20635545623976`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011648799886672645`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.618099162223654`", ",", "0.631822219651038`"}], "}"}],
             ",", "59.54839671666803`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011610786720315793`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.645647895609862`", ",", "0.6786811532817432`"}], 
             "}"}], ",", "57.33736383394778`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4510426663153465`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.9705929431190015`", ",", "0.6843149737851442`"}], 
             "}"}], ",", "138.94824033741924`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4455559388258916`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.899941011965765`", ",", "0.7458439041177413`"}], 
             "}"}], ",", "145.24697692078274`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010061315303617036`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.698679316809952`", ",", "0.14323389961481361`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.30889439323923`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010013157072089955`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.655763772139483`", ",", "0.1366737163587785`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.73493909721176`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030946525278727734`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.050783306785948`", ",", 
              RowBox[{"-", "0.26091767258249676`"}]}], "}"}], ",", 
            RowBox[{"-", "149.05226101547626`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029968592048010056`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.883599341133357`", ",", 
              RowBox[{"-", "0.36116449926156435`"}]}], "}"}], ",", 
            RowBox[{"-", "158.2123571374608`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.5744859607118045`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.266462557308947`", ",", 
              RowBox[{"-", "0.4372999424005015`"}]}], "}"}], ",", 
            RowBox[{"-", "35.27785196220935`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.553628102947669`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.381514964835767`", ",", 
              RowBox[{"-", "0.5186948359539496`"}]}], "}"}], ",", 
            RowBox[{"-", "32.533331021087314`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02077981465243545`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.639330255385841`", ",", 
              RowBox[{"-", "0.6831522198358223`"}]}], "}"}], ",", 
            "98.69443094718983`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03060762434679379`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.340928797522072`", ",", 
              RowBox[{"-", "0.1688171249226691`"}]}], "}"}], ",", 
            "78.49655709105726`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0303439986044081`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.364726631954419`", ",", 
              RowBox[{"-", "0.05188299846126178`"}]}], "}"}], ",", 
            "73.18366973126003`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2113051996916409`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.078954373256245`", ",", "0.2500927233677525`"}], 
             "}"}], ",", 
            RowBox[{"-", "169.78896551888397`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21067610754528882`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8171415788764795`", ",", "0.2029331101765597`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.58181478702485`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "83.83761926703055`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.385877384362597`", ",", "0.3672198357910872`"}], 
             "}"}], ",", "20.35613324277711`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "79.87033702506476`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.46397806998668`", ",", "0.3961971742504616`"}], "}"}],
             ",", "30.84540105065904`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.7795463720183426`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5901068238903555`", ",", "0.4715205258808095`"}], 
             "}"}], ",", "98.14750745204253`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17885201578345836`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.569286664841523`", ",", "0.616946076728329`"}], "}"}],
             ",", "165.44961385342606`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008463461061525249`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.427090072857617`", ",", "0.65385405811834`"}], "}"}], 
            ",", 
            RowBox[{"-", "127.24827974519039`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21024671262394828`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.10438412011554`", ",", "0.19786211558100952`"}], 
             "}"}], ",", 
            RowBox[{"-", "149.49876799556029`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20888941283739879`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.081452134150184`", ",", "0.18435347933583313`"}], 
             "}"}], ",", 
            RowBox[{"-", "145.01829444482533`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07821442192863452`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.826683256183537`", ",", "0.45472933508594915`"}], 
             "}"}], ",", "156.95802047148322`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07791643761151348`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.668343071788032`", ",", "0.5220777142812463`"}], 
             "}"}], ",", "159.76783695926608`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.833380786117062`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.865410312505054`", ",", "0.6554846140465254`"}], 
             "}"}], ",", "72.04947237248746`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.725890388587162`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.865531100028655`", ",", "0.6558574549179828`"}], 
             "}"}], ",", "80.11923306814161`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10509989984878894`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.898362925789411`", ",", "0.8443488925545409`"}], 
             "}"}], ",", "158.46511729836496`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07578105026646675`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.068810334202852`", ",", "0.6347265289902424`"}], 
             "}"}], ",", 
            RowBox[{"-", "12.859075726508376`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07559040039126813`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.345098640148805`", ",", "0.5716557199086093`"}], 
             "}"}], ",", 
            RowBox[{"-", "13.437721493465014`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29375092030399896`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.324433384014403`", ",", "0.5643586341087806`"}], 
             "}"}], ",", "148.30614525467564`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2898582568283681`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.25685805736425`", ",", "0.6060839947188786`"}], "}"}],
             ",", "141.76150744647595`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015502343724646688`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.960778241183477`", ",", 
              RowBox[{"-", "0.13227393548212468`"}]}], "}"}], ",", 
            RowBox[{"-", "166.94223666414194`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0154576254827468`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.862506407101621`", ",", 
              RowBox[{"-", "0.15506615480032948`"}]}], "}"}], ",", 
            RowBox[{"-", "165.31265470439195`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17284443708879696`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.368665699292367`", ",", 
              RowBox[{"-", "0.6386508757579388`"}]}], "}"}], ",", 
            RowBox[{"-", "93.82449824629026`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.159651211132068`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.346770984931949`", ",", 
              RowBox[{"-", "0.966173849270861`"}]}], "}"}], ",", 
            RowBox[{"-", "81.63151815193689`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012186186250522457`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.370658469300976`", ",", 
              RowBox[{"-", "1.1285576357412543`"}]}], "}"}], ",", 
            RowBox[{"-", "19.579294257533935`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18493387167233927`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.862033541413417`", ",", 
              RowBox[{"-", "0.5694760611249675`"}]}], "}"}], ",", 
            RowBox[{"-", "156.87060336581652`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18385079305088364`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.843546772902948`", ",", 
              RowBox[{"-", "0.577372549175145`"}]}], "}"}], ",", 
            RowBox[{"-", "152.6782050284165`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0677662676767037`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6598052417380575`", ",", 
              RowBox[{"-", "0.08667403832027229`"}]}], "}"}], ",", 
            "163.02059352259943`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06746903671021276`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.644180013893946`", ",", 
              RowBox[{"-", "0.08190306712637067`"}]}], "}"}], ",", 
            "159.7282029139003`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025660162922156938`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.023892590390386`", ",", "0.17942858185625332`"}], 
             "}"}], ",", "105.00052453835055`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025504774974547464`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.963593281354314`", ",", "0.40446042622468326`"}], 
             "}"}], ",", "100.7087045107558`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009284057230028295`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.668226346046645`", ",", "0.5234462570138415`"}], 
             "}"}], ",", "62.282583297046116`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00925969124989129`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.7218301323823555`", ",", "0.6254710583343828`"}], 
             "}"}], ",", "63.30017497111`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23895551012227334`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.836599226409276`", ",", 
              RowBox[{"-", "0.5489259410795577`"}]}], "}"}], ",", 
            RowBox[{"-", "159.31350060884515`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23621957715124342`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.669827641570253`", ",", 
              RowBox[{"-", "0.6118987683239112`"}]}], "}"}], ",", 
            RowBox[{"-", "165.43881906205675`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015257402963397159`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.874401641472924`", ",", "0.8353535702065428`"}], 
             "}"}], ",", "113.89715463601347`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015213052704004033`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7800941570748763`", ",", "1.048199041125198`"}], 
             "}"}], ",", "112.22673403336411`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2392784345860258`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.700765721031118`", ",", "0.872423121498889`"}], "}"}],
             ",", "179.06655980625877`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2365152442046992`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.540332325001979`", ",", "0.8750370702415957`"}], 
             "}"}], ",", "172.9167519078222`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013575278918476414`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.594207019314376`", ",", "0.7304061239629206`"}], 
             "}"}], ",", 
            RowBox[{"-", "115.76403502349586`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013541004802550265`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5653768335927825`", ",", "0.67067236065996`"}], "}"}],
             ",", 
            RowBox[{"-", "116.39098034934581`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011782427141818165`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.434230233882032`", ",", "1.8265236218852379`"}], 
             "}"}], ",", "62.76937100196972`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011752149891347843`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.442488502570082`", ",", "1.842571367732075`"}], "}"}],
             ",", "61.9422705343557`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06087723352217307`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.647719817861916`", ",", "0.8400449151302908`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.86758717145162`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06072655287750267`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4122339635400483`", ",", "0.8147439907309327`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.60495077281456`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24351189900647474`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.651432219296955`", ",", "1.3603774696099153`"}], 
             "}"}], ",", "114.20685758592926`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24218263486516475`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6317869098812796`", ",", "1.4040762764764532`"}], 
             "}"}], ",", "118.1875788017513`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031107606560806533`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9294255861950274`", ",", "1.2662841266646672`"}], 
             "}"}], ",", "90.99275290905999`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031008827758712634`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9280989752410815`", ",", "1.3428405400690842`"}], 
             "}"}], ",", "88.89932293449291`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012713490011077166`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7903414601329137`", ",", 
              RowBox[{"-", "0.9150460813852921`"}]}], "}"}], ",", 
            RowBox[{"-", "124.93241254259587`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012654263035535213`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4842168326986034`", ",", 
              RowBox[{"-", "1.3533368486914512`"}]}], "}"}], ",", 
            RowBox[{"-", "121.44462000690558`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3546692743972801`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.335531677235352`", ",", 
              RowBox[{"-", "1.4663065767668944`"}]}], "}"}], ",", 
            RowBox[{"-", "139.60605103715554`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2779633196139141`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1968282486405424`", ",", 
              RowBox[{"-", "1.5843271908251064`"}]}], "}"}], ",", 
            RowBox[{"-", "123.07222913717686`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.060116405239702936`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.122821027838444`", ",", 
              RowBox[{"-", "1.6979744077857233`"}]}], "}"}], ",", 
            RowBox[{"-", "68.8090335282522`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013001651383225262`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.17184458169658`", ",", 
              RowBox[{"-", "1.8244238040708087`"}]}], "}"}], ",", 
            RowBox[{"-", "14.545837919327456`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2650310623981845`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2175576221075644`", ",", 
              RowBox[{"-", "1.407368696474002`"}]}], "}"}], ",", 
            RowBox[{"-", "133.88931340202993`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26402217744730205`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1691153892197756`", ",", 
              RowBox[{"-", "1.4577264201050941`"}]}], "}"}], ",", 
            RowBox[{"-", "136.69613864469306`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009106118133536577`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5497612598705612`", ",", 
              RowBox[{"-", "0.30326694863810244`"}]}], "}"}], ",", 
            RowBox[{"-", "160.75705853937313`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00902536925074922`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.404192993676753`", ",", 
              RowBox[{"-", "0.35408154355463156`"}]}], "}"}], ",", 
            RowBox[{"-", "166.1531207059948`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2172794304223771`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3199501454438773`", ",", "0.46261288869489703`"}], 
             "}"}], ",", "162.4477573838632`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21673588577882225`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1817374130547575`", ",", "0.5063297872396552`"}], 
             "}"}], ",", "162.9398464571576`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009327987147502123`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.316627609022407`", ",", "1.4150762881589727`"}], 
             "}"}], ",", "82.77467724553435`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009294433670189554`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.339192280199492`", ",", "1.5930613960057278`"}], 
             "}"}], ",", "85.37316282951504`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011572897601142393`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.799127858721389`", ",", "0.9180940447729026`"}], 
             "}"}], ",", "55.12633095122784`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011321684154192444`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.0516089093221535`", ",", "1.2803718303013756`"}], 
             "}"}], ",", "47.1298208691403`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4401359548638054`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.71671549254766`", ",", "0.8729662902272273`"}], "}"}],
             ",", "151.5457135041463`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4390147261340071`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.656340914544981`", ",", "0.9056846679963191`"}], 
             "}"}], ",", "150.81056004270977`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009965229348721485`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.397708205712049`", ",", "0.08057332563951655`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.1609838011843`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009936213526491131`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.189373374273458`", ",", "0.021467253382598736`"}], 
             "}"}], ",", 
            RowBox[{"-", "165.84027431247813`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02902156223520853`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.734567675388738`", ",", 
              RowBox[{"-", "0.42073563195442343`"}]}], "}"}], ",", 
            RowBox[{"-", "167.37245325944534`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028924509565415823`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.628213718193005`", ",", 
              RowBox[{"-", "0.444562251532586`"}]}], "}"}], ",", 
            RowBox[{"-", "165.05974074722164`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020857857764136536`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.381514964835767`", ",", 
              RowBox[{"-", "0.5186948359539496`"}]}], "}"}], ",", 
            RowBox[{"-", "161.01657204824238`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020806130667997542`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.911232301346223`", ",", 
              RowBox[{"-", "0.6804740080385091`"}]}], "}"}], ",", 
            RowBox[{"-", "161.33383337344577`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.532848288295237`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.639330255385841`", ",", 
              RowBox[{"-", "0.6831522198358223`"}]}], "}"}], ",", 
            RowBox[{"-", "29.788810079964883`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.517424936317343`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.6616951298003775`", ",", 
              RowBox[{"-", "0.6959549043217395`"}]}], "}"}], ",", 
            RowBox[{"-", "31.224146676713374`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01538035788627458`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.903791814934578`", ",", 
              RowBox[{"-", "0.8427133549804139`"}]}], "}"}], ",", 
            "175.66265768454178`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02070206355189626`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.593103752960103`", ",", 
              RowBox[{"-", "0.3808641690826178`"}]}], "}"}], ",", 
            "101.43895188831199`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020218071203846697`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.585937710344732`", ",", 
              RowBox[{"-", "0.34544883692820877`"}]}], "}"}], ",", 
            "93.21730160903196`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030082643490126744`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.435475922970339`", ",", "0.18220880631998992`"}], 
             "}"}], ",", "67.8707823714628`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02978984769763544`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5277167916844`", ",", "0.4090387728449872`"}], "}"}], 
            ",", "73.5325316406815`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21004888831512233`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.593901268418461`", ",", "0.1698954461074504`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.37466405516616`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09602529295412246`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5368369334040395`", ",", "0.16326730455128366`"}], 
             "}"}], ",", 
            RowBox[{"-", "152.06113200950438`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.052126670300655`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.447483270690153`", ",", "0.11587933936681133`"}], 
             "}"}], ",", 
            RowBox[{"-", "101.18825640636696`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028296604707378912`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.42785836360701`", ",", "0.016659586763362176`"}], 
             "}"}], ",", 
            RowBox[{"-", "50.315380803229495`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015360617383527722`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.492443700937656`", ",", 
              RowBox[{"-", "0.06117633352154406`"}]}], "}"}], ",", 
            "0.557494799907982`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008338405573499956`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.593580874204508`", ",", 
              RowBox[{"-", "0.06019222565020976`"}]}], "}"}], ",", 
            "51.430370403045465`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.9672822419658496`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.46397806998668`", ",", "0.3961971742504616`"}], "}"}],
             ",", 
            RowBox[{"-", "25.967437542842497`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.9572924151053797`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.612509852193087`", ",", "0.3238578492146921`"}], 
             "}"}], ",", 
            RowBox[{"-", "26.558633762487858`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009964671947203912`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.898387262851132`", ",", "0.1809591662737341`"}], 
             "}"}], ",", "164.71606333937373`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "76.09079065304638`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5901068238903555`", ",", "0.47152052588080956`"}], 
             "}"}], ",", "41.33466885854101`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "75.78805238539758`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.7103606959140265`", ",", "0.5772951254941001`"}], 
             "}"}], ",", "44.2976736494366`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.30153377945895193`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.935844594623621`", ",", "0.7973177727561169`"}], 
             "}"}], ",", "172.22598883106838`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.6006943562348837`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.569286664841523`", ",", "0.616946076728329`"}], "}"}],
             ",", "108.63677525992458`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.591139600561047`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.4874006132775435`", ",", "0.8597499173682634`"}], 
             "}"}], ",", "107.53199655203302`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009529401298553416`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.385731150277527`", ",", "1.1815774722078438`"}], 
             "}"}], ",", 
            RowBox[{"-", "51.59229888861741`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1703885547219331`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.427090072857617`", ",", "0.65385405811834`"}], "}"}], 
            ",", "175.938881661308`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16967267903905908`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.407772164511959`", ",", "0.6552256069035045`"}], 
             "}"}], ",", "172.78954484994117`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008062961392420711`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.338170829330356`", ",", "0.5369120297766741`"}], 
             "}"}], ",", 
            RowBox[{"-", "116.75901193730849`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008042596384623464`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.29429118719413`", ",", "0.4498904721833331`"}], "}"}],
             ",", 
            RowBox[{"-", "116.12688646104385`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2075408754361802`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.850888149584709`", ",", "0.023020528021387654`"}], 
             "}"}], ",", 
            RowBox[{"-", "140.5378208940903`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20455874324321377`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.152008776889274`", ",", 
              RowBox[{"-", "0.5523167722276326`"}]}], "}"}], ",", 
            RowBox[{"-", "147.3162158120979`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07761958856652082`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.367192815857526`", ",", "0.6330714094465906`"}], 
             "}"}], ",", "162.57765344704893`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07727506301232216`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.339669363981522`", ",", "0.6417085268261644`"}], 
             "}"}], ",", "159.24623564175045`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10749039752990319`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.865531100028655`", ",", "0.6558574549179828`"}], 
             "}"}], ",", "9.843109533572385`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10385264082103`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.866032082750782`", ",", "0.6559443778978106`"}], 
             "}"}], ",", "0.4635918467535744`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.62079048873837`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.898362925789411`", ",", "0.8443488925545409`"}], 
             "}"}], ",", "88.18899376379582`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.5302938238138175`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.899262128321833`", ",", "0.8727879726536775`"}], 
             "}"}], ",", "80.50127827280868`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08872431744798197`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.934985647022961`", ",", "1.0862925640458698`"}], 
             "}"}], ",", 
            RowBox[{"-", "0.10736642999356864`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10276256486215848`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.720389387508421`", ",", "0.9145797299183803`"}], 
             "}"}], ",", "166.53487799401907`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10250354332498902`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.666533260694018`", ",", "0.9274747733141636`"}], 
             "}"}], ",", "165.92991393404552`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07540023015279645`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.601759200889874`", ",", "0.5103319550200578`"}], 
             "}"}], ",", 
            RowBox[{"-", "14.01636726042354`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07518882025403502`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.839475126009467`", ",", "0.4509905851077668`"}], 
             "}"}], ",", 
            RowBox[{"-", "12.54648369278691`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2860171772896278`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.090506017080307`", ",", "0.737171203163886`"}], "}"}],
             ",", "135.21686963827628`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28287139440904074`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.991659151421143`", ",", "0.8352725985202283`"}], 
             "}"}], ",", "129.2063833067123`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015413036235610177`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.561073218499606`", ",", 
              RowBox[{"-", "0.23407451704225998`"}]}], "}"}], ",", 
            RowBox[{"-", "163.68307274464172`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01535772897019159`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.44134789660697`", ",", 
              RowBox[{"-", "0.2691230503460128`"}]}], "}"}], ",", 
            RowBox[{"-", "166.2723787748419`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013193225956728961`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.346770984931949`", ",", 
              RowBox[{"-", "0.966173849270861`"}]}], "}"}], ",", 
            RowBox[{"-", "131.49076195198654`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013111306819803749`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.040126630241996`", ",", 
              RowBox[{"-", "1.3128848690005974`"}]}], "}"}], ",", 
            RowBox[{"-", "127.12485544671159`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14746502488154556`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.370658469300976`", ",", 
              RowBox[{"-", "1.1285576357412543`"}]}], "}"}], ",", 
            RowBox[{"-", "69.43853805758356`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1470860527947584`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.461859781943019`", ",", 
              RowBox[{"-", "1.371691218610847`"}]}], "}"}], ",", 
            RowBox[{"-", "68.6105958527151`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011256013943783253`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.525299534917696`", ",", 
              RowBox[{"-", "1.1835598797215485`"}]}], "}"}], ",", 
            RowBox[{"-", "7.386314163180548`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011228016663161554`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.600761982400861`", ",", 
              RowBox[{"-", "1.1933424117791065`"}]}], "}"}], ",", 
            RowBox[{"-", "7.00062483963788`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18277405755786433`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.62020904994084`", ",", 
              RowBox[{"-", "0.6927533534632233`"}]}], "}"}], ",", 
            RowBox[{"-", "148.48580669101665`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18113716219857534`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.421059584571563`", ",", 
              RowBox[{"-", "0.814860172281644`"}]}], "}"}], ",", 
            RowBox[{"-", "153.91015702773728`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06717310943434061`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.3916852340172055`", ",", "0.011356320668955004`"}], 
             "}"}], ",", "156.43581230520104`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06609561949505885`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.165796928560684`", ",", "0.1098764015693789`"}], 
             "}"}], ",", "163.5343212946823`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025350327995798387`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.917328532690551`", ",", "0.6491059597694256`"}], 
             "}"}], ",", "96.41688448316104`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02507899940711894`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.891472330682532`", ",", "0.879007572435998`"}], "}"}],
             ",", "90.48413197987007`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009235389218195503`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.856008136082876`", ",", "0.892256352907218`"}], "}"}],
             ",", "64.31776664517353`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009064769491379732`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.877142979456383`", ",", "0.9362061847735541`"}], 
             "}"}], ",", "56.80355173133095`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23351496938053268`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.440801978911579`", ",", 
              RowBox[{"-", "0.6713898163737759`"}]}], "}"}], ",", 
            RowBox[{"-", "171.5641375152683`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23255393365007304`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3397884269225475`", ",", 
              RowBox[{"-", "0.6863708108810382`"}]}], "}"}], ",", 
            RowBox[{"-", "168.484723657966`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015168831362062506`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.652262238794404`", ",", "1.3610242766510867`"}], 
             "}"}], ",", "110.55631343071475`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01506031858180493`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.634322296068684`", ",", "1.4088634427580893`"}], 
             "}"}], ",", "115.33576240762893`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2337839631807564`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3652191267041047`", ",", "0.8967965807865681`"}], 
             "}"}], ",", "166.7669440093856`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21848697272013848`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3584371703534224`", ",", "0.8983914028520312`"}], 
             "}"}], ",", "178.3939225001021`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014296075282482465`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.22879531666272`", ",", "0.9020263899058154`"}], "}"}],
             ",", 
            RowBox[{"-", "117.99064192160036`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01350681722002278`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.423048150401369`", ",", "0.3838397198217184`"}], 
             "}"}], ",", 
            RowBox[{"-", "117.01792567519519`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01347350134962201`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.070299296037435`", ",", 
              RowBox[{"-", "0.3079337586645584`"}]}], "}"}], ",", 
            RowBox[{"-", "116.90517343317211`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011721950444193009`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.592996513027466`", ",", "2.1249490237982482`"}], 
             "}"}], ",", "61.11517006674166`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01168525852973367`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.611110226660915`", ",", "2.157782503145335`"}], "}"}],
             ",", "59.08555403376247`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24086062680934622`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.495720909980971`", ",", "1.6579704444939585`"}], 
             "}"}], ",", "122.16830001757351`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23591873599117533`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4243203082646443`", ",", "1.7714919169140946`"}], 
             "}"}], ",", "129.9952148554264`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03091036261790038`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9343541138804152`", ",", "1.6684119244566258`"}], 
             "}"}], ",", "86.80589295992618`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03082021752639167`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.944238569475594`", ",", "1.8455352239882736`"}], 
             "}"}], ",", "85.11827292706349`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012595311974366787`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3495590308742202`", ",", 
              RowBox[{"-", "1.5735559140602946`"}]}], "}"}], ",", 
            RowBox[{"-", "117.95682747121529`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012564226001410135`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.344019420635874`", ",", 
              RowBox[{"-", "1.5839933710191287`"}]}], "}"}], ",", 
            RowBox[{"-", "118.10626850177142`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21784691437421075`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.122821027838444`", ",", 
              RowBox[{"-", "1.6979744077857233`"}]}], "}"}], ",", 
            RowBox[{"-", "106.53840723719836`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21729486882195345`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0942813412035988`", ",", 
              RowBox[{"-", "1.7940861426641752`"}]}], "}"}], ",", 
            RowBox[{"-", "107.21207851171971`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04711475385647763`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.17184458169658`", ",", 
              RowBox[{"-", "1.8244238040708087`"}]}], "}"}], ",", 
            RowBox[{"-", "52.275211628273794`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0386882498429953`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3314998299859577`", ",", 
              RowBox[{"-", "2.030808955936765`"}]}], "}"}], ",", 
            RowBox[{"-", "36.60810887479941`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010189724455510725`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3031174647941777`", ",", 
              RowBox[{"-", "1.8584853486187098`"}]}], "}"}], ",", 
            "1.9879839806507893`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01011723167946918`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3538526555372528`", ",", 
              RowBox[{"-", "1.856724289753587`"}]}], "}"}], ",", 
            RowBox[{"-", "2.775487782526721`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26301713298528495`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9545503044322277`", ",", 
              RowBox[{"-", "1.6599496305216161`"}]}], "}"}], ",", 
            RowBox[{"-", "139.50296388735643`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2616521920850118`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8843245852369903`", ",", 
              RowBox[{"-", "1.7199217785169294`"}]}], "}"}], ",", 
            RowBox[{"-", "143.32915135264645`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008945336412051759`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1711990803001635`", ",", 
              RowBox[{"-", "0.4115125146935025`"}]}], "}"}], ",", 
            RowBox[{"-", "171.54918287261643`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008922328194784484`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1507501855607156`", ",", 
              RowBox[{"-", "0.41455067932681255`"}]}], "}"}], ",", 
            RowBox[{"-", "170.71280279542464`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21619370086259623`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8956096724243867`", ",", "0.5941363996724759`"}], 
             "}"}], ",", "163.43193553045052`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21533601896397675`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.874159596136431`", ",", "0.6005179289230769`"}], 
             "}"}], ",", "160.47897165357705`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009261000887279972`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.3638619846663005`", ",", "1.897890825549716`"}], 
             "}"}], ",", "87.97164841349573`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009097216469408765`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.3728757462880425`", ",", "2.152400317364623`"}], 
             "}"}], ",", "95.3567774012162`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01107592380966364`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.186980434491088`", ",", "1.4262010764902882`"}], 
             "}"}], ",", "39.133310787052736`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010822634391580802`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.350438183835544`", ",", "1.5591974553303574`"}], 
             "}"}], ",", "30.978872389036407`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.43789635368952373`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.3477706183017695`", ",", "1.0780641496062522`"}], 
             "}"}], ",", "150.07540658127277`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4333137727847597`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.284510727295245`", ",", "1.1144763410521983`"}], 
             "}"}], ",", "144.2068681317708`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00990728218981653`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.886363500432843`", ",", 
              RowBox[{"-", "0.05497944326763965`"}]}], "}"}], ",", 
            RowBox[{"-", "167.519564823772`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00970568834935842`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.766450187298416`", ",", 
              RowBox[{"-", "0.08152062867129992`"}]}], "}"}], ",", 
            RowBox[{"-", "159.71753168807584`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028827781455019248`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.335781837376667`", ",", 
              RowBox[{"-", "0.5225924266413898`"}]}], "}"}], ",", 
            RowBox[{"-", "162.74702823499794`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028607857665319522`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1406776893927555`", ",", 
              RowBox[{"-", "0.5831849702109122`"}]}], "}"}], ",", 
            RowBox[{"-", "167.71207700848728`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02075453185408701`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.624663377518157`", ",", 
              RowBox[{"-", "0.777283667465705`"}]}], "}"}], ",", 
            RowBox[{"-", "161.65109469865143`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017174531323319905`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.285262011497718`", ",", 
              RowBox[{"-", "0.8898514129071506`"}]}], "}"}], ",", 
            RowBox[{"-", "177.1572020131803`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015423351977895943`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.6616951298003775`", ",", 
              RowBox[{"-", "0.6959549043217395`"}]}], "}"}], ",", 
            "120.45371236528294`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015384292576962095`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.649809728695999`", ",", 
              RowBox[{"-", "0.6757401709390647`"}]}], "}"}], ",", 
            "121.11956115803216`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.502044578431068`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.903791814934578`", ",", 
              RowBox[{"-", "0.8427133549804139`"}]}], "}"}], ",", 
            RowBox[{"-", "32.659483273462115`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.400012755553523`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.952683447459978`", ",", 
              RowBox[{"-", "0.8740524240884584`"}]}], "}"}], ",", 
            RowBox[{"-", "40.184875332326214`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10013970936750122`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.098021325764257`", ",", 
              RowBox[{"-", "0.9968067045346964`"}]}], "}"}], ",", 
            RowBox[{"-", "121.80705962635722`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015337483644859371`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.621496895843233`", ",", 
              RowBox[{"-", "0.8213024594383405`"}]}], "}"}], ",", 
            "174.22732108779306`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015298968107760425`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.386503912598267`", ",", 
              RowBox[{"-", "0.79754594807913`"}]}], "}"}], ",", 
            "173.67516362163684`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01974539408494728`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.574334237508879`", ",", 
              RowBox[{"-", "0.139023951860052`"}]}], "}"}], ",", 
            "84.99565132975194`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01965111971513255`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.577263296573113`", ",", 
              RowBox[{"-", "0.10557389463469018`"}]}], "}"}], ",", 
            "88.56167492728946`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029499901700446484`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5835171622575075`", ",", "0.5978111898525217`"}], 
             "}"}], ",", "79.19428090990027`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028596646778779558`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.601474680697096`", ",", "0.6918967745999689`"}], 
             "}"}], ",", "70.13444119156834`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11402359536099986`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5368369334040395`", ",", "0.16326730455128366`"}], 
             "}"}], ",", "178.37952443301978`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1135790028857132`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.348854642305988`", ",", "0.16858535696493876`"}], 
             "}"}], ",", "175.48725785287127`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04389862265346749`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.447483270690153`", ",", "0.11587933936681133`"}], 
             "}"}], ",", 
            RowBox[{"-", "130.74759996384304`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04373972409248053`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.325030926814644`", ",", 
              RowBox[{"-", "0.026245639924664915`"}]}], "}"}], ",", 
            RowBox[{"-", "128.12556293159676`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02383006559327609`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.42785836360701`", ",", "0.01665958676336221`"}], 
             "}"}], ",", 
            RowBox[{"-", "79.87472436070594`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02376757003658947`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.4982581522663425`", ",", 
              RowBox[{"-", "0.377555216146243`"}]}], "}"}], ",", 
            RowBox[{"-", "80.88619674316874`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01293598732385119`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.492443700937656`", ",", 
              RowBox[{"-", "0.061176333521544085`"}]}], "}"}], ",", 
            RowBox[{"-", "29.001848757568478`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01288417361574604`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.6973141732691275`", ",", 
              RowBox[{"-", "0.1747465325449184`"}]}], "}"}], ",", 
            RowBox[{"-", "31.988115253259416`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009989826860471058`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.612509852193087`", ",", "0.3238578492146921`"}], 
             "}"}], ",", "141.57547291600534`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00994384498497979`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5127792552332116`", ",", "0.4029728818525733`"}], 
             "}"}], ",", "138.12627536543016`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.9473277431581772`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.898387262851132`", ",", "0.1809591662737341`"}], 
             "}"}], ",", 
            RowBox[{"-", "27.14982998213385`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.93090829127967`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.97435174451669`", ",", "0.14200277352684282`"}], 
             "}"}], ",", 
            RowBox[{"-", "30.265436778514374`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016351152913349525`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1533879505423`", ",", "0.03752729228343482`"}], "}"}],
             ",", 
            RowBox[{"-", "155.95362229257535`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0099395803753412`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5900884129714665`", ",", "0.26520729191273357`"}], 
             "}"}], ",", "164.12486711972775`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009905449424197901`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.400758126154542`", ",", "0.3190506142465829`"}], 
             "}"}], ",", "166.54399696697314`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3027382676488262`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.7103606959140265`", ",", "0.5772951254941001`"}], 
             "}"}], ",", 
            RowBox[{"-", "80.6676367412996`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3019759219363605`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.739719792815295`", ",", "0.3986426170525476`"}], 
             "}"}], ",", 
            RowBox[{"-", "81.25946416418196`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "75.48651860593858`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.935844594623621`", ",", "0.7973177727561169`"}], 
             "}"}], ",", "47.26067844033207`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "75.18908972622434`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9767342513768655`", ",", "0.8415684967397441`"}], 
             "}"}], ",", "50.18974863351283`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29625696266042756`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.156710522321821`", ",", "1.057504153542214`"}], "}"}],
             ",", "178.62343125498694`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.30033408350038`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.623695705447773`", ",", "0.8399326160826954`"}], 
             "}"}], ",", "175.18899362196373`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29929508032626695`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.188869344374059`", ",", "0.8765301252217953`"}], 
             "}"}], ",", "172.74052678453037`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00955475567383658`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.4874006132775435`", ",", "0.8597499173682634`"}], 
             "}"}], ",", 
            RowBox[{"-", "94.44848671520808`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009531017240429419`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.471949617710071`", ",", "0.6611436641888342`"}], 
             "}"}], ",", 
            RowBox[{"-", "94.08786761640705`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.581610199262495`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.385731150277527`", ",", "1.1815774722078438`"}], 
             "}"}], ",", "106.42721784414178`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.3948656574795173`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.364102736692175`", ",", "1.2549358388771608`"}], 
             "}"}], ",", "117.24981010180657`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1770077133886069`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.285753978708785`", ",", "1.4070605913421486`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.61038484895062`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00922915183109922`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.114937969488056`", ",", "1.3969433197743022`"}], 
             "}"}], ",", 
            RowBox[{"-", "110.47057979970772`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009504114203310814`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.595407208774853`", ",", "0.9171051574870768`"}], 
             "}"}], ",", 
            RowBox[{"-", "52.69707759650896`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009479162575955621`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.639117835616823`", ",", "0.8597328288639436`"}], 
             "}"}], ",", 
            RowBox[{"-", "51.676815753657145`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16895981105816463`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.17426127708289`", ",", "0.6847681835117939`"}], "}"}],
             ",", "169.64020803857449`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16853957652470247`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.9129569581717885`", ",", "0.7325369742730579`"}], 
             "}"}], ",", "169.25563452569548`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008022282813701877`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.149860507509465`", ",", "0.15542061427856801`"}], 
             "}"}], ",", 
            RowBox[{"-", "115.49476098477925`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20161946098232789`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.976148157166832`", ",", 
              RowBox[{"-", "0.6651470108793203`"}]}], "}"}], ",", 
            RowBox[{"-", "154.09461073010547`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2010189555938405`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.922093988224713`", ",", 
              RowBox[{"-", "0.6914005885171679`"}]}], "}"}], ",", 
            RowBox[{"-", "155.88952454396505`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0769320666836668`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.090655489293798`", ",", "0.7360701536815027`"}], 
             "}"}], ",", "155.91481783645196`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017436484983645455`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.813642807021752`", ",", "0.8598979484814954`"}], 
             "}"}], ",", "179.3646281616771`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013484543723114452`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.679967194926414`", ",", "0.8613803822979871`"}], 
             "}"}], ",", 
            RowBox[{"-", "130.28026479001534`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010428301322837948`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.593536982293348`", ",", "0.7593941811564283`"}], 
             "}"}], ",", 
            RowBox[{"-", "79.92515774170776`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008064749591302904`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.616922886965641`", ",", "0.6277717425612483`"}], 
             "}"}], ",", 
            RowBox[{"-", "29.570050693400123`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10033799533117782`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.043512798331155`", ",", "0.6573804419320666`"}], 
             "}"}], ",", 
            RowBox[{"-", "8.915925840065315`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09835373539021006`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.210986383001262`", ",", "0.6311070841589409`"}], 
             "}"}], ",", 
            RowBox[{"-", "1.1992298383238487`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09049666492455452`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.899262128321833`", ",", "0.8727879726536775`"}], 
             "}"}], ",", "153.42220748462375`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.034900456856099216`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.841682554284794`", ",", "0.9015937670123577`"}], 
             "}"}], ",", "175.4617768609451`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02144093445513161`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.712539000534084`", ",", "0.9118442775173976`"}], 
             "}"}], ",", 
            RowBox[{"-", "133.8947192363088`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01317213904117977`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.622717590410879`", ",", "0.8184888024532366`"}], 
             "}"}], ",", 
            RowBox[{"-", "83.25121533356258`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008092242774364275`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.637941798653708`", ",", "0.6898367370817262`"}], 
             "}"}], ",", 
            RowBox[{"-", "32.60771143081625`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.441569506365835`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.934985647022961`", ",", "1.0862925640458698`"}], 
             "}"}], ",", "72.81356278182163`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.428545035069252`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.02114616024396`", ",", "1.3648656312182066`"}], "}"}],
             ",", "74.52970414272157`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0129862782991946`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.10158126102411`", ",", "1.6554902335190946`"}], "}"}],
             ",", 
            RowBox[{"-", "137.32972322182462`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08698668081496037`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.151457852592751`", ",", "1.0858869168008731`"}], 
             "}"}], ",", 
            RowBox[{"-", "7.795081920980665`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08677016129752341`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.298381427932044`", ",", "1.0657737383879953`"}], 
             "}"}], ",", 
            RowBox[{"-", "8.195713655713424`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10224517467300984`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.343756785437981`", ",", "1.0083714905520778`"}], 
             "}"}], ",", "165.32494987407017`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1017535771684494`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.161225427054131`", ",", "1.0561727505257825`"}], 
             "}"}], ",", "168.9131105635396`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07497800311401193`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.143881683462895`", ",", "0.3832461284525548`"}], 
             "}"}], ",", 
            RowBox[{"-", "11.076600125150037`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07414352473640408`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.32151291507871`", ",", "0.3484715981465151`"}], "}"}],
             ",", 
            RowBox[{"-", "5.032277059895307`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27976021067395124`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.839439865992445`", ",", "1.0218694340316077`"}], 
             "}"}], ",", "123.19589697514846`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.278727566910716`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.750805233635593`", ",", "1.157338521753208`"}], "}"}],
             ",", "120.50114930110017`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015302620166228706`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.122856680468086`", ",", 
              RowBox[{"-", "0.3469255217782274`"}]}], "}"}], ",", 
            RowBox[{"-", "168.86168480504196`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015138093205970727`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.05452514831685`", ",", 
              RowBox[{"-", "0.36037909558971937`"}]}], "}"}], ",", 
            RowBox[{"-", "162.91605544976164`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013029896333682863`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.899821121356265`", ",", 
              RowBox[{"-", "1.4982348238119843`"}]}], "}"}], ",", 
            RowBox[{"-", "122.75894894143671`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012997495591885134`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8447250389984315`", ",", 
              RowBox[{"-", "1.5838618799218238`"}]}], "}"}], ",", 
            RowBox[{"-", "123.13889289484467`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14670805463275563`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5760497386044126`", ",", 
              RowBox[{"-", "1.6632283365645302`"}]}], "}"}], ",", 
            RowBox[{"-", "67.78265364784708`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1374711393535217`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.6059430288850525`", ",", 
              RowBox[{"-", "1.7364162622695076`"}]}], "}"}], ",", 
            RowBox[{"-", "56.294481242760945`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008655348002035998`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.698922125620347`", ",", 
              RowBox[{"-", "1.8758034494156233`"}]}], "}"}], ",", 
            "7.73003902138586`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011200089020666285`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.916170905633331`", ",", 
              RowBox[{"-", "1.2320732494795885`"}]}], "}"}], ",", 
            RowBox[{"-", "6.614935516095213`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011169332644271364`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.120371921029847`", ",", 
              RowBox[{"-", "1.2557540571998236`"}]}], "}"}], ",", 
            RowBox[{"-", "5.272445975983037`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17951492661350738`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.211636102543155`", ",", 
              RowBox[{"-", "0.9174096462932262`"}]}], "}"}], ",", 
            RowBox[{"-", "159.33450736445798`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1790670088391891`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1540997221684615`", ",", 
              RowBox[{"-", "0.9391112416421967`"}]}], "}"}], ",", 
            RowBox[{"-", "158.8872116167217`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06503541302797344`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.956690241253088`", ",", "0.17168039885872202`"}], 
             "}"}], ",", "170.6328302841635`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06487305345468208`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9225528304364947`", ",", "0.177311715770142`"}], 
             "}"}], ",", "170.17596174522126`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024810574891437957`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8894263217254865`", ",", "1.1211417280571658`"}], 
             "}"}], ",", "84.551379476579`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02471879451365109`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.911625254895543`", ",", "1.3538738076488344`"}], 
             "}"}], ",", "81.84859222927432`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008897301888474594`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.996981320663829`", ",", "1.1193631448066796`"}], 
             "}"}], ",", "49.28933681748847`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008867776320461054`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.067545715787124`", ",", "1.2013709460128568`"}], 
             "}"}], ",", "47.00827039061789`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23159685308222092`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.060092723143652`", ",", 
              RowBox[{"-", "0.7433532091214999`"}]}], "}"}], ",", 
            RowBox[{"-", "165.40530980066367`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2309243587133448`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9321073113160727`", ",", 
              RowBox[{"-", "0.7766782465086752`"}]}], "}"}], ",", 
            RowBox[{"-", "167.07014185023118`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014952582065927799`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5179669445967625`", ",", "1.6546179606098674`"}], 
             "}"}], ",", "120.1152113845432`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014456281109720108`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4031273095709067`", ",", "1.8526055614273562`"}], 
             "}"}], ",", "110.79811322981409`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015296990460617858`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3584371703534224`", ",", "0.8983914028520312`"}], 
             "}"}], ",", "126.40546541252102`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015209278402895503`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2418943733926846`", ",", "1.0564346421307682`"}], 
             "}"}], ",", "122.27637739601138`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20419089743765598`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.22879531666272`", ",", "0.9020263899058154`"}], "}"}],
             ",", 
            RowBox[{"-", "169.97909900918143`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20084734110354682`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1107622699206594`", ",", "0.8811695801798028`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.137921559203`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013360652149753193`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.167926937343688`", ",", "0.7875044978575387`"}], 
             "}"}], ",", 
            RowBox[{"-", "106.3636634308839`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01332445518595478`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1018694891400234`", ",", "0.5625338826359672`"}], 
             "}"}], ",", 
            RowBox[{"-", "107.61731042452053`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011648681467882966`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.764975851525028`", ",", "2.414726189496874`"}], "}"}],
             ",", "57.05593800078328`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01150095117809422`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.040372770179408`", ",", "2.839708033129257`"}], "}"}],
             ",", "63.474247874165194`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23107824109305267`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.312530256982746`", ",", "1.9047407108645917`"}], 
             "}"}], ",", "137.8221296932794`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22941892763031516`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.160245365407655`", ",", "2.042717078838258`"}], "}"}],
             ",", "142.61251127885697`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03073033532851586`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9696703051931497`", ",", "2.143299400268076`"}], 
             "}"}], ",", "83.43065289420122`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030653458184703334`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.989624174191954`", ",", "2.316567486165755`"}], "}"}],
             ",", "82.93805421791085`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012533216750468534`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.203960725449316`", ",", 
              RowBox[{"-", "1.846230942491997`"}]}], "}"}], ",", 
            RowBox[{"-", "118.25570953233003`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012457273060717559`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.183252305621113`", ",", 
              RowBox[{"-", "1.8847619765155457`"}]}], "}"}], ",", 
            RowBox[{"-", "122.54938119246671`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2167442222075358`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9941947604424164`", ",", 
              RowBox[{"-", "2.117172517617665`"}]}], "}"}], ",", 
            RowBox[{"-", "107.88574978624267`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21442058623731008`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9225117896096935`", ",", 
              RowBox[{"-", "2.339296137369611`"}]}], "}"}], ",", 
            RowBox[{"-", "101.94834046576706`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00842650401348229`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3314998299859577`", ",", 
              RowBox[{"-", "2.030808955936765`"}]}], "}"}], ",", 
            RowBox[{"-", "76.29191789676202`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008382122169376241`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.343528762848731`", ",", 
              RowBox[{"-", "2.080123389095915`"}]}], "}"}], ",", 
            RowBox[{"-", "80.16356807228352`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031768831489039896`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4515426952274284`", ",", 
              RowBox[{"-", "2.1199870179428464`"}]}], "}"}], ",", 
            RowBox[{"-", "20.941006121325106`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03169040267991834`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.556943566838984`", ",", 
              RowBox[{"-", "2.160322154999426`"}]}], "}"}], ",", 
            RowBox[{"-", "20.777375108963387`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010045254638921875`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6087330171752736`", ",", 
              RowBox[{"-", "1.8690807179268634`"}]}], "}"}], ",", 
            RowBox[{"-", "7.538959545704307`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009699307143704223`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.626161706169526`", ",", 
              RowBox[{"-", "1.8713873058769472`"}]}], "}"}], ",", 
            "1.8968548487244494`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2602943346155405`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6583334482814975`", ",", 
              RowBox[{"-", "1.8881915848497568`"}]}], "}"}], ",", 
            RowBox[{"-", "147.15533881793655`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2595849112566412`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.628396231651677`", ",", 
              RowBox[{"-", "1.9075178484490787`"}]}], "}"}], ",", 
            RowBox[{"-", "148.4489642062329`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008899379156740599`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.844387562893518`", ",", 
              RowBox[{"-", "0.4646491925784466`"}]}], "}"}], ",", 
            RowBox[{"-", "169.87642271823418`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008877209848899389`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.711766618665485`", ",", 
              RowBox[{"-", "0.4883288901651158`"}]}], "}"}], ",", 
            RowBox[{"-", "169.459797578088`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21448173965403708`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5947838776974526`", ",", "0.699565467163501`"}], 
             "}"}], ",", "157.5260077767038`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21390216141656454`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.411995464801956`", ",", "0.7751817178667965`"}], 
             "}"}], ",", "158.76200417268007`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008936328642938847`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.352532376797479`", ",", "2.369357454152633`"}], "}"}],
             ",", "102.7419063889365`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010575137314652998`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.52218963097219`", ",", "1.6623099573089042`"}], "}"}],
             ",", "22.82443399102018`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010540848720848851`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.625069808407641`", ",", "1.7056084372372071`"}], 
             "}"}], ",", "20.640641650560084`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.42877914854273486`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.096591811836374`", ",", "1.2499734969440517`"}], 
             "}"}], ",", "138.338329682269`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4182358096509167`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9862592797803313`", ",", "1.3481438736691491`"}], 
             "}"}], ",", "129.96227813976702`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010284086557917411`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8677830330422824`", ",", "1.489527299309895`"}], 
             "}"}], ",", "53.31314400394015`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009508196549776105`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.560933992060265`", ",", 
              RowBox[{"-", "0.15747189595957234`"}]}], "}"}], ",", 
            RowBox[{"-", "151.9154985523798`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009483135678169314`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4144325205014994`", ",", 
              RowBox[{"-", "0.2356454770595336`"}]}], "}"}], ",", 
            RowBox[{"-", "152.9676180646845`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028389611648616347`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.908455139197296`", ",", 
              RowBox[{"-", "0.6337664010897093`"}]}], "}"}], ",", 
            RowBox[{"-", "172.67712578197646`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02829547433083988`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.902628181296575`", ",", 
              RowBox[{"-", "0.6345152162075803`"}]}], "}"}], ",", 
            RowBox[{"-", "170.39926886569683`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01421205393836006`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.147244857449752`", ",", 
              RowBox[{"-", "0.8967049223682861`"}]}], "}"}], ",", 
            "167.3366906722908`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013895593409651902`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.137138975144561`", ",", 
              RowBox[{"-", "0.8944342626544151`"}]}], "}"}], ",", 
            "175.41024640567576`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015345332093358513`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.477344047574457`", ",", 
              RowBox[{"-", "0.3900611068834905`"}]}], "}"}], ",", 
            "121.78540995078029`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01208765519280617`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.37136217824953`", ",", 
              RowBox[{"-", "0.2190326212415336`"}]}], "}"}], ",", 
            "138.2327845289799`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.102031822877546`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.952683447459978`", ",", 
              RowBox[{"-", "0.8740524240884584`"}]}], "}"}], ",", 
            "33.911916902840716`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10171591638734098`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.052469467204013`", ",", 
              RowBox[{"-", "0.8069688713511451`"}]}], "}"}], ",", 
            "31.9320184987648`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.299873046186019`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.098021325764257`", ",", 
              RowBox[{"-", "0.9968067045346964`"}]}], "}"}], ",", 
            RowBox[{"-", "47.71026739119036`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.279616600698042`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.224219046840725`", ",", 
              RowBox[{"-", "1.1355461267955338`"}]}], "}"}], ",", 
            RowBox[{"-", "50.53157107104334`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02017902408934035`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.404873413023072`", ",", 
              RowBox[{"-", "1.354943595196123`"}]}], "}"}], ",", 
            "179.41250770359824`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0982826838666087`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.997752704567444`", ",", 
              RowBox[{"-", "1.1584789527443164`"}]}], "}"}], ",", 
            RowBox[{"-", "129.33245168522143`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0977787930460281`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.91710714484928`", ",", 
              RowBox[{"-", "1.2568947932735157`"}]}], "}"}], ",", 
            RowBox[{"-", "133.12121229683976`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015260549290999206`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.084428116973464`", ",", 
              RowBox[{"-", "0.7640639246493693`"}]}], "}"}], ",", 
            "173.12300615548128`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015222883000252874`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.9151743398878`", ",", 
              RowBox[{"-", "0.7436509199874607`"}]}], "}"}], ",", 
            "172.97020708192977`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01955729545822849`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.584222943013781`", ",", "0.1716058667428289`"}], 
             "}"}], ",", "92.12769852482685`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01934716147380595`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.574033746401171`", ",", "0.44585974810855794`"}], 
             "}"}], ",", "98.07146277665998`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0277210485409145`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.672516915681058`", ",", "0.8885179867466502`"}], 
             "}"}], ",", "61.07460147323644`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.027185381555830897`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.804524202477089`", ",", "1.1273984324969137`"}], 
             "}"}], ",", "68.72229551796222`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1131361439329352`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.062238178947538`", ",", "0.1912066990993062`"}], 
             "}"}], ",", "172.59499127272275`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11280753395326751`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.854268663032112`", ",", "0.21823571056275384`"}], 
             "}"}], ",", "170.9286572823858`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04358140069196921`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1212892282563045`", ",", 
              RowBox[{"-", "0.28584844369612605`"}]}], "}"}], ",", 
            RowBox[{"-", "125.50352589935048`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04346055979354915`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.058741770078805`", ",", 
              RowBox[{"-", "0.37352533270738797`"}]}], "}"}], ",", 
            RowBox[{"-", "124.10058136952266`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023705238377672685`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.548883626199007`", ",", 
              RowBox[{"-", "0.6931337635867161`"}]}], "}"}], ",", 
            RowBox[{"-", "81.89766912563228`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023557862314608866`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.577185086091668`", ",", 
              RowBox[{"-", "0.8919322091923785`"}]}], "}"}], ",", 
            RowBox[{"-", "86.2673013538829`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012832567441884733`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.903281161164852`", ",", 
              RowBox[{"-", "0.3033895933541004`"}]}], "}"}], ",", 
            RowBox[{"-", "34.97438174895035`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012462827083531003`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.971531298262972`", ",", 
              RowBox[{"-", "0.3511333900671929`"}]}], "}"}], ",", 
            RowBox[{"-", "43.84244036585447`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009898074758088963`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.34098319847574`", ",", "0.5569745163120173`"}], "}"}],
             ",", "134.6770778148549`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009821291566382246`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.300445387111725`", ",", "0.5979718692414645`"}], 
             "}"}], ",", "129.66399042567593`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016419451878506252`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.97435174451669`", ",", "0.14200277352684282`"}], 
             "}"}], ",", "92.30714193916606`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01637449812895876`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.96810564813093`", ",", "0.29703507084169406`"}], 
             "}"}], ",", "90.98396273037005`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.914557138366321`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1533879505423`", ",", "0.03752729228343482`"}], "}"}],
             ",", 
            RowBox[{"-", "33.381043574894804`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.7807874059594893`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.39375033838211`", ",", 
              RowBox[{"-", "0.12084842573426254`"}]}], "}"}], ",", 
            RowBox[{"-", "23.970290148934822`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.129198502335155`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5496058187056825`", ",", 
              RowBox[{"-", "0.19014294206542603`"}]}], "}"}], ",", 
            "47.633481229287845`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016283138047119023`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.964087541651995`", ",", 
              RowBox[{"-", "0.04693834832296653`"}]}], "}"}], ",", 
            RowBox[{"-", "159.0692290889559`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016214232730260462`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8111748949094295`", ",", 
              RowBox[{"-", "0.1054241267005212`"}]}], "}"}], ",", 
            RowBox[{"-", "155.89579154075085`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00987143567335703`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.103008723708266`", ",", "0.39029214819013164`"}], 
             "}"}], ",", "168.96312681421838`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009772716261754294`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.033355543856384`", ",", "0.40387788023287086`"}], 
             "}"}], ",", "163.22407459397994`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.30121549593820734`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.788286169112373`", ",", "0.08275477138089243`"}], 
             "}"}], ",", 
            RowBox[{"-", "81.85129158706617`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2981272510973552`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8157708955746745`", ",", 
              RowBox[{"-", "0.10919306060865114`"}]}], "}"}], ",", 
            RowBox[{"-", "87.66134389042425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29742887971425863`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9767342513768655`", ",", "0.8415684967397441`"}], 
             "}"}], ",", 
            RowBox[{"-", "75.3148637947805`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2962795400380463`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.037289686503661`", ",", "0.6105007043935301`"}], 
             "}"}], ",", 
            RowBox[{"-", "78.17532072301118`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "74.89283276356394`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.156710522321821`", ",", "1.057504153542214`"}], "}"}],
             ",", "53.118818826693584`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "74.54594837632067`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.192065638887377`", ",", "1.1046249733468794`"}], 
             "}"}], ",", "56.58809724210488`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3452777077564049`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.353649000460349`", ",", "1.3495682650002878`"}], 
             "}"}], ",", "177.28976402830634`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29508966314603813`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.875687281178761`", ",", "1.0642572209501147`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.44749855183218`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2943378479465851`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.635547121943515`", ",", "1.057748727360387`"}], "}"}],
             ",", 
            RowBox[{"-", "177.71106158631576`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29825967157468253`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.881209576075601`", ",", "0.9157210836573269`"}], 
             "}"}], ",", "170.2920599470966`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29752346497243076`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.673185502654298`", ",", "0.9513089607076581`"}], 
             "}"}], ",", "170.13653498805604`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009507337784272946`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.453084848827884`", ",", "0.3971828149358141`"}], 
             "}"}], ",", 
            RowBox[{"-", "93.72724851760502`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009473108443659173`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.439182291361847`", ",", "0.18377233116537578`"}], 
             "}"}], ",", 
            RowBox[{"-", "91.12537676247729`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1867445417829799`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.364102736692175`", ",", "1.2549358388771608`"}], 
             "}"}], ",", "61.93259731022847`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18628405188088945`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.422826032225031`", ",", "1.365065552474647`"}], "}"}],
             ",", "61.84311480447392`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.2178579440909103`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.285753978708785`", ",", "1.4070605913421486`"}], 
             "}"}], ",", "128.07240235947125`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.1221576234966264`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.174197682692963`", ",", "1.5494748272910812`"}], 
             "}"}], ",", "137.04019877930722`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09285415661781521`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.036656461720002`", ",", "1.6775537955970146`"}], 
             "}"}], ",", 
            RowBox[{"-", "149.3179170100164`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1677785615575076`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.114937969488056`", ",", "1.3969433197743022`"}], 
             "}"}], ",", 
            RowBox[{"-", "165.78779259128592`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008747945436807911`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.055094413422918`", ",", "1.2366335665228163`"}], 
             "}"}], ",", 
            RowBox[{"-", "99.64798754204313`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008724604657246544`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.036231460668536`", ",", "1.1256743437386747`"}], 
             "}"}], ",", 
            RowBox[{"-", "98.50223236998023`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009454276455358273`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.853458526119032`", ",", "0.5885561136172155`"}], 
             "}"}], ",", 
            RowBox[{"-", "50.65655391080425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009429612362099857`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.87794882615238`", ",", "0.5586810616236928`"}], "}"}],
             ",", 
            RowBox[{"-", "49.68956524251557`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16812038719283007`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.615981264787904`", ",", "0.7888893143257181`"}], 
             "}"}], ",", "168.87106101281742`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16687660816130284`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.369808577478939`", ",", "0.8373156111747763`"}], 
             "}"}], ",", "173.7476175387645`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.200420238756517`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.655926041426688`", ",", 
              RowBox[{"-", "0.8105216709669426`"}]}], "}"}], ",", 
            RowBox[{"-", "157.6844383578246`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19935506263517028`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.593039866070804`", ",", 
              RowBox[{"-", "0.836333126310018`"}]}], "}"}], ",", 
            RowBox[{"-", "153.7851467154957`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05949558170002157`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.813642807021752`", ",", "0.8598979484814954`"}], 
             "}"}], ",", "152.45933143859418`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05934870297569491`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.672920885593271`", ",", "0.9332801431723884`"}], 
             "}"}], ",", "152.62293929037097`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09640871569417986`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.382123401893994`", ",", "0.6275245760517915`"}], 
             "}"}], ",", "6.517466163417426`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0948712557500937`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.382254773277838`", ",", "0.6275395844991265`"}], 
             "}"}], ",", 
            RowBox[{"-", "0.5640206175443543`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05559620806845538`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.841682554284794`", ",", "0.9015937670123577`"}], 
             "}"}], ",", "146.8578423345198`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.055201250034786715`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.674320094655733`", ",", "1.010871541214962`"}], "}"}],
             ",", "151.6171356378731`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013459522400967618`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.712539000534084`", ",", "0.9118442775173976`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.498653762735`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013295512126931313`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.64849501488751`", ",", "0.8916496320041639`"}], "}"}],
             ",", 
            RowBox[{"-", "168.80231218943698`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00826879541395185`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.622717590410879`", ",", "0.8184888024532366`"}], 
             "}"}], ",", 
            RowBox[{"-", "111.85514985998898`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008248378369815169`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.563056991588514`", ",", "0.6697420551766223`"}], 
             "}"}], ",", 
            RowBox[{"-", "112.02727014945185`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01302447129658328`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.02114616024396`", ",", "1.3648656312182066`"}], "}"}],
             ",", 
            RowBox[{"-", "71.89472713183234`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01201864247176827`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.051328059475833`", ",", "1.2725527638858225`"}], 
             "}"}], ",", 
            RowBox[{"-", "59.658165183703034`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.415558756770056`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.10158126102411`", ",", "1.6554902335190946`"}], "}"}],
             ",", "76.2458455036211`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.219363342218478`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.111402240816899`", ",", "1.6956126639955889`"}], 
             "}"}], ",", "65.96996389556105`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18747791291442026`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.184072372672007`", ",", "1.8586024464312514`"}], 
             "}"}], ",", 
            RowBox[{"-", "2.1152675779987717`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008330159073777816`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.36240697690967`", ",", "1.8520156282570719`"}], "}"}],
             ",", 
            RowBox[{"-", "70.20049905155858`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012948197299062807`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8798616310272624`", ",", "1.4511061084650112`"}], 
             "}"}], ",", 
            RowBox[{"-", "135.61358186092468`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012907460466375639`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.833820172339405`", ",", "1.4060403563564783`"}], 
             "}"}], ",", 
            RowBox[{"-", "133.5611683243165`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08655418072123228`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.637302678486836`", ",", "1.0169603213082352`"}], 
             "}"}], ",", 
            RowBox[{"-", "8.596345390446183`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08632282556897239`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.858767059798419`", ",", "0.9834814317062208`"}], 
             "}"}], ",", 
            RowBox[{"-", "7.4373994198669555`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10126434327769537`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.879946877019573`", ",", "1.1112905707736813`"}], 
             "}"}], ",", "172.50127125300932`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09949505690056722`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.630680122811341`", ",", "1.1441015350696153`"}], 
             "}"}], ",", "179.85060228406243`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07331833380489744`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5841933507179515`", ",", "0.3253409192139103`"}], 
             "}"}], ",", "1.0120460053594813`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07275867915652669`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.626714297149007`", ",", "0.32609206755954295`"}], 
             "}"}], ",", 
            RowBox[{"-", "3.954636338716895`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27769873481583474`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.628638705595014`", ",", "1.3647266179686772`"}], 
             "}"}], ",", "117.80640162705188`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2768719222552171`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.628289473465782`", ",", "1.3653888162929944`"}], 
             "}"}], ",", "119.5995839218644`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014975335166352324`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8418719011631226`", ",", 
              RowBox[{"-", "0.4257345527276301`"}]}], "}"}], ",", 
            RowBox[{"-", "156.97042609448138`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014936601135951322`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6865263052883464`", ",", 
              RowBox[{"-", "0.4917694976009767`"}]}], "}"}], ",", 
            RowBox[{"-", "157.86058497814227`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01296517541926786`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6801569042007625`", ",", 
              RowBox[{"-", "1.8359346973849022`"}]}], "}"}], ",", 
            RowBox[{"-", "123.51883684825455`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012926979602887445`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.628435784582611`", ",", 
              RowBox[{"-", "1.9140209948334994`"}]}], "}"}], ",", 
            RowBox[{"-", "125.25874934305428`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009236915279233931`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.6059430288850525`", ",", 
              RowBox[{"-", "1.7364162622695076`"}]}], "}"}], ",", 
            RowBox[{"-", "108.83082910182166`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009212778928076043`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.580392820833384`", ",", 
              RowBox[{"-", "1.8113373396360717`"}]}], "}"}], ",", 
            RowBox[{"-", "109.81178758688053`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1288157913514856`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.698922125620347`", ",", 
              RowBox[{"-", "1.8758034494156233`"}]}], "}"}], ",", 
            RowBox[{"-", "44.80630883767494`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11020071862710995`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.1387084261467875`", ",", 
              RowBox[{"-", "2.3126263188259486`"}]}], "}"}], ",", 
            RowBox[{"-", "30.069264496571073`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015925022623388713`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.275115027170251`", ",", 
              RowBox[{"-", "2.39160072839328`"}]}], "}"}], ",", 
            "26.67132499101252`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008110396898927022`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.864952223193942`", ",", 
              RowBox[{"-", "1.8532666557235384`"}]}], "}"}], ",", 
            "19.218211426471964`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008078540266813651`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.087955228348104`", ",", 
              RowBox[{"-", "1.7755293071353104`"}]}], "}"}], ",", 
            "16.300089767938356`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011138660727445219`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.446986340259031`", ",", 
              RowBox[{"-", "1.2858947444894115`"}]}], "}"}], ",", 
            RowBox[{"-", "3.92995643587086`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011110705312078101`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.634975538592947`", ",", 
              RowBox[{"-", "1.2988093106254066`"}]}], "}"}], ",", 
            RowBox[{"-", "3.386361281286148`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17862020868966294`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.854644651235509`", ",", 
              RowBox[{"-", "1.0547381333962738`"}]}], "}"}], ",", 
            RowBox[{"-", "158.43991586898292`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17803973008588353`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3777554314599088`", ",", 
              RowBox[{"-", "1.2431677270440258`"}]}], "}"}], ",", 
            RowBox[{"-", "160.63342486310583`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06471109920873179`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6037690263909803`", ",", "0.23251298497403247`"}], 
             "}"}], ",", "169.7190932062798`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06453786688081013`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4006273323013927`", ",", "0.2693601613068275`"}], 
             "}"}], ",", "170.88905180878817`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024627353653903755`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.955364090593181`", ",", "1.6592345551760308`"}], 
             "}"}], ",", "79.14580498196977`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024563707780477777`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.990563917608184`", ",", "1.8428149348015401`"}], 
             "}"}], ",", "78.26349505702298`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00883834873261919`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.267562956917228`", ",", "1.4159252596804341`"}], 
             "}"}], ",", "44.727203963747314`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008784764056170971`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.3414793017053155`", ",", "1.4891410751493424`"}], 
             "}"}], ",", "40.43189171315737`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23025381708549322`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.660008727854707`", ",", 
              RowBox[{"-", "0.8391463939340966`"}]}], "}"}], ",", 
            RowBox[{"-", "168.73497389979912`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22443726071711514`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.54432612307239`", ",", 
              RowBox[{"-", "0.8621886350649688`"}]}], "}"}], ",", 
            RowBox[{"-", "160.27597129655464`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013976453203989363`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3465003261523547`", ",", "2.0016919364102153`"}], 
             "}"}], ",", "101.48101507508498`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013922465758562676`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.322593379298374`", ",", "2.1193979559844265`"}], 
             "}"}], ",", "104.34008581987273`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015122069281034293`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0948678087528037`", ",", "1.28922010582574`"}], "}"}],
             ",", "118.14728937950176`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015082284760137343`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.057027867898407`", ",", "1.3599474591186946`"}], 
             "}"}], ",", "117.10986224234333`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013288356287742805`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.030548797235382`", ",", "0.3379380311434561`"}], 
             "}"}], ",", 
            RowBox[{"-", "108.87095741815713`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013251577968552922`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9734752681722851`", ",", "0.1709637584621732`"}], 
             "}"}], ",", 
            RowBox[{"-", "107.4792387480908`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011355094425544969`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.14196656423911`", ",", "3.043244514731989`"}], "}"}], 
            ",", "69.89255774754704`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011326642907984163`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.170744503251183`", ",", "3.121852289530835`"}], "}"}],
             ",", "70.41066222185908`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030576773362099727`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0356327260310234`", ",", "2.687957121083041`"}], 
             "}"}], ",", "82.445455541619`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030492686970856185`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0616699245015138`", ",", "2.8842848435931794`"}], 
             "}"}], ",", "83.79702819751033`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00833797408153295`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.392586079497609`", ",", 
              RowBox[{"-", "2.3630622067704063`"}]}], "}"}], ",", 
            RowBox[{"-", "84.03521824780522`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008252250294128315`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.394983681095318`", ",", 
              RowBox[{"-", "2.386009537355096`"}]}], "}"}], ",", 
            RowBox[{"-", "78.2172429447636`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03161216749070068`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8588435170927085`", ",", 
              RowBox[{"-", "2.274866792392901`"}]}], "}"}], ",", 
            RowBox[{"-", "20.613744096597223`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030314999018646115`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9627488659543375`", ",", 
              RowBox[{"-", "2.3139506941956443`"}]}], "}"}], ",", 
            RowBox[{"-", "30.62333579868526`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009365273698826688`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8201946499746575`", ",", 
              RowBox[{"-", "1.8649612329970076`"}]}], "}"}], ",", 
            "11.332669243153088`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009338396665339768`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.108523759879753`", ",", 
              RowBox[{"-", "1.8071764067739187`"}]}], "}"}], ",", 
            "12.934439677470689`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2588774214069859`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3601829633056144`", ",", 
              RowBox[{"-", "2.072207955493204`"}]}], "}"}], ",", 
            RowBox[{"-", "149.7425895945289`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.257487750986994`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3453218671299387`", ",", 
              RowBox[{"-", "2.0808772665983004`"}]}], "}"}], ",", 
            RowBox[{"-", "145.8128075802196`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00885509576718143`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.37955614645619`", ",", 
              RowBox[{"-", "0.5501416006647808`"}]}], "}"}], ",", 
            RowBox[{"-", "169.04317243793918`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008782603006572872`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3117054913161614`", ",", 
              RowBox[{"-", "0.563277382484079`"}]}], "}"}], ",", 
            RowBox[{"-", "163.87559192237472`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2133241493307555`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.187360460058735`", ",", "0.8624833169471092`"}], 
             "}"}], ",", "159.99800056865692`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21263547278197578`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.117252386810888`", ",", "0.8880033394673086`"}], 
             "}"}], ",", "157.83279515707858`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010506671303630892`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.865402790228393`", ",", "1.7961382788338658`"}], 
             "}"}], ",", "18.456849310100335`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010478898418429052`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3413858183556036`", ",", "1.955001466937924`"}], 
             "}"}], ",", "19.53182824456148`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010543338891818188`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9862592797803313`", ",", "1.3481438736691491`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.76463926690803`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010517277329279352`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9406505601097632`", ",", "1.3331172926123287`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.9820424688601`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4079517230929995`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8677830330422824`", ",", "1.489527299309895`"}], 
             "}"}], ",", "121.58622659726507`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4065136136684532`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7888325516111925`", ",", "1.6179286271643638`"}], 
             "}"}], ",", "119.06463955031148`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010031209033109072`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9779876884070617`", ",", "1.6374489948889326`"}], 
             "}"}], ",", "44.937092461438276`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009860713068529951`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.122485381220374`", ",", "1.7816297349162387`"}], 
             "}"}], ",", "37.668934257513996`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00945814085981273`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.136273110507371`", ",", 
              RowBox[{"-", "0.3775728539432791`"}]}], "}"}], ",", 
            RowBox[{"-", "154.01973757698917`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009434397517409005`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.134336033072358`", ",", 
              RowBox[{"-", "0.3785168038398527`"}]}], "}"}], ",", 
            RowBox[{"-", "153.47257921722118`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02820164916367357`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.621919019136533`", ",", 
              RowBox[{"-", "0.6819973016660933`"}]}], "}"}], ",", 
            RowBox[{"-", "168.12141194941753`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028130144925547763`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.417776698132674`", ",", 
              RowBox[{"-", "0.7249371646637658`"}]}], "}"}], ",", 
            RowBox[{"-", "167.44119973592953`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013586179523650327`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.950544740297555`", ",", 
              RowBox[{"-", "0.8794548318219492`"}]}], "}"}], ",", 
            RowBox[{"-", "176.5161978609394`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013540244654536173`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.650177889460393`", ",", 
              RowBox[{"-", "0.8977408237269249`"}]}], "}"}], ",", 
            RowBox[{"-", "174.15901685406703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009521553992527193`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.258025463924768`", ",", 
              RowBox[{"-", "0.11781453791912785`"}]}], "}"}], ",", 
            "154.68015910717952`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009497200546697086`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.169782539508914`", ",", 
              RowBox[{"-", "0.07606490709734837`"}]}], "}"}], ",", 
            "153.90118970293483`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1014009879930647`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.353433065589417`", ",", 
              RowBox[{"-", "0.6194021000598979`"}]}], "}"}], ",", 
            "29.952120094688528`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10106380707993437`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.385488297624597`", ",", 
              RowBox[{"-", "0.6009307024520898`"}]}], "}"}], ",", 
            "32.24154623513792`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020256445487972553`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.224219046840725`", ",", 
              RowBox[{"-", "1.1355461267955338`"}]}], "}"}], ",", 
            "76.70304647446208`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020187025190116295`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.269024531048093`", ",", 
              RowBox[{"-", "0.9459605645839262`"}]}], "}"}], ",", 
            "79.11435472900831`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.259437576608702`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.404873413023072`", ",", 
              RowBox[{"-", "1.354943595196123`"}]}], "}"}], ",", 
            RowBox[{"-", "53.35287475089647`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.2453551903496605`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.416265530500333`", ",", 
              RowBox[{"-", "1.3702567653724946`"}]}], "}"}], ",", 
            RowBox[{"-", "54.52427641114215`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014044680021468097`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5948414737607`", ",", 
              RowBox[{"-", "1.6208355140056565`"}]}], "}"}], ",", 
            "147.57525305149824`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020101898600125026`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.120685522106613`", ",", 
              RowBox[{"-", "1.3520295228243422`"}]}], "}"}], ",", 
            "176.59120402374498`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020045701722223426`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9146782862872165`", ",", 
              RowBox[{"-", "1.3397586999505606`"}]}], "}"}], ",", 
            "175.13872589277725`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09727748565061539`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.750245482442702`", ",", 
              RowBox[{"-", "1.435074784336653`"}]}], "}"}], ",", 
            RowBox[{"-", "136.9099729084581`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.096802406225178`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.676997172033755`", ",", 
              RowBox[{"-", "1.5035954304728814`"}]}], "}"}], ",", 
            RowBox[{"-", "140.5473624858018`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015185309677946384`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.614645344029233`", ",", 
              RowBox[{"-", "0.7065919626854019`"}]}], "}"}], ",", 
            "172.81740800837588`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014311953167502712`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.536595683944297`", ",", 
              RowBox[{"-", "0.696756088761932`"}]}], "}"}], ",", 
            "161.65158439293083`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019139285280676866`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5469469278676025`", ",", "0.6368635855234813`"}], 
             "}"}], ",", "104.01522702849313`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01909127551823867`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.49118398859179`", ",", "0.8602635747106462`"}], "}"}],
             ",", "103.47963383461301`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02666006551827676`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.881204474904297`", ",", "1.3242995202150794`"}], 
             "}"}], ",", "76.36998956268805`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02658880912907812`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8980403815701745`", ",", "1.3937316749718944`"}], 
             "}"}], ",", "75.21152245114669`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1124798784388572`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.5969460739394234`", ",", "0.25932011660617466`"}], 
             "}"}], ",", "169.26232329204885`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1121465306727456`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.46026753674279`", ",", "0.28523889220537657`"}], 
             "}"}], ",", "171.03236488019266`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04334005395830969`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.892604669438865`", ",", 
              RowBox[{"-", "0.6189034417401148`"}]}], "}"}], ",", 
            RowBox[{"-", "122.6976368396943`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043206165761176765`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.892404349855441`", ",", 
              RowBox[{"-", "0.6192154998693977`"}]}], "}"}], ",", 
            RowBox[{"-", "124.66725627349666`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023411402492234893`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.594092515281308`", ",", 
              RowBox[{"-", "1.1510887972667576`"}]}], "}"}], ",", 
            RowBox[{"-", "90.63693358213358`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02334105314434112`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.591763735583777`", ",", 
              RowBox[{"-", "1.3605670779720842`"}]}], "}"}], ",", 
            RowBox[{"-", "92.47543965486314`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012103739927135081`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.089186185011931`", ",", 
              RowBox[{"-", "0.46412778297490015`"}]}], "}"}], ",", 
            RowBox[{"-", "52.710498982758516`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012060594818937327`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.205953928125927`", ",", 
              RowBox[{"-", "0.6174656362047188`"}]}], "}"}], ",", 
            RowBox[{"-", "55.274633312923854`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009745104011571878`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.16874912920781`", ",", "0.7568037859242456`"}], "}"}],
             ",", "124.6509030364968`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009720889215466981`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.128686699457673`", ",", "0.8147673432488302`"}], 
             "}"}], ",", "124.28708101248907`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016329667455358837`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.962721548274071`", ",", "0.6105183577215063`"}], 
             "}"}], ",", "89.66078352157378`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01628091859219892`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.964111540215825`", ",", "0.845293925448589`"}], "}"}],
             ",", "87.85442859951237`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.13376973240683207`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.39375033838211`", ",", 
              RowBox[{"-", "0.12084842573426252`"}]}], "}"}], ",", 
            RowBox[{"-", "86.16330810119763`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1333275609806711`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.408684917542238`", ",", 
              RowBox[{"-", "0.34354261569780986`"}]}], "}"}], ",", 
            RowBox[{"-", "83.89850635921084`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.6515889036243343`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5496058187056825`", ",", 
              RowBox[{"-", "0.19014294206542603`"}]}], "}"}], ",", 
            RowBox[{"-", "14.559536722974844`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.642568569406351`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.600626168023581`", ",", 
              RowBox[{"-", "0.20339427849454242`"}]}], "}"}], ",", 
            RowBox[{"-", "14.367874260730193`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008998051745461854`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.882934929861941`", ",", 
              RowBox[{"-", "0.2757101473357457`"}]}], "}"}], ",", 
            "161.96461467083756`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12478348207262034`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.664545060342192`", ",", 
              RowBox[{"-", "0.06412059693375713`"}]}], "}"}], ",", 
            "57.04423465524786`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12432259782539284`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.733352346359235`", ",", "0.0420126293025313`"}], 
             "}"}], ",", "59.74127413866241`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01614561899986869`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.543886199459315`", ",", 
              RowBox[{"-", "0.22501170017298794`"}]}], "}"}], ",", 
            RowBox[{"-", "152.72235399254555`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016053205872168536`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.379552487833043`", ",", 
              RowBox[{"-", "0.3097494748182285`"}]}], "}"}], ",", 
            RowBox[{"-", "156.84609419815763`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00967498409481887`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.819217854866354`", ",", "0.46843169438588755`"}], 
             "}"}], ",", "157.4850223737415`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009634840293621137`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.667336484476603`", ",", "0.5313895380341801`"}], 
             "}"}], ",", "160.59215196051005`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2950706688247494`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8256738210161805`", ",", 
              RowBox[{"-", "0.3516744978920914`"}]}], "}"}], ",", 
            RowBox[{"-", "93.47139619378231`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2895606635512515`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.825576837079949`", ",", 
              RowBox[{"-", "0.35327326938085934`"}]}], "}"}], ",", 
            RowBox[{"-", "85.9254164851212`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2951346416981715`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.0967852982839235`", ",", "0.326322821662418`"}], 
             "}"}], ",", 
            RowBox[{"-", "81.03577765124211`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29212706276233985`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1057991123948865`", ",", "0.2691809260645134`"}], 
             "}"}], ",", 
            RowBox[{"-", "75.24304676421988`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3468843872432643`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.192065638887377`", ",", "1.1046249733468794`"}], 
             "}"}], ",", 
            RowBox[{"-", "60.6442911286852`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.34500226009211427`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.277988308189711`", ",", "0.951860803297774`"}], "}"}],
             ",", 
            RowBox[{"-", "64.60664134827591`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "74.20067066856427`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.353649000460349`", ",", "1.3495682650002878`"}], 
             "}"}], ",", "60.057375657516175`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "73.99593692078204`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3775247299827535`", ",", "1.391018043860573`"}], 
             "}"}], ",", "58.68481766788946`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20416884847466557`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.543884862887944`", ",", "1.6644691373106297`"}], 
             "}"}], ",", 
            RowBox[{"-", "95.55771005859022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.34367846999673873`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.060538310049242`", ",", "1.3634434958074577`"}], 
             "}"}], ",", 
            RowBox[{"-", "179.24095755628215`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.34210884544200904`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.863122473350959`", ",", "1.3608280192880524`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.8168671957885`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2935879481856063`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.295198604732274`", ",", "1.0441447323620774`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.97462462079935`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.292540606754237`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.189895363322487`", ",", "1.0385792570356913`"}], 
             "}"}], ",", 
            RowBox[{"-", "174.40752902907587`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2967890755791845`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.34378759472657`", ",", "1.0085816823173743`"}], "}"}],
             ",", "169.98101002900844`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29578886132670673`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.166006433166219`", ",", "1.0399900566600764`"}], 
             "}"}], ",", "172.32517003396833`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00943900233920104`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.433388240338392`", ",", 
              RowBox[{"-", "0.11117953659543567`"}]}], "}"}], ",", 
            RowBox[{"-", "88.52350500734958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009385218372845817`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.441161199556236`", ",", 
              RowBox[{"-", "0.41274450725640877`"}]}], "}"}], ",", 
            RowBox[{"-", "84.41325719690103`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18582469749230796`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.57323765724591`", ",", "1.646089620359747`"}], "}"}], 
            ",", "61.75363229871936`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18464906523227212`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8197075233683275`", ",", "2.104862101175398`"}], 
             "}"}], ",", "66.17472957299023`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09570032059428298`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.174197682692963`", ",", "1.5494748272910812`"}], 
             "}"}], ",", "72.36611098846686`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09543951924306254`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.186069607961884`", ",", "1.5868232171547578`"}], 
             "}"}], ",", "71.07315873438571`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.0293034668788104`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.036656461720002`", ",", "1.6775537955970146`"}], 
             "}"}], ",", "146.00799519914304`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.0213846701845166`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.625588209786038`", ",", "1.954739381579031`"}], "}"}],
             ",", "145.02367496402`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0900926386418106`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.875024991266699`", ",", "1.5816524017169022`"}], 
             "}"}], ",", 
            RowBox[{"-", "140.35012059018047`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08730617473994005`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.386838787639893`", ",", "1.17707328175869`"}], "}"}], 
            ",", 
            RowBox[{"-", "149.44190112564692`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1597814174755787`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.995683381404745`", ",", "1.3667402332319012`"}], 
             "}"}], ",", 
            RowBox[{"-", "155.27384016322904`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15938277195077405`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.915766996348002`", ",", "1.329938586737978`"}], "}"}],
             ",", 
            RowBox[{"-", "155.71957428322997`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00870132615424994`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.987631729229609`", ",", "0.8005725958373693`"}], 
             "}"}], ",", 
            RowBox[{"-", "97.35647719791575`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008679869408958098`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.972639396864549`", ",", "0.6844474588014469`"}], 
             "}"}], ",", 
            RowBox[{"-", "97.26570875890071`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009405012611945766`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.082999887296782`", ",", "0.31698239836342923`"}], 
             "}"}], ",", 
            RowBox[{"-", "48.72257657422726`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009380802278179341`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.114516242080115`", ",", "0.28107956277846663`"}], 
             "}"}], ",", 
            RowBox[{"-", "47.878133048238155`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16564203078761788`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.132603163998297`", ",", "0.8633038107538517`"}], 
             "}"}], ",", "178.62417406471167`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16314354674625212`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0986847040374785`", ",", "0.8641184408836207`"}], 
             "}"}], ",", "171.70493080742685`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19829554761959076`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.359421295530483`", ",", 
              RowBox[{"-", "0.9513629506393492`"}]}], "}"}], ",", 
            RowBox[{"-", "149.8858550731669`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19571861166878693`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.158007169770423`", ",", 
              RowBox[{"-", "1.0681850780699813`"}]}], "}"}], ",", 
            RowBox[{"-", "156.3743121555345`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.059202186855767495`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.356816966072465`", ",", "1.0969723235612296`"}], 
             "}"}], ",", "152.78654714214778`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.058782329376076733`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.309155676079274`", ",", "1.1214810476127461`"}], 
             "}"}], ",", "148.03220095151582`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09335831416062572`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.560609031189221`", ",", "0.6257838054686258`"}], 
             "}"}], ",", 
            RowBox[{"-", "7.645507398506084`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09186435675773418`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.650244092232106`", ",", "0.6137514666967877`"}], 
             "}"}], ",", 
            RowBox[{"-", "0.5539459740844064`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05480909780125768`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.441039746564652`", ",", "1.1369156045927298`"}], 
             "}"}], ",", "156.37642894122624`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.054672499688885344`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.380342865732236`", ",", "1.1634631615150444`"}], 
             "}"}], ",", "155.9509014104194`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013133500391118599`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.415740315443308`", ",", "0.8455727215350262`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.105970616139`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0130814633506536`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3671627411517635`", ",", "0.8414132536242973`"}], 
             "}"}], ",", 
            RowBox[{"-", "172.157432765967`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008228011738788303`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.43041916475558`", ",", "0.3419012486380427`"}], "}"}],
             ",", 
            RowBox[{"-", "112.19939043891472`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008201918012840724`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.2825728163768`", ",", 
              RowBox[{"-", "0.02039618674577165`"}]}], "}"}], ",", 
            RowBox[{"-", "110.11159736536656`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011090489861349362`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.132844253351959`", ",", "1.133288049183445`"}], "}"}],
             ",", 
            RowBox[{"-", "47.42160323557383`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010209838977461047`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.826067983688849`", ",", "0.37884217744721077`"}], 
             "}"}], ",", 
            RowBox[{"-", "59.76252654200126`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19619541455157707`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.111402240816899`", ",", "1.6956126639955889`"}], 
             "}"}], ",", "123.77931376106082`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1953461399360908`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.028279707946844`", ",", "1.8198766499719492`"}], 
             "}"}], ",", "120.53038515358611`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "4.03188542930406`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.184072372672007`", ",", "1.8586024464312514`"}], 
             "}"}], ",", "55.69408228750106`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.997855174516123`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.320906309499774`", ",", "2.0591489993432495`"}], 
             "}"}], ",", "60.94902774196264`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033743029800710284`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.440837379378749`", ",", "2.2750571618804605`"}], 
             "}"}], ",", "160.70584453509753`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17914775384064238`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.36240697690967`", ",", "1.8520156282570719`"}], "}"}],
             ",", 
            RowBox[{"-", "12.391149186058719`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17853621610004966`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.6517446872126405`", ",", "1.7884474615593178`"}], 
             "}"}], ",", 
            RowBox[{"-", "14.78678744626888`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012866851797439688`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.599442986112421`", ",", "1.1595858165884754`"}], 
             "}"}], ",", 
            RowBox[{"-", "131.50875478770797`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012829652935721525`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.578820183056489`", ",", "1.1362831538007814`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.867181857826`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0860920888178808`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.162702661414744`", ",", "0.9438053337150264`"}], 
             "}"}], ",", 
            RowBox[{"-", "6.2784534492874124`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08394844419421651`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.19531982452479`", ",", "0.9402167803239352`"}], "}"}],
             ",", 
            RowBox[{"-", "14.693023096784009`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09775668342113808`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.395280740220098`", ",", "1.1447153361225655`"}], 
             "}"}], ",", 
            RowBox[{"-", "172.8000666848845`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09441775778949685`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.341300350337997`", ",", "1.1378960908493214`"}], 
             "}"}], ",", "177.7907752843749`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07220329647274092`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.891581672955386`", ",", "0.3077814576649613`"}], 
             "}"}], ",", 
            RowBox[{"-", "8.921318682792975`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07200528489167993`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.077006186780842`", ",", "0.27867406472608236`"}], 
             "}"}], ",", 
            RowBox[{"-", "10.255264261604577`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27604757142353303`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.503571201537513`", ",", "1.5849363906658709`"}], 
             "}"}], ",", "121.39276621667733`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27456430801567877`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.440374935192335`", ",", "1.6884978939291888`"}], 
             "}"}], ",", "125.32547286957923`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014897967291963146`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3847302367062975`", ",", 
              RowBox[{"-", "0.6145580846091381`"}]}], "}"}], ",", 
            RowBox[{"-", "158.75074386180273`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014813936086023877`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2969396556608648`", ",", 
              RowBox[{"-", "0.6486966623067383`"}]}], "}"}], ",", 
            RowBox[{"-", "154.6710480778327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012888896312588756`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.444584970458577`", ",", 
              RowBox[{"-", "2.17407961338191`"}]}], "}"}], ",", 
            RowBox[{"-", "126.99866183785443`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012667005466950527`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.401395049186998`", ",", 
              RowBox[{"-", "2.231397359948631`"}]}], "}"}], ",", 
            RowBox[{"-", "134.30448198138762`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009188705645965512`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.466710937071036`", ",", 
              RowBox[{"-", "2.126897206581193`"}]}], "}"}], ",", 
            RowBox[{"-", "110.79274607193865`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009059551948214036`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3881037401442144`", ",", 
              RowBox[{"-", "2.333911060676379`"}]}], "}"}], ",", 
            RowBox[{"-", "104.07811920384727`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0186150727243756`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.1387084261467875`", ",", 
              RowBox[{"-", "2.3126263188259486`"}]}], "}"}], ",", 
            RowBox[{"-", "72.07280964305113`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01855211657722031`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.225760321846037`", ",", 
              RowBox[{"-", "2.5817075108829264`"}]}], "}"}], ",", 
            RowBox[{"-", "74.43118110298312`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09427569600372121`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.275115027170251`", ",", 
              RowBox[{"-", "2.39160072839328`"}]}], "}"}], ",", 
            RowBox[{"-", "15.332220155467173`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09404150968592384`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.376396982301569`", ",", 
              RowBox[{"-", "2.4193695636149584`"}]}], "}"}], ",", 
            RowBox[{"-", "14.975295945507634`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0136237096309247`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.415962670666085`", ",", 
              RowBox[{"-", "2.3208500429481655`"}]}], "}"}], ",", 
            "41.40836933211641`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013542091135676294`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.324472913554798`", ",", 
              RowBox[{"-", "1.5196546351294475`"}]}], "}"}], ",", 
            "37.148430003614614`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008046808763596223`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.29649179032783`", ",", 
              RowBox[{"-", "1.714548594238228`"}]}], "}"}], ",", 
            "13.38196810940487`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011082820058220305`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.920460688392599`", ",", 
              RowBox[{"-", "1.3157020578048386`"}]}], "}"}], ",", 
            RowBox[{"-", "2.8427661267000963`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01105083673751191`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.111345118114919`", ",", 
              RowBox[{"-", "1.3251806879671508`"}]}], "}"}], ",", 
            RowBox[{"-", "1.2108801552004895`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17746113791708212`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.08320727731976`", ",", 
              RowBox[{"-", "1.3467014046111412`"}]}], "}"}], ",", 
            RowBox[{"-", "162.82693385722854`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1743001972414755`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.061437346951778`", ",", 
              RowBox[{"-", "1.3534291110795635`"}]}], "}"}], ",", 
            RowBox[{"-", "155.42074939647335`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06436509829774531`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0823029265595387`", ",", "0.3204098587077727`"}], 
             "}"}], ",", "172.05901041129593`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06381637470298848`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.875842145644434`", ",", "0.349209221182765`"}], "}"}],
             ",", "177.34257443950457`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024500226390709316`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.042768365054769`", ",", "2.0940943312606244`"}], 
             "}"}], ",", "77.38118513207493`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019871883268168213`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.073874337603238`", ",", "2.2330401138623297`"}], 
             "}"}], ",", "61.46822844173404`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008731504250084504`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.540441563317021`", ",", "1.658662282854143`"}], "}"}],
             ",", "36.13657946256744`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008670982290149471`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.625737115933364`", ",", "1.7209443206159765`"}], 
             "}"}], ",", "31.448630735019787`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21876763927652582`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3362231553334047`", ",", 
              RowBox[{"-", "0.9367987626976133`"}]}], "}"}], ",", 
            RowBox[{"-", "151.81696869331026`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2177562740382631`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1561864118925493`", ",", 
              RowBox[{"-", "1.033264979160073`"}]}], "}"}], ",", 
            RowBox[{"-", "155.28019284672456`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013868686852757673`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.258971730969517`", ",", "2.3682680267369927`"}], 
             "}"}], ",", "107.19915656466061`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013809783044862618`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1707816353633187`", ",", "2.6531790411572076`"}], 
             "}"}], ",", "104.0134376852345`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011298262679029265`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.261063463459581`", ",", "3.37564683895124`"}], "}"}], 
            ",", "70.92876669617111`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009928046162535169`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.317602229717479`", ",", "3.5391865573943955`"}], 
             "}"}], ",", "56.924628064479265`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030408831817915934`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0949401737714983`", ",", "3.1903948146437107`"}], 
             "}"}], ",", "85.14860085340219`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023802575426291463`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.100638485469136`", ",", "3.2575318555276516`"}], 
             "}"}], ",", "68.59384364830186`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008167407844043167`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4434141231202973`", ",", 
              RowBox[{"-", "2.618182018279854`"}]}], "}"}], ",", 
            RowBox[{"-", "72.39926764172202`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008129882585708893`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.507203505473403`", ",", 
              RowBox[{"-", "2.8192627123809926`"}]}], "}"}], ",", 
            RowBox[{"-", "75.84261907698817`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029071058343938503`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.131828495403569`", ",", 
              RowBox[{"-", "2.4140370798315542`"}]}], "}"}], ",", 
            RowBox[{"-", "40.6329275007733`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02840872678841154`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5736524678233232`", ",", 
              RowBox[{"-", "2.793166685997226`"}]}], "}"}], ",", 
            RowBox[{"-", "32.489843867872686`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009311596765202315`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4145530314090804`", ",", 
              RowBox[{"-", "1.7368927213868033`"}]}], "}"}], ",", 
            "14.53621011178783`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008892737407424346`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6175598185970927`", ",", 
              RowBox[{"-", "1.6842546957809021`"}]}], "}"}], ",", 
            "4.21884675598593`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2561055404059701`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.108755056526315`", ",", 
              RowBox[{"-", "2.2415706126908783`"}]}], "}"}], ",", 
            RowBox[{"-", "141.8830255659103`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25319534593083126`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0154221800005097`", ",", 
              RowBox[{"-", "2.3147975971414723`"}]}], "}"}], ",", 
            RowBox[{"-", "135.77933588385838`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010451198946883183`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.6650107297416685`", ",", "2.069805418458244`"}], 
             "}"}], ",", "20.60680717902263`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010424100011493862`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.063843397574225`", ",", "2.219770844068518`"}], "}"}],
             ",", "19.693925905551648`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010491280187039336`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6579620877190564`", ",", "1.2411682766713321`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.1994456708172`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01046206966147482`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1701167073340666`", ",", "1.0845330539530924`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.77130934518595`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4050805738602362`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.64293783700036`", ",", "1.8804307999132586`"}], "}"}],
             ",", "116.54305250335776`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4039430340575549`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.627751011380789`", ",", "1.9108336284133907`"}], 
             "}"}], ",", "118.02202676845064`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009693114947455218`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.297582025844731`", ",", "1.9168082156473396`"}], 
             "}"}], ",", "30.400776053589823`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009657370105847711`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.376064366816332`", ",", "1.9628549605429493`"}], 
             "}"}], ",", "27.70954729974`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009410713779352138`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8550571286116426`", ",", 
              RowBox[{"-", "0.5179270523033074`"}]}], "}"}], ",", 
            RowBox[{"-", "152.9254208574525`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009309332837770938`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.704601447193009`", ",", 
              RowBox[{"-", "0.5948348992005054`"}]}], "}"}], ",", 
            RowBox[{"-", "158.8767189675213`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0280588219837724`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.118371926014607`", ",", 
              RowBox[{"-", "0.7916360463911913`"}]}], "}"}], ",", 
            RowBox[{"-", "166.76098752244155`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.027285911110495113`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8896606650171655`", ",", 
              RowBox[{"-", "0.8454441103070542`"}]}], "}"}], ",", 
            RowBox[{"-", "175.48836913651695`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013494465091201462`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.364103526572395`", ",", 
              RowBox[{"-", "0.9270059505467887`"}]}], "}"}], ",", 
            RowBox[{"-", "171.8018358471945`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013459071982889852`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.161058715726155`", ",", 
              RowBox[{"-", "0.9562585138170068`"}]}], "}"}], ",", 
            RowBox[{"-", "170.78961842883695`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009472909390102981`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8600330983876`", ",", "0.07567180311158181`"}], "}"}],
             ",", "153.12222029869108`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00943571583997411`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.767312050664425`", ",", "0.12266667029449653`"}], 
             "}"}], ",", "150.20550125958533`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10072774736858355`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.626023718036561`", ",", 
              RowBox[{"-", "0.4492137686747103`"}]}], "}"}], ",", 
            "34.530972375587304`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09965710111863778`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.72673538027961`", ",", 
              RowBox[{"-", "0.3799163735965593`"}]}], "}"}], ",", 
            "40.44391151188273`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02011784280062146`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.334496159081358`", ",", 
              RowBox[{"-", "0.6055118865612469`"}]}], "}"}], ",", 
            "81.52566298355424`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019825809161793266`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.342652343122805`", ",", 
              RowBox[{"-", "0.5507698702134257`"}]}], "}"}], ",", 
            "74.71772836827125`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014082386259038229`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.416265530500333`", ",", 
              RowBox[{"-", "1.3702567653724946`"}]}], "}"}], ",", 
            "102.20479246597178`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013809884103596163`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.410231089580755`", ",", 
              RowBox[{"-", "1.3423576688021113`"}]}], "}"}], ",", 
            "109.8566598373605`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.231310510328191`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5948414737607`", ",", 
              RowBox[{"-", "1.6208355140056565`"}]}], "}"}], ",", 
            RowBox[{"-", "55.69567807138846`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.209477790497711`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.666658242611352`", ",", 
              RowBox[{"-", "1.7260979029653378`"}]}], "}"}], ",", 
            RowBox[{"-", "52.56884804118948`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02174160161941837`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.823226157153527`", ",", 
              RowBox[{"-", "1.930649643545257`"}]}], "}"}], ",", 
            "72.95668857684666`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014007074744085104`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.33511329940802`", ",", 
              RowBox[{"-", "1.4558495987725213`"}]}], "}"}], ",", 
            "146.40385139125195`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013918848862568497`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.307758015701156`", ",", 
              RowBox[{"-", "1.4376774421161653`"}]}], "}"}], ",", 
            "141.99576309346932`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019989661948342154`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.636570319863082`", ",", 
              RowBox[{"-", "1.3161057789349486`"}]}], "}"}], ",", 
            "173.686247761809`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019934029997220225`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.443841666585319`", ",", 
              RowBox[{"-", "1.2947815133730185`"}]}], "}"}], ",", 
            "172.26078320920752`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09632964697135038`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.489914395050555`", ",", 
              RowBox[{"-", "1.6575550106708106`"}]}], "}"}], ",", 
            RowBox[{"-", "144.1847520631457`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09597518380971577`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.32590391948947`", ",", 
              RowBox[{"-", "1.7759094604061625`"}]}], "}"}], ",", 
            RowBox[{"-", "146.86800062988058`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01348882622830329`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3712579755478105`", ",", 
              RowBox[{"-", "0.6419208330212081`"}]}], "}"}], ",", 
            "150.4857607774859`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013437340610427924`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1564270156805865`", ",", 
              RowBox[{"-", "0.520304833930549`"}]}], "}"}], ",", 
            "153.30222928298647`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019043386185443257`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.41150589720002`", ",", "1.1926671838836118`"}], "}"}],
             ",", "102.94404064072947`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015376806516702356`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.354979373850421`", ",", "1.4386060953362028`"}], 
             "}"}], ",", "86.94491153535182`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026517743192262206`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.966496046375656`", ",", "1.6530371043377268`"}], 
             "}"}], ",", "74.05305533960501`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026059017545362138`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.051610080316026`", ",", "1.9509057415606017`"}], 
             "}"}], ",", "81.37305675608414`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11181417082318149`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.151550991487545`", ",", "0.3339560449741226`"}], 
             "}"}], ",", "172.80240646833667`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11136090835582428`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5911278109148954`", ",", "0.40473004330086804`"}], 
             "}"}], ",", "169.77476240322196`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04307269117795738`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.727886367284384`", ",", 
              RowBox[{"-", "0.8570999932866199`"}]}], "}"}], ",", 
            RowBox[{"-", "126.63687570729903`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04274634605243103`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.664926309399225`", ",", 
              RowBox[{"-", "0.9417618929029387`"}]}], "}"}], ",", 
            RowBox[{"-", "131.58213426000492`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023270915190478556`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.578707936680302`", ",", 
              RowBox[{"-", "1.6625646141888275`"}]}], "}"}], ",", 
            RowBox[{"-", "94.31394572759326`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02319900721475991`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.567958176702326`", ",", 
              RowBox[{"-", "1.8050679294545213`"}]}], "}"}], ",", 
            RowBox[{"-", "96.28474086495915`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01201760350620879`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.366015524438264`", ",", 
              RowBox[{"-", "0.8484054132965815`"}]}], "}"}], ",", 
            RowBox[{"-", "57.83876764308892`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011981220273258689`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.390699751889108`", ",", 
              RowBox[{"-", "0.8876621830023901`"}]}], "}"}], ",", 
            RowBox[{"-", "55.964080144758455`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009696734588689125`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.940507675890693`", ",", "1.090761132862692`"}], "}"}],
             ",", "123.92325898847831`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009665706492078707`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.906650267057244`", ",", "1.1411021167992952`"}], 
             "}"}], ",", "126.05023824826934`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01623231525874228`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.975305451484222`", ",", "1.144078691628268`"}], "}"}],
             ",", "86.04807367745038`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016183740011021297`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.991925785457024`", ",", "1.3846612093021353`"}], 
             "}"}], ",", "87.86631700644675`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1328868511375348`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.438952443142733`", ",", 
              RowBox[{"-", "0.6266931228462786`"}]}], "}"}], ",", 
            RowBox[{"-", "81.63370461722407`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1324858712460342`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.470287291566744`", ",", 
              RowBox[{"-", "0.8397595192879214`"}]}], "}"}], ",", 
            RowBox[{"-", "79.7750057913425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009020334217983232`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.600626168023581`", ",", 
              RowBox[{"-", "0.20339427849454245`"}]}], "}"}], ",", 
            "169.4912992699466`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008270635030373886`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.538987903316532`", ",", 
              RowBox[{"-", "0.1919606194188685`"}]}], "}"}], ",", 
            "156.9780873057337`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.633570517660891`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.882934929861941`", ",", 
              RowBox[{"-", "0.2757101473357457`"}]}], "}"}], ",", 
            RowBox[{"-", "14.176211798487442`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.590303230054508`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.129580112651137`", ",", 
              RowBox[{"-", "0.3380120252934028`"}]}], "}"}], ",", 
            RowBox[{"-", "7.93863076458169`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0427520758696878`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.371022184652178`", ",", 
              RowBox[{"-", "0.3716808198235361`"}]}], "}"}], ",", 
            "82.97489039043516`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008975824316198333`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.605830110964485`", ",", 
              RowBox[{"-", "0.1854840910062472`"}]}], "}"}], ",", 
            "162.15627713308413`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008896853607336734`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.583808442483033`", ",", 
              RowBox[{"-", "0.17839516500404123`"}]}], "}"}], ",", 
            "156.78264751015834`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12386341584104354`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.8898389876045965`", ",", "0.310250823629456`"}], 
             "}"}], ",", "62.43831362207722`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12354873668994602`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.923392072908012`", ",", "0.37453662136558347`"}], 
             "}"}], ",", "61.73434159606469`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015961321692052968`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.125657458194816`", ",", 
              RowBox[{"-", "0.41832732762270464`"}]}], "}"}], ",", 
            RowBox[{"-", "160.96983440377`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01592172875302877`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.080637716367729`", ",", 
              RowBox[{"-", "0.43385538527627593`"}]}], "}"}], ",", 
            RowBox[{"-", "160.6466930788365`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009594863058565406`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.370259476906691`", ",", "0.6360526074102332`"}], 
             "}"}], ",", "163.6992815472785`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009552742827458662`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.342481872083101`", ",", "0.6441757256033335`"}], 
             "}"}], ",", "160.4040789067542`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2841535494198482`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.840886796903556`", ",", 
              RowBox[{"-", "0.5681950703666385`"}]}], "}"}], ",", 
            RowBox[{"-", "78.37943677646012`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27922743402544303`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.866761886098688`", ",", 
              RowBox[{"-", "0.694019397587685`"}]}], "}"}], ",", 
            RowBox[{"-", "85.70577638103478`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2891501326551351`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.149448457539012`", ",", "0.10347078033821677`"}], 
             "}"}], ",", 
            RowBox[{"-", "69.45031587719765`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2882825865942385`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.238157393487466`", ",", 
              RowBox[{"-", "0.13316628934978925`"}]}], "}"}], ",", 
            RowBox[{"-", "71.28136617987171`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.34313034499645995`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.390408105692144`", ",", "0.7150344162751484`"}], 
             "}"}], ",", 
            RowBox[{"-", "68.56899156786663`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.34225796082991805`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.419974370971576`", ",", "0.6397102217070847`"}], 
             "}"}], ",", 
            RowBox[{"-", "69.28163178729251`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20473374778223055`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3775247299827535`", ",", "1.391018043860573`"}], 
             "}"}], ",", 
            RowBox[{"-", "148.44521259525752`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20422639908246404`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.341954503215509`", ",", "1.3691737677150844`"}], 
             "}"}], ",", 
            RowBox[{"-", "148.14815294784609`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "73.79176807230742`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.543884862887944`", ",", "1.6644691373106297`"}], 
             "}"}], ",", "57.31225967826247`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "72.40537642210035`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.590368247538926`", ",", "1.7369085399029403`"}], 
             "}"}], ",", "49.748154432180556`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3603442758456952`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.738157029364659`", ",", "1.911472297130765`"}], "}"}],
             ",", 
            RowBox[{"-", "31.62938407433456`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02555799914688803`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.932904742021405`", ",", "1.7915249845889867`"}], 
             "}"}], ",", 
            RowBox[{"-", "113.00692258084968`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20360550783162337`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.512885661753796`", ",", "1.345893802643445`"}], "}"}],
             ",", 
            RowBox[{"-", "96.93026804821667`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20302652711350602`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.496842644551443`", ",", "1.2139061125156703`"}], 
             "}"}], ",", 
            RowBox[{"-", "95.37935071670816`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3405463895680606`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.57982954868064`", ",", "1.3401081333321252`"}], "}"}],
             ",", 
            RowBox[{"-", "172.39277683529502`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3396831595089225`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.359754642466834`", ",", "1.3107156326557965`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.71555091097684`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2914970015936533`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.883323261180942`", ",", "1.0085602719018325`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.84043343735198`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2907377575713962`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.67637167252377`", ",", "0.978887154996747`"}], "}"}], 
            ",", 
            RowBox[{"-", "172.79362645868295`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2947920179144425`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.858833762293857`", ",", "1.081384031628743`"}], "}"}],
             ",", "174.6693300389285`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2933092808604072`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6671547952838885`", ",", "1.099269044092898`"}], 
             "}"}], ",", "178.39877808417347`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009331740870556703`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.468322005052908`", ",", 
              RowBox[{"-", "0.690413361520776`"}]}], "}"}], ",", 
            RowBox[{"-", "80.3030093864523`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009308691707241247`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.4922024195277235`", ",", 
              RowBox[{"-", "0.830163736610522`"}]}], "}"}], ",", 
            RowBox[{"-", "80.48990514360716`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1834808706876179`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.902671251455068`", ",", "2.2927415826140214`"}], 
             "}"}], ",", "70.59582684726125`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18302503380982799`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.918722068695445`", ",", "2.3383097548097824`"}], 
             "}"}], ",", "70.2359262181389`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0951794286245165`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.287150018382918`", ",", "1.8816042394023436`"}], 
             "}"}], ",", "69.78020648030486`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0944078045663355`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.356777134173283`", ",", "2.0706436486224016`"}], 
             "}"}], ",", "74.91982218307797`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.013486573740879`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.434632846005179`", ",", "2.0883302110018165`"}], 
             "}"}], ",", "144.03935472889586`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.006058013087019`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.377379804505068`", ",", "2.129866926644981`"}], "}"}],
             ",", "143.9855297802709`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08460589303001663`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.216418216343868`", ",", "1.0764549847096392`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.53368166111326`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08439661581420521`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.161659475834462`", ",", "1.054922119649615`"}], "}"}],
             ",", 
            RowBox[{"-", "158.77545157257856`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15898512102382034`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.589348707423781`", ",", "1.1826893079768626`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.16530840323253`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12103378312832232`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.518103669062487`", ",", "1.1512149591504777`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.1642411214983`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028891974108604036`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.461139648466303`", ",", "1.1443863509174352`"}], 
             "}"}], ",", 
            RowBox[{"-", "153.40955666061444`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008658465574212347`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.934336026432902`", ",", "0.3840163419848044`"}], 
             "}"}], ",", 
            RowBox[{"-", "97.17494031987762`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008553618377615537`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.904292357145209`", ",", "0.1453567907485327`"}], 
             "}"}], ",", 
            RowBox[{"-", "90.8892706574212`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009356654266526165`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.269243314924368`", ",", "0.10997104284251004`"}], 
             "}"}], ",", 
            RowBox[{"-", "47.03368952224905`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009316071866090764`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3793113611938725`", ",", 
              RowBox[{"-", "0.008201718506410174`"}]}], "}"}], ",", 
            RowBox[{"-", "43.778225425488465`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16068274892785345`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.874911054466808`", ",", "0.8967438186105634`"}], 
             "}"}], ",", "164.7856875501421`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16028158611906965`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.67989996195875`", ",", "0.9497794729162449`"}], "}"}],
             ",", "164.32785678993352`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19317516410929736`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9514534114328006`", ",", 
              RowBox[{"-", "1.1585364994661662`"}]}], "}"}], ",", 
            RowBox[{"-", "162.86276923790209`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1922473465867297`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.88193336815691`", ",", 
              RowBox[{"-", "1.17997311673636`"}]}], "}"}], ",", 
            RowBox[{"-", "159.27792326821194`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.058365449494218354`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.0960916602283275`", ",", "1.2544517791728071`"}], 
             "}"}], ",", "143.277854760884`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.050483767032209075`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.959387763546078`", ",", "1.3564299397503847`"}], 
             "}"}], ",", "128.82748594619622`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09039430626384935`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.885969195992962`", ",", "0.6114723626851394`"}], 
             "}"}], ",", "6.537615450337324`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08664499971912516`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.2096543937444535`", ",", "0.6485669109904696`"}], 
             "}"}], ",", "16.582958055645328`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05453624201350348`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0774646795014835`", ",", "1.2986243324192273`"}], 
             "}"}], ",", "155.52537387961166`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.052956282245871136`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.01246476383433`", ",", "1.3282117434903686`"}], "}"}],
             ",", "146.64011992087444`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013029632489310678`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.096699440575585`", ",", "0.8041596610668059`"}], 
             "}"}], ",", 
            RowBox[{"-", "169.2088949157949`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012996707814092888`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.895066441242999`", ",", "0.7657285500947084`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.57083462606306`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00817590703866301`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.165712099764965`", ",", 
              RowBox[{"-", "0.3395329293425942`"}]}], "}"}], ",", 
            RowBox[{"-", "108.02380429181804`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008122867838280187`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.134211892678214`", ",", 
              RowBox[{"-", "0.4363437224036853`"}]}], "}"}], ",", 
            RowBox[{"-", "112.51855169838343`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0093991170136647`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9089651371026575`", ",", "0.23662464116783447`"}], 
             "}"}], ",", 
            RowBox[{"-", "72.10344984842796`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009356549167343929`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.947263191339536`", ",", "0.11802716847812038`"}], 
             "}"}], ",", 
            RowBox[{"-", "68.70651842993273`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19450054159088923`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.871677664455433`", ",", "2.085412051030004`"}], "}"}],
             ",", "117.28145654611117`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19212239195866207`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.821416870401075`", ",", "2.182867931844339`"}], "}"}],
             ",", "123.59486529394175`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03403025478793858`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.320906309499774`", ",", "2.0591489993432495`"}], 
             "}"}], ",", 
            RowBox[{"-", "33.55284359671073`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03392739336227029`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.3633446608630795`", ",", "2.0310033450348413`"}], 
             "}"}], ",", 
            RowBox[{"-", "31.68585586749268`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.9641121447154126`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.440837379378749`", ",", "2.2750571618804605`"}], 
             "}"}], ",", "66.20397319642422`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.949966292510657`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.472040952293647`", ",", "2.3458184217531763`"}], 
             "}"}], ",", "68.77223420362462`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014095373023719666`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.583810886957185`", ",", "2.633564846050262`"}], "}"}],
             ",", 
            RowBox[{"-", "157.26009069750867`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03345822907371311`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.2077278035136985`", ",", "2.356664280519256`"}], 
             "}"}], ",", "165.96078998955915`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03330863362328728`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.164941740114911`", ",", "2.3673631501433543`"}], 
             "}"}], ",", "162.60558641409048`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1779267659011658`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.897227864791424`", ",", "1.7236485654343994`"}], 
             "}"}], ",", 
            RowBox[{"-", "17.182425706479197`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17703044897375564`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.0821012120622076`", ",", "1.6664828386215795`"}], 
             "}"}], ",", 
            RowBox[{"-", "13.448168865552617`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012792561618205705`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.372007422895698`", ",", "0.8886497691912926`"}], 
             "}"}], ",", 
            RowBox[{"-", "128.22560892794382`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012759855650103761`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.350843936590856`", ",", "0.8617804958970844`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.00009387426755`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08185817511685006`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3821519417883765`", ",", "0.8912266074744308`"}], 
             "}"}], ",", 
            RowBox[{"-", "23.107592744280463`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08163762128954866`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.622852413903404`", ",", "0.7885214531920586`"}], 
             "}"}], ",", 
            RowBox[{"-", "21.891829929084864`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09119287473769258`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.156171182713343`", ",", "1.1450378863667876`"}], 
             "}"}], ",", "168.38161725363437`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08995559488743221`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.153496893426274`", ",", "1.1455877333499838`"}], 
             "}"}], ",", "174.99420717553255`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2730890145034687`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.278409306365115`", ",", "1.9170346464985808`"}], 
             "}"}], ",", "129.2581795224812`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2640567711830703`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.201877408545196`", ",", "2.010677723111943`"}], "}"}],
             ",", "138.56392078050183`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008733507688182688`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.055325171769849`", ",", "2.140045002997775`"}], "}"}],
             ",", 
            RowBox[{"-", "149.36459029356257`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014730378853710223`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.056035109608411`", ",", 
              RowBox[{"-", "0.7627206856098533`"}]}], "}"}], ",", 
            RowBox[{"-", "150.59135229386254`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014371721753125401`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9121687742877462`", ",", 
              RowBox[{"-", "0.8438138098897752`"}]}], "}"}], ",", 
            RowBox[{"-", "158.93718043375475`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012448934618477603`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.250973596039403`", ",", 
              RowBox[{"-", "2.385515828997722`"}]}], "}"}], ",", 
            RowBox[{"-", "141.6103021249209`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012388138816846063`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.141155509164145`", ",", 
              RowBox[{"-", "2.4725244263466686`"}]}], "}"}], ",", 
            RowBox[{"-", "145.2476014214346`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008932213596201732`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.334963802773455`", ",", 
              RowBox[{"-", "2.54581248256604`"}]}], "}"}], ",", 
            RowBox[{"-", "97.36349233575606`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008900564346459292`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.330985085163504`", ",", 
              RowBox[{"-", "2.576600492582407`"}]}], "}"}], ",", 
            RowBox[{"-", "99.90470929697905`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0184893733476573`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.290875589312144`", ",", 
              RowBox[{"-", "2.815415160633884`"}]}], "}"}], ",", 
            RowBox[{"-", "76.78955256291572`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018103943472246403`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.329760945790908`", ",", 
              RowBox[{"-", "2.9810678518678104`"}]}], "}"}], ",", 
            RowBox[{"-", "68.91496864211445`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09380790510057467`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.709709089406296`", ",", 
              RowBox[{"-", "2.50852625996953`"}]}], "}"}], ",", 
            RowBox[{"-", "14.618371735546045`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.092370580340839`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.863121642356406`", ",", 
              RowBox[{"-", "2.5485397701708075`"}]}], "}"}], ",", 
            RowBox[{"-", "7.65351903979394`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013460961609948455`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.529897953148777`", ",", 
              RowBox[{"-", "1.3640197673514542`"}]}], "}"}], ",", 
            "32.8884906751128`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013424507334127814`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.627798623920488`", ",", 
              RowBox[{"-", "1.3007128758044786`"}]}], "}"}], ",", 
            "31.63753452983537`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011018945715766977`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.41383491331418`", ",", 
              RowBox[{"-", "1.3315744125057838`"}]}], "}"}], ",", 
            "0.4210058162993401`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010972780041362174`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.641643426389006`", ",", 
              RowBox[{"-", "1.3299004596253732`"}]}], "}"}], ",", 
            "3.560899376028884`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1711955592926065`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.866810299806632`", ",", 
              RowBox[{"-", "1.442451087010559`"}]}], "}"}], ",", 
            RowBox[{"-", "148.01456493571828`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17032709141775013`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.419159283002482`", ",", 
              RowBox[{"-", "1.7220162844483655`"}]}], "}"}], ",", 
            RowBox[{"-", "151.77055552142684`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06327232907177721`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.605303873416047`", ",", "0.3617660148907954`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.37386153228672`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0629808306555191`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.300476159870274`", ",", "0.3477845166552455`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.92174987800684`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01611788145653439`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1481400246627125`", ",", "2.369639803748075`"}], 
             "}"}], ",", "45.55527175139333`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014107026393222017`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.367259958218387`", ",", "2.59304855884162`"}], "}"}], 
            ",", "31.434606317864716`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008610879834978966`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.811440419389403`", ",", "1.8345145594733225`"}], 
             "}"}], ",", "26.76068200747205`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00802715695922945`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.985714678248692`", ",", "1.922396766792331`"}], "}"}],
             ",", "38.51616765525809`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013751129416283115`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.114866436608288`", ",", "2.87721879600748`"}], "}"}], 
            ",", "100.82771880580843`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008092529737647243`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5716690254112136`", ",", 
              RowBox[{"-", "3.0748271865089367`"}]}], "}"}], ",", 
            RowBox[{"-", "79.28597051225451`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02776148526105819`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7370821451708434`", ",", 
              RowBox[{"-", "2.897242151157988`"}]}], "}"}], ",", 
            RowBox[{"-", "24.346760234972212`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02769265687691364`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9134400662329862`", ",", 
              RowBox[{"-", "2.9770441415149165`"}]}], "}"}], ",", 
            RowBox[{"-", "24.65664235205616`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008492719411232584`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.767724301347901`", ",", 
              RowBox[{"-", "1.6731776431117509`"}]}], "}"}], ",", 
            RowBox[{"-", "6.098516599816007`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00847171375373309`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.05889476923608`", ",", 
              RowBox[{"-", "1.7042871649611344`"}]}], "}"}], ",", 
            RowBox[{"-", "6.3378105672945635`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010432940465813664`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.847931087938611`", ",", "0.9721552211046295`"}], 
             "}"}], ",", 
            RowBox[{"-", "159.3431730195547`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01040388742614954`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.413079136039623`", ",", "0.8082127062037942`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.7723371645825`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4028086886731848`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5075177202934777`", ",", "2.1367499951643203`"}], 
             "}"}], ",", "119.5010010335433`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3936760800675188`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.45669261763965`", ",", "2.226579398023197`"}], "}"}], 
            ",", "127.6292662182781`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008925551155592217`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.332308243559459`", ",", "2.3879252482139632`"}], 
             "}"}], ",", 
            RowBox[{"-", "154.35676891624718`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009621757078802242`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.637363154484737`", ",", "2.100095438023548`"}], "}"}],
             ",", "25.018318545890313`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009555005386657857`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.669297845975176`", ",", "2.114999261324612`"}], "}"}],
             ",", "29.70883535266231`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009209044065769745`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4748039084685063`", ",", 
              RowBox[{"-", "0.6836136830671304`"}]}], "}"}], ",", 
            RowBox[{"-", "164.82801707759012`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009181855406227324`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3839809742100564`", ",", 
              RowBox[{"-", "0.7082420446104155`"}]}], "}"}], ",", 
            RowBox[{"-", "166.57888534747923`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026534290910731333`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7044712285073365`", ",", 
              RowBox[{"-", "0.8600566613744223`"}]}], "}"}], ",", 
            "175.7842492494077`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026363873661098672`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6789730870763115`", ",", 
              RowBox[{"-", "0.8581771474698388`"}]}], "}"}], ",", 
            RowBox[{"-", "179.7504135633546`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013423771703164444`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8477455568113452`", ",", 
              RowBox[{"-", "1.0070624334439158`"}]}], "}"}], ",", 
            RowBox[{"-", "169.77740101047976`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013341396477410651`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6896996591254667`", ",", 
              RowBox[{"-", "1.035563739061351`"}]}], "}"}], ",", 
            RowBox[{"-", "174.10852634213`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009398668323140206`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5831585270802275`", ",", "0.2281089080558495`"}], 
             "}"}], ",", "147.28878222047956`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009372900830459567`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.169421741661696`", ",", "0.4938376082481516`"}], 
             "}"}], ",", "148.6208400652999`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09859783488484906`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.888559142148566`", ",", 
              RowBox[{"-", "0.24197956494456557`"}]}], "}"}], ",", 
            "46.356850648178096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09823175194889973`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.960429604410104`", ",", 
              RowBox[{"-", "0.1666218653883848`"}]}], "}"}], ",", 
            "49.073158839067936`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019538014727289936`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.397588857222164`", ",", 
              RowBox[{"-", "0.3497113918811222`"}]}], "}"}], ",", 
            "67.90979375298828`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019489859011447036`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4653602179059835`", ",", 
              RowBox[{"-", "0.18272877991268882`"}]}], "}"}], ",", 
            "67.9286864545682`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01354265501930516`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.341191770303148`", ",", 
              RowBox[{"-", "1.1511869589989376`"}]}], "}"}], ",", 
            "117.50852720874924`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013492489451439745`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.236059442686831`", ",", 
              RowBox[{"-", "0.9493030010524817`"}]}], "}"}], ",", 
            "114.80075560744797`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021832719830477885`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.666658242611352`", ",", 
              RowBox[{"-", "1.7260979029653378`"}]}], "}"}], ",", 
            RowBox[{"-", "174.96755462902658`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021773850230226044`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3802853501272025`", ",", 
              RowBox[{"-", "1.7513157008069478`"}]}], "}"}], ",", 
            RowBox[{"-", "173.74649030519294`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.1877361888782945`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.823226157153527`", ",", 
              RowBox[{"-", "1.930649643545257`"}]}], "}"}], ",", 
            RowBox[{"-", "49.442018010990736`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.144021869820614`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.863139321655691`", ",", 
              RowBox[{"-", "1.9772863051707465`"}]}], "}"}], ",", 
            RowBox[{"-", "44.19175667322398`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04334596152732044`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.022041265246742`", ",", 
              RowBox[{"-", "2.1317672179825253`"}]}], "}"}], ",", 
            "55.61138267740907`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021650863687520526`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.898725692883722`", ",", 
              RowBox[{"-", "1.6843677998318296`"}]}], "}"}], ",", 
            "76.08351860704516`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021577543430302697`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.90382085132422`", ",", 
              RowBox[{"-", "1.663804587281601`"}]}], "}"}], ",", 
            "73.71981264722203`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013831178686387337`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.106842406878487`", ",", 
              RowBox[{"-", "1.2806810371144008`"}]}], "}"}], ",", 
            "137.5876747956866`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013751558650465753`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.978182730931252`", ",", 
              RowBox[{"-", "1.1631478453094757`"}]}], "}"}], ",", 
            "133.44678540841971`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019878552871827406`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.119803288382871`", ",", 
              RowBox[{"-", "1.2507439383342212`"}]}], "}"}], ",", 
            "170.83531865660606`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019829222934472254`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.918159887220145`", ",", 
              RowBox[{"-", "1.2182123801542875`"}]}], "}"}], ",", 
            "171.16856072295886`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09562202496234898`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.141316224293418`", ",", 
              RowBox[{"-", "1.8963876196907001`"}]}], "}"}], ",", 
            RowBox[{"-", "149.55124919661532`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09538462304405353`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.137011277797102`", ",", 
              RowBox[{"-", "1.8989182429969074`"}]}], "}"}], ",", 
            RowBox[{"-", "149.20691565097445`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013386051508454167`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.909899322736532`", ",", 
              RowBox[{"-", "0.39632633971432635`"}]}], "}"}], ",", 
            "156.11869778848666`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013337406193758792`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.826113860211855`", ",", 
              RowBox[{"-", "0.35923044026463574`"}]}], "}"}], ",", 
            "153.48184052393793`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012416183568909675`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.362812811651092`", ",", "1.5853767994063988`"}], 
             "}"}], ",", "70.94578242997433`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012172288816274489`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.367294364003814`", ",", "1.5983522727364021`"}], 
             "}"}], ",", "78.64241529489833`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02560822731052177`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.076721279197129`", ",", "2.116419354507405`"}], "}"}],
             ",", "88.69305817256333`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025250848033238505`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.078080013573787`", ",", "2.1759753661073877`"}], 
             "}"}], ",", "81.99908196305839`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11090948328405656`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3223761266728817`", ",", "0.45320832530609795`"}], 
             "}"}], ",", "166.7471183381069`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11062956885746135`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1763382067299815`", ",", "0.4876034430521933`"}], 
             "}"}], ",", "166.12504273234796`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04242247351772829`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.5046753581612275`", ",", 
              RowBox[{"-", "1.1223702829451243`"}]}], "}"}], ",", 
            RowBox[{"-", "136.52739281271073`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04214961154879319`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.415850647724226`", ",", 
              RowBox[{"-", "1.2065811131300719`"}]}], "}"}], ",", 
            RowBox[{"-", "140.99706139902042`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023127321437305916`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.532598262384877`", ",", 
              RowBox[{"-", "2.126137966057005`"}]}], "}"}], ",", 
            RowBox[{"-", "98.25553600232483`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02306989640155276`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5055179968266055`", ",", 
              RowBox[{"-", "2.312780313975175`"}]}], "}"}], ",", 
            RowBox[{"-", "98.60256193373222`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011944947190359654`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.558502686551672`", ",", 
              RowBox[{"-", "1.1361041517412096`"}]}], "}"}], ",", 
            RowBox[{"-", "54.089392646427996`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01188117040879269`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.641624614133751`", ",", 
              RowBox[{"-", "1.2508878463061588`"}]}], "}"}], ",", 
            RowBox[{"-", "50.17604286045781`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009634777680724621`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.7072547024128575`", ",", "1.4150411308714208`"}], 
             "}"}], ",", "128.17721750806052`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009602697319747713`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.655358674577875`", ",", "1.4810432047924222`"}], 
             "}"}], ",", "130.47210534108746`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016135310124861718`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.001660413572281`", ",", "1.6459442831685513`"}], 
             "}"}], ",", "89.68456033544354`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016090017719086726`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.003201024612557`", ",", "1.9257747184821181`"}], 
             "}"}], ",", "91.16114531570773`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1320861012927029`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.523807089318023`", ",", 
              RowBox[{"-", "1.1364673427704632`"}]}], "}"}], ",", 
            RowBox[{"-", "77.91630696546075`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1305648895256623`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.578043295185931`", ",", 
              RowBox[{"-", "1.389808408822895`"}]}], "}"}], ",", 
            RowBox[{"-", "84.05837841619474`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04326728760638411`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.129580112651137`", ",", 
              RowBox[{"-", "0.3380120252934028`"}]}], "}"}], ",", 
            RowBox[{"-", "92.61457088569271`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03955961226727557`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.112982644365966`", ",", 
              RowBox[{"-", "0.7014769110622621`"}]}], "}"}], ",", 
            RowBox[{"-", "79.98500138122373`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04224299909425905`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.400837322111133`", ",", 
              RowBox[{"-", "0.12973264472074342`"}]}], "}"}], ",", 
            "89.21247142434098`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04190150848794057`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.41846620837065`", ",", "1.152756908452858`"}], "}"}], 
            ",", "94.34391231043831`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00881857769514655`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.380663139819714`", ",", 
              RowBox[{"-", "0.09125414151794078`"}]}], "}"}], ",", 
            "151.40901788723272`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008789188700428658`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.153035130388449`", ",", "0.03280620533953821`"}], 
             "}"}], ",", "153.7075807309928`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12323485699175779`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.080195487154919`", ",", "0.6661707831798577`"}], 
             "}"}], ",", "61.03036957005266`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12279693417128397`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.087933797518698`", ",", "0.6801485323010795`"}], 
             "}"}], ",", "58.47806474206751`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015882234026474134`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.825637039936708`", ",", 
              RowBox[{"-", "0.5234217821511212`"}]}], "}"}], ",", 
            RowBox[{"-", "160.3235517539019`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015798993829612164`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.652425320378326`", ",", 
              RowBox[{"-", "0.5853602408820765`"}]}], "}"}], ",", 
            RowBox[{"-", "164.18011432960517`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009510807498820831`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.091004786913011`", ",", "0.7337025154327036`"}], 
             "}"}], ",", "157.10887626622977`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008799909207814084`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.850167520404469`", ",", "0.8353921946611623`"}], 
             "}"}], ",", "169.2238133974156`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2743867182782657`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.881191250877583`", ",", 
              RowBox[{"-", "0.8861829153964238`"}]}], "}"}], ",", 
            RowBox[{"-", "93.03211598560948`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.273103411309412`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.880779105955508`", ",", 
              RowBox[{"-", "0.8939636586819787`"}]}], "}"}], ",", 
            RowBox[{"-", "89.5317173032171`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28741764345854515`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.331543225782122`", ",", 
              RowBox[{"-", "0.40876767013290327`"}]}], "}"}], ",", 
            RowBox[{"-", "73.11241648254577`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28387955112004487`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.335812371414638`", ",", 
              RowBox[{"-", "0.42283003841443123`"}]}], "}"}], ",", 
            RowBox[{"-", "66.77961154555182`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3413877946372311`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.548191576253571`", ",", "0.30072193789939994`"}], 
             "}"}], ",", 
            RowBox[{"-", "69.9942720067184`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3160805289196947`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.581851068272584`", ",", "0.2082720020311536`"}], 
             "}"}], ",", 
            RowBox[{"-", "57.91003989472051`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023431224136205592`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.675336249011812`", ",", "0.05918582749291684`"}], 
             "}"}], ",", "4.42994113969281`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20372030763855262`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.055504511607546`", ",", "1.1912081890792554`"}], 
             "}"}], ",", 
            RowBox[{"-", "147.8510933004322`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19112322792901326`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.983547199606125`", ",", "1.1459838153379867`"}], 
             "}"}], ",", 
            RowBox[{"-", "136.42764059125062`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011818137153208003`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.863324853607964`", ",", "1.031608164437147`"}], "}"}],
             ",", 
            RowBox[{"-", "72.20874463888306`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.38639165020708`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.590368247538926`", ",", "1.7369085399029403`"}], 
             "}"}], ",", "123.56158769261376`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3806870656860148`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.503845818473073`", ",", "1.867324869727871`"}], "}"}],
             ",", "120.48285386545193`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "71.04503214625467`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.738157029364659`", ",", "1.911472297130765`"}], "}"}],
             ",", "42.184049186098626`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "70.78086318727493`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.066377499692184`", ",", "2.2089179863153836`"}], 
             "}"}], ",", "39.46237545796201`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26318669129995625`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.279619357017198`", ",", "2.3844659508650694`"}], 
             "}"}], ",", 
            RowBox[{"-", "92.11663331440805`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3347862766988072`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.932904742021405`", ",", "1.7915249845889867`"}], 
             "}"}], ",", 
            RowBox[{"-", "39.19348932041634`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2472027523639106`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.353376858084014`", ",", "1.4486758481567938`"}], 
             "}"}], ",", 
            RowBox[{"-", "50.83063242442032`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08183663146610168`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.471556087494077`", ",", "1.3036155224815655`"}], 
             "}"}], ",", 
            RowBox[{"-", "114.41652348547844`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02507781826033543`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.843510263820795`", ",", "1.5809955172019488`"}], 
             "}"}], ",", 
            RowBox[{"-", "120.57102782693131`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02483729915265739`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.742433758337944`", ",", "1.4098870680789055`"}], 
             "}"}], ",", 
            RowBox[{"-", "114.95122892952203`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20244919280798096`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.464985043809726`", ",", "0.8755865366445774`"}], 
             "}"}], ",", 
            RowBox[{"-", "93.82843338519893`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20193058988788956`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.449521888375906`", ",", "0.6445117044053194`"}], 
             "}"}], ",", 
            RowBox[{"-", "93.03334959314469`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.338822117598471`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.051399004163451`", ",", "1.2658168799102762`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.03832498665756`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3379617789708981`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.9381947141431874`", ",", "1.2479646951500007`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.73614988969695`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28998049110459306`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.348678083172981`", ",", "0.9374527928655113`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.7468194800147`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28837576716301516`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.146843271438939`", ",", "0.915336947551428`"}], "}"}],
             ",", 
            RowBox[{"-", "177.7689787322483`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2918340016377845`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.363292513720586`", ",", "1.1077631715094527`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.87177387058156`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2909368741618161`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.180835378956244`", ",", "1.1009827641266325`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.92492303516144`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009285699474774697`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.544058705200856`", ",", 
              RowBox[{"-", "1.1397096353662313`"}]}], "}"}], ",", 
            RowBox[{"-", "80.67680090076398`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009248513187835832`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.585515200998242`", ",", 
              RowBox[{"-", "1.3922282078274029`"}]}], "}"}], ",", 
            RowBox[{"-", "83.66245397692349`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1825703294057307`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.023459793219201`", ",", "2.629803328498619`"}], "}"}],
             ",", "69.87602558901452`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18050619647547012`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.10368184781019`", ",", "2.848736495535804`"}], "}"}], 
            ",", "75.96526405634826`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.093642436100311`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.42157587195393`", ",", "2.311129214326098`"}], "}"}], 
            ",", "80.05943788585101`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09341025455145736`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.428421427838424`", ",", "2.3501891946211466`"}], 
             "}"}], ",", "79.74774011460116`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "2.99864776461476`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.105130303168906`", ",", "2.32777283886906`"}], "}"}], 
            ",", "143.93170483163917`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.1357602968139426`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.973860009185009`", ",", "2.4233855638274715`"}], 
             "}"}], ",", "121.82554963819592`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.7055825790302638`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.911576044151911`", ",", "2.523739366932794`"}], "}"}],
             ",", "71.2001755020867`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4383378933279654`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.949638783966609`", ",", "2.6355490531667902`"}], 
             "}"}], ",", "20.574801365977343`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2723141336500434`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0602158577717615`", ",", "2.677056749400575`"}], 
             "}"}], ",", 
            RowBox[{"-", "30.050572770132085`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1691731162518658`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.162450707646214`", ",", "2.6179110515934285`"}], 
             "}"}], ",", 
            RowBox[{"-", "80.6759469062416`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10509753158513789`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.18158680607505`", ",", "2.5013606855070525`"}], "}"}],
             ",", 
            RowBox[{"-", "131.30132104235128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06529105445361282`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1036313876707275`", ",", "2.412630020912711`"}], 
             "}"}], ",", "178.07330482153893`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040561578634327314`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.985587288433265`", ",", "2.416601007334562`"}], "}"}],
             ",", "127.44793068542896`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025198576973167956`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.913771130957169`", ",", "2.5103699660752623`"}], 
             "}"}], ",", "76.82255654931893`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01565442724004946`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.9406965792129025`", ",", "2.6253708283945265`"}], 
             "}"}], ",", "26.197182413208786`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009725195691602856`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.046675111958901`", ",", "2.677512258130888`"}], "}"}],
             ",", 
            RowBox[{"-", "24.42819172290156`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08418785625681557`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.851961525503718`", ",", "0.934645522777102`"}], "}"}],
             ",", 
            RowBox[{"-", "159.0172214840484`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08396323415536613`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.424351740191631`", ",", "0.7706489542266817`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.16287053732864`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037951337895498025`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.518103669062487`", ",", "1.1512149591504777`"}], 
             "}"}], ",", "150.08214169935206`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03781867161783675`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.398525796497053`", ",", "1.2200248889577248`"}], 
             "}"}], ",", "147.5930349233807`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09214180901971822`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.461139648466303`", ",", "1.1443863509174352`"}], 
             "}"}], ",", "169.83682616023586`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09184567454461695`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3780326268083885`", ",", "1.1592845253399489`"}], 
             "}"}], ",", "171.98278147920334`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02199517103167116`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.409836078855042`", ",", "1.1187061391187512`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.4084893788803`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008450040797966445`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.900457870164396`", ",", 
              RowBox[{"-", "0.10167967351866608`"}]}], "}"}], ",", 
            RowBox[{"-", "84.6036009949648`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008428470707011719`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.924279037284031`", ",", 
              RowBox[{"-", "0.35385045836149054`"}]}], "}"}], ",", 
            RowBox[{"-", "83.84590262632943`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009275665482763417`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5649167357676115`", ",", 
              RowBox[{"-", "0.1860555186724132`"}]}], "}"}], ",", 
            RowBox[{"-", "40.52276132872811`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009233652315384836`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.598560623249983`", ",", 
              RowBox[{"-", "0.21481323580048364`"}]}], "}"}], ",", 
            RowBox[{"-", "37.12548893906633`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15988142485899107`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.338030659768891`", ",", "1.0456952774415846`"}], 
             "}"}], ",", "163.87002602972336`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1591171623905866`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.184804334084109`", ",", "1.0900086345508422`"}], 
             "}"}], ",", "167.43981755317935`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1913239853583196`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6682505014656734`", ",", 
              RowBox[{"-", "1.260811247870144`"}]}], "}"}], ",", 
            RowBox[{"-", "155.6930772985218`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18133119751960128`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.515237747523003`", ",", 
              RowBox[{"-", "1.3299214132440937`"}]}], "}"}], ",", 
            RowBox[{"-", "144.8645144526981`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009470867868241547`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3631369823812154`", ",", 
              RowBox[{"-", "1.436960415300968`"}]}], "}"}], ",", 
            RowBox[{"-", "78.74487519357464`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043666428612270575`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8700807173829546`", ",", "1.4673964527622854`"}], 
             "}"}], ",", "114.37711713150861`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043547136433508146`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8010335980801604`", ",", "1.619771714514598`"}], 
             "}"}], ",", "113.06803457819824`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08305120407046669`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.379052243606461`", ",", "0.6990117450102403`"}], 
             "}"}], ",", "26.628300660953254`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08205377451641607`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.634981857793197`", ",", "0.8273299019140062`"}], 
             "}"}], ",", "20.366248909529595`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05142209521165748`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.842566133514247`", ",", "1.440068636143774`"}], "}"}],
             ",", "137.75486596213727`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05096531262506663`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.720940674311308`", ",", "1.5505265746309072`"}], 
             "}"}], ",", "132.35382993358746`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012963866336481724`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.588794290327433`", ",", "0.7038109943929166`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.9327743363301`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012877801990218384`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.405729173165847`", ",", "0.664674750076516`"}], "}"}],
             ",", 
            RowBox[{"-", "172.49507536613723`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008070172716757851`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0400177056328745`", ",", 
              RowBox[{"-", "0.6635405089458228`"}]}], "}"}], ",", 
            RowBox[{"-", "117.01329910494891`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008046922784696818`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.818081978692056`", ",", 
              RowBox[{"-", "1.098864073309862`"}]}], "}"}], ",", 
            RowBox[{"-", "118.63606731800834`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009314174107381465`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.021149725198444`", ",", 
              RowBox[{"-", "0.07154571447836386`"}]}], "}"}], ",", 
            RowBox[{"-", "65.30958701143763`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009224364734456833`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.098059280499725`", ",", 
              RowBox[{"-", "0.2388328067404872`"}]}], "}"}], ",", 
            RowBox[{"-", "59.67457118834301`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18977331985818377`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.728774910946679`", ",", "2.3223324043258624`"}], 
             "}"}], ",", "129.90827404177236`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18924189136883612`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.6539520195670985`", ",", "2.4117933223224775`"}], 
             "}"}], ",", "131.37078225884963`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03382484285031562`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.6258440355301405`", ",", "1.8689699323790148`"}], 
             "}"}], ",", 
            RowBox[{"-", "29.81886813827425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.033673916425846`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.697475812834526`", ",", "1.8279146946195524`"}], 
             "}"}], ",", 
            RowBox[{"-", "33.16742263704937`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014145852204755924`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.472040952293647`", ",", "2.3458184217531763`"}], 
             "}"}], ",", 
            RowBox[{"-", "62.62717988804172`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014001271585279368`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.577898380087658`", ",", "2.1413614120070266`"}], 
             "}"}], ",", 
            RowBox[{"-", "68.42834369695274`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.935870919486937`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.583810886957185`", ",", "2.633564846050262`"}], "}"}],
             ",", "71.34049521082532`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.9164072744211462`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.585555138189024`", ",", "2.638730032428786`"}], "}"}],
             ",", "67.66392474646807`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019367393565932853`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.692367912281009`", ",", "2.8987001271996897`"}], 
             "}"}], ",", 
            RowBox[{"-", "50.24828794684315`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014045073976597542`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.299114145669607`", ",", "2.5142405463846695`"}], 
             "}"}], ",", 
            RowBox[{"-", "154.6918296903081`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013987573944107053`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.215984381681101`", ",", "2.4749307830443343`"}], 
             "}"}], ",", 
            RowBox[{"-", "157.75333187041656`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033159707030700245`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8856226064772645`", ",", "2.454866553037327`"}], 
             "}"}], ",", "159.25038283862193`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03303044008086781`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.683048452564097`", ",", "2.531613486608514`"}], "}"}],
             ",", "162.14191352847385`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17613864729749557`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.354603703684484`", ",", "1.6013214427552687`"}], 
             "}"}], ",", 
            RowBox[{"-", "9.71391202462584`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17552946217379214`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.356213552333505`", ",", "1.6010458639601983`"}], 
             "}"}], ",", 
            RowBox[{"-", "12.161315443351151`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01272723329937115`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.161374580802137`", ",", "0.6278061110068232`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.77457882059267`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012688689233488683`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.155851148044681`", ",", "0.62117069692608`"}], "}"}], 
            ",", 
            RowBox[{"-", "131.65081302863672`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08141766170943962`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.929742957745927`", ",", "0.6652030754613594`"}], 
             "}"}], ",", 
            RowBox[{"-", "20.67606711388866`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08083291346468757`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.943743831431117`", ",", "0.6599192684195407`"}], 
             "}"}], ",", 
            RowBox[{"-", "25.466987802737354`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08873510210998069`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.934429269750753`", ",", "1.1647759852781359`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.39320290256939`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08613915523312513`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8711843852292245`", ",", "1.1630018869658185`"}], 
             "}"}], ",", "172.6908459561108`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0090322433203985`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.201877408545196`", ",", "2.010677723111943`"}], "}"}],
             ",", "75.79817311258682`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009009215361748977`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.220711907001162`", ",", "2.085100957738307`"}], "}"}],
             ",", "76.54237579514508`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25532326349488754`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.055325171769849`", ",", "2.140045002997775`"}], "}"}],
             ",", "147.8696620385224`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24035783209437522`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8070783438029028`", ",", "2.2959531760368335`"}], 
             "}"}], ",", "159.10253289804862`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014088252666628965`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.675134321503202`", ",", "2.346331015390589`"}], "}"}],
             ",", 
            RowBox[{"-", "136.09241230099096`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008444652544654986`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8871266030435763`", ",", "2.040432289515257`"}], 
             "}"}], ",", 
            RowBox[{"-", "140.05884903554187`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008347331480467958`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7699581791501924`", ",", "1.9423212098599785`"}], 
             "}"}], ",", 
            RowBox[{"-", "133.91485121250864`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014021797280334971`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7442304120272185`", ",", 
              RowBox[{"-", "0.9084906570121896`"}]}], "}"}], ",", 
            RowBox[{"-", "167.28300857364695`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013977533816082882`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6368300877082387`", ",", 
              RowBox[{"-", "0.932727835487602`"}]}], "}"}], ",", 
            RowBox[{"-", "165.21558500387724`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012327639918492539`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9103644313012382`", ",", 
              RowBox[{"-", "2.63264420570771`"}]}], "}"}], ",", 
            RowBox[{"-", "148.8849007179482`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012297234943880136`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8531464172669496`", ",", 
              RowBox[{"-", "2.667180887666956`"}]}], "}"}], ",", 
            RowBox[{"-", "148.99196921286688`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008869027238572677`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.275954050371112`", ",", 
              RowBox[{"-", "2.8917611585853704`"}]}], "}"}], ",", 
            RowBox[{"-", "102.4459262582022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008842181070358002`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.232309234713183`", ",", 
              RowBox[{"-", "3.089513230492525`"}]}], "}"}], ",", 
            RowBox[{"-", "100.57209033059138`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01772654827632767`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.402864922916759`", ",", 
              RowBox[{"-", "3.1706687047615048`"}]}], "}"}], ",", 
            RowBox[{"-", "61.04038472131329`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017660669639167025`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.477872133810045`", ",", 
              RowBox[{"-", "3.3062105155783237`"}]}], "}"}], ",", 
            RowBox[{"-", "63.76013863255009`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09095527827165098`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.065516021771263`", ",", 
              RowBox[{"-", "2.5757373891090496`"}]}], "}"}], ",", 
            RowBox[{"-", "0.6886663440416735`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09070150533705124`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.330498288687872`", ",", 
              RowBox[{"-", "2.5789224955651515`"}]}], "}"}], ",", 
            "0.752022688321635`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013388151781880133`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.907913549349928`", ",", 
              RowBox[{"-", "1.128131966537967`"}]}], "}"}], ",", 
            "30.38657838455852`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013353982074667318`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.925750905818889`", ",", 
              RowBox[{"-", "1.1176724675766507`"}]}], "}"}], ",", 
            "31.142454919089445`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010926807785597252`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.9396332096186235`", ",", 
              RowBox[{"-", "1.3113566863266601`"}]}], "}"}], ",", 
            "6.70079293575831`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010894464334518713`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.12417255435784`", ",", 
              RowBox[{"-", "1.2896757064740478`"}]}], "}"}], ",", 
            "8.464696566250852`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16946302924391063`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.195908819104282`", ",", 
              RowBox[{"-", "1.8418698879684676`"}]}], "}"}], ",", 
            RowBox[{"-", "155.5265461071354`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1690240168438554`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1672204988726462`", ",", 
              RowBox[{"-", "1.8549278598035843`"}]}], "}"}], ",", 
            RowBox[{"-", "154.62176334727195`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012347044132055179`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.507286540201194`", ",", "2.678637279603003`"}], "}"}],
             ",", "17.313940884336233`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012309762312982598`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.573136455120478`", ",", "2.6991648220460918`"}], 
             "}"}], ",", "19.175901196420124`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01369256098645535`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0728522647269667`", ",", "3.096887373596184`"}], 
             "}"}], ",", "97.63263498921711`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013658338411207886`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0379501329067837`", ",", "3.357334989361348`"}], 
             "}"}], ",", "97.15563279458993`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02762399913733004`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.16312011496545`", ",", 
              RowBox[{"-", "3.0916553002213503`"}]}], "}"}], ",", 
            RowBox[{"-", "24.966524469138946`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02694271009682234`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.204481116344392`", ",", 
              RowBox[{"-", "3.110912839801599`"}]}], "}"}], ",", 
            RowBox[{"-", "33.35176862107053`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008450760051046375`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.4193349084766895`", ",", 
              RowBox[{"-", "1.7443209047785018`"}]}], "}"}], ",", 
            RowBox[{"-", "6.577104534771598`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008414614059508836`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.617159875700941`", ",", 
              RowBox[{"-", "1.7671299287408804`"}]}], "}"}], ",", 
            RowBox[{"-", "3.3678973369053526`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009132608605665917`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.45669261763965`", ",", "2.226579398023197`"}], "}"}], 
            ",", "57.74356653753813`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008953168700008701`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5395831023513624`", ",", "2.3579201842494855`"}], 
             "}"}], ",", "65.44095423499321`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3847505289119267`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.332308243559459`", ",", "2.3879252482139632`"}], 
             "}"}], ",", "135.75753140301288`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3816464895602496`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2156463427626463`", ",", "2.5015423567450736`"}], 
             "}"}], ",", "140.88318990992553`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00872318817885908`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1486487051213468`", ",", "2.299759893171285`"}], 
             "}"}], ",", 
            RowBox[{"-", "146.22850373151238`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008651437781788993`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.610436075581841`", ",", "1.9398455583721346`"}], 
             "}"}], ",", 
            RowBox[{"-", "151.4095886367574`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009488716789597621`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.888010749790684`", ",", "2.239795602771776`"}], "}"}],
             ",", "34.39935215943431`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00937395846192137`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.352094276162099`", ",", "2.5575525177369407`"}], 
             "}"}], ",", "28.117240417713116`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026194550921173086`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4125453660218863`", ",", 
              RowBox[{"-", "0.8593377419620716`"}]}], "}"}], ",", 
            RowBox[{"-", "175.28507637611685`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02606860083849863`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.353904435352324`", ",", 
              RowBox[{"-", "0.8641742816307323`"}]}], "}"}], ",", 
            RowBox[{"-", "178.8733872922872`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013259526748768102`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.422089061304332`", ",", 
              RowBox[{"-", "1.0631783556271799`"}]}], "}"}], ",", 
            RowBox[{"-", "178.43965167378056`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013195382163280214`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.093326910640336`", ",", 
              RowBox[{"-", "1.0721338202571287`"}]}], "}"}], ",", 
            "177.95282238261203`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009347203982220907`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.9164044126609205`", ",", "0.6481537547206977`"}], 
             "}"}], ",", "149.95289791011996`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009323085692243398`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.891964282972589`", ",", "0.6622910721049998`"}], 
             "}"}], ",", "150.8201787439885`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09786702823869965`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.150256002333505`", ",", "0.05231239248044925`"}], 
             "}"}], ",", "51.78946702995778`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09758750040512609`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.164078058226643`", ",", "0.069870449653405`"}], "}"}],
             ",", "53.36497799969245`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019441821985911233`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.574921277472411`", ",", "0.0874755916513075`"}], 
             "}"}], ",", "67.94757915618669`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019292251155254413`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.596749065410667`", ",", "0.14135927252437472`"}], 
             "}"}], ",", "62.95835964094559`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013442509710075531`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.093124318394603`", ",", 
              RowBox[{"-", "0.6399737634313856`"}]}], "}"}], ",", 
            "112.09298400614668`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013401727792807969`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.067044428207292`", ",", 
              RowBox[{"-", "0.5757241701134088`"}]}], "}"}], ",", 
            "113.97763196730179`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02171513936557199`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.095556880334739`", ",", 
              RowBox[{"-", "1.782516190304264`"}]}], "}"}], ",", 
            RowBox[{"-", "172.52542598135872`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021587779468350228`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.836140707000324`", ",", 
              RowBox[{"-", "1.8165518686022184`"}]}], "}"}], ",", 
            RowBox[{"-", "176.72213011355245`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04371431905767775`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.863139321655691`", ",", 
              RowBox[{"-", "1.9772863051707465`"}]}], "}"}], ",", 
            RowBox[{"-", "138.74463468609022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04173424052011483`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.7142040229293976`", ",", 
              RowBox[{"-", "2.10792373154992`"}]}], "}"}], ",", 
            RowBox[{"-", "128.4038174122411`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.100675908293293`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.022041265246742`", ",", 
              RowBox[{"-", "2.1317672179825253`"}]}], "}"}], ",", 
            RowBox[{"-", "38.94149533545729`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.085012741178588`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.079759756486173`", ",", 
              RowBox[{"-", "2.178409227415667`"}]}], "}"}], ",", 
            RowBox[{"-", "36.99964756880024`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015615068625707015`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.33682100981092`", ",", 
              RowBox[{"-", "2.372116296911316`"}]}], "}"}], ",", 
            "107.24548211588342`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04298070795175712`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.147211336256754`", ",", 
              RowBox[{"-", "1.948883010289454`"}]}], "}"}], ",", 
            "60.86164401517582`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04285973902290488`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.177544675768603`", ",", 
              RowBox[{"-", "1.8944705060288458`"}]}], "}"}], ",", 
            "62.353712522748154`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021504471470806186`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.981703858840445`", ",", 
              RowBox[{"-", "1.3971231822573906`"}]}], "}"}], ",", 
            "71.35610668739905`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02142982434960078`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.05729602739823`", ",", 
              RowBox[{"-", "1.1730735280725026`"}]}], "}"}], ",", 
            "73.817855630127`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013672396952207486`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.81221724320332`", ",", 
              RowBox[{"-", "0.9879310810174107`"}]}], "}"}], ",", 
            "129.30589602115307`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013603579244059243`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.775781437771898`", ",", 
              RowBox[{"-", "0.9434245706739666`"}]}], "}"}], ",", 
            "125.57424954565988`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019780015412603533`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.603984831371815`", ",", 
              RowBox[{"-", "1.169398971513567`"}]}], "}"}], ",", 
            "171.5018027893138`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019538039861123544`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.574104318307114`", ",", 
              RowBox[{"-", "1.1649342600888264`"}]}], "}"}], ",", 
            "165.1868986279668`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09514781052627358`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.930221352069838`", ",", 
              RowBox[{"-", "2.022155952212378`"}]}], "}"}], ",", 
            RowBox[{"-", "148.86258210533362`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0945532599995545`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.770604205594284`", ",", 
              RowBox[{"-", "2.118585400139093`"}]}], "}"}], ",", 
            RowBox[{"-", "144.47795791835188`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013288937657603401`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.561283549930273`", ",", 
              RowBox[{"-", "0.227086100596803`"}]}], "}"}], ",", 
            "150.84498325938904`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012947902499315668`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.41769083502157`", ",", 
              RowBox[{"-", "0.14698272811855936`"}]}], "}"}], ",", 
            "159.3526325880933`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01193318496013604`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.407879210301261`", ",", "1.8004025358513511`"}], 
             "}"}], ",", "86.33904815982224`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011864851132445337`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.412338370545742`", ",", "1.87009568796768`"}], "}"}], 
            ",", "82.21392367109125`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0248984562135517`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1079055127338115`", ",", "2.388170150014077`"}], 
             "}"}], ",", "75.30510575355352`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022851189005179948`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1101305241034725`", ",", "2.3966544690921925`"}], 
             "}"}], ",", "87.77762997488098`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11035036088160324`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8863540324988484`", ",", "0.559232777351813`"}], 
             "}"}], ",", "165.5029671265896`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10928234430771655`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8356563595576576`", ",", "0.5723412860644501`"}], 
             "}"}], ",", "159.8572689008221`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0418785046320254`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.2133081495809765`", ",", 
              RowBox[{"-", "1.3706139949046245`"}]}], "}"}], ",", 
            RowBox[{"-", "145.46672998533`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.041749658315437824`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.108618644472275`", ",", 
              RowBox[{"-", "1.4426546388240173`"}]}], "}"}], ",", 
            RowBox[{"-", "147.41746300855849`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023012613951906694`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.458210494903547`", ",", 
              RowBox[{"-", "2.6254920219548468`"}]}], "}"}], ",", 
            RowBox[{"-", "98.9495878651417`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019248099947778104`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.407019887660409`", ",", 
              RowBox[{"-", "2.9505475865878963`"}]}], "}"}], ",", 
            RowBox[{"-", "83.67699185820453`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011817734145923898`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.796596113038852`", ",", 
              RowBox[{"-", "1.4367323507430918`"}]}], "}"}], ",", 
            RowBox[{"-", "46.26269307448791`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011780119441163816`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.821543249800346`", ",", 
              RowBox[{"-", "1.4628040299671872`"}]}], "}"}], ",", 
            RowBox[{"-", "44.15888786060312`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00957072377488993`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.507576983832616`", ",", "1.6542440114158796`"}], 
             "}"}], ",", "132.76699317411442`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009424671261420842`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.430740033522393`", ",", "2.8184667495682527`"}], 
             "}"}], ",", "139.72011058195227`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01604485245075161`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9982269963100165`", ",", "2.1711805332934513`"}], 
             "}"}], ",", "92.63773029597193`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016005257171484762`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.991086841474694`", ",", "2.3261666890661976`"}], 
             "}"}], ",", "92.78106209168295`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1290611972797337`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.601329198023765`", ",", 
              RowBox[{"-", "1.6135517013908613`"}]}], "}"}], ",", 
            RowBox[{"-", "90.20044986692868`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12705050018888117`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.600403197491476`", ",", 
              RowBox[{"-", "1.8782348697021982`"}]}], "}"}], ",", 
            RowBox[{"-", "97.21383171369399`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03616965632267346`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.144168730365307`", ",", 
              RowBox[{"-", "0.8780716570571427`"}]}], "}"}], ",", 
            RowBox[{"-", "67.35543187675484`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.036073961902658234`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.229428519827426`", ",", 
              RowBox[{"-", "1.0824469116506141`"}]}], "}"}], ",", 
            RowBox[{"-", "68.43734231681997`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04156277847714569`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.397711101966816`", ",", "1.425990015523278`"}], "}"}],
             ",", "99.47535319653558`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.041104093087562646`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.355766015401802`", ",", "1.677308046114456`"}], "}"}],
             ",", "105.49553117827398`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00875989764815006`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9578493651101825`", ",", "0.12924088828540214`"}], 
             "}"}], ",", "156.00614357475288`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008737986765164067`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.888620916030578`", ",", "0.16005448555398563`"}], 
             "}"}], ",", "155.51619109575307`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12236056753711465`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.246315232740649`", ",", "0.938381580360709`"}], "}"}],
             ",", "55.92575991408235`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11976412636108417`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.368445590996329`", ",", "1.1189421761208362`"}], 
             "}"}], ",", "63.853775853499954`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015716189902003127`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.388581737806026`", ",", 
              RowBox[{"-", "0.6601193636767255`"}]}], "}"}], ",", 
            RowBox[{"-", "168.0366769053084`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015660870595436388`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.32799048777566`", ",", 
              RowBox[{"-", "0.672957898133279`"}]}], "}"}], ",", 
            RowBox[{"-", "165.5208866036744`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008142147980113375`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.690582381629045`", ",", "0.865765952717761`"}], "}"}],
             ",", 
            RowBox[{"-", "178.66124947139863`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2718261063685962`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.882842248520935`", ",", 
              RowBox[{"-", "1.1463896616883769`"}]}], "}"}], ",", 
            RowBox[{"-", "86.03131862082505`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26809663024753516`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.886544713685529`", ",", 
              RowBox[{"-", "1.1997565696185986`"}]}], "}"}], ",", 
            RowBox[{"-", "92.67612871254703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28038501246615904`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4207183716486735`", ",", 
              RowBox[{"-", "0.620736054269777`"}]}], "}"}], ",", 
            RowBox[{"-", "60.44680660855803`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2793503516646433`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.534987210262611`", ",", 
              RowBox[{"-", "0.8222687521754535`"}]}], "}"}], ",", 
            RowBox[{"-", "63.14052429095053`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025307265717536664`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.581851068272584`", ",", "0.2082720020311536`"}], 
             "}"}], ",", 
            RowBox[{"-", "108.16578881713595`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02524255363827332`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.545049759835014`", ",", "0.09611452520613893`"}], 
             "}"}], ",", 
            RowBox[{"-", "107.38957079742102`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2926493047834892`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.675336249011812`", ",", "0.0591858274929169`"}], 
             "}"}], ",", 
            RowBox[{"-", "45.82580778272275`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28868765007548547`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.30451965388601`", ",", 
              RowBox[{"-", "0.5884010241932411`"}]}], "}"}], ",", 
            RowBox[{"-", "52.431903515616675`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021694254553177014`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.850782598441062`", ",", "0.07277791814304138`"}], 
             "}"}], ",", "16.51417325169054`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021376871550046972`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.87963114875032`", ",", "0.08133101104005919`"}], 
             "}"}], ",", "9.683626119136653`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012597079709539365`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.983547199606125`", ",", "1.1459838153379867`"}], 
             "}"}], ",", "170.77691616556342`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012544637138556657`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.852980997598422`", ",", "1.167184912738187`"}], "}"}],
             ",", "167.65851585159015`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1793050907758053`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.863324853607964`", ",", "1.031608164437147`"}], "}"}],
             ",", 
            RowBox[{"-", "125.00418788206912`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.178553439888321`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.783168053508213`", ",", "0.9171501968809312`"}], 
             "}"}], ",", 
            RowBox[{"-", "121.86239823036823`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011087360641710873`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.914027006419358`", ",", "0.8736066021139146`"}], 
             "}"}], ",", 
            RowBox[{"-", "60.78529192970161`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010922902169554315`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.066867649932133`", ",", "0.6002952428894279`"}], 
             "}"}], ",", 
            RowBox[{"-", "67.65585228367964`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.375005953813934`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.346007987984193`", ",", "2.1354637918059716`"}], 
             "}"}], ",", "117.40412003829024`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3701762291127424`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.327120090947857`", ",", "2.1718958268236905`"}], 
             "}"}], ",", "119.91181105550658`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2641689589797744`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.066377499692184`", ",", "2.2089179863153836`"}], 
             "}"}], ",", "168.31971050219542`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26351488861141836`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.898965312849362`", ",", "2.243527325900353`"}], "}"}],
             ",", "168.04727040250376`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2622080760166959`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.269418053371558`", ",", "2.1084494459656544`"}], 
             "}"}], ",", 
            RowBox[{"-", "94.83830704254505`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2615603495313354`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.251000233336963`", ",", "1.8908622107119537`"}], 
             "}"}], ",", 
            RowBox[{"-", "95.03044121316142`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07646682752923194`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.394212442133696`", ",", "1.133243022143843`"}], "}"}],
             ",", 
            RowBox[{"-", "126.05366658948233`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07619447622862997`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.251696866129556`", ",", "0.9374730351937544`"}], 
             "}"}], ",", 
            RowBox[{"-", "123.49264939678761`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024599086842187857`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.6564143033686465`", ",", "1.2250070433451765`"}], 
             "}"}], ",", 
            RowBox[{"-", "109.3314300321128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024521132686194165`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.6385450164797195`", ",", "1.1740699618890027`"}], 
             "}"}], ",", 
            RowBox[{"-", "111.41596415692479`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20141331544426683`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.430375912009466`", ",", "0.283208622726918`"}], "}"}],
             ",", 
            RowBox[{"-", "92.23826580109001`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19979764395859306`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.421668960201598`", ",", "0.06043892671619491`"}], 
             "}"}], ",", 
            RowBox[{"-", "87.12900126195116`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.33710362491899387`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.585010064392459`", ",", "1.196668184852395`"}], "}"}],
             ",", 
            RowBox[{"-", "172.43397479273634`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.335538024806492`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.38361273321551`", ",", "1.1699175830622408`"}], "}"}],
             ",", 
            RowBox[{"-", "175.91190952326457`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2867799236082485`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.869019545342315`", ",", "0.9045133912008863`"}], 
             "}"}], ",", "178.2088620155177`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28549430929952446`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6601133026574955`", ",", "0.9110461907966975`"}], 
             "}"}], ",", "174.84506314820194`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2900425045471786`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8802831926153463`", ",", "1.0795703200884155`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.97807219974132`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2892851428382827`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6903964674858494`", ",", "1.0595389433095326`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.00307008426276`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009211475820204557`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.613447268885137`", ",", 
              RowBox[{"-", "1.6437226269738707`"}]}], "}"}], ",", 
            RowBox[{"-", "86.64810705308265`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009144178844074995`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.61359122751234`", ",", 
              RowBox[{"-", "1.6461805843378567`"}]}], "}"}], ",", 
            RowBox[{"-", "81.80782076349875`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17846540055055785`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1516229963101905`", ",", "3.04052253545903`"}], "}"}],
             ",", "82.05450252368206`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17799828216807748`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1594300176847945`", ",", "3.096458406591349`"}], 
             "}"}], ",", "81.05936317641887`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09317864868467558`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.488034289750155`", ",", "2.6797783985379304`"}], 
             "}"}], ",", "79.43604234335129`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09289994309639356`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.512358282793377`", ",", "2.8102062193222936`"}], 
             "}"}], ",", "81.25196060208084`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.8628874678008174`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.973860009185009`", ",", "2.4233855638274715`"}], 
             "}"}], ",", "150.34476858086228`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.8581358924226263`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.42036330315144`", ",", "2.7385215816048163`"}], "}"}],
             ",", "151.0938359839008`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4301777177836793`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.911576044151911`", ",", "2.523739366932794`"}], "}"}],
             ",", "99.71939444475326`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4261380628670148`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.88366247065081`", ",", "2.686708323647802`"}], "}"}], 
            ",", "105.27901881397781`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2672446857022981`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.949638783966609`", ",", "2.6355490531667902`"}], 
             "}"}], ",", "49.094020308644374`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2514363227260545`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.30327979785749`", ",", "3.0437173209918855`"}], "}"}],
             ",", "37.82865181428635`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014873248628385755`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.4372327959670805`", ",", "3.147729248239088`"}], 
             "}"}], ",", 
            RowBox[{"-", "26.874976847738786`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16602375967792204`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0602158577717615`", ",", "2.677056749400575`"}], 
             "}"}], ",", 
            RowBox[{"-", "1.531353827464691`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16546651203471324`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1235570583401175`", ",", "2.675363415373785`"}], 
             "}"}], ",", "0.7962969625204293`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1031410173981778`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.162450707646214`", ",", "2.6179110515934285`"}], 
             "}"}], ",", 
            RowBox[{"-", "52.15672796357385`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10273052734101643`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.522941060404558`", ",", "2.1538937358320926`"}], 
             "}"}], ",", 
            RowBox[{"-", "55.12082232259104`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06407558466672793`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.18158680607505`", ",", "2.5013606855070525`"}], "}"}],
             ",", 
            RowBox[{"-", "102.78210209968287`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06354535848363348`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.152322539864831`", ",", "2.372367037486031`"}], "}"}],
             ",", 
            RowBox[{"-", "97.58374634426224`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039806477131525075`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1036313876707275`", ",", "2.412630020912711`"}], 
             "}"}], ",", 
            RowBox[{"-", "153.4074762357919`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03970141247948349`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.883622081333916`", ",", "2.302493471582756`"}], "}"}],
             ",", 
            RowBox[{"-", "154.4706455055919`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024729475819285418`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.985587288433265`", ",", "2.416601007334562`"}], "}"}],
             ",", "155.96714962809875`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024651918776346305`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.384889466004231`", ",", "2.6844616944699413`"}], 
             "}"}], ",", "153.92887831328815`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015363001661159345`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.913771130957169`", ",", "2.5103699660752623`"}], 
             "}"}], ",", "105.34177549198894`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015290852539424834`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.870247198990103`", ",", "2.669012116609145`"}], "}"}],
             ",", "108.85530914077306`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009544149733118451`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.9406965792129025`", ",", "2.6253708283945265`"}], 
             "}"}], ",", "54.7164013558794`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009511743778559264`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.457306936761345`", ",", "3.355448852941872`"}], "}"}],
             ",", "57.09064122574636`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08373921136943206`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1188388464948025`", ",", "0.6604338486612473`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.30851959060885`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0834447391571244`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1166751170879525`", ",", "0.6597018252416424`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.79640518256713`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03768646910093345`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.143855725421484`", ",", "1.3816868608239041`"}], 
             "}"}], ",", "145.1039281474095`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037592344494505804`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.132335989322367`", ",", "1.3897219659560067`"}], 
             "}"}], ",", "145.56853769111024`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09155049181583227`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.072201536619233`", ",", "1.2023600096651306`"}], 
             "}"}], ",", "174.12873679817065`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09122629485963236`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.851498967343398`", ",", "1.2250555314779823`"}], 
             "}"}], ",", "176.66769588968904`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021995171031671156`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.327993242796761`", ",", "1.1048759326021627`"}], 
             "}"}], ",", 
            RowBox[{"-", "120.49075152845165`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02178238613968048`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.210763959576821`", ",", "0.9057866227232705`"}], 
             "}"}], ",", 
            RowBox[{"-", "126.13519704042865`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008406955677190412`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.953065952582621`", ",", 
              RowBox[{"-", "0.6208304854292546`"}]}], "}"}], ",", 
            RowBox[{"-", "83.08820425769409`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008384926219419794`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.979795162103256`", ",", 
              RowBox[{"-", "0.8413281452657155`"}]}], "}"}], ",", 
            RowBox[{"-", "82.08358902731925`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009191829442302282`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.8015864440438545`", ",", 
              RowBox[{"-", "0.3685024860381718`"}]}], "}"}], ",", 
            RowBox[{"-", "33.728216549404344`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009163249487429402`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.865477093546045`", ",", 
              RowBox[{"-", "0.4111577264223858`"}]}], "}"}], ",", 
            RowBox[{"-", "35.727463261516824`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15835655323663772`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9180161944865612`", ",", "1.1494482120242693`"}], 
             "}"}], ",", "171.00960907663514`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15573397530720887`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8621851503738815`", ",", "1.158281382640382`"}], 
             "}"}], ",", "163.81759780847025`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009992787838718266`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.515237747523003`", ",", 
              RowBox[{"-", "1.3299214132440937`"}]}], "}"}], ",", 
            "159.84440913400212`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00996739686590369`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3736817974158426`", ",", 
              RowBox[{"-", "1.2779634997862737`"}]}], "}"}], ",", 
            "160.5502039418248`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17186032965135978`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3631369823812154`", ",", 
              RowBox[{"-", "1.436960415300968`"}]}], "}"}], ",", 
            RowBox[{"-", "134.03595160687442`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16989633312019414`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2347894055906963`", ",", 
              RowBox[{"-", "1.5697014360895865`"}]}], "}"}], ",", 
            RowBox[{"-", "127.9160539509001`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008976207603462818`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3994379955641585`", ",", 
              RowBox[{"-", "1.6193726603941647`"}]}], "}"}], ",", 
            RowBox[{"-", "67.91631234775099`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008952112530770833`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4950612409166117`", ",", 
              RowBox[{"-", "1.855056788319011`"}]}], "}"}], ",", 
            RowBox[{"-", "69.10583971778145`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043428170148673055`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6764578941698423`", ",", "1.912287471595425`"}], 
             "}"}], ",", "111.75895202488815`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04309512000844569`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.659701915750172`", ",", "1.9542676047755663`"}], 
             "}"}], ",", "116.7390861781061`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08106832390627644`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.8600772293281915`", ",", "0.9108912178091552`"}], 
             "}"}], ",", "14.10419715810605`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08070835521041393`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.917087917971804`", ",", "0.9252157528523273`"}], 
             "}"}], ",", "17.436845128462938`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.050512587639212486`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.563509470794093`", ",", "1.7232149979237499`"}], 
             "}"}], ",", "126.95279390503762`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0497964265762504`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.491949144930795`", ",", "1.8183417237540334`"}], 
             "}"}], ",", "120.2131365314655`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012792309006811277`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1420754931227135`", ",", "0.6299410302479087`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.05737639594443`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012743424265618152`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.13941268460613`", ",", "0.6298041521065122`"}], "}"}],
             ",", 
            RowBox[{"-", "174.23667802454779`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008023739835011482`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6730830867006965`", ",", 
              RowBox[{"-", "1.3644129827131524`"}]}], "}"}], ",", 
            RowBox[{"-", "120.25883553106776`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009135421323814214`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.212311557604752`", ",", 
              RowBox[{"-", "0.4341530931148644`"}]}], "}"}], ",", 
            RowBox[{"-", "54.03955536524852`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008517132002126502`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.338588345914811`", ",", 
              RowBox[{"-", "0.6082107515768171`"}]}], "}"}], ",", 
            RowBox[{"-", "65.78920177425572`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18871195105622218`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.435909779053422`", ",", "2.6593680888455133`"}], 
             "}"}], ",", "132.8332904759274`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18750941602837956`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3888323111581675`", ",", "2.7101479142359346`"}], 
             "}"}], ",", "137.27558227033012`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03352366343497384`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8978100437530285`", ",", "1.696982269817469`"}], 
             "}"}], ",", 
            RowBox[{"-", "36.515977135824386`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03304788095536744`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.956747605735684`", ",", "1.6533453290572493`"}], 
             "}"}], ",", 
            RowBox[{"-", "43.25860494910863`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013858168682042577`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.665193389335898`", ",", "1.9205603235213684`"}], 
             "}"}], ",", 
            RowBox[{"-", "74.22950750586358`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013819595685257417`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.69219454215379`", ",", "1.82495236190656`"}], "}"}], 
            ",", 
            RowBox[{"-", "72.80322588941829`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0194636450657914`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.585555138189024`", ",", "2.638730032428786`"}], "}"}],
             ",", 
            RowBox[{"-", "178.100433024578`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019289780411100174`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.578523583257114`", ",", "2.6384968249285388`"}], 
             "}"}], ",", 
            RowBox[{"-", "172.68343971696808`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.8970398808552136`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.692367912281009`", ",", "2.8987001271996897`"}], 
             "}"}], ",", "63.98735428211081`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.818583817398182`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.829041889572819`", ",", "3.1787664066759094`"}], 
             "}"}], ",", "71.75745618959026`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07687656874273986`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.883506851961149`", ",", "3.3440089025840014`"}], 
             "}"}], ",", "151.86382449847446`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019271618048410034`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.872093610858287`", ",", "2.6826165966951008`"}], 
             "}"}], ",", 
            RowBox[{"-", "53.9248584112006`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01922031977264812`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.91602272532324`", ",", "2.622319810077522`"}], "}"}], 
            ",", 
            RowBox[{"-", "55.053110082371035`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013930309314701081`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.939781396097772`", ",", "2.361951907883309`"}], "}"}],
             ",", 
            RowBox[{"-", "160.81483405052538`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013856605921443037`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.772658749981498`", ",", "2.303802156351581`"}], "}"}],
             ",", 
            RowBox[{"-", "156.9292989172056`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03290167705419436`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.391351704172249`", ",", "2.625593379193287`"}], "}"}],
             ",", "165.03344421832603`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03278073812803582`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.355124772949332`", ",", "2.6352776953953128`"}], 
             "}"}], ",", "162.35413714092834`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17492238395008286`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.653693099468152`", ",", "1.5369387176341482`"}], 
             "}"}], ",", 
            RowBox[{"-", "14.60871886207676`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17448462683892865`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.849169220663623`", ",", "1.4859892362381888`"}], 
             "}"}], ",", 
            RowBox[{"-", "14.110125377065682`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012650261897218986`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.963243164986898`", ",", "0.40461823168334243`"}], 
             "}"}], ",", 
            RowBox[{"-", "133.52704723668097`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012585585767993008`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.864035069368825`", ",", "0.3001735008972025`"}], 
             "}"}], ",", 
            RowBox[{"-", "137.30716004917082`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08361915282499986`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.693844003873882`", ",", "1.1857485126662142`"}], 
             "}"}], ",", "163.774894814791`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08339803321601268`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4228500119969545`", ",", "1.264608325084982`"}], 
             "}"}], ",", "164.8528503739111`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00898624611352839`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.2970211362664825`", ",", "2.4039905965296344`"}], 
             "}"}], ",", "77.28657847770381`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008914558721356186`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.354927469531008`", ",", "2.660660901539697`"}], "}"}],
             ",", "82.37998973698235`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014965431400512286`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8070783438029028`", ",", "2.2959531760368335`"}], 
             "}"}], ",", "105.53034895661435`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014794145320095998`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7064987451471687`", ",", "2.657886923554598`"}], 
             "}"}], ",", "99.4060548237696`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22626957942774628`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.675134321503202`", ",", "2.346331015390589`"}], "}"}],
             ",", "170.33540375757482`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22395049021830984`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5557058479751067`", ",", "2.3666693537413117`"}], 
             "}"}], ",", "164.5262914361907`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013262488590337719`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.573380697926003`", ",", "2.248385357970332`"}], "}"}],
             ",", 
            RowBox[{"-", "124.85954144146476`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013029652756978094`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4922244091376218`", ",", "2.1318753049699684`"}], 
             "}"}], ",", 
            RowBox[{"-", "117.49607314433285`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008251132000559797`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.608033170338925`", ",", "1.7741434996327017`"}], 
             "}"}], ",", 
            RowBox[{"-", "127.77085338947532`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008222372346247762`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.494865762782598`", ",", "1.6280956073710566`"}], 
             "}"}], ",", 
            RowBox[{"-", "125.29305650505091`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013933410081013042`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.30918847720457`", ",", 
              RowBox[{"-", "1.0191991468394757`"}]}], "}"}], ",", 
            RowBox[{"-", "163.1481614341077`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013871411983682134`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1501325925922243`", ",", 
              RowBox[{"-", "1.0673780166924594`"}]}], "}"}], ",", 
            RowBox[{"-", "166.48763524735386`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012266904960303113`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.589108696355187`", ",", 
              RowBox[{"-", "2.8258811301481175`"}]}], "}"}], ",", 
            RowBox[{"-", "149.09903770779235`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012225610598768887`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5793722792052693`", ",", 
              RowBox[{"-", "2.831708477702094`"}]}], "}"}], ",", 
            RowBox[{"-", "146.75944130659153`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008815416164352637`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.172461097552453`", ",", 
              RowBox[{"-", "3.4101727141824996`"}]}], "}"}], ",", 
            RowBox[{"-", "98.69825440298057`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00808866082489783`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1639613154432675`", ",", 
              RowBox[{"-", "3.465730359428305`"}]}], "}"}], ",", 
            RowBox[{"-", "111.1807480380335`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017595035832233152`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.601170038740591`", ",", 
              RowBox[{"-", "3.55634550583027`"}]}], "}"}], ",", 
            RowBox[{"-", "66.47989254378719`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01754692263322301`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.628715581397982`", ",", 
              RowBox[{"-", "3.6196351682442374`"}]}], "}"}], ",", 
            RowBox[{"-", "65.16466740742031`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09044844045044562`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.638935893568386`", ",", 
              RowBox[{"-", "2.5748739356299155`"}]}], "}"}], ",", 
            "2.192711720684943`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08991535508416518`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.862015843501545`", ",", 
              RowBox[{"-", "2.566332486898788`"}]}], "}"}], ",", 
            "6.404013612354198`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013319899576571198`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.17711503024882`", ",", 
              RowBox[{"-", "0.9657857867526604`"}]}], "}"}], ",", 
            "31.898331453619885`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013226833351632132`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.229584526554289`", ",", 
              RowBox[{"-", "0.9331285216554779`"}]}], "}"}], ",", 
            "36.609459762419064`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012272593066119079`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.859102310574856`", ",", "2.798613824550409`"}], "}"}],
             ",", "21.037861508504008`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011960144256608192`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.084440878437667`", ",", "2.8852840868237886`"}], 
             "}"}], ",", "12.554843298649132`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026278223647221502`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.346900401770584`", ",", 
              RowBox[{"-", "3.2046491384338243`"}]}], "}"}], ",", 
            RowBox[{"-", "41.7370127730019`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026154910625220514`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.4508501385809875`", ",", 
              RowBox[{"-", "3.297385501936052`"}]}], "}"}], ",", 
            RowBox[{"-", "45.248034784034864`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008378622673319966`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8834535086676665`", ",", 
              RowBox[{"-", "1.782800960434623`"}]}], "}"}], ",", 
            RowBox[{"-", "0.1586901390393347`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008350282437598965`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.105640936272439`", ",", 
              RowBox[{"-", "1.7834163468424353`"}]}], "}"}], ",", 
            "2.2002140965389096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008777254477004986`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6246736316529993`", ",", "2.5441255502263878`"}], 
             "}"}], ",", "73.13834193244851`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008720520321501175`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6704688145865982`", ",", "2.6952186852900835`"}], 
             "}"}], ",", "68.65422652052884`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3785674925660814`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.990766656968944`", ",", "2.68440669863797`"}], "}"}], 
            ",", "146.0088484168383`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.37661141892337874`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8845911525099703`", ",", "2.7559991259945607`"}], 
             "}"}], ",", "149.82164511240043`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00858027754961896`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.427325078483299`", ",", "1.8400499517806694`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.59067354200232`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008558993392664983`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4097248437291436`", ",", "1.8324302484370008`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.26717141524983`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009260588043070206`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5648705308709445`", ",", "2.67124674879148`"}], "}"}],
             ",", "21.835128675991815`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009229627545588556`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.588892206482666`", ",", "2.680871821839608`"}], "}"}],
             ",", "24.146736979060005`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025943256355949695`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0780660610831423`", ",", 
              RowBox[{"-", "0.8695988186114041`"}]}], "}"}], ",", 
            "177.5383017915425`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025117912326129387`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0428885243697246`", ",", 
              RowBox[{"-", "0.8680864942479819`"}]}], "}"}], ",", 
            RowBox[{"-", "173.28023176409397`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013131547885084987`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.844101538872602`", ",", 
              RowBox[{"-", "1.0632252089375354`"}]}], "}"}], ",", 
            "174.3452964390048`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013099150648358019`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.666467982513889`", ",", 
              RowBox[{"-", "1.0456368429455045`"}]}], "}"}], ",", 
            "174.47266316178008`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009299029633914253`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.620435270414352`", ",", "0.8139180346299864`"}], 
             "}"}], ",", "151.6874595778558`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009229151067912247`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.568674019498865`", ",", "0.8418032120599352`"}], 
             "}"}], ",", "146.7658691680177`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01914383101064954`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.71725703465744`", ",", "0.3774451573715266`"}], "}"}],
             ",", "57.969140125704406`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018786695888718015`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.859452932420811`", ",", "0.6047336633735261`"}], 
             "}"}], ",", "65.51223497119587`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013361069599816009`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.939023855942025`", ",", 
              RowBox[{"-", "0.28788288655888045`"}]}], "}"}], ",", 
            "115.8622799284567`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013318726843723708`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.761532495199798`", ",", "0.0782594081300623`"}], 
             "}"}], ",", "113.77756688122014`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021461166540473097`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.603624631246455`", ",", 
              RowBox[{"-", "1.8298685568134114`"}]}], "}"}], ",", 
            "179.08116575425387`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021046991752128888`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.570468399754491`", ",", 
              RowBox[{"-", "1.8293367952577892`"}]}], "}"}], ",", 
            RowBox[{"-", "173.27494552563357`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03984385138180222`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.608643324015406`", ",", 
              RowBox[{"-", "2.241089960054466`"}]}], "}"}], ",", 
            RowBox[{"-", "118.06300013839203`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03973858991586621`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5302611664733945`", ",", 
              RowBox[{"-", "2.388115128296302`"}]}], "}"}], ",", 
            RowBox[{"-", "116.99248774388022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015663167114706073`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.079759756486173`", ",", 
              RowBox[{"-", "2.178409227415667`"}]}], "}"}], ",", 
            RowBox[{"-", "179.30292948682686`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015603551854063535`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.8944045676906915`", ",", 
              RowBox[{"-", "2.180664402454299`"}]}], "}"}], ",", 
            RowBox[{"-", "176.49665854971514`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015567117837656668`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.241396205327685`", ",", 
              RowBox[{"-", "2.0647126153737987`"}]}], "}"}], ",", 
            "109.18732988254084`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015500840483340902`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.182546427716614`", ",", 
              RowBox[{"-", "1.895598670219838`"}]}], "}"}], ",", 
            "105.993539802665`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021355436346258933`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.13369358484671`", ",", 
              RowBox[{"-", "0.909805201904108`"}]}], "}"}], ",", 
            "76.27960457285509`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02123954235960414`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.142056766957792`", ",", 
              RowBox[{"-", "0.8755510463406937`"}]}], "}"}], ",", 
            "72.31663673168963`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013535107918258687`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.631251815124599`", ",", 
              RowBox[{"-", "0.7413559237850313`"}]}], "}"}], ",", 
            "121.8426030701666`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013499134451970375`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.605605728708971`", ",", 
              RowBox[{"-", "0.7000616123378564`"}]}], "}"}], ",", 
            "120.7258291858763`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019299024477585434`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.35587456765623`", ",", 
              RowBox[{"-", "1.1072220852942924`"}]}], "}"}], ",", 
            "158.8719944666197`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019250282026786802`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.178150371177928`", ",", 
              RowBox[{"-", "1.038544202537983`"}]}], "}"}], ",", 
            "159.50358148237805`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0939624246432305`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.56054423222673`", ",", 
              RowBox[{"-", "2.2685416838301906`"}]}], "}"}], ",", 
            RowBox[{"-", "140.09333373137017`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09343608168659631`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.507209445819916`", ",", 
              RowBox[{"-", "2.3131470319159875`"}]}], "}"}], ",", 
            RowBox[{"-", "136.03444154204675`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012615619355837918`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.212331653106352`", ",", 
              RowBox[{"-", "0.0695994659840488`"}]}], "}"}], ",", 
            "167.86028191679753`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012577171129079178`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.165340332262248`", ",", 
              RowBox[{"-", "0.05949132258521739`"}]}], "}"}], ",", 
            "165.9539556971546`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011796908609508758`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.448658799778517`", ",", "2.1357213457488884`"}], 
             "}"}], ",", "78.0887991823601`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011759641439691458`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.493406679852289`", ",", "2.34785971181047`"}], "}"}], 
            ",", "80.15945708104249`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020972257656129187`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1162682073205294`", ",", "2.5548130859784597`"}], 
             "}"}], ",", "100.25015419620841`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02092037523015651`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.065798112577622`", ",", "2.833912076653831`"}], "}"}],
             ",", "100.49604905092319`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10822466444132209`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6055738337734273`", ",", "0.6567341618634729`"}], 
             "}"}], ",", "154.21157067505465`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1079533728649814`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4061119345070474`", ",", "0.7531081223307664`"}], 
             "}"}], ",", "154.736729051692`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04162120841637863`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8962224611401854`", ",", 
              RowBox[{"-", "1.5783964706025564`"}]}], "}"}], ",", 
            RowBox[{"-", "149.3681960317866`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0413847438651463`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.750287447374651`", ",", 
              RowBox[{"-", "1.6648115713326714`"}]}], "}"}], ",", 
            RowBox[{"-", "145.2667701542009`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01609940323919443`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.421649245250298`", ",", 
              RowBox[{"-", "3.0825725534329287`"}]}], "}"}], ",", 
            RowBox[{"-", "68.40439585126742`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01600462836506241`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.532067868258321`", ",", 
              RowBox[{"-", "3.3615206858124775`"}]}], "}"}], ",", 
            RowBox[{"-", "72.61218124421205`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01174262446037085`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.016042773262057`", ",", 
              RowBox[{"-", "1.6516751997741703`"}]}], "}"}], ",", 
            RowBox[{"-", "42.055082646718844`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011708367027352314`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.108282798810705`", ",", 
              RowBox[{"-", "1.7348892010832604`"}]}], "}"}], ",", 
            RowBox[{"-", "40.36563747215957`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00928084755918825`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.262747380025582`", ",", "2.9608335378144637`"}], 
             "}"}], ",", "146.6732279897899`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009257721782905237`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.930376204807889`", ",", "3.179382975753243`"}], "}"}],
             ",", "147.09506037963934`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015965759604935754`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.976035586645406`", ",", "2.6360109109681593`"}], 
             "}"}], ",", "92.92439388739398`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015890154412593283`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.965115949693173`", ",", "2.849766562718292`"}], "}"}],
             ",", "89.38442127670436`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12507112856901748`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.575596281441464`", ",", 
              RowBox[{"-", "2.0742213214166454`"}]}], "}"}], ",", 
            RowBox[{"-", "104.22721356045932`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1247474454342944`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.497597923677322`", ",", 
              RowBox[{"-", "2.381853343242259`"}]}], "}"}], ",", 
            RowBox[{"-", "103.33176350534004`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040650469734116866`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.300925599643978`", ",", "1.8751161064027455`"}], 
             "}"}], ",", "111.51570916001243`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040521575965739895`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.213321694087746`", ",", "2.097332886682772`"}], "}"}],
             ",", "109.42867579011366`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008716130687246871`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.597317163585998`", ",", "0.2927098512295937`"}], 
             "}"}], ",", "155.0262386167547`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008365667326248064`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.363415043055312`", ",", "0.4016498220837778`"}], 
             "}"}], ",", "164.96843174938104`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015605746006908698`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.063027041023098`", ",", 
              RowBox[{"-", "0.7413790643896072`"}]}], "}"}], ",", 
            RowBox[{"-", "163.0050963020401`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015445256537428079`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.900853631799341`", ",", 
              RowBox[{"-", "0.7909446785446752`"}]}], "}"}], ",", 
            RowBox[{"-", "168.82386758263664`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.264418322839897`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.87725476830333`", ",", 
              RowBox[{"-", "1.3985091703707337`"}]}], "}"}], ",", 
            RowBox[{"-", "99.32093880426889`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2626869904616622`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.876882042036348`", ",", 
              RowBox[{"-", "1.4007800698946995`"}]}], "}"}], ",", 
            RowBox[{"-", "94.79902957824035`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2783195089094803`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.665234411496248`", ",", 
              RowBox[{"-", "1.0794506771927341`"}]}], "}"}], ",", 
            RowBox[{"-", "65.83424197334318`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2775450987620716`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.68024549226014`", ",", 
              RowBox[{"-", "1.1129053057541303`"}]}], "}"}], ",", 
            RowBox[{"-", "64.41005134882556`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025178007031378655`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4586303530034055`", ",", 
              RowBox[{"-", "0.17982614486075948`"}]}], "}"}], ",", 
            RowBox[{"-", "106.61335277770561`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024994843945423804`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.409973767999245`", ",", 
              RowBox[{"-", "0.34290258960178854`"}]}], "}"}], ",", 
            RowBox[{"-", "101.78537167066156`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021064131802596874`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.093840169841501`", ",", "0.11788342776077729`"}], 
             "}"}], ",", "2.8530789865829815`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02095541557519201`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.099263833995069`", ",", "0.11815372593931085`"}], 
             "}"}], ",", "6.662389654044234`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012492412889860909`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.569808117033248`", ",", "1.2291413933762683`"}], 
             "}"}], ",", "164.5401155376169`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012452970345813984`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.364174656875045`", ",", "1.2860135822578602`"}], 
             "}"}], ",", "166.60832507804955`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1778049399379028`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.61876224892598`", ",", "0.6526344388411479`"}], "}"}],
             ",", 
            RowBox[{"-", "118.72060857866711`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17701340302364668`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.586204528821855`", ",", "0.5932172930600468`"}], 
             "}"}], ",", 
            RowBox[{"-", "122.06163412899105`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010760883104749801`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.150151747661281`", ",", "0.39767247546671286`"}], 
             "}"}], ",", 
            RowBox[{"-", "74.52641263765771`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010734358805697898`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1720769430198406`", ",", "0.31847101385484194`"}], 
             "}"}], ",", 
            RowBox[{"-", "74.48866434100958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3653634688767773`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.184201931052216`", ",", "2.420319605206351`"}], "}"}],
             ",", "122.41950207272322`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3145257902223082`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.133875783682815`", ",", "2.4995612934954696`"}], 
             "}"}], ",", "132.10878784451558`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04894479838493547`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.013927724321256`", ",", "2.6322695172548927`"}], 
             "}"}], ",", 
            RowBox[{"-", "157.48371150834726`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26286243769164735`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.585569373781221`", ",", "2.3098714954677755`"}], 
             "}"}], ",", "167.77483030281076`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25418655224553155`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.496013510024986`", ",", "2.3292753428951984`"}], 
             "}"}], ",", "158.4757791277915`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008389534193592906`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.311736426290701`", ",", "2.4019540191871216`"}], 
             "}"}], ",", "86.37417481688229`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2609142231095817`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.226143229094154`", ",", "1.6084734436314265`"}], 
             "}"}], ",", 
            RowBox[{"-", "95.2225753837778`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25967082701411404`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.210443865659897`", ",", "1.4367162884544131`"}], 
             "}"}], ",", 
            RowBox[{"-", "91.66250657688619`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07592309495952186`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.084613540559982`", ",", "0.6849672883762922`"}], 
             "}"}], ",", 
            RowBox[{"-", "120.93163220409305`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0757219415205776`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.074604986041667`", ",", "0.6682651451625644`"}], 
             "}"}], ",", 
            RowBox[{"-", "119.83883837592617`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024443425565811028`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.517440732883323`", ",", "0.8653015214522295`"}], 
             "}"}], ",", 
            RowBox[{"-", "113.50049828173712`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024305773443645085`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.419272103491942`", ",", "0.6395345000659645`"}], 
             "}"}], ",", 
            RowBox[{"-", "109.42560489874994`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19819493285909787`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.432955462470727`", ",", 
              RowBox[{"-", "0.16461433324118624`"}]}], "}"}], ",", 
            RowBox[{"-", "82.01973672281233`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19770644826205294`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.455973551255673`", ",", 
              RowBox[{"-", "0.3288069164334586`"}]}], "}"}], ",", 
            RowBox[{"-", "82.02393737999826`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3339796957629762`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.095547716240053`", ",", "1.1493290099655205`"}], 
             "}"}], ",", 
            RowBox[{"-", "179.38984425379292`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.32382384725927527`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.079872856413603`", ",", "1.1491620785190124`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.3518350894107`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00984702356572182`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.884183329433145`", ",", "1.1158944386613112`"}], 
             "}"}], ",", 
            RowBox[{"-", "97.04462264003966`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2842144583096899`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.349677723758777`", ",", "0.9390518793580136`"}], 
             "}"}], ",", "171.48126428088597`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2833336055578053`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.172850117231622`", ",", "0.9655380592388819`"}], 
             "}"}], ",", "169.49677804146384`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28852975875938647`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3824431749592`", ",", "1.0217437832545335`"}], "}"}], 
            ",", 
            RowBox[{"-", "172.02806796878383`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2878040356395935`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1976610322841617`", ",", "0.995866649072636`"}], 
             "}"}], ",", 
            RowBox[{"-", "172.60358933762132`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009077373524557748`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.645263755494122`", ",", 
              RowBox[{"-", "1.866185420573217`"}]}], "}"}], ",", 
            RowBox[{"-", "76.967534473915`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009043961861891115`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.699133125138902`", ",", 
              RowBox[{"-", "2.0989175663572746`"}]}], "}"}], ",", 
            RowBox[{"-", "74.28320774432814`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1775323864292164`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.211612833848461`", ",", "3.428151601916212`"}], "}"}],
             ",", "80.06422382915423`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17705865641862906`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.235215586903052`", ",", "3.562892476138304`"}], "}"}],
             ",", "78.91772233046699`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09262207114120274`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.560121556279733`", ",", "3.120599832514311`"}], "}"}],
             ",", "83.06787886081018`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08926632481016271`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.598423449002021`", ",", "3.4356287083046526`"}], 
             "}"}], ",", "92.6680666858998`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.8533964366538942`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.138474141033417`", ",", "2.894172329501781`"}], "}"}],
             ",", "151.84290338693978`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.8485406563067763`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.080013278153141`", ",", "2.925462430168098`"}], "}"}],
             ",", "152.84609257627184`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4221363429971257`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.821355136964984`", ",", "2.914793700563985`"}], "}"}],
             ",", "110.8386431832023`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.420515972296579`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.75847914606916`", ",", "3.0799802186572953`"}], "}"}],
             ",", "108.00199375236859`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015808362976243297`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.30327979785749`", ",", "3.0437173209918855`"}], "}"}],
             ",", "91.2669119819533`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015685949146524682`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.300767807755573`", ",", "3.1573029335704743`"}], 
             "}"}], ",", "96.27489107120314`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23656307409766864`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.4372327959670805`", ",", "3.147729248239088`"}], 
             "}"}], ",", "26.563283319928495`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.235847264520867`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.668793819653014`", ",", "3.263500829221451`"}], "}"}],
             ",", "24.69116887325459`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013993449232803616`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.5885091764360935`", ",", "3.0710654143640497`"}], 
             "}"}], ",", 
            RowBox[{"-", "38.14034534209651`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013015058505972097`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.751131827436362`", ",", "2.943367950001699`"}], "}"}],
             ",", 
            RowBox[{"-", "50.00884528879269`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1649111347559417`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3812716959614155`", ",", "2.6789453650180284`"}], 
             "}"}], ",", "3.123947752505863`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16398664728395093`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.58057510902941`", ",", "2.6898228005408806`"}], "}"}],
             ",", "7.185175570976962`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10232167098973927`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.644278954911342`", ",", "1.9798251660506894`"}], 
             "}"}], ",", 
            RowBox[{"-", "58.08491668160822`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.101642624684561`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.730922672863257`", ",", "1.8407078588253922`"}], 
             "}"}], ",", 
            RowBox[{"-", "62.646162014212244`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06301951992816199`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.118213821951841`", ",", "2.1161797360726418`"}], 
             "}"}], ",", 
            RowBox[{"-", "92.38539058884155`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06268682856734187`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.116121369485934`", ",", "2.0659492119851817`"}], 
             "}"}], ",", 
            RowBox[{"-", "96.26415558560664`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03959662513359669`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.60282190644634`", ",", "2.1683820226624086`"}], "}"}],
             ",", 
            RowBox[{"-", "155.53381477539193`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037343383810377724`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.528702525048912`", ",", "2.1346566890071426`"}], 
             "}"}], ",", 
            RowBox[{"-", "144.40550687143758`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024574604969250673`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.108774052035784`", ",", "2.8195567145089377`"}], 
             "}"}], ",", "151.89060699847738`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024488139417201616`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.033330609019542`", ",", "2.859855657210858`"}], "}"}],
             ",", "149.37635128414962`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015219042250939311`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.781731117882949`", ",", "2.928205971915999`"}], "}"}],
             ",", "112.3688427895573`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015088822067630016`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.714349277427727`", ",", "3.0919392338751`"}], "}"}], 
            ",", "107.07482646988583`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009479447854324441`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.634090986696744`", ",", "3.6286175405357364`"}], 
             "}"}], ",", "59.46488109561347`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009450198465022392`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.647119825236141`", ",", "3.6507051496787444`"}], 
             "}"}], ",", "57.500779366055596`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08315130246786985`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.832018778269499`", ",", "0.5492703607319532`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.2842907745251`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08263711157970306`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6155978878735318`", ",", "0.4541974514948907`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.63810193097012`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03749845497090089`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8547025614206625`", ",", "1.5800455557922033`"}], 
             "}"}], ",", "146.033147234811`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037399703149124115`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.828195341595365`", ",", "1.5979025979241401`"}], 
             "}"}], ",", "147.07852249227477`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09090324594386706`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.613741195307599`", ",", "1.2388990593583549`"}], 
             "}"}], ",", "179.2066549812073`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09066534806994662`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.409518578935311`", ",", "1.2417270050109548`"}], 
             "}"}], ",", 
            RowBox[{"-", "179.79940082155636`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02157165976363377`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.090100669028041`", ",", "0.7405292894550553`"}], 
             "}"}], ",", 
            RowBox[{"-", "131.7796425524056`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02145096558646744`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{
                "0.`", ",", "0.9999999999999999`", ",", 
                 "167.35910683550452`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.047734840827478`", ",", "0.6931117933551798`"}], 
             "}"}], ",", 
            RowBox[{"-", "135.83498068412567`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008362954487302588`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.021253812479882`", ",", 
              RowBox[{"-", "1.1394772355398624`"}]}], "}"}], ",", 
            RowBox[{"-", "81.07897379694441`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008296795959606034`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.054017287501334`", ",", 
              RowBox[{"-", "1.3481992558309215`"}]}], "}"}], ",", 
            RowBox[{"-", "86.14834536993936`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009134758395587078`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.090697161067123`", ",", 
              RowBox[{"-", "0.5731585137979203`"}]}], "}"}], ",", 
            RowBox[{"-", "37.7267099736295`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009110517163747832`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.163270847579373`", ",", 
              RowBox[{"-", "0.6293038944579838`"}]}], "}"}], ",", 
            RowBox[{"-", "38.831914732003305`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1531548304713613`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6713872384178625`", ",", "1.2136497580075274`"}], 
             "}"}], ",", "156.62558654030545`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15200720131031964`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4149910609401246`", ",", "1.324466377966882`"}], 
             "}"}], ",", "161.53897947659965`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00994207040976963`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.062560437831467`", ",", 
              RowBox[{"-", "1.1680963505251802`"}]}], "}"}], ",", 
            "161.25599874964854`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00932575546924344`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9761983032071324`", ",", 
              RowBox[{"-", "1.13879043959612`"}]}], "}"}], ",", 
            "149.8235559091691`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16795478087493373`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0912834629691233`", ",", 
              RowBox[{"-", "1.7539364159912485`"}]}], "}"}], ",", 
            RowBox[{"-", "121.79615629492594`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16675850431367437`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0188197633552356`", ",", 
              RowBox[{"-", "1.8708259074624283`"}]}], "}"}], ",", 
            RowBox[{"-", "117.02930405838666`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008928082137123013`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.589344272267322`", ",", 
              RowBox[{"-", "2.1020351712178833`"}]}], "}"}], ",", 
            RowBox[{"-", "70.29536708781251`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008878183979121459`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7667858207547886`", ",", 
              RowBox[{"-", "2.597483960778643`"}]}], "}"}], ",", 
            RowBox[{"-", "74.34739622491725`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.042764624025935026`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5671895390265544`", ",", "2.1378958136711663`"}], 
             "}"}], ",", "121.71922033132392`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.042428635352687254`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4381985078642834`", ",", "2.3465934659157877`"}], 
             "}"}], ",", "116.66958854196835`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04909041915403561`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.380048048528092`", ",", "2.0105057011738268`"}], 
             "}"}], ",", "113.47347915789351`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04895945632813861`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.3348175139279395`", ",", "2.1146606225039792`"}], 
             "}"}], ",", "114.61825029828553`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012694726333383463`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.84117167131676`", ",", "0.5997028117287332`"}], "}"}],
             ",", 
            RowBox[{"-", "171.41597965315103`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012657291554271059`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.605395170373543`", ",", "0.5641122271604382`"}], 
             "}"}], ",", 
            RowBox[{"-", "169.67120727802637`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18631454395185035`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.224191606502897`", ",", "2.8622039459876105`"}], 
             "}"}], ",", "141.71787406473283`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18578832793871375`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.137604686626926`", ",", "2.930542326395737`"}], "}"}],
             ",", "143.23011788787363`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032578850988604406`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.093661954241497`", ",", "1.5245104065784694`"}], 
             "}"}], ",", 
            RowBox[{"-", "50.00123276239287`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03245583209334701`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1663719160576385`", ",", "1.4378542619639703`"}], 
             "}"}], ",", 
            RowBox[{"-", "52.778938645696854`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013781130053024898`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.7707649418967755`", ",", "1.571081812287572`"}], 
             "}"}], ",", 
            RowBox[{"-", "71.37694427297221`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013513575193398476`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.829062553610241`", ",", "1.3980842767110477`"}], 
             "}"}], ",", 
            RowBox[{"-", "79.03865199936881`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019117468852863858`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.327120076572609`", ",", "2.606217434266993`"}], "}"}],
             ",", 
            RowBox[{"-", "167.26644640935822`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019059989290064604`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.191739739163332`", ",", "2.5756248385797793`"}], 
             "}"}], ",", 
            RowBox[{"-", "165.4251327182077`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07845606345703046`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.829041889572819`", ",", "3.1787664066759094`"}], 
             "}"}], ",", 
            RowBox[{"-", "0.5788102118144657`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07814151938321014`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.0636939052972245`", ",", "3.176395837595149`"}], 
             "}"}], ",", "2.4107247662341544`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.741707248655444`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.883506851961149`", ",", "3.3440089025840014`"}], 
             "}"}], ",", "79.52755809706962`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.7307488563514473`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.887209292294565`", ",", "3.364039245201363`"}], "}"}],
             ",", "77.81791642396212`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010926298301470265`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.942088537623861`", ",", "3.6182506337634655`"}], 
             "}"}], ",", 
            RowBox[{"-", "70.43622179475737`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07532887276321726`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.730079919853941`", ",", "3.4260557860474723`"}], 
             "}"}], ",", "159.6339264059539`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07514292080116731`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.614471715614493`", ",", "3.468972186371477`"}], "}"}],
             ",", "159.79349961118885`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.019169158045519`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.090703027845902`", ",", "2.372357661055526`"}], "}"}],
             ",", 
            RowBox[{"-", "56.181361753542106`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013783292482927213`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.589205417729699`", ",", "2.225663533370224`"}], "}"}],
             ",", 
            RowBox[{"-", "153.04376378388602`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01242147399553092`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.358245643211889`", ",", "2.1082057756821846`"}], 
             "}"}], ",", 
            RowBox[{"-", "166.22477712637897`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03266024374529178`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1144186586145235`", ",", "2.7118462900651146`"}], 
             "}"}], ",", "159.6748300635305`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03254310426332896`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.908658190760104`", ",", "2.788062173697886`"}], "}"}],
             ",", "162.26230644099616`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1740479652495941`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.113793252067586`", ",", "1.4194705564399406`"}], 
             "}"}], ",", 
            RowBox[{"-", "13.611531892051671`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1732988597622128`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.169498280706339`", ",", "1.4059822232091812`"}], 
             "}"}], ",", 
            RowBox[{"-", "16.84148892279766`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012521240303991646`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.694976960098423`", ",", "0.14421027926079488`"}], 
             "}"}], ",", 
            RowBox[{"-", "141.0872728616609`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01249019145047567`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.66760203244225`", ",", "0.12211145550534279`"}], 
             "}"}], ",", 
            RowBox[{"-", "141.4015572207307`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08317749832810706`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1565195605696372`", ",", "1.3367049720306945`"}], 
             "}"}], ",", "165.9308059330319`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08249257582622119`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0764932009547103`", ",", "1.3567604682757834`"}], 
             "}"}], ",", "160.7465129925466`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008843443212274158`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.388221823160652`", ",", "2.9095274470816745`"}], 
             "}"}], ",", "87.47340099626096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008649489005714219`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.388688848237903`", ",", "2.920111326351133`"}], "}"}],
             ",", "79.44573838084902`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014624819685761025`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.675537600714022`", ",", "2.844785459439058`"}], "}"}],
             ",", "93.28176069092505`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011409047810579394`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6666652177736796`", ",", "2.9995176613208825`"}], 
             "}"}], ",", "109.89286470521824`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.221655169890112`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3314682700404803`", ",", "2.4287451418733497`"}], 
             "}"}], ",", "158.7171791148065`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22105176618492475`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2138668225961746`", ",", "2.4745554143657085`"}], 
             "}"}], ",", "160.00303000624257`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012800904582199806`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4118601926906513`", ",", "1.9774712451865195`"}], 
             "}"}], ",", 
            RowBox[{"-", "110.13260484720092`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012760774007616042`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3814054766801434`", ",", "1.8943963373611692`"}], 
             "}"}], ",", 
            RowBox[{"-", "112.16910139086357`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008193712934874038`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.345010882115403`", ",", "1.4163935745926908`"}], 
             "}"}], ",", 
            RowBox[{"-", "122.81525962062665`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008172425749640224`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3381077552641885`", ",", "1.405688281109693`"}], 
             "}"}], ",", 
            RowBox[{"-", "121.88467502705065`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012184455247384334`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3311028726883682`", ",", 
              RowBox[{"-", "2.9944225439346672`"}]}], "}"}], ",", 
            RowBox[{"-", "144.41984490539085`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012080212992138361`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9000758278077194`", ",", 
              RowBox[{"-", "3.30278184605173`"}]}], "}"}], ",", 
            RowBox[{"-", "149.7135103897125`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01749894099858938`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.770942851840212`", ",", 
              RowBox[{"-", "3.9269453409866735`"}]}], "}"}], ",", 
            RowBox[{"-", "63.84944227105288`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01744661169277578`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.968359650415052`", ",", 
              RowBox[{"-", "4.329024738210822`"}]}], "}"}], ",", 
            RowBox[{"-", "65.66427169638028`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011655650103300682`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.2854634585950215`", ",", "2.930051637924093`"}], 
             "}"}], ",", "4.071825088794249`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011625347850951798`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.330169129435359`", ",", "2.933234084288223`"}], "}"}],
             ",", "5.008590864257576`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026032176261107487`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.653245556053751`", ",", 
              RowBox[{"-", "3.501540898488227`"}]}], "}"}], ",", 
            RowBox[{"-", "48.75905679506792`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02451448565971566`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.773889911495325`", ",", 
              RowBox[{"-", "3.6391532943810976`"}]}], "}"}], ",", 
            RowBox[{"-", "59.972955689147874`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00832203806118468`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.421968446816875`", ",", 
              RowBox[{"-", "1.7712630858995746`"}]}], "}"}], ",", 
            "4.559118332117152`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008301303467120947`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.607815702618099`", ",", 
              RowBox[{"-", "1.7564436272019612`"}]}], "}"}], ",", 
            "4.979039262037431`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008664152882538302`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7481042170747867`", ",", "2.8938741145769025`"}], 
             "}"}], ",", "64.17011110860926`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008566952064386606`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8509603849960232`", ",", "3.1063593674367422`"}], 
             "}"}], ",", "70.23721468259609`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3746654523928048`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.656496102702559`", ",", "2.8886382820148584`"}], 
             "}"}], ",", "153.6344418079624`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3737409020829626`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6041384557393847`", ",", "2.9145896264108724`"}], 
             "}"}], ",", "153.77503772689917`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00853776203299345`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1617716970949905`", ",", "1.7234169393512568`"}], 
             "}"}], ",", 
            RowBox[{"-", "155.94366928849846`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008495656917114966`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0981549132147475`", ",", "1.6950179459541808`"}], 
             "}"}], ",", 
            RowBox[{"-", "152.2756895282689`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009198770556912162`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.858952183105744`", ",", "2.80193995526425`"}], "}"}], 
            ",", "26.458345282128356`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009084833907498703`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.340608338011412`", ",", "3.0416477975838894`"}], 
             "}"}], ",", "20.10785183101982`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02431882532272911`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8724930742377612`", ",", 
              RowBox[{"-", "0.8881629628885982`"}]}], "}"}], ",", 
            RowBox[{"-", "164.09876531973046`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022553581274540324`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8708371103867525`", ",", 
              RowBox[{"-", "0.888634715180869`"}]}], "}"}], ",", 
            RowBox[{"-", "176.10515322729353`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013066833339828143`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3099577862941993`", ",", 
              RowBox[{"-", "1.0111371331343069`"}]}], "}"}], ",", 
            "174.6000298845525`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013032187873623657`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1558050837059786`", ",", 
              RowBox[{"-", "0.9965654936102184`"}]}], "}"}], ",", 
            "175.69852476567385`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009159797611967821`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.335307961329535`", ",", "0.9947123023651957`"}], 
             "}"}], ",", "141.84427875817943`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008516651925285315`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.167880082384757`", ",", "1.1262556643233088`"}], 
             "}"}], ",", "153.72828314249105`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018436223252223514`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.9507690227662335`", ",", "0.8052219787546446`"}], 
             "}"}], ",", "73.05532981668725`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01839062436127478`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.976217467467496`", ",", "0.8887484947175992`"}], 
             "}"}], ",", "72.81659809803868`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013276518276663214`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.639163844367371`", ",", "0.35600074813492016`"}], 
             "}"}], ",", "111.6928538339839`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013169861514621333`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5917685741927246`", ",", "0.47514305546185914`"}], 
             "}"}], ",", "116.80633978204133`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02064081004072096`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.364338814151551`", ",", 
              RowBox[{"-", "1.8536428419150592`"}]}], "}"}], ",", 
            RowBox[{"-", "165.63105680552104`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02036317876011437`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.301717809521697`", ",", 
              RowBox[{"-", "1.869685007195425`"}]}], "}"}], ",", 
            RowBox[{"-", "172.21864653571396`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03963360653490009`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.388525244576338`", ",", 
              RowBox[{"-", "2.6663777250317304`"}]}], "}"}], ",", 
            RowBox[{"-", "115.9219753493684`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039526969423696795`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.385285491719142`", ",", 
              RowBox[{"-", "2.67304322521958`"}]}], "}"}], ",", 
            RowBox[{"-", "117.12793973260845`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015544163493847673`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.618630463181174`", ",", 
              RowBox[{"-", "2.1975476124328246`"}]}], "}"}], ",", 
            RowBox[{"-", "173.6903876126035`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015505816997499491`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.383847382218892`", ",", 
              RowBox[{"-", "2.223507775755651`"}]}], "}"}], ",", 
            RowBox[{"-", "173.56806680410423`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015434845306351783`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.10977393330874`", ",", 
              RowBox[{"-", "1.6417027819848846`"}]}], "}"}], ",", 
            "102.79974972278914`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015348831316798414`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.10964461137912`", ",", 
              RowBox[{"-", "1.6411335578766304`"}]}], "}"}], ",", 
            "106.84302650066583`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02112427731894346`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.232240954122844`", ",", 
              RowBox[{"-", "0.5926830924116476`"}]}], "}"}], ",", 
            "68.35366889052445`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02101616993305529`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.307891776053028`", ",", 
              RowBox[{"-", "0.40206142026351155`"}]}], "}"}], ",", 
            "72.13683617343219`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013463256595579277`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.436956136237303`", ",", 
              RowBox[{"-", "0.4163147868373776`"}]}], "}"}], ",", 
            "119.60905530158598`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013327980320105749`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.378723026894536`", ",", 
              RowBox[{"-", "0.3138436879739406`"}]}], "}"}], ",", 
            "125.36156348366431`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01920166268202976`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.902025869288929`", ",", 
              RowBox[{"-", "0.9353251541593269`"}]}], "}"}], ",", 
            "160.13516849813638`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0191355626097128`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.425748637850462`", ",", 
              RowBox[{"-", "0.7632457802846241`"}]}], "}"}], ",", 
            "162.56415410757737`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09291268710968995`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.317042174504154`", ",", 
              RowBox[{"-", "2.496568643107816`"}]}], "}"}], ",", 
            RowBox[{"-", "131.97554935272328`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09250139933565829`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.267414443626319`", ",", 
              RowBox[{"-", "2.551733145538712`"}]}], "}"}], ",", 
            RowBox[{"-", "128.65301474744336`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012538840079773187`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.865264422165415`", ",", "0.01558219543576532`"}], 
             "}"}], ",", "164.0476294775115`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01201232796385104`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5553008412191462`", ",", "0.10418403203907302`"}], 
             "}"}], ",", "174.13396154784553`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011722491999187169`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.547614972963494`", ",", "2.660373650005636`"}], "}"}],
             ",", "82.2301149797245`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010454560928429111`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.554837225932531`", ",", "2.7133042740968643`"}], 
             "}"}], ",", "68.68995299772382`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020868621154033862`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.015837296923768`", ",", "3.1035802932107157`"}], 
             "}"}], ",", "100.74194390563649`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020816945212477858`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.969200230953496`", ",", "3.3494134145434793`"}], 
             "}"}], ",", "100.46595710605715`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10768276134729257`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1844334948319033`", ",", "0.8577212354772984`"}], 
             "}"}], ",", "155.26188742832935`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10737113842549359`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1176780270552102`", ",", "0.888479135663443`"}], 
             "}"}], ",", "153.61507343154858`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04114962275121717`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.566128926377194`", ",", 
              RowBox[{"-", "1.7924870565715108`"}]}], "}"}], ",", 
            RowBox[{"-", "141.16534427661526`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03958053518457367`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4861205041345973`", ",", 
              RowBox[{"-", "1.8568951960375732`"}]}], "}"}], ",", 
            RowBox[{"-", "131.3980387215106`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015910411416999663`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.613537725456426`", ",", 
              RowBox[{"-", "3.6216851368345666`"}]}], "}"}], ",", 
            RowBox[{"-", "76.8199666371566`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01580250332956923`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.625609448203834`", ",", 
              RowBox[{"-", "3.6732339857997185`"}]}], "}"}], ",", 
            RowBox[{"-", "72.19531634797086`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011674209535511395`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.322692665885227`", ",", 
              RowBox[{"-", "1.9171446844618552`"}]}], "}"}], ",", 
            RowBox[{"-", "38.6761922976005`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011632371798397366`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.338693997548402`", ",", 
              RowBox[{"-", "1.9299532556065953`"}]}], "}"}], ",", 
            RowBox[{"-", "36.0917061542994`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009234653630834382`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6460075670016345`", ",", "3.363384076381549`"}], 
             "}"}], ",", "147.5168927694888`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009210907228012639`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.641308145352485`", ",", "3.366375990633749`"}], "}"}],
             ",", "146.68300441369152`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015814907245503013`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.967666509375516`", ",", "3.0871540433788582`"}], 
             "}"}], ",", "85.84444866601483`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015766487599311256`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9869882325984545`", ",", "3.3530902027251317`"}], 
             "}"}], ",", "87.77233120355793`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12442459998907568`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.425253906713074`", ",", 
              RowBox[{"-", "2.687134026360825`"}]}], "}"}], ",", 
            RowBox[{"-", "102.43631345021912`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12334643097475351`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.419796584842048`", ",", 
              RowBox[{"-", "2.7118805555779257`"}]}], "}"}], ",", 
            RowBox[{"-", "107.76645659227735`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04039309089137395`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.118134773638745`", ",", "2.367199620738484`"}], "}"}],
             ",", "107.34164242021471`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040222472700680044`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.117789784286584`", ",", "2.3683044252525343`"}], 
             "}"}], ",", "110.50893237897267`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008029295604281504`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.182146425329703`", ",", "0.4503276617857824`"}], 
             "}"}], ",", "174.91062488200723`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00800139876845557`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.0872471334290434`", ",", "0.4587794600283177`"}], 
             "}"}], ",", "172.44533634568973`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015286417541420677`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.68166825234663`", ",", 
              RowBox[{"-", "0.834249674863952`"}]}], "}"}], ",", 
            RowBox[{"-", "174.64263886323312`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015117817506643988`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.601379121612772`", ",", 
              RowBox[{"-", "0.8417789523378222`"}]}], "}"}], ",", 
            RowBox[{"-", "168.6241602326469`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2609669943318832`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.857503797053943`", ",", 
              RowBox[{"-", "1.631596318035911`"}]}], "}"}], ",", 
            RowBox[{"-", "90.27712035221171`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26008655888193055`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.855348031303997`", ",", 
              RowBox[{"-", "2.0773063315811187`"}]}], "}"}], ",", 
            RowBox[{"-", "92.62562768241764`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27677284337226055`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.821491369572861`", ",", 
              RowBox[{"-", "1.4078409622156671`"}]}], "}"}], ",", 
            RowBox[{"-", "62.98586072430847`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27518630244426884`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.85970811237031`", ",", 
              RowBox[{"-", "1.482799807515262`"}]}], "}"}], ",", 
            RowBox[{"-", "58.85763930038267`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024813013320613118`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.360966391982671`", ",", 
              RowBox[{"-", "0.5777872347677663`"}]}], "}"}], ",", 
            RowBox[{"-", "96.95739056361747`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024694866876892138`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.355657786762561`", ",", 
              RowBox[{"-", "0.6212897865834256`"}]}], "}"}], ",", 
            RowBox[{"-", "100.51475375406419`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012413652334497018`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.075636979375578`", ",", "1.354708650666049`"}], "}"}],
             ",", "168.67653461848235`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01047614904650106`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.024587853821008`", ",", "1.3649310161556567`"}], 
             "}"}], ",", "153.60854429084867`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17622538980612734`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.462835957629652`", ",", "0.3962580859494457`"}], 
             "}"}], ",", 
            RowBox[{"-", "125.40265967931498`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17433134228123778`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.401800641306805`", ",", "0.31038149519909297`"}], 
             "}"}], ",", 
            RowBox[{"-", "131.34731050636665`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010707899885893532`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.234378837136803`", ",", "0.09399011306815414`"}], 
             "}"}], ",", 
            RowBox[{"-", "74.45091604437111`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01064693246405689`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.300742584987046`", ",", 
              RowBox[{"-", "0.14451621421034622`"}]}], "}"}], ",", 
            RowBox[{"-", "78.5588596081471`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0508376786544684`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.133875783682815`", ",", "2.4995612934954696`"}], 
             "}"}], ",", "71.3905729691707`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05071237055720806`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.180237032875569`", ",", "2.637246016100087`"}], "}"}],
             ",", "71.427023302306`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2655809918373722`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.013927724321256`", ",", "2.6322695172548927`"}], 
             "}"}], ",", "141.79807361630793`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.258255220130773`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.881221144900748`", ",", "2.7367065227106515`"}], 
             "}"}], ",", "145.95551196524468`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.047122397252328675`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.848681154583996`", ",", "2.563767102786102`"}], "}"}],
             ",", 
            RowBox[{"-", "147.79442573655493`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04227214269382524`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.592467754632565`", ",", "2.4023860998368267`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.136963347192`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008675885446115741`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.496013510024986`", ",", "2.3292753428951984`"}], 
             "}"}], ",", 
            RowBox[{"-", "138.72166773631858`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008125914795933447`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.340774332740918`", ",", "2.1929983763609657`"}], 
             "}"}], ",", 
            RowBox[{"-", "150.23428083855993`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24579701805193852`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.311736426290701`", ",", "2.4019540191871216`"}], 
             "}"}], ",", "149.17672795277224`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24414790491148575`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.132449862213479`", ",", "2.5089289844678593`"}], 
             "}"}], ",", "153.76984430794428`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008112634084741051`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.324263802301104`", ",", "2.5996489822677544`"}], 
             "}"}], ",", "77.07512364186316`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25843335636736947`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.201544877431438`", ",", "1.1301121692279588`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.10243776999438`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25779341729664584`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.20785455614225`", ",", "0.9396647794255726`"}], "}"}],
             ",", 
            RowBox[{"-", "87.82676214747465`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07552132102494946`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.911408050797058`", ",", "0.38375460538032846`"}], 
             "}"}], ",", 
            RowBox[{"-", "118.74604454775931`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.075290895035326`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.878705842196716`", ",", "0.3241365905784629`"}], 
             "}"}], ",", 
            RowBox[{"-", "120.65774906155809`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024168896503610877`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3181519197722915`", ",", "0.352797237396545`"}], 
             "}"}], ",", 
            RowBox[{"-", "105.35071151576268`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024031922073260648`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.29714803826906`", ",", "0.27628610566998607`"}], 
             "}"}], ",", 
            RowBox[{"-", "109.44474058759633`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19721916761708747`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4981801653118625`", ",", 
              RowBox[{"-", "0.6300356770624768`"}]}], "}"}], ",", 
            RowBox[{"-", "82.02813803718419`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1967324479978787`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5252117425817255`", ",", 
              RowBox[{"-", "0.8230631277620201`"}]}], "}"}], ",", 
            RowBox[{"-", "82.17431635125322`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010155848503700847`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.079872856413603`", ",", "1.1491620785190124`"}], 
             "}"}], ",", "125.3789616256004`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00999760033494628`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.946357056947727`", ",", "1.3371832328657298`"}], 
             "}"}], ",", "118.36509974558575`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3139768236935531`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.884183329433145`", ",", "1.1158944386613112`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.31382592502862`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.31318590669708823`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6865304189315635`", ",", "1.0490457747668551`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.91037740502566`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009547589555766872`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.859839177235601`", ",", "0.9188957354033456`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.00661347565753`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00943484333847693`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8632038120715215`", ",", "0.8222252776510854`"}], 
             "}"}], ",", 
            RowBox[{"-", "94.22034170073402`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2824554827921963`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8771242751091632`", ",", "1.0203648055844956`"}], 
             "}"}], ",", "167.51229180204152`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2813076860894983`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.689696749116665`", ",", "1.0618743042281937`"}], 
             "}"}], ",", "170.54833521272116`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.287080137891467`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.851433958250631`", ",", "0.9509216586411364`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.1791107064613`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2857843220414894`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5742653848532453`", ",", "0.9177688138836663`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.56518751062592`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009010673179643778`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.773314947406275`", ",", 
              RowBox[{"-", "2.362531201942003`"}]}], "}"}], ",", 
            RowBox[{"-", "71.59888101474128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00898832765291629`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.925505318214823`", ",", 
              RowBox[{"-", "2.8200025049527064`"}]}], "}"}], ",", 
            RowBox[{"-", "71.2825089684225`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08603215893289086`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.590262861182729`", ",", "3.6107477297384736`"}], 
             "}"}], ",", "102.26825451098945`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08144387988438724`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.58082047593546`", ",", "3.654169993663881`"}], "}"}], 
            ",", "91.36709559311188`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.8436975977941865`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8485975650478776`", ",", "3.044158711728051`"}], 
             "}"}], ",", "153.84928176560356`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.5501949375025736`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7427671292921243`", ",", "3.096120721976002`"}], 
             "}"}], ",", "138.69549935917382`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2467792650334446`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.622847132670974`", ",", "3.201489704433622`"}], "}"}],
             ",", "82.60824634315858`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039285385455173426`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.643384671488563`", ",", "3.3597983825061997`"}], 
             "}"}], ",", "26.52099332714331`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4189018213903022`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.667391997490735`", ",", "3.360284447263403`"}], "}"}],
             ",", "105.16534432153486`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.4172591163243085`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.649074573465307`", ",", "3.427865298501506`"}], "}"}],
             ",", "108.07772044583567`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015564483242010537`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.277758717143984`", ",", "3.366557381576849`"}], "}"}],
             ",", "101.28287016045299`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015523502650433552`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.233858861547429`", ",", "3.5865970474625457`"}], 
             "}"}], ",", "100.23912546621924`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2351336208922049`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.898000674453068`", ",", "3.368881404682121`"}], "}"}],
             ",", "22.81905442658029`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.234174851383517`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.899134242939919`", ",", "3.3693583566555887`"}], 
             "}"}], ",", "25.866816677443797`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012105074674283072`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8574455005292645`", ",", "2.816628517706533`"}], 
             "}"}], ",", 
            RowBox[{"-", "61.877345235488804`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01207483296882638`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.958198181637355`", ",", "2.6281149491080376`"}], 
             "}"}], ",", 
            RowBox[{"-", "61.407861221097846`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16306734246434534`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8427720735431`", ",", "2.7228770601336127`"}], "}"}], 
            ",", "11.246403389447611`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16265773361049068`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.047190372337455`", ",", "2.7635250484531877`"}], 
             "}"}], ",", "10.690146803127895`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10096808479410525`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.820946895856471`", ",", "1.666690518766145`"}], "}"}],
             ",", 
            RowBox[{"-", "67.20740734681608`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09942613898925415`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.867096760510475`", ",", "1.5568645856293863`"}], 
             "}"}], ",", 
            RowBox[{"-", "60.2521408990183`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06235589354395006`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.092211361633606`", ",", "1.8481257845740613`"}], 
             "}"}], ",", 
            RowBox[{"-", "100.14292058237176`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05621955499857236`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.088297965282513`", ",", "1.8262510277303763`"}], 
             "}"}], ",", 
            RowBox[{"-", "86.97759877340057`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035218362921186554`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.387311192534063`", ",", "2.0334509906640714`"}], 
             "}"}], ",", 
            RowBox[{"-", "133.27719896748337`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.034906898048323344`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.277659440999164`", ",", "1.9169985646153616`"}], 
             "}"}], ",", 
            RowBox[{"-", "127.88878569524309`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02440197809350946`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8238202808915664`", ",", "2.9838764681221184`"}], 
             "}"}], ",", "146.86209556982155`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023717147410956534`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.648140038558968`", ",", "3.098566661548034`"}], "}"}],
             ",", "155.64771662742973`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014959716100042153`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.641487887169879`", ",", "3.3291496725314924`"}], 
             "}"}], ",", "101.78081015021438`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014913376547723609`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.624830179117953`", ",", "3.40901924966295`"}], "}"}], 
            ",", "103.76288155218614`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08212610034430937`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3805055831974253`", ",", "0.37158406636224844`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.99191308741524`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08184612156414703`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3641239810316463`", ",", "0.3671921510397863`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.60149143015437`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037301211389323546`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.573649858233891`", ",", "1.7627108399105784`"}], 
             "}"}], ",", "148.12389774973852`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09042807278543785`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.098053619989534`", ",", "1.2406365255603116`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.80545662432036`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09010655765813673`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9358161488169614`", ",", "1.2372535926012982`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.25109455619653`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021330946697367084`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{
                "0.`", ",", "0.9999999999999999`", ",", 
                 "167.35910683550452`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.875021438164752`", ",", "0.5253603907749506`"}], 
             "}"}], ",", 
            RowBox[{"-", "139.89031881584566`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021005434590515924`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.73748714802897`", ",", "0.40950604122527534`"}], 
             "}"}], ",", 
            RowBox[{"-", "146.8433877303675`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008231160805651819`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.070713347817326`", ",", 
              RowBox[{"-", "1.596189391324968`"}]}], "}"}], ",", 
            RowBox[{"-", "91.21771694293415`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008209098769605051`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.065334003334559`", ",", 
              RowBox[{"-", "1.8492591456462795`"}]}], "}"}], ",", 
            RowBox[{"-", "92.39653497720954`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15086817163443453`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2065309528116637`", ",", "1.3940584934118068`"}], 
             "}"}], ",", "166.45237241289396`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1504130030912096`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1330446222023243`", ",", "1.4117656203703455`"}], 
             "}"}], ",", "164.5944072842307`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008747646263565279`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.843136121561057`", ",", 
              RowBox[{"-", "1.0614196196331982`"}]}], "}"}], ",", 
            "138.39111306868983`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008516627514714629`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.374937088589322`", ",", 
              RowBox[{"-", "0.6456031838817202`"}]}], "}"}], ",", 
            "146.98743662182605`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16557074836494867`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.910787109517695`", ",", 
              RowBox[{"-", "2.0825841162416596`"}]}], "}"}], ",", 
            RowBox[{"-", "112.26245182184724`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16220192185862228`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8685673441515807`", ",", 
              RowBox[{"-", "2.1857190069215964`"}]}], "}"}], ",", 
            RowBox[{"-", "120.06429390496052`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008828564696933742`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.836149343049395`", ",", 
              RowBox[{"-", "2.845038464983356`"}]}], "}"}], ",", 
            RowBox[{"-", "78.3994253620219`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00854113758069572`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9074945903586378`", ",", 
              RowBox[{"-", "3.192587711922769`"}]}], "}"}], ",", 
            RowBox[{"-", "87.65461849933202`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.042095286440483146`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3278659338480487`", ",", "2.5662557517157665`"}], 
             "}"}], ",", "111.61995675261286`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0419764609277312`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.311936366792392`", ",", "2.6064483382348436`"}], 
             "}"}], ",", "110.11090334571954`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04882884288328304`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.199617787190727`", ",", "2.409714096482288`"}], "}"}],
             ",", "115.7630214386782`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04847285641668143`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.180860665318691`", ",", "2.4485790599121247`"}], 
             "}"}], ",", "120.59725946101781`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01261996716451644`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3170462945642005`", ",", "0.5115606526621097`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.9264349029009`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01255782721996194`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1737449217559712`", ",", "0.4809086478989754`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.5895253900572`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18526359813962467`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.886521337520707`", ",", "3.1181709029604834`"}], 
             "}"}], ",", "144.7423617110144`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18475735323859188`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.885546272031111`", ",", "3.1188602060507615`"}], 
             "}"}], ",", "143.43168369151715`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03233327772179539`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.352014452126943`", ",", "1.193465846067691`"}], "}"}],
             ",", 
            RowBox[{"-", "55.556644529000955`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03223665902254091`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.38442038266304`", ",", "1.146214917856264`"}], "}"}], 
            ",", 
            RowBox[{"-", "53.745465952900496`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01325121479914858`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.869205868538643`", ",", "1.1908184192383027`"}], 
             "}"}], ",", 
            RowBox[{"-", "86.70035972576531`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012955010863459836`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.876421105352835`", ",", "1.0656697795973613`"}], 
             "}"}], ",", 
            RowBox[{"-", "78.61513400628635`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019002682548268236`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.882439085046726`", ",", "2.4952029161458746`"}], 
             "}"}], ",", 
            RowBox[{"-", "163.58381902705713`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018857482624384282`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.665748465648419`", ",", "2.431360896350264`"}], "}"}],
             ",", 
            RowBox[{"-", "168.55344279014494`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07782823637156928`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.36873589652042`", ",", "3.1892380843199777`"}], "}"}],
             ",", "5.400259744282775`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07761646722590164`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.586433657280547`", ",", "3.2098175772256794`"}], 
             "}"}], ",", "6.68298361454642`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01095839230399624`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.887209292294565`", ",", "3.364039245201363`"}], "}"}],
             ",", 
            RowBox[{"-", "135.6375870304259`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010926500070207843`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.878341464867088`", ",", "3.355366615909915`"}], "}"}],
             ",", 
            RowBox[{"-", "137.31434324941807`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01089429829311552`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.0291737225527635`", ",", "3.3731969004548623`"}], 
             "}"}], ",", 
            RowBox[{"-", "72.14586346786507`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010715530046262984`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.05028264096431`", ",", "3.3076631218756067`"}], "}"}],
             ",", 
            RowBox[{"-", "64.98084543721473`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07495742786805175`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.3305081301654775`", ",", "3.5734870220448216`"}], 
             "}"}], ",", "159.95307281642837`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07455453200892936`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.316650533579623`", ",", "3.5785436319596386`"}], 
             "}"}], ",", "156.01935726915286`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019117156574398258`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.258892531326898`", ",", "2.1212958894635108`"}], 
             "}"}], ",", 
            RowBox[{"-", "57.44385450554936`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015863803786497575`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.319072018686604`", ",", "2.0270369739297505`"}], 
             "}"}], ",", 
            RowBox[{"-", "72.8902545685189`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011194206058731483`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.195563023826857`", ",", "2.0683216790920302`"}], 
             "}"}], ",", 
            RowBox[{"-", "179.4057904688717`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011050292583148413`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.114170409498007`", ",", "2.067477533124626`"}], "}"}],
             ",", 
            RowBox[{"-", "172.94833868944104`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032426384914735054`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.631857465184819`", ",", "2.876601243636376`"}], "}"}],
             ",", "164.84978281846182`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03227175994160671`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.630982662709606`", ",", "2.876838106199413`"}], "}"}],
             ",", "161.28774808691148`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012459219588637941`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.428739814516301`", ",", 
              RowBox[{"-", "0.06855911911277818`"}]}], "}"}], ",", 
            RowBox[{"-", "141.71584157980283`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012426480776489567`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.382351075793916`", ",", 
              RowBox[{"-", "0.10517391641614338`"}]}], "}"}], ",", 
            RowBox[{"-", "140.68833266117082`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08181329329720088`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8263520093400993`", ",", "1.444130763380094`"}], 
             "}"}], ",", "155.5622200520613`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08136198035884218`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6487928585431653`", ",", "1.524816379995089`"}], 
             "}"}], ",", "159.57478232788543`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008459788598646096`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.425356686909021`", ",", "3.1169129380419007`"}], 
             "}"}], ",", "71.41807576543697`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008438262258830306`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.516830552912185`", ",", "3.3890059587277985`"}], 
             "}"}], ",", "72.14029031681018`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008900374482621383`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6155601683525647`", ",", "3.140748752813215`"}], 
             "}"}], ",", "126.50396871951145`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008818277576626286`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.488082437448585`", ",", "3.3130000643458306`"}], 
             "}"}], ",", "120.99543084306072`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22045000510342017`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.868843846892141`", ",", "2.60011284487213`"}], "}"}], 
            ",", "161.2888808976789`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21911161364479734`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8116934041868635`", ",", "2.6194695648763573`"}], 
             "}"}], ",", "156.98944933426262`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012720769241564482`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.26131283152225`", ",", "1.5996640494127237`"}], "}"}],
             ",", 
            RowBox[{"-", "114.2055979345264`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01268743223333858`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0638595987935724`", ",", "1.1604254624250783`"}], 
             "}"}], ",", 
            RowBox[{"-", "113.20005916153707`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00815119386830329`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.191782608675725`", ",", "1.1704668874483517`"}], 
             "}"}], ",", 
            RowBox[{"-", "120.95409043347543`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008127404314064142`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.153448928015458`", ",", "1.10655298156924`"}], "}"}], 
            ",", 
            RowBox[{"-", "122.64564481143964`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011976862565665873`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.69371070634779`", ",", 
              RowBox[{"-", "3.4233066182279197`"}]}], "}"}], ",", 
            RowBox[{"-", "155.00717587403403`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011947336524091232`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.670413320797123`", ",", 
              RowBox[{"-", "3.4341668154465013`"}]}], "}"}], ",", 
            RowBox[{"-", "154.94475522401802`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011595124378120948`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.65303976200892`", ",", "2.961530386470526`"}], "}"}], 
            ",", "5.9453566397216795`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011563207725312523`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.899423196141074`", ",", "2.98718877936853`"}], "}"}], 
            ",", "4.587841780808842`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023085277278882387`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.854366695460026`", ",", 
              RowBox[{"-", "3.7783913530293813`"}]}], "}"}], ",", 
            RowBox[{"-", "71.18685458322774`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022978405695244324`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.903634815891672`", ",", 
              RowBox[{"-", "3.9230067389810745`"}]}], "}"}], ",", 
            RowBox[{"-", "67.71918128849634`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008280620533886911`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.921928558588366`", ",", 
              RowBox[{"-", "1.7290781022400192`"}]}], "}"}], ",", 
            "5.398960191956841`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00818566325929982`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.121394253571286`", ",", 
              RowBox[{"-", "1.7102266949563503`"}]}], "}"}], ",", 
            RowBox[{"-", "0.7308156028906033`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008470841716264398`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.933775921915895`", ",", "3.33685800507418`"}], "}"}], 
            ",", "76.30431825658285`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008449774780802957`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9501014524724933`", ",", "3.4038499652223475`"}], 
             "}"}], ",", "75.92138374007257`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.37281863325722814`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.319455317078221`", ",", "3.0548251894317278`"}], 
             "}"}], ",", "153.91563364583595`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3627022135869865`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2762663904675184`", ",", "3.0759686155040873`"}], 
             "}"}], ",", "145.2351040608176`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009841911000837502`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.11741073100309`", ",", "3.1862318942371473`"}], "}"}],
             ",", "70.17604514487674`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008972308485813917`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.558434112117004`", ",", "3.121394561388964`"}], "}"}],
             ",", "13.757358379911222`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00869483209502335`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.726026292771315`", ",", "3.1624269201018165`"}], 
             "}"}], ",", "22.848829995650885`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02091647197415751`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7207957282082207`", ",", 
              RowBox[{"-", "0.8988499529645195`"}]}], "}"}], ",", 
            "171.88845886514332`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019911736844423877`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.580453695055914`", ",", 
              RowBox[{"-", "0.8788474812033391`"}]}], "}"}], ",", 
            RowBox[{"-", "177.57113826326636`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01834513825149751`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.073286747564538`", ",", "1.2026505553483355`"}], 
             "}"}], ",", "72.57786637938709`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018299469443057163`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.201736972220186`", ",", "1.6119815177360024`"}], 
             "}"}], ",", "72.98103870054057`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0130640615784921`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.499397579882815`", ",", "0.6579562769550734`"}], 
             "}"}], ",", "121.91982573009861`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020089281786825147`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.135532990828835`", ",", 
              RowBox[{"-", "1.892394399522408`"}]}], "}"}], ",", 
            RowBox[{"-", "178.80623626590676`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019981090247845213`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.132323290557163`", ",", 
              RowBox[{"-", "1.8924612836515469`"}]}], "}"}], ",", 
            RowBox[{"-", "174.86655270601807`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03942061922742455`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.249945292601955`", ",", 
              RowBox[{"-", "2.9372034400351885`"}]}], "}"}], ",", 
            RowBox[{"-", "118.33390411584821`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039057655766644425`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.163782036569682`", ",", 
              RowBox[{"-", "3.096999373830829`"}]}], "}"}], ",", 
            RowBox[{"-", "112.83048391429293`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015467565099601897`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.071484832429513`", ",", 
              RowBox[{"-", "2.258721142881024`"}]}], "}"}], ",", 
            RowBox[{"-", "173.44574599559903`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015402976513957261`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.931722774464518`", ",", 
              RowBox[{"-", "2.2747790926863147`"}]}], "}"}], ",", 
            RowBox[{"-", "176.57441466241713`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015263296658670286`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.037465293458888`", ",", 
              RowBox[{"-", "1.4027113492410619`"}]}], "}"}], ",", 
            "110.88630327854261`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014321783793023742`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.931161121804959`", ",", 
              RowBox[{"-", "1.1241284316455704`"}]}], "}"}], ",", 
            "99.47156723245195`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013194063275259375`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.236712677796566`", ",", 
              RowBox[{"-", "0.11373154791280835`"}]}], "}"}], ",", 
            "131.11407166574259`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01314859414084821`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.183012615094738`", ",", 
              RowBox[{"-", "0.052204520762133305`"}]}], "}"}], ",", 
            "133.54737245370248`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019069690081209758`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.152490345497259`", ",", 
              RowBox[{"-", "0.6774240377395112`"}]}], "}"}], ",", 
            "164.99313971701804`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018586723648170465`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.017570463917072`", ",", 
              RowBox[{"-", "0.6412550494577799`"}]}], "}"}], ",", 
            "156.5262313280434`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09209193217018218`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.077151719566918`", ",", 
              RowBox[{"-", "2.7896193673170946`"}]}], "}"}], ",", 
            RowBox[{"-", "125.33048014216337`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09182984584338193`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.04843387188945`", ",", 
              RowBox[{"-", "2.830133321013055`"}]}], "}"}], ",", 
            RowBox[{"-", "123.77506396890465`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011507924352898182`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3735957448722327`", ",", "0.12285257957385659`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.77970638182043`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010978168210542209`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3126918097624993`", ",", "0.11835838566538617`"}], 
             "}"}], ",", "173.82474660947872`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009323772130858846`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.613477516367497`", ",", "2.8636309481357225`"}], 
             "}"}], ",", "55.14979101572329`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008686223664738335`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.836228146190559`", ",", "3.1835285607538286`"}], 
             "}"}], ",", "66.93687245421152`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020765397233517745`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.920138022643766`", ",", "3.6150100035364083`"}], 
             "}"}], ",", "100.1899703064778`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012562704846381669`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.893635248830319`", ",", "3.7624543145467406`"}], 
             "}"}], ",", "119.73434791254286`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.038071278926875105`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.383789456511689`", ",", 
              RowBox[{"-", "1.9729749954037983`"}]}], "}"}], ",", 
            RowBox[{"-", "121.63073316640606`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03796757085197436`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.330907938269609`", ",", 
              RowBox[{"-", "2.058829454821125`"}]}], "}"}], ",", 
            RowBox[{"-", "120.34053813103519`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01569532709972737`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.7020451715431815`", ",", 
              RowBox[{"-", "3.9112365439015684`"}]}], "}"}], ",", 
            RowBox[{"-", "67.57066605878501`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0156346115766811`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.771706365735673`", ",", 
              RowBox[{"-", "4.080001974130683`"}]}], "}"}], ",", 
            RowBox[{"-", "70.43491731169665`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011590683998308326`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.555889127695717`", ",", 
              RowBox[{"-", "2.088286515364006`"}]}], "}"}], ",", 
            RowBox[{"-", "33.50722001099845`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011560738412840877`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.648601230646284`", ",", 
              RowBox[{"-", "2.149668120186087`"}]}], "}"}], ",", 
            RowBox[{"-", "34.38673466128312`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00918722188775691`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3690487587760924`", ",", "3.5453326097585736`"}], 
             "}"}], ",", "145.84911605789512`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009136442549007983`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2605448101087156`", ",", "3.61893592385977`"}], "}"}],
             ",", "141.8306390546295`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12227760455364485`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.34954007318907`", ",", 
              RowBox[{"-", "2.9311449148270943`"}]}], "}"}], ",", 
            RowBox[{"-", "113.09659973433551`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12197617804681277`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.277103947723624`", ",", 
              RowBox[{"-", "3.1009969653937595`"}]}], "}"}], ",", 
            RowBox[{"-", "113.04308606251146`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04005257519182435`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.023701590059098`", ",", "2.6198351822922343`"}], 
             "}"}], ",", "113.6762223377305`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03812215150147079`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.889445456338815`", ",", "2.926024376894937`"}], "}"}],
             ",", "103.12433828480121`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014951077029324087`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.382315238116761`", ",", 
              RowBox[{"-", "0.8858538580442203`"}]}], "}"}], ",", 
            RowBox[{"-", "162.6056816020606`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01442919213850764`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.378244028380549`", ",", 
              RowBox[{"-", "0.8871292544932251`"}]}], "}"}], ",", 
            RowBox[{"-", "172.08504444742292`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2592090937945081`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.842558002495407`", ",", 
              RowBox[{"-", "2.3562116887071047`"}]}], "}"}], ",", 
            RowBox[{"-", "94.97413501262356`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2333391156040766`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.838998481869474`", ",", 
              RowBox[{"-", "2.3971098311794203`"}]}], "}"}], ",", 
            RowBox[{"-", "81.75344189579589`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023288063482978356`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.860468037503002`", ",", 
              RowBox[{"-", "2.5452454429729006`"}]}], "}"}], ",", 
            RowBox[{"-", "22.152648996405883`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2736088560216683`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.987758823987346`", ",", 
              RowBox[{"-", "1.6947174978191548`"}]}], "}"}], ",", 
            RowBox[{"-", "54.72941787645714`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2719906318120623`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.249651997048355`", ",", 
              RowBox[{"-", "2.065005472982989`"}]}], "}"}], ",", 
            RowBox[{"-", "58.951100522971096`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024577282984038457`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.296808618032822`", ",", 
              RowBox[{"-", "0.9383558163661906`"}]}], "}"}], ",", 
            RowBox[{"-", "104.07211694451097`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024502237353548752`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.2484503078147435`", ",", 
              RowBox[{"-", "1.131275623238627`"}]}], "}"}], ",", 
            RowBox[{"-", "102.15683112746794`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008841048217494886`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.892238369604698`", ",", "1.4306052722726568`"}], 
             "}"}], ",", "138.54055396321507`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008715109357626271`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.701552488729594`", ",", "1.5990694274151984`"}], 
             "}"}], ",", "131.78727179072587`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17245765173232358`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.243269221268635`", ",", "0.13022919532730276`"}], 
             "}"}], ",", 
            RowBox[{"-", "137.29196133341844`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17188949785270988`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.188201289061612`", ",", "0.0793996632269098`"}], 
             "}"}], ",", 
            RowBox[{"-", "139.5428878218816`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01058631217158876`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.35088627346321`", ",", 
              RowBox[{"-", "0.39228288094063185`"}]}], "}"}], ",", 
            RowBox[{"-", "82.66680317192309`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01047791027299739`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.351114219330654`", ",", 
              RowBox[{"-", "0.3940541335758071`"}]}], "}"}], ",", 
            RowBox[{"-", "76.86031183280261`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05058737132769413`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.267663358684314`", ",", "2.8974339656723194`"}], 
             "}"}], ",", "71.46347363545128`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04165783591531445`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.359469019374845`", ",", "3.1712319685556047`"}], 
             "}"}], ",", "87.07201362095188`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2509718533997882`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.656119914545259`", ",", "2.8887936551931834`"}], 
             "}"}], ",", "150.11295031418166`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.247866025183471`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.636500606390305`", ",", "2.9000693577730754`"}], 
             "}"}], ",", "150.4574800741623`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037921119300415765`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.435364607407312`", ",", "2.3487108780900354`"}], 
             "}"}], ",", 
            RowBox[{"-", "174.47950095782878`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037585883610391155`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.3900416727379525`", ",", "2.3443304094935713`"}], 
             "}"}], ",", 
            RowBox[{"-", "169.0922107978152`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24250985607999634`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.90909050153152`", ",", "2.6189814743779674`"}], "}"}],
             ",", "158.36296066311635`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2418475581176971`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.851180149953768`", ",", "2.6419531208205154`"}], 
             "}"}], ",", "157.05598674471776`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25715506285888134`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.220310908486281`", ",", "0.6114199351966487`"}], 
             "}"}], ",", 
            RowBox[{"-", "87.5510865249483`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25651258153130724`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.230386758025595`", ",", "0.3758248157132166`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.02163570337042`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07506117210724828`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.713475040829654`", ",", "0.0453881684976358`"}], 
             "}"}], ",", 
            RowBox[{"-", "122.56945357535706`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07415323361893261`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.6645860830738215`", ",", 
              RowBox[{"-", "0.031147231682318602`"}]}], "}"}], ",", 
            RowBox[{"-", "128.85199000655862`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023895723929679133`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.232629346704844`", ",", "0.0935309731620283`"}], 
             "}"}], ",", 
            RowBox[{"-", "113.53876965942996`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02383202775510653`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.053641669446334`", ",", 
              RowBox[{"-", "0.31735196978193336`"}]}], "}"}], ",", 
            RowBox[{"-", "114.67744659673802`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1962469295600287`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5681643822077485`", ",", 
              RowBox[{"-", "1.1355830966992775`"}]}], "}"}], ",", 
            RowBox[{"-", "82.32049466532227`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1911250966889257`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.606344688347924`", ",", 
              RowBox[{"-", "1.4187334913977334`"}]}], "}"}], ",", 
            RowBox[{"-", "90.88020349994467`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009841817985064952`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.837885967467196`", ",", "1.5380887190130017`"}], 
             "}"}], ",", "111.35123786557104`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009811690677919238`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.818216791195257`", ",", "1.5884045492762944`"}], 
             "}"}], ",", "113.27836459837478`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.31239698204415983`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.349692745732636`", ",", "0.9390177742939605`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.5069288850233`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2801784840613447`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.257659461780888`", ",", "0.9100120270629408`"}], 
             "}"}], ",", 
            RowBox[{"-", "149.1565276967669`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028895701438889386`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.117167632438771`", ",", "0.8261175470069844`"}], 
             "}"}], ",", 
            RowBox[{"-", "89.83324921222524`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009323428526295995`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.846694276822012`", ",", "0.5984956863594586`"}], 
             "}"}], ",", 
            RowBox[{"-", "100.43406992581052`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00929171402085879`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.807577656537465`", ",", "0.386077457015285`"}], "}"}],
             ",", 
            RowBox[{"-", "102.81564141420775`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28016455361656745`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.412383262155191`", ",", "1.1080402052512859`"}], 
             "}"}], ",", "173.58437862340068`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2673399707217089`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.109795497765404`", ",", "1.1420644005632679`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.03918391239137`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012237535303347718`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9148613770099985`", ",", "1.1285672376053026`"}], 
             "}"}], ",", 
            RowBox[{"-", "108.32690231020912`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2844943552158621`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3595970983370855`", ",", "0.9048842717050697`"}], 
             "}"}], ",", 
            RowBox[{"-", "179.95126431479076`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27574864497424645`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3474023378701885`", ",", "0.9048738988616299`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.87878616125818`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008476856233695713`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.202642609176679`", ",", "0.8816321711879552`"}], 
             "}"}], ",", 
            RowBox[{"-", "97.73423319676586`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008966037540757144`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.028902406669837`", ",", 
              RowBox[{"-", "3.1251692495618935`"}]}], "}"}], ",", 
            RowBox[{"-", "70.9661369221049`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00880072066566727`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.058316122578409`", ",", 
              RowBox[{"-", "3.2104291544489056`"}]}], "}"}], ",", 
            RowBox[{"-", "63.45777260664327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29350266029161254`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7427671292921243`", ",", "3.096120721976002`"}], 
             "}"}], ",", "179.62896996875946`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2923722035278479`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6491189382290914`", ",", "3.096727167638321`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.52222857579645`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.3034156724691288`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.622847132670974`", ",", "3.201489704433622`"}], "}"}],
             ",", "123.54171695274425`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2991297679476463`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.548730151265034`", ",", "3.313291298098303`"}], "}"}],
             ",", "121.2987066380636`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2074938795782712`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.643384671488563`", ",", "3.3597983825061997`"}], 
             "}"}], ",", "67.45446393672898`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17507661322311674`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.651399080236819`", ",", "3.37910346651708`"}], "}"}], 
            ",", "82.52672760686615`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02735263909927003`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6715545154570086`", ",", "3.532753025731774`"}], 
             "}"}], ",", "138.73773604088652`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03303145034375969`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7862216760573277`", ",", "3.4310796435752473`"}], 
             "}"}], ",", "11.36721092071368`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032903138430371154`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.881455294618198`", ",", "3.4502254001223314`"}], 
             "}"}], ",", "14.246231216580236`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2332199913071227`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.111585282110616`", ",", "3.472367027206931`"}], "}"}],
             ",", "28.91457892830718`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21124556975227035`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.264634592188302`", ",", "3.5569056035555873`"}], 
             "}"}], ",", "41.90992721173995`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019903950666125318`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.377435097169095`", ",", "3.658150991890274`"}], "}"}],
             ",", "102.00902072714804`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01204466681521663`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.1176548356263805`", ",", "2.335555256105638`"}], 
             "}"}], ",", 
            RowBox[{"-", "60.9383772067069`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011983669133454427`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.144325840184996`", ",", "2.2875612976895767`"}], 
             "}"}], ",", 
            RowBox[{"-", "57.18769029722968`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16224915365310683`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.374197998047203`", ",", "2.8252555391612586`"}], 
             "}"}], ",", "10.133890216808835`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1604729420220983`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.406564721915494`", ",", "2.8310406851140684`"}], 
             "}"}], ",", "16.131065015829854`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09790774118840805`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.9726659601126935`", ",", "1.3721407739913314`"}], 
             "}"}], ",", 
            RowBox[{"-", "53.29687445122056`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09633888958622767`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.051377142344828`", ",", "1.2665536430853388`"}], 
             "}"}], ",", 
            RowBox[{"-", "46.20141323327297`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.050687083202645936`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.095108047103927`", ",", "1.6972718055676446`"}], 
             "}"}], ",", 
            RowBox[{"-", "73.81227696442964`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.049494744637069245`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.117654458232004`", ",", "1.619604436013454`"}], "}"}],
             ",", 
            RowBox[{"-", "82.05273130349639`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.034598187714824896`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.122848840957539`", ",", "1.7180552732101344`"}], 
             "}"}], ",", 
            RowBox[{"-", "122.50037242300289`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.034505898670755424`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.06868495637522`", ",", "1.6330362242929266`"}], "}"}],
             ",", 
            RowBox[{"-", "121.35652674575891`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02305153619749623`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4661872280868278`", ",", "3.180921472328808`"}], 
             "}"}], ",", "164.4333376850379`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022989948179846304`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.397482177038022`", ",", "3.200061181694977`"}], "}"}],
             ",", "163.27766487564935`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08156709726881975`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.072694552474338`", ",", "0.27587203506025676`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.21106977289335`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08126037382539143`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9111937313212852`", ",", "0.21776340620799062`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.9737304231867`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03730121138932358`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.47360863487234`", ",", "1.8249231390726355`"}], "}"}],
             ",", "165.4786947626636`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.036816131696574134`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.428650990937275`", ",", "1.8365678135129835`"}], 
             "}"}], ",", "158.98825389637892`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08978618567116699`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.667818548636428`", ",", "1.2196932435683943`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.69673248807257`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08868550331442777`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.392784632189184`", ",", "1.1893133403696`"}], "}"}], 
            ",", 
            RowBox[{"-", "167.37583562271107`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02068488982680287`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.605132568154086`", ",", "0.3230387054496063`"}], 
             "}"}], ",", 
            RowBox[{"-", "153.7964566448894`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020585614942961496`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.461195578242246`", ",", "0.2522018687756769`"}], 
             "}"}], ",", 
            RowBox[{"-", "150.2139769517848`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008187095866582905`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.055440525207455`", ",", 
              RowBox[{"-", "2.0856520759379458`"}]}], "}"}], ",", 
            RowBox[{"-", "93.57535301148462`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00816679943348881`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.035374206978884`", ",", 
              RowBox[{"-", "2.406801521780479`"}]}], "}"}], ",", 
            RowBox[{"-", "93.88311036071906`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14995920778927538`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8155000203866543`", ",", "1.49926532461838`"}], "}"}],
             ",", "162.73644215556686`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14900047646286538`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6393669072293284`", ",", "1.554001809947269`"}], 
             "}"}], ",", "167.18837728074797`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0082917097970114`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.205090409605016`", ",", 
              RowBox[{"-", "0.5352505042925035`"}]}], "}"}], ",", 
            "155.5837601749622`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00827119083604342`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1486604500619717`", ",", 
              RowBox[{"-", "0.509633451286922`"}]}], "}"}], ",", 
            "155.83980878664227`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15890164002061336`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7646409666322525`", ",", 
              RowBox[{"-", "2.3652591978116506`"}]}], "}"}], ",", 
            RowBox[{"-", "127.86613598807375`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1574414362572255`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.687346924834199`", ",", 
              RowBox[{"-", "2.4646689242798066`"}]}], "}"}], ",", 
            RowBox[{"-", "133.3639434397474`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008263068083729345`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9147952493490976`", ",", 
              RowBox[{"-", "3.3708372984770985`"}]}], "}"}], ",", 
            RowBox[{"-", "96.90981163664205`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.041857970832639396`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2063272730200887`", ",", "2.8948686695957933`"}], 
             "}"}], ",", "108.60184993882595`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04155156283495627`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1824858594920125`", ",", "2.9657044306250255`"}], 
             "}"}], ",", "113.44782628189209`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04811946526786577`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.044827874469686`", ",", "2.678623059659469`"}], "}"}],
             ",", "125.43149748335767`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.047731239538056386`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9333640797218736`", ",", "2.8352853936772213`"}], 
             "}"}], ",", "120.30573646441692`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012495993248684466`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.918979408019427`", ",", "0.4432405576931465`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.2526158772133`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012329205797224829`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5876291796852042`", ",", "0.4157227093399586`"}], 
             "}"}], ",", "178.18201879863275`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18425249168486746`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.630191771136144`", ",", "3.308284194420784`"}], "}"}],
             ",", "142.12100567201878`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18029339692309035`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.528763188868726`", ",", "3.3871844873446237`"}], 
             "}"}], ",", "134.15519974689136`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03214032904047513`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.583154901338565`", ",", "0.8752202076403494`"}], 
             "}"}], ",", 
            RowBox[{"-", "51.93428737679964`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031997405606215196`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.630096466793213`", ",", "0.8152795720390332`"}], 
             "}"}], ",", 
            RowBox[{"-", "48.59682748804748`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01266542796386836`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.915310280175682`", ",", "0.8725376930146247`"}], 
             "}"}], ",", 
            RowBox[{"-", "70.52990828680754`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012624684158436088`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.006439621925628`", ",", "0.6147688300325258`"}], 
             "}"}], ",", 
            RowBox[{"-", "72.67993120093384`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018713392176377876`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.405927012198225`", ",", "2.3787519570622178`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.52306655323287`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018499332020293288`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.334621434201527`", ",", "2.3706567906970477`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.4004152287048`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07740527430003738`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.8855943003165185`", ",", "3.2448708046005024`"}], 
             "}"}], ",", "7.965707484809215`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07716041610470682`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.080559990141701`", ",", "3.272152460207569`"}], "}"}],
             ",", "5.889072142481674`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010894700652459226`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.686899135231831`", ",", "3.1787974319452377`"}], 
             "}"}], ",", 
            RowBox[{"-", "138.99109946841025`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010866584956333542`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.59454673071253`", ",", "3.0984915207788184`"}], "}"}],
             ",", 
            RowBox[{"-", "138.12230510174277`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010539695268388717`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.146594245946951`", ",", "3.101302362746748`"}], "}"}],
             ",", 
            RowBox[{"-", "57.81582740656453`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010363912059326562`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.277212258579763`", ",", "2.893757354530947`"}], "}"}],
             ",", 
            RowBox[{"-", "65.02847750525787`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07415380171335308`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.083933215616448`", ",", "3.682061863205232`"}], "}"}],
             ",", "152.08564172187715`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07389998680337813`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.955770445167616`", ",", "3.749961683916154`"}], "}"}],
             ",", "154.49201745823729`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013164105739109632`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.341081509098933`", ",", "1.9555372819863597`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.33665463148859`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013037210331737627`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.344366407822268`", ",", "1.8424170849010477`"}], 
             "}"}], ",", 
            RowBox[{"-", "82.70244492501301`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0109082292690101`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.933471172038791`", ",", "2.0451250526433418`"}], 
             "}"}], ",", 
            RowBox[{"-", "166.49088691001043`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010880347429740273`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.698023718464621`", ",", "1.9885595114614365`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.2628545986558`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03211787229650239`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.372429286979578`", ",", "2.9644152224685603`"}], 
             "}"}], ",", "157.72571335536134`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03202407014881213`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9123037629453368`", ",", "3.1528852667350202`"}], 
             "}"}], ",", "156.03054610031572`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012393827991384323`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.110370663361457`", ",", 
              RowBox[{"-", "0.32787980772381814`"}]}], "}"}], ",", 
            RowBox[{"-", "139.66082374253807`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012358861385522885`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.064677983430684`", ",", 
              RowBox[{"-", "0.3666837619941653`"}]}], "}"}], ",", 
            RowBox[{"-", "138.15479596955356`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.080913157032625`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.379458000813778`", ",", "1.6251160758509406`"}], 
             "}"}], ",", "163.5873446037096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07930040003714685`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.326056895709007`", ",", "1.6408456934842706`"}], 
             "}"}], ",", "155.84714374307492`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008416790693823655`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.608146945359943`", ",", "3.6724081726290074`"}], 
             "}"}], ",", "72.8625048681824`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008736937931124794`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.360907336975386`", ",", "3.524693212670782`"}], "}"}],
             ",", "115.48689296661014`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008713682529030067`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.304799005122269`", ",", "3.6423960631976082`"}], 
             "}"}], ",", "116.61480075975769`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2177813478003957`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.577113124496869`", ",", "2.7190939695865692`"}], 
             "}"}], ",", "152.69001777084645`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20907787479473`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3044227199070897`", ",", "2.8599001531862447`"}], 
             "}"}], ",", "162.61203669613775`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008355645043696427`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1626895965014343`", ",", "2.9042839244054353`"}], 
             "}"}], ",", 
            RowBox[{"-", "127.93271589045659`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012654182590593201`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9275913020691573`", ",", "0.8424886120484518`"}], 
             "}"}], ",", 
            RowBox[{"-", "112.19452038854735`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012567539497110194`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.906504493089363`", ",", "0.790802834633577`"}], "}"}],
             ",", 
            RowBox[{"-", "116.84683317856948`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008103684190499815`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9713169457996758`", ",", "0.8222603747779084`"}], 
             "}"}], ",", 
            RowBox[{"-", "124.3371991894034`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008036156829238536`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9206628938257806`", ",", "0.7481077742418967`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.55551702543892`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011917883271790598`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3865127223489795`", ",", 
              RowBox[{"-", "3.5668852488817966`"}]}], "}"}], ",", 
            RowBox[{"-", "154.88233457401367`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011881426859347045`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3275229689816683`", ",", 
              RowBox[{"-", "3.594540250413836`"}]}], "}"}], ",", 
            RowBox[{"-", "152.9585609402958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011531378926044368`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.166293012942752`", ",", "3.0086036193514536`"}], 
             "}"}], ",", "3.2303269218954673`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01148464108005055`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.375858465854501`", ",", "3.0204314211510552`"}], 
             "}"}], ",", "0.20320098900830982`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008091794898757283`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.294542797162495`", ",", 
              RowBox[{"-", "1.712435348389325`"}]}], "}"}], ",", 
            RowBox[{"-", "6.860591397738048`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008071171132543742`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.574341747354627`", ",", 
              RowBox[{"-", "1.7460994912691292`"}]}], "}"}], ",", 
            RowBox[{"-", "6.119885940723795`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010116419670241383`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2762663904675184`", ",", "3.0759686155040873`"}], 
             "}"}], ",", 
            RowBox[{"-", "148.38636660825986`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010085525454068142`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.155549579335169`", ",", "3.0016635362683948`"}], 
             "}"}], ",", 
            RowBox[{"-", "150.30229068446988`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009574851113911351`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1829895557969965`", ",", "3.368145414678848`"}], 
             "}"}], ",", "61.495515559858354`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009338512798426355`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3023266289224917`", ",", "3.587895943765453`"}], 
             "}"}], ",", "69.88328594058919`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008425936901320234`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.874329786784559`", ",", "3.224916746452884`"}], "}"}],
             ",", "31.940301611390545`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008163537134455279`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.066713849244671`", ",", "3.3448531121491145`"}], 
             "}"}], ",", "22.826724964043013`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01895526476221411`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.38258625282617`", ",", 
              RowBox[{"-", "0.8872404335930295`"}]}], "}"}], ",", 
            RowBox[{"-", "167.03073539167602`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018906009797879823`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1419537588121385`", ",", 
              RowBox[{"-", "0.9426588754758249`"}]}], "}"}], ",", 
            RowBox[{"-", "166.09844899759347`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01987348137823251`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.930327422316176`", ",", 
              RowBox[{"-", "1.9106077982607501`"}]}], "}"}], ",", 
            RowBox[{"-", "170.92686914612918`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019823295162250266`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.66751611441676`", ",", 
              RowBox[{"-", "1.9525769503209212`"}]}], "}"}], ",", 
            RowBox[{"-", "171.55661238182992`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03869803427452041`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.069476274145186`", ",", 
              RowBox[{"-", "3.3210102154751135`"}]}], "}"}], ",", 
            RowBox[{"-", "107.32706371273771`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03860062655474068`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.05875444315332`", ",", 
              RowBox[{"-", "3.3553768685733916`"}]}], "}"}], ",", 
            RowBox[{"-", "106.74101092241992`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015338657633684406`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.6658613148600745`", ",", 
              RowBox[{"-", "2.290693316004209`"}]}], "}"}], ",", 
            RowBox[{"-", "179.70308332923526`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014280252355921732`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.603155983884158`", ",", 
              RowBox[{"-", "2.2910182688181258`"}]}], "}"}], ",", 
            RowBox[{"-", "167.88283120211557`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013438347927123846`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.905259287943307`", ",", 
              RowBox[{"-", "0.9688719174246986`"}]}], "}"}], ",", 
            "88.05683118636152`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013402351513102574`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.915357255053708`", ",", 
              RowBox[{"-", "0.671240002641347`"}]}], "}"}], ",", 
            "86.8825011336664`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013103281701318744`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.960741327726372`", ",", "0.18163303324655294`"}], 
             "}"}], ",", "135.98067324166195`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013047235194754725`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.66440582370264`", ",", "0.4679941414438552`"}], "}"}],
             ",", "139.1899118729836`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01811598901200094`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.844581130049851`", ",", 
              RowBox[{"-", "0.5661312995344663`"}]}], "}"}], ",", 
            "148.0593229390688`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017769936436893032`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.675606847818308`", ",", 
              RowBox[{"-", "0.4607875571318453`"}]}], "}"}], ",", 
            "155.6727123103927`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09156850539345801`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8796782695141685`", ",", 
              RowBox[{"-", "3.08245491405061`"}]}], "}"}], ",", 
            RowBox[{"-", "122.21964779564568`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09134272639066464`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8505075852022514`", ",", 
              RowBox[{"-", "3.1287419660385773`"}]}], "}"}], ",", 
            RowBox[{"-", "122.13774477075529`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010472798878679407`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1309275385333617`", ",", "0.13802487590127688`"}], 
             "}"}], ",", "163.42919960077793`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010446684103274234`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9088502337360813`", ",", "0.20410577926362702`"}], 
             "}"}], ",", "163.86482537864327`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0080922700056281`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.891693862377186`", ",", "3.3137983546813343`"}], 
             "}"}], ",", "78.72395389269977`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008071051389010852`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.900480009785586`", ",", "3.357864598318122`"}], "}"}],
             ",", "77.71395303779198`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037864145283075586`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.182742657092213`", ",", 
              RowBox[{"-", "2.311972613455932`"}]}], "}"}], ",", 
            RowBox[{"-", "119.05034309566432`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03768178656136339`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.129136823338847`", ",", 
              RowBox[{"-", "2.408480019606195`"}]}], "}"}], ",", 
            RowBox[{"-", "122.64382367246702`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015574130924479852`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.875281126091442`", ",", 
              RowBox[{"-", "4.37143559027782`"}]}], "}"}], ",", 
            RowBox[{"-", "73.29916856460855`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015526499000413602`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.883357522681043`", ",", 
              RowBox[{"-", "4.39835420285686`"}]}], "}"}], ",", 
            RowBox[{"-", "71.37626587180178`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011530870194514922`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.897226245942283`", ",", 
              RowBox[{"-", "2.319820684585405`"}]}], "}"}], ",", 
            RowBox[{"-", "35.266249311568195`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011484988558032566`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.91112926995619`", ",", 
              RowBox[{"-", "2.329652284028459`"}]}], "}"}], ",", 
            RowBox[{"-", "38.229587325408524`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12167549458642282`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.150433843677726`", ",", 
              RowBox[{"-", "3.3987902081105528`"}]}], "}"}], ",", 
            RowBox[{"-", "112.98957239066699`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12124974700989788`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.147521702715067`", ",", 
              RowBox[{"-", "3.405654255286705`"}]}], "}"}], ",", 
            RowBox[{"-", "115.48239228470185`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03628476891038316`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.850770231733905`", ",", "3.0919020319561095`"}], 
             "}"}], ",", "92.57245423187184`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03596607957172944`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.84782261656146`", ",", "3.157509579376103`"}], "}"}], 
            ",", "97.94116129624298`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013925524252307543`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.200021876269678`", ",", 
              RowBox[{"-", "0.9119070393901738`"}]}], "}"}], ",", 
            "178.43559270721485`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013841783394522045`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.136410550081083`", ",", 
              RowBox[{"-", "0.9101697603019961`"}]}], "}"}], ",", 
            RowBox[{"-", "177.29330222306427`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02586997819043141`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.838998481869474`", ",", 
              RowBox[{"-", "2.3971098311794203`"}]}], "}"}], ",", 
            RowBox[{"-", "128.13354167835823`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024862725998632637`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.66306013011406`", ",", 
              RowBox[{"-", "2.6212220089192915`"}]}], "}"}], ",", 
            RowBox[{"-", "118.29763821511378`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21005105212109818`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.860468037503002`", ",", 
              RowBox[{"-", "2.5452454429729006`"}]}], "}"}], ",", 
            RowBox[{"-", "68.5327487789683`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20947303678310183`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.964529303640744`", ",", 
              RowBox[{"-", "2.809863803943051`"}]}], "}"}], ",", 
            RowBox[{"-", "69.88840967141066`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020963832933877245`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.999102128718822`", ",", 
              RowBox[{"-", "2.6016873604925377`"}]}], "}"}], ",", 
            RowBox[{"-", "8.931955879578291`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0195717957129455`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.261874385091049`", ",", 
              RowBox[{"-", "2.6429865621305675`"}]}], "}"}], ",", 
            RowBox[{"-", "20.612251546112397`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02442742087152347`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.185536517567847`", ",", 
              RowBox[{"-", "1.4233285737793353`"}]}], "}"}], ",", 
            RowBox[{"-", "100.24154531042474`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024005506395813808`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.136704245799847`", ",", 
              RowBox[{"-", "1.693602331480489`"}]}], "}"}], ",", 
            RowBox[{"-", "92.92608232129359`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008590964470150397`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.589911053871509`", ",", "1.723989415994277`"}], "}"}],
             ",", "125.03398961823677`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008569745768531502`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.333991827929522`", ",", "2.0890188684700233`"}], 
             "}"}], ",", "124.84866217798358`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1713232157301778`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.940248911892806`", ",", 
              RowBox[{"-", "0.1320508901896091`"}]}], "}"}], ",", 
            RowBox[{"-", "141.79381431034494`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17088743869980935`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.863056968970465`", ",", 
              RowBox[{"-", "0.19280845491380338`"}]}], "}"}], ",", 
            RowBox[{"-", "141.07588361490355`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010370618390002365`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.401924794015256`", ",", 
              RowBox[{"-", "0.6117164683421243`"}]}], "}"}], ",", 
            RowBox[{"-", "71.05382049368214`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010344701171262202`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.478801711368002`", ",", 
              RowBox[{"-", "0.8356664099524582`"}]}], "}"}], ",", 
            RowBox[{"-", "70.5785666700482`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00892953541237966`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.359469019374845`", ",", "3.1712319685556047`"}], 
             "}"}], ",", "47.24927257301712`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008879945190229206`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.505099127366551`", ",", "3.3287697191965226`"}], 
             "}"}], ",", "51.282120459066114`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03430451607983149`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.367555068531391`", ",", "3.3293246155986482`"}], 
             "}"}], ",", "102.6805536064522`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03421890285377395`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.31726555061554`", ",", "3.552830485456761`"}], "}"}], 
            ",", "102.2294160341504`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2447679079071583`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.351578364845772`", ",", "3.0615498507624155`"}], 
             "}"}], ",", "150.802009834144`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.236378070327634`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.332726271625041`", ",", "3.072085061703826`"}], "}"}],
             ",", "146.19552392913295`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00833328938755617`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.111084384355568`", ",", "3.220486449041145`"}], "}"}],
             ",", "39.6152363247523`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03725361151875023`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.149841575224362`", ",", "2.298041295074627`"}], "}"}],
             ",", 
            RowBox[{"-", "163.70492063780182`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0371432684417718`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.823748620050392`", ",", "2.202715441043321`"}], "}"}],
             ",", 
            RowBox[{"-", "165.47211360299883`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2411870689008152`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.556008619207015`", ",", "2.7669057467627027`"}], 
             "}"}], ",", "155.74901282631888`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2002580428142613`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.455720919383612`", ",", "2.812084139995091`"}], "}"}],
             ",", "140.31512247918386`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033983441549087716`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.337832227099149`", ",", "2.9099046679207174`"}], 
             "}"}], ",", "84.63868139429606`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2558717053918702`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.241317660936481`", ",", "0.0593787069427702`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.49218488179176`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2552285554710081`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.24463024279155`", ",", 
              RowBox[{"-", "0.06646771856770184`"}]}], "}"}], ",", 
            RowBox[{"-", "87.92626176978506`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07325627753703859`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.534634195919815`", ",", 
              RowBox[{"-", "0.19247479425545638`"}]}], "}"}], ",", 
            RowBox[{"-", "135.1345264377602`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06969638555442212`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.38369793090081`", ",", 
              RowBox[{"-", "0.3427039428852845`"}]}], "}"}], ",", 
            RowBox[{"-", "145.71453033249566`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023768501368344793`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.918235140502793`", ",", 
              RowBox[{"-", "0.6120523874165424`"}]}], "}"}], ",", 
            RowBox[{"-", "115.81612353404607`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02368978988878191`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8745919970061`", ",", 
              RowBox[{"-", "0.7022677679808029`"}]}], "}"}], ",", 
            RowBox[{"-", "118.08859080618777`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18613693812303794`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.603390235694879`", ",", 
              RowBox[{"-", "1.6110348748944543`"}]}], "}"}], ",", 
            RowBox[{"-", "99.439912334567`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18547431890347077`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.564839912479123`", ",", 
              RowBox[{"-", "1.8428960138801187`"}]}], "}"}], ",", 
            RowBox[{"-", "101.99895661686973`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009781655595059446`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.701971665894905`", ",", "1.8586035155755987`"}], 
             "}"}], ",", "115.20549133117872`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009724803632390321`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.681822241294973`", ",", "1.9014125722190873`"}], 
             "}"}], ",", "119.37511804165635`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032218497982814835`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.257659461780888`", ",", "0.9100120270629408`"}], 
             "}"}], ",", "164.87059500694778`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03210303400659668`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1537787624621005`", ",", "0.9380983931909275`"}], 
             "}"}], ",", "162.28610436070255`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2512827826224551`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.117167632438771`", ",", "0.8261175470069844`"}], 
             "}"}], ",", 
            RowBox[{"-", "135.80612650851063`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2491558155402798`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.998399544867169`", ",", "0.7106453352719848`"}], 
             "}"}], ",", 
            RowBox[{"-", "130.5430080330151`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0259155955094754`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.117643865374875`", ",", "0.662483775743396`"}], "}"}],
             ",", 
            RowBox[{"-", "76.48284802396901`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025230996322651453`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.118875553318521`", ",", "0.6573601836489971`"}], 
             "}"}], ",", 
            RowBox[{"-", "85.08002229939916`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009260107395248438`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.751781410101081`", ",", "0.14079931650843222`"}], 
             "}"}], ",", 
            RowBox[{"-", "105.1972129026048`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009226806826398662`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.6926775436207055`", ",", 
              RowBox[{"-", "0.07678088209334447`"}]}], "}"}], ",", 
            RowBox[{"-", "102.59971734911835`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012824582894858435`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.109795497765404`", ",", "1.1420644005632679`"}], 
             "}"}], ",", "126.62497194963441`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.012728163364922`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.967594342453163`", ",", "1.3333641745595262`"}], 
             "}"}], ",", "121.70195249085492`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.255102435418361`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9148613770099985`", ",", "1.1285672376053026`"}], 
             "}"}], ",", 
            RowBox[{"-", "165.6627464481836`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2526513120101845`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.906428365600408`", ",", "1.1264118496109896`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.2877375107902`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011677359921056776`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.853419889646802`", ",", "0.9430775385026428`"}], 
             "}"}], ",", 
            RowBox[{"-", "97.95046484600131`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011639207662630451`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.841861157799778`", ",", "0.8603137646950654`"}], 
             "}"}], ",", 
            RowBox[{"-", "100.16657528783458`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00874571024161575`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3474023378701885`", ",", "0.90487389886163`"}], "}"}],
             ",", "125.0491390277821`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008697978940488392`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2410664177084985`", ",", "1.0564604651676346`"}], 
             "}"}], ",", "121.06899721173266`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008216267132293393`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1829116023236583`", ",", "0.7363522884607112`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.66175504323338`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008195810767901284`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.190827813661015`", ",", "0.39748830483989306`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.25602048549912`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008638451922939694`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.152935114196686`", ",", 
              RowBox[{"-", "3.3998557454180136`"}]}], "}"}], ",", 
            RowBox[{"-", "55.949408291181555`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008493593975680641`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.343013019922998`", ",", 
              RowBox[{"-", "3.681121789661831`"}]}], "}"}], ",", 
            RowBox[{"-", "63.177981382391444`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2912461008387395`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.350901074353575`", ",", "3.083822610252523`"}], "}"}],
             ",", 
            RowBox[{"-", "174.67342712035247`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.29051786504563903`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.199044104206012`", ",", "3.069664227035078`"}], "}"}],
             ",", 
            RowBox[{"-", "174.18922763534425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.294857956380511`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3885589709624035`", ",", "3.5767400067352`"}], "}"}], 
            ",", "119.05569632338279`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2904129674601188`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3350883661874784`", ",", "3.6729827736237035`"}], 
             "}"}], ",", "121.4736246735672`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03241726635515453`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.651399080236819`", ",", "3.37910346651708`"}], "}"}], 
            ",", "41.38798284298281`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03215893897230612`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.847707350386743`", ",", "3.5520993251997077`"}], 
             "}"}], ",", "36.29767904850843`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14772397412384664`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6715545154570086`", ",", "3.532753025731774`"}], 
             "}"}], ",", "97.59899127700305`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11735526001872232`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6447050878359932`", ",", "3.7340071536615724`"}], 
             "}"}], ",", "81.30019652806459`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024125592080625955`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.666413661944249`", ",", "3.8758765752816933`"}], 
             "}"}], ",", "26.76020018622506`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023079270704020948`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5550668598930115`", ",", "3.63495407620088`"}], "}"}],
             ",", "153.80999971102344`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023016772023067712`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3616401828882223`", ",", "3.7300898723231537`"}], 
             "}"}], ",", "155.06058614511164`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0327753249494446`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.139812661650813`", ",", "3.5158217226159985`"}], 
             "}"}], ",", "17.12525151244704`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032548757325003466`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.409143393975804`", ",", "3.598808626479347`"}], "}"}],
             ",", "12.44515005391116`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02197442155485222`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.264634592188302`", ",", "3.5569056035555873`"}], 
             "}"}], ",", 
            RowBox[{"-", "5.193818020235503`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02191839661334862`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.323640786141722`", ",", "3.551542038427968`"}], "}"}],
             ",", 
            RowBox[{"-", "5.93812656407877`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011922980361622036`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.29350856581124`", ",", "2.0561842066253853`"}], "}"}],
             ",", 
            RowBox[{"-", "53.43700338775256`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011570571696116201`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.360070698942792`", ",", "1.9664371853324578`"}], 
             "}"}], ",", 
            RowBox[{"-", "44.48869998165202`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15871617534773266`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.635004169707646`", ",", "2.8971105400953423`"}], 
             "}"}], ",", "22.12823981485094`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15778811140663979`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.903575285557843`", ",", "3.006320190988968`"}], "}"}],
             ",", "17.940562856934797`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0947951769089147`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.1972652318558445`", ",", "1.114415438426117`"}], 
             "}"}], ",", 
            RowBox[{"-", "39.105952015325336`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09426843411389882`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.294695493609805`", ",", "1.0352192052585532`"}], 
             "}"}], ",", 
            RowBox[{"-", "35.07139850437076`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.048330454070413295`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.14685598326838`", ",", "1.4104281174482072`"}], "}"}],
             ",", 
            RowBox[{"-", "90.29318564256303`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.048117425433559805`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.146718110808978`", ",", "1.3834846388450577`"}], 
             "}"}], ",", 
            RowBox[{"-", "86.98463734846231`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03441385580338529`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9166370419365357`", ",", "1.3835162247723365`"}], 
             "}"}], ",", 
            RowBox[{"-", "120.21268106851431`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.034301104467841105`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9159720498642523`", ",", "1.3823742354471145`"}], 
             "}"}], ",", 
            RowBox[{"-", "122.44053915627715`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022928524710185104`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1006670786341908`", ",", "3.289236112860523`"}], 
             "}"}], ",", "162.12199206626082`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022871896228055025`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.692734014232927`", ",", "3.4208220106492813`"}], 
             "}"}], ",", "162.3054871700115`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08095480377927528`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.602454551891017`", ",", "0.12321755953209025`"}], 
             "}"}], ",", 
            RowBox[{"-", "165.73639107348035`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08052361116729567`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5955754033611145`", ",", "0.1214687389375463`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.8304227583107`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03633736017183194`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.237518902676637`", ",", "1.909981509090571`"}], "}"}],
             ",", "152.49781303009425`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03623889957405221`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.19964115086494`", ",", "1.929701256250354`"}], "}"}], 
            ",", "151.24315719586932`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08759831414309759`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2213753721831653`", ",", "1.1509229207014182`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.0549387573496`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08718679004135797`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1376643673154043`", ",", "1.1221886645158219`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.56953367281426`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020486816518151044`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.226784094955743`", ",", "0.11802907473082361`"}], 
             "}"}], ",", 
            RowBox[{"-", "146.63149725868016`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020431511625259153`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.177832688135187`", ",", "0.08579016512972962`"}], 
             "}"}], ",", 
            RowBox[{"-", "145.40236432820674`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008146553316795431`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.017758252410186`", ",", 
              RowBox[{"-", "2.666329052544557`"}]}], "}"}], ",", 
            RowBox[{"-", "94.19086770995585`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00812636191240054`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.006534413084269`", ",", 
              RowBox[{"-", "2.8195029085434435`"}]}], "}"}], ",", 
            RowBox[{"-", "93.88908526421808`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1480478745750526`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3678358241441186`", ",", "1.6157500856389455`"}], 
             "}"}], ",", "171.640312405929`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.146813265913905`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1502410153074516`", ",", "1.6477252730810639`"}], 
             "}"}], ",", "176.860804026782`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15599465082627487`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5207053132081034`", ",", 
              RowBox[{"-", "2.6411097727657418`"}]}], "}"}], ",", 
            RowBox[{"-", "138.86175089142105`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1545458112842911`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.42761242653415`", ",", 
              RowBox[{"-", "2.722429377510061`"}]}], "}"}], ",", 
            RowBox[{"-", "144.3899428436172`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.041247397799824295`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0835451215110132`", ",", "3.193820375821446`"}], 
             "}"}], ",", "118.2938026249583`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04102605515943896`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.980971346924826`", ",", "3.384369921390081`"}], "}"}],
             ",", "114.36506729150055`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04734614599636355`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.830651011562688`", ",", "3.011017350880267`"}], "}"}],
             ",", "115.17997544547623`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.047194885599491566`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.792604485067973`", ",", "3.091943737459184`"}], "}"}],
             ",", "113.05989985448504`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01216464450365523`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.363445515092777`", ",", "0.42283839082818514`"}], 
             "}"}], ",", "171.61665347447885`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012134089490406542`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1629977363500927`", ",", "0.45237841394074313`"}], 
             "}"}], ",", "172.17225592368717`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17641937255134932`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.395953481947561`", ",", "3.52396953458935`"}], "}"}], 
            ",", "126.18939382176393`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17597462123819133`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.330377895951577`", ",", "3.613602019872441`"}], "}"}],
             ",", "126.79654024808698`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03185511773197192`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.825791340319894`", ",", "0.5933320850040109`"}], 
             "}"}], ",", 
            RowBox[{"-", "45.25936759929522`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03173083555516049`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.8593814876447174`", ",", "0.5594364396521986`"}], 
             "}"}], ",", 
            RowBox[{"-", "42.364970532193446`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012584071423006818`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.096466395184083`", ",", "0.3260823219419739`"}], 
             "}"}], ",", 
            RowBox[{"-", "74.82995411505976`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012510582246910786`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.110169719282886`", ",", "0.2755412943464901`"}], 
             "}"}], ",", 
            RowBox[{"-", "70.64609016910634`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01828772047160128`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.098600632748835`", ",", "2.3179016869850884`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.2777639041767`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018225971422683965`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.888769269933546`", ",", "2.2467869132101863`"}], 
             "}"}], ",", 
            RowBox[{"-", "163.629608445628`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01083854181771943`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.352822588729898`", ",", "2.881774653529568`"}], "}"}],
             ",", 
            RowBox[{"-", "137.25351073507534`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010811178194709677`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.348498540963568`", ",", "2.8777780362125003`"}], 
             "}"}], ",", 
            RowBox[{"-", "137.88001091060835`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010191060598839815`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.35450132886719`", ",", "2.727795098489933`"}], "}"}], 
            ",", 
            RowBox[{"-", "72.24112760395106`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010165094290472217`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.381310718910736`", ",", "2.6440872337303665`"}], 
             "}"}], ",", 
            RowBox[{"-", "71.50382163092304`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012911538132742338`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.372508919400013`", ",", "1.6226560092947893`"}], 
             "}"}], ",", 
            RowBox[{"-", "77.06823521853735`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01283864572793367`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.372752225477329`", ",", "1.6215963790450416`"}], 
             "}"}], ",", 
            RowBox[{"-", "81.15063884332731`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010852536857487473`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.385537894137745`", ",", "1.917924882028194`"}], "}"}],
             ",", 
            RowBox[{"-", "168.0348222873016`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010605829287655058`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.339896425545627`", ",", "1.9082524771412326`"}], 
             "}"}], ",", 
            RowBox[{"-", "159.89847829197697`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03193054195584809`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.613683131266335`", ",", "3.285649020901551`"}], "}"}],
             ",", "154.33537884526947`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03152819925925279`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.553902918326969`", ",", "3.314373845341771`"}], "}"}],
             ",", "147.93560579851973`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012323993430661468`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8437336950449588`", ",", 
              RowBox[{"-", "0.5645446446200453`"}]}], "}"}], ",", 
            RowBox[{"-", "136.64876819656857`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01226749733389535`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.823958396045145`", ",", 
              RowBox[{"-", "0.5832133566231358`"}]}], "}"}], ",", 
            RowBox[{"-", "133.21262609739745`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008703473005665709`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3044227199070897`", ",", "2.8599001531862447`"}], 
             "}"}], ",", "103.07880820802352`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008677599357854674`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2541150612332057`", ",", "3.0764472252778026`"}], 
             "}"}], ",", "101.2932884127373`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20072222975103354`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1626895965014343`", ",", "2.9042839244054353`"}], 
             "}"}], ",", "172.53405562142905`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20004600485478619`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1397724922646493`", ",", "2.907287161873985`"}], 
             "}"}], ",", "170.19128857903485`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008021717772985479`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0713890407219795`", ",", "2.787141251001066`"}], 
             "}"}], ",", 
            RowBox[{"-", "118.01069696516521`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012481489648239759`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7875435276326748`", ",", "0.5557776983030938`"}], 
             "}"}], ",", 
            RowBox[{"-", "121.49914596859168`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012391837481959015`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7013439460896578`", ",", "0.41510805924679106`"}], 
             "}"}], ",", 
            RowBox[{"-", "116.70793170287729`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011438092667277355`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.63197961151276`", ",", "3.0213397653388454`"}], "}"}],
             ",", 
            RowBox[{"-", "2.823924943878605`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011407129365692659`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.843513348210977`", ",", "3.0109054965819593`"}], 
             "}"}], ",", 
            RowBox[{"-", "1.575769051719089`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008050599930654703`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.852640212802115`", ",", 
              RowBox[{"-", "1.7759387147053527`"}]}], "}"}], ",", 
            RowBox[{"-", "5.37918048370954`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00803028887204484`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.094971761813688`", ",", 
              RowBox[{"-", "1.7987569508849908`"}]}], "}"}], ",", 
            RowBox[{"-", "4.761748442208664`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019773235680795632`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.333169237688875`", ",", 
              RowBox[{"-", "2.0022077378949565`"}]}], "}"}], ",", 
            RowBox[{"-", "172.18635561753007`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019709822162423958`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.102642866096751`", ",", 
              RowBox[{"-", "2.0338418521312005`"}]}], "}"}], ",", 
            RowBox[{"-", "174.32306991113265`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03850346402219204`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.965978042793`", ",", 
              RowBox[{"-", "3.6638144368616565`"}]}], "}"}], ",", 
            RowBox[{"-", "106.15495813210212`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03802347580759137`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.904023761744716`", ",", 
              RowBox[{"-", "3.8776898950459926`"}]}], "}"}], ",", 
            RowBox[{"-", "99.78598301284478`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013294879657590014`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.426423131981197`", ",", 
              RowBox[{"-", "2.3289619051770183`"}]}], "}"}], ",", 
            RowBox[{"-", "156.06257907499597`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012590715941711086`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.399416597563361`", ",", 
              RowBox[{"-", "2.340950662209046`"}]}], "}"}], ",", 
            RowBox[{"-", "166.9397016642384`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013366451520295392`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.930958569340212`", ",", 
              RowBox[{"-", "0.3847901262935921`"}]}], "}"}], ",", 
            "85.70817108097096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013327488754502318`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.947664964619279`", ",", 
              RowBox[{"-", "0.16217757645068404`"}]}], "}"}], ",", 
            "84.02301268645304`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012991428415227772`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.427593108847438`", ",", "0.6724781669937853`"}], 
             "}"}], ",", "142.39915050430537`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012953072608805799`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.383963743079979`", ",", "0.7060783323082914`"}], 
             "}"}], ",", "144.15003007806868`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01743049417627911`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4805411901108987`", ",", 
              RowBox[{"-", "0.372600169719215`"}]}], "}"}], ",", 
            "163.2861016817165`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017385696064913338`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4060816265724547`", ",", 
              RowBox[{"-", "0.350241541182473`"}]}], "}"}], ",", 
            "162.45742704226296`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09111750408755619`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.676768144014921`", ",", 
              RowBox[{"-", "3.4053014779424857`"}]}], "}"}], ",", 
            RowBox[{"-", "122.05584174586937`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09006462351004987`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.657676669171288`", ",", 
              RowBox[{"-", "3.4357880667505545`"}]}], "}"}], ",", 
            RowBox[{"-", "128.20742827826183`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01042063444718457`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.568817617378096`", ",", "0.30247733245865827`"}], 
             "}"}], ",", "164.3004511565061`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010394789967959126`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1565119128098553`", ",", "0.41836773618834916`"}], 
             "}"}], ",", "163.98170362690266`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0375003061033261`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9681142684318607`", ",", 
              RowBox[{"-", "2.6598401862157806`"}]}], "}"}], ",", 
            RowBox[{"-", "126.23730424926984`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03716721373871164`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.919631614244007`", ",", 
              RowBox[{"-", "2.7259929176539672`"}]}], "}"}], ",", 
            RowBox[{"-", "131.63814365996114`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011439289485791308`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.12604817160651`", ",", 
              RowBox[{"-", "2.498956565176562`"}]}], "}"}], ",", 
            RowBox[{"-", "41.192925339249214`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011373621288093732`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.246993911727618`", ",", 
              RowBox[{"-", "2.6048101806406474`"}]}], "}"}], ",", 
            RowBox[{"-", "45.32548431364763`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12082548914171178`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.018810165197388`", ",", 
              RowBox[{"-", "3.6757171600667142`"}]}], "}"}], ",", 
            RowBox[{"-", "117.97521217873685`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11827831057451985`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9154365070604165`", ",", 
              RowBox[{"-", "3.8703378116629303`"}]}], "}"}], ",", 
            RowBox[{"-", "110.06685526104644`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035650189283410655`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.815550438724145`", ",", "3.3888616835434866`"}], 
             "}"}], ",", "103.30986836061413`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03555074778499699`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.770634920213825`", ",", "3.578721628612756`"}], "}"}],
             ",", "101.87071914089658`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013758546110687195`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.872301017939595`", ",", 
              RowBox[{"-", "0.9226557924440155`"}]}], "}"}], ",", 
            RowBox[{"-", "173.02219715334343`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013724514919912245`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.710162616831017`", ",", 
              RowBox[{"-", "0.9425001262725878`"}]}], "}"}], ",", 
            RowBox[{"-", "173.26266865885623`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023894691349671197`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.575543885995159`", ",", 
              RowBox[{"-", "2.7837733642724407`"}]}], "}"}], ",", 
            RowBox[{"-", "108.46173475186939`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023835213525979424`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.541654341085413`", ",", 
              RowBox[{"-", "2.88528378636298`"}]}], "}"}], ",", 
            RowBox[{"-", "108.86280443165042`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2088966120190522`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.072749319436245`", ",", 
              RowBox[{"-", "3.105403635144691`"}]}], "}"}], ",", 
            RowBox[{"-", "71.24407056385301`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2079332617048073`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.08799960753779`", ",", 
              RowBox[{"-", "3.150314265218908`"}]}], "}"}], ",", 
            RowBox[{"-", "67.78877361342904`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018272192334172897`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.410905318833086`", ",", 
              RowBox[{"-", "2.699039979861575`"}]}], "}"}], ",", 
            RowBox[{"-", "32.29254721264639`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018087030809893354`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.588084346100509`", ",", 
              RowBox[{"-", "2.811015656833259`"}]}], "}"}], ",", 
            RowBox[{"-", "26.515818101145033`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023590879297095364`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1268187889837655`", ",", 
              RowBox[{"-", "1.8870016953381006`"}]}], "}"}], ",", 
            RowBox[{"-", "85.61061933216244`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023253661275712302`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.128881658595486`", ",", 
              RowBox[{"-", "1.9138761945120275`"}]}], "}"}], ",", 
            RowBox[{"-", "92.37396966124959`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008548579474683583`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.14175033611594`", ",", "2.3651174583367935`"}], "}"}],
             ",", "124.66333473772447`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008526442329211152`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1076434555438315`", ",", "2.4144414593341925`"}], 
             "}"}], ",", "123.76224489302848`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17045277011011184`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.653980257328887`", ",", 
              RowBox[{"-", "0.3616574428833441`"}]}], "}"}], ",", 
            RowBox[{"-", "140.35795291946314`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16999037541435172`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.594967418142435`", ",", 
              RowBox[{"-", "0.41055009918854746`"}]}], "}"}], ",", 
            RowBox[{"-", "139.09551933436853`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010318848722259188`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.583398214968567`", ",", 
              RowBox[{"-", "1.132330017951795`"}]}], "}"}], ",", 
            RowBox[{"-", "70.10331284641198`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009908168301184886`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.618430132596749`", ",", 
              RowBox[{"-", "1.2291221078227457`"}]}], "}"}], ",", 
            RowBox[{"-", "60.19499439196128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0088306303676398`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.666072835015382`", ",", "3.5295693043040495`"}], 
             "}"}], ",", "55.3149683451151`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00880737111655251`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.709587383961219`", ",", "3.592447385020252`"}], "}"}],
             ",", "56.361677673115295`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008389837579523699`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.332726271625041`", ",", "3.072085061703826`"}], "}"}],
             ",", 
            RowBox[{"-", "111.83067437149744`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008369155533173411`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.27728416674348`", ",", "2.933684843818274`"}], "}"}], 
            ",", 
            RowBox[{"-", "111.88605266849663`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2280447809400767`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.111084384355568`", ",", "3.220486449041145`"}], "}"}],
             ",", "141.58903802412163`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.1907037301657544`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.954758455371051`", ",", "3.344437558261244`"}], "}"}],
             ",", "132.55120245704782`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0362056246933072`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.848099970795353`", ",", "3.4606262406768167`"}], 
             "}"}], ",", "59.24316808297181`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008277122335031238`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.316562790117922`", ",", "3.3905650271201493`"}], 
             "}"}], ",", "35.00875041974084`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008256340871542143`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.356524519002311`", ",", "3.4185556272910147`"}], 
             "}"}], ",", "35.557995106435115`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03703325219470707`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.604405943891403`", ",", "2.1458756573122315`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.23930656819564`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03658015217719984`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.592964444774758`", ",", "2.143284465560271`"}], "}"}],
             ",", 
            RowBox[{"-", "160.92402367249736`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040929026086553834`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.455720919383612`", ",", "2.812084139995091`"}], "}"}],
             ",", 
            RowBox[{"-", "179.44232678306327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04082176782059912`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.377552899821237`", ",", "2.8113232883593313`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.43705402303573`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1662746012651736`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.337832227099149`", ",", "2.9099046679207174`"}], 
             "}"}], ",", "124.88123213204912`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.163970710004797`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.225713861223167`", ",", "3.070734819407332`"}], "}"}],
             ",", "118.20797025898116`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028216510626910527`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.352145538186897`", ",", "3.0624226294134362`"}], 
             "}"}], ",", "69.20479104716135`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.027877254482644786`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.360730456802546`", ",", "3.0850282812256205`"}], 
             "}"}], ",", "75.47006284842753`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2545870221486679`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.256952250972121`", ",", 
              RowBox[{"-", "0.4067665791358533`"}]}], "}"}], ",", 
            RowBox[{"-", "87.36033865777772`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2539585588019182`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.26526151421365`", ",", 
              RowBox[{"-", "0.5869975905894367`"}]}], "}"}], ",", 
            RowBox[{"-", "87.20025136364882`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06630948667702445`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.245025077907684`", ",", 
              RowBox[{"-", "0.43724862593718694`"}]}], "}"}], ",", 
            RowBox[{"-", "156.29453422723105`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06592681237779134`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.117777238390528`", ",", 
              RowBox[{"-", "0.4931210008312532`"}]}], "}"}], ",", 
            RowBox[{"-", "160.44294440644333`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0236113390691958`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.746337843806928`", ",", 
              RowBox[{"-", "0.9425816125023615`"}]}], "}"}], ",", 
            RowBox[{"-", "120.36105807832993`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02325496386566611`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.480883233853334`", ",", 
              RowBox[{"-", "1.3957434313766623`"}]}], "}"}], ",", 
            RowBox[{"-", "113.43993501739988`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18481405850765223`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.508878933533153`", ",", 
              RowBox[{"-", "2.1061952972400784`"}]}], "}"}], ",", 
            RowBox[{"-", "104.55800089917248`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18397945415253414`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.435440312755351`", ",", 
              RowBox[{"-", "2.388980126571918`"}]}], "}"}], ",", 
            RowBox[{"-", "101.17038946310448`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00966828209902613`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.550720203660656`", ",", "2.1343176423314136`"}], 
             "}"}], ",", "123.54474475213415`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009492820494557604`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.428443316827227`", ",", "2.3187447737060687`"}], 
             "}"}], ",", "116.08330838352009`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03198798382775079`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.876393431753907`", ",", "1.0266974747121043`"}], 
             "}"}], ",", "159.701613714457`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031504984949511365`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6701262197708275`", ",", "1.1029914289804044`"}], 
             "}"}], ",", "166.62389079739543`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24704685203527538`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.834142400424299`", ",", "0.5186169949293943`"}], 
             "}"}], ",", 
            RowBox[{"-", "125.2798895575198`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24479880758501874`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.73333375410169`", ",", "0.37613382223822867`"}], 
             "}"}], ",", 
            RowBox[{"-", "119.81006742234952`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024564481846496396`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.13623424416586`", ",", "0.45570602404111304`"}], 
             "}"}], ",", 
            RowBox[{"-", "93.67719657482913`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024463118315835128`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.117262062815048`", ",", "0.16049933262649818`"}], 
             "}"}], ",", 
            RowBox[{"-", "96.7656148750636`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009193626010791307`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.627965300614364`", ",", 
              RowBox[{"-", "0.36629352393380893`"}]}], "}"}], ",", 
            RowBox[{"-", "100.00222179563161`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009145360169150624`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.616643151682505`", ",", 
              RowBox[{"-", "0.43049006424632213`"}]}], "}"}], ",", 
            RowBox[{"-", "103.86395308253414`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012632468749458765`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.825680949044306`", ",", "1.5631240269047626`"}], 
             "}"}], ",", "116.77893303207534`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012594372275134429`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7959855139893546`", ",", "1.6219647450608035`"}], 
             "}"}], ",", "114.92294939216094`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25022373994894936`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.648326616778112`", ",", "1.086860197629454`"}], "}"}],
             ",", 
            RowBox[{"-", "176.91272857339683`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24449284781285735`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5204903062092607`", ",", "1.0799653130267683`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.75369321146778`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01160118005522395`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.78724020649285`", ",", "0.5557238620463394`"}], "}"}],
             ",", 
            RowBox[{"-", "102.38268572966818`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011572121172541583`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.756798215815996`", ",", "0.4170659713737852`"}], 
             "}"}], ",", 
            RowBox[{"-", "101.8696189840642`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00865050814160092`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0974595866669437`", ",", "1.2948117347041475`"}], 
             "}"}], ",", "117.08885539568314`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008628455971146688`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0631151281931768`", ",", "1.361958894730527`"}], 
             "}"}], ",", "116.3459323353367`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00817540533452656`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.198137492260498`", ",", "0.1574141637177774`"}], 
             "}"}], ",", 
            RowBox[{"-", "87.85028592776577`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008150231902771919`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2090268470570162`", ",", 
              RowBox[{"-", "0.13268082458635444`"}]}], "}"}], ",", 
            RowBox[{"-", "85.89578668219421`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00835116514709602`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.415501185784918`", ",", 
              RowBox[{"-", "3.8244870407543035`"}]}], "}"}], ",", 
            RowBox[{"-", "70.40655447360135`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008329517840496571`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.422972368351319`", ",", 
              RowBox[{"-", "3.8454761566998754`"}]}], "}"}], ",", 
            RowBox[{"-", "69.49639078664958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28979145014342367`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8860657647081065`", ",", "3.0378135942946987`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.70502815033527`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2890726448865627`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.616602416028211`", ",", "3.0080884991397507`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.38323562158064`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03190267015405101`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.03176716932845`", ",", "3.687293224962993`"}], "}"}], 
            ",", "31.20737525403434`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03177263621721155`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.083036431691981`", ",", "3.7183520146823694`"}], 
             "}"}], ",", "28.16095217862719`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032323755905886736`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.642666223636448`", ",", "3.6503448995112304`"}], 
             "}"}], ",", "7.765048595375285`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03222052453646206`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.648119115760208`", ",", "3.6510884643268637`"}], 
             "}"}], ",", "9.88361165664551`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021862514510374933`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.622413844330305`", ",", "3.520465895530815`"}], "}"}],
             ",", 
            RowBox[{"-", "6.682435107921549`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021808621140697426`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.816371544651145`", ",", "3.497741381394294`"}], "}"}],
             ",", 
            RowBox[{"-", "6.628674364880957`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011228579207082773`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.498313174423297`", ",", "1.8306402663680825`"}], 
             "}"}], ",", 
            RowBox[{"-", "35.540396575551384`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011191586991407477`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.628465941339579`", ",", "1.7376646769887718`"}], 
             "}"}], ",", 
            RowBox[{"-", "33.28945061611368`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15686547415048863`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.119367256792085`", ",", "3.0761878458813996`"}], 
             "}"}], ",", "13.75288589901865`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1506862901766112`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.180006138502992`", ",", "3.0910293230434465`"}], 
             "}"}], ",", "23.627214763191365`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09374461823965194`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.529350429469603`", ",", "0.870475889649174`"}], "}"}],
             ",", 
            RowBox[{"-", "31.03684499341601`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09351088110400799`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.612412203942919`", ",", "0.8204946137409735`"}], 
             "}"}], ",", 
            RowBox[{"-", "30.603041022655816`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.047905335774023894`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.162084544223142`", ",", "1.0917722028025019`"}], 
             "}"}], ",", 
            RowBox[{"-", "83.67608905436151`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04776944736918801`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.183607526553527`", ",", "0.8975625777593969`"}], 
             "}"}], ",", 
            RowBox[{"-", "82.13914646917975`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03418872254349396`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7662921383577954`", ",", "1.1468848888748389`"}], 
             "}"}], ",", 
            RowBox[{"-", "124.66839724404063`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03390025856023029`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6942946472059317`", ",", "1.0427846718180966`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.92236599553755`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02281540760599134`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3617301027851787`", ",", "3.5264239061816407`"}], 
             "}"}], ",", "162.48898227376617`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021661359017307216`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2362153506393723`", ",", "3.5660250924968926`"}], 
             "}"}], ",", "151.77128512305904`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0800947152327206`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.319178571095467`", ",", "0.030756680964077566`"}], 
             "}"}], ",", 
            RowBox[{"-", "157.92445444314106`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07979802317557987`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1509732346100674`", ",", 
              RowBox[{"-", "0.037460808890576236`"}]}], "}"}], ",", 
            RowBox[{"-", "160.63222723682787`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.036140705767510724`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.915873650154078`", ",", "2.085425531623274`"}], "}"}],
             ",", "149.98850136164526`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03605109866124203`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.811957347798449`", ",", "2.145449446476206`"}], "}"}],
             ",", "150.29964710695322`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08677719921981861`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8556411871541107`", ",", "1.0443451746924912`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.08412858827893`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08656063162434105`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.585297879846851`", ",", "0.987296686739908`"}], "}"}],
             ",", 
            RowBox[{"-", "167.6330626467129`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020376356029900882`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9173878228281183`", ",", 
              RowBox[{"-", "0.09386285124665286`"}]}], "}"}], ",", 
            RowBox[{"-", "144.17323139773364`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020326123603821886`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{
                "0.`", ",", "0.9999999999999999`", ",", 
                 "167.35910683550452`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8483375195141334`", ",", 
              RowBox[{"-", "0.14371255809062766`"}]}], "}"}], ",", 
            RowBox[{"-", "144.1121805289304`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008106220552827743`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.982587617186125`", ",", 
              RowBox[{"-", "3.1717560561794467`"}]}], "}"}], ",", 
            RowBox[{"-", "93.58730281847909`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008079289286411688`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.969952656087857`", ",", 
              RowBox[{"-", "3.3732957056206274`"}]}], "}"}], ",", 
            RowBox[{"-", "91.30150342715216`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15311042820384177`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2264786672156953`", ",", 
              RowBox[{"-", "2.866480413713278`"}]}], "}"}], ",", 
            RowBox[{"-", "149.9181347958133`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15273183879548274`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.181353800596747`", ",", 
              RowBox[{"-", "2.892619305560026`"}]}], "}"}], ",", 
            RowBox[{"-", "149.6888879818087`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04080590029251491`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.873754933729199`", ",", "3.6211107541915326`"}], 
             "}"}], ",", "110.4363319580428`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04062403406869375`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.860348670364729`", ",", "3.65708926283423`"}], "}"}], 
            ",", "113.78112798646536`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.047044108445915965`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.667143186592133`", ",", "3.386655018692026`"}], "}"}],
             ",", "110.93982426349315`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04673044047412252`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6629156674126215`", ",", "3.3977027496627663`"}], 
             "}"}], ",", "115.51474012452597`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03160703826305748`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.081675417603904`", ",", "0.3567032731689679`"}], 
             "}"}], ",", 
            RowBox[{"-", "39.470573465091164`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03152737399264827`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.112777383536885`", ",", "0.3310916078713156`"}], 
             "}"}], ",", 
            RowBox[{"-", "40.074876540524095`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012437522237085495`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.173986439691582`", ",", "0.09385754040219779`"}], 
             "}"}], ",", 
            RowBox[{"-", "66.46222622315292`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012374114899797433`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.274268209074545`", ",", 
              RowBox[{"-", "0.1363595633154113`"}]}], "}"}], ",", 
            RowBox[{"-", "70.23351306476336`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01816443087132368`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.60623413005632`", ",", "2.1637909267630078`"}], "}"}],
             ",", 
            RowBox[{"-", "165.98145298707942`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01811263836004397`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.18329341596266`", ",", "2.0581945319702597`"}], "}"}],
             ",", 
            RowBox[{"-", "164.4154554548623`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010783883655519206`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.101941934037496`", ",", "2.654840751506858`"}], "}"}],
             ",", 
            RowBox[{"-", "138.50651108614136`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010734899908417542`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.0951283677385755`", ",", "2.6488139974837615`"}], 
             "}"}], ",", 
            RowBox[{"-", "135.10002447413643`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010139194142948596`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4872954362059225`", ",", "2.3272620760423`"}], "}"}], 
            ",", 
            RowBox[{"-", "70.76651565789405`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010096473093018712`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.527369175267768`", ",", "2.2124021505044738`"}], 
             "}"}], ",", 
            RowBox[{"-", "73.92546042942524`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012766164838981913`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.412708949979767`", ",", "1.3649542899157536`"}], 
             "}"}], ",", 
            RowBox[{"-", "85.23304246811736`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012709240607369532`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4275612104463455`", ",", "1.1868517104206138`"}], 
             "}"}], ",", 
            RowBox[{"-", "88.57939831136295`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01036473004938714`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1432445512089`", ",", "1.8362821881632283`"}], "}"}], 
            ",", 
            RowBox[{"-", "151.76213429665236`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010239825751505265`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.920732809479422`", ",", "1.7167830393253625`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.03397030828376`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031130926305780807`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.357456586428072`", ",", "3.437434345337315`"}], "}"}],
             ",", "141.53583275177`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029610080232268826`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1387202755849977`", ",", "3.6112018223763473`"}], 
             "}"}], ",", "152.133986059271`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012211260228580977`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6415973214998734`", ",", 
              RowBox[{"-", "0.7773224395460558`"}]}], "}"}], ",", 
            RowBox[{"-", "129.77648399822627`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012177567440452109`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.617055429827024`", ",", 
              RowBox[{"-", "0.8068031282257101`"}]}], "}"}], ",", 
            RowBox[{"-", "128.40400003590605`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008651802627114628`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1945212760539454`", ",", "3.3748669079486944`"}], 
             "}"}], ",", "99.50776861745106`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008610412978161293`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.160334222458122`", ",", "3.5789906596311543`"}], 
             "}"}], ",", "95.93549411747375`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012302829270137653`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5751762563305114`", ",", "0.164338020188098`"}], 
             "}"}], ",", 
            RowBox[{"-", "111.9167174371629`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012271991089420805`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.565815094168653`", ",", "0.14107101664663185`"}], 
             "}"}], ",", 
            RowBox[{"-", "112.44093137476234`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008010029056709446`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3847323755227645`", ",", 
              RowBox[{"-", "1.8228940275480667`"}]}], "}"}], ",", 
            RowBox[{"-", "4.144316400706608`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019646612013615936`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.810627423020948`", ",", 
              RowBox[{"-", "2.0628701227823787`"}]}], "}"}], ",", 
            RowBox[{"-", "176.45978420473506`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019581525776108916`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.655261269437338`", ",", 
              RowBox[{"-", "2.072482187679916`"}]}], "}"}], ",", 
            RowBox[{"-", "178.73382547506014`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03754947117633854`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.866622737248663`", ",", 
              RowBox[{"-", "4.094535006342286`"}]}], "}"}], ",", 
            RowBox[{"-", "93.41700789358755`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0356307897580996`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.859571591560801`", ",", 
              RowBox[{"-", "4.212627155441221`"}]}], "}"}], ",", 
            RowBox[{"-", "104.16970048970886`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011923848279014368`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.2235295923556375`", ",", 
              RowBox[{"-", "2.3817523947534873`"}]}], "}"}], ",", 
            RowBox[{"-", "177.8168242534808`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011700911716802006`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8106301849454995`", ",", 
              RowBox[{"-", "2.3974929692183786`"}]}], "}"}], ",", 
            "174.63351397925524`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013288639563887815`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.979510040500845`", ",", "0.14198319736464082`"}], 
             "}"}], ",", "82.3378542919349`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0132556663911243`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.006806903401426`", ",", "0.34488466422178027`"}], 
             "}"}], ",", "82.66852309362757`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01291483004381035`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.14771009037063`", ",", "0.8767832613979392`"}], "}"}],
             ",", "145.90090965183157`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01288191299428509`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.128144313032029`", ",", "0.8900298355245744`"}], 
             "}"}], ",", "145.15997102680564`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017341013089169174`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1066298187111636`", ",", 
              RowBox[{"-", "0.2555800674312975`"}]}], "}"}], ",", 
            "161.62875240280945`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017229021097724437`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.913926441095321`", ",", 
              RowBox[{"-", "0.19158357221137529`"}]}], "}"}], ",", 
            "166.11034649423033`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08902390917350449`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.510555217834851`", ",", 
              RowBox[{"-", "3.622696215050899`"}]}], "}"}], ",", 
            RowBox[{"-", "134.3590148106544`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08800349095817998`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.346861212778436`", ",", 
              RowBox[{"-", "3.790094402998322`"}]}], "}"}], ",", 
            RowBox[{"-", "140.4875144148465`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.036837080030569444`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7454803212975145`", ",", 
              RowBox[{"-", "2.9218814178830406`"}]}], "}"}], ",", 
            RowBox[{"-", "137.03898307065242`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03657096042967973`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4385228322540007`", ",", 
              RowBox[{"-", "3.207733694584439`"}]}], "}"}], ",", 
            RowBox[{"-", "141.84683004622968`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11578483026834266`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.847230167096772`", ",", 
              RowBox[{"-", "4.057055011384567`"}]}], "}"}], ",", 
            RowBox[{"-", "102.15849834335614`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11520049002439489`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.825875960104849`", ",", 
              RowBox[{"-", "4.156169652824735`"}]}], "}"}], ",", 
            RowBox[{"-", "105.89843345812447`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01369056790387031`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3837451970089263`", ",", 
              RowBox[{"-", "0.9810609906121149`"}]}], "}"}], ",", 
            RowBox[{"-", "173.50314016437207`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013653239158579933`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1151139283275167`", ",", 
              RowBox[{"-", "1.0116527439306593`"}]}], "}"}], ",", 
            RowBox[{"-", "174.7995134954129`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02377588375239048`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.43912162825665`", ",", 
              RowBox[{"-", "3.185392938272045`"}]}], "}"}], ",", 
            RowBox[{"-", "109.26387411143327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017845064802731653`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.4054814356495156`", ",", 
              RowBox[{"-", "3.2816487654920232`"}]}], "}"}], ",", 
            RowBox[{"-", "126.47352347905017`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.206974353989315`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.194421264377078`", ",", 
              RowBox[{"-", "3.4109465853670002`"}]}], "}"}], ",", 
            RowBox[{"-", "64.33347666300507`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2058791164333152`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.321252999872217`", ",", 
              RowBox[{"-", "3.674877994366107`"}]}], "}"}], ",", 
            RowBox[{"-", "68.2194703802668`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01790374562258787`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.757347622260808`", ",", 
              RowBox[{"-", "2.895465567414296`"}]}], "}"}], ",", 
            RowBox[{"-", "20.73908898964362`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01785479870312892`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.85372094736996`", ",", 
              RowBox[{"-", "2.9319571685943555`"}]}], "}"}], ",", 
            RowBox[{"-", "22.052928125127448`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022921263591566918`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.120352531365677`", ",", 
              RowBox[{"-", "2.119608947377167`"}]}], "}"}], ",", 
            RowBox[{"-", "99.13731999033674`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022593734368124205`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.118421919627566`", ",", 
              RowBox[{"-", "2.1316120902231095`"}]}], "}"}], ",", 
            RowBox[{"-", "92.37500380428324`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008504362509427871`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.9558269679507205`", ",", "2.6415458060438706`"}], 
             "}"}], ",", "122.8611550483321`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008452235239997557`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.9018847525001386`", ",", "2.7250518604226603`"}], 
             "}"}], ",", "127.18888256570317`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16952923507693698`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3552372974225495`", ",", 
              RowBox[{"-", "0.6182436607527533`"}]}], "}"}], ",", 
            RowBox[{"-", "137.83308574927395`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1691085201095186`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.313269548490573`", ",", 
              RowBox[{"-", "0.656253555064122`"}]}], "}"}], ",", 
            RowBox[{"-", "137.49885752929114`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009513832572507326`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.71366100941622`", ",", 
              RowBox[{"-", "1.3953709118801847`"}]}], "}"}], ",", 
            RowBox[{"-", "50.28667593751066`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009373462859084827`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.846069552065707`", ",", 
              RowBox[{"-", "1.5547823287806197`"}]}], "}"}], ",", 
            RowBox[{"-", "43.431554857019655`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008348524470770927`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.152706677785381`", ",", "2.623570492538123`"}], "}"}],
             ",", 
            RowBox[{"-", "111.94143096548925`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008324924162037084`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.151437642763765`", ",", "2.6204202530124365`"}], 
             "}"}], ",", 
            RowBox[{"-", "113.45883245486905`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037341050774322045`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.954758455371051`", ",", "3.344437558261244`"}], "}"}],
             ",", 
            RowBox[{"-", "163.17859873594995`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037246420574836535`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.920544336604041`", ",", "3.3340937605348855`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.5043733645863`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.1544981054724472`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.848099970795353`", ",", "3.4606262406768167`"}], 
             "}"}], ",", "123.51336688997418`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.1474144156040729`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.763727798657249`", ",", "3.5880340962695576`"}], 
             "}"}], ",", "119.18262122523532`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008235611584305526`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.601745336365228`", ",", "3.5938447090001717`"}], 
             "}"}], ",", "36.10723979312939`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008210805481025828`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.624242981949835`", ",", "3.610254629137234`"}], "}"}],
             ",", "37.95727225338355`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03613259581610135`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.434749207937504`", ",", "2.0885718099516564`"}], 
             "}"}], ",", 
            RowBox[{"-", "154.608740776799`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03599695695836152`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.164801340599267`", ",", "1.9604416019457573`"}], 
             "}"}], ",", 
            RowBox[{"-", "157.3651569699128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040714790634765664`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.048061583993393`", ",", "2.8023330118719088`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.43178126300674`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04061414788246977`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8591954719604376`", ",", "2.793861627005079`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.64987289402575`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16169874132850273`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.116955393542976`", ",", "3.2735007709854105`"}], 
             "}"}], ",", "111.53470838591308`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1611439538202129`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.07412909135062`", ",", "3.3820288297901584`"}], "}"}],
             ",", "113.95055237538871`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.027542077323656298`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.420110121692732`", ",", "3.3141384967822844`"}], 
             "}"}], ",", "81.73533464969383`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.027471709648714253`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.428544256025292`", ",", "3.3722030476344838`"}], 
             "}"}], ",", "80.96807818616112`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25333164685466586`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.282525643195672`", ",", 
              RowBox[{"-", "0.9400201055250266`"}]}], "}"}], ",", 
            RowBox[{"-", "87.04016406951992`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2526215490268054`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.289914658878898`", ",", 
              RowBox[{"-", "1.0829276038966589`"}]}], "}"}], ",", 
            RowBox[{"-", "88.50836739250732`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06554634650493328`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.860004043903626`", ",", 
              RowBox[{"-", "0.5846922603434024`"}]}], "}"}], ",", 
            RowBox[{"-", "164.5913545856556`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06491907621816267`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.690008009051376`", ",", 
              RowBox[{"-", "0.6315445677566753`"}]}], "}"}], ",", 
            RowBox[{"-", "170.20489182222428`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022903967572892772`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.404594217038392`", ",", 
              RowBox[{"-", "1.5717003663107687`"}]}], "}"}], ",", 
            RowBox[{"-", "106.51881195646983`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022826583892989208`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.259408443254719`", ",", 
              RowBox[{"-", "2.061249027219967`"}]}], "}"}], ",", 
            RowBox[{"-", "104.16447702183984`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18314861879873123`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.381736509769126`", ",", 
              RowBox[{"-", "2.6609417351921207`"}]}], "}"}], ",", 
            RowBox[{"-", "97.78277802703647`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18243289297965154`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.380574323379593`", ",", 
              RowBox[{"-", "2.669444910492241`"}]}], "}"}], ",", 
            RowBox[{"-", "100.68296578514985`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009320543196703987`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.337253499543261`", ",", "2.5050236894144997`"}], 
             "}"}], ",", "108.62187201490599`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009296105364908028`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.292422481352895`", ",", "2.6380683363991775`"}], 
             "}"}], ",", "107.6123529424297`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03102927905721432`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4621819624918184`", ",", "1.1524391197069026`"}], 
             "}"}], ",", "173.54616788033394`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03073100693773136`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3656486830671053`", ",", "1.1633589103542972`"}], 
             "}"}], ",", "167.9199266026694`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24257121959396685`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6118972978118684`", ",", "0.16418018278816915`"}], 
             "}"}], ",", 
            RowBox[{"-", "114.34024528717924`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24169118025090436`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5755001570220437`", ",", "0.08372018670784769`"}], 
             "}"}], ",", 
            RowBox[{"-", "116.97085416105904`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024362173054340373`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.08319075266063`", ",", 
              RowBox[{"-", "0.12669712854553145`"}]}], "}"}], ",", 
            RowBox[{"-", "99.85403317529796`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02429397479168017`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.043580714792697`", ",", 
              RowBox[{"-", "0.35473242622201256`"}]}], "}"}], ",", 
            RowBox[{"-", "101.31446555789232`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009097347719530306`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.552047754432303`", ",", 
              RowBox[{"-", "0.6922139549788413`"}]}], "}"}], ",", 
            RowBox[{"-", "107.72568436943659`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00907068872064511`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.51316159899305`", ",", 
              RowBox[{"-", "0.8138720656466969`"}]}], "}"}], ",", 
            RowBox[{"-", "106.01304354804157`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012556390690574295`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6709939753795493`", ",", "1.8909537908995016`"}], 
             "}"}], ",", "113.06696575224656`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01247986905247673`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4586418271341675`", ",", "2.389602901024031`"}], 
             "}"}], ",", "108.75630302872577`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23889321070749203`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3688715306818175`", ",", "1.0498166231520185`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.59465784953875`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23797549081717562`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1586051450993393`", ",", "0.9757481031880711`"}], 
             "}"}], ",", 
            RowBox[{"-", "163.43413980529309`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011543135077166946`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6840645451323115`", ",", "0.07101065378714078`"}], 
             "}"}], ",", 
            RowBox[{"-", "101.35655223845953`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010851675001839178`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.636307215419951`", ",", 
              RowBox[{"-", "0.16676976387992273`"}]}], "}"}], ",", 
            RowBox[{"-", "90.0464531666702`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008125135984197411`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2306487365576024`", ",", 
              RowBox[{"-", "0.434011017903535`"}]}], "}"}], ",", 
            RowBox[{"-", "83.94128743662209`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008102817684153265`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2415014762410768`", ",", 
              RowBox[{"-", "0.5362599279497503`"}]}], "}"}], ",", 
            RowBox[{"-", "85.28549102088918`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008307926646532274`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.5064694967424925`", ",", 
              RowBox[{"-", "4.068756492661345`"}]}], "}"}], ",", 
            RowBox[{"-", "68.58622709969703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00814390780893489`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.578285539175333`", ",", 
              RowBox[{"-", "4.251879845857825`"}]}], "}"}], ",", 
            RowBox[{"-", "60.87456459730977`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2883556225704925`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.301734612303231`", ",", "2.9715636864263844`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.06144309282487`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.28753592812209033`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.15678870259673`", ",", "2.953924326936628`"}], "}"}], 
            ",", 
            RowBox[{"-", "174.61040585382725`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03211762285383692`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.926853849632756`", ",", "3.6996533119034503`"}], 
             "}"}], ",", "12.002174717915564`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03203841564892293`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.06111150636273`", ",", "3.728195983954255`"}], "}"}], 
            ",", "11.902969724332527`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02175486062377545`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.08493018736672`", ",", "3.4665318756219445`"}], "}"}],
             ",", 
            RowBox[{"-", "6.574913621847145`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021678417844706352`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.373505533449265`", ",", "3.4332706036957727`"}], 
             "}"}], ",", 
            RowBox[{"-", "4.06577885453093`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011154716645471472`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8423809303975185`", ",", "1.5972051673966625`"}], 
             "}"}], ",", 
            RowBox[{"-", "31.038504656676153`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011126973395551534`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.845562438732375`", ",", "1.5952906131564648`"}], 
             "}"}], ",", 
            RowBox[{"-", "31.422612880117853`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14475051422345883`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.358079660061334`", ",", "3.168928479704756`"}], "}"}],
             ",", "33.501543627363965`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.14166595628413695`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.592570358476737`", ",", "3.3241435725362685`"}], 
             "}"}], ",", "25.5607943242936`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09327772675433729`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.913412393865279`", ",", "0.6424620335464204`"}], 
             "}"}], ",", 
            RowBox[{"-", "30.169237051894775`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09235911634911008`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.966790918559761`", ",", "0.6114333462384633`"}], 
             "}"}], ",", 
            RowBox[{"-", "35.86450208913387`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04763394442576827`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.223831140464143`", ",", "0.6062246397799318`"}], 
             "}"}], ",", 
            RowBox[{"-", "80.60220388399776`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04745898715223935`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.25788395479941`", ",", "0.40047914863717937`"}], 
             "}"}], ",", 
            RowBox[{"-", "83.27867753885248`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033614228463448755`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5400266537753016`", ",", "0.8584285114380503`"}], 
             "}"}], ",", 
            RowBox[{"-", "135.17633474703447`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03339658625640332`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.418791294547206`", ",", "0.7379370981728014`"}], 
             "}"}], ",", 
            RowBox[{"-", "139.66540582714876`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035961713726436834`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.58339473401461`", ",", "2.2758211254393754`"}], "}"}],
             ",", "150.61079285226117`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02528997250968048`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4639266872794554`", ",", "2.343108263921816`"}], 
             "}"}], ",", "168.6732329006984`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0863446045109698`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.345772548463666`", ",", "0.9347785088876049`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.18199670514844`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08104188262691892`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1109418660443935`", ",", "0.8813486848297772`"}], 
             "}"}], ",", 
            RowBox[{"-", "155.78302703149296`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020276015012280636`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5719528092812887`", ",", 
              RowBox[{"-", "0.3436921906763729`"}]}], "}"}], ",", 
            RowBox[{"-", "144.0511296601331`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019897858517167778`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.540315837718936`", ",", 
              RowBox[{"-", "0.3666346889023103`"}]}], "}"}], ",", 
            RowBox[{"-", "151.59344059413488`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008052447493641963`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.96350433554662`", ",", 
              RowBox[{"-", "3.6571197780856823`"}]}], "}"}], ",", 
            RowBox[{"-", "89.01570403582491`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00803258833253827`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.966474220943696`", ",", 
              RowBox[{"-", "3.8299795327438115`"}]}], "}"}], ",", 
            RowBox[{"-", "88.91431905883087`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012311030817442746`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.361821664728799`", ",", 
              RowBox[{"-", "0.379995678727669`"}]}], "}"}], ",", 
            RowBox[{"-", "74.0047999063739`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012253810099394923`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.361840882167571`", ",", 
              RowBox[{"-", "0.3800627190973369`"}]}], "}"}], ",", 
            RowBox[{"-", "70.52434698635753`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018060993525520194`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8735678907445887`", ",", "1.9718076657689771`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.8494579226454`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016796250386695615`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7775506922884885`", ",", "1.9421761779742046`"}], 
             "}"}], ",", 
            RowBox[{"-", "150.97527476813147`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010686138660700773`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.888508547977647`", ",", "2.4429143369798125`"}], 
             "}"}], ",", 
            RowBox[{"-", "131.69353786213142`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010658263821516021`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.767552045297535`", ",", "2.3071249030370566`"}], 
             "}"}], ",", 
            RowBox[{"-", "130.72744958687673`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010053932046359442`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.613073684194516`", ",", "1.9149759269957787`"}], 
             "}"}], ",", 
            RowBox[{"-", "77.08440520095631`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009994875061707703`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.628545758690353`", ",", "1.8475056952641078`"}], 
             "}"}], ",", 
            RowBox[{"-", "72.88313083703785`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012652570200471572`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4349281815717845`", ",", "0.8897875450281161`"}], 
             "}"}], ",", 
            RowBox[{"-", "91.92575415460854`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01261710592430744`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.4265704102400125`", ",", "0.6412175565394289`"}], 
             "}"}], ",", 
            RowBox[{"-", "93.39373505485621`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010116426662495704`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7061559660456895`", ",", "1.6302363202035928`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.30580631991515`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010076230151400516`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5630614227640534`", ",", "1.590029904485815`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.3474024817301`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028163532390573003`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9882413674549433`", ",", "3.6907620563599965`"}], 
             "}"}], ",", "162.7321393667719`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02809378635381146`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8913015105007416`", ",", "3.7208958175518165`"}], 
             "}"}], ",", "163.01067611444506`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01214396761602647`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.417849472132508`", ",", 
              RowBox[{"-", "1.058102453305081`"}]}], "}"}], ",", 
            RowBox[{"-", "127.03151607358555`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012107295987815172`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3495126332599936`", ",", 
              RowBox[{"-", "1.148684791261067`"}]}], "}"}], ",", 
            RowBox[{"-", "128.89387053172317`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012241230207459314`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4346059552727373`", ",", 
              RowBox[{"-", "0.17662184558167104`"}]}], "}"}], ",", 
            RowBox[{"-", "112.96514531236245`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0121397315140795`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.416036833516986`", ",", 
              RowBox[{"-", "0.22044205134953043`"}]}], "}"}], ",", 
            RowBox[{"-", "118.16921480874805`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01951665515940765`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.34509924734631`", ",", 
              RowBox[{"-", "2.079337547647544`"}]}], "}"}], ",", 
            "178.9921332546149`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01882252703547951`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.312866981451187`", ",", 
              RowBox[{"-", "2.0787705044848455`"}]}], "}"}], ",", 
            RowBox[{"-", "171.4678408334471`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011482143331641896`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.604807374485697`", ",", 
              RowBox[{"-", "2.3781584461875953`"}]}], "}"}], ",", 
            "167.08385221199129`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011371672798873451`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.603160721611645`", ",", 
              RowBox[{"-", "2.3777808238799247`"}]}], "}"}], ",", 
            "172.71260510540782`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01322277503487157`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.049286457408408`", ",", "0.6750501916120701`"}], 
             "}"}], ",", "82.99919189531913`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01162506070492232`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.058839754670561`", ",", "0.7528464829549052`"}], 
             "}"}], ",", "69.01017495097477`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012849079843049296`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.857304483961946`", ",", "1.0785491778117529`"}], 
             "}"}], ",", "144.4190324017792`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012710497532463748`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.747626960664649`", ",", "1.1570154792815404`"}], 
             "}"}], ",", "138.46443462602127`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017117752374642584`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6677729820998963`", ",", 
              RowBox[{"-", "0.13071392041402335`"}]}], "}"}], ",", 
            "170.59194058565123`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017046098949106227`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6187428803404096`", ",", 
              RowBox[{"-", "0.12258995378609706`"}]}], "}"}], ",", 
            "167.45506543681174`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08699476907638912`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.199850853875885`", ",", 
              RowBox[{"-", "3.9113342055346747`"}]}], "}"}], ",", 
            RowBox[{"-", "146.6160140190385`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08676491918242181`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.167172969626897`", ",", 
              RowBox[{"-", "3.932868198177771`"}]}], "}"}], ",", 
            RowBox[{"-", "147.68730406167515`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03630676333844383`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2504504448487164`", ",", 
              RowBox[{"-", "3.355483321000886`"}]}], "}"}], ",", 
            RowBox[{"-", "146.65467702180703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03620787450596532`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.135404990293597`", ",", 
              RowBox[{"-", "3.4311843999347778`"}]}], "}"}], ",", 
            RowBox[{"-", "147.94402878154762`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013616012193963287`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.833124009085632`", ",", 
              RowBox[{"-", "1.0373182512021093`"}]}], "}"}], ",", 
            RowBox[{"-", "176.09588682645344`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013580844600214552`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6662098907927887`", ",", 
              RowBox[{"-", "1.0487093524605482`"}]}], "}"}], ",", 
            RowBox[{"-", "176.97254842818958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013393669868598643`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.323627665433101`", ",", 
              RowBox[{"-", "3.3923747599303007`"}]}], "}"}], ",", 
            RowBox[{"-", "143.68317284666688`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013335137780755424`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.171777647535761`", ",", 
              RowBox[{"-", "3.5039883632184616`"}]}], "}"}], ",", 
            RowBox[{"-", "146.9635437009482`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20478967450020755`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.396788952294392`", ",", 
              RowBox[{"-", "3.863917628126922`"}]}], "}"}], ",", 
            RowBox[{"-", "72.10546409752862`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20403468454437404`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.3970953867840885`", ",", 
              RowBox[{"-", "3.8648666770073263`"}]}], "}"}], ",", 
            RowBox[{"-", "69.41522810646259`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02227088531389559`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.109466376042483`", ",", 
              RowBox[{"-", "2.3475363475123796`"}]}], "}"}], ",", 
            RowBox[{"-", "85.61268761822976`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021259099729042108`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.112100941858732`", ",", 
              RowBox[{"-", "2.3818749918280813`"}]}], "}"}], ",", 
            RowBox[{"-", "95.96356786725185`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008400427483313232`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.745581720203257`", ",", "2.93105649072293`"}], "}"}], 
            ",", "131.51661008307406`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008308138995562058`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.685296765772567`", ",", "2.999156445129354`"}], "}"}],
             ",", "137.52387098832637`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16868884921620195`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0950691582980365`", ",", 
              RowBox[{"-", "0.8562053790945715`"}]}], "}"}], ",", 
            RowBox[{"-", "137.16462930930942`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16807545660187906`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.0876498459533925`", ",", 
              RowBox[{"-", "0.8630842502231568`"}]}], "}"}], ",", 
            RowBox[{"-", "134.52550444890957`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009235164199183203`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.994065167912832`", ",", 
              RowBox[{"-", "1.694889300567602`"}]}], "}"}], ",", 
            RowBox[{"-", "36.57643377652856`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009188077088564358`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.063713541240318`", ",", 
              RowBox[{"-", "1.7465703138020194`"}]}], "}"}], ",", 
            RowBox[{"-", "32.80477791676501`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008301390568634113`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.022441816341458`", ",", "2.3231662784791007`"}], 
             "}"}], ",", 
            RowBox[{"-", "114.97623394424957`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008195005765858115`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.941956888865805`", ",", "2.150378709482794`"}], "}"}],
             ",", 
            RowBox[{"-", "108.52791239264472`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.037152030188491524`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.6701500886058795`", ",", "3.255165769425571`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.8301479932221`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03705124552272197`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1265156431039856`", ",", "3.076744775513107`"}], 
             "}"}], ",", 
            RowBox[{"-", "160.56766584184643`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03586182727798118`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.946889611226584`", ",", "1.869578185063331`"}], "}"}],
             ",", 
            RowBox[{"-", "160.12157316302657`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03571534524504367`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.81685376611325`", ",", "1.822561236102724`"}], "}"}], 
            ",", 
            RowBox[{"-", "157.0678804870531`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040513753908650474`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.542744171328283`", ",", "2.780874315517512`"}], "}"}],
             ",", 
            RowBox[{"-", "177.86796452504478`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04039359241338009`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3812344063793915`", ",", "2.7748615939355155`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.09399057676393`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.160591069784868`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.974551438823336`", ",", "3.606204375382554`"}], "}"}],
             ",", "116.36639636486434`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15973254664361652`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.93698715466518`", ",", "3.681988704384638`"}], "}"}], 
            ",", "120.28362763927251`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25191344162900536`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.297399842444705`", ",", 
              RowBox[{"-", "1.3703794401746636`"}]}], "}"}], ",", 
            RowBox[{"-", "89.97657071549422`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.250674451114743`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.297504651474537`", ",", 
              RowBox[{"-", "1.6266875117243267`"}]}], "}"}], ",", 
            RowBox[{"-", "93.6360836794783`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06429780882909183`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.443488422529625`", ",", 
              RowBox[{"-", "0.6741042190569693`"}]}], "}"}], ",", 
            RowBox[{"-", "175.81842905879313`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06402806781700361`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.362490433178861`", ",", 
              RowBox[{"-", "0.6800261468809501`"}]}], "}"}], ",", 
            RowBox[{"-", "172.6741016094434`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02274946166271862`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.183785132830618`", ",", 
              RowBox[{"-", "2.3608905041613863`"}]}], "}"}], ",", 
            RowBox[{"-", "101.81014208720985`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0205864070092409`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.149600281557578`", ",", 
              RowBox[{"-", "2.5243795802136213`"}]}], "}"}], ",", 
            RowBox[{"-", "114.84087775212274`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18171996414288846`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.329947657622755`", ",", 
              RowBox[{"-", "2.9378162837687634`"}]}], "}"}], ",", 
            RowBox[{"-", "103.5831535432631`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1812231873625461`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.28916863721412`", ",", 
              RowBox[{"-", "3.106593666353948`"}]}], "}"}], ",", 
            RowBox[{"-", "104.8966509732426`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009271731607448755`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1955955310933275`", ",", "2.9430773810869217`"}], 
             "}"}], ",", "106.60283386995378`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009096705829027354`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.135076293354458`", ",", "3.146048459213462`"}], "}"}],
             ",", "99.02461952672782`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030435601989512576`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1615855378483713`", ",", "1.207032031787801`"}], 
             "}"}], ",", "162.29368532500487`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030262615454523963`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.924273756208271`", ",", "1.2827967015776476`"}], 
             "}"}], ",", "166.39635003812646`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24081433365777574`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4410452598506835`", ",", 
              RowBox[{"-", "0.18049458499323162`"}]}], "}"}], ",", 
            RowBox[{"-", "119.60146303493894`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23919154037313073`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4127101159956346`", ",", 
              RowBox[{"-", "0.23037049313153385`"}]}], "}"}], ",", 
            RowBox[{"-", "124.20738311193588`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.024225967439864368`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9852894961017116`", ",", 
              RowBox[{"-", "0.6460686592447719`"}]}], "}"}], ",", 
            RowBox[{"-", "102.77489794048668`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02407531150051946`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.935730260460921`", ",", 
              RowBox[{"-", "0.8646476621391642`"}]}], "}"}], ",", 
            RowBox[{"-", "98.4044333340578`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009044107843674506`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.43125834980598`", ",", 
              RowBox[{"-", "1.0992574212415742`"}]}], "}"}], ",", 
            RowBox[{"-", "104.30040272664654`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008780237424073651`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.411462985290634`", ",", 
              RowBox[{"-", "1.1769154495360734`"}]}], "}"}], ",", 
            RowBox[{"-", "113.20783884946086`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01240381375548319`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3767600525366226`", ",", "2.6307316791079334`"}], 
             "}"}], ",", "104.44564030520498`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012368030325712107`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.262077448055811`", ",", "3.075918410771986`"}], "}"}],
             ",", "102.81557021425061`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010201634959507322`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6361714884051755`", ",", 
              RowBox[{"-", "0.33417672375082363`"}]}], "}"}], ",", 
            RowBox[{"-", "78.73635409488094`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010103089830228935`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.648156598461509`", ",", 
              RowBox[{"-", "0.3943550324390119`"}]}], "}"}], ",", 
            RowBox[{"-", "84.3765444337419`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008080560688500561`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2680396580060287`", ",", 
              RowBox[{"-", "0.8580522163487847`"}]}], "}"}], ",", 
            RowBox[{"-", "86.62969460515679`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008055170324611846`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.284457958746897`", ",", 
              RowBox[{"-", "1.1368441939427059`"}]}], "}"}], ",", 
            RowBox[{"-", "88.67644098108464`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03195940378166947`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.403187952588996`", ",", "3.800301315581602`"}], "}"}],
             ",", "11.803764730745819`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031742246390203614`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.630284451455838`", ",", "3.8477598192669125`"}], 
             "}"}], ",", "7.173727396519533`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02160224367220629`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.657254405218824`", ",", "3.413101570340565`"}], "}"}],
             ",", 
            RowBox[{"-", "1.556644087214717`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016496266149675438`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.709790060700965`", ",", "3.4116739007042938`"}], 
             "}"}], ",", 
            RowBox[{"-", "18.508550410030043`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011099299146749298`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.078171501620103`", ",", "1.4531793955188055`"}], 
             "}"}], ",", 
            RowBox[{"-", "31.806721103561447`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01105173183287477`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.126234424523609`", ",", "1.4233713146992655`"}], 
             "}"}], ",", 
            RowBox[{"-", "35.02243483108043`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1386471286652363`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.76948545282574`", ",", "3.4087582852440135`"}], "}"}],
             ",", "17.620045021223245`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1383026528670347`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.826222303376928`", ",", "3.426778123712218`"}], "}"}],
             ",", "17.981462266738085`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09144955253095094`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.159514962471937`", ",", "0.4721062938499978`"}], 
             "}"}], ",", 
            RowBox[{"-", "41.55976712637297`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07698969842798983`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.812765773017162`", ",", 
              RowBox[{"-", "0.10705713229944788`"}]}], "}"}], ",", 
            RowBox[{"-", "56.68410833936893`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012173485554484881`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.888113141749456`", ",", 
              RowBox[{"-", "0.22169323589710352`"}]}], "}"}], ",", 
            RowBox[{"-", "112.81583459778055`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04728467248867965`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.2919813439335`", ",", "0.11115117115553974`"}], "}"}],
             ",", 
            RowBox[{"-", "85.95515119370748`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04715996806817774`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.30137660267463`", ",", 
              RowBox[{"-", "0.021712658906653276`"}]}], "}"}], ",", 
            RowBox[{"-", "87.01209658936926`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033180353218404846`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2337022530914274`", ",", "0.5807779500679296`"}], 
             "}"}], ",", 
            RowBox[{"-", "144.15447690726316`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033026689297777176`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1850486011279524`", ",", "0.5456290314456834`"}], 
             "}"}], ",", 
            RowBox[{"-", "147.62335958098154`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01067174121675637`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4639266872794554`", ",", "2.343108263921816`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.6346877148011`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010642239483722064`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.42524535983107`", ",", "2.32639715513739`"}], "}"}], 
            ",", 
            RowBox[{"-", "158.01915955236734`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0177851009661479`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.419021162144573`", ",", "2.3521030916458017`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.26432705086427`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017624845741933917`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4036866376173576`", ",", "2.350292019126975`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.70609134522348`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019526754805094863`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.381604823976741`", ",", 
              RowBox[{"-", "0.45247289711526967`"}]}], "}"}], ",", 
            RowBox[{"-", "159.13575152813664`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0188306493500104`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1315529398097395`", ",", 
              RowBox[{"-", "0.5477796894646114`"}]}], "}"}], ",", 
            RowBox[{"-", "149.5881729983392`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008012778148628164`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.972389363345108`", ",", 
              RowBox[{"-", "4.14210818712324`"}]}], "}"}], ",", 
            RowBox[{"-", "88.81293408183322`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01219685533881422`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.449908629578593`", ",", 
              RowBox[{"-", "0.6290946221239575`"}]}], "}"}], ",", 
            RowBox[{"-", "67.0438940663414`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012160121274981043`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.531812469884396`", ",", 
              RowBox[{"-", "0.8224597114203069`"}]}], "}"}], ",", 
            RowBox[{"-", "68.89346227437515`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015620072431449951`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6290617411838237`", ",", "1.8597836212114276`"}], 
             "}"}], ",", 
            RowBox[{"-", "139.10109161361768`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01288808963587158`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4058226965187366`", ",", "1.6664153391472372`"}], 
             "}"}], ",", 
            RowBox[{"-", "154.66874718928074`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010630461693970548`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.615425364229257`", ",", "2.1304326170238865`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.76136131162164`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01060424037599711`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.614686661186413`", ",", "2.1295447813128416`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.6479071713565`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009936164978887019`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.713787371339179`", ",", "1.570713499858081`"}], "}"}],
             ",", 
            RowBox[{"-", "68.6818564731195`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00990682077110572`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.774328954197708`", ",", "1.4155775426289767`"}], 
             "}"}], ",", 
            RowBox[{"-", "70.43424622580066`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012581741052048121`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.405720745714707`", ",", "0.28962841116119903`"}], 
             "}"}], ",", 
            RowBox[{"-", "94.86171595510363`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010036193356730718`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3243323955771182`", ",", "1.5094446611867771`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.388998643545`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009958635797187197`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1473289708149186`", ",", "1.439324730597311`"}], 
             "}"}], ",", 
            RowBox[{"-", "163.39109675615265`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01207073509839684`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1502362259938024`", ",", 
              RowBox[{"-", "1.3957048186924736`"}]}], "}"}], ",", 
            RowBox[{"-", "130.75622498986158`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012039266566667994`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.140939782144625`", ",", 
              RowBox[{"-", "1.4064915027523015`"}]}], "}"}], ",", 
            RowBox[{"-", "131.7173527867946`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012039074401536185`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3009531280733664`", ",", 
              RowBox[{"-", "0.43534944114653396`"}]}], "}"}], ",", 
            RowBox[{"-", "123.37328430513378`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011993146577347942`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.234991679446133`", ",", 
              RowBox[{"-", "0.5354867968672238`"}]}], "}"}], ",", 
            RowBox[{"-", "120.558706637335`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018153086228537434`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.126212024936174`", ",", 
              RowBox[{"-", "2.1067733899757095`"}]}], "}"}], ",", 
            RowBox[{"-", "161.92781492150914`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017554742480894805`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.074089590001083`", ",", 
              RowBox[{"-", "2.1237816255091575`"}]}], "}"}], ",", 
            RowBox[{"-", "171.22254815208146`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011262265111103337`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3692815675533225`", ",", 
              RowBox[{"-", "2.347872509711066`"}]}], "}"}], ",", 
            "178.34135799882444`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01119160099071891`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3459786044157145`", ",", 
              RowBox[{"-", "2.3471977292237662`"}]}], "}"}], ",", 
            "173.94463182860906`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010220398973492943`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.11598951992452`", ",", "0.901805773284278`"}], "}"}], 
            ",", "55.021158006630465`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009743557485578981`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.117465107955368`", ",", "0.9039147885466935`"}], 
             "}"}], ",", "65.46225261112687`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012573409885857397`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.604221962285013`", ",", "1.2840482842581151`"}], 
             "}"}], ",", "132.50983685026335`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01252307649637794`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.563582880352831`", ",", "1.3283827761195492`"}], 
             "}"}], ",", "129.5255008920877`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016974745458589298`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3194844998904247`", ",", 
              RowBox[{"-", "0.05599969509460018`"}]}], "}"}], ",", 
            "164.31819028797227`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0169230207771294`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.151209848715848`", ",", 
              RowBox[{"-", "0.008757463641831466`"}]}], "}"}], ",", 
            "166.22371894222718`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08653567657754005`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9464350153265713`", ",", 
              RowBox[{"-", "4.072481409782038`"}]}], "}"}], ",", 
            RowBox[{"-", "148.75859410431212`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0859778359737021`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.835722394194781`", ",", 
              RowBox[{"-", "4.13964075830178`"}]}], "}"}], ",", 
            RowBox[{"-", "144.2823865496042`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013545767837733614`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.312220468657105`", ",", 
              RowBox[{"-", "1.0674312255994285`"}]}], "}"}], ",", 
            RowBox[{"-", "177.84921002992576`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013504632056860493`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1483285684874125`", ",", 
              RowBox[{"-", "1.0735863512073813`"}]}], "}"}], ",", 
            RowBox[{"-", "179.73856896873326`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01327686148578607`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.947765141123858`", ",", 
              RowBox[{"-", "3.6496665162900763`"}]}], "}"}], ",", 
            RowBox[{"-", "150.24391455522954`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013244126484075079`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.887302745128805`", ",", 
              RowBox[{"-", "3.684232142683669`"}]}], "}"}], ",", 
            RowBox[{"-", "150.16682420031646`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2032824779800118`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.474559788528993`", ",", 
              RowBox[{"-", "4.071123810438171`"}]}], "}"}], ",", 
            RowBox[{"-", "66.72499211539612`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15014819618983194`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.579937962894859`", ",", 
              RowBox[{"-", "4.3161032824231205`"}]}], "}"}], ",", 
            RowBox[{"-", "49.289173122385115`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03924596278987575`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.666259953006467`", ",", 
              RowBox[{"-", "4.416423503191367`"}]}], "}"}], ",", 
            "4.026114600010307`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01025816915813612`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.798279980013547`", ",", 
              RowBox[{"-", "4.407131294580484`"}]}], "}"}], ",", 
            "57.34140232240581`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02029328043853616`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.094646516432469`", ",", 
              RowBox[{"-", "2.548964716506338`"}]}], "}"}], ",", 
            RowBox[{"-", "106.31444811627381`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02024264715887027`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.017709930673849`", ",", 
              RowBox[{"-", "2.8118212473725794`"}]}], "}"}], ",", 
            RowBox[{"-", "105.86773792171074`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008216864404423688`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.516406202241529`", ",", "3.153786736063154`"}], "}"}],
             ",", "143.5311318935787`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00819351101102162`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.4247886751073`", ",", "3.2215031330595845`"}], "}"}], 
            ",", "145.07906227575617`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16746429442840072`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.897134594666521`", ",", 
              RowBox[{"-", "1.0567814332362302`"}]}], "}"}], ",", 
            RowBox[{"-", "131.88637958850958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1670094770389857`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.838260177596472`", ",", 
              RowBox[{"-", "1.1224294320918338`"}]}], "}"}], ",", 
            RowBox[{"-", "133.15664609206152`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008089984316145455`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.863954869871214`", ",", "1.9176321217127803`"}], 
             "}"}], ",", 
            RowBox[{"-", "102.07959084103997`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03695073426189968`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.828233618459975`", ",", "2.9715138482660324`"}], 
             "}"}], ",", 
            RowBox[{"-", "159.30518369046987`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.036355405316505024`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.657936910198665`", ",", "2.9071816910221346`"}], 
             "}"}], ",", 
            RowBox[{"-", "166.4165894882148`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03556946153593966`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.56275376786472`", ",", "1.7150572909505666`"}], "}"}],
             ",", 
            RowBox[{"-", "154.01418781107986`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03383326130557584`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.411361324814766`", ",", "1.641264663471477`"}], "}"}],
             ",", 
            RowBox[{"-", "164.6094163263504`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04027378731028649`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.116889302356681`", ",", "2.756812497992865`"}], "}"}],
             ",", 
            RowBox[{"-", "174.32001662848245`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.040151370201531866`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.90488330168855`", ",", "2.735726286789342`"}], "}"}], 
            ",", 
            RowBox[{"-", "176.21379992706252`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2494415543503198`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.281273842308778`", ",", 
              RowBox[{"-", "1.8821019026795236`"}]}], "}"}], ",", 
            RowBox[{"-", "97.29559664346239`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24882635126203284`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.257770156028219`", ",", 
              RowBox[{"-", "2.0656888230253854`"}]}], "}"}], ",", 
            RowBox[{"-", "97.19117866979059`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06375945841756175`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.093639983498253`", ",", 
              RowBox[{"-", "0.7145902088797783`"}]}], "}"}], ",", 
            RowBox[{"-", "169.5297741600937`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06356053230102765`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.914514873020996`", ",", 
              RowBox[{"-", "0.7476928139270784`"}]}], "}"}], ",", 
            RowBox[{"-", "171.5445853909737`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01862901899980518`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.094872903973718`", ",", 
              RowBox[{"-", "2.6425988951424286`"}]}], "}"}], ",", 
            RowBox[{"-", "127.87161341703548`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018325650740303748`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.951171420434094`", ",", 
              RowBox[{"-", "2.8273803728010924`"}]}], "}"}], ",", 
            RowBox[{"-", "120.72891428954327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.18072776864525777`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.207895388041592`", ",", 
              RowBox[{"-", "3.412112857650837`"}]}], "}"}], ",", 
            RowBox[{"-", "106.21014840322182`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17462954874357203`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.186656610075415`", ",", 
              RowBox[{"-", "3.4851689095687415`"}]}], "}"}], ",", 
            RowBox[{"-", "115.58013876828221`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008924984074536874`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.097702904223805`", ",", "3.381360299048231`"}], "}"}],
             ",", "91.44640518350201`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008863020427805972`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.09629675294918`", ",", "3.437049686041319`"}], "}"}], 
            ",", "96.13907286419816`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030090612121421702`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6408519376863855`", ",", "1.35138276775199`"}], "}"}],
             ",", "170.49901475124798`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02991307961919179`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5958833832665844`", ",", "1.3589087179036896`"}], 
             "}"}], ",", "166.2846162849951`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23757968272510135`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2698138327236355`", ",", 
              RowBox[{"-", "0.4405777175670541`"}]}], "}"}], ",", 
            RowBox[{"-", "128.81330318893296`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2344716387877651`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.937998642286805`", ",", 
              RowBox[{"-", "0.8530764190411502`"}]}], "}"}], ",", 
            RowBox[{"-", "122.30571876437818`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023925592457177423`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8973613008508083`", ",", 
              RowBox[{"-", "1.124342701262884`"}]}], "}"}], ",", 
            RowBox[{"-", "94.03396872762885`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023766055741274536`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.892751312928141`", ",", 
              RowBox[{"-", "1.1897116440320903`"}]}], "}"}], ",", 
            RowBox[{"-", "98.60910649204439`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008524065674097695`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.3351822088776855`", ",", 
              RowBox[{"-", "1.3548246086900826`"}]}], "}"}], ",", 
            RowBox[{"-", "122.11527497227516`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008468562486519738`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.21139443529494`", ",", 
              RowBox[{"-", "1.5520424102655443`"}]}], "}"}], ",", 
            RowBox[{"-", "117.60966534690901`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012332350126598257`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1941208268320462`", ",", "3.3746548047126277`"}], 
             "}"}], ",", "101.18550012329626`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012259491984874664`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1530100585787526`", ",", "3.5825554779714337`"}], 
             "}"}], ",", "96.96708487893588`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01000549662116167`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6728400483340056`", ",", 
              RowBox[{"-", "0.6450395782798753`"}]}], "}"}], ",", 
            RowBox[{"-", "90.01673477260266`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009872945037530766`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6728293627882644`", ",", 
              RowBox[{"-", "0.6816242794814096`"}]}], "}"}], ",", 
            RowBox[{"-", "83.47290169780094`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00802985974114967`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.291385780639463`", ",", 
              RowBox[{"-", "1.436690548982074`"}]}], "}"}], ",", 
            RowBox[{"-", "90.72318735701245`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008009581870598843`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2897548956541605`", ",", 
              RowBox[{"-", "1.5658933942645108`"}]}], "}"}], ",", 
            RowBox[{"-", "91.35304729242709`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03152656453729881`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.907182003757885`", ",", "3.882611126529649`"}], "}"}],
             ",", "2.543690062293249`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025818944992908193`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.679674476361992`", ",", "3.916929071821072`"}], "}"}],
             ",", 
            RowBox[{"-", "13.17785814177143`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012597154305367621`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.841941765830849`", ",", "3.367434628351651`"}], "}"}],
             ",", 
            RowBox[{"-", "35.460456732844975`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012447299934343995`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.081998778109991`", ",", "3.196453475142506`"}], "}"}],
             ",", 
            RowBox[{"-", "29.225705314989238`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011004368374155358`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.370656595532074`", ",", "1.2520823986515497`"}], 
             "}"}], ",", 
            RowBox[{"-", "38.238148558599754`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01096704909811298`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.442301448445294`", ",", "1.1956261762702811`"}], 
             "}"}], ",", 
            RowBox[{"-", "40.607587372419204`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.13795903293636302`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.135770010216715`", ",", "3.527245556395318`"}], "}"}],
             ",", "18.342879512252928`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1342857484716806`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.25819076382651`", ",", "3.567834013922942`"}], "}"}], 
            ",", "26.96454811711376`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014459854102961163`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.812765773017162`", ",", 
              RowBox[{"-", "0.10705713229944788`"}]}], "}"}], ",", 
            RowBox[{"-", "15.676723293953211`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013999677330604303`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.898297320087702`", ",", 
              RowBox[{"-", "0.13106147713959804`"}]}], "}"}], ",", 
            RowBox[{"-", "6.494154022295504`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06481621287350493`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.888113141749456`", ",", 
              RowBox[{"-", "0.22169323589710355`"}]}], "}"}], ",", 
            RowBox[{"-", "71.80844955236462`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06463714399228207`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.9413563276372345`", ",", 
              RowBox[{"-", "0.3837138304238663`"}]}], "}"}], ",", 
            RowBox[{"-", "73.18897607761542`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010248633872102194`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.834918368184336`", ",", 
              RowBox[{"-", "0.34814076765746804`"}]}], "}"}], ",", 
            RowBox[{"-", "127.94017581077621`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010095283466440808`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.220197575325882`", ",", 
              RowBox[{"-", "1.1366431247685609`"}]}], "}"}], ",", 
            RowBox[{"-", "121.04426618038063`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04703559253210442`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.319840476503305`", ",", 
              RowBox[{"-", "0.3754533054975368`"}]}], "}"}], ",", 
            RowBox[{"-", "88.0690419850314`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.046203128067370994`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.329960608744796`", ",", 
              RowBox[{"-", "0.6756262338699552`"}]}], "}"}], ",", 
            RowBox[{"-", "95.4563749148177`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03287373702118617`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9646265652922676`", ",", "0.4058709806656777`"}], 
             "}"}], ",", 
            RowBox[{"-", "151.09224225469993`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032787214709693056`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.871601740402528`", ",", "0.35450208351356993`"}], 
             "}"}], ",", 
            RowBox[{"-", "150.05154384481708`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01061281930741165`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1344910450342534`", ",", "2.2090378699962967`"}], 
             "}"}], ",", 
            RowBox[{"-", "159.40363138993385`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010586617895193861`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.605605904911915`", ",", "2.0102812707078206`"}], 
             "}"}], ",", 
            RowBox[{"-", "159.23778215747774`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017466034520592713`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1808192602493235`", ",", "2.3452581568970534`"}], 
             "}"}], ",", "175.85214436041736`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01711559636621599`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1380886835098276`", ",", "2.34835699848299`"}], "}"}],
             ",", 
            RowBox[{"-", "176.38791267649066`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01815935922186763`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{
                "0.`", ",", "0.9999999999999999`", ",", 
                 "167.35910683550452`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.013239309426549`", ",", 
              RowBox[{"-", "0.6172267168862021`"}]}], "}"}], ",", 
            RowBox[{"-", "140.04059446854177`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018110736853952092`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9142006442519786`", ",", 
              RowBox[{"-", "0.7002105201445175`"}]}], "}"}], ",", 
            RowBox[{"-", "138.8692154410246`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012123497845521093`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.640428094261788`", ",", 
              RowBox[{"-", "1.1038480785083356`"}]}], "}"}], ",", 
            RowBox[{"-", "70.74303048240873`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012067911144361454`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.653211682028765`", ",", 
              RowBox[{"-", "1.1404403509867747`"}]}], "}"}], ",", 
            RowBox[{"-", "67.30632488531677`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010633936250374093`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.264465092946304`", ",", "1.5995015474563508`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.23640276494328`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01060386785010563`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1433883712892046`", ",", "1.578667178518207`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.71757399346654`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010578083736072108`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.4640233858549445`", ",", "1.9477339013071668`"}], 
             "}"}], ",", 
            RowBox[{"-", "129.5344530310914`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010506174175654186`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.332146241952127`", ",", "1.7879499890282105`"}], 
             "}"}], ",", 
            RowBox[{"-", "134.16585600410514`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009877563224781047`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.862360376716455`", ",", "1.1678882075169161`"}], 
             "}"}], ",", 
            RowBox[{"-", "72.18663597848182`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009778346537379792`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.880779110920352`", ",", "1.1105665064762662`"}], 
             "}"}], ",", 
            RowBox[{"-", "66.4350248140164`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012581741052048123`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.380816080976115`", ",", 
              RowBox[{"-", "0.003170653943217805`"}]}], "}"}], ",", 
            RowBox[{"-", "120.50455369498104`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012548900588498939`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.29815300656839`", ",", 
              RowBox[{"-", "0.1434792057361047`"}]}], "}"}], ",", 
            RowBox[{"-", "121.47613587551825`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00988167758590537`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8900303313193105`", ",", "1.3625771376378866`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.39319486876022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009821481803894826`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8701993775974306`", ",", "1.3585039727833168`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.08378732793838`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01200788007372809`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9274205586807724`", ",", 
              RowBox[{"-", "1.6459941452217333`"}]}], "}"}], ",", 
            RowBox[{"-", "132.67848058372843`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011948967157664725`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.880748875491625`", ",", 
              RowBox[{"-", "1.6966098945074817`"}]}], "}"}], ",", 
            RowBox[{"-", "136.33025312430456`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011947393963060755`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0824279862392947`", ",", 
              RowBox[{"-", "0.7938827603812862`"}]}], "}"}], ",", 
            RowBox[{"-", "117.74412896953626`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011917947551899127`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0544620146035415`", ",", 
              RowBox[{"-", "0.8470505500838811`"}]}], "}"}], ",", 
            RowBox[{"-", "117.75118376801811`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016976120737314512`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9177412468353956`", ",", 
              RowBox[{"-", "2.1479226278260843`"}]}], "}"}], ",", 
            "179.48271861734622`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01690142703356013`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9031775651540577`", ",", 
              RowBox[{"-", "2.147791139500906`"}]}], "}"}], ",", 
            RowBox[{"-", "177.21456338797933`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011121380246321502`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.071169419359076`", ",", 
              RowBox[{"-", "2.318045595221131`"}]}], "}"}], ",", 
            "169.54790565839377`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011093664199602598`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.914250378235094`", ",", 
              RowBox[{"-", "2.2890980576784323`"}]}], "}"}], ",", 
            "169.1232373987507`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009288963446633084`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.193310352004639`", ",", "1.0700518446392056`"}], 
             "}"}], ",", "75.9033472156233`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009262750743684305`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.207500799389074`", ",", "1.1265603554403336`"}], 
             "}"}], ",", "74.39603890645711`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012472944599581818`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.413118909568857`", ",", "1.5107447399974474`"}], 
             "}"}], ",", "126.54116493391194`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012438560679173198`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.349313759099647`", ",", "1.5968430133600238`"}], 
             "}"}], ",", "125.17430781294563`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08542359141431197`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6249144125819277`", ",", 
              RowBox[{"-", "4.291219948717063`"}]}], "}"}], ",", 
            RowBox[{"-", "139.80617899489658`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08507614425715486`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5146907617059844`", ",", 
              RowBox[{"-", "4.384345781536437`"}]}], "}"}], ",", 
            RowBox[{"-", "136.76700730667335`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013211472192729126`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.616473148431152`", ",", 
              RowBox[{"-", "3.839546036759751`"}]}], "}"}], ",", 
            RowBox[{"-", "150.08973384540337`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013141193910169713`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.580849709699812`", ",", 
              RowBox[{"-", "3.8600389169282856`"}]}], "}"}], ",", 
            RowBox[{"-", "146.18769685554935`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.053134281790179844`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.579937962894859`", ",", 
              RowBox[{"-", "4.3161032824231205`"}]}], "}"}], ",", 
            RowBox[{"-", "85.16864185176969`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.052918151944205384`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.583838827532015`", ",", 
              RowBox[{"-", "4.362254507597883`"}]}], "}"}], ",", 
            RowBox[{"-", "88.20804252094239`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11090223339995614`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.666259953006467`", ",", 
              RowBox[{"-", "4.416423503191367`"}]}], "}"}], ",", 
            RowBox[{"-", "31.853354129374374`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11037993616003676`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.813075213571055`", ",", 
              RowBox[{"-", "4.507642203723091`"}]}], "}"}], ",", 
            RowBox[{"-", "28.33085018556708`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028987793631739634`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.798279980013547`", ",", 
              RowBox[{"-", "4.407131294580484`"}]}], "}"}], ",", 
            "21.46193359302112`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02770677081002304`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.862689890837578`", ",", 
              RowBox[{"-", "4.381808975953809`"}]}], "}"}], ",", 
            "11.204364652735427`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020192140213091986`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.929734262581606`", ",", 
              RowBox[{"-", "3.1213235621942435`"}]}], "}"}], ",", 
            RowBox[{"-", "105.42102772714523`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019363456096660202`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9071799002491305`", ",", 
              RowBox[{"-", "3.203089436157028`"}]}], "}"}], ",", 
            RowBox[{"-", "115.43111338436502`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008170223990989801`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.134348357352752`", ",", "3.424274933828437`"}], "}"}],
             ",", "146.62699265793316`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008149113919701217`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.103650192613267`", ",", "3.4444959002671793`"}], 
             "}"}], ",", "145.74678265861985`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1665558948911391`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.628548247530289`", ",", 
              RowBox[{"-", "1.346088855764899`"}]}], "}"}], ",", 
            RowBox[{"-", "134.42691259561371`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16608988290248408`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.614717322515146`", ",", 
              RowBox[{"-", "1.3601992666660045`"}]}], "}"}], ",", 
            RowBox[{"-", "132.969484399494`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03576966796814638`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.451625246734025`", ",", "2.8573328742422452`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.52799528595966`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03567219812241412`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.42224035122515`", ",", "2.8539994316229933`"}], "}"}],
             ",", 
            RowBox[{"-", "172.23566710062843`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032181807683953075`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.234404632860996`", ",", "1.5925539569764573`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.20464484162096`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032035557953147414`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.134558778891135`", ",", "1.5841778176651693`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.79661062428022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0400293251945714`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.604009722506619`", ",", "2.7158150708953386`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.1075832256428`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03982590242782695`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.405039731031097`", ",", "2.7092409194679954`"}], 
             "}"}], ",", "178.13100201502812`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24821266546239837`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.215440038407017`", ",", 
              RowBox[{"-", "2.401181598702991`"}]}], "}"}], ",", 
            RowBox[{"-", "97.08676069611181`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24682851916630746`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.187344793038829`", ",", 
              RowBox[{"-", "2.6271694339600202`"}]}], "}"}], ",", 
            RowBox[{"-", "93.04145951890658`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06336222682338886`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.630380699138552`", ",", 
              RowBox[{"-", "0.7899309361355071`"}]}], "}"}], ",", 
            RowBox[{"-", "173.5593966218541`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06309905247534335`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.345367726580626`", ",", 
              RowBox[{"-", "0.8221047988375817`"}]}], "}"}], ",", 
            RowBox[{"-", "176.66999654252328`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0180272227463565`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.8301339973671515`", ",", 
              RowBox[{"-", "3.0309964858953027`"}]}], "}"}], ",", 
            RowBox[{"-", "113.58621516205113`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01798229336808007`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.78627592501987`", ",", 
              RowBox[{"-", "3.131449517541143`"}]}], "}"}], ",", 
            RowBox[{"-", "114.01216350834807`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16873709847124718`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.104736350691827`", ",", 
              RowBox[{"-", "3.6563018927554336`"}]}], "}"}], ",", 
            RowBox[{"-", "124.9501291333425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1673942821251315`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.968545787671244`", ",", 
              RowBox[{"-", "3.8511629426954896`"}]}], "}"}], ",", 
            RowBox[{"-", "119.86370989240123`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029736594546280398`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3206781979850604`", ",", "1.4260747983155784`"}], 
             "}"}], ",", "162.07021781874224`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029663102732973772`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1758216835623503`", ",", "1.4729453427395387`"}], 
             "}"}], ",", "161.85932572557977`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23140425462825842`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8297096805049433`", ",", 
              RowBox[{"-", "1.02433477027403`"}]}], "}"}], ",", 
            RowBox[{"-", "115.7981343398234`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23060867096257184`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.800016384379107`", ",", 
              RowBox[{"-", "1.0857634080385206`"}]}], "}"}], ",", 
            RowBox[{"-", "113.37413869402823`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023607582821963784`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.860881282240003`", ",", 
              RowBox[{"-", "1.4002161107014388`"}]}], "}"}], ",", 
            RowBox[{"-", "103.18424425645993`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023511201945448527`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.792643879086505`", ",", 
              RowBox[{"-", "1.6915080459494076`"}]}], "}"}], ",", 
            RowBox[{"-", "106.2362620442511`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008413420699703935`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.07555611396809`", ",", 
              RowBox[{"-", "1.8117704305492082`"}]}], "}"}], ",", 
            RowBox[{"-", "113.10405572154288`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008392659555218038`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.035231998209413`", ",", 
              RowBox[{"-", "1.9062904564970764`"}]}], "}"}], ",", 
            RowBox[{"-", "113.24355555374115`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00974214948091065`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6958045992808475`", ",", 
              RowBox[{"-", "0.8824309136322641`"}]}], "}"}], ",", 
            RowBox[{"-", "76.92906862299908`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00971748232989414`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7450952301165734`", ",", 
              RowBox[{"-", "1.0947326431897753`"}]}], "}"}], ",", 
            RowBox[{"-", "76.26557255388754`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021144641997327355`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.834619754427745`", ",", "3.8806501516394767`"}], 
             "}"}], ",", 
            RowBox[{"-", "28.899406345836134`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021063892986337974`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.134549649453645`", ",", "3.7150840089529598`"}], 
             "}"}], ",", 
            RowBox[{"-", "26.081079873094563`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010929856383479403`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.690322061937462`", ",", "0.9829898218117369`"}], 
             "}"}], ",", 
            RowBox[{"-", "42.97702618623881`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010874451028889988`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.7545209504678905`", ",", "0.9231714981215575`"}], 
             "}"}], ",", 
            RowBox[{"-", "46.73070364521987`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013554145426743982`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.085192016271241`", ",", 
              RowBox[{"-", "0.15233612156201284`"}]}], "}"}], ",", 
            "2.688415249362286`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013492646147050695`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.118623229274593`", ",", 
              RowBox[{"-", "0.15076632007160554`"}]}], "}"}], ",", 
            RowBox[{"-", "0.7145037985848365`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06445856982777903`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.023749465279174`", ",", 
              RowBox[{"-", "0.6564234254441896`"}]}], "}"}], ",", 
            RowBox[{"-", "74.569502602867`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06416011546702369`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.086800653178619`", ",", 
              RowBox[{"-", "0.8848543317206131`"}]}], "}"}], ",", 
            RowBox[{"-", "78.03769373191008`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009944227644351244`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.110066133937232`", ",", 
              RowBox[{"-", "1.3196122735009896`"}]}], "}"}], ",", 
            RowBox[{"-", "114.14835654998495`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009909143792764185`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.060689219099167`", ",", 
              RowBox[{"-", "1.4297462813242712`"}]}], "}"}], ",", 
            RowBox[{"-", "116.67307054806113`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04538539706399608`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.311374477317961`", ",", 
              RowBox[{"-", "0.8702033506379357`"}]}], "}"}], ",", 
            RowBox[{"-", "102.84370784460411`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.045248087198569265`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.24895411678124`", ",", 
              RowBox[{"-", "1.1439807200337655`"}]}], "}"}], ",", 
            RowBox[{"-", "100.97231153788428`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032700920121332896`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.568609747241561`", ",", "0.17993281888803214`"}], 
             "}"}], ",", 
            RowBox[{"-", "149.0108454349342`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03242944352826545`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.527798254498685`", ",", "0.1554213130849209`"}], 
             "}"}], ",", 
            RowBox[{"-", "143.8032362085446`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010560481170217254`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.352085693409248`", ",", "1.914169228756334`"}], "}"}],
             ",", 
            RowBox[{"-", "159.07193292502163`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010165196285888195`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3220548648436976`", ",", "1.9026847111612062`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.77845758014595`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01677218939570061`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9377092946462433`", ",", "2.335707755262018`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.6279697133987`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016726350294304044`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8772032825485674`", ",", "2.323538337846488`"}], 
             "}"}], ",", 
            RowBox[{"-", "169.93978422644588`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.018062244674257`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7009504064931456`", ",", 
              RowBox[{"-", "0.886442425745927`"}]}], "}"}], ",", 
            RowBox[{"-", "137.69783641350745`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01801356295806492`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6416685364883628`", ",", 
              RowBox[{"-", "0.9403888692305328`"}]}], "}"}], ",", 
            RowBox[{"-", "136.47980073474366`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012012579310351976`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.766147741904659`", ",", 
              RowBox[{"-", "1.4105064288629432`"}]}], "}"}], ",", 
            RowBox[{"-", "63.86961928822468`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009876541128831037`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.850274393352393`", ",", 
              RowBox[{"-", "1.582000064127832`"}]}], "}"}], ",", 
            RowBox[{"-", "48.22838847202045`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010573884470912466`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8156411223846534`", ",", "1.5132813511973178`"}], 
             "}"}], ",", 
            RowBox[{"-", "167.19874522198978`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010543648094998134`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6527186743894404`", ",", "1.4762625269830916`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.7807093452752`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01043475345470932`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1875130680893315`", ",", "1.639042991257376`"}], 
             "}"}], ",", 
            RowBox[{"-", "138.7972589771189`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010408644686908277`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.138377464275786`", ",", "1.5960238694596374`"}], 
             "}"}], ",", 
            RowBox[{"-", "139.29268558090277`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009680126447098179`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.977761929985089`", ",", "0.8882111978820659`"}], 
             "}"}], ",", 
            RowBox[{"-", "60.68341364955079`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008708366501372047`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.06130159699868`", ",", "0.7394461874404072`"}], "}"}],
             ",", 
            RowBox[{"-", "47.43974103561976`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012516145844091615`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.14183109987971`", ",", 
              RowBox[{"-", "0.39881202640755253`"}]}], "}"}], ",", 
            RowBox[{"-", "122.44771805605546`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012258600049010884`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.1216425990063`", ",", 
              RowBox[{"-", "0.4305655282711646`"}]}], "}"}], ",", 
            RowBox[{"-", "114.61212403900429`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009761652713889806`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5939123039010066`", ",", "1.2797169994967676`"}], 
             "}"}], ",", 
            RowBox[{"-", "159.77437978711637`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009728819207225788`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.412278309774798`", ",", "1.2127964730526846`"}], 
             "}"}], ",", 
            RowBox[{"-", "162.11059780907308`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011890343279437995`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6744488706177325`", ",", 
              RowBox[{"-", "1.8935461606096162`"}]}], "}"}], ",", 
            RowBox[{"-", "139.982025664881`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01184455417907567`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6340094531314135`", ",", 
              RowBox[{"-", "1.927500485180183`"}]}], "}"}], ",", 
            RowBox[{"-", "142.83021875742236`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01682706197670141`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6672522571574695`", ",", 
              RowBox[{"-", "2.159269702104077`"}]}], "}"}], ",", 
            RowBox[{"-", "173.9118453933052`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016785584278621882`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4330706213555873`", ",", 
              RowBox[{"-", "2.184247532440832`"}]}], "}"}], ",", 
            RowBox[{"-", "173.86928323225854`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01106601722517766`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.626555883353152`", ",", 
              RowBox[{"-", "2.233817827673968`"}]}], "}"}], ",", 
            "168.69856913910678`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011028382037576908`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.397673717117399`", ",", 
              RowBox[{"-", "2.1880767136477473`"}]}], "}"}], ",", 
            "171.0794074251379`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012404271544239908`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.162346604277734`", ",", "1.862138328747747`"}], "}"}],
             ",", "123.80745069197906`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01237034459444045`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.162179615633744`", ",", "1.862387703249933`"}], "}"}],
             ",", "125.12416303689798`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01307128947216959`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.362099643024295`", ",", 
              RowBox[{"-", "4.006547355628791`"}]}], "}"}], ",", 
            RowBox[{"-", "142.28565986569532`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013004965192346592`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.279787419090234`", ",", 
              RowBox[{"-", "4.070198385837125`"}]}], "}"}], ",", 
            RowBox[{"-", "138.5290064789951`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026482358694543965`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.051406858091678`", ",", 
              RowBox[{"-", "4.344427070346459`"}]}], "}"}], ",", 
            "0.9467957124498002`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02639985048466714`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.11099580886446`", ",", 
              RowBox[{"-", "4.343442291022954`"}]}], "}"}], ",", 
            "2.9552706641600928`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018568781122279714`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8268878473143895`", ",", 
              RowBox[{"-", "3.3719473963555866`"}]}], "}"}], ",", 
            RowBox[{"-", "125.44119904158475`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0181734531402836`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.665933962421392`", ",", 
              RowBox[{"-", "3.5980869677647735`"}]}], "}"}], ",", 
            RowBox[{"-", "117.50321543376491`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008128058392218326`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.862323337613243`", ",", "3.6088293415498454`"}], 
             "}"}], ",", "144.86657265930654`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008073324742445615`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.829911836817922`", ",", "3.63163678705379`"}], "}"}], 
            ",", "140.26275538881242`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16562517478346214`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.414914889031484`", ",", 
              RowBox[{"-", "1.574690063371122`"}]}], "}"}], ",", 
            RowBox[{"-", "131.51205620337402`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16519836703602336`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.37831481021951`", ",", 
              RowBox[{"-", "1.6160413907100193`"}]}], "}"}], ",", 
            RowBox[{"-", "132.36693852184186`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035574993875200585`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.107906924151698`", ",", "2.811140438077034`"}], "}"}],
             ",", 
            RowBox[{"-", "170.9433389152969`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.035486848129557`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9126355914282813`", ",", "2.7800145138044243`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.23655391163092`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031889972851997475`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8776235649819144`", ",", "1.547137372789917`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.38857640693905`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0318049566061322`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.603518065205677`", ",", "1.4908146381672884`"}], 
             "}"}], ",", 
            RowBox[{"-", "169.52818464420787`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03962351342375098`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.128791118712853`", ",", "2.7182553933505633`"}], 
             "}"}], ",", "174.36958725569906`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0395238984121437`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9106446064727507`", ",", "2.739761757931408`"}], 
             "}"}], ",", "173.8009426407295`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24545209149716662`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.170792281269932`", ",", 
              RowBox[{"-", "2.938696871178345`"}]}], "}"}], ",", 
            RowBox[{"-", "88.99615834170126`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2426787829787857`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.175387372593446`", ",", 
              RowBox[{"-", "3.200941815523302`"}]}], "}"}], ",", 
            RowBox[{"-", "82.90873642721452`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06283697121920676`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.081982035900316`", ",", 
              RowBox[{"-", "0.837429909266994`"}]}], "}"}], ",", 
            RowBox[{"-", "179.78059646319244`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0616603080326803`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.8549634431669375`", ",", 
              RowBox[{"-", "0.8382992390160692`"}]}], "}"}], ",", 
            "172.66514903429248`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017937475967619666`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.656320172600433`", ",", 
              RowBox[{"-", "3.4231682308452736`"}]}], "}"}], ",", 
            RowBox[{"-", "114.43811185464584`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01778744057656669`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.638641215965254`", ",", 
              RowBox[{"-", "3.462072466565094`"}]}], "}"}], ",", 
            RowBox[{"-", "119.66720399978257`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1660621519633566`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.848439921609096`", ",", 
              RowBox[{"-", "4.060339923633495`"}]}], "}"}], ",", 
            RowBox[{"-", "114.7772906514599`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1655970462999427`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.810830744740259`", ",", 
              RowBox[{"-", "4.141818437470286`"}]}], "}"}], ",", 
            RowBox[{"-", "116.24076906343583`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22981582256798078`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.690471506059175`", ",", 
              RowBox[{"-", "1.3392204971550752`"}]}], "}"}], ",", 
            RowBox[{"-", "110.95014304823353`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2166363620687963`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6285767423124753`", ",", 
              RowBox[{"-", "1.5008821935487953`"}]}], "}"}], ",", 
            RowBox[{"-", "122.10580370393512`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012423645790219824`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.543596105985032`", ",", 
              RowBox[{"-", "1.6363224572962705`"}]}], "}"}], ",", 
            "172.8456907357269`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023415214555781466`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7253197317359628`", ",", 
              RowBox[{"-", "1.9226930520229284`"}]}], "}"}], ",", 
            RowBox[{"-", "109.28827983204253`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023357075642886575`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5646833574010808`", ",", 
              RowBox[{"-", "2.3816995048095375`"}]}], "}"}], ",", 
            RowBox[{"-", "109.63491810460665`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008371949641395121`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9291983209491628`", ",", 
              RowBox[{"-", "2.1531670824734057`"}]}], "}"}], ",", 
            RowBox[{"-", "113.38305538593421`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008273919058432035`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.9174504507025527`", ",", 
              RowBox[{"-", "2.180336851323488`"}]}], "}"}], ",", 
            RowBox[{"-", "119.5725737388855`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009692877636176246`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.81530561668199`", ",", 
              RowBox[{"-", "1.3819969648385397`"}]}], "}"}], ",", 
            RowBox[{"-", "75.60207648477711`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02098345234674483`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.396143214128973`", ",", "3.5870377413582615`"}], 
             "}"}], ",", 
            RowBox[{"-", "23.262753400353123`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020921442860254384`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.403854419465872`", ",", "3.5837227126396174`"}], 
             "}"}], ",", 
            RowBox[{"-", "25.018379710171846`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010819326533738205`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.951636345348979`", ",", "0.7137730150913497`"}], 
             "}"}], ",", 
            RowBox[{"-", "50.484381104200914`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010778340393249044`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.984278723080915`", ",", "0.6741966303886024`"}], 
             "}"}], ",", 
            RowBox[{"-", "53.27373391635643`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06386304300173534`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.140126437614487`", ",", 
              RowBox[{"-", "1.1365465124910128`"}]}], "}"}], ",", 
            RowBox[{"-", "81.50588486095327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06335220939627735`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.14040047723197`", ",", 
              RowBox[{"-", "1.138381443590131`"}]}], "}"}], ",", 
            RowBox[{"-", "76.40477630241244`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009874183719180427`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.941744632947714`", ",", 
              RowBox[{"-", "1.6665184367310864`"}]}], "}"}], ",", 
            RowBox[{"-", "119.19778454613703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009348102033914648`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.700922205001355`", ",", 
              RowBox[{"-", "2.0974585618943045`"}]}], "}"}], ",", 
            RowBox[{"-", "108.30012927132721`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04511119275308724`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1971633524093805`", ",", 
              RowBox[{"-", "1.411110251959242`"}]}], "}"}], ",", 
            RowBox[{"-", "99.10091523116425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0448112476161388`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.171495430089541`", ",", 
              RowBox[{"-", "1.571344055739821`"}]}], "}"}], ",", 
            RowBox[{"-", "94.5341166987728`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03216022068036205`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3141454695633144`", ",", 
              RowBox[{"-", "0.0009303562125356213`"}]}], "}"}], ",", 
            RowBox[{"-", "138.59562698215495`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03162983664470131`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9827536820664209`", ",", 
              RowBox[{"-", "0.29313647247103203`"}]}], "}"}], ",", 
            RowBox[{"-", "131.41590305104853`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016680636473105984`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5359324408170836`", ",", "2.2629931975671616`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.2515987394931`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016638817946494158`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.373788782868912`", ",", "2.2380415331809025`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.72479133641778`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01796501244978937`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3882353982456106`", ",", 
              RowBox[{"-", "1.1810577998572418`"}]}], "}"}], ",", 
            RowBox[{"-", "135.26176505598045`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017916861488427804`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{
                "0.`", ",", "0.9999999999999999`", ",", 
                 "167.35910683550452`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3688702250328464`", ",", 
              RowBox[{"-", "1.200246830713806`"}]}], "}"}], ",", 
            RowBox[{"-", "134.08306373894055`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00812032638031625`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.942643768053254`", ",", 
              RowBox[{"-", "1.6854126608445184`"}]}], "}"}], ",", 
            RowBox[{"-", "32.58715765581652`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008074222850921381`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.06431006465274`", ",", 
              RowBox[{"-", "1.7631830852736665`"}]}], "}"}], ",", 
            RowBox[{"-", "28.48774322353844`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010513498181010916`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3269097514349193`", ",", "1.4116366195782286`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.3626734685608`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009425621503675973`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0829310118783844`", ",", "1.3702071945206948`"}], 
             "}"}], ",", "176.27382627041365`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010382601245783043`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.883148682769548`", ",", "1.3764357895408095`"}], 
             "}"}], ",", 
            RowBox[{"-", "139.7881121846881`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010354830967041598`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.852140342572451`", ",", "1.35022068032724`"}], "}"}], 
            ",", 
            RowBox[{"-", "140.95179783723307`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01200635379560934`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.048745360448051`", ",", 
              RowBox[{"-", "0.5896979328317056`"}]}], "}"}], ",", 
            RowBox[{"-", "106.77653002195306`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01197293597997323`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.9629454351588285`", ",", 
              RowBox[{"-", "0.8743022802455626`"}]}], "}"}], ",", 
            RowBox[{"-", "108.20266389354039`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009696096136692976`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1178173572235908`", ",", "1.1177483207118895`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.44681583102982`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009659018158444893`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1143800737692033`", ",", "1.1167916407522147`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.62368699860946`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01179894141018357`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4018199732914707`", ",", 
              RowBox[{"-", "2.10354895449524`"}]}], "}"}], ",", 
            RowBox[{"-", "145.67841184996374`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011766564565803052`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.391765974104575`", ",", 
              RowBox[{"-", "2.1104128801252755`"}]}], "}"}], ",", 
            RowBox[{"-", "144.34066184178837`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016744208820579295`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.134775657365511`", ",", 
              RowBox[{"-", "2.2162878220725832`"}]}], "}"}], ",", 
            RowBox[{"-", "173.8267210712033`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016695259721568153`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.86782894591727`", ",", 
              RowBox[{"-", "2.2451615561793226`"}]}], "}"}], ",", 
            RowBox[{"-", "175.52684879678011`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01099087484610312`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.099114995086564`", ",", 
              RowBox[{"-", "2.141213723451201`"}]}], "}"}], ",", 
            "173.4602457111689`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010888310461735268`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.059116012474011`", ",", 
              RowBox[{"-", "2.136628299514328`"}]}], "}"}], ",", 
            "167.91856453310317`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012336510438314416`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.975437887865956`", ",", "2.127856256636735`"}], "}"}],
             ",", "126.44087538181665`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011830980142825758`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4230846793690546`", ",", "2.8759319963892263`"}], 
             "}"}], ",", "116.43577685165907`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01293897744474587`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.092301143738348`", ",", 
              RowBox[{"-", "4.23590309475546`"}]}], "}"}], ",", 
            RowBox[{"-", "134.77235309229502`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012858589134751576`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.988579227331983`", ",", 
              RowBox[{"-", "4.340452516713437`"}]}], "}"}], ",", 
            RowBox[{"-", "130.4046893146536`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017786541661897512`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.56398960641994`", ",", 
              RowBox[{"-", "3.7938934235005783`"}]}], "}"}], ",", 
            RowBox[{"-", "109.56523182594526`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017742468331167927`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.543285241504151`", ",", 
              RowBox[{"-", "3.852149876543363`"}]}], "}"}], ",", 
            RowBox[{"-", "109.27024440551004`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16477265915068884`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.136185292466732`", ",", 
              RowBox[{"-", "1.8815145244865437`"}]}], "}"}], ",", 
            RowBox[{"-", "133.22182084030968`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.164358864692161`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.080829143176823`", ",", 
              RowBox[{"-", "1.940417865237979`"}]}], "}"}], ",", 
            RowBox[{"-", "133.7745814184609`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035398920786550436`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.652329238880699`", ",", "2.7398869964278223`"}], 
             "}"}], ",", 
            RowBox[{"-", "171.52976890796617`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035258889720509196`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4438157125500233`", ",", "2.7088351887185578`"}], 
             "}"}], ",", 
            RowBox[{"-", "174.47269776577926`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03172016700712219`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.33269357193641`", ",", "1.4407580715476331`"}], "}"}],
             ",", 
            RowBox[{"-", "170.66779288147734`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03147833208649081`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1302201679194464`", ",", "1.4074849028546426`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.6310032308577`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03942453383644382`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6496634334844873`", ",", "2.7681090417856065`"}], 
             "}"}], ",", "173.232298025758`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03931069464505399`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.451260765305006`", ",", "2.791653704045864`"}], "}"}],
             ",", "174.86730220412667`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2399368094557239`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.202925738185447`", ",", 
              RowBox[{"-", "3.42230821353291`"}]}], "}"}], ",", 
            RowBox[{"-", "76.82131451272777`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23934541463425085`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.248112007121396`", ",", 
              RowBox[{"-", "3.615283735849963`"}]}], "}"}], ",", 
            RowBox[{"-", "76.85048670504725`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.060505678630209135`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.658065848402106`", ",", 
              RowBox[{"-", "0.8129543347630941`"}]}], "}"}], ",", 
            "165.11089453177738`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06029923664829346`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.424263155239173`", ",", 
              RowBox[{"-", "0.7507918497619795`"}]}], "}"}], ",", 
            "167.5046048570846`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0176386601345717`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.513356881400975`", ",", 
              RowBox[{"-", "3.6820117133582566`"}]}], "}"}], ",", 
            RowBox[{"-", "124.8962961449194`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017426836973892735`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.4472361063926655`", ",", 
              RowBox[{"-", "3.7768066801453966`"}]}], "}"}], ",", 
            RowBox[{"-", "131.15816023743142`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1651332433010769`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.672843912771113`", ",", 
              RowBox[{"-", "4.421741734640321`"}]}], "}"}], ",", 
            RowBox[{"-", "117.70424747541178`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1643827321877667`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.659903152929509`", ",", 
              RowBox[{"-", "4.446385810830566`"}]}], "}"}], ",", 
            RowBox[{"-", "121.1125644498652`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01317946049918434`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6285767423124753`", ",", 
              RowBox[{"-", "1.5008821935487953`"}]}], "}"}], ",", 
            RowBox[{"-", "68.21295879929868`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013146963147281995`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6594651458304117`", ",", 
              RowBox[{"-", "1.5781593961122107`"}]}], "}"}], ",", 
            RowBox[{"-", "68.297756415899`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.20421271627857635`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.543596105985032`", ",", 
              RowBox[{"-", "1.6363224572962705`"}]}], "}"}], ",", 
            RowBox[{"-", "133.26146435963668`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16286185078610396`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3965708830209524`", ",", 
              RowBox[{"-", "1.7925522233475382`"}]}], "}"}], ",", 
            RowBox[{"-", "149.49064758495007`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.032977762641009926`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.279009699303809`", ",", 
              RowBox[{"-", "1.8618269030697097`"}]}], "}"}], ",", 
            "155.88485542772798`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011711175486311043`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3849479729325935`", ",", 
              RowBox[{"-", "1.616409057948625`"}]}], "}"}], ",", 
            "161.69003008002534`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011440152111491957`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.382855125444696`", ",", 
              RowBox[{"-", "1.6157165107911804`"}]}], "}"}], ",", 
            "169.880681147676`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023299081086268443`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.461323438055423`", ",", 
              RowBox[{"-", "2.6714090529866406`"}]}], "}"}], ",", 
            RowBox[{"-", "109.98155637717394`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.023025736618500225`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4057873386829636`", ",", 
              RowBox[{"-", "2.8241461926857054`"}]}], "}"}], ",", 
            RowBox[{"-", "103.78652539232493`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008177036355665052`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.822596609712692`", ",", 
              RowBox[{"-", "2.3474960651091377`"}]}], "}"}], ",", 
            RowBox[{"-", "125.76209209183672`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02085961662179916`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.6717827922214505`", ",", "3.458681008403295`"}], 
             "}"}], ",", 
            RowBox[{"-", "26.77400601999036`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017031190648950163`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.772022016348352`", ",", "3.40810360023285`"}], "}"}], 
            ",", 
            RowBox[{"-", "42.556844465222596`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010737509517850274`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.165363385013364`", ",", "0.43148520809964575`"}], 
             "}"}], ",", 
            RowBox[{"-", "56.063086728512204`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010697809466999778`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.203554124833435`", ",", "0.37473041028837395`"}], 
             "}"}], ",", 
            RowBox[{"-", "58.76396375108864`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0628454618938329`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.194207568944458`", ",", 
              RowBox[{"-", "1.3608744551039436`"}]}], "}"}], ",", 
            RowBox[{"-", "71.30366774387154`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06230220432101657`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.280785062159566`", ",", 
              RowBox[{"-", "1.6167105668714303`"}]}], "}"}], ",", 
            RowBox[{"-", "76.62691055040588`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008850049191077075`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.649765790317664`", ",", 
              RowBox[{"-", "2.252140099420774`"}]}], "}"}], ",", 
            RowBox[{"-", "97.4024739965174`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0088175565671167`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.642168701414975`", ",", 
              RowBox[{"-", "2.310614675154861`"}]}], "}"}], ",", 
            RowBox[{"-", "100.07744456431794`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04451329681983375`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.149893895290433`", ",", 
              RowBox[{"-", "1.8437437694677532`"}]}], "}"}], ",", 
            RowBox[{"-", "89.96731816638145`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0443617892119538`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.150028337380061`", ",", 
              RowBox[{"-", "2.0794393420918182`"}]}], "}"}], ",", 
            RowBox[{"-", "87.58332957538543`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01659710425935718`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0947908614681428`", ",", "2.1924778196150227`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.1979839333425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017868839584314972`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1535509058181757`", ",", 
              RowBox[{"-", "1.4225705938373867`"}]}], "}"}], ",", 
            RowBox[{"-", "132.90436242190128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017792015423060425`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1410113125605466`", ",", 
              RowBox[{"-", "1.4360627430792223`"}]}], "}"}], ",", 
            RowBox[{"-", "129.67801911372118`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010327134965291359`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.651262681609272`", ",", "1.1872731524470477`"}], 
             "}"}], ",", 
            RowBox[{"-", "142.11548348977806`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010296816236058009`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.613254550733855`", ",", "1.1577011222800127`"}], 
             "}"}], ",", 
            RowBox[{"-", "140.39332569565605`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01193961117762166`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.8750291013448415`", ",", 
              RowBox[{"-", "1.1416594337420962`"}]}], "}"}], ",", 
            RowBox[{"-", "109.62879776512695`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011904517772118586`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.862194451580757`", ",", 
              RowBox[{"-", "1.177646071358585`"}]}], "}"}], ",", 
            RowBox[{"-", "107.90068007694306`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011734276564990412`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.122311827895533`", ",", 
              RowBox[{"-", "2.3037455073972075`"}]}], "}"}], ",", 
            RowBox[{"-", "143.00291183361327`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011690882294326037`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0846919533166233`", ",", 
              RowBox[{"-", "2.3320911188318774`"}]}], "}"}], ",", 
            RowBox[{"-", "140.30128444776133`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016646453717660506`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5579443007284106`", ",", 
              RowBox[{"-", "2.269403900700476`"}]}], "}"}], ",", 
            RowBox[{"-", "177.22697652235652`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01659944827306273`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4442099759061167`", ",", 
              RowBox[{"-", "2.2749127608980144`"}]}], "}"}], ",", 
            RowBox[{"-", "178.73801851045937`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010786703185249007`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.862287847875723`", ",", 
              RowBox[{"-", "2.0944986984044083`"}]}], "}"}], ",", 
            "162.37688335503742`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010760097970568731`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6469436431969653`", ",", 
              RowBox[{"-", "2.026091854644832`"}]}], "}"}], ",", 
            "162.48625391239327`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011346165663283178`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.339779505009526`", ",", "3.0434863985286267`"}], 
             "}"}], ",", "106.43067832150163`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011317811409310014`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.315343322038069`", ",", "3.126349591829431`"}], "}"}],
             ",", "106.9053526400342`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017698504209891105`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.434314923225942`", ",", 
              RowBox[{"-", "4.16383908087726`"}]}], "}"}], ",", 
            RowBox[{"-", "108.97525698507609`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017234324784482932`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.400555111761498`", ",", 
              RowBox[{"-", "4.262022410720735`"}]}], "}"}], ",", 
            RowBox[{"-", "117.55012778563545`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16394610939786583`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.895683725659957`", ",", 
              RowBox[{"-", "2.133657255674023`"}]}], "}"}], ",", 
            RowBox[{"-", "134.32734199661408`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16352832101342266`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.894363137934695`", ",", 
              RowBox[{"-", "2.1350092208711593`"}]}], "}"}], ",", 
            RowBox[{"-", "135.06630534645882`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03511941258941911`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1602250446055833`", ",", "2.681392119152333`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.4156266235926`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033099505557120684`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.088276325440507`", ",", "2.678144610161838`"}], "}"}],
             ",", 
            RowBox[{"-", "166.2496710463285`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03123834091809515`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.861739231903491`", ",", "1.3869725520795433`"}], 
             "}"}], ",", "179.40578641976188`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02894387027297956`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8189310068960913`", ",", "1.3874165313898386`"}], 
             "}"}], ",", 
            RowBox[{"-", "168.5441300187184`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039197184166783514`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1468993997360766`", ",", "2.818992318919108`"}], 
             "}"}], ",", "176.50230638249553`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.038985020101843765`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.859142571987567`", ",", "2.8365806538130016`"}], 
             "}"}], ",", 
            RowBox[{"-", "179.54267546271095`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23875547747921777`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.319354478030785`", ",", 
              RowBox[{"-", "3.9202359941616067`"}]}], "}"}], ",", 
            RowBox[{"-", "76.87965889736674`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2375123194526273`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.361110025060112`", ",", 
              RowBox[{"-", "4.099381638041829`"}]}], "}"}], ",", 
            RowBox[{"-", "80.71607075150101`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06009349903484142`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.144075751525485`", ",", 
              RowBox[{"-", "0.6886994227943991`"}]}], "}"}], ",", 
            "169.89831518239194`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.059642794307125366`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.915434832123526`", ",", 
              RowBox[{"-", "0.647965335292557`"}]}], "}"}], ",", 
            "174.8143208613902`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017217557603448272`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.301047359768452`", ",", 
              RowBox[{"-", "3.944042993187486`"}]}], "}"}], ",", 
            RowBox[{"-", "137.42002432994332`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015802974506275023`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1473790497722725`", ",", 
              RowBox[{"-", "4.085249162367698`"}]}], "}"}], ",", 
            RowBox[{"-", "149.8895395832615`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013114545925964711`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7823370711004873`", ",", 
              RowBox[{"-", "1.8868877195185065`"}]}], "}"}], ",", 
            RowBox[{"-", "68.38255403250794`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013078439761677923`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9520001666773728`", ",", 
              RowBox[{"-", "2.3150268609912428`"}]}], "}"}], ",", 
            RowBox[{"-", "69.74132129700955`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.041350865492472015`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3965708830209524`", ",", 
              RowBox[{"-", "1.7925522233475382`"}]}], "}"}], ",", 
            RowBox[{"-", "111.09533382294144`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04055729127874689`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3818224814643028`", ",", 
              RowBox[{"-", "1.8307828693178243`"}]}], "}"}], ",", 
            RowBox[{"-", "103.46808515232895`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12988408814509395`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.279009699303809`", ",", 
              RowBox[{"-", "1.8618269030697097`"}]}], "}"}], ",", 
            RowBox[{"-", "165.71983081026315`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.12955305318067176`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.183786388996578`", ",", 
              RowBox[{"-", "1.8860639242246482`"}]}], "}"}], ",", 
            RowBox[{"-", "164.9792585302121`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026300122521132445`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.154464827177917`", ",", 
              RowBox[{"-", "1.8060757775677903`"}]}], "}"}], ",", 
            "139.6556722024149`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025668947877907827`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9635584338880692`", ",", 
              RowBox[{"-", "1.6439212922441218`"}]}], "}"}], ",", 
            "131.35408411266502`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011175400837179281`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1992812968316877`", ",", 
              RowBox[{"-", "1.582953166762202`"}]}], "}"}], ",", 
            "178.0713322153267`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01112239553128573`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1201065284469833`", ",", 
              RowBox[{"-", "1.5802870100530664`"}]}], "}"}], ",", 
            "174.52628133584943`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022755599023903672`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.351553571969628`", ",", 
              RowBox[{"-", "3.045170916975937`"}]}], "}"}], ",", 
            RowBox[{"-", "97.5914944074759`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022691519711564332`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.337120111113439`", ",", 
              RowBox[{"-", "3.153467306216698`"}]}], "}"}], ",", 
            RowBox[{"-", "99.08662760799609`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013905406804924856`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.877126940960202`", ",", "3.311600672087688`"}], "}"}],
             ",", 
            RowBox[{"-", "58.33968291045474`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013865737655638305`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.954147366881353`", ",", "3.186700566472998`"}], "}"}],
             ",", 
            RowBox[{"-", "59.9085520865083`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06176364285165033`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.333292854791026`", ",", 
              RowBox[{"-", "1.8375753072924508`"}]}], "}"}], ",", 
            RowBox[{"-", "81.95015335694022`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.060065185511272545`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.37502059150578`", ",", 
              RowBox[{"-", "2.132620862057291`"}]}], "}"}], ",", 
            RowBox[{"-", "90.67223365155886`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008785183238607578`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.586852865388811`", ",", 
              RowBox[{"-", "2.621865656387353`"}]}], "}"}], ",", 
            RowBox[{"-", "102.75241513211876`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008763250208185996`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.5283406794940015`", ",", 
              RowBox[{"-", "2.8804016821273737`"}]}], "}"}], ",", 
            RowBox[{"-", "103.21009831957046`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04421079728268869`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1633437138595895`", ",", 
              RowBox[{"-", "2.3949405336234557`"}]}], "}"}], ",", 
            RowBox[{"-", "85.19934098438942`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04408637587737085`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.177189268849019`", ",", 
              RowBox[{"-", "2.5598001098368637`"}]}], "}"}], ",", 
            RowBox[{"-", "83.7077208799835`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010266586517508204`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.34950135708816`", ",", "0.9394537482734076`"}], "}"}],
             ",", 
            RowBox[{"-", "138.67116790153403`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010220902427665947`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.308246115973363`", ",", "0.9031733340704978`"}], 
             "}"}], ",", 
            RowBox[{"-", "135.33155903012968`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011869527514623546`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.778138158256813`", ",", 
              RowBox[{"-", "1.4378788033585193`"}]}], "}"}], ",", 
            RowBox[{"-", "106.17256238876003`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011838149682084834`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.730084543669796`", ",", 
              RowBox[{"-", "1.6035765617551552`"}]}], "}"}], ",", 
            RowBox[{"-", "107.24814675477587`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010733558377184975`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3899699046641167`", ",", 
              RowBox[{"-", "1.9450005602570204`"}]}], "}"}], ",", 
            "162.59562446974914`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01070710151021494`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.876920695888101`", ",", 
              RowBox[{"-", "1.784177655015215`"}]}], "}"}], ",", 
            "162.55853056603502`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011289528013082296`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2238502271956717`", ",", "3.427387713933632`"}], 
             "}"}], ",", "107.38002695856831`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01123257182359135`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.164101554416602`", ",", "3.6182791304508584`"}], 
             "}"}], ",", "103.64115734723856`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1631115972906224`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7055343143627244`", ",", 
              RowBox[{"-", "2.3234015063995175`"}]}], "}"}], ",", 
            RowBox[{"-", "135.80526869630256`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1627092163903207`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6126373039872774`", ",", 
              RowBox[{"-", "2.4137232822676298`"}]}], "}"}], ",", 
            RowBox[{"-", "135.68383961901284`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03119577428399096`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.892263836527015`", ",", "2.630179466514019`"}], "}"}],
             ",", 
            RowBox[{"-", "155.08371546906463`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031059387794138946`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.656542139953466`", ",", "2.52067965515237`"}], "}"}], 
            ",", 
            RowBox[{"-", "158.3654603124171`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02681792956212341`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6407767730931617`", ",", "1.3513135172147952`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.49404645719878`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02674474298628302`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4100475676243165`", ",", "1.2509610945770788`"}], 
             "}"}], ",", 
            RowBox[{"-", "157.7962310661119`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.038774004425274476`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.597929550289893`", ",", "2.8344956544945057`"}], 
             "}"}], ",", 
            RowBox[{"-", "175.5876573079176`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02733474697376804`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4952292852444606`", ",", "2.826571044663803`"}], 
             "}"}], ",", "166.37915769543096`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008064403268104786`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.358105900150826`", ",", "2.859797487829117`"}], "}"}],
             ",", "113.60011120122442`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05919546989100458`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6767553638289288`", ",", 
              RowBox[{"-", "0.6263039518208819`"}]}], "}"}], ",", 
            "179.73032654038838`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05889722832488268`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.660707579059717`", ",", 
              RowBox[{"-", "0.6262284193186336`"}]}], "}"}], ",", 
            "175.99564479156146`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01450461261683035`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.017777290759835`", ",", 
              RowBox[{"-", "4.160408289752661`"}]}], "}"}], ",", 
            RowBox[{"-", "162.3590548365797`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01446619739916272`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.871824473011491`", ",", 
              RowBox[{"-", "4.206822074429016`"}]}], "}"}], ",", 
            RowBox[{"-", "161.2690356676432`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01304243300267034`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.068991289281188`", ",", 
              RowBox[{"-", "2.631997311602204`"}]}], "}"}], ",", 
            RowBox[{"-", "71.10008856151065`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012912891969377635`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.084678752134776`", ",", 
              RowBox[{"-", "2.677816872230564`"}]}], "}"}], ",", 
            RowBox[{"-", "65.38056039857949`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03977894673494984`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3331305227023598`", ",", 
              RowBox[{"-", "2.0340983190730886`"}]}], "}"}], ",", 
            RowBox[{"-", "95.84083648171661`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039673570314835725`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.328960687100035`", ",", 
              RowBox[{"-", "2.0748605967363356`"}]}], "}"}], ",", 
            RowBox[{"-", "96.93250633761616`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022627620845288635`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.289440215654356`", ",", 
              RowBox[{"-", "3.451588365206402`"}]}], "}"}], ",", 
            RowBox[{"-", "100.58176080851631`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022560469168505248`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.265160825292077`", ",", 
              RowBox[{"-", "3.581552939267163`"}]}], "}"}], ",", 
            RowBox[{"-", "98.80484189090893`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013826181673943847`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.103699191777398`", ",", "2.928621355054173`"}], "}"}],
             ",", 
            RowBox[{"-", "61.47742126256186`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013790079556213985`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.12458174917919`", ",", "2.890196586484368`"}], "}"}], 
            ",", 
            RowBox[{"-", "60.50264155119739`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05841343456973877`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.372609199076223`", ",", 
              RowBox[{"-", "2.338139090646819`"}]}], "}"}], ",", 
            RowBox[{"-", "99.39431394617743`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05826750875932775`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.328067160359495`", ",", 
              RowBox[{"-", "2.6073615446193075`"}]}], "}"}], ",", 
            RowBox[{"-", "99.86301893224791`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008741371935623231`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.455915662084558`", ",", 
              RowBox[{"-", "3.1889427043325047`"}]}], "}"}], ",", 
            RowBox[{"-", "103.66778150702376`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008695149140509732`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.424566515033717`", ",", 
              RowBox[{"-", "3.317857071873617`"}]}], "}"}], ",", 
            RowBox[{"-", "99.78400931937425`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04396230462828299`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.2141051080821414`", ",", 
              RowBox[{"-", "2.8945932194192343`"}]}], "}"}], ",", 
            RowBox[{"-", "82.21610077557686`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04385305370694658`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.240643944512358`", ",", 
              RowBox[{"-", "3.0887371814349898`"}]}], "}"}], ",", 
            RowBox[{"-", "82.58250731217989`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010175421622144257`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.102079489920942`", ",", "0.6993790946992785`"}], 
             "}"}], ",", 
            RowBox[{"-", "131.99195015872561`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010149253843155022`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.087892909975138`", ",", "0.6836188491282627`"}], 
             "}"}], ",", 
            RowBox[{"-", "131.15721049647004`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011806854798793563`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.648066431511518`", ",", 
              RowBox[{"-", "1.8677482212282193`"}]}], "}"}], ",", 
            RowBox[{"-", "108.32373112079138`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011452211919860853`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.633457387841712`", ",", 
              RowBox[{"-", "1.9118605919964782`"}]}], "}"}], ",", 
            RowBox[{"-", "99.32459987501026`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010680709856083492`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.5598910142943008`", ",", 
              RowBox[{"-", "1.6845745240638166`"}]}], "}"}], ",", 
            "162.52143666230126`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010558094981586623`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3957522094877737`", ",", 
              RowBox[{"-", "1.632889265754243`"}]}], "}"}], ",", 
            "168.65435785904953`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16230782812568448`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3922309432078155`", ",", 
              RowBox[{"-", "2.628930241020917`"}]}], "}"}], ",", 
            RowBox[{"-", "135.5624105417201`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16188751415535485`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.373086493082613`", ",", 
              RowBox[{"-", "2.647702492049789`"}]}], "}"}], ",", 
            RowBox[{"-", "136.4636425842942`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030923597579745426`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4021847771895124`", ",", "2.4197950374793806`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.64720515577002`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02982057945656011`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2508515589624474`", ",", "2.369591616676134`"}], 
             "}"}], ",", 
            RowBox[{"-", "152.0977754492438`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026671756137825423`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.109843693225373`", ",", "1.128427125877418`"}], "}"}],
             ",", 
            RowBox[{"-", "159.09841567502446`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026571964416807037`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1045353568776313`", ",", "1.1263999011482146`"}], 
             "}"}], ",", 
            RowBox[{"-", "156.35407905482958`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011439257451506436`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4952292852444606`", ",", "2.826571044663803`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.8749808070138`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011394453687226162`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3308064325818236`", ",", "2.763043043820169`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.7830606392799`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019270343705663242`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.358105900150826`", ",", "2.859797487829117`"}], "}"}],
             ",", "148.34597269877995`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019172075462033394`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.158132977113625`", ",", "2.9830817346584992`"}], 
             "}"}], ",", "152.1181011742073`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.058600489374280605`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.380318304137456`", ",", 
              RowBox[{"-", "0.6066002737367311`"}]}], "}"}], ",", 
            "172.26096304273455`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05828746212156104`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1133430358425915`", ",", 
              RowBox[{"-", "0.5703185624998235`"}]}], "}"}], ",", 
            "168.34618953240005`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014427883923540014`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.566101814353904`", ",", 
              RowBox[{"-", "4.310487669884657`"}]}], "}"}], ",", 
            RowBox[{"-", "160.17901649870606`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012398625647326524`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.446348884020257`", ",", 
              RowBox[{"-", "4.35365092609602`"}]}], "}"}], ",", 
            RowBox[{"-", "145.55702961899175`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012784637573271645`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.186830152915206`", ",", 
              RowBox[{"-", "2.9007350279240947`"}]}], "}"}], ",", 
            RowBox[{"-", "59.66103223564833`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012617007760862888`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.333988727489665`", ",", 
              RowBox[{"-", "3.1521740169841297`"}]}], "}"}], ",", 
            RowBox[{"-", "66.17514382514165`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039568473042130674`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2886130596423895`", ",", 
              RowBox[{"-", "2.406696796436617`"}]}], "}"}], ",", 
            RowBox[{"-", "98.02417619351606`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03946908602100868`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.269709177066505`", ",", 
              RowBox[{"-", "2.5407943245044953`"}]}], "}"}], ",", 
            RowBox[{"-", "97.46866441758438`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.022493516776822393`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.21414977933437`", ",", 
              RowBox[{"-", "3.9108801651768457`"}]}], "}"}], ",", 
            RowBox[{"-", "97.02792297330095`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02223493310608651`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1878751517765105`", ",", 
              RowBox[{"-", "4.124011085105019`"}]}], "}"}], ",", 
            RowBox[{"-", "90.89104619931001`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05812194749420158`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.264249979302264`", ",", 
              RowBox[{"-", "2.9744161410151913`"}]}], "}"}], ",", 
            RowBox[{"-", "100.3317239183184`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.057829600887681694`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.230821166008036`", ",", 
              RowBox[{"-", "3.1577858296872368`"}]}], "}"}], ",", 
            RowBox[{"-", "96.60220801850853`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008649170763183722`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.380694900367936`", ",", 
              RowBox[{"-", "3.572269944766505`"}]}], "}"}], ",", 
            RowBox[{"-", "95.90023713172455`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043744074285567106`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.2846673386373135`", ",", 
              RowBox[{"-", "3.42689019718041`"}]}], "}"}], ",", 
            RowBox[{"-", "82.94891384878488`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043624030622833515`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3101931958713955`", ",", 
              RowBox[{"-", "3.633260269225098`"}]}], "}"}], ",", 
            RowBox[{"-", "84.28708417557984`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010123153358935738`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8723596812644248`", ",", "0.43704591406790944`"}], 
             "}"}], ",", 
            RowBox[{"-", "130.3224708342145`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01009043382390742`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.8163508583297476`", ",", "0.37105506085661005`"}], 
             "}"}], ",", 
            RowBox[{"-", "128.15217443686078`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011108221460536992`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.609319392222294`", ",", 
              RowBox[{"-", "2.0588667500189346`"}]}], "}"}], ",", 
            RowBox[{"-", "90.32546862922905`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011071264259578377`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.607990499786304`", ",", 
              RowBox[{"-", "2.292803609693519`"}]}], "}"}], ",", 
            RowBox[{"-", "88.03382784593904`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010436887729583996`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1864040273262773`", ",", 
              RowBox[{"-", "1.5908839168081363`"}]}], "}"}], ",", 
            "174.78727905579777`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010389989784159245`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.116943046812807`", ",", 
              RowBox[{"-", "1.584546922441695`"}]}], "}"}], ",", 
            "171.41583588962368`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16146828863427443`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.135354215431099`", ",", 
              RowBox[{"-", "2.873588876929993`"}]}], "}"}], ",", 
            RowBox[{"-", "137.3648746268687`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16106976677838786`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1291590347370537`", ",", 
              RowBox[{"-", "2.8792926509807226`"}]}], "}"}], ",", 
            RowBox[{"-", "137.21426682780537`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011349825404379212`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.107523011322846`", ",", "2.6895580339560903`"}], 
             "}"}], ",", 
            RowBox[{"-", "164.69114047154616`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010277417254604973`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9715389495919409`", ",", "2.652334402765798`"}], 
             "}"}], ",", 
            RowBox[{"-", "151.68486151311876`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05797610697195857`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8546878672361986`", ",", 
              RowBox[{"-", "0.5169710757238604`"}]}], "}"}], ",", 
            "164.43141602206532`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.057693255181950016`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.7081137701951414`", ",", 
              RowBox[{"-", "0.4761334728962817`"}]}], "}"}], ",", 
            "168.06559373047196`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01245157587967019`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4218536151488363`", ",", 
              RowBox[{"-", "3.351156547170038`"}]}], "}"}], ",", 
            RowBox[{"-", "72.68925541463484`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012394992483478704`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.4253620668364504`", ",", 
              RowBox[{"-", "3.362413453139368`"}]}], "}"}], ",", 
            RowBox[{"-", "69.28136973321689`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.039369948637520094`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2269974575965636`", ",", 
              RowBox[{"-", "2.866598855823816`"}]}], "}"}], ",", 
            RowBox[{"-", "96.91315264165009`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03909782909135094`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2005832540538934`", ",", 
              RowBox[{"-", "3.084454745644393`"}]}], "}"}], ",", 
            RowBox[{"-", "92.23342555929034`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.057538724750442846`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.200425868156623`", ",", 
              RowBox[{"-", "3.420396074804406`"}]}], "}"}], ",", 
            RowBox[{"-", "92.87269211869868`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05718265653137244`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.189281402749307`", ",", 
              RowBox[{"-", "3.642485901268315`"}]}], "}"}], ",", 
            RowBox[{"-", "88.5167206216064`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.043504316387141154`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.340524913380642`", ",", 
              RowBox[{"-", "3.9364533047015757`"}]}], "}"}], ",", 
            RowBox[{"-", "85.62525450237504`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04262623936684563`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.354799821483549`", ",", 
              RowBox[{"-", "4.123047464971758`"}]}], "}"}], ",", 
            RowBox[{"-", "93.40299656995415`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01005782004327544`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6277582609737444`", ",", "0.1309845474264109`"}], 
             "}"}], ",", 
            RowBox[{"-", "125.98187803950674`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01002689046088073`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5846098472847885`", ",", "0.0715563325483261`"}], 
             "}"}], ",", 
            RowBox[{"-", "127.93035635427199`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011034430015720277`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.6188993657553175`", ",", 
              RowBox[{"-", "2.610571620417632`"}]}], "}"}], ",", 
            RowBox[{"-", "85.74218706264918`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010937699242241987`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.621906511845788`", ",", 
              RowBox[{"-", "2.650963131536688`"}]}], "}"}], ",", 
            RowBox[{"-", "91.10544582544853`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16067222851916274`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.8747270856212968`", ",", 
              RowBox[{"-", "3.114781565921408`"}]}], "}"}], ",", 
            RowBox[{"-", "137.06365902874688`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1602489253146359`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.838082340362363`", ",", 
              RowBox[{"-", "3.148877303266252`"}]}], "}"}], ",", 
            RowBox[{"-", "136.01498285876502`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05741178335929856`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.4233374609525127`", ",", 
              RowBox[{"-", "0.41594306614899723`"}]}], "}"}], ",", 
            "171.6997714388788`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.056936823920177744`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3635825394116026`", ",", 
              RowBox[{"-", "0.40722552239788085`"}]}], "}"}], ",", 
            "166.50216130116522`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012338666217850892`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5187321549010875`", ",", 
              RowBox[{"-", "3.6092674409253935`"}]}], "}"}], ",", 
            RowBox[{"-", "65.87348405179902`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01161965895953892`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.66216580349884`", ",", 
              RowBox[{"-", "3.929519671680314`"}]}], "}"}], ",", 
            RowBox[{"-", "77.085689757564`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03882759039720142`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.19117527744928`", ",", 
              RowBox[{"-", "3.3256825326061277`"}]}], "}"}], ",", 
            RowBox[{"-", "87.55369847693062`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03873154493018055`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2006771023350336`", ",", 
              RowBox[{"-", "3.5480932227332427`"}]}], "}"}], ",", 
            RowBox[{"-", "87.31076295692564`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05682879177748452`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.195899279209828`", ",", 
              RowBox[{"-", "3.8980626220087173`"}]}], "}"}], ",", 
            RowBox[{"-", "84.16074912451386`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05666664760788331`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.216390756546161`", ",", 
              RowBox[{"-", "4.098432075737106`"}]}], "}"}], ",", 
            RowBox[{"-", "82.59106386890582`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009996055992443423`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.3955428969268873`", ",", 
              RowBox[{"-", "0.17104557766406175`"}]}], "}"}], ",", 
            RowBox[{"-", "129.87883466903742`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009969678396836617`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.386058930047751`", ",", 
              RowBox[{"-", "0.1823967932116381`"}]}], "}"}], ",", 
            RowBox[{"-", "130.94025086195933`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010841816436671809`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.617583509206603`", ",", 
              RowBox[{"-", "2.8749985982825743`"}]}], "}"}], ",", 
            RowBox[{"-", "96.46870458824797`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010658158601366319`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.610183188278267`", ",", 
              RowBox[{"-", "2.940267322267495`"}]}], "}"}], ",", 
            RowBox[{"-", "89.21037858885515`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15982673733459185`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6159504524003254`", ",", 
              RowBox[{"-", "3.3632753449875312`"}]}], "}"}], ",", 
            RowBox[{"-", "134.96630668878316`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15939074054648214`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.610911570792706`", ",", 
              RowBox[{"-", "3.368320156404455`"}]}], "}"}], ",", 
            RowBox[{"-", "133.6667253740382`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05646579375229029`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1264231119612176`", ",", 
              RowBox[{"-", "0.3502980429841255`"}]}], "}"}], ",", 
            "161.30455116345155`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.05524930315696491`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1230759113004076`", ",", 
              RowBox[{"-", "0.3491653743978561`"}]}], "}"}], ",", 
            "169.27828118798516`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010942550187528316`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.70053918451893`", ",", 
              RowBox[{"-", "4.096874564738043`"}]}], "}"}], ",", 
            RowBox[{"-", "88.29789546332887`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010898277795699938`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.702257626811304`", ",", 
              RowBox[{"-", "4.154703283557864`"}]}], "}"}], ",", 
            RowBox[{"-", "85.27689174478681`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03863573704503487`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2155922311191225`", ",", 
              RowBox[{"-", "3.8656354417860164`"}]}], "}"}], ",", 
            RowBox[{"-", "87.0678274369207`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03853247656745058`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.228243500126284`", ",", 
              RowBox[{"-", "4.112630251758305`"}]}], "}"}], ",", 
            RowBox[{"-", "88.22599782084951`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009943370406437158`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1814876357625916`", ",", 
              RowBox[{"-", "0.4182253843986803`"}]}], "}"}], ",", 
            RowBox[{"-", "132.00166705488087`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00987278893074765`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.157010076547749`", ",", 
              RowBox[{"-", "0.4454088774003837`"}]}], "}"}], ",", 
            RowBox[{"-", "136.75863469103018`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010477611886846358`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.612659338632755`", ",", 
              RowBox[{"-", "3.1199280820686464`"}]}], "}"}], ",", 
            RowBox[{"-", "81.95205258946237`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010355146338043755`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.613883624297096`", ",", 
              RowBox[{"-", "3.128586745291935`"}]}], "}"}], ",", 
            RowBox[{"-", "88.1364090506651`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1589559331288271`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3994172582498967`", ",", 
              RowBox[{"-", "3.5898937933800235`"}]}], "}"}], ",", 
            RowBox[{"-", "132.36714405929274`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.158449817778772`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.357224672434786`", ",", 
              RowBox[{"-", "3.6361538172685215`"}]}], "}"}], ",", 
            RowBox[{"-", "134.47245563534466`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009802708466737973`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.9759563094528474`", ",", 
              RowBox[{"-", "0.6156758306537146`"}]}], "}"}], ",", 
            RowBox[{"-", "141.51560232717964`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009778520280707782`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.898480630675166`", ",", 
              RowBox[{"-", "0.6772683293156354`"}]}], "}"}], ",", 
            RowBox[{"-", "141.37900915184113`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010234112204224405`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.620701540397806`", ",", 
              RowBox[{"-", "3.3381284650382446`"}]}], "}"}], ",", 
            RowBox[{"-", "94.32076551186775`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009714020314729989`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.617152559466575`", ",", 
              RowBox[{"-", "3.3851007019041273`"}]}], "}"}], ",", 
            RowBox[{"-", "83.58691029157379`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15794531389890568`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1468082288758534`", ",", 
              RowBox[{"-", "3.850481151304229`"}]}], "}"}], ",", 
            RowBox[{"-", "136.5777672113959`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1575484884853253`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.132850973422473`", ",", 
              RowBox[{"-", "3.8636901345735404`"}]}], "}"}], ",", 
            RowBox[{"-", "136.01845501868604`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00975439177903375`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.672209777524318`", ",", 
              RowBox[{"-", "0.858033741578869`"}]}], "}"}], ",", 
            RowBox[{"-", "141.24241597650266`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00972977672635962`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.6138631964053385`", ",", 
              RowBox[{"-", "0.9048745229806487`"}]}], "}"}], ",", 
            RowBox[{"-", "140.62204477765187`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009220359205758574`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.630213745123582`", ",", 
              RowBox[{"-", "3.5013041336861583`"}]}], "}"}], ",", 
            RowBox[{"-", "72.85305507127984`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009196715279504124`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.660778854575984`", ",", 
              RowBox[{"-", "3.600368690908474`"}]}], "}"}], ",", 
            RowBox[{"-", "73.65891354466358`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009705223789379826`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3384123243514687`", ",", 
              RowBox[{"-", "1.1309549887150265`"}]}], "}"}], ",", 
            RowBox[{"-", "140.00167357880048`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009675060194578883`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.315348086617261`", ",", 
              RowBox[{"-", "1.1503070340854382`"}]}], "}"}], ",", 
            RowBox[{"-", "138.0043379773409`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009173131983777866`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.757251316699107`", ",", 
              RowBox[{"-", "3.9294027223609964`"}]}], "}"}], ",", 
            RowBox[{"-", "74.46477201804777`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008477358699008812`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.818098322848967`", ",", 
              RowBox[{"-", "4.148287247464208`"}]}], "}"}], ",", 
            RowBox[{"-", "62.295357561168856`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009644990347482377`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0918985495275626`", ",", 
              RowBox[{"-", "1.3514712695253897`"}]}], "}"}], ",", 
            RowBox[{"-", "136.0070023758813`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009619770402865472`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.083749471856234`", ",", 
              RowBox[{"-", "1.3593388178846615`"}]}], "}"}], ",", 
            RowBox[{"-", "135.02022438370295`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.25210800679539547`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            "1.7667114977152143`", ",", "167.19899911042882`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2508384402129281`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.7737198649463215`", ",", 
              RowBox[{"-", "0.07722951543100699`"}]}], "}"}], ",", 
            RowBox[{"-", "169.62953444217587`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24399111906604629`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.7672930323709903`", ",", "0.004669646611714488`"}], 
             "}"}], ",", "179.63900122860838`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24281264740012035`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.7661119968940817`", ",", 
              RowBox[{"-", "0.006264234149068747`"}]}], "}"}], ",", 
            RowBox[{"-", "179.87969435115326`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24931985845250892`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3675489352810515`", ",", "0.11310424430511475`"}], 
             "}"}], ",", "171.53659394767965`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24086346391192495`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.850524420653777`", ",", 
              RowBox[{"-", "0.5013247962187429`"}]}], "}"}], ",", 
            RowBox[{"-", "158.7766183606123`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23369156789924644`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9375366706374482`", ",", "0.3992115048105958`"}], 
             "}"}], ",", "171.54545878873466`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.24520328198809632`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.842422203976989`", ",", 
              RowBox[{"-", "0.4570800530492261`"}]}], "}"}], ",", 
            RowBox[{"-", "159.81093338390926`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06057624519092128`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1679364592479047`", ",", "0.7873630095557195`"}], 
             "}"}], ",", 
            RowBox[{"-", "173.3423143741775`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07670595478336543`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1968282486405424`", ",", 
              RowBox[{"-", "1.5843271908251064`"}]}], "}"}], ",", 
            RowBox[{"-", "160.80160284612302`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013440267656036283`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9265945208348418`", ",", 
              RowBox[{"-", "0.5911279665573725`"}]}], "}"}], ",", 
            RowBox[{"-", "116.79242119114255`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19755853436454543`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8849683746156314`", ",", "0.8698811764446064`"}], 
             "}"}], ",", "175.70325589077552`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.22777152927111408`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.981736479233178`", ",", "2.1791356728325355`"}], 
             "}"}], ",", "147.40289286443442`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01238178954365232`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0330784063531713`", ",", 
              RowBox[{"-", "2.120040053223454`"}]}], "}"}], ",", 
            RowBox[{"-", "126.8430528526034`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21212186112314835`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.871705955361084`", ",", 
              RowBox[{"-", "2.579383011099843`"}]}], "}"}], ",", 
            RowBox[{"-", "96.01093114529128`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015042604907991313`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8907195989671668`", ",", "1.684804414747426`"}], 
             "}"}], ",", "116.07243510518562`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01321490144109207`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8604948557158172`", ",", 
              RowBox[{"-", "0.18781759303254186`"}]}], "}"}], ",", 
            RowBox[{"-", "106.08752007802445`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008710703712198769`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0670908527082337`", ",", 
              RowBox[{"-", "0.6339946714700225`"}]}], "}"}], ",", 
            RowBox[{"-", "158.70801140681021`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21194901949479275`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.82287096155126`", ",", "1.0079416589077277`"}], "}"}],
             ",", "155.66758974549973`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07180781634103656`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.382099314299674`", ",", "0.22347529134967298`"}], 
             "}"}], ",", 
            RowBox[{"-", "11.58920984041727`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.21674958435278577`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8528470577585507`", ",", 
              RowBox[{"-", "1.17291256256883`"}]}], "}"}], ",", 
            RowBox[{"-", "158.74341700013886`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008724005044455016`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.410142819605809`", ",", "3.6812770041790377`"}], 
             "}"}], ",", "42.920489432787356`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01863151469667742`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1531498249152365`", ",", "3.3914826324245704`"}], 
             "}"}], ",", "52.03908644320149`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2503182207593463`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.841612151678042`", ",", 
              RowBox[{"-", "2.4839424729838475`"}]}], "}"}], ",", 
            RowBox[{"-", "129.67564620180644`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010397071340990218`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.34571974139002`", ",", "2.320663474652185`"}], "}"}], 
            ",", "18.781044632081063`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.5475511541848186`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.371022184652178`", ",", 
              RowBox[{"-", "0.3716808198235361`"}]}], "}"}], ",", 
            RowBox[{"-", "1.7010497306758807`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.06269067518534704`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0921927069666446`", ",", "0.3256054024297014`"}], 
             "}"}], ",", 
            RowBox[{"-", "170.46963822372692`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010374915291683382`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.18705552402088`", ",", "0.7293805768078586`"}], "}"}],
             ",", 
            RowBox[{"-", "162.20150130961`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009154747018122682`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.074965366139089`", ",", 
              RowBox[{"-", "0.7819802989291605`"}]}], "}"}], ",", 
            RowBox[{"-", "168.32975361736854`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "70.51767649597501`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.279619357017198`", ",", "2.3844659508650694`"}], 
             "}"}], ",", "36.74070172982526`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0875835243348965`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.353376858084014`", ",", "1.4486758481567938`"}], 
             "}"}], ",", "1.1181155326338097`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.1653661208978088`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.471556087494077`", ",", "1.3036155224815655`"}], 
             "}"}], ",", 
            RowBox[{"-", "62.46777552842411`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08025236492921935`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.18182694304322`", ",", "0.5465277883779298`"}], "}"}],
             ",", 
            RowBox[{"-", "30.25790849158597`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010862216620351466`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.40513098295746`", ",", 
              RowBox[{"-", "1.2478631540215561`"}]}], "}"}], ",", 
            "10.228600196743807`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16858614175314884`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8631456608056345`", ",", 
              RowBox[{"-", "1.9991716919118454`"}]}], "}"}], ",", 
            RowBox[{"-", "153.7169805874081`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013624201370336193`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0003485458539485`", ",", "3.6568472194308046`"}], 
             "}"}], ",", "96.67863059996351`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09730877095902937`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.347403889598631`", ",", "0.3164039243675053`"}], 
             "}"}], ",", "54.94048896942712`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "5.069397672552881`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.33682100981092`", ",", 
              RowBox[{"-", "2.372116296911316`"}]}], "}"}], ",", 
            RowBox[{"-", "35.05779980214282`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.042739110560332604`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.311903601845028`", ",", 
              RowBox[{"-", "1.6379705011059962`"}]}], "}"}], ",", 
            "63.845781030320474`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035978520662323245`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.336491908698271`", ",", 
              RowBox[{"-", "1.3533739219868754`"}]}], "}"}], ",", 
            RowBox[{"-", "69.51925275688477`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11722278060440564`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.468165047516123`", ",", "1.3220799330813995`"}], 
             "}"}], ",", "71.78179179291755`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2847796251139698`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.454284569695465`", ",", 
              RowBox[{"-", "0.7830988991393053`"}]}], "}"}], ",", 
            RowBox[{"-", "59.03799924851048`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08034998488806841`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.192257270270463`", ",", "1.011642970905468`"}], "}"}],
             ",", "20.76949309882005`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013809689753066571`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.822712616640818`", ",", 
              RowBox[{"-", "1.146059333803818`"}]}], "}"}], ",", 
            RowBox[{"-", "169.82710906060004`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08938541161846728`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.11164321715692`", ",", 
              RowBox[{"-", "2.5383145838870496`"}]}], "}"}], ",", 
            "10.615315504023455`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013134417381011775`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.45538678793015`", ",", 
              RowBox[{"-", "0.7653751126454883`"}]}], "}"}], ",", 
            "41.3205880712183`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020847260454136658`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.367052651840087`", ",", "0.14943348693084343`"}], 
             "}"}], ",", "10.471700321505581`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17658619051611493`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.295863451371103`", ",", "3.872524143458744`"}], "}"}],
             ",", "77.77122083177879`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00942103932641719`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.825246023854241`", ",", "3.9303156676656474`"}], 
             "}"}], ",", "55.5366776364981`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009086340261723959`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.43413732121714`", ",", 
              RowBox[{"-", "0.8473346537407715`"}]}], "}"}], ",", 
            RowBox[{"-", "39.937119490377775`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "3.7198225580499793`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.942088537623861`", ",", "3.6182506337634655`"}], 
             "}"}], ",", "76.1082747508538`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.17255297843795475`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.469682112473555`", ",", "1.3151141464055818`"}], 
             "}"}], ",", 
            RowBox[{"-", "20.07144595354387`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017394438873931734`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.114318319292503`", ",", 
              RowBox[{"-", "4.651750633423436`"}]}], "}"}], ",", 
            RowBox[{"-", "67.4791011217079`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008453759448249396`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8170903467914052`", ",", "1.5473035894966969`"}], 
             "}"}], ",", 
            RowBox[{"-", "148.60770976803934`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01299763426657872`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.779063316539821`", ",", 
              RowBox[{"-", "0.9682283827490923`"}]}], "}"}], ",", 
            "176.7970196467942`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02090861580665654`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.397117182488653`", ",", 
              RowBox[{"-", "0.1252058009954891`"}]}], "}"}], ",", 
            "75.92000345633994`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10706041730862778`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8258596958523285`", ",", "1.0332433360189008`"}], 
             "}"}], ",", "151.96825943476807`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015718216196931555`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.996997111901896`", ",", "3.6103894700818837`"}], 
             "}"}], ",", "89.70021374110082`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07710030357132663`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.576370351743306`", ",", "3.840641917987641`"}], "}"}],
             ",", "80.4659366752344`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.41562285305397206`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.5651883069599`", ",", "3.6848540105536114`"}], "}"}], 
            ",", "110.99009657013657`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015482629958930077`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.1726285273595956`", ",", "3.9255726373682482`"}], 
             "}"}], ",", "99.19538077198547`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.014867180537842278`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.557058154927904`", ",", "3.6857111952687807`"}], 
             "}"}], ",", "105.74495295415792`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02287202886569785`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.000414990405947`", ",", 
              RowBox[{"-", "4.159206389957394`"}]}], "}"}], ",", 
            RowBox[{"-", "64.25150799376473`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00842876023869091`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.021738605429321`", ",", "3.6895005923389186`"}], 
             "}"}], ",", "75.53844922356132`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.3528603025861492`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.11741073100309`", ",", "3.1862318942371473`"}], "}"}],
             ",", "136.55457447579917`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018253914323597284`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.28456357642351`", ",", "1.882574819793523`"}], "}"}], 
            ",", "73.38421102169585`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008202692387136062`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.893635248830319`", ",", "3.7624543145467406`"}], 
             "}"}], ",", "87.5750655627184`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009085943876305364`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.057522303906609`", ",", "3.7785231599775653`"}], 
             "}"}], ",", "137.81216205136357`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.27038197838035677`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.393442965850957`", ",", 
              RowBox[{"-", "2.303851857405552`"}]}], "}"}], ",", 
            RowBox[{"-", "63.172783169485044`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.26727178874055074`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.202642609176679`", ",", "0.8816321711879552`"}], 
             "}"}], ",", 
            RowBox[{"-", "161.80630800772565`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.191341619086145`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.377435097169095`", ",", "3.658150991890274`"}], "}"}],
             ",", "54.905275495172546`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.018028563397250823`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.345897813530606`", ",", "3.806407466702233`"}], "}"}],
             ",", "115.00436901058066`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00825072265202851`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8591223699710941`", ",", 
              RowBox[{"-", "0.379751604104828`"}]}], "}"}], ",", 
            "156.09585739832232`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07691633247592052`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.370476193877607`", ",", "3.3020565011722733`"}], 
             "}"}], ",", "3.8124368001543103`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07364704065544961`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.6634007260393116`", ",", "3.889464890278438`"}], 
             "}"}], ",", "156.8983931945971`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07771978843336844`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1664863383255795`", ",", "1.7124017880902116`"}], 
             "}"}], ",", "148.1069428824405`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00869048902662272`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1688661246212564`", ",", "3.9136726985842807`"}], 
             "}"}], ",", "117.74270855290527`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011845081965868559`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.057599674808473`", ",", 
              RowBox[{"-", "3.732319033051137`"}]}], "}"}], ",", 
            RowBox[{"-", "151.0347873065779`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01005472558477097`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.939751687198152`", ",", "2.8785860260273344`"}], 
             "}"}], ",", 
            RowBox[{"-", "152.21821476068007`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009108008077500871`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.3669117145038703`", ",", "3.764223584864702`"}], 
             "}"}], ",", "78.27105632132013`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0188568828218138`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.7735416284485892`", ",", 
              RowBox[{"-", "1.0338422441077806`"}]}], "}"}], ",", 
            RowBox[{"-", "165.16616260351088`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008049888409401629`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.957214733053927`", ",", "3.6183783225821378`"}], 
             "}"}], ",", "76.70395218288492`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.015479012753830191`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.988617948777935`", ",", 
              RowBox[{"-", "4.710701163914752`"}]}], "}"}], ",", 
            RowBox[{"-", "69.45336317899522`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.034133503291260255`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.249413289851313`", ",", "3.865881414191816`"}], "}"}],
             ",", "101.77827846184863`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.2859832372995041`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1854391618308204`", ",", "3.917440606065164`"}], 
             "}"}], ",", "123.89155302375207`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.030368714105124362`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.6447050878359932`", ",", "3.7340071536615724`"}], 
             "}"}], ",", "119.54139812096562`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.09322966793809642`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.666413661944249`", ",", "3.8758765752816933`"}], 
             "}"}], ",", "65.00140177912648`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019165915001405957`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7945631340613906`", ",", "3.9404978394038013`"}], 
             "}"}], ",", "10.461405437286924`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02295444258858553`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.0875717529220807`", ",", "3.857537429702332`"}], 
             "}"}], ",", "156.31117257920042`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1455889529665632`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.866738553866757`", ",", "1.6632737373389903`"}], 
             "}"}], ",", 
            RowBox[{"-", "177.91870435236493`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012103611224886438`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9255244467780555`", ",", "0.4850253643387584`"}], 
             "}"}], ",", "172.7278583728955`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1755309911382409`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.1545226228344525`", ",", "3.848702210669975`"}], 
             "}"}], ",", "127.40368667441064`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.19937205813226602`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9002821581533915`", ",", "2.948691825759078`"}], 
             "}"}], ",", "167.84852153664048`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011376249882806836`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.145218465973057`", ",", "3.002605801682305`"}], "}"}],
             ",", 
            RowBox[{"-", "0.32761315955869674`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010369009586280703`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9254498630377734`", ",", "0.4847035724536128`"}], 
             "}"}], ",", "163.66295609730378`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011308330064175354`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.464967287231055`", ",", 
              RowBox[{"-", "2.8252742464879286`"}]}], "}"}], ",", 
            RowBox[{"-", "49.45804328804603`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.035451583665520314`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.705414945740973`", ",", "3.888998368063742`"}], "}"}],
             ",", "100.43156992117854`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008784173128675054`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.88750394744357`", ",", "3.8598451511704264`"}], "}"}],
             ",", "57.408387001115486`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03510472341432141`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.928757673475447`", ",", "3.59616286765204`"}], "}"}], 
            ",", "50.20533251589817`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00860646001683766`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8999957360474449`", ",", "1.691340859919253`"}], 
             "}"}], ",", "115.60300927498879`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03164313229320953`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.315560330733823`", ",", "3.842826281431774`"}], "}"}],
             ",", "25.114529103220054`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.020565684496185017`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.089830620806531`", ",", "3.644610377272796`"}], "}"}],
             ",", "141.05358797235212`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07950243014446738`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8184609758976726`", ",", 
              RowBox[{"-", "0.1543466785264378`"}]}], "}"}], ",", 
            RowBox[{"-", "163.3400000305147`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1523541855084696`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8925223693054563`", ",", 
              RowBox[{"-", "3.0614739192830824`"}]}], "}"}], ",", 
            RowBox[{"-", "149.45964116780254`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04044297839734489`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.735202566971461`", ",", "3.941086772914109`"}], "}"}],
             ",", "117.12592401488814`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.046418863892723754`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.5490640983277992`", ",", "3.6362395798778353`"}], 
             "}"}], ",", "120.08965598555879`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0314479105128328`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.35458679363506`", ",", "0.12765032623837`"}], "}"}], 
            ",", 
            RowBox[{"-", "40.67917961595703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008569221334538671`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.133292155381548`", ",", "3.839095338540685`"}], "}"}],
             ",", "92.36321961749675`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.033810148026422675`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.816528145569681`", ",", 
              RowBox[{"-", "4.383112257242901`"}]}], "}"}], ",", 
            RowBox[{"-", "114.92239308583001`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.11461909881547977`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.750818439690522`", ",", 
              RowBox[{"-", "4.419688470805187`"}]}], "}"}], ",", 
            RowBox[{"-", "109.63836857289277`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017805985599295766`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.166895214856064`", ",", 
              RowBox[{"-", "3.0588244373516718`"}]}], "}"}], ",", 
            RowBox[{"-", "23.366767260611834`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "1.1403741893515447`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.624661889022492`", ",", "3.837040565238847`"}], "}"}],
             ",", "114.8518755604965`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008186074095058088`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.882779322650426`", ",", "3.811935048904515`"}], "}"}],
             ",", "39.80730471363811`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02740152175722202`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.475677707174433`", ",", "3.668722634526091`"}], "}"}],
             ",", "80.200821722627`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2370612963924621`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8654612149900247`", ",", "0.8885482619526972`"}], 
             "}"}], ",", 
            RowBox[{"-", "166.2736217610478`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.2867185637790726`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.905450895359237`", ",", "2.9302119632853034`"}], 
             "}"}], ",", 
            RowBox[{"-", "176.15936861482984`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.07606481930067648`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.001820259253169`", ",", "0.8322686305099309`"}], 
             "}"}], ",", 
            RowBox[{"-", "144.38405735783746`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028024213040754323`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.553007083039228`", ",", "3.824253879775438`"}], "}"}],
             ",", "163.2892128621183`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0361092550172754`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8717760217040529`", ",", 
              RowBox[{"-", "3.596276373248007`"}]}], "}"}], ",", 
            RowBox[{"-", "149.23338054128817`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00914123005986919`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.277153594740588`", ",", 
              RowBox[{"-", "1.8841482342927005`"}]}], "}"}], ",", 
            RowBox[{"-", "29.03312205700166`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15887861318462476`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.78884187988963`", ",", "3.9356753447342863`"}], "}"}],
             ",", "124.20085891368073`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01687145370879416`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.7936828751715794`", ",", "0.0789026636679371`"}], 
             "}"}], ",", "168.1292475964825`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013463621197105787`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.7818741487236447`", ",", 
              RowBox[{"-", "1.0752584328605608`"}]}], "}"}], ",", 
            "178.3720720924594`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008801486977194652`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.07115545095173`", ",", "3.6707940629447973`"}], "}"}],
             ",", "100.83174054489427`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012187064280882806`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1227029962502155`", ",", "3.8305644736481965`"}], 
             "}"}], ",", "92.74866963457558`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012299228214542272`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.27378532912938`", ",", "3.089154647252922`"}], "}"}], 
            ",", 
            RowBox[{"-", "22.99095389713344`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.13071026853977363`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.495946585525004`", ",", "3.6887914096803205`"}], 
             "}"}], ",", "35.58621672197445`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.01188857371649193`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8756163776684474`", ",", 
              RowBox[{"-", "1.1869631499097286`"}]}], "}"}], ",", 
            RowBox[{"-", "117.75823856665497`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00923661201086145`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.300156147257562`", ",", "1.4583259666974322`"}], 
             "}"}], ",", "72.88873059729019`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.08473011028721002`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.2909883109441656`", ",", 
              RowBox[{"-", "4.5946589053852165`"}]}], "}"}], ",", 
            RowBox[{"-", "133.7278356184503`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0527029012314148`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"7.592086742145651`", ",", 
              RowBox[{"-", "4.625886100022921`"}]}], "}"}], ",", 
            RowBox[{"-", "91.24744319011555`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.10986009869390606`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.074781152017092`", ",", 
              RowBox[{"-", "4.648738151644846`"}]}], "}"}], ",", 
            RowBox[{"-", "24.808346241759477`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.029589792549295744`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8240741026616254`", ",", "1.588190619940066`"}], 
             "}"}], ",", "161.64843363241732`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013431425908291657`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.417195633114394`", ",", 
              RowBox[{"-", "0.1544898434743955`"}]}], "}"}], ",", 
            RowBox[{"-", "4.117422846532065`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009784707142137649`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", 
                 RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2076719681319608`", ",", "1.8799915918934478`"}], 
             "}"}], ",", 
            RowBox[{"-", "178.4849822352703`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.02631759933666217`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.470391685845325`", ",", 
              RowBox[{"-", "4.324888481466`"}]}], "}"}], ",", 
            "4.963745615870568`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008018959664387442`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.636771330728353`", ",", "3.7921973243101887`"}], 
             "}"}], ",", "135.65893811831836`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.031108199664232762`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8423080769447733`", ",", 
              RowBox[{"-", "0.45235163317290616`"}]}], "}"}], ",", 
            RowBox[{"-", "124.23617911994208`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.00802838107645152`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.282380208947151`", ",", 
              RowBox[{"-", "1.8815251178425596`"}]}], "}"}], ",", 
            RowBox[{"-", "24.388328791260378`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.008450312084613576`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.900105784987952`", ",", "1.382113841150748`"}], "}"}],
             ",", "162.91032600938826`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009622081966793348`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8238439393769457`", ",", "1.0202765181166027`"}], 
             "}"}], ",", 
            RowBox[{"-", "158.8005581661891`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.012778700267654632`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.815103198866747`", ",", 
              RowBox[{"-", "4.5442523639535395`"}]}], "}"}], ",", 
            RowBox[{"-", "126.03702553701217`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.16363563205894352`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.515057093215638`", ",", 
              RowBox[{"-", "4.686380860885859`"}]}], "}"}], ",", 
            RowBox[{"-", "124.52088142431859`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010658256200097168`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.353958111122084`", ",", "0.12673605509693064`"}], 
             "}"}], ",", 
            RowBox[{"-", "61.464840773665365`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0165971042593572`"}], 
              ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "132.56507968104114`"}], 
                "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.0375417428426617`", ",", "2.1825871052305135`"}], 
             "}"}], ",", "154.5701194401237`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.017715521554756614`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{
                "0.`", ",", "0.9999999999999999`", ",", 
                 "167.35910683550452`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9679775262061567`", ",", 
              RowBox[{"-", "1.6446457138116022`"}]}], "}"}], ",", 
            RowBox[{"-", "126.45167580554087`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011647648499061757`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8478535170951083`", ",", 
              RowBox[{"-", "2.5287092081334865`"}]}], "}"}], ",", 
            RowBox[{"-", "137.5996570619094`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.0165525755601482`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.1147820855425192`", ",", 
              RowBox[{"-", "2.2821698249394347`"}]}], "}"}], ",", 
            "179.75093950143753`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.016782319412679363`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"6.302464808170437`", ",", 
              RowBox[{"-", "4.450050301458311`"}]}], "}"}], ",", 
            RowBox[{"-", "126.12499858619478`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.23627563433252427`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.412962572471049`", ",", 
              RowBox[{"-", "4.416584131883879`"}]}], "}"}], ",", 
            RowBox[{"-", "84.55248260563498`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.1292228619235062`"}], 
              ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8575330775666872`", ",", 
              RowBox[{"-", "1.973609833425109`"}]}], "}"}], ",", 
            RowBox[{"-", "164.238686250161`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.025052920747016295`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8331971455187728`", ",", 
              RowBox[{"-", "1.49581634012526`"}]}], "}"}], ",", 
            "123.0524960229152`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011069641631359073`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.847484571749867`", ",", 
              RowBox[{"-", "1.5541627057341192`"}]}], "}"}], ",", 
            "170.98123045637232`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.011175902980703164`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.101985669129406`", ",", "3.8742308283456834`"}], 
             "}"}], ",", "99.90228773590891`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.013754071706224509`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.301227485802736`", ",", "2.5779427149896432`"}], 
             "}"}], ",", 
            RowBox[{"-", "59.527861839832894`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.028756905040941163`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.105089716554118`", ",", "2.2924074478347602`"}], 
             "}"}], ",", 
            RowBox[{"-", "142.5483457427178`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.026472546064063754`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8227355325169223`", ",", "1.0030155268912893`"}], 
             "}"}], ",", 
            RowBox[{"-", "153.60974243463457`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.019074308332854527`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9620053601186829`", ",", "3.0868466436547135`"}], 
             "}"}], ",", "155.89022964963465`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010654779228694138`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"4.30456992408814`", ",", 
              RowBox[{"-", "4.450885268302151`"}]}], "}"}], ",", 
            RowBox[{"-", "130.93504273927766`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.021979322092558224`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.1843017802244207`", ",", 
              RowBox[{"-", "4.353766402763522`"}]}], "}"}], ",", 
            RowBox[{"-", "84.75416942531919`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010343302573710479`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8429277720194244`", ",", 
              RowBox[{"-", "1.5431834720036013`"}]}], "}"}], ",", 
            "168.04439272344925`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009306337468812365`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8126837753289176`", ",", "2.5667455556332626`"}], 
             "}"}], ",", 
            RowBox[{"-", "138.6785825546915`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.04176588516850442`"}],
               ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"5.3435873933583835`", ",", 
              RowBox[{"-", "4.311607522435026`"}]}], "}"}], ",", 
            RowBox[{"-", "101.18073863753324`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.056504966068771215`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"8.2637206997027`", ",", 
              RowBox[{"-", "4.46240798472222`"}]}], "}"}], ",", 
            RowBox[{"-", "81.02137861329751`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.054059020452650715`"}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.9247809079917395`", ",", 
              RowBox[{"-", "0.31161928865510713`"}]}], "}"}], ",", 
            "177.25201121251865`"}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.010854184525250454`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3.7259065841173045`", ",", 
              RowBox[{"-", "4.4409374302681215`"}]}], "}"}], ",", 
            RowBox[{"-", "82.25588802624462`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.03842949207078567`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"2.2382741906794665`", ",", 
              RowBox[{"-", "4.436492633377812`"}]}], "}"}], ",", 
            RowBox[{"-", "89.38416820477865`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{"Intensity", "\[RuleDelayed]", "0.15715266006497608`"}],
               ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.892191514199834`", ",", 
              RowBox[{"-", "4.095942514368096`"}]}], "}"}], ",", 
            RowBox[{"-", "135.45914282597485`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"Ray", "[", 
             RowBox[{
              RowBox[{
              "Intensity", "\[RuleDelayed]", "0.009594616403945098`"}], ",", 
              RowBox[{"Polarization", "\[RuleDelayed]", 
               RowBox[{"{", 
                RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1.8626583431103891`", ",", 
              RowBox[{"-", "1.5802739192837725`"}]}], "}"}], ",", 
            RowBox[{"-", "134.03344639152346`"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", 
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"SingleRay", "[", 
              RowBox[{"IntrinsicMedium", "\[Rule]", "1.34`"}], "]"}], ",", 
             RowBox[{"-", "2.`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], "}"}]}], "}"}], ",", 
     RowBox[{"Optica`Optica`Private`HeldList", "[", 
      RowBox[{
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"RemoveSurface", "[", 
           RowBox[{
            RowBox[{"RodLens", "[", 
             RowBox[{"1", ",", "1", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"FresnelReflections", "\[Rule]", "True"}], ",", 
                RowBox[{"ComponentMedium", "\[Rule]", "1.48`"}]}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "5"}], "}"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm], ",", 
       TagBox[
        StyleBox[
         TagBox[
          RowBox[{"Move", "[", 
           RowBox[{
            RowBox[{"ClearBoundary", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "5"}], ",", 
                RowBox[{"-", "5"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"9", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.75`", ",", 
              RowBox[{"-", "0.4`"}]}], "}"}]}], "]"}],
          HoldForm],
         FontColor->RGBColor[0., 0.392193, 0.]],
        DisplayForm]}], "]"}], ",", "\<\"-optics graphics-\"\>", 
     ",", "\<\"-Options-\"\>"}], "]"}]}],
  SequenceForm["No changes to numeric parameters have been made for ", 
   Hold[{
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {-1.9999999999999996`, 0., 0.}, 
      Optica`Optica`RayEnd :> {1.7667114977152143`, 0., 0.}, 
      RotationMatrix :> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 100., 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      3.766711497715214, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 5.047393406938387, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05573880608888074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 4, 
      Optica`Optica`IntersectionNumber :> 1, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {1., 0., 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7667114977152143`, 0., 0.}, 
      Optica`Optica`RayEnd :> {2.150842225822762, -0.004073940169013586, 0.}, 
      RotationMatrix :> {{0.9999437652765565, -0.010605012236808924`, 0.}, {
       0.010605012236808924`, 0.9999437652765565, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.74789199320458, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.38415233080763067`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      5.61593885653368, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.408646719457491, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 4, 
      Optica`Optica`IntersectionNumber :> 2, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999437652765565, -0.010605012236808924`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.150842225822762, -0.004073940169013586, 0.},
       Optica`Optica`RayEnd :> {1.7737198649463215`, -0.07722951543100699, 
       0.}, RotationMatrix :> {{-0.9817000461342819, -0.19043376649100038`, 
       0.}, {0.19043376649100038`, -0.9817000461342819, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2514724223244908, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3841523308076281, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 6.18448430612897, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14427332443753854`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 4, 
      Optica`Optica`IntersectionNumber :> 3, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9817000461342819, -0.19043376649100038`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.150842225822762, -0.004073940169013586, 0.},
       Optica`Optica`RayEnd :> {2.313846576425795, -0.007531849809321051, 0.},
       RotationMatrix :> {{0.9997750674309145, -0.021208831733746873`, 0.}, {
       0.021208831733746873`, 0.9997750674309145, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.49641957088005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16304102383939145`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      5.834413828478465, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.013044597128339214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 8, 
      Optica`Optica`IntersectionNumber :> 3, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9997750674309145, -0.021208831733746873`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.313846576425795, -0.007531849809321051, 0.},
       Optica`Optica`RayEnd :> {2.6587982155668994`, -0.015008885084780993`, 
       0.}, 
      RotationMatrix :> {{0.9997651668322586, -0.021670514273228633`, 0.}, {
       0.021670514273228633`, 0.9997651668322586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.25118366957307, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3450326642546253, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      6.345062171575311, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42863540965260527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 8, 
      Optica`Optica`IntersectionNumber :> 4, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9997651668322586, -0.021670514273228633`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6587982155668994`, -0.015008885084780993`, 
       0.}, Optica`Optica`RayEnd :> {2.3137939589293546`, -0.010581436087871, 
       0.}, RotationMatrix :> {{-0.9999176668761433, 0.012831970580161198`, 
       0.}, {-0.012831970580161198`, -0.9999176668761433, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24463145094031025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34503266425462553`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      6.855710514672157, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.00420613976960598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 8, 
      Optica`Optica`IntersectionNumber :> 5, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999176668761433, 0.012831970580161198`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.313846576425795, -0.007531849809321053, 0.},
       Optica`Optica`RayEnd :> {2.1506905823677744`, -0.002476657692228986, 
       0.}, RotationMatrix :> {{-0.9995203474979495, 0.030968935041074536`, 
       0.}, {-0.030968935041074536`, -0.9995203474979495, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24523590130695874`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16323428979354024`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.053147776801809, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40623824978740386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 4, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9995203474979495, 0.030968935041074536`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1506905823677744`, -0.0024766576922289896`, 
       0.}, Optica`Optica`RayEnd :> {1.7672930323709903`, 
       0.004669646611714488, 0.}, 
      RotationMatrix :> {{-0.9998263314404735, 0.018636173380943626`, 
       0.}, {-0.018636173380943626`, -0.9998263314404735, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24461271838368367`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.38346414566259146`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      6.620674712382444, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06783244622635987, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 5, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9998263314404735, 0.018636173380943626`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6587982155668994`, -0.015008885084780998`, 
       0.}, Optica`Optica`RayEnd :> {2.88220483912467, -0.019954574845912905`,
        0.}, RotationMatrix :> {{0.9997550530348914, -0.022132192191499464`, 
       0.}, {0.022132192191499464`, 0.9997550530348914, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.00655221863269, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22346135973965783`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.644500393626452, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07815640850299857, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 12, 
      Optica`Optica`IntersectionNumber :> 5, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9997550530348914, -0.022132192191499464`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.88220483912467, -0.01995457484591291, 0.}, 
      Optica`Optica`RayEnd :> {3.203448398313732, -0.03118806463673083, 0.}, 
      RotationMatrix :> {{0.9993891529748828, -0.03494740213729931, 0.}, {
       0.03494740213729931, 0.9993891529748828, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      98.75435028932107, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32143990980171855`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.120231460132995, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40963882827172354`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 12, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9993891529748828, -0.03494740213729931, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.203448398313732, -0.03118806463673083, 0.}, 
      Optica`Optica`RayEnd :> {2.8890066728387804`, -0.09789651158066667, 0.},
       RotationMatrix :> {{-0.9782286389668182, -0.20753006988175557`, 0.}, {
       0.20753006988175557`, -0.9782286389668182, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2515594888698206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32143990980171844`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.595962526639538, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1625187257260004, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 12, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9782286389668182, -0.20753006988175557`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3137939589293546`, -0.010581436087871, 0.}, 
      Optica`Optica`RayEnd :> {2.1511871633859885`, -0.008419595868123391, 
       0.}, RotationMatrix :> {{-0.9999116346018719, 0.01329371986362917, 
       0.}, {-0.01329371986362917, -0.9999116346018719, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24402849040546773`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.162621165627411, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.0736228766128875`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41504764644609426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999116346018719, 0.01329371986362917, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1511871633859885`, -0.008419595868123391, 
       0.}, Optica`Optica`RayEnd :> {
       1.7661119968940817`, -0.006264234149068746, 0.}, 
      RotationMatrix :> {{-0.9999843357680084, 0.00559716165704483, 
       0.}, {-0.00559716165704483, -0.9999843357680084, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24341980978631647`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3850811984931353, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.6435430503827275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03951543849063535, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999843357680084, 0.00559716165704483, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.88220483912467, -0.019954574845912905`, 0.},
       Optica`Optica`RayEnd :> {2.6470204120697653`, 0.05068334347140578, 0.},
       RotationMatrix :> {{-0.9577336678208785, 0.2876564296558782, 
       0.}, {-0.2876564296558782, -0.9577336678208785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25220192931161994`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2455634953191293, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.973555477354085, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3125031565382293, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9577336678208785, 0.2876564296558782, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6470204120697653`, 0.05068334347140578, 0.},
       Optica`Optica`RayEnd :> {2.3675489352810515`, 0.11310424430511475`, 
       0.}, RotationMatrix :> {{-0.9759527129068826, 0.21798234371089836`, 
       0.}, {-0.21798234371089836`, -0.9759527129068826, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2507567532837804, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28635760021231554`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.397364725668313, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36267791665571997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9759527129068826, 0.21798234371089836`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.203448398313732, -0.03118806463673083, 0.}, 
      Optica`Optica`RayEnd :> {3.289988407633029, -0.03532566548370465, 0.}, 
      RotationMatrix :> {{0.9988589898270124, -0.04775686800618502, 0.}, {
       0.04775686800618502, 0.9988589898270124, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      98.50279080045121, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08663886514580404, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.236327539428372, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05003789986576571, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 16, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9988589898270124, -0.04775686800618502, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.289988407633029, -0.03532566548370465, 0.}, 
      Optica`Optica`RayEnd :> {3.6101936044655933`, -0.046115682956667625`, 
       0.}, RotationMatrix :> {{0.9994327325242668, -0.033678081285566805`, 
       0.}, {0.033678081285566805`, 0.9994327325242668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      98.25016212424417, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32038694192436795`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.710500213476437, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3852372121838523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 16, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9994327325242668, -0.033678081285566805`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6101936044655933`, -0.046115682956667625`, 
       0.}, Optica`Optica`RayEnd :> {3.304262492718633, 0.049036549917380684`,
        0.}, RotationMatrix :> {{-0.9548800893988368, 0.29699160740611696`, 
       0.}, {-0.29699160740611696`, -0.9548800893988368, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2519807631121969, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.320386941924368, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.184672887524501, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21091766295593617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 16, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9548800893988368, 0.29699160740611696`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8890066728387804`, -0.09789651158066667, 
       0.}, Optica`Optica`RayEnd :> {
       2.8351104353765613`, -0.10861037831299702`, 0.}, 
      RotationMatrix :> {{-0.9808088170137308, -0.19497195815841276`, 0.}, {
       0.19497195815841276`, -0.9808088170137308, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25091868493303154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05495080848306122, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.66959661000684, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04307688827840045, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9808088170137308, -0.19497195815841276`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8351104353765613`, -0.10861037831299702`, 
       0.}, Optica`Optica`RayEnd :> {2.631370047670223, -0.17513360904866818`,
        0.}, RotationMatrix :> {{-0.9506112975353982, -0.31038389294237956`, 
       0.}, {0.31038389294237956`, -0.9506112975353982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24723671810648565`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21432565364472916`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.986798577401039, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24070583031372797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9506112975353982, -0.31038389294237956`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.289988407633029, -0.03532566548370465, 0.}, 
      Optica`Optica`RayEnd :> {3.203619614090072, -0.057219436555797455`, 0.},
       RotationMatrix :> {{-0.9693408857366421, -0.24571985519957873`, 0.}, {
       0.24571985519957873`, -0.9693408857366421, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2526286762070828, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08910053709054258, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.355722259129699, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41337462017475474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9693408857366421, -0.24571985519957873`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2036196140900715`, -0.057219436555797455`, 
       0.}, Optica`Optica`RayEnd :> {2.9006298519039526`, -0.1239716558766005,
        0.}, RotationMatrix :> {{-0.9765805269957853, -0.21515221191666578`, 
       0.}, {0.21515221191666578`, -0.9765805269957853, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2518754848342481, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31025578926726516`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.814900827245252, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24303557091065608`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9765805269957853, -0.21515221191666578`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6101936044655933`, -0.046115682956667625`, 
       0.}, Optica`Optica`RayEnd :> {3.884424114220212, -0.05148960539899354, 
       0.}, RotationMatrix :> {{0.9998080464314015, -0.019592608071010764`, 
       0.}, {0.019592608071010764`, 0.9998080464314015, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      97.99818136113194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27428315938586945`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.078039647053503, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23748150751418137`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 20, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9998080464314015, -0.019592608071010764`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.884424114220212, -0.05148960539899354, 0.}, 
      Optica`Optica`RayEnd :> {4.174745282155764, -0.04187068499412144, 0.}, 
      RotationMatrix :> {{0.9994515868142558, 0.03311382814574367, 
       0.}, {-0.03311382814574367, 0.9994515868142558, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      97.60177509251764, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2904804712561898, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.507950744512664, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28991308320566767`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 20, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9994515868142558, 0.03311382814574367, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.174745282155764, -0.04187068499412144, 0.}, 
      Optica`Optica`RayEnd :> {3.9920227327644295`, 0.18394201200307905`, 0.},
       RotationMatrix :> {{-0.6290355719995433, 0.7773765169846638, 
       0.}, {-0.7773765169846638, -0.6290355719995433, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.39480279059446854`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2904804712561897, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.937861841971825, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33792178208558277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 20, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6290355719995433, 0.7773765169846638, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.304262492718633, 0.049036549917380684`, 0.},
       Optica`Optica`RayEnd :> {2.8975987417994986`, 0.16926171893825742`, 
       0.}, RotationMatrix :> {{-0.9589699460058219, 0.28350774708566767`, 
       0.}, {-0.28350774708566767`, -0.9589699460058219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2513345117106132, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.42406308207354987`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.752917417503058, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.295180108361651, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9589699460058219, 0.28350774708566767`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8975987417994986`, 0.16926171893825742`, 
       0.}, Optica`Optica`RayEnd :> {2.560781759415158, 0.27331809425780756`, 
       0.}, RotationMatrix :> {{-0.955443202349738, 0.29517501094042053`, 
       0.}, {-0.29517501094042053`, -0.955443202349738, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2506962929360381, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3525243379784386, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.274653437711146, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09127768688089939, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.955443202349738, 0.29517501094042053`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.631370047670223, -0.17513360904866818`, 0.},
       Optica`Optica`RayEnd :> {2.4272549118351114`, -0.2699744584069052, 0.},
       RotationMatrix :> {{-0.9068848635602611, -0.4213785047261982, 0.}, {
       0.4213785047261982, -0.9068848635602611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24360878025636062`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22507282240194557`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.288396159419646, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41665265513164207`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9068848635602611, -0.4213785047261982, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4272549118351114`, -0.2699744584069052, 0.},
       Optica`Optica`RayEnd :> {2.1508630265649438`, -0.38625248209328467`, 
       0.}, RotationMatrix :> {{-0.9217516335228982, -0.38778077066542205`, 
       0.}, {0.38778077066542205`, -0.9217516335228982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.242833156181243, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2998550533768069, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.73218163841732, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33503683690138536`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9217516335228982, -0.38778077066542205`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9006298519039526`, -0.1239716558766005, 0.},
       Optica`Optica`RayEnd :> {2.868778330669892, -0.1299466247306531, 0.}, 
      RotationMatrix :> {{-0.9828564852107069, -0.18437225788945374`, 0.}, {
       0.18437225788945374`, -0.9828564852107069, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25112453903880644`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.032407092707163646`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.858326331472851, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08398174809308423, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9828564852107069, -0.18437225788945374`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.868778330669892, -0.12994662473065313`, 0.},
       Optica`Optica`RayEnd :> {2.621793917817546, -0.19608559386754335`, 0.},
       RotationMatrix :> {{-0.9659652235143442, -0.2586719678683463, 0.}, {
       0.2586719678683463, -0.9659652235143442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24956482069046557`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25568665086489895`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.2367425747529, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17386074561011847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9659652235143442, -0.2586719678683463, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.884424114220212, -0.051489605398993554`, 
       0.}, Optica`Optica`RayEnd :> {
       3.8360941866799445`, -0.12834485163359455`, 0.}, 
      RotationMatrix :> {{-0.532336668538546, -0.8465327349425312, 0.}, {
       0.8465327349425312, -0.532336668538546, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39640626861431016`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09078827440715387, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 8.199695934759088, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1557887690226129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.532336668538546, -0.8465327349425312, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8360941866799445`, -0.12834485163359455`, 
       0.}, Optica`Optica`RayEnd :> {
       3.6527301356231905`, -0.40317480552400664`, 0.}, 
      RotationMatrix :> {{-0.5550020774845027, -0.8318489610427399, 0.}, {
       0.8318489610427399, -0.5550020774845027, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3952797393161795, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3303844408796364, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 8.68866490726095, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37888153375539146`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5550020774845027, -0.8318489610427399, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.174745282155764, -0.04187068499412144, 0.}, 
      Optica`Optica`RayEnd :> {4.400554302185327, -0.022440938596222378`, 0.},
       RotationMatrix :> {{0.9963185552591743, 0.08572827098613041, 
       0.}, {-0.08572827098613041, 0.9963185552591743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      97.20697230192317, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22664339516473522`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.81165289403341, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18129781125149372`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9963185552591743, 0.08572827098613041, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.400554302185327, -0.022440938596222378`, 
       0.}, Optica`Optica`RayEnd :> {4.6946057131986, 0.011066496590403974`, 
       0.}, RotationMatrix :> {{0.9935701420223269, 0.11321825330631577`, 
       0.}, {-0.11321825330631577`, 0.9935701420223269, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.92895544545073, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29595435548692706`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.249665340154062, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3926154927590467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9935701420223269, 0.11321825330631577`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6946057131986, 0.011066496590403974`, 0.}, 
      Optica`Optica`RayEnd :> {4.422212158743575, 0.12678482713072758`, 0.}, 
      RotationMatrix :> {{-0.9203904230666321, 0.3910005999064781, 
       0.}, {-0.3910005999064781, -0.9203904230666321, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2772217142037861, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2959543554869271, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.687677786274714, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3062852140674474, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9203904230666321, 0.3910005999064781, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9920227327644295`, 0.18394201200307905`, 
       0.}, Optica`Optica`RayEnd :> {3.9208762860103477`, 
       0.26296014394196404`, 0.}, 
      RotationMatrix :> {{-0.669121263326238, 0.7431532378754055, 
       0.}, {-0.7431532378754055, -0.669121263326238, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3932057987025339, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10632818093451259`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.080341604424072, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3446207370521083, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.669121263326238, 0.7431532378754055, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9208762860103477`, 0.26296014394196404`, 
       0.}, Optica`Optica`RayEnd :> {3.774007014814893, 0.3790719956019406, 
       0.}, RotationMatrix :> {{-0.7844606483542546, 0.6201785961992098, 
       0.}, {-0.6201785961992098, -0.7844606483542546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.37864452946942234`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18722324886987857`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.357432012751493, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22630871180950718`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7844606483542546, 0.6201785961992098, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.774007014814893, 0.3790719956019406, 0.}, 
      Optica`Optica`RayEnd :> {3.615497598354153, 0.27943610944304614`, 0.}, 
      RotationMatrix :> {{-0.8466331901488637, -0.5321768891434107, 0.}, {
       0.5321768891434107, -0.8466331901488637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014022033641014977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18722324886987846`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.634522421078913, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19219943114675692`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8466331901488637, -0.5321768891434107, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.560781759415158, 0.27331809425780756`, 0.}, 
      Optica`Optica`RayEnd :> {2.289831266060674, 0.36065725145027167`, 0.}, 
      RotationMatrix :> {{-0.9517745152170292, 0.3067984227198519, 
       0.}, {-0.3067984227198519, -0.9517745152170292, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2500596948032183, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28467929012860815`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.65612368648348, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14144486928827724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9517745152170292, 0.3067984227198519, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.289831266060674, 0.36065725145027167`, 0.}, 
      Optica`Optica`RayEnd :> {2.1456962410064944`, 0.3837580623745752, 0.}, 
      RotationMatrix :> {{-0.9873986958724716, 0.15825237877941062`, 
       0.}, {-0.15825237877941062`, -0.9873986958724716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24309711641608542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14597449404854732`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.87216593767533, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42504658342537627`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9873986958724716, 0.15825237877941062`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1508630265649438`, -0.38625248209328467`, 
       0.}, Optica`Optica`RayEnd :> {
       2.1468470929130756`, -0.38777088348810573`, 0.}, 
      RotationMatrix :> {{-0.9353741967840518, -0.35365959903640376`, 0.}, {
       0.35365959903640376`, -0.9353741967840518, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.242060001609504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.004293397942423073, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.737934791660166, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29799885069007614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9353741967840518, -0.35365959903640376`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1468470929130756`, -0.38777088348810573`, 
       0.}, Optica`Optica`RayEnd :> {1.850524420653777, -0.5013247962187429, 
       0.}, RotationMatrix :> {{-0.9337844962275794, -0.35783587663201916`, 
       0.}, {0.35783587663201916`, -0.9337844962275794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24146099159531187`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31733518114342246`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.20759085975243, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1588053123770257, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9337844962275794, -0.35783587663201916`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.621793917817546, -0.19608559386754337`, 0.},
       Optica`Optica`RayEnd :> {2.4268272613564683`, -0.26458365317247373`, 
       0.}, RotationMatrix :> {{-0.9434657979925637, -0.33146989006281524`, 
       0.}, {0.33146989006281524`, -0.9434657979925637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24801478965239496`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20664941630731395`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.513652792604702, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40700052959136984`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9434657979925637, -0.33146989006281524`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4268272613564683`, -0.26458365317247373`, 
       0.}, Optica`Optica`RayEnd :> {2.131967869541339, -0.36053596551370937`,
        0.}, RotationMatrix :> {{-0.9509173889076586, -0.3094448569180631, 
       0.}, {0.3094448569180631, -0.9509173889076586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24733481050217856`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3100788725231343, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.97256952393894, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25407187421879324`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9509173889076586, -0.3094448569180631, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6527301356231905`, -0.40317480552400664`, 
       0.}, 
      Optica`Optica`RayEnd :> {3.6440775948960247`, -0.4154141300939811, 0.}, 
      RotationMatrix :> {{-0.5772627045571342, -0.8165584914305786, 0.}, {
       0.8165584914305786, -0.5772627045571342, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39415641145142666`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.014988913468441984`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 8.708750051308662, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13402888307773247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5772627045571342, -0.8165584914305786, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6440775948960247`, -0.4154141300939811, 0.},
       Optica`Optica`RayEnd :> {3.4519109865691275`, -0.6775846688198423, 0.},
       RotationMatrix :> {{-0.5911800248285837, -0.8065396321593097, 0.}, {
       0.8065396321593097, -0.5911800248285837, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39312627612022405`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.325055990148884, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 9.18983291672901, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.419015874056054, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5911800248285837, -0.8065396321593097, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.400554302185327, -0.02244093859622237, 0.}, 
      Optica`Optica`RayEnd :> {4.332719604913328, -0.07468346298845327, 0.}, 
      RotationMatrix :> {{-0.7922739759528378, -0.6101655078975557, 0.}, {
       0.6101655078975557, -0.7922739759528378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27801685647241575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08562025174487939, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.926384031371548, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06816741876586356, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7922739759528378, -0.6101655078975557, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.332719604913328, -0.07468346298845327, 0.}, 
      Optica`Optica`RayEnd :> {4.092110418388803, -0.2817319083055005, 0.}, 
      RotationMatrix :> {{-0.7579911961537824, -0.6522647825487422, 0.}, {
       0.6522647825487422, -0.7579911961537824, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.276861944470144, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31743005426109294`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.396180511677965, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11748060513014594`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7579911961537824, -0.6522647825487422, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6946057131986, 0.011066496590403974`, 0.}, 
      Optica`Optica`RayEnd :> {4.8241048464905125`, 0.02945966646765053, 0.}, 
      RotationMatrix :> {{0.9900633834899635, 0.14062182146596425`, 
       0.}, {-0.14062182146596425`, 0.9900633834899635, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.65173373124696, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1307988311166798, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.424935773850413, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012742916591336223`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 28, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9900633834899635, 0.14062182146596425`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8241048464905125`, 0.02945966646765053, 0.},
       Optica`Optica`RayEnd :> {5.136587594956282, 0.06878987295939466, 0.}, 
      RotationMatrix :> {{0.9921720597457364, 0.12487835625080448`, 
       0.}, {-0.12487835625080448`, 0.9921720597457364, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.40120163838044, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3149481437179856, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.891059026553032, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34853343095568107`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 28, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9921720597457364, 0.12487835625080448`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.136587594956282, 0.06878987295939468, 0.}, 
      Optica`Optica`RayEnd :> {4.849864850132244, -0.06152666793996342, 0.}, 
      RotationMatrix :> {{-0.9103808056756774, -0.413771420783631, 0.}, {
       0.413771420783631, -0.9103808056756774, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24988268568952332`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3149481437179855, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.357182279255651`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2728761681498907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 28, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9103808056756774, -0.413771420783631, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.422212158743575, 0.12678482713072758`, 0.}, 
      Optica`Optica`RayEnd :> {4.399096479845423, 0.13585950227795887`, 0.}, 
      RotationMatrix :> {{-0.9308403332153881, 0.36542615404410395`, 
       0.}, {-0.36542615404410395`, -0.9308403332153881, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27642884608225426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.024833129886308154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.720954180322366, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06984729830253202, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9308403332153881, 0.36542615404410395`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.399096479845423, 0.13585950227795887`, 0.}, 
      Optica`Optica`RayEnd :> {4.1360406816166115`, 0.2561933497483976, 0.}, 
      RotationMatrix :> {{-0.9093701777881628, 0.41598783605957174`, 
       0.}, {-0.41598783605957174`, -0.9093701777881628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2752680041887159, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28927251481749156`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.149077502252254`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.024483670967811073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9093701777881628, 0.41598783605957174`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9208762860103477`, 0.26296014394196404`, 
       0.}, Optica`Optica`RayEnd :> {3.9412780345169445`, 0.3897730672871572, 
       0.}, RotationMatrix :> {{0.15883823240493306`, 0.9873046216474813, 
       0.}, {-0.9873046216474813, 0.15883823240493306`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014561269233111584`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12844356297409484`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.25245597880936, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38193737398048777`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15883823240493306`, 0.9873046216474813, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9412780345169445`, 0.3897730672871572, 0.}, 
      Optica`Optica`RayEnd :> {3.9987729664076967`, 0.7106424299902512, 0.}, 
      RotationMatrix :> {{0.17637576291505594`, 0.9843229095455067, 
       0.}, {-0.9843229095455067, 0.17637576291505594`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014523045470901708`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3259797771559027, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 9.734906049000097, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24613225581910286`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17637576291505594`, 0.9843229095455067, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.774007014814893, 0.3790719956019406, 0.}, 
      Optica`Optica`RayEnd :> {3.618102085979958, 0.46427768108364853`, 0.}, 
      RotationMatrix :> {{-0.8775010050140475, 0.4795747972937451, 
       0.}, {-0.4795747972937451, -0.8775010050140475, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3646224958284075, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17766923108246344`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.595508782401994, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3715665650713764, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8775010050140475, 0.4795747972937451, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.618102085979958, 0.46427768108364853`, 0.}, 
      Optica`Optica`RayEnd :> {3.3555961043193907`, 0.5982774551320276, 0.}, 
      RotationMatrix :> {{-0.8906682424648924, 0.45465380441001435`, 
       0.}, {-0.45465380441001435`, -0.8906682424648924, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.36357353990223545`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2947292483833167, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.031708070009303`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3351117811344288, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8906682424648924, 0.45465380441001435`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.615497598354153, 0.27943610944304614`, 0.}, 
      Optica`Optica`RayEnd :> {3.4620287086386394`, 0.14210240451730616`, 0.},
       RotationMatrix :> {{-0.7451944166345312, -0.666847269932719, 0.}, {
       0.666847269932719, -0.7451944166345312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013502767120235534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2059447659425766, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.910488407441965, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21936585876489084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7451944166345312, -0.666847269932719, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4620287086386394`, 0.14210240451730616`, 
       0.}, Optica`Optica`RayEnd :> {3.290651511409753, -0.04093297677543393, 
       0.}, RotationMatrix :> {{-0.6834772628729329, -0.729971801603133, 
       0.}, {0.729971801603133, -0.6834772628729329, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01339630247316773, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2507430847202119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.28158817282788, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06738285776063474, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6834772628729329, -0.729971801603133, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1456962410064944`, 0.3837580623745752, 0.}, 
      Optica`Optica`RayEnd :> {2.137773631112005, 0.3838057059622634, 0.}, 
      RotationMatrix :> {{-0.9999819186606784, 0.006013514089774824, 
       0.}, {-0.006013514089774824, -0.9999819186606784, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2363284017295186, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007922753148477363, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.88278242689429, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18840259110947652`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999819186606784, 0.006013514089774824, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.137773631112005, 0.3838057059622634, 0.}, 
      Optica`Optica`RayEnd :> {1.9375366706374482`, 0.3992115048105958, 0.}, 
      RotationMatrix :> {{-0.9970533599238541, 0.07671112999137163, 
       0.}, {-0.07671112999137163, -0.9970533599238541, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23500628659526143`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20082873046017238`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.180008947975345`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24290061066354512`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9970533599238541, 0.07671112999137163, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.131967869541339, -0.36053596551370937`, 0.},
       Optica`Optica`RayEnd :> {2.1317647742058625`, -0.3605968720764497, 0.},
       RotationMatrix :> {{-0.9578548869787742, -0.2872525291287782, 0.}, {
       0.2872525291287782, -0.9578548869787742, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24665669564257717`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0002120314237963691, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.972853646046827, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21409910787816447`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9578548869787742, -0.2872525291287782, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1317647742058625`, -0.3605968720764497, 0.},
       Optica`Optica`RayEnd :> {1.842422203976989, -0.4570800530492261, 0.}, 
      RotationMatrix :> {{-0.9486482197923176, -0.3163329813422345, 0.}, {
       0.3163329813422345, -0.9486482197923176, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24592891512772325`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3050051264442551, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.424261233184325, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.019506742582937334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9486482197923176, -0.3163329813422345, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4519109865691275`, -0.6775846688198423, 0.},
       Optica`Optica`RayEnd :> {3.3743027929427307`, -0.7797432585536458, 0.},
       RotationMatrix :> {{-0.604923497177565, -0.796283594306993, 0.}, {
       0.796283594306993, -0.604923497177565, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39209883306744114`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12829422892068026`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.361747183482722, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.423259716504044, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.604923497177565, -0.796283594306993, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3743027929427307`, -0.7797432585536458, 0.},
       Optica`Optica`RayEnd :> {3.2171263394543335`, -0.945791594974529, 0.}, 
      RotationMatrix :> {{-0.687439187190562, -0.726241945851917, 0.}, {
       0.726241945851917, -0.687439187190562, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.38748365083341024`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.228640520379335, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 9.700135153644137, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24256034056857045`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.687439187190562, -0.726241945851917, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.092110418388803, -0.2817319083055005, 0.}, 
      Optica`Optica`RayEnd :> {4.023924522203216, -0.3471739477614017, 0.}, 
      RotationMatrix :> {{-0.721474117604436, -0.6924414037497325, 0.}, {
       0.6924414037497325, -0.721474117604436, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2757118300968718, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09450913694865332, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.52282275518916, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.111759557276061, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.721474117604436, -0.6924414037497325, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.023924522203216, -0.3471739477614017, 0.}, 
      Optica`Optica`RayEnd :> {3.8359760786024566`, -0.547303048019383, 0.}, 
      RotationMatrix :> {{-0.6845755755823887, -0.7289418915908461, 0.}, {
       0.7289418915908461, -0.6845755755823887, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27461136868058705`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27454739886223106`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.929152905505262, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17657179835465311`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6845755755823887, -0.7289418915908461, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8241048464905125`, 0.02945966646765053, 0.},
       Optica`Optica`RayEnd :> {4.69466225720908, 0.05463155987304365, 0.}, 
      RotationMatrix :> {{-0.9816118359488982, 0.19088793446688382`, 
       0.}, {-0.19088793446688382`, -0.9816118359488982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2505320928665387, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1318673884533026, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.601638074377838, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3934178451262893, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9816118359488982, 0.19088793446688382`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.69466225720908, 0.05463155987304365, 0.}, 
      Optica`Optica`RayEnd :> {4.40607822076775, 0.1010441468157273, 0.}, 
      RotationMatrix :> {{-0.9873126720810275, 0.15878818453594562`, 
       0.}, {-0.15878818453594562`, -0.9873126720810275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24977465691115894`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29229244655906383`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.034230895285253`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22217963939932622`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9873126720810275, 0.15878818453594562`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.136587594956282, 0.06878987295939468, 0.}, 
      Optica`Optica`RayEnd :> {5.438567307187545, 0.1019347427665358, 0.}, 
      RotationMatrix :> {{0.9940304078034512, 0.1091033838251799, 
       0.}, {-0.1091033838251799, 0.9940304078034512, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.15131895269093, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30379323395001484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.298141960046053`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23906828014549203`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 32, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9940304078034512, 0.1091033838251799, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.438567307187545, 0.1019347427665358, 0.}, 
      Optica`Optica`RayEnd :> {5.639921896520204, 0.11098310414783293`, 0.}, 
      RotationMatrix :> {{0.9989918395183365, 0.044892143809023996`, 
       0.}, {-0.044892143809023996`, 0.9989918395183365, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      95.67368665723663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20155779193325782`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.596447492107274`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2214592476354068, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 32, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9989918395183365, 0.044892143809023996`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.639921896520204, 0.11098310414783293`, 0.}, 
      Optica`Optica`RayEnd :> {5.554250872733547, -0.07146146050772646, 0.}, 
      RotationMatrix :> {{-0.42504446474103386`, -0.9051724714069733, 0.}, {
       0.9051724714069733, -0.42504446474103386`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.47525965395389297`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2015577919332577, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.894753024168494`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2035015634172836, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 32, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.42504446474103386`, -0.9051724714069733, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.849864850132244, -0.06152666793996342, 0.}, 
      Optica`Optica`RayEnd :> {4.788657960453038, -0.08818067542507846, 0.}, 
      RotationMatrix :> {{-0.9168381205189038, -0.399259139862025, 0.}, {
       0.399259139862025, -0.9168381205189038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24923496184846966`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06675866579867423, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.446638891425875`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.050590084903721244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9168381205189038, -0.399259139862025, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.788657960453038, -0.08818067542507849, 0.}, 
      Optica`Optica`RayEnd :> {4.563160363805937, -0.2095253732610226, 0.}, 
      RotationMatrix :> {{-0.88059672689059, -0.473866441721272, 0.}, {
       0.473866441721272, -0.88059672689059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24746780161251128`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2560736257143928, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.825627857483177`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08025064745371002, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.88059672689059, -0.473866441721272, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1360406816166115`, 0.2561933497483976, 0.}, 
      Optica`Optica`RayEnd :> {3.6179271192659637`, 0.5285467804054872, 0.}, 
      RotationMatrix :> {{-0.8851560421700713, 0.4652942950540173, 
       0.}, {-0.4652942950540173, -0.8851560421700713, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2741120371623301, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5853358477680699, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.933427538261467`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36973938896155384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8851560421700713, 0.4652942950540173, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6179271192659637`, 0.5285467804054872, 0.}, 
      Optica`Optica`RayEnd :> {3.3901148833251633`, 0.6267205401047594, 0.}, 
      RotationMatrix :> {{-0.9183551041269086, 0.3957573786097422, 
       0.}, {-0.3957573786097422, -0.9183551041269086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27238082007958386`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24806551944564428`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.30056450704102, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42831104982300866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9183551041269086, 0.3957573786097422, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9987729664076967`, 0.7106424299902512, 0.}, 
      Optica`Optica`RayEnd :> {4.032900255712351, 0.8833460304798999, 0.}, 
      RotationMatrix :> {{0.19385747833021866`, 0.9810297029628862, 
       0.}, {-0.9810297029628862, 0.19385747833021866`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014484922047197642`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.176043192135827, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.970803926462105, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2530598713774328, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19385747833021866`, 0.9810297029628862, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.032900255712351, 0.8833460304798999, 0.}, 
      Optica`Optica`RayEnd :> {4.087894069184557, 1.190572550681726, 0.}, 
      RotationMatrix :> {{0.1762002797858955, 0.9843543373213591, 
       0.}, {-0.9843543373213591, 0.1762002797858955, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014446851157553332`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3121096830211119, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.432726257333352`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08775795741922073, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1762002797858955, 0.9843543373213591, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3555961043193907`, 0.5982774551320276, 0.}, 
      Optica`Optica`RayEnd :> {3.3506237843433677`, 0.6006414315659845, 0.}, 
      RotationMatrix :> {{-0.9031279045372516, 0.4293716199822167, 
       0.}, {-0.4293716199822167, -0.9031279045372516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3625276016410393, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00550566531168221, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.039085661526958`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02532004483700924, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9031279045372516, 0.4293716199822167, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3506237843433677`, 0.6006414315659845, 0.}, 
      Optica`Optica`RayEnd :> {3.1189077061664916`, 0.7275798313596082, 0.}, 
      RotationMatrix :> {{-0.8770224926183509, 0.4804493182860131, 
       0.}, {-0.4804493182860131, -0.8770224926183509, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3609400849938371, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26420768010759665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.4301130280862, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.002899050341736653, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8770224926183509, 0.4804493182860131, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.290651511409753, -0.04093297677543392, 0.}, 
      Optica`Optica`RayEnd :> {3.221579882986132, -0.12916230350309768`, 0.}, 
      RotationMatrix :> {{-0.6164332830949181, -0.7874071421398339, 0.}, {
       0.7874071421398339, -0.6164332830949181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013290677263007516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11205045268943635`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.431735779431724`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.354227948066582, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6164332830949181, -0.7874071421398339, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.221579882986132, -0.12916230350309768`, 0.},
       Optica`Optica`RayEnd :> {3.1079744812692307`, -0.31578149969126973`, 
       0.}, RotationMatrix :> {{-0.5199840451850417, -0.8541759729429296, 
       0.}, {0.8541759729429296, -0.5199840451850417, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013103198876517008`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21847862981348537`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.755084151555682`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10590305690193888`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5199840451850417, -0.8541759729429296, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2171263394543335`, -0.945791594974529, 0.}, 
      Optica`Optica`RayEnd :> {3.109609326425071, -1.037191798066271, 0.}, 
      RotationMatrix :> {{-0.761901752869223, -0.6476926114869652, 0.}, {
       0.6476926114869652, -0.761901752869223, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3829227914008192, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1411166369211877, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.889231447118528, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3388389581834084, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.761901752869223, -0.6476926114869652, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.109609326425071, -1.037191798066271, 0.}, 
      Optica`Optica`RayEnd :> {2.9525382644923193`, -1.1376453192431852`, 0.},
       RotationMatrix :> {{-0.8424465876432952, -0.5387798687480512, 0.}, {
       0.5387798687480512, -0.8424465876432952, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3752210699497621, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1864463150977328, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.165171993463172`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3041121382895055, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8424465876432952, -0.5387798687480512, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8359760786024566`, -0.547303048019383, 0.}, 
      Optica`Optica`RayEnd :> {3.8081445731435055`, -0.5802043795349205, 0.}, 
      RotationMatrix :> {{-0.6458329320787934, -0.7634787645000404, 0.}, {
       0.7634787645000404, -0.6458329320787934, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2735152995869976, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04309397071061014, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.98689882625748, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1892807338968753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6458329320787934, -0.7634787645000404, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8081445731435055`, -0.5802043795349205, 0.},
       Optica`Optica`RayEnd :> {3.6479267674466245`, -0.7940552712029678, 0.},
       RotationMatrix :> {{-0.5995918841929333, -0.8003059242626956, 0.}, {
       0.8003059242626956, -0.5995918841929333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2722801779361296, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2672114315098484, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.382371744892056`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20395846594105088`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5995918841929333, -0.8003059242626956, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.40607822076775, 0.10104414681572732`, 0.}, 
      Optica`Optica`RayEnd :> {4.34698126031897, 0.10858164471908821`, 0.}, 
      RotationMatrix :> {{-0.9919641000130234, 0.1265196596792469, 
       0.}, {-0.1265196596792469, -0.9919641000130234, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24901951091879346`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05957570485464469, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.114062339790477`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11055091198386752`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9919641000130234, 0.1265196596792469, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.34698126031897, 0.10858164471908821`, 0.}, 
      Optica`Optica`RayEnd :> {4.170700334701458, 0.1634694739701575, 0.}, 
      RotationMatrix :> {{-0.9547878069669318, 0.2972881492210493, 
       0.}, {-0.2972881492210493, -0.9547878069669318, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23874988737056477`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18462837955325728`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.387312341529299`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3090955933492257, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9547878069669318, 0.2972881492210493, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.170700334701458, 0.1634694739701575, 0.}, 
      Optica`Optica`RayEnd :> {4.158904414755697, 0.3477206471254315, 0.}, 
      RotationMatrix :> {{-0.06389006919902085, 0.9979569424868711, 
       0.}, {-0.9979569424868711, -0.06389006919902085, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009846101843310104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1846283795532571, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.660562343268118`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2564554058148944, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.06389006919902085, 0.9979569424868711, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.438567307187545, 0.1019347427665358, 0.}, 
      Optica`Optica`RayEnd :> {5.369947045855445, 0.2389135007740329, 0.}, 
      RotationMatrix :> {{-0.4478968991145136, 0.8940852128089376, 
       0.}, {-0.8940852128089376, -0.4478968991145136, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.47763229545424635`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.153205484270512, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.50343730896854, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4175723766432237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.4478968991145136, 0.8940852128089376, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.369947045855445, 0.2389135007740329, 0.}, 
      Optica`Optica`RayEnd :> {5.256652686999513, 0.4008534369572916, 0.}, 
      RotationMatrix :> {{-0.5732463612250787, 0.8193830663018407, 
       0.}, {-0.8193830663018407, -0.5732463612250787, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4659181433095814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19763642042805413`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.79593921120206, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11521949459319769`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5732463612250787, 0.8193830663018407, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.256652686999513, 0.4008534369572916, 0.}, 
      Optica`Optica`RayEnd :> {5.072982639363519, 0.3278776308226116, 0.}, 
      RotationMatrix :> {{-0.9293330006594371, -0.36924270322557007`, 0.}, {
       0.36924270322557007`, -0.9293330006594371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01142685716529616, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19763642042805418`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.088441113435579`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24988721411724535`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9293330006594371, -0.36924270322557007`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.639921896520204, 0.11098310414783293`, 0.}, 
      Optica`Optica`RayEnd :> {5.656117764920519, 0.11066713884056856`, 0.}, 
      RotationMatrix :> {{0.9998097536305198, -0.019505295313812135`, 0.}, {
       0.019505295313812135`, 0.9998097536305198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      95.19842700328273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.016198950191778097`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.618154085364257`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39505696612238694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9998097536305198, -0.019505295313812135`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.656117764920519, 0.11066713884056857`, 0.}, 
      Optica`Optica`RayEnd :> {5.780139413390965, 0.1328722918237478, 0.}, 
      RotationMatrix :> {{0.9843472189495585, 0.1762400424031657, 
       0.}, {-0.1762400424031657, 0.9843472189495585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      89.56221790895778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474787`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.804624912124083`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10820121574341954`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9843472189495585, 0.1762400424031657, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.780139413390965, 0.1328722918237478, 0.}, 
      Optica`Optica`RayEnd :> {5.813078531240988, 0.25448418525360783`, 0.}, 
      RotationMatrix :> {{0.26143443060304344`, 0.9652212381082702, 
       0.}, {-0.9652212381082702, 0.26143443060304344`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.302518150525389, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474785`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.99109573888391, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33977318087657354`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26143443060304344`, 0.9652212381082702, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.813078531240988, 0.25448418525360783`, 0.}, 
      Optica`Optica`RayEnd :> {5.717216724786908, 0.33624574206176727`, 0.}, 
      RotationMatrix :> {{-0.7608454148957724, 0.6489331665372633, 
       0.}, {-0.6489331665372633, -0.7608454148957724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3139348197610793, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474793`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.177566565643737`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1863786948954282, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7608454148957724, 0.6489331665372633, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.717216724786908, 0.33624574206176727`, 0.}, 
      Optica`Optica`RayEnd :> {5.602324795163315, 0.28453227557864835`, 0.}, 
      RotationMatrix :> {{-0.9118855683625422, -0.4104445275699544, 0.}, {
       0.4104445275699544, -0.9118855683625422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018586465573654988`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474796`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.364037392403564`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27538787328100506`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9118855683625422, -0.4104445275699544, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.554250872733547, -0.07146146050772645, 0.}, 
      Optica`Optica`RayEnd :> {5.446013302160968, -0.26798629236588783`, 0.}, 
      RotationMatrix :> {{-0.4824282451602636, -0.8759354932137345, 0.}, {
       0.8759354932137345, -0.4824282451602636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.47289879856545575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2243599367541645, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.195395339419075`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.306869572752462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4824282451602636, -0.8759354932137345, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.446013302160968, -0.26798629236588783`, 0.},
       Optica`Optica`RayEnd :> {5.3289129465642615`, -0.373110817031439, 0.}, 
      RotationMatrix :> {{-0.7441334147530378, -0.6680310329977068, 0.}, {
       0.6680310329977068, -0.7441334147530378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29646093220014913`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15736473228469317`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.42829514320042, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12121326779677413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7441334147530378, -0.6680310329977068, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3289129465642615`, -0.373110817031439, 0.}, 
      Optica`Optica`RayEnd :> {5.173926973483606, -0.3458526601738012, 0.}, 
      RotationMatrix :> {{-0.9848837845081162, 0.173216428242157, 
       0.}, {-0.173216428242157, -0.9848837845081162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11060915040751881`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1573647322846933, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.661194946981766`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4049186434789684, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9848837845081162, 0.173216428242157, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.173926973483606, -0.3458526601738012, 0.}, 
      Optica`Optica`RayEnd :> {5.099721637990405, -0.2070822485170844, 0.}, 
      RotationMatrix :> {{-0.47154997448192115`, 0.8818393399968609, 
       0.}, {-0.8818393399968609, -0.47154997448192115`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04126811604846847, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15736473228469344`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.894094750763113`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.019105609878257376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.47154997448192115`, 0.8818393399968609, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.099721637990405, -0.2070822485170844, 0.}, 
      Optica`Optica`RayEnd :> {5.163112851191095, -0.06305026229187857, 0.}, 
      RotationMatrix :> {{0.40282986079757116`, 0.9152748785200047, 
       0.}, {-0.9152748785200047, 0.40282986079757116`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015397075159833136`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15736473228469341`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.12699455454446, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3813357873739703, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.40282986079757116`, 0.9152748785200047, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.563160363805937, -0.2095253732610226, 0.}, 
      Optica`Optica`RayEnd :> {4.435873312302021, -0.29231063265284085`, 0.}, 
      RotationMatrix :> {{-0.8382971024368879, -0.5452136902590744, 0.}, {
       0.5452136902590744, -0.8382971024368879, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24571317114074157`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15184002322553636`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.029093488605396`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.340267179967318, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8382971024368879, -0.5452136902590744, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.435873312302021, -0.29231063265284085`, 0.},
       Optica`Optica`RayEnd :> {4.2072759558879405`, -0.40840447476237973`, 
       0.}, RotationMatrix :> {{-0.8916089465832205, -0.45280623490932603`, 
       0.}, {0.45280623490932603`, -0.8916089465832205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24290961227306532`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2563874636858447, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.408546934860446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37757037488619244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8916089465832205, -0.45280623490932603`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3901148833251633`, 0.6267205401047594, 0.}, 
      Optica`Optica`RayEnd :> {3.3831584032670334`, 0.629101891221183, 0.}, 
      RotationMatrix :> {{-0.9461013771261277, 0.32387062880113826`, 
       0.}, {-0.32387062880113826`, -0.9461013771261277, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27066053689313274`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007352785046419563, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.310417239003222`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1665292357658861, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9461013771261277, 0.32387062880113826`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3831584032670334`, 0.629101891221183, 0.}, 
      Optica`Optica`RayEnd :> {3.118958057251666, 0.730693687402561, 0.}, 
      RotationMatrix :> {{-0.9333736819997513, 0.3589060737159891, 
       0.}, {-0.3589060737159891, -0.9333736819997513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26979268882356827`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.283059562435185, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.729345391407296`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.013267977284063037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9333736819997513, 0.3589060737159891, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.087894069184557, 1.190572550681726, 0.}, 
      Optica`Optica`RayEnd :> {4.096974615643519, 1.2471439068332988`, 0.}, 
      RotationMatrix :> {{0.1584861985309714, 0.987361192712779, 
       0.}, {-0.987361192712779, 0.1584861985309714, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014408880330072529`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.057295502972061034`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 10.509502231315913`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07149724037825003, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1584861985309714, 0.987361192712779, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.096974615643519, 1.2471439068332988`, 0.}, 
      Optica`Optica`RayEnd :> {4.1566020874311045`, 1.3948686334667941`, 0.}, 
      RotationMatrix :> {{0.3742979428517587, 0.9273084977379111, 
       0.}, {-0.9273084977379111, 0.3742979428517587, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013097169104803217`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15930483436079493`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.74527338616989, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39498665502861907`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3742979428517587, 0.9273084977379111, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1189077061664916`, 0.7275798313596082, 0.}, 
      Optica`Optica`RayEnd :> {2.962953264961906, 0.8250378530382365, 0.}, 
      RotationMatrix :> {{-0.8480313050205771, 0.5299461347204043, 
       0.}, {-0.5299461347204043, -0.8480313050205771, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.35935952011828964`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18390175018456614`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.676541373333519`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38195710108162617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8480313050205771, 0.5299461347204043, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.962953264961906, 0.8250378530382365, 0.}, 
      Optica`Optica`RayEnd :> {2.8527497331871134`, 0.9455596562108208, 0.}, 
      RotationMatrix :> {{-0.6748097851451538, 0.7379917031189114, 
       0.}, {-0.7379917031189114, -0.6748097851451538, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29663190931406896`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16331051238548253`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.918240931664034`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12678825010796402`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6748097851451538, 0.7379917031189114, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8527497331871134`, 0.9455596562108208, 0.}, 
      Optica`Optica`RayEnd :> {2.88965565168125, 1.1046454086706592`, 0.}, 
      RotationMatrix :> {{0.22598617783417996`, 0.9741305084165561, 
       0.}, {-0.9741305084165561, 0.22598617783417996`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.051778260816468594`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16331051238548247`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.159940489994549`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3267829882867522, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22598617783417996`, 0.9741305084165561, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.88965565168125, 1.1046454086706592`, 0.}, 
      Optica`Optica`RayEnd :> {3.0416663960619714`, 1.164336756858046, 0.}, 
      RotationMatrix :> {{0.9308080794083295, 0.36550830265286244`, 
       0.}, {-0.36550830265286244`, 0.9308080794083295, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009038098090585665, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16331051238548244`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.401640048325064`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20088390683858276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9308080794083295, 0.36550830265286244`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1079744812692307`, -0.31578149969126973`, 
       0.}, Optica`Optica`RayEnd :> {3.0979082551464243`, -0.3377617363851812,
        0.}, RotationMatrix :> {{-0.416379550046603, -0.9091908877144492, 
       0.}, {0.9091908877144492, -0.416379550046603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012918365061458454`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02417560161559255, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.787479457720575`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07101695824818587, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.416379550046603, -0.9091908877144492, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0979082551464243`, -0.3377617363851812, 0.},
       Optica`Optica`RayEnd :> {2.964069326973405, -0.6132710566160591, 0.}, 
      RotationMatrix :> {{-0.436957098991212, -0.8994823475984306, 0.}, {
       0.8994823475984306, -0.436957098991212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012883102638388119`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30629763993309367`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.240799964821553`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3451523158640592, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.436957098991212, -0.8994823475984306, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9525382644923193`, -1.1376453192431852`, 
       0.}, Optica`Optica`RayEnd :> {2.9202939341265974`, -1.15256709084685, 
       0.}, RotationMatrix :> {{-0.9075329858758598, -0.4199808085463499, 
       0.}, {0.4199808085463499, -0.9075329858758598, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3676742531286771, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03552965111742231, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 10.212781725960518`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22381684908110722`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9075329858758598, -0.4199808085463499, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9202939341265974`, -1.15256709084685, 0.}, 
      Optica`Optica`RayEnd :> {2.6545398615910583`, -1.280178969740208, 0.}, 
      RotationMatrix :> {{-0.9014569821761123, -0.4328686975122316, 0.}, {
       0.4328686975122316, -0.9014569821761123, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.36673044716996733`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29480505203255547`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.6490932029687, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1536074871725836, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9014569821761123, -0.4328686975122316, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6479267674466245`, -0.7940552712029678, 0.},
       Optica`Optica`RayEnd :> {3.63352257300137, -0.8158563100177105, 0.}, 
      RotationMatrix :> {{-0.5512555779337724, -0.8343364356162939, 0.}, {
       0.8343364356162939, -0.5512555779337724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27105063376299215`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.026129793551013997`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.417385668250414`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01810937399030649, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5512555779337724, -0.8343364356162939, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.63352257300137, -0.8158563100177105, 0.}, 
      Optica`Optica`RayEnd :> {3.4528534018009265`, -1.0906598151282794`, 0.},
       RotationMatrix :> {{-0.5493562808388661, -0.8355882219747287, 0.}, {
       0.8355882219747287, -0.5493562808388661, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2703818851158309, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3288743161806797, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.904119656197821`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4117163466854287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5493562808388661, -0.8355882219747287, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.34698126031897, 0.10858164471908821`, 0.}, 
      Optica`Optica`RayEnd :> {4.172131662576525, -0.04731871164326101, 0.}, 
      RotationMatrix :> {{-0.746394203533001, -0.6655040893430612, 0.}, {
       0.6655040893430612, -0.746394203533001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010269623548228695`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23425905093422206`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.427969468042335`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2745418560488449, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.746394203533001, -0.6655040893430612, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.172131662576525, -0.04731871164326101, 0.}, 
      Optica`Optica`RayEnd :> {4.0215053031803265`, -0.13656884224374358`, 
       0.}, RotationMatrix :> {{-0.8603164176767244, -0.5097603961430193, 
       0.}, {0.5097603961430193, -0.8603164176767244, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009694321865884491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1750825118541425, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.687091585586465`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2650220322688981, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8603164176767244, -0.5097603961430193, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.170700334701458, 0.1634694739701575, 0.}, 
      Optica`Optica`RayEnd :> {3.9039351419317736`, 0.3012815070009306, 0.}, 
      RotationMatrix :> {{-0.888448519270324, 0.4589762832722063, 
       0.}, {-0.4589762832722063, -0.888448519270324, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2289037855272547, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3002595952197393, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.78966019912375, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24035121676729038`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.888448519270324, 0.4589762832722063, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9039351419317736`, 0.3012815070009306, 0.}, 
      Optica`Optica`RayEnd :> {3.7095927179649006`, 0.3694555953323202, 0.}, 
      RotationMatrix :> {{-0.9436246080317363, 0.3310175208609837, 
       0.}, {-0.3310175208609837, -0.9436246080317363, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22394480345779205`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2059531113460924, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.094470803915966`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3834156906957767, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9436246080317363, 0.3310175208609837, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.158904414755697, 0.34772064712543155`, 0.}, 
      Optica`Optica`RayEnd :> {4.186709549300818, 0.5970566748280117, 0.}, 
      RotationMatrix :> {{0.1108297056567604, 0.9938394117482137, 
       0.}, {-0.9938394117482137, 0.1108297056567604, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009440046273707401, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.250881605976951, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.996743695277233`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41804244091325343`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1108297056567604, 0.9938394117482137, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.186709549300818, 0.5970566748280117, 0.}, 
      Optica`Optica`RayEnd :> {4.232349480833086, 0.9075335520499724, 0.}, 
      RotationMatrix :> {{0.14543649567760558`, 0.9893675887783152, 
       0.}, {-0.9893675887783152, 0.14543649567760558`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009410693493085256, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31381347109353125`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.46118763249566, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3214196086825758, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14543649567760558`, 0.9893675887783152, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.369947045855445, 0.2389135007740329, 0.}, 
      Optica`Optica`RayEnd :> {5.4363474180854485`, 0.33981791682190754`, 0.},
       RotationMatrix :> {{0.5497082970382567, 0.8353566832002361, 
       0.}, {-0.8353566832002361, 0.5497082970382567, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01171415214466485, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12079201385127093`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.665298607529243`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3735805626744669, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5497082970382567, 0.8353566832002361, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.4363474180854485`, 0.33981791682190754`, 
       0.}, Optica`Optica`RayEnd :> {5.618099162223654, 0.631822219651038, 
       0.}, RotationMatrix :> {{0.5284280107905021, 0.8489781136236629, 
       0.}, {-0.8489781136236629, 0.5284280107905021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011681430313760297`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34394797479852446`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.174341610231059`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1332284997693361, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5284280107905021, 0.8489781136236629, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.256652686999513, 0.4008534369572916, 0.}, 
      Optica`Optica`RayEnd :> {5.169280136629371, 0.4934251559499546, 0.}, 
      RotationMatrix :> {{-0.68638974683991, 0.7272338794590391, 
       0.}, {-0.7272338794590391, -0.68638974683991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.45449128614428513`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12729291306054602`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.966511714703191`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32782586539922676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.68638974683991, 0.7272338794590391, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.169280136629371, 0.4934251559499546, 0.}, 
      Optica`Optica`RayEnd :> {4.9705929431190015`, 0.6843149737851442, 0.}, 
      RotationMatrix :> {{-0.7211150838502431, 0.6928152970623966, 
       0.}, {-0.6928152970623966, -0.7211150838502431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.45276369280189577`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27552771805787307`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.374292737428844`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.390346966988952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7211150838502431, 0.6928152970623966, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.072982639363519, 0.3278776308226116, 0.}, 
      Optica`Optica`RayEnd :> {4.8388393340441525`, 0.1924932213145497, 0.}, 
      RotationMatrix :> {{-0.8657022896828663, -0.5005592328964099, 0.}, {
       0.5005592328964099, -0.8657022896828663, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01114660822768542, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27046631169837904`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.450865971111407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19287556528403926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8657022896828663, -0.5005592328964099, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8388393340441525`, 0.1924932213145497, 0.}, 
      Optica`Optica`RayEnd :> {4.698679316809952, 0.14323389961481361`, 0.}, 
      RotationMatrix :> {{-0.9434308533947554, -0.33156933643333675`, 0.}, {
       0.33156933643333675`, -0.9434308533947554, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0105900679858363, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1485641652802231, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.670740935726137`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3470922515716134, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9434308533947554, -0.33156933643333675`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.656117764920519, 0.11066713884056856`, 0.}, 
      Optica`Optica`RayEnd :> {6.050783306785948, -0.26091767258249676`, 0.}, 
      RotationMatrix :> {{0.7280757873521932, -0.6854966432240815, 0.}, {
       0.6854966432240815, 0.7280757873521932, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.636209094324948, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5420665660380165, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.3445232838552, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05368274216917744, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7280757873521932, -0.6854966432240815, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.050783306785948, -0.26091767258249676`, 0.},
       Optica`Optica`RayEnd :> {6.266462557308947, -0.4372999424005015, 0.}, 
      RotationMatrix :> {{0.7741025248562585, -0.6330602506959078, 0.}, {
       0.6330602506959078, 0.7741025248562585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.60526256904622, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2786184563382585, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.756878599235822`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10727442243556647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7741025248562585, -0.6330602506959078, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.266462557308947, -0.4372999424005015, 0.}, 
      Optica`Optica`RayEnd :> {6.340928797522072, -0.1688171249226691, 0.}, 
      RotationMatrix :> {{0.2672695886403147, 0.9636217966547025, 
       0.}, {-0.9636217966547025, 0.2672695886403147, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03077660833441297, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2786184563382585, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.169233914616445`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15960082820150506`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2672695886403147, 0.9636217966547025, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.780139413390965, 0.1328722918237478, 0.}, 
      Optica`Optica`RayEnd :> {6.078954373256245, 0.25009272336775246`, 0.}, 
      RotationMatrix :> {{0.9309328551471545, 0.3651903876166055, 
       0.}, {-0.3651903876166055, 0.9309328551471545, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      84.25969975843235, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.320984438580208, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.234744059821562`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13626747688806312`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9309328551471545, 0.3651903876166055, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.078954373256245, 0.2500927233677525, 0.}, 
      Optica`Optica`RayEnd :> {6.385877384362597, 0.3672198357910872, 0.}, 
      RotationMatrix :> {{0.9342809324260642, 0.3565377109158069, 
       0.}, {-0.3565377109158069, 0.9342809324260642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      84.04839455874071, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3285125495490519, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.72094263315416, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2798838489145635, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9342809324260642, 0.3565377109158069, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.385877384362597, 0.3672198357910872, 0.}, 
      Optica`Optica`RayEnd :> {6.10438412011554, 0.19786211558100952`, 0.}, 
      RotationMatrix :> {{-0.8568721792621364, -0.5155289210185561, 0.}, {
       0.5155289210185561, -0.8568721792621364, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21077529171018483`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32851254954905174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.207141206486757`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2946360043839924, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8568721792621364, -0.5155289210185561, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.813078531240988, 0.25448418525360783`, 0.}, 
      Optica`Optica`RayEnd :> {5.826683256183537, 0.45472933508594915`, 0.}, 
      RotationMatrix :> {{0.06778408503872654, 0.9977000139397925, 
       0.}, {-0.9977000139397925, 0.06778408503872654, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.988583330764308, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20070677261153702`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.26004281418337, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2615144857211294, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.06778408503872654, 0.9977000139397925, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.826683256183537, 0.45472933508594915`, 0.}, 
      Optica`Optica`RayEnd :> {5.865410312505054, 0.6554846140465254, 0.}, 
      RotationMatrix :> {{0.18941463488272425`, 0.981897192221387, 
       0.}, {-0.981897192221387, 0.18941463488272425`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.9103689088356735`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20445651596823403`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.562638457816357`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4012676849529541, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.18941463488272425`, 0.981897192221387, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.865410312505054, 0.6554846140465254, 0.}, 
      Optica`Optica`RayEnd :> {6.068810334202852, 0.6347265289902424, 0.}, 
      RotationMatrix :> {{0.9948326700891261, -0.10152811691023872`, 0.}, {
       0.10152811691023872`, 0.9948326700891261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07698812271861409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20445651596823386`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.865234101449342`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1568425033036861, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9948326700891261, -0.10152811691023872`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.717216724786908, 0.33624574206176727`, 0.}, 
      Optica`Optica`RayEnd :> {5.623040498948695, 0.3888634059114886, 0.}, 
      RotationMatrix :> {{-0.8729838495118031, 0.4877491142908955, 
       0.}, {-0.4877491142908955, -0.8729838495118031, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2953483541874244, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1078785431034938, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.322123813402419`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1527130991181252, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8729838495118031, 0.4877491142908955, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.623040498948695, 0.3888634059114886, 0.}, 
      Optica`Optica`RayEnd :> {5.324433384014403, 0.5643586341087806, 0.}, 
      RotationMatrix :> {{-0.8621310028322385, 0.5066854388626915, 
       0.}, {-0.5066854388626915, -0.8621310028322385, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29454855432140103`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3463593281685959, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.83473561909194, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16006185115881488`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8621310028322385, 0.5066854388626915, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.602324795163315, 0.28453227557864835`, 0.}, 
      Optica`Optica`RayEnd :> {5.11645815730649, -0.0620488094172342, 0.}, 
      RotationMatrix :> {{-0.8141030179567975, -0.5807204802257572, 0.}, {
       0.5807204802257572, -0.8141030179567975, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017486056569061072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5968122303197364, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.16376578103201, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22465539936752438`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8141030179567975, -0.5807204802257572, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.11645815730649, -0.0620488094172342, 0.}, 
      Optica`Optica`RayEnd :> {4.960778241183477, -0.13227393548212463`, 0.}, 
      RotationMatrix :> {{-0.9115504669414317, -0.4111882126458123, 0.}, {
       0.4111882126458123, -0.9115504669414317, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01646435116614683, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17078584430478472`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.416528830603092`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3087958313064085, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9115504669414317, -0.4111882126458123, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.446013302160968, -0.26798629236588783`, 0.},
       Optica`Optica`RayEnd :> {5.408512329344934, -0.4038070907651124, 0.}, 
      RotationMatrix :> {{-0.266147729902546, -0.96393225170015, 0.}, {
       0.96393225170015, -0.266147729902546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17643786636530676`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.140902846812801, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.384205154148228`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4189919327987829, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.266147729902546, -0.96393225170015, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.408512329344934, -0.4038070907651124, 0.}, 
      Optica`Optica`RayEnd :> {5.368665699292367, -0.6386508757579388, 0.}, 
      RotationMatrix :> {{-0.16728206915382476`, -0.9859090776230914, 0.}, {
       0.9859090776230914, -0.16728206915382476`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17463190914910087`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23820024617179367`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.736741518482482`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3055436864776241, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.16728206915382476`, -0.9859090776230914, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3289129465642615`, -0.373110817031439, 0.}, 
      Optica`Optica`RayEnd :> {5.142156563325427, -0.4511357329145888, 0.}, 
      RotationMatrix :> {{-0.9227085679539582, -0.3854982472390188, 0.}, {
       0.3854982472390188, -0.9227085679539582, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18585178179263037`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20240018324849182`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.6995113887534, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2862376263562592, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9227085679539582, -0.3854982472390188, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.142156563325427, -0.4511357329145888, 0.}, 
      Optica`Optica`RayEnd :> {4.862033541413417, -0.5694760611249675, 0.}, 
      RotationMatrix :> {{-0.9211715769080618, -0.38915668553516414`, 0.}, {
       0.38915668553516414`, -0.9211715769080618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18539225864127637`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30409429571443264`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.14957094641076, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17695851153888617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9211715769080618, -0.38915668553516414`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.173926973483606, -0.3458526601738012, 0.}, 
      Optica`Optica`RayEnd :> {4.873260489996408, -0.17770917402864797`, 0.}, 
      RotationMatrix :> {{-0.8727901801440048, 0.48809558638057327`, 
       0.}, {-0.48809558638057327`, -0.8727901801440048, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0693410343590504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.344488847752149, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.122810002969645`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3149851727870629, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8727901801440048, 0.48809558638057327`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.873260489996408, -0.17770917402864797`, 0.},
       Optica`Optica`RayEnd :> {4.6598052417380575`, -0.08667403832027229, 
       0.}, RotationMatrix :> {{-0.9198389811837516, 0.39229612373159883`, 
       0.}, {-0.39229612373159883`, -0.9198389811837516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06854912906343096, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2320571889480614, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.466254642612776`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3985446421528405, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9198389811837516, 0.39229612373159883`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.099721637990405, -0.2070822485170844, 0.}, 
      Optica`Optica`RayEnd :> {5.082806838587439, -0.09899688104197428, 0.}, 
      RotationMatrix :> {{-0.15461298102288035`, 0.9879751141092664, 
       0.}, {-0.9879751141092664, -0.15461298102288035`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02587104088863533, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10940090082386048`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.040691957867086`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0751790541254807, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.15461298102288035`, 0.9879751141092664, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.082806838587439, -0.0989968810419743, 0.}, 
      Optica`Optica`RayEnd :> {5.023892590390386, 0.17942858185625338`, 0.}, 
      RotationMatrix :> {{-0.20701426751819224`, 0.9783379237481832, 
       0.}, {-0.9783379237481832, -0.20701426751819224`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025765386163769534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2845902792273769, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.461885571123604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13149199614344578`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20701426751819224`, 0.9783379237481832, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.163112851191095, -0.0630502622918786, 0.}, 
      Optica`Optica`RayEnd :> {5.5353880389761905`, 0.33622452132097363`, 0.},
       RotationMatrix :> {{0.6819448888048971, 0.7314035607193039, 
       0.}, {-0.7314035607193039, 0.6819448888048971, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009652448407327154, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5459021599787984, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.85850344891605, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13623023485727218`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.6819448888048971, 0.7314035607193039, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5353880389761905`, 0.33622452132097363`, 
       0.}, Optica`Optica`RayEnd :> {5.668226346046645, 0.5234462570138415, 
       0.}, RotationMatrix :> {{0.5786637668296475, 0.815566211265844, 
       0.}, {-0.815566211265844, 0.5786637668296475, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00946646097670723, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22956043679431032`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.19825289537163, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4090873832053674, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5786637668296475, 0.815566211265844, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.2072759558879405`, -0.40840447476237973`, 
       0.}, Optica`Optica`RayEnd :> {4.122525323515495, -0.44061256833959456`,
        0.}, RotationMatrix :> {{-0.9347731302688989, -0.3552452602460506, 
       0.}, {0.3552452602460506, -0.9347731302688989, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24013804168785682`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09066438649992627, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.530037212770347`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3202977342459794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9347731302688989, -0.3552452602460506, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.122525323515495, -0.44061256833959456`, 0.},
       Optica`Optica`RayEnd :> {3.836599226409276, -0.5489259410795577, 0.}, 
      RotationMatrix :> {{-0.93515074200629, -0.3542500384263707, 0.}, {
       0.3542500384263707, -0.93515074200629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2395460462025737, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30575401832306526`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.982553159888484`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18187936175766015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.93515074200629, -0.3542500384263707, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.118958057251666, 0.730693687402561, 0.}, 
      Optica`Optica`RayEnd :> {2.874401641472924, 0.8353535702065428, 0.}, 
      RotationMatrix :> {{-0.919349085961141, 0.3934428270313421, 
       0.}, {-0.3934428270313421, -0.919349085961141, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26892762342886484`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2660103974792871, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.08579932402954, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12633756237227736`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.919349085961141, 0.3934428270313421, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.874401641472924, 0.8353535702065428, 0.}, 
      Optica`Optica`RayEnd :> {2.700765721031118, 0.872423121498889, 0.}, 
      RotationMatrix :> {{-0.9779615411699503, 0.20878511439395192`, 
       0.}, {-0.20878511439395192`, -0.9779615411699503, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2536702204654676, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17754882286483611`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.348571581869498`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38599837952821525`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9779615411699503, 0.20878511439395192`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.700765721031118, 0.872423121498889, 0.}, 
      Optica`Optica`RayEnd :> {2.594207019314376, 0.7304061239629206, 0.}, 
      RotationMatrix :> {{-0.6001656333022449, -0.7998757482277578, 0.}, {
       0.7998757482277578, -0.6001656333022449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014391785879441892`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17754882286483611`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.611343839709455`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.037463767002821335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6001656333022449, -0.7998757482277578, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1566020874311045`, 1.3948686334667941`, 0.},
       Optica`Optica`RayEnd :> {4.288513573205669, 1.5843620745615243`, 0.}, 
      RotationMatrix :> {{0.5713270289417913, 0.8207225024334021, 
       0.}, {-0.8207225024334021, 0.5713270289417913, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011904869402086862`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23088612842086265`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.054660798253845`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24351973363473522`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5713270289417913, 0.8207225024334021, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.288513573205669, 1.5843620745615243`, 0.}, 
      Optica`Optica`RayEnd :> {4.434230233882032, 1.8265236218852379`, 0.}, 
      RotationMatrix :> {{0.515587347952126, 0.8568370245453295, 
       0.}, {-0.8568370245453295, 0.515587347952126, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01184349004149321, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28262264629870976`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.472942314775937`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2717869671677527, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.515587347952126, 0.8568370245453295, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.962953264961906, 0.8250378530382365, 0.}, 
      Optica`Optica`RayEnd :> {2.872577200713656, 0.8371273671687086, 0.}, 
      RotationMatrix :> {{-0.9911712418568374, 0.13258796821723612`, 
       0.}, {-0.13258796821723612`, -0.9911712418568374, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06272761080422067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09118107995036416, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.798724020467008`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1188548633701251, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9911712418568374, 0.13258796821723612`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.872577200713656, 0.8371273671687086, 0.}, 
      Optica`Optica`RayEnd :> {2.647719817861916, 0.8400449151302908, 0.}, 
      RotationMatrix :> {{-0.9999158339632128, 0.012974012087726763`, 
       0.}, {-0.012974012087726763`, -0.9999158339632128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06179549669042663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22487630979950307`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.131540958970271`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37002308138249973`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9999158339632128, 0.012974012087726763`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8527497331871134`, 0.9455596562108208, 0.}, 
      Optica`Optica`RayEnd :> {2.799054144884693, 1.0514884273813996`, 0.}, 
      RotationMatrix :> {{-0.45213236476252294`, 0.8919508533177425, 
       0.}, {-0.8919508533177425, -0.45213236476252294`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2448536484976005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11876077115298585`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.077380365009034`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14629085791748353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45213236476252294`, 0.8919508533177425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.799054144884693, 1.0514884273813996`, 0.}, 
      Optica`Optica`RayEnd :> {2.651432219296955, 1.3603774696099153`, 0.}, 
      RotationMatrix :> {{-0.43119965194147714`, 0.9022565378901662, 
       0.}, {-0.9022565378901662, -0.43119965194147714`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24418185216005425`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3423516807656731, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.58406085254223, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3934674176173692, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.43119965194147714`, 0.9022565378901662, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.88965565168125, 1.1046454086706592`, 0.}, 
      Optica`Optica`RayEnd :> {2.8897054905365716`, 1.104736744939623, 0.}, 
      RotationMatrix :> {{0.47899339421294007`, 0.8778185053303256, 
       0.}, {-0.8778185053303256, 0.47899339421294007`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04274016272588291, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.00010404914957834294`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.160079915854984`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1534480098790993, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.47899339421294007`, 0.8778185053303256, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8897054905365716`, 1.104736744939623, 0.}, 
      Optica`Optica`RayEnd :> {2.9294255861950274`, 1.2662841266646672`, 0.}, 
      RotationMatrix :> {{0.23876164803439073`, 0.9710782025294882, 
       0.}, {-0.9710782025294882, 0.23876164803439073`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.036462914946855426`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16635877656839743`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.406290905176213`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3566203076408562, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.23876164803439073`, 0.9710782025294882, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.964069326973405, -0.6132710566160591, 0.}, 
      Optica`Optica`RayEnd :> {2.9168138999373223`, -0.7051666635248719, 0.}, 
      RotationMatrix :> {{-0.45730843905955176`, -0.8893081533219607, 0.}, {
       0.8893081533219607, -0.45730843905955176`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012847936468866497`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10333381805344069`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.379267281013163`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2745597872243769, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45730843905955176`, -0.8893081533219607, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9168138999373223`, -0.7051666635248719, 0.},
       Optica`Optica`RayEnd :> {2.7903414601329137`, -0.9150460813852921, 0.},
       RotationMatrix :> {{-0.5161295742032981, -0.8565105151909823, 0.}, {
       0.8565105151909823, -0.5161295742032981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012780536450395506`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2450400948243138, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.741926621353148`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24117763257177255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5161295742032981, -0.8565105151909823, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6545398615910583`, -1.280178969740208, 0.}, 
      Optica`Optica`RayEnd :> {2.503822008840952, -1.3552129096803736`, 0.}, 
      RotationMatrix :> {{-0.8951979687337348, -0.4456687074217739, 0.}, {
       0.4456687074217739, -0.8951979687337348, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3657890639256037, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16836259465970213`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 10.874699079812702`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17703669313984083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8951979687337348, -0.4456687074217739, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.503822008840952, -1.3552129096803736`, 0.}, 
      Optica`Optica`RayEnd :> {2.335531677235352, -1.4663065767668944`, 0.}, 
      RotationMatrix :> {{-0.8345591361865511, -0.5509183680070552, 0.}, {
       0.5509183680070552, -0.8345591361865511, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.36018625998912585`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20165177554054278`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.173143707612706`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11991566619494523`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8345591361865511, -0.5509183680070552, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4528534018009265`, -1.0906598151282794`, 
       0.}, Optica`Optica`RayEnd :> {
       3.3747794230132278`, -1.2100033118374303`, 0.}, 
      RotationMatrix :> {{-0.5474541412105977, -0.8368356847502183, 0.}, {
       0.8368356847502183, -0.5474541412105977, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26971478643623065`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1426128197972019, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.09522083472607, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3780422879275489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5474541412105977, -0.8368356847502183, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3747794230132278`, -1.2100033118374303`, 
       0.}, Optica`Optica`RayEnd :> {3.2175576221075644`, -1.407368696474002, 
       0.}, RotationMatrix :> {{-0.6230734386558696, -0.7821633397453182, 
       0.}, {0.7821633397453182, -0.6230734386558696, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26736266828727917`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2523326965194204, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.468673225574813`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23443997703986008`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6230734386558696, -0.7821633397453182, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.0215053031803265`, -0.1365688422437436, 0.},
       Optica`Optica`RayEnd :> {3.8714170205849907`, -0.1899383071354556, 0.},
       RotationMatrix :> {{-0.9422052929995457, -0.3350360963293958, 0.}, {
       0.3350360963293958, -0.9422052929995457, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009151248436518955, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15929467145904477`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.900546445341586`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3357216018531316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9422052929995457, -0.3350360963293958, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8714170205849907`, -0.1899383071354556, 0.},
       Optica`Optica`RayEnd :> {3.5497612598705612`, -0.30326694863810244`, 
       0.}, RotationMatrix :> {{-0.943171414727655, -0.3323066090835899, 
       0.}, {0.3323066090835899, -0.943171414727655, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00912865539563651, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3410363754581229, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.405280281019609`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17915321385408342`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.943171414727655, -0.3323066090835899, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7095927179649006`, 0.3694555953323202, 0.}, 
      Optica`Optica`RayEnd :> {3.5830711532181354`, 0.39482902294536726`, 0.},
       RotationMatrix :> {{-0.9804775398039611, 0.19663111132262778`, 
       0.}, {-0.19663111132262778`, -0.9804775398039611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21909325300248375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12904075780467364`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.267385419374229`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1583783172010458, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9804775398039611, 0.19663111132262778`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5830711532181354`, 0.39482902294536726`, 
       0.}, Optica`Optica`RayEnd :> {3.3199501454438773`, 
       0.46261288869489703`, 0.}, 
      RotationMatrix :> {{-0.9683826067583299, 0.24946969140146397`, 
       0.}, {-0.24946969140146397`, -0.9683826067583299, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.218184456874832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27171182747184813`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.669518924032564`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10941940776492415`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9683826067583299, 0.24946969140146397`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.232349480833086, 0.9075335520499725, 0.}, 
      Optica`Optica`RayEnd :> {4.269784719445412, 1.1122674644837052`, 0.}, 
      RotationMatrix :> {{0.17986619827761616`, 0.9836910850044117, 
       0.}, {-0.9836910850044117, 0.17986619827761616`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009381431981690535, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20812825850995134`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.740079498898995`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20467872675588336`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17986619827761616`, 0.9836910850044117, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.269784719445412, 1.1122674644837052`, 0.}, 
      Optica`Optica`RayEnd :> {4.316627609022407, 1.4150762881589727`, 0.}, 
      RotationMatrix :> {{0.15287621745698116`, 0.9882453451122576, 
       0.}, {-0.9882453451122576, 0.15287621745698116`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009354671397241844, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3064105742292875, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.19356714875834, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.057270820678346254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15287621745698116`, 0.9882453451122576, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.618099162223654, 0.631822219651038, 0.}, 
      Optica`Optica`RayEnd :> {5.645647895609862, 0.6786811532817432, 0.}, 
      RotationMatrix :> {{0.5068103792978771, 0.8620575615560379, 
       0.}, {-0.8620575615560379, 0.5068103792978771, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011648799886672645`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.054357082079441975`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.247180100217511`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3023109729977167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5068103792978771, 0.8620575615560379, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.645647895609862, 0.6786811532817432, 0.}, 
      Optica`Optica`RayEnd :> {5.799127858721389, 0.9180940447729026, 0.}, 
      RotationMatrix :> {{0.5396914380146275, 0.8418629055456142, 
       0.}, {-0.8418629055456142, 0.5396914380146275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011610786720315793`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28438465445391625`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.668069388809307`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1501288793974286, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5396914380146275, 0.8418629055456142, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.9705929431190015`, 0.6843149737851442, 0.}, 
      Optica`Optica`RayEnd :> {4.899941011965765, 0.7458439041177413, 0.}, 
      RotationMatrix :> {{-0.7541166040180155, 0.6567405481195263, 
       0.}, {-0.6567405481195263, -0.7541166040180155, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4510426663153465, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09368833782043083, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.49983511010822, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3828069356111753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7541166040180155, 0.6567405481195263, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.899941011965765, 0.7458439041177413, 0.}, 
      Optica`Optica`RayEnd :> {4.71671549254766, 0.8729662902272273, 0.}, 
      RotationMatrix :> {{-0.8216168622383428, 0.5700401141021745, 
       0.}, {-0.5700401141021745, -0.8216168622383428, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4455559388258916, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22300603582908657`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.829884043135268`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3244292278095978, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8216168622383428, 0.5700401141021745, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.698679316809952, 0.14323389961481361`, 0.}, 
      Optica`Optica`RayEnd :> {4.655763772139483, 0.1366737163587785, 0.}, 
      RotationMatrix :> {{-0.9885173560903553, -0.15110736814640574`, 0.}, {
       0.15110736814640574`, -0.9885173560903553, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010061315303617036`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04341405277920694, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.728915766450275`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14931504021982187`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9885173560903553, -0.15110736814640574`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.655763772139483, 0.1366737163587785, 0.}, 
      Optica`Optica`RayEnd :> {4.397708205712049, 0.08057332563951655, 0.}, 
      RotationMatrix :> {{-0.9771752991818241, -0.21243454208040694`, 0.}, {
       0.21243454208040694`, -0.9771752991818241, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010013157072089955`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2640831861422415, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.119758881940792`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1552928998926695, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9771752991818241, -0.21243454208040694`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.050783306785948, -0.26091767258249676`, 0.},
       Optica`Optica`RayEnd :> {5.883599341133357, -0.36116449926156435`, 0.},
       RotationMatrix :> {{-0.8576367240922441, -0.5142560155100997, 0.}, {
       0.5142560155100997, -0.8576367240922441, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.030946525278727734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1949356422785467, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.605737044508452`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23593369186020247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8576367240922441, -0.5142560155100997, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.883599341133357, -0.36116449926156435`, 0.},
       Optica`Optica`RayEnd :> {5.734567675388738, -0.42073563195442343`, 0.},
       RotationMatrix :> {{-0.928565899202874, -0.3711675778372323, 0.}, {
       0.3711675778372323, -0.928565899202874, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.029968592048010056`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16049659574248362`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.843272006207327`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35095406772873755`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.928565899202874, -0.3711675778372323, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.266462557308947, -0.4372999424005015, 0.}, 
      Optica`Optica`RayEnd :> {6.381514964835767, -0.5186948359539496, 0.}, 
      RotationMatrix :> {{0.8163609035358363, -0.5775420981869226, 0.}, {
       0.5775420981869226, 0.8163609035358363, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.5744859607118045`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14093326496712716`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.945729174291772`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07085848419638827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8163609035358363, -0.5775420981869226, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.381514964835767, -0.5186948359539496, 0.}, 
      Optica`Optica`RayEnd :> {6.639330255385841, -0.6831522198358223, 0.}, 
      RotationMatrix :> {{0.8430787365638333, -0.537790148621124, 0.}, {
       0.537790148621124, 0.8430787365638333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.553628102947669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3058021503434675, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.398316356800104`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026869919721666847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8430787365638333, -0.537790148621124, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.639330255385841, -0.6831522198358223, 0.}, 
      Optica`Optica`RayEnd :> {6.593103752960103, -0.3808641690826178, 0.}, 
      RotationMatrix :> {{-0.1511647395998275, 0.9885085844350145, 
       0.}, {-0.9885085844350145, -0.1511647395998275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02077981465243545, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30580215034346747`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.850903539308435`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1235697928932768, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1511647395998275, 0.9885085844350145, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.340928797522072, -0.1688171249226691, 0.}, 
      Optica`Optica`RayEnd :> {6.364726631954419, -0.05188299846126178, 0.}, 
      RotationMatrix :> {{0.19942681782767357`, 0.9799127228131737, 
       0.}, {-0.9799127228131737, 0.19942681782767357`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03060762434679379, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11933116464261023`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.329137675237543`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2706875525341686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19942681782767357`, 0.9799127228131737, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.364726631954419, -0.05188299846126178, 0.}, 
      Optica`Optica`RayEnd :> {6.435475922970339, 0.18220880631998992`, 0.}, 
      RotationMatrix :> {{0.2893046374913776, 0.9572370796861049, 
       0.}, {-0.9572370796861049, 0.2893046374913776, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0303439986044081, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24454945357738808`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.691070866532078`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4023953250998421, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2893046374913776, 0.9572370796861049, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.078954373256245, 0.2500927233677525, 0.}, 
      Optica`Optica`RayEnd :> {5.8171415788764795`, 0.20293311017655968`, 0.},
       RotationMatrix :> {{-0.9841614853167712, -0.1772742813244109, 0.}, {
       0.1772742813244109, -0.9841614853167712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2113051996916409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2660262551277307, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.591219241692722`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3930429168148243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9841614853167712, -0.1772742813244109, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8171415788764795`, 0.2029331101765597, 0.}, 
      Optica`Optica`RayEnd :> {5.593901268418461, 0.16989544610745042`, 0.}, 
      RotationMatrix :> {{-0.9892259175738551, -0.14639700816671014`, 0.}, {
       0.14639700816671014`, -0.9892259175738551, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21067610754528882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22567171612884007`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.925213381563404`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21142897696779941`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9892259175738551, -0.14639700816671014`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.385877384362597, 0.3672198357910872, 0.}, 
      Optica`Optica`RayEnd :> {6.46397806998668, 0.3961971742504616, 0.}, 
      RotationMatrix :> {{0.9375485882639469, 0.34785434400662535`, 
       0.}, {-0.34785434400662535`, 0.9375485882639469, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      83.83761926703055, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08330308061014889, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.832568761171759`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27089556419442856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9375485882639469, 0.34785434400662535`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.46397806998668, 0.3961971742504616, 0.}, 
      Optica`Optica`RayEnd :> {6.5901068238903555`, 0.47152052588080945`, 0.},
       RotationMatrix :> {{0.8585538856563496, 0.5127233419929145, 
       0.}, {-0.5127233419929145, 0.8585538856563496, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      79.87033702506476, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14690837233501414`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.04999315222758, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2831776174003318, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8585538856563496, 0.5127233419929145, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5901068238903555`, 0.4715205258808095, 0.}, 
      Optica`Optica`RayEnd :> {6.569286664841523, 0.616946076728329, 0.}, 
      RotationMatrix :> {{-0.14172207286697952`, 0.9899064875341942, 
       0.}, {-0.9899064875341942, -0.14172207286697952`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7795463720183426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1469083723350142, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.267417543283402`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1561793914964976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.14172207286697952`, 0.9899064875341942, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.569286664841523, 0.616946076728329, 0.}, 
      Optica`Optica`RayEnd :> {6.427090072857617, 0.65385405811834, 0.}, 
      RotationMatrix :> {{-0.967927080831294, 0.25123130018651946`, 
       0.}, {-0.25123130018651946`, -0.967927080831294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17885201578345836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1469083723350143, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.484841934339224`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37793054589963226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.967927080831294, 0.25123130018651946`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.427090072857617, 0.65385405811834, 0.}, 
      Optica`Optica`RayEnd :> {6.338170829330356, 0.5369120297766741, 0.}, 
      RotationMatrix :> {{-0.605270088518074, -0.7960201755893643, 0.}, {
       0.7960201755893643, -0.605270088518074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008463461061525249, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14690837233501436`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.702266325395046`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.031371104521828785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.605270088518074, -0.7960201755893643, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.10438412011554, 0.19786211558100952`, 0.}, 
      Optica`Optica`RayEnd :> {6.081452134150184, 0.18435347933583313`, 0.}, 
      RotationMatrix :> {{-0.8616182468814945, -0.5075568900535776, 0.}, {
       0.5075568900535776, -0.8616182468814945, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21024671262394828`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02661501894644841, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.242805331874997`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09522270847788408, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8616182468814945, -0.5075568900535776, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.081452134150184, 0.18435347933583313`, 0.}, 
      Optica`Optica`RayEnd :> {5.850888149584709, 0.023020528021387685`, 0.}, 
      RotationMatrix :> {{-0.8193351445083715, -0.5733148532642821, 0.}, {
       0.5733148532642821, -0.8193351445083715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20888941283739879`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2814037529219139, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.65928288619943, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.008860295732218635, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8193351445083715, -0.5733148532642821, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.826683256183537, 0.45472933508594915`, 0.}, 
      Optica`Optica`RayEnd :> {5.668343071788032, 0.5220777142812463, 0.}, 
      RotationMatrix :> {{-0.9202183251342401, 0.39140545996081016`, 
       0.}, {-0.39140545996081016`, -0.9202183251342401, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07821442192863452, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17206806262242863`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.490614018097425`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41130715317541283`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9202183251342401, 0.39140545996081016`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.668343071788032, 0.5220777142812463, 0.}, 
      Optica`Optica`RayEnd :> {5.367192815857526, 0.6330714094465906, 0.}, 
      RotationMatrix :> {{-0.9382990414282795, 0.3458249685242107, 
       0.}, {-0.3458249685242107, -0.9382990414282795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07791643761151348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.320953387602416, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.965625031749001`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3542744208367552, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9382990414282795, 0.3458249685242107, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.865410312505054, 0.6554846140465254, 0.}, 
      Optica`Optica`RayEnd :> {5.865531100028655, 0.6558574549179828, 0.}, 
      RotationMatrix :> {{0.3081956840279179, 0.9513229842417154, 
       0.}, {-0.9513229842417154, 0.3081956840279179, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.833380786117062, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0003919182839407598, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.563163628316838`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09494436732138734, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3081956840279179, 0.9513229842417154, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.865531100028655, 0.6558574549179828, 0.}, 
      Optica`Optica`RayEnd :> {5.898362925789411, 0.8443488925545409, 0.}, 
      RotationMatrix :> {{0.17159840874151186`, 0.9851669838750079, 
       0.}, {-0.9851669838750079, 0.17159840874151186`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.725890388587162, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19132943015929646`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.846331184952597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2553301710782405, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.17159840874151186`, 0.9851669838750079, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.898362925789411, 0.8443488925545409, 0.}, 
      Optica`Optica`RayEnd :> {5.720389387508421, 0.9145797299183803, 0.}, 
      RotationMatrix :> {{-0.9301942630196168, 0.36706761372448937`, 
       0.}, {-0.36706761372448937`, -0.9301942630196168, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10509989984878894`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19132943015929665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.129498741588355`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3694515455888065, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9301942630196168, 0.36706761372448937`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.068810334202852, 0.6347265289902424, 0.}, 
      Optica`Optica`RayEnd :> {6.345098640148805, 0.5716557199086093, 0.}, 
      RotationMatrix :> {{0.9749204048979498, -0.22255382295888898`, 0.}, {
       0.22255382295888898`, 0.9749204048979498, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07578105026646675, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.283395756779625, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.24498441553404, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16242314970763216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9749204048979498, -0.22255382295888898`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.345098640148805, 0.5716557199086093, 0.}, 
      Optica`Optica`RayEnd :> {6.601759200889874, 0.5103319550200578, 0.}, 
      RotationMatrix :> {{0.9726230928618069, -0.23238829409402662`, 0.}, {
       0.23238829409402662`, 0.9726230928618069, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07559040039126813, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2638849135134979, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.635534087534017`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.394439204991071, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9726230928618069, -0.23238829409402662`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.324433384014403, 0.5643586341087806, 0.}, 
      Optica`Optica`RayEnd :> {5.25685805736425, 0.6060839947188786, 0.}, 
      RotationMatrix :> {{-0.8508674639540593, 0.5253803943662032, 
       0.}, {-0.5253803943662032, -0.8508674639540593, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29375092030399896`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07941933322508876, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.94115752561356, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2033536368899778, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8508674639540593, 0.5253803943662032, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.25685805736425, 0.6060839947188786, 0.}, 
      Optica`Optica`RayEnd :> {5.090506017080307, 0.737171203163886, 0.}, 
      RotationMatrix :> {{-0.785441255621421, 0.618936211549983, 
       0.}, {-0.618936211549983, -0.785441255621421, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2898582568283681, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21179437557342073`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.254613201462224`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0654462795249977, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.785441255621421, 0.618936211549983, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.960778241183477, -0.13227393548212468`, 0.},
       Optica`Optica`RayEnd :> {4.862506407101621, -0.15506615480032948`, 0.},
       RotationMatrix :> {{-0.9741427829105711, -0.2259332611707447, 0.}, {
       0.2259332611707447, -0.9741427829105711, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015502343724646688`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10088031837410609`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.551708457224393`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25107397040858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9741427829105711, -0.2259332611707447, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.862506407101621, -0.15506615480032948`, 0.},
       Optica`Optica`RayEnd :> {4.561073218499606, -0.23407451704225998`, 0.},
       RotationMatrix :> {{-0.9673237757503729, -0.253544301588583, 0.}, {
       0.253544301588583, -0.9673237757503729, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0154576254827468, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31161561015926315`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.012899560260102`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.00421579940482858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9673237757503729, -0.253544301588583, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.368665699292367, -0.6386508757579388, 0.}, 
      Optica`Optica`RayEnd :> {5.346770984931949, -0.966173849270861, 0.}, 
      RotationMatrix :> {{-0.06670052935029462, -0.9977730400168118, 0.}, {
       0.9977730400168118, -0.06670052935029462, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17284443708879696`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3282539819951476, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.17660185435598, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19261186261765134`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.06670052935029462, -0.9977730400168118, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.346770984931949, -0.966173849270861, 0.}, 
      Optica`Optica`RayEnd :> {5.3706584693009765`, -1.1285576357412543`, 0.},
       RotationMatrix :> {{0.14553881220331744`, -0.9893525428998741, 0.}, {
       0.9893525428998741, 0.14553881220331744`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.159651211132068, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1641313681717874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.419516279250224`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31732879913581796`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14553881220331744`, -0.9893525428998741, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.370658469300976, -1.1285576357412543`, 0.}, 
      Optica`Optica`RayEnd :> {5.525299534917696, -1.1835598797215485`, 0.}, 
      RotationMatrix :> {{0.9421786178914109, -0.3351111039464828, 0.}, {
       0.3351111039464828, 0.9421786178914109, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012186186250522457`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16413136817178714`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.66243070414447, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15909237984661712`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9421786178914109, -0.3351111039464828, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.862033541413417, -0.5694760611249675, 0.}, 
      Optica`Optica`RayEnd :> {4.843546772902948, -0.577372549175145, 0.}, 
      RotationMatrix :> {{-0.9196200806226859, -0.3928089959707195, 0.}, {
       0.3928089959707195, -0.9196200806226859, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18493387167233927`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02010261509073525, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.176508450632346`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014185212150559987`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9196200806226859, -0.3928089959707195, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.843546772902948, -0.577372549175145, 0.}, 
      Optica`Optica`RayEnd :> {4.62020904994084, -0.6927533534632233, 0.}, 
      RotationMatrix :> {{-0.8884427008225914, -0.45898754596945146`, 0.}, {
       0.45898754596945146`, -0.8884427008225914, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18385079305088364`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2513811219961893, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.548552511186706`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.060779918600043836`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8884427008225914, -0.45898754596945146`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6598052417380575`, -0.08667403832027229, 
       0.}, Optica`Optica`RayEnd :> {4.644180013893946, -0.08190306712637067, 
       0.}, RotationMatrix :> {{-0.9564097798239777, 0.2920279662242139, 
       0.}, {-0.2920279662242139, -0.9564097798239777, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0677662676767037, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01633737773675604, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.488146728780029`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09804229918705785, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9564097798239777, 0.2920279662242139, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.644180013893946, -0.08190306712637067, 0.}, 
      Optica`Optica`RayEnd :> {4.3916852340172055`, 0.011356320668955006`, 
       0.}, RotationMatrix :> {{-0.9380595944041554, 0.34647394901537903`, 
       0.}, {-0.34647394901537903`, -0.9380595944041554, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06746903671021276, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26916709917254455`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.886514035555395`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07086802159870237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9380595944041554, 0.34647394901537903`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.023892590390386, 0.17942858185625332`, 0.}, 
      Optica`Optica`RayEnd :> {4.963593281354314, 0.40446042622468326`, 0.}, 
      RotationMatrix :> {{-0.2588278880665669, 0.9659234567806086, 
       0.}, {-0.9659234567806086, -0.2588278880665669, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025660162922156938`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23297067980774966`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.774066282065988`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4054793105792124, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2588278880665669, 0.9659234567806086, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.963593281354314, 0.40446042622468326`, 0.}, 
      Optica`Optica`RayEnd :> {4.917328532690551, 0.6491059597694256, 0.}, 
      RotationMatrix :> {{-0.18581589410963678`, 0.982584578291475, 
       0.}, {-0.982584578291475, -0.18581589410963678`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025504774974547464`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24898165404766856`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.142559130056537`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34978735997273125`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.18581589410963678`, 0.982584578291475, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.668226346046645, 0.5234462570138415, 0.}, 
      Optica`Optica`RayEnd :> {5.7218301323823555`, 0.6254710583343828, 0.}, 
      RotationMatrix :> {{0.46511116514601436`, 0.8852522827174845, 
       0.}, {-0.8852522827174845, 0.46511116514601436`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009284057230028295, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11524940778164712`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.352687101799036`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36607540433313523`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.46511116514601436`, 0.8852522827174845, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.7218301323823555`, 0.6254710583343828, 0.}, 
      Optica`Optica`RayEnd :> {5.856008136082876, 0.892256352907218, 0.}, 
      RotationMatrix :> {{0.4493162704166326, 0.8933727604638994, 
       0.}, {-0.8933727604638994, 0.4493162704166326, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00925969124989129, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2986270752583752, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.794655173181432`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.055150279632332676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.4493162704166326, 0.8933727604638994, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.836599226409276, -0.5489259410795577, 0.}, 
      Optica`Optica`RayEnd :> {3.669827641570253, -0.6118987683239112, 0.}, 
      RotationMatrix :> {{-0.9355272941645352, -0.353254415221074, 0.}, {
       0.353254415221074, -0.9355272941645352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23895551012227334`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17826479877100415`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.22142799024163, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25362838280680616`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9355272941645352, -0.353254415221074, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.669827641570253, -0.6118987683239112, 0.}, 
      Optica`Optica`RayEnd :> {3.440801978911579, -0.6713898163737759, 0.}, 
      RotationMatrix :> {{-0.9678797305071055, -0.2514136576908511, 0.}, {
       0.2514136576908511, -0.9678797305071055, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23621957715124342`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23662615864336756`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.571634705033814`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42696209079840625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9678797305071055, -0.2514136576908511, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.874401641472924, 0.8353535702065428, 0.}, 
      Optica`Optica`RayEnd :> {2.7800941570748763`, 1.048199041125198, 0.}, 
      RotationMatrix :> {{-0.4050961835420712, 0.9142740738310632, 
       0.}, {-0.9142740738310632, -0.4050961835420712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015257402963397159`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23280269780239252`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.397754939084747`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1977948329616978, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4050961835420712, 0.9142740738310632, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7800941570748763`, 1.048199041125198, 0.}, 
      Optica`Optica`RayEnd :> {2.6522622387944037`, 1.3610242766510867`, 0.}, 
      RotationMatrix :> {{-0.3782727540213073, 0.9256941846879754, 
       0.}, {-0.9256941846879754, -0.3782727540213073, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015213052704004033`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33793583312974235`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.897899972116765`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39531153669233515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3782727540213073, 0.9256941846879754, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.700765721031118, 0.872423121498889, 0.}, 
      Optica`Optica`RayEnd :> {2.540332325001979, 0.8750370702415957, 0.}, 
      RotationMatrix :> {{-0.9998672947425328, 0.016290884084328106`, 
       0.}, {-0.016290884084328106`, -0.9998672947425328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2392784345860258, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1604546892099825, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.563580865410875`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07593147614194116, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9998672947425328, 0.016290884084328106`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.540332325001979, 0.8750370702415957, 0.}, 
      Optica`Optica`RayEnd :> {2.3652191267041047`, 0.8967965807865681, 0.}, 
      RotationMatrix :> {{-0.9923680335697468, 0.12331133747110881`, 
       0.}, {-0.12331133747110881`, -0.9923680335697468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2365152442046992, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17645993459498768`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.824741568611458`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3015942563136603, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9923680335697468, 0.12331133747110881`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.594207019314376, 0.7304061239629206, 0.}, 
      Optica`Optica`RayEnd :> {2.5653768335927825`, 0.67067236065996, 0.}, 
      RotationMatrix :> {{-0.43466587704036574`, -0.9005917917329302, 0.}, {
       0.9005917917329302, -0.43466587704036574`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013575278918476414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06632723488187711, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.70022233445117, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.020645105970546085`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.43466587704036574`, -0.9005917917329302, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5653768335927825`, 0.67067236065996, 0.}, 
      Optica`Optica`RayEnd :> {2.423048150401369, 0.3838397198217184, 0.}, 
      RotationMatrix :> {{-0.44449416840075556`, -0.8957817447669498, 0.}, {
       0.8957817447669498, -0.44449416840075556`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013541004802550265`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3202037131409339, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.174123829899752`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38534301113681946`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.44449416840075556`, -0.8957817447669498, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.434230233882032, 1.8265236218852379`, 0.}, 
      Optica`Optica`RayEnd :> {4.442488502570082, 1.842571367732075, 0.}, 
      RotationMatrix :> {{0.45757332313709626`, 0.8891718922420314, 
       0.}, {-0.8891718922420314, 0.45757332313709626`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011782427141818165`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01804796798780154, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.49712659187959, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4049366527296472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.45757332313709626`, 0.8891718922420314, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.442488502570082, 1.842571367732075, 0.}, 
      Optica`Optica`RayEnd :> {4.592996513027466, 2.1249490237982482`, 0.}, 
      RotationMatrix :> {{0.47036095517733756`, 0.8824741196458188, 
       0.}, {-0.8824741196458188, 0.47036095517733756`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011752149891347843`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31998406500522175`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.970703008087318`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08511323023941678, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.47036095517733756`, 0.8824741196458188, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.647719817861916, 0.8400449151302908, 0.}, 
      Optica`Optica`RayEnd :> {2.4122339635400483`, 0.8147439907309327, 0.}, 
      RotationMatrix :> {{-0.9942776703189736, -0.10682656179562355`, 0.}, {
       0.10682656179562355`, -0.9942776703189736, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06087723352217307, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2368411373920542, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.448908083075624`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3890833067284579, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9942776703189736, -0.10682656179562355`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4122339635400483`, 0.8147439907309327, 0.}, 
      Optica`Optica`RayEnd :> {2.1679364592479047`, 0.7873630095557195, 0.}, 
      RotationMatrix :> {{-0.9937775471786597, -0.11138306300136665`, 0.}, {
       0.11138306300136665`, -0.9937775471786597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06072655287750267, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2458271521485925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.812732268255541`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0338606432267373, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9937775471786597, -0.11138306300136665`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.651432219296955, 1.3603774696099153`, 0.}, 
      Optica`Optica`RayEnd :> {2.6317869098812796`, 1.4040762764764532`, 0.}, 
      RotationMatrix :> {{-0.4100322002389416, 0.9120710469953602, 
       0.}, {-0.9120710469953602, -0.4100322002389416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24351189900647474`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047911625975295476`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.648262431349126`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25893636894280153`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4100322002389416, 0.9120710469953602, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6317869098812796`, 1.4040762764764532`, 0.},
       Optica`Optica`RayEnd :> {2.495720909980971, 1.6579704444939585`, 0.}, 
      RotationMatrix :> {{-0.472359695279891, 0.8814058760157483, 
       0.}, {-0.8814058760157483, -0.472359695279891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24218263486516475`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2880559058276222, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.074585171974007`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21277507255616118`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.472359695279891, 0.8814058760157483, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9294255861950274`, 1.2662841266646672`, 0.},
       Optica`Optica`RayEnd :> {2.9280989752410815`, 1.3428405400690842`, 0.},
       RotationMatrix :> {{-0.01732593996428833, 0.9998498946363669, 
       0.}, {-0.9998498946363669, -0.01732593996428833, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031107606560806533`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07656790665788844, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.508891900097783`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38446972738177027`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.01732593996428833, 0.9998498946363669, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9280989752410815`, 1.3428405400690842`, 0.},
       Optica`Optica`RayEnd :> {2.9343541138804152`, 1.6684119244566258`, 0.},
       RotationMatrix :> {{0.019209257242965398`, 0.9998154851952302, 
       0.}, {-0.9998154851952302, 0.019209257242965398`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031008827758712634`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32563146821432604`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.990826473054986`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37190736496495813`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.019209257242965398`, 0.9998154851952302, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7903414601329137`, -0.9150460813852921, 0.},
       Optica`Optica`RayEnd :> {2.4842168326986034`, -1.3533368486914512`, 
       0.}, RotationMatrix :> {{-0.5726097463694746, -0.8198280785400593, 
       0.}, {0.8198280785400593, -0.5726097463694746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012713490011077166`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5346130228750671, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.458308072005737`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23728312717586658`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5726097463694746, -0.8198280785400593, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4842168326986034`, -1.3533368486914512`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3495590308742202`, -1.5735559140602946`, 0.}, 
      RotationMatrix :> {{-0.5216741901514949, -0.8531447938830675, 0.}, {
       0.8531447938830675, -0.5216741901514949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012654263035535213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25812624884753926`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.840334920300096`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24072118058475644`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5216741901514949, -0.8531447938830675, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.335531677235352, -1.4663065767668944`, 0.}, 
      Optica`Optica`RayEnd :> {2.1968282486405424`, -1.5843271908251064`, 0.},
       RotationMatrix :> {{-0.761606751570431, -0.6480394709910309, 0.}, {
       0.6480394709910309, -0.761606751570431, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3546692743972801, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18211948398409436`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.417183816151391`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4321206009747099, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.761606751570431, -0.6480394709910309, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1968282486405424`, -1.5843271908251064`, 
       0.}, Optica`Optica`RayEnd :> {2.122821027838444, -1.6979744077857233`, 
       0.}, RotationMatrix :> {{-0.5456958604916653, -0.8379833100022103, 
       0.}, {0.8379833100022103, -0.5456958604916653, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2779633196139141, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13561990507939486`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.617901275668896`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05174895245824496, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5456958604916653, -0.8379833100022103, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.122821027838444, -1.6979744077857233`, 0.}, 
      Optica`Optica`RayEnd :> {2.17184458169658, -1.8244238040708087`, 0.}, 
      RotationMatrix :> {{0.3614775709320574, -0.9323808050968547, 0.}, {
       0.9323808050968547, 0.3614775709320574, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.060116405239702936`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13561990507939506`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.8186187351864, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37345005300224243`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3614775709320574, -0.9323808050968547, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.17184458169658, -1.8244238040708087`, 0.}, 
      Optica`Optica`RayEnd :> {2.3031174647941777`, -1.8584853486187098`, 0.},
       RotationMatrix :> {{0.9679470209092621, -0.25115446385219625`, 0.}, {
       0.25115446385219625`, 0.9679470209092621, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013001651383225262`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13561990507939523`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.019336194703904`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1496389734707451, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9679470209092621, -0.25115446385219625`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2175576221075644`, -1.407368696474002, 0.}, 
      Optica`Optica`RayEnd :> {3.1691153892197756`, -1.4577264201050941`, 0.},
       RotationMatrix :> {{-0.6932674216734224, -0.7206804299037715, 0.}, {
       0.7206804299037715, -0.6932674216734224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2650310623981845, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06987524780965147, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.562306057639747`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3316902588202187, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6932674216734224, -0.7206804299037715, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1691153892197756`, -1.4577264201050941`, 
       0.}, Optica`Optica`RayEnd :> {
       2.9545503044322277`, -1.6599496305216164`, 0.}, 
      RotationMatrix :> {{-0.7277265363988344, -0.6858673984240361, 0.}, {
       0.6858673984240361, -0.7277265363988344, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26402217744730205`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29484301321390105`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.99867371719632, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39311226480388517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7277265363988344, -0.6858673984240361, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5497612598705612`, -0.30326694863810244`, 
       0.}, Optica`Optica`RayEnd :> {3.404192993676753, -0.35408154355463156`,
        0.}, RotationMatrix :> {{-0.9441296293859127, -0.3295743359480816, 
       0.}, {0.3295743359480816, -0.9441296293859127, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009106118133536577, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15418249958799585`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.611884830467524`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.272591951734736, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9441296293859127, -0.3295743359480816, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.404192993676753, -0.35408154355463156`, 0.},
       Optica`Optica`RayEnd :> {3.1711990803001635`, -0.4115125146935025, 0.},
       RotationMatrix :> {{-0.970938787264056, -0.23932795780310312`, 0.}, {
       0.23932795780310312`, -0.970938787264056, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00902536925074922, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23996766473108738`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.967036974269533`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40784945243095694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.970938787264056, -0.23932795780310312`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3199501454438773`, 0.46261288869489703`, 
       0.}, Optica`Optica`RayEnd :> {3.1817374130547575`, 0.5063297872396552, 
       0.}, RotationMatrix :> {{-0.95344236908067, 0.3015752788970593, 
       0.}, {-0.3015752788970593, -0.95344236908067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2172794304223771, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14496181087734497`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.863767750608206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.369448648681519, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.95344236908067, 0.3015752788970593, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1817374130547575`, 0.5063297872396552, 0.}, 
      Optica`Optica`RayEnd :> {2.8956096724243867`, 0.5941363996724759, 0.}, 
      RotationMatrix :> {{-0.9559972745404482, 0.29337554613708816`, 
       0.}, {-0.29337554613708816`, -0.9559972745404482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21673588577882225`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.299297653089977, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.306728277181373`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18534253756761937`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9559972745404482, 0.29337554613708816`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.316627609022407, 1.4150762881589727`, 0.}, 
      Optica`Optica`RayEnd :> {4.339192280199492, 1.5930613960057278`, 0.}, 
      RotationMatrix :> {{0.12577170172073085`, 0.9920592114618314, 
       0.}, {-0.9920592114618314, 0.12577170172073085`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009327987147502123, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1794097628351116, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.43397623095739, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09860033243838158, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12577170172073085`, 0.9920592114618314, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.339192280199492, 1.5930613960057278`, 0.}, 
      Optica`Optica`RayEnd :> {4.3638619846663005`, 1.897890825549716, 0.}, 
      RotationMatrix :> {{0.08066580373739199, 0.9967412041785971, 
       0.}, {-0.9967412041785971, 0.08066580373739199, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009294433670189554, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3058260542115287, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.886598791190451`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.018493083516881555`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.08066580373739199, 0.9967412041785971, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.799127858721389, 0.9180940447729026, 0.}, 
      Optica`Optica`RayEnd :> {6.0516089093221535`, 1.2803718303013756`, 0.}, 
      RotationMatrix :> {{0.5717689025735088, 0.8204147256417853, 
       0.}, {-0.8204147256417853, 0.5717689025735088, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011572897601142393`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.44157884324306135`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.259785038755009`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.030409063087059936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5717689025735088, 0.8204147256417853, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.0516089093221535`, 1.2803718303013756`, 0.},
       Optica`Optica`RayEnd :> {6.186980434491088, 1.4262010764902882`, 0.}, 
      RotationMatrix :> {{0.6803395084496997, 0.7328970959435038, 
       0.}, {-0.7328970959435038, 0.6803395084496997, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011321684154192444`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1989764279270034, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.554270152086975`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3060839057686657, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.6803395084496997, 0.7328970959435038, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.71671549254766, 0.8729662902272273, 0.}, 
      Optica`Optica`RayEnd :> {4.656340914544981, 0.9056846679963191, 0.}, 
      RotationMatrix :> {{-0.8791975345792012, 0.47645744320962646`, 
       0.}, {-0.47645744320962646`, -0.8791975345792012, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4401359548638054, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06867009474904294, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.921901970098984`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20189078715298964`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8791975345792012, 0.47645744320962646`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.656340914544981, 0.9056846679963191, 0.}, 
      Optica`Optica`RayEnd :> {4.3477706183017695`, 1.0780641496062522`, 0.}, 
      RotationMatrix :> {{-0.8730119786442122, 0.4876987647551691, 
       0.}, {-0.4876987647551691, -0.8730119786442122, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4390147261340071, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35345482512441817`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.445015111283123`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18886930194987742`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8730119786442122, 0.4876987647551691, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.397708205712049, 0.08057332563951655, 0.}, 
      Optica`Optica`RayEnd :> {4.189373374273458, 0.021467253382598736`, 0.}, 
      RotationMatrix :> {{-0.9620323581845438, -0.2729354169137553, 0.}, {
       0.2729354169137553, -0.9620323581845438, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009965229348721485, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21655698965442333`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.409945248077719`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4265590464736081, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9620323581845438, -0.2729354169137553, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.189373374273458, 0.021467253382598736`, 0.},
       Optica`Optica`RayEnd :> {3.886363500432843, -0.05497944326763965, 0.}, 
      RotationMatrix :> {{-0.9696175416914782, -0.24462588343054456`, 0.}, {
       0.24462588343054456`, -0.9696175416914782, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009936213526491131, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31250452968499354`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.87245195201151, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24823706987915836`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9696175416914782, -0.24462588343054456`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.734567675388738, -0.42073563195442343`, 0.},
       Optica`Optica`RayEnd :> {5.628213718193005, -0.444562251532586, 0.}, 
      RotationMatrix :> {{-0.9758117699551414, -0.21861241871635323`, 0.}, {
       0.21861241871635323`, -0.9758117699551414, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02902156223520853, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10899023814871793`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.989318925326609`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2040878039891582, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9758117699551414, -0.21861241871635323`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.628213718193005, -0.444562251532586, 0.}, 
      Optica`Optica`RayEnd :> {5.335781837376667, -0.5225924266413898, 0.}, 
      RotationMatrix :> {{-0.9661951647411955, -0.257811760070665, 0.}, {
       0.257811760070665, -0.9661951647411955, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028924509565415823`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3026633660443425, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.437260707072236`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.052517653342319365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9661951647411955, -0.257811760070665, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.381514964835767, -0.5186948359539496, 0.}, 
      Optica`Optica`RayEnd :> {5.911232301346223, -0.6804740080385091, 0.}, 
      RotationMatrix :> {{-0.9456127023409506, -0.32529466207032165`, 0.}, {
       0.32529466207032165`, -0.9456127023409506, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020857857764136536`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4973311613997109, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.612152930567385`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34962697728596326`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9456127023409506, -0.32529466207032165`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.911232301346223, -0.6804740080385091, 0.}, 
      Optica`Optica`RayEnd :> {5.624663377518157, -0.777283667465705, 0.}, 
      RotationMatrix :> {{-0.9473994357690588, -0.3200536034861488, 0.}, {
       0.3200536034861488, -0.9473994357690588, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020806130667997542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30247951709559684`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.059822615868868`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1848694261107446, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9473994357690588, -0.3200536034861488, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.639330255385841, -0.6831522198358223, 0.}, 
      Optica`Optica`RayEnd :> {6.6616951298003775`, -0.6959549043217395, 0.}, 
      RotationMatrix :> {{0.8678624963045017, -0.4968044761353491, 0.}, {
       0.4968044761353491, 0.8678624963045017, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.532848288295237, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.025770066698089115`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.432848246175544`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35149600395726116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8678624963045017, -0.4968044761353491, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.6616951298003775`, -0.6959549043217395, 0.},
       Optica`Optica`RayEnd :> {6.903791814934578, -0.8427133549804139, 0.}, 
      RotationMatrix :> {{0.8551458674149354, -0.5183874472276095, 0.}, {
       0.5183874472276095, 0.8551458674149354, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.517424936317343, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28310571840339493`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.851844709412568`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33598475751220963`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8551458674149354, -0.5183874472276095, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.903791814934578, -0.8427133549804139, 0.}, 
      Optica`Optica`RayEnd :> {6.621496895843233, -0.8213024594383405, 0.}, 
      RotationMatrix :> {{-0.9971360546278507, 0.07562862263193548, 
       0.}, {-0.07562862263193548, -0.9971360546278507, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01538035788627458, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28310571840339493`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.270841172649591`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07913124989772191, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9971360546278507, 0.07562862263193548, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.593103752960103, -0.3808641690826178, 0.}, 
      Optica`Optica`RayEnd :> {6.585937710344732, -0.34544883692820877`, 0.}, 
      RotationMatrix :> {{-0.19832372093299083`, 0.9801365729913832, 
       0.}, {-0.9801365729913832, -0.19832372093299083`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02070206355189626, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036133058525018795`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.89932183773196, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33432688459842586`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.19832372093299083`, 0.9801365729913832, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.585937710344732, -0.34544883692820877`, 0.},
       Optica`Optica`RayEnd :> {6.574334237508879, -0.139023951860052, 0.}, 
      RotationMatrix :> {{-0.05612300164450737, 0.998423862238083, 
       0.}, {-0.998423862238083, -0.05612300164450737, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020218071203846697`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20675075273685006`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.2053129517825, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2905549405960226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.05612300164450737, 0.998423862238083, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.435475922970339, 0.18220880631998992`, 0.}, 
      Optica`Optica`RayEnd :> {6.5277167916844, 0.4090387728449872, 0.}, 
      RotationMatrix :> {{0.3766966917488446, 0.9263366571746342, 
       0.}, {-0.9263366571746342, 0.3766966917488446, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030082643490126744`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24486774302642647`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.019193642187489`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03846639944391395, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3766966917488446, 0.9263366571746342, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5277167916844, 0.4090387728449872, 0.}, 
      Optica`Optica`RayEnd :> {6.5835171622575075`, 0.5978111898525217, 0.}, 
      RotationMatrix :> {{0.2834708962175038, 0.9589808397448016, 
       0.}, {-0.9589808397448016, 0.2834708962175038, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02978984769763544, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19684691203816906`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.310527072003978`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2387530844385779, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2834708962175038, 0.9589808397448016, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.593901268418461, 0.1698954461074504, 0.}, 
      Optica`Optica`RayEnd :> {5.5368369334040395`, 0.16326730455128366`, 0.},
       RotationMatrix :> {{-0.9933218437727763, -0.11537640436350709`, 0.}, {
       0.11537640436350709`, -0.9933218437727763, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21004888831512233`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057447981610555296`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.002193676921548`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2686676900707515, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9933218437727763, -0.11537640436350709`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5368369334040395`, 0.16326730455128366`, 
       0.}, Optica`Optica`RayEnd :> {5.447483270690153, 0.11587933936681133`, 
       0.}, RotationMatrix :> {{-0.8834479951515504, -0.4685292305317842, 
       0.}, {0.4685292305317842, -0.8834479951515504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09602529295412246, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837817`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.151883779273147`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2982854150422827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8834479951515504, -0.4685292305317842, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.447483270690153, 0.11587933936681133`, 0.}, 
      Optica`Optica`RayEnd :> {5.42785836360701, 0.016659586763362173`, 0.}, 
      RotationMatrix :> {{-0.1940332862812153, -0.9809949458661403, 0.}, {
       0.9809949458661403, -0.1940332862812153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.052126670300655, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837829`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.301573881624748`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1230612644470728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.1940332862812153, -0.9809949458661403, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.42785836360701, 0.016659586763362176`, 0.}, 
      Optica`Optica`RayEnd :> {5.492443700937656, -0.06117633352154406, 0.}, 
      RotationMatrix :> {{0.6385612525325074, -0.7695710017692422, 0.}, {
       0.7695710017692422, 0.6385612525325074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028296604707378912`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837836`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.451263983976348`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40896916986254844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6385612525325074, -0.7695710017692422, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.492443700937656, -0.06117633352154406, 0.}, 
      Optica`Optica`RayEnd :> {5.593580874204508, -0.06019222565020976, 0.}, 
      RotationMatrix :> {{0.9999526627576067, 0.00972996628830991, 
       0.}, {-0.00972996628830991, 0.9999526627576067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015360617383527722`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837835`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.600954086327949`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03493105573826716, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999526627576067, 0.00972996628830991, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.593580874204508, -0.06019222565020976, 0.}, 
      Optica`Optica`RayEnd :> {5.656639372597604, 0.018885723647427514`, 0.}, 
      RotationMatrix :> {{0.6234652535848404, 0.7818510584327365, 
       0.}, {-0.7818510584327365, 0.6234652535848404, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008338405573499956, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837841`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.75064418867955, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3648831647242815, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6234652535848404, 0.7818510584327365, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.46397806998668, 0.3961971742504616, 0.}, 
      Optica`Optica`RayEnd :> {6.612509852193087, 0.3238578492146921, 0.}, 
      RotationMatrix :> {{0.8990430371413274, -0.43786027151101214`, 0.}, {
       0.43786027151101214`, 0.8990430371413274, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9672822419658496`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1652109810879477, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.053951475829608`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2664084690613324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8990430371413274, -0.43786027151101214`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.612509852193087, 0.3238578492146921, 0.}, 
      Optica`Optica`RayEnd :> {6.898387262851132, 0.1809591662737341, 0.}, 
      RotationMatrix :> {{0.8944772755545145, -0.44711341236488594`, 0.}, {
       0.44711341236488594`, 0.8944772755545145, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9572924151053797`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31960276518016745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.526963568296257`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3151937324938385, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8944772755545145, -0.44711341236488594`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.898387262851132, 0.1809591662737341, 0.}, 
      Optica`Optica`RayEnd :> {6.5900884129714665`, 0.26520729191273357`, 0.},
       RotationMatrix :> {{-0.9646313595123946, 0.26360261805465574`, 
       0.}, {-0.26360261805465574`, -0.9646313595123946, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009964671947203912, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3196027651801672, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.999975660762905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08378521027950564, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9646313595123946, 0.26360261805465574`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5901068238903555`, 0.47152052588080956`, 
       0.}, Optica`Optica`RayEnd :> {6.7103606959140265`, 0.5772951254941001, 
       0.}, RotationMatrix :> {{0.7508646384074936, 0.6604561263166412, 
       0.}, {-0.6604561263166412, 0.7508646384074936, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      76.09079065304638, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16015386245744243`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.264599327920553`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3811449247375621, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7508646384074936, 0.6604561263166412, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.7103606959140265`, 0.5772951254941001, 0.}, 
      Optica`Optica`RayEnd :> {6.935844594623621, 0.7973177727561169, 0.}, 
      RotationMatrix :> {{0.7157210905042805, 0.6983862259576451, 
       0.}, {-0.6983862259576451, 0.7157210905042805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      75.78805238539758, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31504436812211745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.730864992741287`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33286379768071034`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7157210905042805, 0.6983862259576451, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.935844594623621, 0.7973177727561169, 0.}, 
      Optica`Optica`RayEnd :> {6.623695705447773, 0.8399326160826954, 0.}, 
      RotationMatrix :> {{-0.9908092978664267, 0.13526616451070833`, 
       0.}, {-0.13526616451070833`, -0.9908092978664267, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.30153377945895193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31504436812211745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.19713065756202, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2782192589029508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9908092978664267, 0.13526616451070833`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.569286664841523, 0.616946076728329, 0.}, 
      Optica`Optica`RayEnd :> {6.4874006132775435`, 0.8597499173682634, 0.}, 
      RotationMatrix :> {{-0.31956756811125786`, 0.9475634909658854, 
       0.}, {-0.9475634909658854, -0.31956756811125786`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.6006943562348837`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25624018121723496`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.610779386114498`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19460904742377685`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.31956756811125786`, 0.9475634909658854, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.4874006132775435`, 0.8597499173682634, 0.}, 
      Optica`Optica`RayEnd :> {6.385731150277527, 1.1815774722078438`, 0.}, 
      RotationMatrix :> {{-0.3012383512237693, 0.9535488743383761, 
       0.}, {-0.9535488743383761, -0.3012383512237693, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.591139600561047, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33750504405228493`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.11028685131188, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4238845577687778, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3012383512237693, 0.9535488743383761, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.385731150277527, 1.1815774722078438`, 0.}, 
      Optica`Optica`RayEnd :> {6.595407208774853, 0.9171051574870768, 0.}, 
      RotationMatrix :> {{0.6212531107086032, -0.7836099619293283, 0.}, {
       0.7836099619293283, 0.6212531107086032, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009529401298553416, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3375050440522846, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.60979431650926, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16150911654754554`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6212531107086032, -0.7836099619293283, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.427090072857617, 0.65385405811834, 0.}, 
      Optica`Optica`RayEnd :> {6.407772164511959, 0.6552256069035045, 0.}, 
      RotationMatrix :> {{-0.997489072354497, 0.07082055163131887, 
       0.}, {-0.07082055163131887, -0.997489072354497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1703885547219331, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01936653631709344, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.510793093004128`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21438606949538386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.997489072354497, 0.07082055163131887, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.407772164511959, 0.6552256069035045, 0.}, 
      Optica`Optica`RayEnd :> {6.17426127708289, 0.6847681835117939, 0.}, 
      RotationMatrix :> {{-0.9920918143905646, 0.12551426938494628`, 
       0.}, {-0.12551426938494628`, -0.9920918143905646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16967267903905908`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2353722549081946, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.859144030268256`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1725625088079654, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9920918143905646, 0.12551426938494628`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.338170829330356, 0.5369120297766741, 0.}, 
      Optica`Optica`RayEnd :> {6.29429118719413, 0.4498904721833331, 0.}, 
      RotationMatrix :> {{-0.4502388903216692, -0.8929081372917997, 0.}, {
       0.8929081372917997, -0.4502388903216692, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008062961392420711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0974585782780279, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.832860820287603`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08594316703795846, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4502388903216692, -0.8929081372917997, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.29429118719413, 0.4498904721833331, 0.}, 
      Optica`Optica`RayEnd :> {6.149860507509465, 0.15542061427856801`, 0.}, 
      RotationMatrix :> {{-0.4403605273706925, -0.8978210322407274, 0.}, {
       0.8978210322407274, -0.4403605273706925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008042596384623464, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.327982802062283, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.318275367339782`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4233229630620845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4403605273706925, -0.8978210322407274, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.850888149584709, 0.023020528021387654`, 0.},
       Optica`Optica`RayEnd :> {5.152008776889274, -0.5523167722276326, 0.}, 
      RotationMatrix :> {{-0.7720442899254092, -0.6355687330207254, 0.}, {
       0.6355687330207254, -0.7720442899254092, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2075408754361802, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9052322280149973, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.872294071739526`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35994847481914943`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7720442899254092, -0.6355687330207254, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.152008776889274, -0.5523167722276326, 0.}, 
      Optica`Optica`RayEnd :> {4.976148157166832, -0.6651470108793203, 0.}, 
      RotationMatrix :> {{-0.8416636466845998, -0.5400021350416871, 0.}, {
       0.5400021350416871, -0.8416636466845998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20455874324321377`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.208944060272979, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.181531280943535`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3259063048263108, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8416636466845998, -0.5400021350416871, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.367192815857526, 0.6330714094465906, 0.}, 
      Optica`Optica`RayEnd :> {5.339669363981522, 0.6417085268261644, 0.}, 
      RotationMatrix :> {{-0.9541236237749215, 0.2994129431982049, 
       0.}, {-0.2994129431982049, -0.9541236237749215, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07761958856652082, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028846840378093732`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.004279797855647`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09156276818225634, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9541236237749215, 0.2994129431982049, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.339669363981522, 0.6417085268261644, 0.}, 
      Optica`Optica`RayEnd :> {5.090655489293798, 0.7360701536815027, 0.}, 
      RotationMatrix :> {{-0.9351119305886533, 0.3543524760330611, 
       0.}, {-0.3543524760330611, -0.9351119305886533, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07727506301232216, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2662931212212958, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.398393617263164`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06907323498632226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9351119305886533, 0.3543524760330611, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.865531100028655, 0.6558574549179828, 0.}, 
      Optica`Optica`RayEnd :> {5.866032082750782, 0.6559443778978106, 0.}, 
      RotationMatrix :> {{0.9852795533817598, 0.17095087507187307`, 
       0.}, {-0.17095087507187307`, 0.9852795533817598, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10749039752990319`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0005084675921739751, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.563844974890351`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40278556923938497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9852795533817598, 0.17095087507187307`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.866032082750782, 0.6559443778978106, 0.}, 
      Optica`Optica`RayEnd :> {6.043512798331155, 0.6573804419320666, 0.}, 
      RotationMatrix :> {{0.9999672663865977, 0.008091115826275752, 
       0.}, {-0.008091115826275752, 0.9999672663865977, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10385264082103, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17748652535567822`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.826525032416756`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04711815972023915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999672663865977, 0.008091115826275752, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.898362925789411, 0.8443488925545409, 0.}, 
      Optica`Optica`RayEnd :> {5.899262128321833, 0.8727879726536775, 0.}, 
      RotationMatrix :> {{0.031602758770109984`, 0.999500508072966, 
       0.}, {-0.999500508072966, 0.031602758770109984`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.62079048873837, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02845329228893244, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.884458596619766`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2560634125904246, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.031602758770109984`, 0.999500508072966, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.899262128321833, 0.8727879726536775, 0.}, 
      Optica`Optica`RayEnd :> {5.934985647022961, 1.0862925640458698`, 0.}, 
      RotationMatrix :> {{0.1650256017195334, 0.9862892835152904, 
       0.}, {-0.9862892835152904, 0.1650256017195334, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.5302938238138175`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21647258564062283`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.204838023367888`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3819151601017152, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.1650256017195334, 0.9862892835152904, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.934985647022961, 1.0862925640458698`, 0.}, 
      Optica`Optica`RayEnd :> {6.151457852592751, 1.0858869168008731`, 0.}, 
      RotationMatrix :> {{0.9999982442542005, -0.0018738966128036272`, 0.}, {
       0.0018738966128036272`, 0.9999982442542005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08872431744798197, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21647258564062308`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.52521745011601, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09035989883336391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999982442542005, -0.0018738966128036272`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.720389387508421, 0.9145797299183803, 0.}, 
      Optica`Optica`RayEnd :> {5.666533260694018, 0.9274747733141636, 0.}, 
      RotationMatrix :> {{-0.9725118467863625, 0.23285340422716097`, 
       0.}, {-0.23285340422716097`, -0.9725118467863625, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10276256486215848`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.055378376101400714`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.203705765564232`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32247748678687355`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9725118467863625, 0.23285340422716097`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.666533260694018, 0.9274747733141636, 0.}, 
      Optica`Optica`RayEnd :> {5.343756785437981, 1.0083714905520778`, 0.}, 
      RotationMatrix :> {{-0.9699990736721646, 0.24310861168445136`, 
       0.}, {-0.24310861168445136`, -0.9699990736721646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10250354332498902`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33275957061906086`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.696189930080441`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0721994446664617, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9699990736721646, 0.24310861168445136`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.601759200889874, 0.5103319550200578, 0.}, 
      Optica`Optica`RayEnd :> {6.839475126009467, 0.4509905851077668, 0.}, 
      RotationMatrix :> {{0.9702265786535564, -0.24219906290944476`, 0.}, {
       0.24219906290944476`, 0.9702265786535564, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07540023015279645, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24501073290476763`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.963848469626406`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.010526486462427513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9702265786535564, -0.24219906290944476`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.839475126009467, 0.4509905851077668, 0.}, 
      Optica`Optica`RayEnd :> {7.143881683462895, 0.3832461284525548, 0.}, 
      RotationMatrix :> {{0.9761200897923513, -0.2172316052138152, 0.}, {
       0.2172316052138152, 0.9761200897923513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07518882025403502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3118535932583701, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.425391787648794`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2774272740043305, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9761200897923513, -0.2172316052138152, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.090506017080307, 0.737171203163886, 0.}, 
      Optica`Optica`RayEnd :> {4.991659151421143, 0.8352725985202283, 0.}, 
      RotationMatrix :> {{-0.7097781717432817, 0.7044252599933964, 
       0.}, {-0.7044252599933964, -0.7097781717432817, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2860171772896278, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13926444851972225`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.441227562478652`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28240375643888527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7097781717432817, 0.7044252599933964, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.991659151421143, 0.8352725985202283, 0.}, 
      Optica`Optica`RayEnd :> {4.839439865992445, 1.0218694340316077`, 0.}, 
      RotationMatrix :> {{-0.632115635090214, 0.7748740696877754, 
       0.}, {-0.7748740696877754, -0.632115635090214, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28287139440904074`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24080923960530265`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.7976252370945, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06265196473653517, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.632115635090214, 0.7748740696877754, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.561073218499606, -0.23407451704225998`, 0.},
       Optica`Optica`RayEnd :> {4.44134789660697, -0.2691230503460128, 0.}, 
      RotationMatrix :> {{-0.9597223309441734, -0.28095025802992724`, 0.}, {
       0.28095025802992724`, -0.9597223309441734, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015413036235610177`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12474995947510187`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.18006450595674, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38606793388928595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9597223309441734, -0.28095025802992724`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.44134789660697, -0.2691230503460128, 0.}, 
      Optica`Optica`RayEnd :> {4.122856680468086, -0.3469255217782274, 0.}, 
      RotationMatrix :> {{-0.9714348318602362, -0.23730648421118783`, 0.}, {
       0.23730648421118783`, -0.9714348318602362, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01535772897019159, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3278564919573598, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.665292114053631`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30027406874602514`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9714348318602362, -0.23730648421118783`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.346770984931949, -0.966173849270861, 0.}, 
      Optica`Optica`RayEnd :> {5.040126630241996, -1.3128848690005974`, 0.}, 
      RotationMatrix :> {{-0.662499282211319, -0.7490625481690343, 0.}, {
       0.7490625481690343, -0.662499282211319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013193225956728961`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.46285990479328726`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.796834126778984`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23634892377228034`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.662499282211319, -0.7490625481690343, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.040126630241996, -1.3128848690005974`, 0.}, 
      Optica`Optica`RayEnd :> {4.899821121356265, -1.4982348238119843`, 0.}, 
      RotationMatrix :> {{-0.6035539303667938, -0.7973221765000615, 0.}, {
       0.7973221765000615, -0.6035539303667938, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013111306819803749`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23246557072449925`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.140883171451243`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15069181790200745`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6035539303667938, -0.7973221765000615, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.370658469300976, -1.1285576357412543`, 0.}, 
      Optica`Optica`RayEnd :> {5.461859781943019, -1.371691218610847, 0.}, 
      RotationMatrix :> {{0.3512119602500902, -0.9362959782981494, 0.}, {
       0.9362959782981494, 0.3512119602500902, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14746502488154556`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25967598762041266`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.767482102661578`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4297299800496498, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3512119602500902, -0.9362959782981494, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.461859781943019, -1.371691218610847, 0.}, 
      Optica`Optica`RayEnd :> {5.5760497386044126`, -1.6632283365645302`, 0.},
       RotationMatrix :> {{0.3647045956037672, -0.931123277523171, 0.}, {
       0.931123277523171, 0.3647045956037672, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1470860527947584, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3131025987548983, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.230873948818827`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14181682785476635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3647045956037672, -0.931123277523171, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.525299534917696, -1.1835598797215485`, 0.}, 
      Optica`Optica`RayEnd :> {5.600761982400861, -1.1933424117791065`, 0.}, 
      RotationMatrix :> {{0.9917018985840854, -0.12855871944259545`, 0.}, {
       0.12855871944259545`, 0.9917018985840854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011256013943783253`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07609388223508266, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.76439650633948, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028912237522287835`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9917018985840854, -0.12855871944259545`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.600761982400861, -1.1933424117791065`, 0.}, 
      Optica`Optica`RayEnd :> {5.916170905633331, -1.2320732494795885`, 0.}, 
      RotationMatrix :> {{0.9925448225350814, -0.12188016761886804`, 0.}, {
       0.12188016761886804`, 0.9925448225350814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011228016663161554`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3177780147267062, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.234707968135005`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3791451063761998, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9925448225350814, -0.12188016761886804`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.62020904994084, -0.6927533534632233, 0.}, 
      Optica`Optica`RayEnd :> {4.421059584571563, -0.814860172281644, 0.}, 
      RotationMatrix :> {{-0.8525107048635936, -0.5227097646811074, 0.}, {
       0.5227097646811074, -0.8525107048635936, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18277405755786433`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23360347762570516`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.86158117120515, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3544439880978478, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8525107048635936, -0.5227097646811074, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.421059584571563, -0.814860172281644, 0.}, 
      Optica`Optica`RayEnd :> {4.211636102543155, -0.9174096462932262, 0.}, 
      RotationMatrix :> {{-0.8981055512395002, -0.43977996638409217`, 0.}, {
       0.43977996638409217`, -0.8981055512395002, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18113716219857534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23318359600313907`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.206692893289796`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39913294126605325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8981055512395002, -0.43977996638409217`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.3916852340172055`, 0.011356320668955004`, 
       0.}, Optica`Optica`RayEnd :> {4.165796928560684, 0.1098764015693789, 
       0.}, RotationMatrix :> {{-0.9166127857600603, 0.3997761886120555, 
       0.}, {-0.3997761886120555, -0.9166127857600603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06717310943434061, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2464380913792448, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.216741078003583`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24002600520805728`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9166127857600603, 0.3997761886120555, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.165796928560684, 0.1098764015693789, 0.}, 
      Optica`Optica`RayEnd :> {3.956690241253088, 0.17168039885872202`, 0.}, 
      RotationMatrix :> {{-0.9589896935910013, 0.2834409419724635, 
       0.}, {-0.2834409419724635, -0.9589896935910013, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06609561949505885, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21804894119829535`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.53945351097706, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41333141945532453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9589896935910013, 0.2834409419724635, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.917328532690551, 0.6491059597694256, 0.}, 
      Optica`Optica`RayEnd :> {4.891472330682532, 0.879007572435998, 0.}, 
      RotationMatrix :> {{-0.11176178065484343`, 0.9937350272506541, 
       0.}, {-0.9937350272506541, -0.11176178065484343`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025350327995798387`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23135102050557316`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.452569497534004`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3670018400589766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.11176178065484343`, 0.9937350272506541, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.891472330682532, 0.879007572435998, 0.}, 
      Optica`Optica`RayEnd :> {4.8894263217254865`, 1.1211417280571658`, 0.}, 
      RotationMatrix :> {{-0.00844959651558487, 0.999964301522171, 
       0.}, {-0.999964301522171, -0.00844959651558487, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02507899940711894, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2421427997505361, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.810940841164797`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3612111348500695, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.00844959651558487, 0.999964301522171, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.856008136082876, 0.892256352907218, 0.}, 
      Optica`Optica`RayEnd :> {5.877142979456383, 0.9362061847735541, 0.}, 
      RotationMatrix :> {{0.43337965196357453`, 0.9012114498073863, 
       0.}, {-0.9012114498073863, 0.43337965196357453`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009235389218195503, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04876750276056676, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.860003626880593`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0665618183291323, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.43337965196357453`, 0.9012114498073863, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.877142979456383, 0.9362061847735541, 0.}, 
      Optica`Optica`RayEnd :> {5.996981320663829, 1.1193631448066796`, 0.}, 
      RotationMatrix :> {{0.547511351917881, 0.8367982549701298, 
       0.}, {-0.8367982549701298, 0.547511351917881, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009064769491379732, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2188782767474384, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.183943476466801`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35940895295526976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.547511351917881, 0.8367982549701298, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.440801978911579, -0.6713898163737759, 0.}, 
      Optica`Optica`RayEnd :> {3.3397884269225475`, -0.6863708108810382, 0.}, 
      RotationMatrix :> {{-0.9891807031225911, -0.14670220369815834`, 0.}, {
       0.14670220369815834`, -0.9891807031225911, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23351496938053268`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10211840128922574`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.708473362761376`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18399781899913412`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9891807031225911, -0.14670220369815834`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3397884269225475`, -0.6863708108810382, 0.},
       Optica`Optica`RayEnd :> {3.060092723143652, -0.7433532091214999, 0.}, 
      RotationMatrix :> {{-0.979871513820895, -0.19962919726920533`, 0.}, {
       0.19962919726920533`, -0.979871513820895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23255393365007304`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28544120309024446`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.130926343334938`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13258783360653154`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.979871513820895, -0.19962919726920533`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.652262238794404, 1.3610242766510867`, 0.}, 
      Optica`Optica`RayEnd :> {2.634322296068684, 1.4088634427580893`, 0.}, 
      RotationMatrix :> {{-0.35112782469810205`, 0.9363275338912014, 
       0.}, {-0.9363275338912014, -0.35112782469810205`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015168831362062506`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.051092341488871894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.966363709711853`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27229770938974, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.35112782469810205`, 0.9363275338912014, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.634322296068684, 1.4088634427580893`, 0.}, 
      Optica`Optica`RayEnd :> {2.5179669445967625`, 1.6546179606098674`, 0.}, 
      RotationMatrix :> {{-0.42792208290091827`, 0.9038156288567595, 
       0.}, {-0.9038156288567595, -0.42792208290091827`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01506031858180493, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2719077984551275, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.368787251425442`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15180455766712608`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.42792208290091827`, 0.9038156288567595, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3652191267041047`, 0.8967965807865681, 0.}, 
      Optica`Optica`RayEnd :> {2.3584371703534224`, 0.8983914028520312, 0.}, 
      RotationMatrix :> {{-0.973446997041405, 0.22891252467060544`, 
       0.}, {-0.22891252467060544`, -0.973446997041405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2337839631807564, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.006966949789042982, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.834077281328776`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.029773360633715728`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.973446997041405, 0.22891252467060544`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3584371703534224`, 0.8983914028520312, 0.}, 
      Optica`Optica`RayEnd :> {2.22879531666272, 0.9020263899058154, 0.}, 
      RotationMatrix :> {{-0.999607147702107, 0.028027669593773064`, 
       0.}, {-0.028027669593773064`, -0.999607147702107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21848697272013848`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12969280380669815`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.02602263096269, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43213020045954514`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999607147702107, 0.028027669593773064`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.22879531666272, 0.9020263899058154, 0.}, 
      Optica`Optica`RayEnd :> {2.167926937343688, 0.7875044978575388, 0.}, 
      RotationMatrix :> {{-0.4693273453302296, -0.883024259533836, 0.}, {
       0.883024259533836, -0.4693273453302296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014296075282482465`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12969280380669806`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.217967980596603`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.033285636167506905`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4693273453302296, -0.883024259533836, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.423048150401369, 0.3838397198217184, 0.}, 
      Optica`Optica`RayEnd :> {2.070299296037435, -0.3079337586645584, 0.}, 
      RotationMatrix :> {{-0.4542692396463146, -0.8908644441839394, 0.}, {
       0.8908644441839394, -0.4542692396463146, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01350681722002278, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7765193492708801, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.214659757922732`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03639175218574628, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4542692396463146, -0.8908644441839394, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.070299296037435, -0.3079337586645584, 0.}, 
      Optica`Optica`RayEnd :> {1.9265945208348418`, -0.5911279665573725, 0.}, 
      RotationMatrix :> {{-0.45251523093629237`, -0.8917566740824955, 0.}, {
       0.8917566740824955, -0.45251523093629237`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01347350134962201, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3175689244873722, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.684661766164043`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4239510826250854, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45251523093629237`, -0.8917566740824955, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.592996513027466, 2.1249490237982482`, 0.}, 
      Optica`Optica`RayEnd :> {4.611110226660915, 2.157782503145335, 0.}, 
      RotationMatrix :> {{0.48305057166566157`, 0.8755924538353889, 
       0.}, {-0.8755924538353889, 0.48305057166566157`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011721950444193009`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.037498586475094325`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.020951113963944`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3244840146937712, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.48305057166566157`, 0.8755924538353889, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.611110226660915, 2.157782503145335, 0.}, 
      Optica`Optica`RayEnd :> {4.764975851525028, 2.414726189496874, 0.}, 
      RotationMatrix :> {{0.5137575793584906, 0.8579353994629807, 
       0.}, {-0.8579353994629807, 0.5137575793584906, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01168525852973367, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29949071516616743`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.464197372409872`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15207694573588917`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5137575793584906, 0.8579353994629807, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.495720909980971, 1.6579704444939585`, 0.}, 
      Optica`Optica`RayEnd :> {2.4243203082646443`, 1.7714919169140946`, 0.}, 
      RotationMatrix :> {{-0.532408022033309, 0.8464878605594882, 
       0.}, {-0.8464878605594882, -0.532408022033309, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24086062680934622`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13410880144826154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.254290965914677`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4325193251081551, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.532408022033309, 0.8464878605594882, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4243203082646443`, 1.7714919169140946`, 0.},
       Optica`Optica`RayEnd :> {2.312530256982746, 1.9047407108645917`, 0.}, 
      RotationMatrix :> {{-0.6427236300727108, 0.7660981238367296, 
       0.}, {-0.7660981238367296, -0.6427236300727108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23591873599117533`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1739317586148992, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.511709968664729`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17000553573826338`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6427236300727108, 0.7660981238367296, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9343541138804152`, 1.6684119244566258`, 0.},
       Optica`Optica`RayEnd :> {2.944238569475594, 1.8455352239882736`, 0.}, 
      RotationMatrix :> {{0.05571881351451869, 0.9984465002294987, 
       0.}, {-0.9984465002294987, 0.05571881351451869, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03091036261790038, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17739888866447537`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.228540983865383`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3861561720624508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.05571881351451869, 0.9984465002294987, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.944238569475594, 1.8455352239882736`, 0.}, 
      Optica`Optica`RayEnd :> {2.9696703051931497`, 2.143299400268076, 0.}, 
      RotationMatrix :> {{0.08509916162572595, 0.9963724869197256, 
       0.}, {-0.9963724869197256, 0.08509916162572595, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03082021752639167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29884825222376094`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.670836397156549`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3267006419953637, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08509916162572595, 0.9963724869197256, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3495590308742202`, -1.5735559140602946`, 
       0.}, Optica`Optica`RayEnd :> {2.344019420635874, -1.5839933710191287`, 
       0.}, RotationMatrix :> {{-0.4688061261135009, -0.883301090296198, 
       0.}, {0.883301090296198, -0.4688061261135009, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012595311974366787`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01181642032767567, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.856168923539181`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0040466111620024526`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4688061261135009, -0.883301090296198, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.344019420635874, -1.5839933710191287`, 0.}, 
      Optica`Optica`RayEnd :> {2.203960725449316, -1.846230942491997, 0.}, 
      RotationMatrix :> {{-0.4711083883678509, -0.8820753292148273, 0.}, {
       0.8820753292148273, -0.4711083883678509, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012564226001410135`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2972961183556703, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.296167178705574`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41778985332797475`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4711083883678509, -0.8820753292148273, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.122821027838444, -1.6979744077857233`, 0.}, 
      Optica`Optica`RayEnd :> {2.0942813412035988`, -1.7940861426641752`, 0.},
       RotationMatrix :> {{-0.28465800911072336`, -0.9586291346757194, 0.}, {
       0.9586291346757194, -0.28465800911072336`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21784691437421075`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10025955961683163`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.75224908555545, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05548554542372017, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.28465800911072336`, -0.9586291346757194, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0942813412035988`, -1.7940861426641752`, 
       0.}, Optica`Optica`RayEnd :> {1.9941947604424164`, -2.117172517617665, 
       0.}, RotationMatrix :> {{-0.29590942551059934`, -0.9552160027417811, 
       0.}, {0.9552160027417811, -0.29590942551059934`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21729486882195345`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3382338382377665, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.252835166147344`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3266802748514827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.29590942551059934`, -0.9552160027417811, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.17184458169658, -1.8244238040708087`, 0.}, 
      Optica`Optica`RayEnd :> {2.3314998299859577`, -2.030808955936765, 0.}, 
      RotationMatrix :> {{0.611869296866437, -0.790958888661207, 0.}, {
       0.790958888661207, 0.611869296866437, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04711475385647763, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26093031486792917`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.168265357109425`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21695876989596052`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.611869296866437, -0.790958888661207, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3314998299859577`, -2.030808955936765, 0.}, 
      Optica`Optica`RayEnd :> {2.4515426952274284`, -2.1199870179428464`, 0.},
       RotationMatrix :> {{0.8027330854934174, -0.5963384889928014, 0.}, {
       0.5963384889928014, 0.8027330854934174, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0386882498429953, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1495426903547691, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.389588538834483`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3142032390398948, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8027330854934174, -0.5963384889928014, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3031174647941777`, -1.8584853486187098`, 
       0.}, Optica`Optica`RayEnd :> {2.3538526555372528`, -1.856724289753587, 
       0.}, RotationMatrix :> {{0.9993981241324486, 0.03468990459114335, 
       0.}, {-0.03468990459114335, 0.9993981241324486, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010189724455510725`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.050765745420141915`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.087362293566894`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3237285598354256, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9993981241324486, 0.03468990459114335, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3538526555372528`, -1.856724289753587, 0.}, 
      Optica`Optica`RayEnd :> {2.6087330171752736`, -1.8690807179268634`, 0.},
       RotationMatrix :> {{0.9988269447904178, -0.04842245719332368, 0.}, {
       0.04842245719332368, 0.9988269447904178, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01011723167946918, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25517970151626407`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.465028251810965`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2128961421464088, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9988269447904178, -0.04842245719332368, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9545503044322277`, -1.6599496305216161`, 
       0.}, Optica`Optica`RayEnd :> {
       2.8843245852369903`, -1.7199217785169294`, 0.}, 
      RotationMatrix :> {{-0.7604395602658442, -0.6494087119701191, 0.}, {
       0.6494087119701191, -0.7604395602658442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26301713298528495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09234885040789663, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.122421176742902`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4113170013809804, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7604395602658442, -0.6494087119701191, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8843245852369903`, -1.7199217785169294`, 
       0.}, Optica`Optica`RayEnd :> {
       2.6583334482814975`, -1.8881915848497568`, 0.}, 
      RotationMatrix :> {{-0.8020796044115993, -0.5972171365482842, 0.}, {
       0.5972171365482842, -0.8020796044115993, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2616521920850118, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2817564936354149, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.539420787323316`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3902640830703706, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8020796044115993, -0.5972171365482842, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1711990803001635`, -0.4115125146935025, 0.},
       Optica`Optica`RayEnd :> {3.1507501855607156`, -0.41455067932681255`, 
       0.}, RotationMatrix :> {{-0.9891423790165267, -0.1469603825305497, 
       0.}, {0.1469603825305497, -0.9891423790165267, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008945336412051759, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02067335822753806, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.994739274294433`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3395107008886745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9891423790165267, -0.1469603825305497, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1507501855607156`, -0.41455067932681255`, 
       0.}, Optica`Optica`RayEnd :> {2.844387562893518, -0.4646491925784466, 
       0.}, RotationMatrix :> {{-0.986891802294198, -0.16138330323955222`, 
       0.}, {0.16138330323955222`, -0.986891802294198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008922328194784484, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3104318243955474, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.454178374399843`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.011706717323782838`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.986891802294198, -0.16138330323955222`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8956096724243867`, 0.5941363996724759, 0.}, 
      Optica`Optica`RayEnd :> {2.874159596136431, 0.6005179289230769, 0.}, 
      RotationMatrix :> {{-0.9584816626210209, 0.28515417307001395`, 
       0.}, {-0.28515417307001395`, -0.9584816626210209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21619370086259623`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022379224480204764`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.336716437984848`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1253400390121111, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9584816626210209, 0.28515417307001395`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.874159596136431, 0.6005179289230769, 0.}, 
      Optica`Optica`RayEnd :> {2.5947838776974526`, 0.699565467163501, 0.}, 
      RotationMatrix :> {{-0.942518915857385, 0.3341527992565968, 
       0.}, {-0.3341527992565968, -0.942518915857385, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21533601896397675`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29641391142249646`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.775409026890141`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.056082938237452765`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.942518915857385, 0.3341527992565968, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.3638619846663005`, 1.897890825549716, 0.}, 
      Optica`Optica`RayEnd :> {4.3728757462880425`, 2.152400317364623, 0.}, 
      RotationMatrix :> {{0.03539401950614821, 0.9993734353999999, 
       0.}, {-0.9993734353999999, 0.03539401950614821, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009261000887279972, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2546690584316357, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.227855329488843`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20412274565843413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.03539401950614821, 0.9993734353999999, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.3728757462880425`, 2.152400317364623, 0.}, 
      Optica`Optica`RayEnd :> {4.352532376797479, 2.369357454152633, 0.}, 
      RotationMatrix :> {{-0.09335725790224841, 0.9956326744321786, 
       0.}, {-0.9956326744321786, -0.09335725790224841, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009097216469408765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21790881552952593`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.550360376472542`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11571360441649856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.09335725790224841, 0.9956326744321786, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.186980434491088, 1.4262010764902882`, 0.}, 
      Optica`Optica`RayEnd :> {6.350438183835544, 1.5591974553303574`, 0.}, 
      RotationMatrix :> {{0.7756796117964934, 0.6311268809385652, 
       0.}, {-0.6311268809385652, 0.7756796117964934, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01107592380966364, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2107284333100927, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.836646252722499`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17172972739441886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.7756796117964934, 0.6311268809385652, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.350438183835544, 1.5591974553303574`, 0.}, 
      Optica`Optica`RayEnd :> {6.52218963097219, 1.6623099573089042`, 0.}, 
      RotationMatrix :> {{0.8573571608444222, 0.514721962566969, 
       0.}, {-0.514721962566969, 0.8573571608444222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010822634391580802`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20032660247158396`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.133129624380443`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18767161616622063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.8573571608444222, 0.514721962566969, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.3477706183017695`, 1.0780641496062522`, 0.},
       Optica`Optica`RayEnd :> {4.284510727295245, 1.1144763410521983`, 0.}, 
      RotationMatrix :> {{-0.8666827001332426, 0.49885979722738955`, 
       0.}, {-0.49885979722738955`, -0.8666827001332426, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.43789635368952373`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07299083158899818, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.542822825612381`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1609195190854098, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8666827001332426, 0.49885979722738955`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.284510727295245, 1.1144763410521983`, 0.}, 
      Optica`Optica`RayEnd :> {4.096591811836374, 1.2499734969440517`, 0.}, 
      RotationMatrix :> {{-0.8111339329234585, 0.5848604473377582, 
       0.}, {-0.5848604473377582, -0.8111339329234585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4333137727847597, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23167433617476849`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.885700843151039`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06256198459982122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8111339329234585, 0.5848604473377582, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.886363500432843, -0.05497944326763965, 0.}, 
      Optica`Optica`RayEnd :> {3.766450187298416, -0.08152062867129992, 0.}, 
      RotationMatrix :> {{-0.9763698579625721, -0.21610622495001539`, 0.}, {
       0.21610622495001539`, -0.9763698579625721, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00990728218981653, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12281545989616517`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.037024668272371`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08962039973658253, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9763698579625721, -0.21610622495001539`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.766450187298416, -0.08152062867129992, 0.}, 
      Optica`Optica`RayEnd :> {3.560933992060265, -0.15747189595957234`, 0.}, 
      RotationMatrix :> {{-0.9379950480456531, -0.3466486547526657, 0.}, {
       0.3466486547526657, -0.9379950480456531, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00970568834935842, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21910157805880925`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.361295003799409`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24818859621682585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9379950480456531, -0.3466486547526657, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.335781837376667, -0.5225924266413898, 0.}, 
      Optica`Optica`RayEnd :> {5.1406776893927555`, -0.5831849702109122, 0.}, 
      RotationMatrix :> {{-0.9550045624258553, -0.29659110867623917`, 0.}, {
       0.29659110867623917`, -0.9550045624258553, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028827781455019248`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2042965611476427, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.711018099010078`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2769843381764971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9550045624258553, -0.29659110867623917`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1406776893927555`, -0.5831849702109122, 0.},
       Optica`Optica`RayEnd :> {4.908455139197296, -0.6337664010897093, 0.}, 
      RotationMatrix :> {{-0.9770904560336162, -0.21282443639774998`, 0.}, {
       0.21282443639774998`, -0.9770904560336162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028607857665319522`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23766740199074157`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.062765853956375`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3882220122721848, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9770904560336162, -0.21282443639774998`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.624663377518157, -0.777283667465705, 0.}, 
      Optica`Optica`RayEnd :> {5.285262011497718, -0.8898514129071506, 0.}, 
      RotationMatrix :> {{-0.9491571208775148, -0.31480273170273915`, 0.}, {
       0.31480273170273915`, -0.9491571208775148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02075453185408701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3575818571604415, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.53898230446386, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005496196215492466, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9491571208775148, -0.31480273170273915`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.285262011497718, -0.8898514129071506, 0.}, 
      Optica`Optica`RayEnd :> {5.147244857449752, -0.8967049223682861, 0.}, 
      RotationMatrix :> {{-0.9987693695924061, -0.049595830106850314`, 0.}, {
       0.049595830106850314`, -0.9987693695924061, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017174531323319905`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1381872114322954, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.743499377383657`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4092966991525711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9987693695924061, -0.049595830106850314`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.6616951298003775`, -0.6959549043217395, 0.},
       Optica`Optica`RayEnd :> {6.649809728695999, -0.6757401709390647, 0.}, 
      RotationMatrix :> {{-0.506842111659063, 0.8620389050669244, 
       0.}, {-0.8620389050669244, -0.506842111659063, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015423351977895943`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023449908425079054`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.46427112346515, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06493765506389962, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.506842111659063, 0.8620389050669244, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.649809728695999, -0.6757401709390647, 0.}, 
      Optica`Optica`RayEnd :> {6.477344047574457, -0.3900611068834905, 0.}, 
      RotationMatrix :> {{-0.5168256340031118, 0.8560906868067668, 
       0.}, {-0.8560906868067668, -0.5168256340031118, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015384292576962095`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3337018711430702, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.958149892756893`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4084553865236776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5168256340031118, 0.8560906868067668, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.903791814934578, -0.8427133549804139, 0.}, 
      Optica`Optica`RayEnd :> {6.952683447459978, -0.8740524240884584, 0.}, 
      RotationMatrix :> {{0.8418926026039051, -0.539645110865301, 0.}, {
       0.539645110865301, 0.8418926026039051, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.502044578431068, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058073479175589124`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.929663171507856`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2547176059747129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8418926026039051, -0.539645110865301, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.952683447459978, -0.8740524240884584, 0.}, 
      Optica`Optica`RayEnd :> {7.098021325764257, -0.9968067045346964, 0.}, 
      RotationMatrix :> {{0.7639663868748405, -0.6452560419906204, 0.}, {
       0.6452560419906204, 0.7639663868748405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.400012755553523, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19024119490232136`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.211220139963292`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3885508337415809, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7639663868748405, -0.6452560419906204, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.098021325764257, -0.9968067045346964, 0.}, 
      Optica`Optica`RayEnd :> {6.997752704567444, -1.1584789527443164`, 0.}, 
      RotationMatrix :> {{-0.5270605099400041, -0.8498277583497627, 0.}, {
       0.8498277583497627, -0.5270605099400041, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10013970936750122`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19024119490232122`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.492777108418727`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10922620444350448`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5270605099400041, -0.8498277583497627, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.621496895843233, -0.8213024594383405, 0.}, 
      Optica`Optica`RayEnd :> {6.386503912598267, -0.79754594807913, 0.}, 
      RotationMatrix :> {{-0.9949287837009535, 0.10058188387249878`, 
       0.}, {-0.10058188387249878`, -0.9949287837009535, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015337483644859371`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23619075766491968`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.587336787920584`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3739427812869002, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9949287837009535, 0.10058188387249878`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.386503912598267, -0.79754594807913, 0.}, 
      Optica`Optica`RayEnd :> {6.084428116973464, -0.7640639246493693, 0.}, 
      RotationMatrix :> {{-0.9939132948195543, 0.11016515956025943`, 
       0.}, {-0.11016515956025943`, -0.9939132948195543, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015298968107760425`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3039257017682273, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.03714682653756, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009225479041633539, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9939132948195543, 0.11016515956025943`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.574334237508879, -0.139023951860052, 0.}, 
      Optica`Optica`RayEnd :> {6.577263296573113, -0.10557389463469018`, 0.}, 
      RotationMatrix :> {{0.08723135229332263, 0.9961880802223434, 
       0.}, {-0.9961880802223434, 0.08723135229332263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01974539408494728, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03357805407378091, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.250307544241366`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009878968941908298, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.08723135229332263, 0.9961880802223434, 0.}],
      
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.577263296573113, -0.10557389463469018`, 0.},
       Optica`Optica`RayEnd :> {6.584222943013781, 0.1716058667428289, 0.}, 
      RotationMatrix :> {{0.025100871668764846`, 0.9996849234841286, 
       0.}, {-0.9996849234841286, 0.025100871668764846`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01965111971513255, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2772671217362014, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.660662884410945`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.015221544269966802`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.025100871668764846`, 0.9996849234841286, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5835171622575075`, 0.5978111898525217, 0.}, 
      Optica`Optica`RayEnd :> {6.601474680697096, 0.6918967745999689, 0.}, 
      RotationMatrix :> {{0.18747936257188869`, 0.9822685420034779, 
       0.}, {-0.9822685420034779, 0.18747936257188869`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029499901700446484`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09578397426384659, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.438877597517532`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14398511729398802`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.18747936257188869`, 0.9822685420034779, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.601474680697096, 0.6918967745999689, 0.}, 
      Optica`Optica`RayEnd :> {6.672516915681058, 0.8885179867466502, 0.}, 
      RotationMatrix :> {{0.3398142700950556, 0.9404925634154502, 
       0.}, {-0.9404925634154502, 0.3398142700950556, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.028596646778779558`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20906195306068182`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.74828928804734, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41678675653064934`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3398142700950556, 0.9404925634154502, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5368369334040395`, 0.16326730455128366`, 
       0.}, Optica`Optica`RayEnd :> {5.348854642305988, 0.16858535696493876`, 
       0.}, RotationMatrix :> {{-0.999600072964193, 0.028278863661387585`, 
       0.}, {-0.028278863661387585`, -0.999600072964193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11402359536099986`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1880575003767379, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.254190727426376`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24984600861103534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.999600072964193, 0.028278863661387585`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.348854642305988, 0.16858535696493876`, 0.}, 
      Optica`Optica`RayEnd :> {5.062238178947538, 0.1912066990993062, 0.}, 
      RotationMatrix :> {{-0.9968998603720471, 0.07868080064534219, 
       0.}, {-0.07868080064534219, -0.9968998603720471, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1135790028857132, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2875077776131728, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.679702238293872`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17914233942716692`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9968998603720471, 0.07868080064534219, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.447483270690153, 0.11587933936681133`, 0.}, 
      Optica`Optica`RayEnd :> {5.325030926814644, -0.026245639924664915`, 0.},
       RotationMatrix :> {{-0.6527280186041213, -0.7575923268679121, 0.}, {
       0.7575923268679121, -0.6527280186041213, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04389862265346749, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18760086955877528`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.403268944481907`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1320394201390007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6527280186041213, -0.7575923268679121, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.325030926814644, -0.026245639924664915`, 
       0.}, Optica`Optica`RayEnd :> {5.1212892282563045`, -0.285848443696126, 
       0.}, RotationMatrix :> {{-0.617386910539281, -0.7866596485741222, 
       0.}, {0.7866596485741222, -0.617386910539281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04373972409248053, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3300065082046727, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.891678576624821`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23809339224779136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.617386910539281, -0.7866596485741222, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.42785836360701, 0.01665958676336221, 0.}, 
      Optica`Optica`RayEnd :> {5.4982581522663425`, -0.377555216146243, 0.}, 
      RotationMatrix :> {{0.17580101582467716`, -0.9844257223554306, 0.}, {
       0.9844257223554306, 0.17580101582467716`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02383006559327609, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.40045154647764514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.838178953904793`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24649777932841221`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17580101582467716`, -0.9844257223554306, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.4982581522663425`, -0.377555216146243, 0.}, 
      Optica`Optica`RayEnd :> {5.548883626199007, -0.6931337635867161, 0.}, 
      RotationMatrix :> {{0.1583959427732378, -0.9873756758767034, 0.}, {
       0.9873756758767034, 0.1583959427732378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02376757003658947, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31961345124313173`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.311206861744628`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09805911887384833, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1583959427732378, -0.9873756758767034, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.492443700937656, -0.061176333521544085`, 
       0.}, Optica`Optica`RayEnd :> {5.6973141732691275`, -0.1747465325449184,
        0.}, RotationMatrix :> {{0.8746040633773366, -0.4848378412663883, 
       0.}, {0.4848378412663883, 0.8746040633773366, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01293598732385119, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2342436776938262, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.765150512086075`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42492984283969715`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8746040633773366, -0.4848378412663883, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.6973141732691275`, -0.1747465325449184, 0.},
       Optica`Optica`RayEnd :> {5.903281161164852, -0.3033895933541004, 0.}, 
      RotationMatrix :> {{0.8481579979841073, -0.5297433439464726, 0.}, {
       0.5297433439464726, 0.8481579979841073, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01288417361574604, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2428403533130198, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.124554234989345`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40563490163435717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8481579979841073, -0.5297433439464726, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.612509852193087, 0.3238578492146921, 0.}, 
      Optica`Optica`RayEnd :> {6.5127792552332116`, 0.4029728818525733, 0.}, 
      RotationMatrix :> {{-0.7834274855973037, 0.6214832055741216, 
       0.}, {-0.6214832055741216, -0.7834274855973037, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009989826860471058, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12730035490628477`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.22453395140403, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09870181037706167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7834274855973037, 0.6214832055741216, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5127792552332116`, 0.4029728818525733, 0.}, 
      Optica`Optica`RayEnd :> {6.34098319847574, 0.5569745163120173, 0.}, 
      RotationMatrix :> {{-0.7446177303798583, 0.6674911502064638, 
       0.}, {-0.6674911502064638, -0.7446177303798583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00994384498497979, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2307171179899678, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.565995286029183`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10704613736909331`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7446177303798583, 0.6674911502064638, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.898387262851132, 0.1809591662737341, 0.}, 
      Optica`Optica`RayEnd :> {6.97435174451669, 0.14200277352684282`, 0.}, 
      RotationMatrix :> {{0.8898162818393892, -0.4563189504869638, 0.}, {
       0.4563189504869638, 0.8898162818393892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9473277431581772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0853709728805229, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.641360671956157`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.421326521649622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8898162818393892, -0.4563189504869638, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.97435174451669, 0.14200277352684282`, 0.}, 
      Optica`Optica`RayEnd :> {7.1533879505423, 0.03752729228343482, 0.}, 
      RotationMatrix :> {{0.8636997457535194, -0.5040066955758679, 0.}, {
       0.5040066955758679, 0.8636997457535194, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.93090829127967, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20728986769518293`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.948149676145027`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4188139381942175, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8636997457535194, -0.5040066955758679, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1533879505423, 0.03752729228343482, 0.}, 
      Optica`Optica`RayEnd :> {6.964087541651995, -0.04693834832296653, 0.}, 
      RotationMatrix :> {{-0.9132159279905991, -0.4074759733582686, 0.}, {
       0.4074759733582686, -0.9132159279905991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016351152913349525`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20728986769518284`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.254938680333897`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38968147660692454`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9132159279905991, -0.4074759733582686, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5900884129714665`, 0.26520729191273357`, 
       0.}, Optica`Optica`RayEnd :> {6.400758126154542, 0.3190506142465829, 
       0.}, RotationMatrix :> {{-0.9618601208589481, 0.27354178456171807`, 
       0.}, {-0.27354178456171807`, -0.9618601208589481, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0099395803753412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19683765103791986`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.263738113153718`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3919858463538214, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9618601208589481, 0.27354178456171807`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.400758126154542, 0.3190506142465829, 0.}, 
      Optica`Optica`RayEnd :> {6.103008723708266, 0.39029214819013164`, 0.}, 
      RotationMatrix :> {{-0.9725488945092793, 0.2326986200835291, 
       0.}, {-0.2326986200835291, -0.9725488945092793, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009905449424197901, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3061536588312212, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.716845528223924`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2888314719036447, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9725488945092793, 0.2326986200835291, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.7103606959140265`, 0.5772951254941001, 0.}, 
      Optica`Optica`RayEnd :> {6.739719792815295, 0.3986426170525476, 0.}, 
      RotationMatrix :> {{0.16216121622643997`, -0.9867642778049686, 0.}, {
       0.9867642778049686, 0.16216121622643997`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3027382676488262, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1810488203311943, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.507204747164353`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27303061022757047`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.16216121622643997`, -0.9867642778049686, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.739719792815295, 0.3986426170525476, 0.}, 
      Optica`Optica`RayEnd :> {6.788286169112373, 0.08275477138089243, 0.}, 
      RotationMatrix :> {{0.15196012574472711`, -0.9883866248506431, 0.}, {
       0.9883866248506431, 0.15196012574472711`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3019759219363605, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.319599474263818, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.980211969074803`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13459558071028083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15196012574472711`, -0.9883866248506431, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.935844594623621, 0.7973177727561169, 0.}, 
      Optica`Optica`RayEnd :> {6.9767342513768655`, 0.8415684967397441, 0.}, 
      RotationMatrix :> {{0.6786638751632282, 0.734449007452818, 
       0.}, {-0.734449007452818, 0.6786638751632282, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      75.48651860593858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0602502332150948, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.811600305249513`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3474992186145835, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6786638751632282, 0.734449007452818, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9767342513768655`, 0.8415684967397441, 0.}, 
      Optica`Optica`RayEnd :> {7.156710522321821, 1.057504153542214, 0.}, 
      RotationMatrix :> {{0.6402471506018536, 0.7681689828066522, 
       0.}, {-0.7681689828066522, 0.6402471506018536, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      75.18908972622434, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2811043684860949, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.227634770608933`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29101472326364913`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6402471506018536, 0.7681689828066522, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.156710522321821, 1.057504153542214, 0.}, 
      Optica`Optica`RayEnd :> {6.875687281178761, 1.0642572209501147`, 0.}, 
      RotationMatrix :> {{-0.999711397786268, 0.02402334565012143, 
       0.}, {-0.02402334565012143, -0.999711397786268, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.29625696266042756`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28110436848609477`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.643669235968353`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2282363266626249, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999711397786268, 0.02402334565012143, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.623695705447773, 0.8399326160826954, 0.}, 
      Optica`Optica`RayEnd :> {6.188869344374059, 0.8765301252217953, 0.}, 
      RotationMatrix :> {{-0.9964767665561046, 0.08386926560957816, 
       0.}, {-0.08386926560957816, -0.9964767665561046, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.30033408350038, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.43636377251072833`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.781858112726397`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25508391160095134`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9964767665561046, 0.08386926560957816, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.188869344374059, 0.8765301252217953, 0.}, 
      Optica`Optica`RayEnd :> {5.881209576075601, 0.9157210836573269, 0.}, 
      RotationMatrix :> {{-0.9919840705344243, 0.12636298431880122`, 
       0.}, {-0.12636298431880122`, -0.9919840705344243, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29929508032626695`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3101458757626098, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.240874008855059`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12777387698494808`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9919840705344243, 0.12636298431880122`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.4874006132775435`, 0.8597499173682634, 0.}, 
      Optica`Optica`RayEnd :> {6.471949617710071, 0.6611436641888342, 0.}, 
      RotationMatrix :> {{-0.077562759262289, -0.9969874715239, 0.}, {
       0.9969874715239, -0.077562759262289, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00955475567383658, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1992063680357573, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.877715919282412`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2451395777162983, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.077562759262289, -0.9969874715239, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.471949617710071, 0.6611436641888342, 0.}, 
      Optica`Optica`RayEnd :> {6.453084848827884, 0.3971828149358141, 0.}, 
      RotationMatrix :> {{-0.07128623460586464, -0.9974559001558498, 0.}, {
       0.9974559001558498, -0.07128623460586464, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009531017240429419, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2646341048378949, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.269374394442497`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3046206660767583, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.07128623460586464, -0.9974559001558498, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.385731150277527, 1.1815774722078438`, 0.}, 
      Optica`Optica`RayEnd :> {6.364102736692175, 1.2549358388771608`, 0.}, 
      RotationMatrix :> {{-0.282797138434122, 0.9591797425370655, 
       0.}, {-0.9591797425370655, -0.282797138434122, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.581610199262495, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07648031272562254, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.212770470364214`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4054293183948725, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.282797138434122, 0.9591797425370655, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.364102736692175, 1.2549358388771608`, 0.}, 
      Optica`Optica`RayEnd :> {6.285753978708785, 1.4070605913421486`, 0.}, 
      RotationMatrix :> {{-0.4578709686016178, 0.8890186590346771, 
       0.}, {-0.8890186590346771, -0.4578709686016178, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.3948656574795173`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17111536514899403`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.466021210784726`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0027900045169841903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4578709686016178, 0.8890186590346771, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.285753978708785, 1.4070605913421486`, 0.}, 
      Optica`Optica`RayEnd :> {6.114937969488056, 1.3969433197743022`, 0.}, 
      RotationMatrix :> {{-0.9982505607956075, -0.059125441827138636`, 0.}, {
       0.059125441827138636`, -0.9982505607956075, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1770077133886069, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17111536514899411`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.719271951205238`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4021384659421463, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9982505607956075, -0.059125441827138636`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.114937969488056, 1.3969433197743022`, 0.}, 
      Optica`Optica`RayEnd :> {6.055094413422918, 1.2366335665228163`, 0.}, 
      RotationMatrix :> {{-0.3497263732747259, -0.9368518900210996, 0.}, {
       0.9368518900210996, -0.3497263732747259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00922915183109922, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17111536514899428`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.97252269162575, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10906585269068017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3497263732747259, -0.9368518900210996, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.595407208774853, 0.9171051574870768, 0.}, 
      Optica`Optica`RayEnd :> {6.639117835616823, 0.8597328288639436, 0.}, 
      RotationMatrix :> {{0.6060289730501683, -0.7954425710406489, 0.}, {
       0.7954425710406489, 0.6060289730501683, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009504114203310814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07212629888299157, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.70644355701247, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.334690289176042, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6060289730501683, -0.7954425710406489, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.639117835616823, 0.8597328288639436, 0.}, 
      Optica`Optica`RayEnd :> {6.853458526119032, 0.5885561136172155, 0.}, 
      RotationMatrix :> {{0.6200965340821851, -0.7845255180166294, 0.}, {
       0.7845255180166294, 0.6200965340821851, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009479162575955621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34565697229618986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.218015876010831`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011643400025154542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6200965340821851, -0.7845255180166294, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.17426127708289, 0.6847681835117939, 0.}, 
      Optica`Optica`RayEnd :> {5.9129569581717885`, 0.7325369742730579, 0.}, 
      RotationMatrix :> {{-0.983697910208221, 0.17982886712643842`, 
       0.}, {-0.17982886712643842`, -0.983697910208221, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16895981105816463`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26563471996783194`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.21509455502515, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3571177824801786, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.983697910208221, 0.17982886712643842`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.9129569581717885`, 0.7325369742730579, 0.}, 
      Optica`Optica`RayEnd :> {5.615981264787904, 0.7888893143257181, 0.}, 
      RotationMatrix :> {{-0.9824687359397828, 0.18642741992766196`, 
       0.}, {-0.18642741992766196`, -0.9824687359397828, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16853957652470247`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30227495544660876`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.66246148908613, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06153502189175683, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9824687359397828, 0.18642741992766196`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.149860507509465, 0.15542061427856801`, 0.}, 
      Optica`Optica`RayEnd :> {6.145120821954897, 0.14548131807801748`, 0.}, 
      RotationMatrix :> {{-0.4304285643566291, -0.9026246456783079, 0.}, {
       0.9026246456783079, -0.4304285643566291, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008022282813701877, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0110115497600681, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.333030844018273`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11918276307359899`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 57, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4304285643566291, -0.9026246456783079, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.976148157166832, -0.6651470108793203, 0.}, 
      Optica`Optica`RayEnd :> {4.922093988224713, -0.6914005885171679, 0.}, 
      RotationMatrix :> {{-0.8995166891795418, -0.43688639929331174`, 0.}, {
       0.43688639929331174`, -0.8995166891795418, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20161946098232789`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06009245808593309, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.262055174778686`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3966999261127353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8995166891795418, -0.43688639929331174`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.922093988224713, -0.6914005885171679, 0.}, 
      Optica`Optica`RayEnd :> {4.655926041426688, -0.8105216709669426, 0.}, 
      RotationMatrix :> {{-0.9127595064292533, -0.40849734812239014`, 0.}, {
       0.40849734812239014`, -0.9127595064292533, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2010189555938405, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29160797003285505`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.693634970427311`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32621674442819887`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9127595064292533, -0.40849734812239014`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.090655489293798, 0.7360701536815027, 0.}, 
      Optica`Optica`RayEnd :> {4.813642807021752, 0.8598979484814954, 0.}, 
      RotationMatrix :> {{-0.9129397491423096, 0.40809436952251166`, 
       0.}, {-0.40809436952251166`, -0.9129397491423096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0769320666836668, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3034293145109464, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.804988898707832`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03650660548058359, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9129397491423096, 0.40809436952251166`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.813642807021752, 0.8598979484814954, 0.}, 
      Optica`Optica`RayEnd :> {4.679967194926414, 0.8613803822979871, 0.}, 
      RotationMatrix :> {{-0.9999385140040391, 0.011089103272740763`, 
       0.}, {-0.011089103272740763`, -0.9999385140040391, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017436484983645455`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13368383177887855`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.002840969740571`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4072714083041462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9999385140040391, 0.011089103272740763`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.679967194926414, 0.8613803822979871, 0.}, 
      Optica`Optica`RayEnd :> {4.593536982293348, 0.7593941811564283, 0.}, 
      RotationMatrix :> {{-0.6465270443177235, -0.7628910675619344, 0.}, {
       0.7628910675619344, -0.6465270443177235, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013484543723114452`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13368383177887846`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.200693040773311`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13027509750710914`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6465270443177235, -0.7628910675619344, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.593536982293348, 0.7593941811564283, 0.}, 
      Optica`Optica`RayEnd :> {4.616922886965641, 0.6277717425612483, 0.}, 
      RotationMatrix :> {{0.17493442820351796`, -0.9845800860413071, 0.}, {
       0.9845800860413071, 0.17493442820351796`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010428301322837948`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13368383177887863`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.398545111806051`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28858966841049677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.17493442820351796`, -0.9845800860413071, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.616922886965641, 0.6277717425612483, 0.}, 
      Optica`Optica`RayEnd :> {4.733194800845937, 0.5618004691030476, 0.}, 
      RotationMatrix :> {{0.8697530010406669, -0.49348730194479473`, 0.}, {
       0.49348730194479473`, 0.8697530010406669, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008064749591302904, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13368383177887883`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.59639718283879, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28242947535571095`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8697530010406669, -0.49348730194479473`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.043512798331155, 0.6573804419320666, 0.}, 
      Optica`Optica`RayEnd :> {6.210986383001262, 0.6311070841589409, 0.}, 
      RotationMatrix :> {{0.987916824561663, -0.15498499200890262`, 0.}, {
       0.15498499200890262`, 0.987916824561663, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10033799533117782`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16952194810976592`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.053684442883842`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3749703932441102, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.987916824561663, -0.15498499200890262`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.210986383001262, 0.6311070841589409, 0.}, 
      Optica`Optica`RayEnd :> {6.382123401893994, 0.6275245760517915, 0.}, 
      RotationMatrix :> {{0.9997809648895369, -0.020928980972465233`, 0.}, {
       0.020928980972465233`, 0.9997809648895369, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09835373539021006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17117451212090246`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.307022720822777`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07835764855033917, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9997809648895369, -0.020928980972465233`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.899262128321833, 0.8727879726536775, 0.}, 
      Optica`Optica`RayEnd :> {5.841682554284794, 0.9015937670123577, 0.}, 
      RotationMatrix :> {{-0.8943277182840005, 0.44741248564264746`, 
       0.}, {-0.44741248564264746`, -0.8943277182840005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09049666492455452, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06438308112323816, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.970731925324905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0012219466370474161`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8943277182840005, 0.44741248564264746`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.841682554284794, 0.9015937670123577, 0.}, 
      Optica`Optica`RayEnd :> {5.712539000534084, 0.9118442775173976, 0.}, 
      RotationMatrix :> {{-0.9968647702960146, 0.07912414133924511, 
       0.}, {-0.07912414133924511, -0.9968647702960146, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.034900456856099216`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12954972188691216`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.162465513717535`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38738138157021235`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9968647702960146, 0.07912414133924511, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.712539000534084, 0.9118442775173976, 0.}, 
      Optica`Optica`RayEnd :> {5.622717590410879, 0.8184888024532366, 0.}, 
      RotationMatrix :> {{-0.6933354145029623, -0.720615017187405, 0.}, {
       0.720615017187405, -0.6933354145029623, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02144093445513161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12954972188691236`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.354199102110165`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15925605365526566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6933354145029623, -0.720615017187405, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.622717590410879, 0.8184888024532366, 0.}, 
      Optica`Optica`RayEnd :> {5.637941798653708, 0.6898367370817262, 0.}, 
      RotationMatrix :> {{0.11751633288814578`, -0.9930709498845091, 0.}, {
       0.9930709498845091, 0.11751633288814578`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01317213904117977, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12954972188691266`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.545932690502795`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2654814456031151, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.11751633288814578`, -0.9930709498845091, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.637941798653708, 0.6898367370817262, 0.}, 
      Optica`Optica`RayEnd :> {5.747071877350697, 0.620024443289261, 0.}, 
      RotationMatrix :> {{0.8423798762937615, -0.53888416567506, 0.}, {
       0.53888416567506, 0.8423798762937615, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008092242774364275, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.129549721886913, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.737666278895427`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30289672433054965`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8423798762937615, -0.53888416567506, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.934985647022961, 1.0862925640458698`, 0.}, 
      Optica`Optica`RayEnd :> {6.02114616024396, 1.3648656312182066`, 0.}, 
      RotationMatrix :> {{0.2954819128541646, 0.9553483339473843, 
       0.}, {-0.9553483339473843, 0.2954819128541646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.441569506365835, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2915931888647423, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.595572896446642`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2465199515033849, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2954819128541646, 0.9553483339473843, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.02114616024396, 1.3648656312182066`, 0.}, 
      Optica`Optica`RayEnd :> {6.10158126102411, 1.6554902335190946`, 0.}, 
      RotationMatrix :> {{0.26673876034450883`, 0.9637688694546394, 
       0.}, {-0.9637688694546394, 0.26673876034450883`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.428545035069252, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3015501034655141, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.041867049575602`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012216172299766872`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26673876034450883`, 0.9637688694546394, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.10158126102411, 1.6554902335190946`, 0.}, 
      Optica`Optica`RayEnd :> {5.8798616310272624`, 1.4511061084650112`, 0.}, 
      RotationMatrix :> {{-0.7352663038373112, -0.6777783283946291, 0.}, {
       0.6777783283946291, -0.7352663038373112, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0129862782991946, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.301550103465514, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.488161202704562`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22497567839677457`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7352663038373112, -0.6777783283946291, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.151457852592751, 1.0858869168008731`, 0.}, 
      Optica`Optica`RayEnd :> {6.298381427932044, 1.0657737383879953`, 0.}, 
      RotationMatrix :> {{0.9907594861945902, -0.1356305294372569, 0.}, {
       0.1356305294372569, 0.9907594861945902, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08698668081496037, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14829388704983434`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.723931258762788`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10415811769891664`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9907594861945902, -0.1356305294372569, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.298381427932044, 1.0657737383879953`, 0.}, 
      Optica`Optica`RayEnd :> {6.637302678486836, 1.0169603213082352`, 0.}, 
      RotationMatrix :> {{0.9897868983256409, -0.14255488733433927`, 0.}, {
       0.14255488733433927`, 0.9897868983256409, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08677016129752341, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34241840453548444`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.230710497475304`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41271578466901077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9897868983256409, -0.14255488733433927`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.343756785437981, 1.0083714905520778`, 0.}, 
      Optica`Optica`RayEnd :> {5.161225427054131, 1.0561727505257825`, 0.}, 
      RotationMatrix :> {{-0.9673781618517749, 0.25333671658936446`, 
       0.}, {-0.25333671658936446`, -0.9673781618517749, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10224517467300984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1886866642042501, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.949030060114136`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32559806674320074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9673781618517749, 0.25333671658936446`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.161225427054131, 1.0561727505257825`, 0.}, 
      Optica`Optica`RayEnd :> {4.879946877019573, 1.1112905707736813`, 0.}, 
      RotationMatrix :> {{-0.9813366916595402, 0.19229741964651353`, 
       0.}, {-0.19229741964651353`, -0.9813366916595402, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1017535771684494, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2866279763359166, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.373239465091293`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3315840030094588, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9813366916595402, 0.19229741964651353`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.143881683462895, 0.3832461284525548, 0.}, 
      Optica`Optica`RayEnd :> {7.32151291507871, 0.3484715981465151, 0.}, 
      RotationMatrix :> {{0.9813712090598536, -0.19212118578751253`, 0.}, {
       0.19212118578751253`, 0.9813712090598536, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07497800311401193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18100310053520355`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.667935942365967`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.312668710117008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9813712090598536, -0.19212118578751253`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.32151291507871, 0.3484715981465151, 0.}, 
      Optica`Optica`RayEnd :> {7.5841933507179515`, 0.3253409192139103, 0.}, 
      RotationMatrix :> {{0.9961454416211456, -0.08771692617398118, 0.}, {
       0.08771692617398118, 0.9961454416211456, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07414352473640408, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.263696870621373, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.0582073108856, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09736103700938936, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9961454416211456, -0.08771692617398118, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.839439865992445, 1.0218694340316077`, 0.}, 
      Optica`Optica`RayEnd :> {4.750805233635593, 1.157338521753208, 0.}, 
      RotationMatrix :> {{-0.5475033003142191, 0.8368035230237968, 
       0.}, {-0.8368035230237968, -0.5475033003142191, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27976021067395124`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16188876360376886`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.01455618032355, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1993874931522745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5475033003142191, 0.8368035230237968, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.750805233635593, 1.157338521753208, 0.}, 
      Optica`Optica`RayEnd :> {4.628638705595014, 1.3647266179686772`, 0.}, 
      RotationMatrix :> {{-0.5075556463540013, 0.8616189795113453, 
       0.}, {-0.8616189795113453, -0.5075556463540013, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.278727566910716, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24069583092643385`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.370786010094672`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2903236426786664, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5075556463540013, 0.8616189795113453, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.122856680468086, -0.3469255217782274, 0.}, 
      Optica`Optica`RayEnd :> {4.05452514831685, -0.36037909558971937`, 0.}, 
      RotationMatrix :> {{-0.9811637000839113, -0.1931781396474474, 0.}, {
       0.1931781396474474, -0.9811637000839113, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015302620166228706`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0696433552784231, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.75861421012672, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.003496791894076423, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9811637000839113, -0.1931781396474474, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.05452514831685, -0.36037909558971937`, 0.}, 
      Optica`Optica`RayEnd :> {3.8418719011631226`, -0.4257345527276301, 0.}, 
      RotationMatrix :> {{-0.955875373386699, -0.293772480931824, 0.}, {
       0.293772480931824, -0.955875373386699, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015138093205970727`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22246963681080062`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.087869272606705`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2210098491383078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.955875373386699, -0.293772480931824, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.899821121356265, -1.4982348238119843`, 0.}, 
      Optica`Optica`RayEnd :> {4.8447250389984315`, -1.5838618799218238`, 0.},
       RotationMatrix :> {{-0.541105825384651, -0.8409545087189886, 0.}, {
       0.8409545087189886, -0.541105825384651, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013029896333682863`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10182127002359946`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.277323673282867`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05894062360649335, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.541105825384651, -0.8409545087189886, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8447250389984315`, -1.5838618799218238`, 
       0.}, Optica`Optica`RayEnd :> {
       4.6801569042007625`, -1.8359346973849022`, 0.}, 
      RotationMatrix :> {{-0.5466704862173666, -0.8373478246815166, 0.}, {
       0.8373478246815166, -0.5466704862173666, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012997495591885134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30103716762977634`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.722858681374936`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4308497730027916, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5466704862173666, -0.8373478246815166, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5760497386044126`, -1.6632283365645302`, 
       0.}, Optica`Optica`RayEnd :> {
       5.6059430288850525`, -1.7364162622695076`, 0.}, 
      RotationMatrix :> {{0.3781210777048861, -0.9257561507196671, 0.}, {
       0.9257561507196671, 0.3781210777048861, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14670805463275563`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07905745551685771, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.336810939211416`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01477431823978348, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3781210777048861, -0.9257561507196671, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.6059430288850525`, -1.7364162622695076`, 
       0.}, Optica`Optica`RayEnd :> {5.698922125620347, -1.8758034494156233`, 
       0.}, RotationMatrix :> {{0.5549245590981283, -0.8319006753872409, 
       0.}, {0.8319006753872409, 0.5549245590981283, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1374711393535217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1675526793883565, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.584788904706183`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4059512074348353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5549245590981283, -0.8319006753872409, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.698922125620347, -1.8758034494156233`, 0.}, 
      Optica`Optica`RayEnd :> {5.864952223193942, -1.8532666557235384`, 0.}, 
      RotationMatrix :> {{0.9909128172684633, 0.13450571948090823`, 
       0.}, {-0.13450571948090823`, 0.9909128172684633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008655348002035998, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16755267938835627`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.83276687020095, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0846085192660949, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9909128172684633, 0.13450571948090823`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.916170905633331, -1.2320732494795885`, 0.}, 
      Optica`Optica`RayEnd :> {6.120371921029847, -1.2557540571998236`, 0.}, 
      RotationMatrix :> {{0.9933427707315731, -0.11519609296899384`, 0.}, {
       0.11519609296899384`, 0.9933427707315731, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011200089020666285`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20556953894789667`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.510171150325187`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06383324744810324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9933427707315731, -0.11519609296899384`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.120371921029847, -1.2557540571998236`, 0.}, 
      Optica`Optica`RayEnd :> {6.446986340259031, -1.2858947444894115`, 0.}, 
      RotationMatrix :> {{0.9957690048360163, -0.09189172437107362, 0.}, {
       0.09189172437107362, 0.9957690048360163, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011169332644271364`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3280021949297071, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.995614398821154`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3353449847907909, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9957690048360163, -0.09189172437107362, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.211636102543155, -0.9174096462932262, 0.}, 
      Optica`Optica`RayEnd :> {4.1540997221684615`, -0.9391112416421967, 0.}, 
      RotationMatrix :> {{-0.9356567474404794, -0.35291139251815407`, 0.}, {
       0.35291139251815407`, -0.9356567474404794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17951492661350738`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06149304275535432, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.28909357058197, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2840308920148464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9356567474404794, -0.35291139251815407`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1540997221684615`, -0.9391112416421967, 0.},
       Optica`Optica`RayEnd :> {3.854644651235509, -1.0547381333962738`, 0.}, 
      RotationMatrix :> {{-0.9328731605177395, -0.36020503381496977`, 0.}, {
       0.36020503381496977`, -0.9328731605177395, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1790670088391891, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3210029869084847, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.764177991206529`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14485633784479876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9328731605177395, -0.36020503381496977`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.956690241253088, 0.17168039885872202`, 0.}, 
      Optica`Optica`RayEnd :> {3.9225528304364947`, 0.177311715770142, 0.}, 
      RotationMatrix :> {{-0.9866655848570586, 0.16276063301264962`, 
       0.}, {-0.16276063301264962`, -0.9866655848570586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06503541302797344, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03459876511405726, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.585815856229896`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.358533818267427, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9866655848570586, 0.16276063301264962`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9225528304364947`, 0.177311715770142, 0.}, 
      Optica`Optica`RayEnd :> {3.6037690263909803`, 0.23251298497403247`, 0.},
       RotationMatrix :> {{-0.9853364009277426, 0.17062290879821201`, 
       0.}, {-0.17062290879821201`, -0.9853364009277426, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06487305345468208, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3235278872731829, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.064637129394207`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04758394739597535, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9853364009277426, 0.17062290879821201`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8894263217254865`, 1.1211417280571658`, 0.},
       Optica`Optica`RayEnd :> {4.911625254895543, 1.3538738076488344`, 0.}, 
      RotationMatrix :> {{0.09495310148652444, 0.9954817469537496, 
       0.}, {-0.9954817469537496, 0.09495310148652444, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024810574891437957`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23378839471828228`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.124217290087294`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42302084037476284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09495310148652444, 0.9954817469537496, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.911625254895543, 1.3538738076488344`, 0.}, 
      Optica`Optica`RayEnd :> {4.955364090593181, 1.6592345551760308`, 0.}, 
      RotationMatrix :> {{0.1417894588417155, 0.9898968377368285, 
       0.}, {-0.9898968377368285, 0.1417894588417155, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02471879451365109, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3084773441900607, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.580763759488585`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35914493449863877`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1417894588417155, 0.9898968377368285, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.996981320663829, 1.1193631448066796`, 0.}, 
      Optica`Optica`RayEnd :> {6.067545715787124, 1.2013709460128568`, 0.}, 
      RotationMatrix :> {{0.652239487131337, 0.7580129625716507, 
       0.}, {-0.7580129625716507, 0.652239487131337, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008897301888474594, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10818786123123234`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.328915210516653`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22151318371939716`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.652239487131337, 0.7580129625716507, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.067545715787124, 1.2013709460128568`, 0.}, 
      Optica`Optica`RayEnd :> {6.267562956917228, 1.4159252596804341`, 0.}, 
      RotationMatrix :> {{0.6818927853080329, 0.731452137425856, 
       0.}, {-0.731452137425856, 0.6818927853080329, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008867776320461054, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2933265249899224, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.763038467501739`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06716090663178226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6818927853080329, 0.731452137425856, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.060092723143652, -0.7433532091214999, 0.}, 
      Optica`Optica`RayEnd :> {2.9321073113160727`, -0.7766782465086752, 0.}, 
      RotationMatrix :> {{-0.9677325264771427, -0.25197967616092787`, 0.}, {
       0.25197967616092787`, -0.9677325264771427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23159685308222092`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13225287806899227`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.308145199947388`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4214583797630963, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9677325264771427, -0.25197967616092787`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9321073113160727`, -0.7766782465086752, 0.},
       Optica`Optica`RayEnd :> {2.660008727854707, -0.8391463939340966, 0.}, 
      RotationMatrix :> {{-0.9746447210638077, -0.22375805617329653`, 0.}, {
       0.22375805617329653`, -0.9746447210638077, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2309243587133448, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27917719922021916`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.721327454793313`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23789116870765983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9746447210638077, -0.22375805617329653`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5179669445967625`, 1.6546179606098674`, 0.},
       Optica`Optica`RayEnd :> {2.4031273095709067`, 1.8526055614273562`, 0.},
       RotationMatrix :> {{-0.5017404074465232, 0.8650182446257402, 
       0.}, {-0.8650182446257402, -0.5017404074465232, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014952582065927799`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22888257218568875`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.675489898154265`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41842200450474876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5017404074465232, 0.8650182446257402, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4031273095709067`, 1.8526055614273562`, 0.},
       Optica`Optica`RayEnd :> {2.3465003261523547`, 2.0016919364102153`, 0.},
       RotationMatrix :> {{-0.3550761780770455, 0.9348373696864061, 
       0.}, {-0.9348373696864061, -0.3550761780770455, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014456281109720108`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15947840749334863`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.911517941244421`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13119659960362945`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3550761780770455, 0.9348373696864061, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3584371703534224`, 0.8983914028520312, 0.}, 
      Optica`Optica`RayEnd :> {2.2418943733926846`, 1.0564346421307682`, 0.}, 
      RotationMatrix :> {{-0.5934956622751659, 0.8048371877967382, 
       0.}, {-0.8048371877967382, -0.5934956622751659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015296990460617858`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1963667207169989, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.097208687089555`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26231522433063464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5934956622751659, 0.8048371877967382, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2418943733926846`, 1.0564346421307682`, 0.},
       Optica`Optica`RayEnd :> {2.094867808752803, 1.28922010582574, 0.}, 
      RotationMatrix :> {{-0.5340038091082082, 0.8454820706898072, 
       0.}, {-0.8454820706898072, -0.5340038091082082, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015209278402895503`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2753286814291025, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.504695135604626`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2018036008379464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5340038091082082, 0.8454820706898072, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.22879531666272, 0.9020263899058154, 0.}, 
      Optica`Optica`RayEnd :> {2.1107622699206594`, 0.8811695801798028, 0.}, 
      RotationMatrix :> {{-0.9847443421772634, -0.17400741521518098`, 0.}, {
       0.17400741521518098`, -0.9847443421772634, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20419089743765598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11986161451924696`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.18663719441848, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12838481902419024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9847443421772634, -0.17400741521518098`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1107622699206594`, 0.8811695801798028, 0.}, 
      Optica`Optica`RayEnd :> {1.8849683746156314`, 0.8698811764446064, 0.}, 
      RotationMatrix :> {{-0.9987526236797839, -0.04993192057940048, 0.}, {
       0.04993192057940048, -0.9987526236797839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20084734110354682`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2260758970255492, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.521229522016293`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3877241077508799, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9987526236797839, -0.04993192057940048, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.167926937343688, 0.7875044978575387, 0.}, 
      Optica`Optica`RayEnd :> {2.1018694891400234`, 0.5625338826359672, 0.}, 
      RotationMatrix :> {{-0.28173301011795826`, -0.9594928405203836, 0.}, {
       0.9594928405203836, -0.28173301011795826`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013360652149753193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2344682583556936, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.532155446793233`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005075661271111976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.28173301011795826`, -0.9594928405203836, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1018694891400234`, 0.5625338826359672, 0.}, 
      Optica`Optica`RayEnd :> {2.030548797235382, 0.33793803114345605`, 0.}, 
      RotationMatrix :> {{-0.30265785863074235`, -0.9530992711197788, 0.}, {
       0.9530992711197788, -0.30265785863074235`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01332445518595478, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23564791024195994`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.880914353951333`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29259390317835116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.30265785863074235`, -0.9530992711197788, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.764975851525028, 2.414726189496874, 0.}, 
      Optica`Optica`RayEnd :> {5.040372770179408, 2.839708033129257, 0.}, 
      RotationMatrix :> {{0.543819979582786, 0.8392019005022441, 
       0.}, {-0.8392019005022441, 0.543819979582786, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011648681467882966`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.50641191753503, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.142789341906813`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09761098000536395, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.543819979582786, 0.8392019005022441, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.040372770179408, 2.839708033129257, 0.}, 
      Optica`Optica`RayEnd :> {5.14196656423911, 3.043244514731989, 0.}, 
      RotationMatrix :> {{0.4466000046751872, 0.8947337234195004, 
       0.}, {-0.8947337234195004, 0.4466000046751872, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01150095117809422, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2274827429381505, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.479463801455275`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3332259906797349, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4466000046751872, 0.8947337234195004, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.312530256982746, 1.9047407108645917`, 0.}, 
      Optica`Optica`RayEnd :> {2.160245365407655, 2.042717078838258, 0.}, 
      RotationMatrix :> {{-0.7410639837047086, 0.6714344138154577, 
       0.}, {-0.6714344138154577, -0.7410639837047086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23107824109305267`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2054949301594607, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.787073175078406`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43155297795209235`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7410639837047086, 0.6714344138154577, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.160245365407655, 2.042717078838258, 0.}, 
      Optica`Optica`RayEnd :> {1.981736479233178, 2.1791356728325355`, 0.}, 
      RotationMatrix :> {{-0.7945472300109391, 0.6072023544766142, 
       0.}, {-0.6072023544766142, -0.7945472300109391, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22941892763031516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2246674325099838, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.119580975193182`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.352887266363194, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7945472300109391, 0.6072023544766142, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9696703051931497`, 2.143299400268076, 0.}, 
      Optica`Optica`RayEnd :> {2.989624174191954, 2.316567486165755, 0.}, 
      RotationMatrix :> {{0.11440568567074283`, 0.9934341141143722, 
       0.}, {-0.9934341141143722, 0.11440568567074283`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03073033532851586, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17441326348264585`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.904550170223294`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3330352624809419, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.11440568567074283`, 0.9934341141143722, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.989624174191954, 2.316567486165755, 0.}, 
      Optica`Optica`RayEnd :> {3.0356327260310234`, 2.687957121083041, 0.}, 
      RotationMatrix :> {{0.12294237103789243`, 0.9924138115743761, 
       0.}, {-0.9924138115743761, 0.12294237103789243`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030653458184703334`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3742286036185947, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.458408503578815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2319620517961507, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.12294237103789243`, 0.9924138115743761, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.203960725449316, -1.846230942491997, 0.}, 
      Optica`Optica`RayEnd :> {2.183252305621113, -1.8847619765155457`, 0.}, 
      RotationMatrix :> {{-0.4734074457181746, -0.8808435674616654, 0.}, {
       0.8808435674616654, -0.4734074457181746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012533216750468534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04374333360301874, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.354783245733618`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3040950667087891, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4734074457181746, -0.8808435674616654, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.183252305621113, -1.8847619765155457`, 0.}, 
      Optica`Optica`RayEnd :> {2.0330784063531713`, -2.120040053223454, 0.}, 
      RotationMatrix :> {{-0.5380262977609901, -0.8429280532273216, 0.}, {
       0.8429280532273216, -0.5380262977609901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012457273060717559`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791199982099283, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.767880843084312`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23195738040889063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5380262977609901, -0.8429280532273216, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9941947604424164`, -2.117172517617665, 0.}, 
      Optica`Optica`RayEnd :> {1.9225117896096935`, -2.339296137369611, 0.}, 
      RotationMatrix :> {{-0.3071199342550494, -0.9516708180790107, 0.}, {
       0.9516708180790107, -0.3071199342550494, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2167442222075358, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2334038362133581, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.565596306673244`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42708034657053395`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3071199342550494, -0.9516708180790107, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9225117896096935`, -2.339296137369611, 0.}, 
      Optica`Optica`RayEnd :> {1.871705955361084, -2.579383011099843, 0.}, 
      RotationMatrix :> {{-0.2070296802215987, -0.9783346623253935, 0.}, {
       0.9783346623253935, -0.2070296802215987, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21442058623731008`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24540362615750727`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.928793673386355`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2851450241387762, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.2070296802215987, -0.9783346623253935, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3314998299859577`, -2.030808955936765, 0.}, 
      Optica`Optica`RayEnd :> {2.343528762848731, -2.080123389095915, 0.}, 
      RotationMatrix :> {{0.2369751897593237, -0.9715157021060092, 0.}, {
       0.9715157021060092, 0.2369751897593237, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00842650401348229, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05076030480232933, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.236284165544546`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06547584871463719, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2369751897593237, -0.9715157021060092, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.343528762848731, -2.080123389095915, 0.}, 
      Optica`Optica`RayEnd :> {2.392586079497609, -2.3630622067704063`, 0.}, 
      RotationMatrix :> {{0.1708360433150209, -0.9852994703664809, 0.}, {
       0.9852994703664809, 0.1708360433150209, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008382122169376241, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28716022507274147`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.661281298652204`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10522114769649174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.1708360433150209, -0.9852994703664809, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4515426952274284`, -2.1199870179428464`, 
       0.}, Optica`Optica`RayEnd :> {2.556943566838984, -2.160322154999426, 
       0.}, RotationMatrix :> {{0.9339489206143823, -0.3574065104096873, 
       0.}, {0.3574065104096873, 0.9339489206143823, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031768831489039896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11285507085571611`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.540814333781142`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1645292948459806, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9339489206143823, -0.3574065104096873, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.556943566838984, -2.160322154999426, 0.}, 
      Optica`Optica`RayEnd :> {2.8588435170927085`, -2.274866792392901, 0.}, 
      RotationMatrix :> {{0.9349658277349367, -0.35473779185184684`, 0.}, {
       0.35473779185184684`, 0.9349658277349367, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03169040267991834, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3228994486195415, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.018705517738065`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30546580852776084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9349658277349367, -0.35473779185184684`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6087330171752736`, -1.8690807179268634`, 
       0.}, Optica`Optica`RayEnd :> {2.626161706169526, -1.8713873058769472`, 
       0.}, RotationMatrix :> {{0.991355877975899, -0.13120031708282623`, 
       0.}, {0.13120031708282623`, 0.991355877975899, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010045254638921875`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01758065835029674, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.488586334000363`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4152497921648321, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.991355877975899, -0.13120031708282623`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.626161706169526, -1.8713873058769472`, 0.}, 
      Optica`Optica`RayEnd :> {2.8201946499746575`, -1.8649612329970076`, 0.},
       RotationMatrix :> {{0.9994520344312882, 0.03310031527280058, 
       0.}, {-0.03310031527280058, 0.9994520344312882, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009699307143704223, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.194139325471022, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.775912535697476`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06650547157165353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9994520344312882, 0.03310031527280058, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6583334482814975`, -1.8881915848497568`, 
       0.}, Optica`Optica`RayEnd :> {2.628396231651677, -1.9075178484490787`, 
       0.}, RotationMatrix :> {{-0.840144094927703, -0.5423632544320368, 
       0.}, {0.5423632544320368, -0.840144094927703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2602943346155405, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.035633430991855085`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.587169584852402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32547650290325086`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.840144094927703, -0.5423632544320368, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.628396231651677, -1.9075178484490787`, 0.}, 
      Optica`Optica`RayEnd :> {2.3601829633056144`, -2.072207955493204, 0.}, 
      RotationMatrix :> {{-0.8521744144140566, -0.5232578402834108, 0.}, {
       0.5232578402834108, -0.8521744144140566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2595849112566412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31473987461883846`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.052984599288283`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.345539391121776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8521744144140566, -0.5232578402834108, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.844387562893518, -0.4646491925784466, 0.}, 
      Optica`Optica`RayEnd :> {2.711766618665485, -0.4883288901651158, 0.}, 
      RotationMatrix :> {{-0.9844309330044857, -0.17577183546836372`, 0.}, {
       0.17577183546836372`, -0.9844309330044857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008899379156740599, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1347183837704828, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.634701008652291`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35650017140974455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9844309330044857, -0.17577183546836372`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.711766618665485, -0.4883288901651158, 0.}, 
      Optica`Optica`RayEnd :> {2.37955614645619, -0.5501416006647808, 0.}, 
      RotationMatrix :> {{-0.9831267973074115, -0.18292539576579153`, 0.}, {
       0.18292539576579153`, -0.9831267973074115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008877209848899389, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33791213210661475`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.13481096417008, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05712149344073794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9831267973074115, -0.18292539576579153`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5947838776974526`, 0.699565467163501, 0.}, 
      Optica`Optica`RayEnd :> {2.411995464801956, 0.7751817178667965, 0.}, 
      RotationMatrix :> {{-0.9240531454994891, 0.38226402432415724`, 
       0.}, {-0.38226402432415724`, -0.9240531454994891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21448173965403708`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19781158019508904`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.040476544351561`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3852689566101825, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9240531454994891, 0.38226402432415724`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.411995464801956, 0.7751817178667965, 0.}, 
      Optica`Optica`RayEnd :> {2.187360460058735, 0.8624833169471092, 0.}, 
      RotationMatrix :> {{-0.9320837840673121, 0.3622427631834212, 
       0.}, {-0.3622427631834212, -0.9320837840673121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21390216141656454`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24100301773622376`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.397161010601172`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.271427543048658, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9320837840673121, 0.3622427631834212, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.352532376797479, 2.369357454152633, 0.}, 
      Optica`Optica`RayEnd :> {4.345611921107683, 2.399961550671878, 0.}, 
      RotationMatrix :> {{-0.22055965580636486`, 0.9753734865325063, 
       0.}, {-0.9753734865325063, -0.22055965580636486`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008936328642938847, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03137679764911769, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.592405285322359`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2036018338902022, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 63, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22055965580636486`, 0.9753734865325063, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.52218963097219, 1.6623099573089042`, 0.}, 
      Optica`Optica`RayEnd :> {6.625069808407641, 1.7056084372372071`, 0.}, 
      RotationMatrix :> {{0.9216978103531939, 0.38790868305585574`, 
       0.}, {-0.38790868305585574`, 0.9216978103531939, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010575137314652998`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11162029059831177`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.282700813782181`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.006371263684616907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9216978103531939, 0.38790868305585574`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.625069808407641, 1.7056084372372071`, 0.}, 
      Optica`Optica`RayEnd :> {6.865402790228393, 1.7961382788338658`, 0.}, 
      RotationMatrix :> {{0.9358097282176724, 0.3525055355213116, 
       0.}, {-0.3525055355213116, 0.9358097282176724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010540848720848851`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2568182126921106, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.662791768566505`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1664824294923158, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9358097282176724, 0.3525055355213116, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.096591811836374, 1.2499734969440517`, 0.}, 
      Optica`Optica`RayEnd :> {3.9862592797803313`, 1.3481438736691491`, 0.}, 
      RotationMatrix :> {{-0.7470830404213084, 0.6647307204536691, 
       0.}, {-0.6647307204536691, -0.7470830404213084, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.42877914854273486`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1476844287534923, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.083597977680718`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3327008805468265, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7470830404213084, 0.6647307204536691, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9862592797803313`, 1.3481438736691491`, 0.},
       Optica`Optica`RayEnd :> {3.8677830330422824`, 1.489527299309895, 0.}, 
      RotationMatrix :> {{-0.6422831292278108, 0.7664674695701909, 
       0.}, {-0.7664674695701909, -0.6422831292278108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4182358096509167, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18446109098410765`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.356600392337198`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014289779190539205`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6422831292278108, 0.7664674695701909, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8677830330422824`, 1.489527299309895, 0.}, 
      Optica`Optica`RayEnd :> {3.9779876884070617`, 1.6374489948889326`, 0.}, 
      RotationMatrix :> {{0.597441198991249, 0.8019127220264679, 
       0.}, {-0.8019127220264679, 0.597441198991249, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010284086557917411`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18446109098410762`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.629602806993677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35348289560043894`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.597441198991249, 0.8019127220264679, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.560933992060265, -0.15747189595957234`, 0.},
       Optica`Optica`RayEnd :> {3.4144325205014994`, -0.2356454770595336, 0.},
       RotationMatrix :> {{-0.8822542428189671, -0.4707732479951796, 0.}, {
       0.4707732479951796, -0.8822542428189671, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009508196549776105, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16605357554378639`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.583806795028083`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34048700927053216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8822542428189671, -0.4707732479951796, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4144325205014994`, -0.2356454770595336, 0.},
       Optica`Optica`RayEnd :> {3.136273110507371, -0.3775728539432791, 0.}, 
      RotationMatrix :> {{-0.8907497994584358, -0.45449399860147366`, 0.}, {
       0.45449399860147366`, -0.8907497994584358, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009483135678169314, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3122755797006586, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.045974652985057`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30079994262717386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8907497994584358, -0.45449399860147366`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.908455139197296, -0.6337664010897093, 0.}, 
      Optica`Optica`RayEnd :> {4.902628181296575, -0.6345152162075803, 0.}, 
      RotationMatrix :> {{-0.9918436354880198, -0.12746059289799383`, 0.}, {
       0.12746059289799383`, -0.9918436354880198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028389611648616347`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005874875526982264, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.070638187162531`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2478384191659382, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9918436354880198, -0.12746059289799383`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.902628181296575, -0.6345152162075803, 0.}, 
      Optica`Optica`RayEnd :> {4.621919019136533, -0.6819973016660933, 0.}, 
      RotationMatrix :> {{-0.9859939089041371, -0.1667813287030066, 0.}, {
       0.1667813287030066, -0.9859939089041371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02829547433083988, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2846966493657453, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.491989228223835`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09612521554475707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9859939089041371, -0.1667813287030066, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.147244857449752, -0.8967049223682861, 0.}, 
      Optica`Optica`RayEnd :> {5.137138975144561, -0.8944342626544151, 0.}, 
      RotationMatrix :> {{-0.975675127495185, 0.21922145330066212`, 
       0.}, {-0.21922145330066212`, -0.975675127495185, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01421205393836006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01035783532899422, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.757378876724509`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11885882372178458`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.975675127495185, 0.21922145330066212`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.137138975144561, -0.8944342626544151, 0.}, 
      Optica`Optica`RayEnd :> {4.950544740297555, -0.8794548318219492, 0.}, 
      RotationMatrix :> {{-0.9967932047725457, 0.08002066557632384, 
       0.}, {-0.08002066557632384, -0.9967932047725457, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013895593409651902`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1871945293703974, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.034426780192698`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4117050734625103, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9967932047725457, 0.08002066557632384, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.477344047574457, -0.3900611068834905, 0.}, 
      Optica`Optica`RayEnd :> {6.37136217824953, -0.2190326212415336, 0.}, 
      RotationMatrix :> {{-0.5267393580018712, 0.8500268517710348, 
       0.}, {-0.8500268517710348, -0.5267393580018712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015345332093358513`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20120362702145028`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.227762752965637`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31431396487850805`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5267393580018712, 0.8500268517710348, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.37136217824953, -0.2190326212415336, 0.}, 
      Optica`Optica`RayEnd :> {6.258025463924768, -0.11781453791912785`, 0.}, 
      RotationMatrix :> {{-0.7458572661530691, 0.6661058013008669, 
       0.}, {-0.6661058013008669, -0.7458572661530691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01208765519280617, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15195496439864747`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.452656100275634`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1329003431580093, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7458572661530691, 0.6661058013008669, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.952683447459978, -0.8740524240884584, 0.}, 
      Optica`Optica`RayEnd :> {7.052469467204013, -0.8069688713511451, 0.}, 
      RotationMatrix :> {{0.8298962621891257, 0.5579177304984291, 
       0.}, {-0.5579177304984291, 0.8298962621891257, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.102031822877546, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12023914830127837`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.09078363023157, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11868176800645894`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.8298962621891257, 0.5579177304984291, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.052469467204013, -0.8069688713511451, 0.}, 
      Optica`Optica`RayEnd :> {7.353433065589417, -0.6194021000598979, 0.}, 
      RotationMatrix :> {{0.8486762488256513, 0.5289126815261863, 
       0.}, {-0.5289126815261863, 0.8486762488256513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10171591638734098`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3546271016796576, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.615631740717463`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08568040801621667, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.8486762488256513, 0.5289126815261863, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.098021325764257, -0.9968067045346964, 0.}, 
      Optica`Optica`RayEnd :> {7.224219046840725, -1.1355461267955338`, 0.}, 
      RotationMatrix :> {{0.6728799609735263, -0.7397516867978507, 0.}, {
       0.7397516867978507, 0.6728799609735263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.299873046186019, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18754863927569534`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.462535316592723`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3504321589346009, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6728799609735263, -0.7397516867978507, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.224219046840725, -1.1355461267955338`, 0.}, 
      Optica`Optica`RayEnd :> {7.404873413023072, -1.354943595196123, 0.}, 
      RotationMatrix :> {{0.6356529438227172, -0.7719749575015457, 0.}, {
       0.7719749575015457, 0.6356529438227172, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.279616600698042, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28420283102272786`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.883155506506359`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28277482227131384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6356529438227172, -0.7719749575015457, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.404873413023072, -1.354943595196123, 0.}, 
      Optica`Optica`RayEnd :> {7.120685522106613, -1.3520295228243422`, 0.}, 
      RotationMatrix :> {{-0.999947431536079, 0.01025349522837049, 
       0.}, {-0.01025349522837049, -0.999947431536079, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02017902408934035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.284202831022728, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.303775696419997`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2064293998235206, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.999947431536079, 0.01025349522837049, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.997752704567444, -1.1584789527443164`, 0.}, 
      Optica`Optica`RayEnd :> {6.91710714484928, -1.2568947932735157`, 0.}, 
      RotationMatrix :> {{-0.6338190654039287, -0.7734813458193351, 0.}, {
       0.7734813458193351, -0.6338190654039287, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0982826838666087, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12723751007200973`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.66327537191522, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3529330528887607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6338190654039287, -0.7734813458193351, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.91710714484928, -1.2568947932735157`, 0.}, 
      Optica`Optica`RayEnd :> {6.750245482442702, -1.435074784336653, 0.}, 
      RotationMatrix :> {{-0.6835440507544367, -0.729909261948508, 0.}, {
       0.729909261948508, -0.6835440507544367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0977787930460281, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24411252240789755`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.024561905078908`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33028177594652613`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6835440507544367, -0.729909261948508, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.084428116973464, -0.7640639246493693, 0.}, 
      Optica`Optica`RayEnd :> {5.9151743398878, -0.7436509199874607, 0.}, 
      RotationMatrix :> {{-0.992805500822268, 0.11973820416661245`, 
       0.}, {-0.11973820416661245`, -0.992805500822268, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015260549290999206`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17048029744545468`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.26559042511447, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39134791806459074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.992805500822268, 0.11973820416661245`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.9151743398878, -0.7436509199874607, 0.}, 
      Optica`Optica`RayEnd :> {5.614645344029233, -0.7065919626854019, 0.}, 
      RotationMatrix :> {{-0.992482647288619, 0.12238543553452148`, 
       0.}, {-0.12238543553452148`, -0.992482647288619, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015222883000252874`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.302805290026569, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.713742254353791`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04851053877923521, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.992482647288619, 0.12238543553452148`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.584222943013781, 0.1716058667428289, 0.}, 
      Optica`Optica`RayEnd :> {6.574033746401171, 0.4458597481085579, 0.}, 
      RotationMatrix :> {{-0.03712681018710209, 0.9993105623205084, 
       0.}, {-0.9993105623205084, -0.03712681018710209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01955729545822849, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27444309277476414`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.02841662872913, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18227719542043766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.03712681018710209, 0.9993105623205084, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.574033746401171, 0.44585974810855794`, 0.}, 
      Optica`Optica`RayEnd :> {6.5469469278676025`, 0.6368635855234813, 0.}, 
      RotationMatrix :> {{-0.14040811487637145`, 0.9900937133811443, 
       0.}, {-0.9900937133811443, -0.14040811487637145`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01934716147380595, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1929149077844866, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.31393069225017, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04563989012152169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.14040811487637145`, 0.9900937133811443, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.672516915681058, 0.8885179867466502, 0.}, 
      Optica`Optica`RayEnd :> {6.804524202477089, 1.1273984324969137`, 0.}, 
      RotationMatrix :> {{0.4836704186055283, 0.8752502077497342, 
       0.}, {-0.8752502077497342, 0.4836704186055283, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0277210485409145, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27292817943388387`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.114013048488745`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.014880981286184196`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4836704186055283, 0.8752502077497342, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.804524202477089, 1.1273984324969137`, 0.}, 
      Optica`Optica`RayEnd :> {6.881204474904297, 1.3242995202150794`, 0.}, 
      RotationMatrix :> {{0.3628886537891379, 0.9318325090653936, 
       0.}, {-0.9318325090653936, 0.3628886537891379, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.027185381555830897`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21130523543941696`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.426744796939083`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32703996589451323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3628886537891379, 0.9318325090653936, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.062238178947538, 0.1912066990993062, 0.}, 
      Optica`Optica`RayEnd :> {4.854268663032112, 0.21823571056275384`, 0.}, 
      RotationMatrix :> {{-0.991659899439686, 0.1288822867708011, 
       0.}, {-0.1288822867708011, -0.991659899439686, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1131361439329352, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20971859004577484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.96072514895521, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28988971922855766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.991659899439686, 0.1288822867708011, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.854268663032112, 0.21823571056275384`, 0.}, 
      Optica`Optica`RayEnd :> {4.5969460739394234`, 0.25932011660617466`, 0.},
       RotationMatrix :> {{-0.9874927882007858, 0.15766417871995314`, 
       0.}, {-0.15766417871995314`, -0.9874927882007858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11280753395326751`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2605817401072178, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.346386124313893`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05592771067944334, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9874927882007858, 0.15766417871995314`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1212892282563045`, -0.28584844369612605`, 
       0.}, Optica`Optica`RayEnd :> {5.058741770078805, -0.37352533270738797`,
        0.}, RotationMatrix :> {{-0.580753054102128, -0.8140797811953386, 
       0.}, {0.8140797811953386, -0.580753054102128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04358140069196921, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1077006099850843, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.035997394004834`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07866410196669993, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.580753054102128, -0.8140797811953386, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.058741770078805, -0.37352533270738797`, 0.},
       Optica`Optica`RayEnd :> {4.892604669438865, -0.6189034417401148, 0.}, 
      RotationMatrix :> {{-0.5606473967072029, -0.8280546458811977, 0.}, {
       0.8280546458811977, -0.5606473967072029, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04346055979354915, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29633081615235757`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.474567001910323`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33938106936887935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5606473967072029, -0.8280546458811977, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.548883626199007, -0.6931337635867161, 0.}, 
      Optica`Optica`RayEnd :> {5.577185086091668, -0.8919322091923785, 0.}, 
      RotationMatrix :> {{0.14094150740125255`, -0.9900179248334154, 0.}, {
       0.9900179248334154, 0.14094150740125255`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023705238377672685`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20080287499755425`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.580282714241351`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0141657271172832, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14094150740125255`, -0.9900179248334154, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.577185086091668, -0.8919322091923785, 0.}, 
      Optica`Optica`RayEnd :> {5.594092515281308, -1.1510887972667576`, 0.}, 
      RotationMatrix :> {{0.06510180719408744, -0.9978786272388358, 0.}, {
       0.9978786272388358, 0.06510180719408744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023557862314608866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2597075245428136, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.964649850564715`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07898327597463918, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06510180719408744, -0.9978786272388358, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.903281161164852, -0.3033895933541004, 0.}, 
      Optica`Optica`RayEnd :> {5.971531298262972, -0.3511333900671929, 0.}, 
      RotationMatrix :> {{0.8194084215176003, -0.5732101174491205, 0.}, {
       0.5732101174491205, 0.8194084215176003, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012832567441884733`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08329196442930964, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.23616546732462, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19713221544600562`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8194084215176003, -0.5732101174491205, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.971531298262972, -0.3511333900671929, 0.}, 
      Optica`Optica`RayEnd :> {6.089186185011931, -0.46412778297490015`, 0.}, 
      RotationMatrix :> {{0.7212473429970422, -0.6926776091514053, 0.}, {
       0.6926776091514053, 0.7212473429970422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012462827083531003`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16312696038512908`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.477593368694611`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38805064964416247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7212473429970422, -0.6926776091514053, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.34098319847574, 0.5569745163120173, 0.}, 
      Optica`Optica`RayEnd :> {6.300445387111725, 0.5979718692414645, 0.}, 
      RotationMatrix :> {{-0.7031102786860972, 0.7110808224146943, 
       0.}, {-0.7110808224146943, -0.7031102786860972, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009898074758088963, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05765498328337413, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.643252963628905`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24418922545684146`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7031102786860972, 0.7110808224146943, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.300445387111725, 0.5979718692414645, 0.}, 
      Optica`Optica`RayEnd :> {6.16874912920781, 0.7568037859242456, 0.}, 
      RotationMatrix :> {{-0.6382841348253419, 0.7698008594631888, 
       0.}, {-0.7698008594631888, -0.6382841348253419, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009821291566382246, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20632857800852625`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.948619259081523`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09915339087034417, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6382841348253419, 0.7698008594631888, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.97435174451669, 0.14200277352684282`, 0.}, 
      Optica`Optica`RayEnd :> {6.96810564813093, 0.297035070841694, 0.}, 
      RotationMatrix :> {{-0.04025634215495033, 0.9991893849097392, 
       0.}, {-0.9991893849097392, -0.04025634215495033, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016419451878506252`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15515807078840801`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.849272486812623`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3309734246900812, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.04025634215495033, 0.9991893849097392, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.96810564813093, 0.29703507084169406`, 0.}, 
      Optica`Optica`RayEnd :> {6.962721548274071, 0.6105183577215063, 0.}, 
      RotationMatrix :> {{-0.017172545229810807`, 0.9998525409730824, 
       0.}, {-0.9998525409730824, -0.017172545229810807`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01637449812895876, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3135295196376879, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.3132961758764, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3436480155943355, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.017172545229810807`, 0.9998525409730824, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1533879505423, 0.03752729228343482, 0.}, 
      Optica`Optica`RayEnd :> {7.39375033838211, -0.12084842573426254`, 0.}, 
      RotationMatrix :> {{0.8350299452392858, -0.5502044988489962, 0.}, {
       0.5502044988489962, 0.8350299452392858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.914557138366321, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28784882411723717`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.333867100462125`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25171979961387453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8350299452392858, -0.5502044988489962, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.39375033838211, -0.12084842573426254`, 0.}, 
      Optica`Optica`RayEnd :> {7.5496058187056825`, -0.19014294206542603`, 
       0.}, RotationMatrix :> {{0.9137562418887829, -0.40626288337637717`, 
       0.}, {0.40626288337637717`, 0.9137562418887829, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7807874059594893`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17056570798510884`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.586304348280086`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15590550628333574`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9137562418887829, -0.40626288337637717`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5496058187056825`, -0.19014294206542603`, 
       0.}, Optica`Optica`RayEnd :> {7.664545060342192, -0.06412059693375714, 
       0.}, RotationMatrix :> {{0.6738707504239021, 0.7388492483065314, 
       0.}, {-0.7388492483065314, 0.6738707504239021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.129198502335155, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17056570798510864`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.838741596098046`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4015926767288006, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6738707504239021, 0.7388492483065314, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.964087541651995, -0.04693834832296653, 0.}, 
      Optica`Optica`RayEnd :> {6.8111748949094295`, -0.1054241267005212, 0.}, 
      RotationMatrix :> {{-0.9340127521389022, -0.3572396658294165, 0.}, {
       0.3572396658294165, -0.9340127521389022, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016283138047119023`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16371580194423838`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.474317854939176`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07237137505338113, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9340127521389022, -0.3572396658294165, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8111748949094295`, -0.1054241267005212, 0.},
       Optica`Optica`RayEnd :> {6.543886199459315, -0.22501170017298794`, 0.},
       RotationMatrix :> {{-0.9128041822979482, -0.40839750829231775`, 0.}, {
       0.40839750829231775`, -0.9128041822979482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016214232730260462`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29282150611670676`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.907693683991903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.030255989273331445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9128041822979482, -0.40839750829231775`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.103008723708266, 0.39029214819013164`, 0.}, 
      Optica`Optica`RayEnd :> {6.033355543856384, 0.40387788023287086`, 0.}, 
      RotationMatrix :> {{-0.9815041834266985, 0.1914406903348646, 
       0.}, {-0.1914406903348646, -0.9815041834266985, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00987143567335703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07096574933456039, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.811939632332235`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.007141696761486682, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9815041834266985, 0.1914406903348646, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.033355543856384, 0.40387788023287086`, 0.}, 
      Optica`Optica`RayEnd :> {5.819217854866354, 0.46843169438588755`, 0.}, 
      RotationMatrix :> {{-0.9574408586696894, 0.28862952404396836`, 
       0.}, {-0.28862952404396836`, -0.9574408586696894, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009772716261754294, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2236563094743658, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.142950970354297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2162769234154685, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9574408586696894, 0.28862952404396836`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.788286169112373, 0.08275477138089243, 0.}, 
      Optica`Optica`RayEnd :> {6.8157708955746745`, -0.10919306060865114`, 
       0.}, RotationMatrix :> {{0.14174282199027954`, -0.9899035167198018, 
       0.}, {0.9899035167198018, 0.14174282199027954`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.30121549593820734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19390559660358847`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.240045468523611`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09012484075276268, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14174282199027954`, -0.9899035167198018, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8157708955746745`, -0.10919306060865114`, 
       0.}, Optica`Optica`RayEnd :> {6.8256738210161805`, -0.3516744978920914,
        0.}, RotationMatrix :> {{0.0408059162131716, -0.9991670917329106, 
       0.}, {0.9991670917329106, 0.0408059162131716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2981272510973552, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24268357043554264`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.599217152768215`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12992882356238586`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0408059162131716, -0.9991670917329106, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9767342513768655`, 0.8415684967397441, 0.}, 
      Optica`Optica`RayEnd :> {7.037289686503661, 0.6105007043935301, 0.}, 
      RotationMatrix :> {{0.2535070053606427, -0.9673335506603078, 0.}, {
       0.9673335506603078, 0.2535070053606427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29742887971425863`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23887085503080668`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.131687250990794`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14247973464683417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2535070053606427, -0.9673335506603078, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.037289686503661, 0.6105007043935301, 0.}, 
      Optica`Optica`RayEnd :> {7.0967852982839235`, 0.326322821662418, 0.}, 
      RotationMatrix :> {{0.204917664951201, -0.9787792144252688, 0.}, {
       0.9787792144252688, 0.204917664951201, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2962795400380463, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2903391066574488, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.561389128843818`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06173953670310367, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.204917664951201, -0.9787792144252688, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.156710522321821, 1.057504153542214, 0.}, 
      Optica`Optica`RayEnd :> {7.192065638887377, 1.1046249733468794`, 0.}, 
      RotationMatrix :> {{0.6001575361283644, 0.7998818236641774, 
       0.}, {-0.7998818236641774, 0.6001575361283644, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      74.89283276356394, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05890972692542202, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.306573804688998`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2778775224086185, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6001575361283644, 0.7998818236641774, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.192065638887377, 1.1046249733468794`, 0.}, 
      Optica`Optica`RayEnd :> {7.353649000460349, 1.3495682650002878`, 0.}, 
      RotationMatrix :> {{0.5506541614333041, 0.8347334871060246, 
       0.}, {-0.8347334871060246, 0.5506541614333041, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      74.54594837632067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2934389184536172, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.740863404000352`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27276631606679513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5506541614333041, 0.8347334871060246, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.353649000460349, 1.3495682650002878`, 0.}, 
      Optica`Optica`RayEnd :> {7.060538310049242, 1.3634434958074577`, 0.}, 
      RotationMatrix :> {{-0.9988814433878126, 0.047284903039755244`, 
       0.}, {-0.047284903039755244`, -0.9988814433878126, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3452777077564049, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2934389184536172, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.175153003311706`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2676142023243001, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9988814433878126, 0.047284903039755244`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.875687281178761, 1.0642572209501147`, 0.}, 
      Optica`Optica`RayEnd :> {6.635547121943515, 1.057748727360387, 0.}, 
      RotationMatrix :> {{-0.9996329187554892, -0.02709294632151572, 0.}, {
       0.02709294632151572, -0.9996329187554892, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.29508966314603813`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24022834255419812`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.965575214990979`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3869379329092527, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9996329187554892, -0.02709294632151572, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.635547121943515, 1.057748727360387, 0.}, 
      Optica`Optica`RayEnd :> {6.295198604732274, 1.0441447323620774`, 0.}, 
      RotationMatrix :> {{-0.9992021243811962, -0.0399388862151133, 0.}, {
       0.0399388862151133, -0.9992021243811962, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2943378479465851, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3406202898357702, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.46969324394792, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.041133610246141025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9992021243811962, -0.0399388862151133, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.881209576075601, 0.9157210836573269, 0.}, 
      Optica`Optica`RayEnd :> {5.673185502654298, 0.9513089607076581, 0.}, 
      RotationMatrix :> {{-0.9856801103546575, 0.16862597679844443`, 
       0.}, {-0.16862597679844443`, -0.9856801103546575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29825967157468253`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2110462321761298, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.523675959971072`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3753343041217139, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9856801103546575, 0.16862597679844443`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.673185502654298, 0.9513089607076581, 0.}, 
      Optica`Optica`RayEnd :> {5.34378759472657, 1.0085816823173743`, 0.}, 
      RotationMatrix :> {{-0.985218757465966, 0.17130090465965828`, 
       0.}, {-0.17130090465965828`, -0.985218757465966, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29752346497243076`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3343398665845106, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.018498962516148`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07282790955168016, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.985218757465966, 0.17130090465965828`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.453084848827884, 0.3971828149358141, 0.}, 
      Optica`Optica`RayEnd :> {6.439182291361847, 0.18377233116537578`, 0.}, 
      RotationMatrix :> {{-0.06500688600318408, -0.9978848153831023, 0.}, {
       0.9978848153831023, -0.06500688600318408, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009507337784272946, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21386284316642984`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.555950604285513`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3948349909409025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.06500688600318408, -0.9978848153831023, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.439182291361847, 0.18377233116537578`, 0.}, 
      Optica`Optica`RayEnd :> {6.433388240338392, -0.11117953659543571`, 0.}, 
      RotationMatrix :> {{-0.019640266938392985`, -0.999807111354279, 0.}, {
       0.999807111354279, -0.019640266938392985`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009473108443659173, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29500877160324174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.992563586258312`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40657798840927944`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.019640266938392985`, -0.999807111354279, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.364102736692175, 1.2549358388771608`, 0.}, 
      Optica`Optica`RayEnd :> {6.422826032225031, 1.365065552474647, 0.}, 
      RotationMatrix :> {{0.4705099362349001, 0.8823946962126583, 
       0.}, {-0.8823946962126583, 0.4705099362349001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1867445417829799, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12480776921050828`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.380012881106294`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.428643355639208, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4705099362349001, 0.8823946962126583, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.422826032225031, 1.365065552474647, 0.}, 
      Optica`Optica`RayEnd :> {6.57323765724591, 1.646089620359747, 0.}, 
      RotationMatrix :> {{0.4718874544402706, 0.8816587947397115, 
       0.}, {-0.8816587947397115, 0.4718874544402706, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18628405188088945`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3187446998337556, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.851755036860252`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.023549007113154184`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4718874544402706, 0.8816587947397115, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.285753978708785, 1.4070605913421486`, 0.}, 
      Optica`Optica`RayEnd :> {6.174197682692963, 1.5494748272910812`, 0.}, 
      RotationMatrix :> {{-0.6166567608270429, 0.787232138143698, 
       0.}, {-0.787232138143698, -0.6166567608270429, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.2178579440909103`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18090500761915915`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.7084339209944, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38178952605014893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6166567608270429, 0.787232138143698, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.174197682692963, 1.5494748272910812`, 0.}, 
      Optica`Optica`RayEnd :> {6.036656461720002, 1.6775537955970146`, 0.}, 
      RotationMatrix :> {{-0.7318320123460498, 0.6814850737217437, 
       0.}, {-0.6814850737217437, -0.7318320123460498, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.1221576234966264`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18794097368334872`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.986586562045757`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20226071439071636`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7318320123460498, 0.6814850737217437, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.036656461720002, 1.6775537955970146`, 0.}, 
      Optica`Optica`RayEnd :> {5.875024991266699, 1.5816524017169022`, 0.}, 
      RotationMatrix :> {{-0.8600118818455528, -0.510274007847225, 0.}, {
       0.510274007847225, -0.8600118818455528, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09285415661781521, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18794097368334886`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.264739203097113`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1913173264784951, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8600118818455528, -0.510274007847225, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.114937969488056, 1.3969433197743022`, 0.}, 
      Optica`Optica`RayEnd :> {5.995683381404745, 1.3667402332319012`, 0.}, 
      RotationMatrix :> {{-0.9693930628289708, -0.24551392982693748`, 0.}, {
       0.24551392982693748`, -0.9693930628289708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1677785615575076, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12301984886841667`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.884118548688917`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3138497625883437, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 63, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9693930628289708, -0.24551392982693748`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.055094413422918, 1.2366335665228163`, 0.}, 
      Optica`Optica`RayEnd :> {6.036231460668536, 1.1256743437386747`, 0.}, 
      RotationMatrix :> {{-0.16759449984852248`, -0.9858560156638103, 0.}, {
       0.9858560156638103, -0.16759449984852248`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008747945436807911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11255114440766383`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.12334122513202, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2672670501305916, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.16759449984852248`, -0.9858560156638103, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.036231460668536, 1.1256743437386747`, 0.}, 
      Optica`Optica`RayEnd :> {5.987631729229609, 0.8005725958373693, 0.}, 
      RotationMatrix :> {{-0.14784794525748984`, -0.9890101036304622, 0.}, {
       0.9890101036304622, -0.14784794525748984`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008724604657246544, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32871428381562573`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.609838365179145`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37916267191914893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.14784794525748984`, -0.9890101036304622, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.853458526119032, 0.5885561136172155, 0.}, 
      Optica`Optica`RayEnd :> {6.87794882615238, 0.5586810616236928, 0.}, 
      RotationMatrix :> {{0.6339674759468782, -0.7733597089592551, 0.}, {
       0.7733597089592551, 0.6339674759468782, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009454276455358273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03863021521217712, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.269780364395148`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3248970359335221, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6339674759468782, -0.7733597089592551, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.87794882615238, 0.5586810616236928, 0.}, 
      Optica`Optica`RayEnd :> {7.082999887296782, 0.31698239836342923`, 0.}, 
      RotationMatrix :> {{0.6469286666066743, -0.7625505231278186, 0.}, {
       0.7625505231278186, 0.6469286666066743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009429612362099857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31696085168084, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.73888242488279, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01000833307199564, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6469286666066743, -0.7625505231278186, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.615981264787904, 0.7888893143257181, 0.}, 
      Optica`Optica`RayEnd :> {5.369808577478939, 0.8373156111747763, 0.}, 
      RotationMatrix :> {{-0.9811952997173442, 0.19301757384391344`, 
       0.}, {-0.19301757384391344`, -0.9811952997173442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16812038719283007`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2508906100343942, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.998654906532218`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23527812355951566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9811952997173442, 0.19301757384391344`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.369808577478939, 0.8373156111747763, 0.}, 
      Optica`Optica`RayEnd :> {5.132603163998297, 0.8633038107538517, 0.}, 
      RotationMatrix :> {{-0.9940518104830969, 0.10890820940258225`, 
       0.}, {-0.10890820940258225`, -0.9940518104830969, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16687660816130284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23862479900857828`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.351819609064915`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35004580985806183`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9940518104830969, 0.10890820940258225`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.655926041426688, -0.8105216709669426, 0.}, 
      Optica`Optica`RayEnd :> {4.593039866070804, -0.836333126310018, 0.}, 
      RotationMatrix :> {{-0.9251066232505742, -0.3797074342410476, 0.}, {
       0.3797074342410476, -0.9251066232505742, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.200420238756517, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06797721881497223, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.784724443639375`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011318523028835625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9251066232505742, -0.3797074342410476, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.593039866070804, -0.836333126310018, 0.}, 
      Optica`Optica`RayEnd :> {4.359421295530483, -0.9513629506393492, 0.}, 
      RotationMatrix :> {{-0.8971438841137577, -0.44173844206416985`, 0.}, {
       0.44173844206416985`, -0.8971438841137577, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19935506263517028`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2604025671658008, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.17012024304476, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05463447470907114, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8971438841137577, -0.44173844206416985`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.813642807021752, 0.8598979484814954, 0.}, 
      Optica`Optica`RayEnd :> {4.672920885593271, 0.9332801431723884, 0.}, 
      RotationMatrix :> {{-0.8866828604568774, 0.4623780974181294, 
       0.}, {-0.4623780974181294, -0.8866828604568774, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05949558170002157, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1587060353867354, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.017654986126058`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2809582994540771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8866828604568774, 0.4623780974181294, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.672920885593271, 0.9332801431723884, 0.}, 
      Optica`Optica`RayEnd :> {4.356816966072465, 1.0969723235612296`, 0.}, 
      RotationMatrix :> {{-0.8879995623899459, 0.45984429668667615`, 
       0.}, {-0.45984429668667615`, -0.8879995623899459, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05934870297569491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3559730577682385, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.54449511162305, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24196634378843132`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8879995623899459, 0.45984429668667615`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.382123401893994, 0.6275245760517915, 0.}, 
      Optica`Optica`RayEnd :> {6.382254773277838, 0.6275395844991265, 0.}, 
      RotationMatrix :> {{0.9935373004106537, 0.11350609099387525`, 
       0.}, {-0.11350609099387525`, 0.9935373004106537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09640871569417986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0001322259202444539, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.307199903555905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3732152307923661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9935373004106537, 0.11350609099387525`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.382254773277838, 0.6275395844991265, 0.}, 
      Optica`Optica`RayEnd :> {6.560609031189221, 0.6257838054686258, 0.}, 
      RotationMatrix :> {{0.9999515480576416, -0.009843857837521855, 0.}, {
       0.009843857837521855, 0.9999515480576416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0948712557500937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17836289994033044`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.571176995467594`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11116505839076407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999515480576416, -0.009843857837521855, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.841682554284794, 0.9015937670123577, 0.}, 
      Optica`Optica`RayEnd :> {5.674320094655733, 1.010871541214962, 0.}, 
      RotationMatrix :> {{-0.8373166734928811, 0.5467181982436791, 
       0.}, {-0.5467181982436791, -0.8373166734928811, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05559620806845538, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19987952578431953`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.238570489875894`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38764255443576323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8373166734928811, 0.5467181982436791, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.674320094655733, 1.010871541214962, 0.}, 
      Optica`Optica`RayEnd :> {5.441039746564652, 1.1369156045927298`, 0.}, 
      RotationMatrix :> {{-0.8797907800263997, 0.47536110840132695`, 
       0.}, {-0.47536110840132695`, -0.8797907800263997, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.055201250034786715`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2651543450865445, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.630998920603979`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40484246661737083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8797907800263997, 0.47536110840132695`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.712539000534084, 0.9118442775173976, 0.}, 
      Optica`Optica`RayEnd :> {5.64849501488751, 0.8916496320041639, 0.}, 
      RotationMatrix :> {{-0.9537098850194715, -0.3007282082149016, 0.}, {
       0.3007282082149016, -0.9537098850194715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013459522400967618`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06715248174791281, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.252449839259738`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2222117339775008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9537098850194715, -0.3007282082149016, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.64849501488751, 0.8916496320041639, 0.}, 
      Optica`Optica`RayEnd :> {5.415740315443308, 0.8455727215350262, 0.}, 
      RotationMatrix :> {{-0.9809629929395483, -0.19419476430399063`, 0.}, {
       0.19419476430399063`, -0.9809629929395483, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013295512126931313`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2372716413559399, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.603611868466528`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4145622966398341, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9809629929395483, -0.19419476430399063`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.622717590410879, 0.8184888024532366, 0.}, 
      Optica`Optica`RayEnd :> {5.563056991588514, 0.6697420551766223, 0.}, 
      RotationMatrix :> {{-0.37226137428868944`, -0.9281279379550509, 0.}, {
       0.9281279379550509, -0.37226137428868944`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00826879541395185, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16026534833586484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.568954668880224`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05509111243615075, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.37226137428868944`, -0.9281279379550509, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.563056991588514, 0.6697420551766223, 0.}, 
      Optica`Optica`RayEnd :> {5.43041916475558, 0.3419012486380427, 0.}, 
      RotationMatrix :> {{-0.37504784773641575`, -0.9270054540876665, 0.}, {
       0.9270054540876665, -0.37504784773641575`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008248378369815169, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35365574721589027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.092365174759742`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38514735223775876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.37504784773641575`, -0.9270054540876665, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.02114616024396, 1.3648656312182066`, 0.}, 
      Optica`Optica`RayEnd :> {6.051328059475833, 1.2725527638858225`, 0.}, 
      RotationMatrix :> {{0.31076390324224085`, -0.9504871363893602, 0.}, {
       0.9504871363893602, 0.31076390324224085`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01302447129658328, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09712163773520933, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.725715891011822`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.005475205737550559, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.31076390324224085`, -0.9504871363893602, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.051328059475833, 1.2725527638858225`, 0.}, 
      Optica`Optica`RayEnd :> {6.132844253351959, 1.133288049183445, 0.}, 
      RotationMatrix :> {{0.5051579020959115, -0.8630269369782478, 0.}, {
       0.8630269369782478, 0.5051579020959115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01201864247176827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1613677496440505, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.964540160485017`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4271791082188854, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5051579020959115, -0.8630269369782478, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.10158126102411, 1.6554902335190946`, 0.}, 
      Optica`Optica`RayEnd :> {6.111402240816899, 1.6956126639955889`, 0.}, 
      RotationMatrix :> {{0.2377563233656335, 0.9713248327411665, 
       0.}, {-0.9713248327411665, 0.2377563233656335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.415558756770056, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04130691311913142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.097218313155238`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08693219696693287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2377563233656335, 0.9713248327411665, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.111402240816899, 1.6956126639955889`, 0.}, 
      Optica`Optica`RayEnd :> {6.184072372672007, 1.8586024464312514`, 0.}, 
      RotationMatrix :> {{0.40721549411083485`, 0.9133321090140583, 
       0.}, {-0.9133321090140583, 0.40721549411083485`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.219363342218478, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17845620539018378`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.36133349713271, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4243596795825109, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.40721549411083485`, 0.9133321090140583, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.184072372672007, 1.8586024464312514`, 0.}, 
      Optica`Optica`RayEnd :> {6.36240697690967, 1.8520156282570719`, 0.}, 
      RotationMatrix :> {{0.9993185938687008, -0.036909997944749695`, 0.}, {
       0.036909997944749695`, 0.9993185938687008, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.18747791291442026`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17845620539018395`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.625448681110182`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.053634275622963704`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9993185938687008, -0.036909997944749695`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.36240697690967, 1.8520156282570719`, 0.}, 
      Optica`Optica`RayEnd :> {6.4228553982991645`, 1.6841090899871713`, 0.}, 
      RotationMatrix :> {{0.33872972507359816`, -0.9408837193572666, 0.}, {
       0.9408837193572666, 0.33872972507359816`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008330159073777816, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17845620539018398`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.889563865087654`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35819289573106766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.33872972507359816`, -0.9408837193572666, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8798616310272624`, 1.4511061084650112`, 0.},
       Optica`Optica`RayEnd :> {5.833820172339405, 1.4060403563564783`, 0.}, 
      RotationMatrix :> {{-0.7146385134871368, -0.6994939564005498, 0.}, {
       0.6994939564005498, -0.7146385134871368, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012948197299062807`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06442622083603396, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.574492338624848`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04577362788830458, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7146385134871368, -0.6994939564005498, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.833820172339405, 1.4060403563564783`, 0.}, 
      Optica`Optica`RayEnd :> {5.599442986112421, 1.1595858165884754`, 0.}, 
      RotationMatrix :> {{-0.6891285847229114, -0.7246390782436425, 0.}, {
       0.7246390782436425, -0.6891285847229114, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012907460466375639`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3401066091623869, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.07785012018518, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23184162520066287`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6891285847229114, -0.7246390782436425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.637302678486836, 1.0169603213082352`, 0.}, 
      Optica`Optica`RayEnd :> {6.858767059798419, 0.9834814317062208, 0.}, 
      RotationMatrix :> {{0.9887659171429442, -0.14947227534386234`, 0.}, {
       0.14947227534386234`, 0.9887659171429442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08655418072123228, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2239805979068419, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.530844498670472`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0305084600023938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9887659171429442, -0.14947227534386234`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.858767059798419, 0.9834814317062208, 0.}, 
      Optica`Optica`RayEnd :> {7.162702661414744, 0.9438053337150264, 0.}, 
      RotationMatrix :> {{0.9915868807006633, -0.12944287551784187`, 0.}, {
       0.12944287551784187`, 0.9915868807006633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08632282556897239, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.306514343353919, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.984485726834272`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33213937097040164`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9915868807006633, -0.12944287551784187`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.879946877019573, 1.1112905707736813`, 0.}, 
      Optica`Optica`RayEnd :> {4.630680122811341, 1.1441015350696153`, 0.}, 
      RotationMatrix :> {{-0.9914477571862711, 0.13050419445485825`, 
       0.}, {-0.13050419445485825`, -0.9914477571862711, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10126434327769537`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2514169328655816, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.710138155131173`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09992862116086007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9914477571862711, 0.13050419445485825`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.630680122811341, 1.1441015350696153`, 0.}, 
      Optica`Optica`RayEnd :> {4.395280740220098, 1.1447153361225655`, 0.}, 
      RotationMatrix :> {{-0.999996600520636, 0.0026074790833754413`, 
       0.}, {-0.0026074790833754413`, -0.999996600520636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09949505690056722, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23540018282930641`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.058530425718546`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3760360187080714, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999996600520636, 0.0026074790833754413`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5841933507179515`, 0.3253409192139103, 0.}, 
      Optica`Optica`RayEnd :> {7.626714297149007, 0.32609206755954295`, 0.}, 
      RotationMatrix :> {{0.9998440038220597, 0.017662616484311777`, 
       0.}, {-0.017662616484311777`, 0.9998440038220597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07331833380489744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04252758057108228, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.11519426885085, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33851110201066054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9998440038220597, 0.017662616484311777`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.626714297149007, 0.32609206755954295`, 0.}, 
      Optica`Optica`RayEnd :> {7.891581672955386, 0.3077814576649613, 0.}, 
      RotationMatrix :> {{0.9976189669440538, -0.06896663536434017, 0.}, {
       0.06896663536434017, 0.9976189669440538, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07275867915652669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2654995389850397, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.508133586548709`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2136622778268778, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9976189669440538, -0.06896663536434017, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.628638705595014, 1.3647266179686772`, 0.}, 
      Optica`Optica`RayEnd :> {4.628289473465782, 1.3653888162929944`, 0.}, 
      RotationMatrix :> {{-0.4664854711917487, 0.8845288605619447, 
       0.}, {-0.8845288605619447, -0.4664854711917487, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27769873481583474`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0007486452436344371, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.371789194721142`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13949084246473148`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4664854711917487, 0.8845288605619447, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.628289473465782, 1.3653888162929944`, 0.}, 
      Optica`Optica`RayEnd :> {4.503571201537513, 1.5849363906658709`, 0.}, 
      RotationMatrix :> {{-0.49393555235692693`, 0.8694985164552367, 
       0.}, {-0.8694985164552367, -0.49393555235692693`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2768719222552171, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25249907874245264`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.745487831259972`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3409974565097846, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.49393555235692693`, 0.8694985164552367, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8418719011631226`, -0.4257345527276301, 0.},
       Optica`Optica`RayEnd :> {3.6865263052883464`, -0.4917694976009767, 0.},
       RotationMatrix :> {{-0.9203030502693476, -0.3912062060664872, 0.}, {
       0.3912062060664872, -0.9203030502693476, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014975335166352324`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1687983059811777, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.314059002621482`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36153628431999923`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9203030502693476, -0.3912062060664872, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6865263052883464`, -0.4917694976009767, 0.},
       Optica`Optica`RayEnd :> {3.3847302367062975`, -0.6145580846091381, 0.},
       RotationMatrix :> {{-0.9262695987464098, -0.37686155340942523`, 0.}, {
       0.37686155340942523`, -0.9262695987464098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014936601135951322`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3258188209895821, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.796270857686064`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25442736223641393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9262695987464098, -0.37686155340942523`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6801569042007625`, -1.8359346973849022`, 
       0.}, Optica`Optica`RayEnd :> {4.628435784582611, -1.9140209948334994`, 
       0.}, RotationMatrix :> {{-0.5522111079699226, -0.833704319429035, 
       0.}, {0.833704319429035, -0.5522111079699226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01296517541926786, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09366186024090042, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.848365574097743`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18240435074462413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.5522111079699226, -0.833704319429035, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.628435784582611, -1.9140209948334994`, 0.}, 
      Optica`Optica`RayEnd :> {4.444584970458577, -2.17407961338191, 0.}, 
      RotationMatrix :> {{-0.5772698884286177, -0.8165534127744559, 0.}, {
       0.8165534127744559, -0.5772698884286177, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012926979602887445`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3184832914540061, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.319720845449671`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3780506280026243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.5772698884286177, -0.8165534127744559, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.6059430288850525`, -1.7364162622695076`, 
       0.}, Optica`Optica`RayEnd :> {5.580392820833384, -1.8113373396360717`, 
       0.}, RotationMatrix :> {{-0.32277501149021404`, -0.946475721800349, 
       0.}, {0.946475721800349, -0.32277501149021404`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009236915279233931, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07915794947603322, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.442882591509301`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.007810122608896826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.32277501149021404`, -0.946475721800349, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.580392820833384, -1.8113373396360717`, 0.}, 
      Optica`Optica`RayEnd :> {5.466710937071036, -2.126897206581193, 0.}, 
      RotationMatrix :> {{-0.33893148254761013`, -0.9408110597447708, 0.}, {
       0.9408110597447708, -0.33893148254761013`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009212778928076043, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33541258223593623`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.939293213218487`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32484733794044635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.33893148254761013`, -0.9408110597447708, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.698922125620347, -1.8758034494156233`, 0.}, 
      Optica`Optica`RayEnd :> {6.1387084261467875`, -2.3126263188259486`, 0.},
       RotationMatrix :> {{0.7094931449697943, -0.7047123365181498, 0.}, {
       0.7047123365181498, 0.7094931449697943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1288157913514856, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6198598304218492, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.415401077471461`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26169885781784324`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7094931449697943, -0.7047123365181498, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.1387084261467875`, -2.3126263188259486`, 
       0.}, 
      Optica`Optica`RayEnd :> {6.275115027170251, -2.3916007283932794`, 0.}, 
      RotationMatrix :> {{0.8654203243568335, -0.501046566887862, 0.}, {
       0.501046566887862, 0.8654203243568335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11020071862710995`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15761890168784629`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.648677051969473`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2627281761886999, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8654203243568335, -0.501046566887862, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.275115027170251, -2.39160072839328, 0.}, 
      Optica`Optica`RayEnd :> {6.415962670666085, -2.3208500429481655`, 0.}, 
      RotationMatrix :> {{0.8935961486064217, 0.44887183381870777`, 
       0.}, {-0.44887183381870777`, 0.8935961486064217, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015925022623388713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15761890168784598`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.881953026467485`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.211638246717272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8935961486064217, 0.44887183381870777`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.864952223193942, -1.8532666557235384`, 0.}, 
      Optica`Optica`RayEnd :> {6.087955228348104, -1.7755293071353104`, 0.}, 
      RotationMatrix :> {{0.9442717924838862, 0.3291667995397902, 
       0.}, {-0.3291667995397902, 0.9442717924838862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008110396898927022, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23616400164570983`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.149226632406203`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08167386762664074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9442717924838862, 0.3291667995397902, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.087955228348104, -1.7755293071353104`, 0.}, 
      Optica`Optica`RayEnd :> {6.29649179032783, -1.714548594238228, 0.}, 
      RotationMatrix :> {{0.9598048522405408, 0.2806682126916288, 
       0.}, {-0.2806682126916288, 0.9598048522405408, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008078540266813651, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2172697517551874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.47078586500388, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15449651245302595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9598048522405408, 0.2806682126916288, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.446986340259031, -1.2858947444894115`, 0.}, 
      Optica`Optica`RayEnd :> {6.634975538592947, -1.2988093106254066`, 0.}, 
      RotationMatrix :> {{0.997648581465386, -0.06853690903522433, 0.}, {
       0.06853690903522433, 0.997648581465386, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011138660727445219`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1884322814931389, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.24811365602196, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015706165023651183`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.997648581465386, -0.06853690903522433, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.634975538592947, -1.2988093106254066`, 0.}, 
      Optica`Optica`RayEnd :> {6.920460688392599, -1.3157020578048386`, 0.}, 
      RotationMatrix :> {{0.9982539169634744, -0.05906875034297252, 0.}, {
       0.05906875034297252, 0.9982539169634744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011110705312078101`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2859845024881561, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.67137071970443, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3909082105631478, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9982539169634744, -0.05906875034297252, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.854644651235509, -1.0547381333962738`, 0.}, 
      Optica`Optica`RayEnd :> {3.3777554314599088`, -1.2431677270440258`, 0.},
       RotationMatrix :> {{-0.930032719118252, -0.3674767222144963, 0.}, {
       0.3674767222144963, -0.930032719118252, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17862020868966294`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5127660672279686, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.451284521292006`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4302627286361166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.930032719118252, -0.3674767222144963, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3777554314599088`, -1.2431677270440258`, 
       0.}, Optica`Optica`RayEnd :> {3.08320727731976, -1.3467014046111412`, 
       0.}, RotationMatrix :> {{-0.9434162715747592, -0.33161082390051716`, 
       0.}, {0.33161082390051716`, -0.9434162715747592, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17803973008588353`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3122144094976083, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.913361847348467`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3170786959815689, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9434162715747592, -0.33161082390051716`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6037690263909803`, 0.23251298497403247`, 
       0.}, Optica`Optica`RayEnd :> {3.4006273323013927`, 0.2693601613068275, 
       0.}, RotationMatrix :> {{-0.9839445672305586, 0.17847433601912885`, 
       0.}, {-0.17847433601912885`, -0.9839445672305586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06471109920873179, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20645644160763704`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.34128876114844, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4243677774598775, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9839445672305586, 0.17847433601912885`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4006273323013927`, 0.2693601613068275, 0.}, 
      Optica`Optica`RayEnd :> {3.0823029265595387`, 0.3204098587077727, 0.}, 
      RotationMatrix :> {{-0.9873835675674664, 0.1583467413549859, 
       0.}, {-0.1583467413549859, -0.9873835675674664, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06453786688081013, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.322391840615783, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.8184286852598, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17221897413353246`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9873835675674664, 0.1583467413549859, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.955364090593181, 1.6592345551760308`, 0.}, 
      Optica`Optica`RayEnd :> {4.990563917608184, 1.8428149348015401`, 0.}, 
      RotationMatrix :> {{0.18831035796382498`, 0.9821095708135297, 
       0.}, {-0.9821095708135297, 0.18831035796382498`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024627353653903755`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18692453986925364`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.831242642913384`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38364641664834326`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.18831035796382498`, 0.9821095708135297, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.990563917608184, 1.8428149348015401`, 0.}, 
      Optica`Optica`RayEnd :> {5.042768365054769, 2.0940943312606244`, 0.}, 
      RotationMatrix :> {{0.20341114780236672`, 0.9790934097162144, 
       0.}, {-0.9790934097162144, 0.20341114780236672`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024563707780477777`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25664496764605566`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.211077195029546`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22417909856085133`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.20341114780236672`, 0.9790934097162144, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.267562956917228, 1.4159252596804341`, 0.}, 
      Optica`Optica`RayEnd :> {6.3414793017053155`, 1.4891410751493424`, 0.}, 
      RotationMatrix :> {{0.710465422849919, 0.7037321102057843, 
       0.}, {-0.7037321102057843, 0.710465422849919, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00883834873261919, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10403932747576128`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.902451166319258`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04803409799231373, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.710465422849919, 0.7037321102057843, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.3414793017053155`, 1.4891410751493424`, 0.},
       Optica`Optica`RayEnd :> {6.540441563317021, 1.658662282854143, 0.}, 
      RotationMatrix :> {{0.7611774360680673, 0.6485436845894373, 
       0.}, {-0.6485436845894373, 0.7611774360680673, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008784764056170971, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26138749282882445`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.289304655705918`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1323655831269353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7611774360680673, 0.6485436845894373, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.660008727854707, -0.8391463939340966, 0.}, 
      Optica`Optica`RayEnd :> {2.54432612307239, -0.8621886350649688, 0.}, 
      RotationMatrix :> {{-0.9807340832785364, -0.19534753107169953`, 0.}, {
       0.19534753107169953`, -0.9807340832785364, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23025381708549322`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11795511826773367`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.879387313272076`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10071595507794567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9807340832785364, -0.19534753107169953`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.54432612307239, -0.8621886350649688, 0.}, 
      Optica`Optica`RayEnd :> {2.3362231553334047`, -0.9367987626976133, 0.}, 
      RotationMatrix :> {{-0.9413290910173204, -0.337490062675192, 0.}, {
       0.337490062675192, -0.9413290910173204, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22443726071711514`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22107355411069113`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.206576173355899`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26623613124668416`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9413290910173204, -0.337490062675192, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3465003261523547`, 2.0016919364102153`, 0.},
       Optica`Optica`RayEnd :> {2.322593379298374, 2.1193979559844265`, 0.}, 
      RotationMatrix :> {{-0.1990432259686228, 0.9799907112804711, 
       0.}, {-0.9799907112804711, -0.1990432259686228, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013976453203989363`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1201093216694009, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.072464432281418`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08336614604124339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1990432259686228, 0.9799907112804711, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.322593379298374, 2.1193979559844265`, 0.}, 
      Optica`Optica`RayEnd :> {2.258971730969517, 2.3682680267369927`, 0.}, 
      RotationMatrix :> {{-0.2476769042472682, 0.9688426864576568, 
       0.}, {-0.9688426864576568, -0.2476769042472682, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013922465758562676`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2568735608280231, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.452637302306892`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1634629008169722, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2476769042472682, 0.9688426864576568, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0948678087528037`, 1.28922010582574, 0.}, 
      Optica`Optica`RayEnd :> {2.057027867898407, 1.3599474591186946`, 0.}, 
      RotationMatrix :> {{-0.4717397888564077, 0.8817378134171812, 
       0.}, {-0.8817378134171812, -0.4717397888564077, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015122069281034293`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08021358755030637, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.612181342922037`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10997854120786196`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4717397888564077, 0.8817378134171812, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.057027867898407, 1.3599474591186946`, 0.}, 
      Optica`Optica`RayEnd :> {1.8907195989671668`, 1.684804414747426, 0.}, 
      RotationMatrix :> {{-0.45569813156848177`, 0.8901343791164312, 
       0.}, {-0.8901343791164312, -0.45569813156848177`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015082284760137343`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36495271191658957`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.15231135655859, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3997048158828596, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.45569813156848177`, 0.8901343791164312, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.030548797235382, 0.3379380311434561, 0.}, 
      Optica`Optica`RayEnd :> {1.9734752681722851`, 0.17096375846217324`, 0.},
       RotationMatrix :> {{-0.3234378166503089, -0.946249427350147, 0.}, {
       0.946249427350147, -0.3234378166503089, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013288356287742805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1764590475355672, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.117369477648992`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21582376657426988`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3234378166503089, -0.946249427350147, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9734752681722851`, 0.1709637584621732, 0.}, 
      Optica`Optica`RayEnd :> {1.8604948557158172`, -0.18781759303254186`, 
       0.}, RotationMatrix :> {{-0.3003601983328228, -0.9538258495435461, 
       0.}, {0.9538258495435461, -0.3003601983328228, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013251577968552922`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.37614974648297705`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.674071102443799`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4306788118792402, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3003601983328228, -0.9538258495435461, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.14196656423911, 3.043244514731989, 0.}, 
      Optica`Optica`RayEnd :> {5.170744503251183, 3.121852289530835, 0.}, 
      RotationMatrix :> {{0.34378167233747065`, 0.9390496055932573, 
       0.}, {-0.9390496055932573, 0.34378167233747065`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011355094425544969`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08370992792141616, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.591635104869972`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35135390427363505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.34378167233747065`, 0.9390496055932573, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.170744503251183, 3.121852289530835, 0.}, 
      Optica`Optica`RayEnd :> {5.261063463459581, 3.37564683895124, 0.}, 
      RotationMatrix :> {{0.33527625564536245`, 0.9421198609521114, 
       0.}, {-0.9421198609521114, 0.33527625564536245`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011326642907984163`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26938668840281005`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.99032740370613, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04762737186439561, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33527625564536245`, 0.9421198609521114, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0356327260310234`, 2.687957121083041, 0.}, 
      Optica`Optica`RayEnd :> {3.0616699245015138`, 2.8842848435931794`, 0.}, 
      RotationMatrix :> {{0.13146996899500815`, 0.9913201537608584, 
       0.}, {-0.9913201537608584, 0.13146996899500815`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030576773362099727`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19804673774190198`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.723791132152963`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19948387775241572`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.13146996899500815`, 0.9913201537608584, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0616699245015138`, 2.8842848435931794`, 0.},
       Optica`Optica`RayEnd :> {3.0949401737714983`, 3.1903948146437107`, 0.},
       RotationMatrix :> {{0.10805091992262104`, 0.994145360952751, 
       0.}, {-0.994145360952751, 0.10805091992262104`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030492686970856185`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3079126887009433, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.179501911430359`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09632709292226663, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10805091992262104`, 0.994145360952751, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.392586079497609, -2.3630622067704063`, 0.}, 
      Optica`Optica`RayEnd :> {2.394983681095318, -2.386009537355096, 0.}, 
      RotationMatrix :> {{0.1039171364290255, -0.9945859584552713, 0.}, {
       0.9945859584552713, 0.1039171364290255, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00833797408153295, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02307224467589494, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.692198106517903`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2900611724380023, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.1039171364290255, -0.9945859584552713, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.394983681095318, -2.386009537355096, 0.}, 
      Optica`Optica`RayEnd :> {2.4434141231202973`, -2.618182018279854, 0.}, 
      RotationMatrix :> {{0.20420145620509228`, -0.9789288867347409, 0.}, {
       0.9789288867347409, 0.20420145620509228`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008252250294128315, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23716991506827365`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.043209580818948`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4286944566926582, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.20420145620509228`, -0.9789288867347409, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8588435170927085`, -2.274866792392901, 0.}, 
      Optica`Optica`RayEnd :> {2.9627488659543375`, -2.3139506941956443`, 0.},
       RotationMatrix :> {{0.9359751091257243, -0.35206617999615925`, 0.}, {
       0.35206617999615925`, 0.9359751091257243, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03161216749070068, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11101294024654661`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.167462857668436`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2790933279611107, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9359751091257243, -0.35206617999615925`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9627488659543375`, -2.3139506941956443`, 
       0.}, Optica`Optica`RayEnd :> {3.131828495403569, -2.4140370798315542`, 
       0.}, RotationMatrix :> {{0.8605346299116557, -0.509391942145544, 0.}, {
       0.509391942145544, 0.8605346299116557, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030314999018646115`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19648207471509846`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.458256328246781`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28805324360970563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8605346299116557, -0.509391942145544, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8201946499746575`, -1.8649612329970076`, 
       0.}, Optica`Optica`RayEnd :> {3.108523759879753, -1.8071764067739187`, 
       0.}, RotationMatrix :> {{0.9805027734277066, 0.19650524496963212`, 
       0.}, {-0.19650524496963212`, 0.9805027734277066, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009365273698826688, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2940625133543838, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.16995630359235, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23365286410306518`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9805027734277066, 0.19650524496963212`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.108523759879753, -1.8071764067739187`, 0.}, 
      Optica`Optica`RayEnd :> {3.4145530314090804`, -1.7368927213868033`, 0.},
       RotationMatrix :> {{0.9746268256398903, 0.2238359907233659, 
       0.}, {-0.2238359907233659, 0.9746268256398903, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009338396665339768, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31399635581383095`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.63467091019682, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.424067198360775, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9746268256398903, 0.2238359907233659, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3601829633056144`, -2.072207955493204, 0.}, 
      Optica`Optica`RayEnd :> {2.3453218671299387`, -2.0808772665983004`, 0.},
       RotationMatrix :> {{-0.8637703418813584, -0.5038856978384691, 0.}, {
       0.5038856978384691, -0.8637703418813584, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2588774214069859, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01720491600036557, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.076039186728773`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.059796149189903815`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8637703418813584, -0.5038856978384691, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3453218671299387`, -2.0808772665983004`, 
       0.}, Optica`Optica`RayEnd :> {2.108755056526315, -2.2415706126908783`, 
       0.}, RotationMatrix :> {{-0.8272061986052553, -0.561898482814327, 
       0.}, {0.561898482814327, -0.8272061986052553, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.257487750986994, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28598287948337003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.499293848364161`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013139169750535584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8272061986052553, -0.561898482814327, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.37955614645619, -0.5501416006647808, 0.}, 
      Optica`Optica`RayEnd :> {2.3117054913161614`, -0.563277382484079, 0.}, 
      RotationMatrix :> {{-0.9817706795724902, -0.19006928403024645`, 0.}, {
       0.19006928403024645`, -0.9817706795724902, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00885509576718143, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06911049245183576, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.227419024055541`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03652720503276222, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9817706795724902, -0.19006928403024645`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3117054913161614`, -0.563277382484079, 0.}, 
      Optica`Optica`RayEnd :> {2.0670908527082337`, -0.6339946714700225, 0.}, 
      RotationMatrix :> {{-0.9606609305734639, -0.277723921313462, 0.}, {
       0.277723921313462, -0.9606609305734639, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008782603006572872, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2546316091588173, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.60427380561059, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19986853393291262`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9606609305734639, -0.277723921313462, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.187360460058735, 0.8624833169471092, 0.}, 
      Optica`Optica`RayEnd :> {2.117252386810888, 0.8880033394673086, 0.}, 
      RotationMatrix :> {{-0.9396806848530521, 0.3420529352514002, 
       0.}, {-0.3420529352514002, -0.9396806848530521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2133241493307555, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07460840089398087, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.497136267799107`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15514211396556693`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9396806848530521, 0.3420529352514002, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.117252386810888, 0.8880033394673086, 0.}, 
      Optica`Optica`RayEnd :> {1.82287096155126, 1.0079416589077277`, 0.}, 
      RotationMatrix :> {{-0.9260867029505805, 0.3773107719349167, 
       0.}, {-0.3773107719349167, -0.9260867029505805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21263547278197578`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.317876743421223, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.967593848062517`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021031729167206525`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9260867029505805, 0.3773107719349167, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.865402790228393, 1.7961382788338658`, 0.}, 
      Optica`Optica`RayEnd :> {7.3413858183556036`, 1.955001466937924, 0.}, 
      RotationMatrix :> {{0.9485623552374743, 0.3165903634451561, 
       0.}, {-0.3165903634451561, 0.9485623552374743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010506671303630892`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5017941366733316, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.33519591170877, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2476918448241146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9485623552374743, 0.3165903634451561, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3413858183556036`, 1.955001466937924, 0.}, 
      Optica`Optica`RayEnd :> {7.6650107297416685`, 2.069805418458244, 0.}, 
      RotationMatrix :> {{0.9424559133892579, 0.33433045227382446`, 
       0.}, {-0.33433045227382446`, 0.9424559133892579, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010478898418429052`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34338466849048194`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.843405221074683`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38654064417784134`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9424559133892579, 0.33433045227382446`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9862592797803313`, 1.3481438736691491`, 0.},
       Optica`Optica`RayEnd :> {3.9406505601097632`, 1.3331172926123287`, 0.},
       RotationMatrix :> {{-0.9497791096215826, -0.31292114490144957`, 0.}, {
       0.31292114490144957`, -0.9497791096215826, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010543338891818188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048020344107947435`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.147945238785367`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3477171748173569, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9497791096215826, -0.31292114490144957`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9406505601097632`, 1.3331172926123287`, 0.},
       Optica`Optica`RayEnd :> {3.6579620877190564`, 1.2411682766713321`, 0.},
       RotationMatrix :> {{-0.9509596180832698, -0.30931505746555854`, 0.}, {
       0.30931505746555854`, -0.9509596180832698, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010517277329279352`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29726653689090027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.5878997133839, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17181144443668792`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9509596180832698, -0.30931505746555854`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8677830330422824`, 1.489527299309895, 0.}, 
      Optica`Optica`RayEnd :> {3.7888325516111925`, 1.6179286271643638`, 0.}, 
      RotationMatrix :> {{-0.5237811431493117, 0.8518528711468903, 
       0.}, {-0.8518528711468903, -0.5237811431493117, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4079517230929995, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15073181320806744`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.558581022036009`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20003855768689463`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5237811431493117, 0.8518528711468903, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7888325516111925`, 1.6179286271643638`, 0.},
       Optica`Optica`RayEnd :> {3.64293783700036, 1.8804307999132586`, 0.}, 
      RotationMatrix :> {{-0.4857960338317726, 0.8740722015447692, 
       0.}, {-0.8740722015447692, -0.4857960338317726, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4065136136684532, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30032092575987224`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.00305599216062, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30980541975078896`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4857960338317726, 0.8740722015447692, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9779876884070617`, 1.6374489948889326`, 0.},
       Optica`Optica`RayEnd :> {4.122485381220374, 1.7816297349162387`, 0.}, 
      RotationMatrix :> {{0.7078827182449516, 0.7063299917249295, 
       0.}, {-0.7063299917249295, 0.7078827182449516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010031209033109072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20412660047919257`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.903132451635795`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09268977524291643, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7078827182449516, 0.7063299917249295, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.122485381220374, 1.7816297349162387`, 0.}, 
      Optica`Optica`RayEnd :> {4.297582025844731, 1.9168082156473396`, 0.}, 
      RotationMatrix :> {{0.7915549862990817, 0.611097949321597, 
       0.}, {-0.611097949321597, 0.7915549862990817, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009860713068529951, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2212059145038334, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.230517205101469`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21935129334518644`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7915549862990817, 0.611097949321597, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.136273110507371, -0.3775728539432791, 0.}, 
      Optica`Optica`RayEnd :> {3.134336033072358, -0.3785168038398527, 0.}, 
      RotationMatrix :> {{-0.8989450055595333, -0.43806149908382785`, 0.}, {
       0.43806149908382785`, -0.8989450055595333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00945814085981273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0021548341923400293`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.048862130802792`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2366778900890481, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8989450055595333, -0.43806149908382785`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.134336033072358, -0.3785168038398527, 0.}, 
      Optica`Optica`RayEnd :> {2.8550571286116426`, -0.5179270523033074, 0.}, 
      RotationMatrix :> {{-0.8947207164590222, -0.44662606231505764`, 0.}, {
       0.44662606231505764`, -0.8947207164590222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009434397517409005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31214087180857863`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.510830621079489`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18168407636267384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8947207164590222, -0.44662606231505764`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.621919019136533, -0.6819973016660933, 0.}, 
      Optica`Optica`RayEnd :> {4.417776698132674, -0.7249371646637658, 0.}, 
      RotationMatrix :> {{-0.9785859771348164, -0.20583849337550228`, 0.}, {
       0.20583849337550228`, -0.9785859771348164, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02820164916367357, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20860948937932222`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.771525943992126`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32778501857669967`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9785859771348164, -0.20583849337550228`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.417776698132674, -0.7249371646637658, 0.}, 
      Optica`Optica`RayEnd :> {4.118371926014607, -0.7916360463911913, 0.}, 
      RotationMatrix :> {{-0.9760733701080334, -0.2174414315762897, 0.}, {
       0.2174414315762897, -0.9760733701080334, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028130144925547763`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30674412527505873`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.225507249399213`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05296272117199598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9760733701080334, -0.2174414315762897, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.950544740297555, -0.8794548318219492, 0.}, 
      Optica`Optica`RayEnd :> {4.650177889460393, -0.8977408237269249, 0.}, 
      RotationMatrix :> {{-0.9981520173235642, -0.06076635839754817, 0.}, {
       0.06076635839754817, -0.9981520173235642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013586179523650327`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3009229512379916, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.437663534851607`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27106206719713777`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9981520173235642, -0.06076635839754817, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.650177889460393, -0.8977408237269249, 0.}, 
      Optica`Optica`RayEnd :> {4.364103526572395, -0.9270059505467887, 0.}, 
      RotationMatrix :> {{-0.9948081696809649, -0.10176790032229555`, 0.}, {
       0.10176790032229555`, -0.9948081696809649, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013540244654536173`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2875673638463804, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.86326323334425, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13353238910238563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9948081696809649, -0.10176790032229555`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.258025463924768, -0.11781453791912785`, 0.},
       Optica`Optica`RayEnd :> {6.169782539508914, -0.07606490709734837, 0.}, 
      RotationMatrix :> {{-0.9039345061696613, 0.4276709115146959, 
       0.}, {-0.4276709115146959, -0.9039345061696613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009521553992527193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09762092697376464, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.583468142420479`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22304976191033185`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9039345061696613, 0.4276709115146959, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.169782539508914, -0.07606490709734837, 0.}, 
      Optica`Optica`RayEnd :> {5.8600330983876, 0.07567180311158178, 0.}, 
      RotationMatrix :> {{-0.8980367105665967, 0.43992052290695305`, 
       0.}, {-0.43992052290695305`, -0.8980367105665967, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009497200546697086, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3449184621037191, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.093947466333983`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16023481144866786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8980367105665967, 0.43992052290695305`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.353433065589417, -0.6194021000598979, 0.}, 
      Optica`Optica`RayEnd :> {7.385488297624597, -0.6009307024520898, 0.}, 
      RotationMatrix :> {{0.8664429323462608, 0.49927612098638635`, 
       0.}, {-0.49927612098638635`, 0.8664429323462608, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1014009879930647, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036996356988424295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.665206859081952`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39942814109485125`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8664429323462608, 0.49927612098638635`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.385488297624597, -0.6009307024520898, 0.}, 
      Optica`Optica`RayEnd :> {7.626023718036561, -0.44921376867471036`, 0.}, 
      RotationMatrix :> {{0.8458065452019363, 0.5334897263242888, 
       0.}, {-0.5334897263242888, 0.8458065452019363, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10106380707993437`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2843858584169928, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.0860979295391, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3746971139210001, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.8458065452019363, 0.5334897263242888, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.224219046840725, -1.1355461267955338`, 0.}, 
      Optica`Optica`RayEnd :> {7.269024531048093, -0.9459605645839262, 0.}, 
      RotationMatrix :> {{0.22999799195941656`, 0.973191103378281, 
       0.}, {-0.973191103378281, 0.22999799195941656`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020256445487972553`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1948081538697702, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.723578242778215`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16375881543214338`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.22999799195941656`, 0.973191103378281, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.269024531048093, -0.9459605645839262, 0.}, 
      Optica`Optica`RayEnd :> {7.334496159081358, -0.6055118865612469, 0.}, 
      RotationMatrix :> {{0.1888494197885076, 0.9820060573364829, 
       0.}, {-0.9820060573364829, 0.1888494197885076, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020187025190116295`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3466869429971602, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.236674918414012`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.023144528843638653`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.1888494197885076, 0.9820060573364829, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.404873413023072, -1.354943595196123, 0.}, 
      Optica`Optica`RayEnd :> {7.416265530500333, -1.3702567653724946`, 0.}, 
      RotationMatrix :> {{0.5968849831742314, -0.8023268142478458, 0.}, {
       0.8023268142478458, 0.5968849831742314, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.259437576608702, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019085950892376725`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.908730680702144`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4066822093019787, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5968849831742314, -0.8023268142478458, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.416265530500333, -1.3702567653724946`, 0.}, 
      Optica`Optica`RayEnd :> {7.5948414737607, -1.6208355140056565`, 0.}, 
      RotationMatrix :> {{0.5803579601602823, -0.8143614910336785, 0.}, {
       0.8143614910336785, 0.5803579601602823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.2453551903496605`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3076996535225399, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.364126167915503`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1422209262218577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5803579601602823, -0.8143614910336785, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5948414737607, -1.6208355140056565`, 0.}, 
      Optica`Optica`RayEnd :> {7.33511329940802, -1.4558495987725213`, 0.}, 
      RotationMatrix :> {{-0.844096414732081, 0.5361914235013897, 
       0.}, {-0.5361914235013897, -0.844096414732081, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014044680021468097`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30769965352253986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.819521655128861`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18223510542956667`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.844096414732081, 0.5361914235013897, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.120685522106613, -1.3520295228243422`, 0.}, 
      Optica`Optica`RayEnd :> {6.9146782862872165`, -1.3397586999505606`, 0.},
       RotationMatrix :> {{-0.9982307115204045, 0.05945962140365959, 
       0.}, {-0.05945962140365959, -0.9982307115204045, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020101898600125026`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2063723680727343, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.580314669637461`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3315823408736166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9982307115204045, 0.05945962140365959, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9146782862872165`, -1.3397586999505606`, 
       0.}, Optica`Optica`RayEnd :> {6.636570319863082, -1.3161057789349486`, 
       0.}, RotationMatrix :> {{-0.9964028014191775, 0.08474347953686345, 
       0.}, {-0.08474347953686345, -0.9964028014191775, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020045701722223426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791119876700724, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.99340041138917, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07593898534511273, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9964028014191775, 0.08474347953686345, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.750245482442702, -1.435074784336653, 0.}, 
      Optica`Optica`RayEnd :> {6.676997172033755, -1.5035954304728814`, 0.}, 
      RotationMatrix :> {{-0.7302811962529004, -0.6831466712203409, 0.}, {
       0.6831466712203409, -0.7302811962529004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09727748565061539, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10030151506678103`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.158965935268395`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39038642681586366`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7302811962529004, -0.6831466712203409, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.676997172033755, -1.5035954304728814`, 0.}, 
      Optica`Optica`RayEnd :> {6.489914395050555, -1.6575550106708106`, 0.}, 
      RotationMatrix :> {{-0.7721501218731773, -0.6354401539808743, 0.}, {
       0.6354401539808743, -0.7721501218731773, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.096802406225178, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24228808839575336`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.51755230609411, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38169140406013674`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7721501218731773, -0.6354401539808743, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.614645344029233, -0.7065919626854019, 0.}, 
      Optica`Optica`RayEnd :> {5.536595683944297, -0.696756088761932, 0.}, 
      RotationMatrix :> {{-0.9921527351505715, 0.125031796488893, 
       0.}, {-0.125031796488893, -0.9921527351505715, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015185309677946384`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07866698071753105, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.819156008515282`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13647836374167951`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9921527351505715, 0.125031796488893, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.536595683944297, -0.696756088761932, 0.}, 
      Optica`Optica`RayEnd :> {5.3712579755478105`, -0.6419208330212081, 0.}, 
      RotationMatrix :> {{-0.9491598113917534, 0.3147946194565133, 
       0.}, {-0.3147946194565133, -0.9491598113917534, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014311953167502712`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17419375158125572`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.07696276085554, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3156320969962272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9491598113917534, 0.3147946194565133, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5469469278676025`, 0.6368635855234813, 0.}, 
      Optica`Optica`RayEnd :> {6.49118398859179, 0.8602635747106462, 0.}, 
      RotationMatrix :> {{-0.24217975457500945`, 0.9702313984168869, 
       0.}, {-0.9702313984168869, -0.24217975457500945`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019139285280676866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2302543388635778, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.622471506327363`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18431332489559263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.24217975457500945`, 0.9702313984168869, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.49118398859179, 0.8602635747106462, 0.}, 
      Optica`Optica`RayEnd :> {6.41150589720002, 1.1926671838836118`, 0.}, 
      RotationMatrix :> {{-0.23309971376864544`, 0.9724528386718685, 
       0.}, {-0.9724528386718685, -0.23309971376864544`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01909127551823867, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3418197736220784, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.12836477128804, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3749990412845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23309971376864544`, 0.9724528386718685, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.881204474904297, 1.3242995202150794`, 0.}, 
      Optica`Optica`RayEnd :> {6.8980403815701745`, 1.3937316749718944`, 0.}, 
      RotationMatrix :> {{0.23565117547166153`, 0.9718377042998609, 
       0.}, {-0.9718377042998609, 0.23565117547166153`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02666006551827676, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07144418707940124, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.52248000762548, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4131458548726178, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.23565117547166153`, 0.9718377042998609, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8980403815701745`, 1.3937316749718944`, 0.},
       Optica`Optica`RayEnd :> {6.966496046375656, 1.6530371043377268`, 0.}, 
      RotationMatrix :> {{0.25525132003400863`, 0.9668747403986184, 
       0.}, {-0.9668747403986184, 0.25525132003400863`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02658880912907812, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26818926850744607`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.919400125016502`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22030427211365294`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.25525132003400863`, 0.9668747403986184, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.5969460739394234`, 0.25932011660617466`, 
       0.}, Optica`Optica`RayEnd :> {4.46026753674279, 0.28523889220537657`, 
       0.}, RotationMatrix :> {{-0.9824904929676053, 0.1863127242790235, 
       0.}, {-0.1863127242790235, -0.9824904929676053, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1124798784388572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1391143610802755, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.532799368161463`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3970403039654316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9824904929676053, 0.1863127242790235, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.46026753674279, 0.28523889220537657`, 0.}, 
      Optica`Optica`RayEnd :> {4.151550991487545, 0.3339560449741226, 0.}, 
      RotationMatrix :> {{-0.9877765487319169, 0.15587652092365464`, 
       0.}, {-0.15587652092365464`, -0.9877765487319169, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1121465306727456, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31253682389156484`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.99535386752098, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2142055554261047, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9877765487319169, 0.15587652092365464`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.892604669438865, -0.6189034417401148, 0.}, 
      Optica`Optica`RayEnd :> {4.892404349855441, -0.6192154998693977, 0.}, 
      RotationMatrix :> {{-0.5402056119664658, -0.8415330634027018, 0.}, {
       0.8415330634027018, -0.5402056119664658, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04334005395830969, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00037082099664763384`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.47506390204583, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19360502258168066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5402056119664658, -0.8415330634027018, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.892404349855441, -0.6192154998693977, 0.}, 
      Optica`Optica`RayEnd :> {4.727886367284384, -0.8570999932866199, 0.}, 
      RotationMatrix :> {{-0.5688095868188919, -0.8224692419433818, 0.}, {
       0.8224692419433818, -0.5688095868188919, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043206165761176765`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28923208466146866`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.903127387344805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3630084109283906, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5688095868188919, -0.8224692419433818, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.594092515281308, -1.1510887972667576`, 0.}, 
      Optica`Optica`RayEnd :> {5.591763735583777, -1.3605670779720842`, 0.}, 
      RotationMatrix :> {{-0.01111635916422822, -0.9999382113705483, 0.}, {
       0.9999382113705483, -0.01111635916422822, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023411402492234893`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20949122488099417`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.245368091905247`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09140092972600045, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.01111635916422822, -0.9999382113705483, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.591763735583777, -1.3605670779720842`, 0.}, 
      Optica`Optica`RayEnd :> {5.578707936680302, -1.6625646141888275`, 0.}, 
      RotationMatrix :> {{-0.04319113247116778, -0.999066827632595, 0.}, {
       0.999066827632595, -0.04319113247116778, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02334105314434112, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3022796152008784, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.692741922402547`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1334836441702167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04319113247116778, -0.999066827632595, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.089186185011931, -0.46412778297490015`, 0.},
       Optica`Optica`RayEnd :> {6.205953928125927, -0.6174656362047188, 0.}, 
      RotationMatrix :> {{0.6058426260865167, -0.7955845099149386, 0.}, {
       0.7955845099149386, 0.6058426260865167, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012103739927135081`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1927360969436334, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.73585973859908, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3328867317467345, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6058426260865167, -0.7955845099149386, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.205953928125927, -0.6174656362047188, 0.}, 
      Optica`Optica`RayEnd :> {6.366015524438264, -0.8484054132965815, 0.}, 
      RotationMatrix :> {{0.5696434572742602, -0.8218919220825984, 0.}, {
       0.8218919220825984, 0.5696434572742602, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012060594818937327`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28098557837955446`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.15171839460082, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2324908876310367, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5696434572742602, -0.8218919220825984, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.16874912920781, 0.7568037859242456, 0.}, 
      Optica`Optica`RayEnd :> {6.128686699457673, 0.8147673432488303, 0.}, 
      RotationMatrix :> {{-0.5685748162680555, 0.8226315568380211, 
       0.}, {-0.8226315568380211, -0.5685748162680555, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009745104011571878, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07046114003622869, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.04303718673007, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00706621414189129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5685748162680555, 0.8226315568380211, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.128686699457673, 0.8147673432488302, 0.}, 
      Optica`Optica`RayEnd :> {5.940507675890693, 1.090761132862692, 0.}, 
      RotationMatrix :> {{-0.5633397669057407, 0.8262253367106247, 
       0.}, {-0.8262253367106247, -0.5633397669057407, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009720889215466981, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33404178902652704`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.53741903448933, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3952678057621355, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5633397669057407, 0.8262253367106247, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.962721548274071, 0.6105183577215063, 0.}, 
      Optica`Optica`RayEnd :> {6.964111540215825, 0.845293925448589, 0.}, 
      RotationMatrix :> {{0.00592040983871546, 0.9999824742200939, 
       0.}, {-0.9999824742200939, 0.00592040983871546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016329667455358837`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23477968242412323`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.627900950324726`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3765490606011601, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.00592040983871546, 0.9999824742200939, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.964111540215825, 0.845293925448589, 0.}, 
      Optica`Optica`RayEnd :> {6.975305451484222, 1.144078691628268, 0.}, 
      RotationMatrix :> {{0.03743853383922596, 0.999298932344055, 
       0.}, {-0.999298932344055, 0.03743853383922596, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01628091859219892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2989943814698365, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.070412634900084`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35087963437360636`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.03743853383922596, 0.999298932344055, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.39375033838211, -0.12084842573426252`, 0.}, 
      Optica`Optica`RayEnd :> {7.408684917542238, -0.34354261569780986`, 0.}, 
      RotationMatrix :> {{0.06691287328211659, -0.9977588222557248, 0.}, {
       0.9977588222557248, 0.06691287328211659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.13376973240683207`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2231944083040851, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.6329476075896, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41780520122580367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.06691287328211659, -0.9977588222557248, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.408684917542238, -0.34354261569780986`, 0.},
       Optica`Optica`RayEnd :> {7.438952443142733, -0.6266931228462788, 0.}, 
      RotationMatrix :> {{0.10628999264588601`, -0.9943351736026124, 0.}, {
       0.9943351736026124, 0.10628999264588601`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1333275609806711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28476364375462637`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.054397800346447`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3503081064711954, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.10628999264588601`, -0.9943351736026124, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5496058187056825`, -0.19014294206542603`, 
       0.}, Optica`Optica`RayEnd :> {7.600626168023581, -0.20339427849454242`,
        0.}, RotationMatrix :> {{0.9678869449174599, -0.25138588237676734`, 
       0.}, {0.25138588237676734`, 0.9678869449174599, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.6515889036243343`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.052713128930827545`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.656939941047394`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1085104721459548, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9678869449174599, -0.25138588237676734`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.600626168023581, -0.20339427849454242`, 0.},
       Optica`Optica`RayEnd :> {7.882934929861941, -0.2757101473357457, 0.}, 
      RotationMatrix :> {{0.9687224492686636, -0.24814676359550103`, 0.}, {
       0.24814676359550103`, 0.9687224492686636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.642568569406351, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29142378402760044`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.088247141408242`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3460613214564372, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9687224492686636, -0.24814676359550103`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.882934929861941, -0.2757101473357457, 0.}, 
      Optica`Optica`RayEnd :> {7.605830110964485, -0.1854840910062472, 0.}, 
      RotationMatrix :> {{-0.9508654889719339, 0.3096042988754595, 
       0.}, {-0.3096042988754595, -0.9508654889719339, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008998051745461854, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2914237840276005, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.51955434176909, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16993653387948152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9508654889719339, 0.3096042988754595, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.664545060342192, -0.06412059693375713, 0.}, 
      Optica`Optica`RayEnd :> {7.733352346359235, 0.0420126293025313, 0.}, 
      RotationMatrix :> {{0.5439913852223792, 0.8390908012866286, 
       0.}, {-0.8390908012866286, 0.5439913852223792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12478348207262034`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12648598467954586`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.008232815568638`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2955720919420466, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5439913852223792, 0.8390908012866286, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.733352346359235, 0.0420126293025313, 0.}, 
      Optica`Optica`RayEnd :> {7.8898389876045965`, 0.310250823629456, 0.}, 
      RotationMatrix :> {{0.5039055290400694, 0.8637587729238108, 
       0.}, {-0.8637587729238108, 0.5039055290400694, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12432259782539284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3105475773275706, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.467843230013443`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20559178602801959`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5039055290400694, 0.8637587729238108, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.543886199459315, -0.22501170017298794`, 0.},
       Optica`Optica`RayEnd :> {6.379552487833043, -0.3097494748182285, 0.}, 
      RotationMatrix :> {{-0.8887961074960566, -0.4583028248874949, 0.}, {
       0.4583028248874949, -0.8887961074960566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01614561899986869, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18489472471840468`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.155452615114566`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37887825200660175`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8887961074960566, -0.4583028248874949, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.379552487833043, -0.3097494748182285, 0.}, 
      Optica`Optica`RayEnd :> {6.125657458194816, -0.41832732762270464`, 0.}, 
      RotationMatrix :> {{-0.9194519662858212, -0.39320234192224324`, 0.}, {
       0.39320234192224324`, -0.9194519662858212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016053205872168536`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2761373502346729, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.564135893461883`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41953003564582614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9194519662858212, -0.39320234192224324`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.819217854866354, 0.46843169438588755`, 0.}, 
      Optica`Optica`RayEnd :> {5.667336484476603, 0.5313895380341801, 0.}, 
      RotationMatrix :> {{-0.9237794640937799, 0.3829249296123312, 
       0.}, {-0.3829249296123312, -0.9237794640937799, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00967498409481887, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1644130187920394, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.36326441553563, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.395683601902494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9237794640937799, 0.3829249296123312, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.667336484476603, 0.5313895380341801, 0.}, 
      Optica`Optica`RayEnd :> {5.370259476906691, 0.6360526074102332, 0.}, 
      RotationMatrix :> {{-0.9431771516177101, 0.3322903258692661, 
       0.}, {-0.3322903258692661, -0.9431771516177101, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009634840293621137, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31497477124034884`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.829427076971346`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36270059943878685`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9431771516177101, 0.3322903258692661, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8256738210161805`, -0.3516744978920914, 0.},
       Optica`Optica`RayEnd :> {6.825576837079949, -0.35327326938085934`, 0.},
       RotationMatrix :> {{-0.06055023251655212, -0.9981651513362859, 0.}, {
       0.9981651513362859, -0.06055023251655212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2950706688247494, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0016017103849274373`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.601363444684019`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2986120237907005, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.06055023251655212, -0.9981651513362859, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.825576837079949, -0.35327326938085934`, 0.},
       Optica`Optica`RayEnd :> {6.840886796903556, -0.5681950703666385, 0.}, 
      RotationMatrix :> {{0.07105497123498378, -0.9974724011534327, 0.}, {
       0.9974724011534327, 0.07105497123498378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2895606635512515, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2154664136443806, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.920253736877703`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35244407991911175`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.07105497123498378, -0.9974724011534327, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.0967852982839235`, 0.326322821662418, 0.}, 
      Optica`Optica`RayEnd :> {7.1057991123948865`, 0.2691809260645134, 0.}, 
      RotationMatrix :> {{0.155817684634513, -0.9877858316229984, 0.}, {
       0.9877858316229984, 0.155817684634513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2951346416981715, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05784846650818694, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.638906073964788`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2693639988573276, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.155817684634513, -0.9877858316229984, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1057991123948865`, 0.2691809260645134, 0.}, 
      Optica`Optica`RayEnd :> {7.149448457539012, 0.10347078033821686`, 0.}, 
      RotationMatrix :> {{0.25471930398713377`, -0.9670150341004576, 0.}, {
       0.9670150341004576, 0.25471930398713377`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29212706276233985`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1713625330349122, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.89252262285646, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42350995840334527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.25471930398713377`, -0.9670150341004576, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.192065638887377, 1.1046249733468794`, 0.}, 
      Optica`Optica`RayEnd :> {7.277988308189711, 0.951860803297774, 0.}, 
      RotationMatrix :> {{0.4902301360584129, -0.8715930321544276, 0.}, {
       0.8715930321544276, 0.4902301360584129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3468843872432643, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1752700680402397, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.54143569586292, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19139491033329725`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4902301360584129, -0.8715930321544276, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.277988308189711, 0.951860803297774, 0.}, 
      Optica`Optica`RayEnd :> {7.390408105692144, 0.7150344162751484, 0.}, 
      RotationMatrix :> {{0.42883042186192816`, -0.9033850061218195, 0.}, {
       0.9033850061218195, 0.42883042186192816`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.34500226009211427`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2621544362788438, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.929424261555608`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23689133474274876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.42883042186192816`, -0.9033850061218195, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.353649000460349, 1.3495682650002878`, 0.}, 
      Optica`Optica`RayEnd :> {7.3775247299827535`, 1.391018043860573, 0.}, 
      RotationMatrix :> {{0.4991325166880318, 0.86652566654697, 
       0.}, {-0.86652566654697, 0.4991325166880318, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      74.20067066856427, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047834450219413585`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.804961567294367`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3584923013136844, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4991325166880318, 0.86652566654697, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3775247299827535`, 1.391018043860573, 0.}, 
      Optica`Optica`RayEnd :> {7.543884862887944, 1.6644691373106297`, 0.}, 
      RotationMatrix :> {{0.5197455095770224, 0.8543211370875242, 
       0.}, {-0.8543211370875242, 0.5197455095770224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      73.99593692078204, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3200799811441888, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.278679939387766`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10022738335330869`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5197455095770224, 0.8543211370875242, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.543884862887944, 1.6644691373106297`, 0.}, 
      Optica`Optica`RayEnd :> {7.512885661753796, 1.345893802643445, 0.}, 
      RotationMatrix :> {{-0.09684829717664795, -0.9952991546936945, 0.}, {
       0.9952991546936945, -0.09684829717664795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20416884847466557`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32007998114418856`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.752398311481166`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1927837342919525, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.09684829717664795, -0.9952991546936945, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.060538310049242, 1.3634434958074577`, 0.}, 
      Optica`Optica`RayEnd :> {6.863122473350959, 1.3608280192880524`, 0.}, 
      RotationMatrix :> {{-0.9999122493160311, -0.013247402302120834`, 0.}, {
       0.013247402302120834`, -0.9999122493160311, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.34367846999673873`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19743316159325025`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.439713439846662`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22292913473889847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9999122493160311, -0.013247402302120834`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.863122473350959, 1.3608280192880524`, 0.}, 
      Optica`Optica`RayEnd :> {6.57982954868064, 1.3401081333321252`, 0.}, 
      RotationMatrix :> {{-0.9973359944621915, -0.07294459644216718, 0.}, {
       0.07294459644216718, -0.9973359944621915, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.34210884544200904`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28404963446955833`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.860106898861607`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2125379735435438, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9973359944621915, -0.07294459644216718, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.295198604732274, 1.0441447323620774`, 0.}, 
      Optica`Optica`RayEnd :> {6.189895363322487, 1.0385792570356913`, 0.}, 
      RotationMatrix :> {{-0.9986062580634089, -0.05277822805471595, 0.}, {
       0.05277822805471595, -0.9986062580634089, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2935879481856063, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10545021179218457`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.610996527749446`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2605088323045261, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9986062580634089, -0.05277822805471595, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.189895363322487, 1.0385792570356913`, 0.}, 
      Optica`Optica`RayEnd :> {5.883323261180942, 1.0085602719018325`, 0.}, 
      RotationMatrix :> {{-0.9952402144015582, -0.09745211972009421, 0.}, {
       0.09745211972009421, -0.9952402144015582, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.292540606754237, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3080382983980286, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.066893209378529`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14964129436996923`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9952402144015582, -0.09745211972009421, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.34378759472657, 1.0085816823173743`, 0.}, 
      Optica`Optica`RayEnd :> {5.166006433166219, 1.0399900566600764`, 0.}, 
      RotationMatrix :> {{-0.984750145401162, 0.17397457036127253`, 
       0.}, {-0.17397457036127253`, -0.984750145401162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2967890755791845, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18053428312816078`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.260414901907883`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36238498668853647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.984750145401162, 0.17397457036127253`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.166006433166219, 1.0399900566600764`, 0.}, 
      Optica`Optica`RayEnd :> {4.858833762293857, 1.081384031628743, 0.}, 
      RotationMatrix :> {{-0.9910419642174088, 0.1335508336181376, 
       0.}, {-0.1335508336181376, -0.9910419642174088, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29578886132670673`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3099492069590869, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.719139728207331`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2416407656165378, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9910419642174088, 0.1335508336181376, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.433388240338392, -0.11117953659543567`, 0.},
       Optica`Optica`RayEnd :> {6.441161199556236, -0.41274450725640877`, 0.},
       RotationMatrix :> {{0.025766846926596882`, -0.9996679796809841, 0.}, {
       0.9996679796809841, 0.025766846926596882`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00943900233920104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30166512961354325`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.39679485994046, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.386414911838435, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.025766846926596882`, -0.9996679796809841, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.441161199556236, -0.41274450725640877`, 0.},
       Optica`Optica`RayEnd :> {6.468322005052908, -0.690413361520776, 0.}, 
      RotationMatrix :> {{0.0973526197059986, -0.9952499522413343, 0.}, {
       0.9952499522413343, 0.0973526197059986, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009385218372845817, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27899408951394383`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.809706112421097`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4250282965438688, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0973526197059986, -0.9952499522413343, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.57323765724591, 1.646089620359747, 0.}, 
      Optica`Optica`RayEnd :> {6.8197075233683275`, 2.104862101175398, 0.}, 
      RotationMatrix :> {{0.4732638216614665, 0.8809207428062883, 
       0.}, {-0.8809207428062883, 0.4732638216614665, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18582469749230796`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5207874653446926, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.54961024042214, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15591773185019542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4732638216614665, 0.8809207428062883, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8197075233683275`, 2.104862101175398, 0.}, 
      Optica`Optica`RayEnd :> {6.902671251455068, 2.2927415826140214`, 0.}, 
      RotationMatrix :> {{0.4039488020220524, 0.9147815943409376, 
       0.}, {-0.9147815943409376, 0.4039488020220524, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18464906523227212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20538179014629487`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.853575289838657`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24606488785988262`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4039488020220524, 0.9147815943409376, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.174197682692963, 1.5494748272910812`, 0.}, 
      Optica`Optica`RayEnd :> {6.186069607961884, 1.5868232171547578`, 0.}, 
      RotationMatrix :> {{0.30293362611627744`, 0.9530116568899053, 
       0.}, {-0.9530116568899053, 0.30293362611627744`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09570032059428298, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.039189856276848394`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.760948328405377`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4281999721170763, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.30293362611627744`, 0.9530116568899053, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.186069607961884, 1.5868232171547578`, 0.}, 
      Optica`Optica`RayEnd :> {6.287150018382918, 1.8816042394023436`, 0.}, 
      RotationMatrix :> {{0.32436059378947335`, 0.9459335099236835, 
       0.}, {-0.9459335099236835, 0.32436059378947335`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09543951924306254, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31162974897820056`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.222160356893113`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19722420337019445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32436059378947335`, 0.9459335099236835, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.036656461720002, 1.6775537955970146`, 0.}, 
      Optica`Optica`RayEnd :> {5.625588209786038, 1.954739381579031, 0.}, 
      RotationMatrix :> {{-0.8291155956865832, 0.559077212010364, 
       0.}, {-0.559077212010364, -0.8291155956865832, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.0293034668788104`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.49579124319035583`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.650946827920833`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1352941307767149, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8291155956865832, 0.559077212010364, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.625588209786038, 1.954739381579031, 0.}, 
      Optica`Optica`RayEnd :> {5.434632846005179, 2.0883302110018165`, 0.}, 
      RotationMatrix :> {{-0.8193889796180508, 0.5732379087957188, 
       0.}, {-0.5732379087957188, -0.8193889796180508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.0213846701845166`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23304604837359494`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.995854979513753`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2164514332292174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8193889796180508, 0.5732379087957188, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.875024991266699, 1.5816524017169022`, 0.}, 
      Optica`Optica`RayEnd :> {5.386838787639893, 1.17707328175869, 0.}, 
      RotationMatrix :> {{-0.7699580350856063, -0.638094526075182, 0.}, {
       0.638094526075182, -0.7699580350856063, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0900926386418106, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.6340426119100471, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.114356303056576`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30150003199133574`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7699580350856063, -0.638094526075182, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.386838787639893, 1.17707328175869, 0.}, 
      Optica`Optica`RayEnd :> {5.216418216343868, 1.0764549847096392`, 0.}, 
      RotationMatrix :> {{-0.8611140652032541, -0.5084118081920648, 0.}, {
       0.5084118081920648, -0.8611140652032541, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08730617473994005, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1979070812828954, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.407258783355262`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2936727848384837, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8611140652032541, -0.5084118081920648, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.995683381404745, 1.3667402332319012`, 0.}, 
      Optica`Optica`RayEnd :> {5.915766996348002, 1.329938586737978, 0.}, 
      RotationMatrix :> {{-0.908317295061435, -0.4182818326108335, 0.}, {
       0.4182818326108335, -0.908317295061435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1597814174755787, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08798289484440285, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.014333233058634`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2576436305371558, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.908317295061435, -0.4182818326108335, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.915766996348002, 1.329938586737978, 0.}, 
      Optica`Optica`RayEnd :> {5.589348707423781, 1.1826893079768626`, 0.}, 
      RotationMatrix :> {{-0.9115438114378106, -0.41120296670796114`, 0.}, {
       0.41120296670796114`, -0.9115438114378106, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15938277195077405`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.358093911481171, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.494179074443403`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1675408757158388, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9115438114378106, -0.41120296670796114`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.987631729229609, 0.8005725958373693, 0.}, 
      Optica`Optica`RayEnd :> {5.972639396864549, 0.6844474588014469, 0.}, 
      RotationMatrix :> {{-0.1280422700152831, -0.9917687114893938, 0.}, {
       0.9917687114893938, -0.1280422700152831, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00870132615424994, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11708892979849185`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.766737531109124`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20019848634276857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1280422700152831, -0.9917687114893938, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.972639396864549, 0.6844474588014469, 0.}, 
      Optica`Optica`RayEnd :> {5.934336026432902, 0.3840163419848044, 0.}, 
      RotationMatrix :> {{-0.1264709419540575, -0.9919703124797902, 0.}, {
       0.9919703124797902, -0.1264709419540575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008679869408958098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.302863012165763, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.214974789114454`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3087542202846538, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1264709419540575, -0.9919703124797902, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.082999887296782, 0.31698239836342923`, 0.}, 
      Optica`Optica`RayEnd :> {7.114516242080115, 0.28107956277846663`, 0.}, 
      RotationMatrix :> {{0.6597055919522317, -0.751524139297571, 0.}, {
       0.751524139297571, 0.6597055919522317, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009405012611945766, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04777336309984665, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.802898731436585`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32043752614926274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6597055919522317, -0.751524139297571, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.114516242080115, 0.28107956277846663`, 0.}, 
      Optica`Optica`RayEnd :> {7.269243314924368, 0.10997104284251003`, 0.}, 
      RotationMatrix :> {{0.6707097454322452, -0.7417199184208364, 0.}, {
       0.7417199184208364, 0.6707097454322452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009380802278179341, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23069155308685285`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.144322230005127`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.035755988847562536`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.6707097454322452, -0.7417199184208364, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.132603163998297, 0.8633038107538517, 0.}, 
      Optica`Optica`RayEnd :> {5.098684704037478, 0.8641184408836207, 0.}, 
      RotationMatrix :> {{-0.9997117091523277, 0.024010384914266644`, 
       0.}, {-0.024010384914266644`, -0.9997117091523277, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16564203078761788`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03392824116222378, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.397283452222295`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.039726440496895554`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9997117091523277, 0.024010384914266644`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0986847040374785`, 0.8641184408836207, 0.}, 
      Optica`Optica`RayEnd :> {4.874911054466808, 0.8967438186105634, 0.}, 
      RotationMatrix :> {{-0.98953820852963, 0.14427104304041727`, 
       0.}, {-0.14427104304041727`, -0.98953820852963, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16314354674625212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22613947358655198`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.731969873130392`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3136604824245467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.98953820852963, 0.14427104304041727`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.359421295530483, -0.9513629506393492, 0.}, 
      Optica`Optica`RayEnd :> {4.158007169770423, -1.0681850780699813`, 0.}, 
      RotationMatrix :> {{-0.8650275834696324, -0.5017243066034248, 0.}, {
       0.5017243066034248, -0.8650275834696324, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19829554761959076`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23284127536394428`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.482127552032445`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3084021781792399, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8650275834696324, -0.5017243066034248, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.158007169770423, -1.0681850780699813`, 0.}, 
      Optica`Optica`RayEnd :> {3.9514534114328006`, -1.1585364994661662`, 0.},
       RotationMatrix :> {{-0.9161831460009936, -0.40075983204872384`, 0.}, {
       0.40075983204872384`, -0.9161831460009936, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19571861166878693`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22545029259619068`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.815793985074807`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38764741018471066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9161831460009936, -0.40075983204872384`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.356816966072465, 1.0969723235612296`, 0.}, 
      Optica`Optica`RayEnd :> {4.309155676079274, 1.1214810476127461`, 0.}, 
      RotationMatrix :> {{-0.8893090237076697, 0.4573067464537458, 
       0.}, {-0.4573067464537458, -0.8893090237076697, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.059202186855767495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05359362012822458, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.61631056259487, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08246259301144312, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8893090237076697, 0.4573067464537458, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.309155676079274, 1.1214810476127461`, 0.}, 
      Optica`Optica`RayEnd :> {4.0960916602283275`, 1.2544517791728071`, 0.}, 
      RotationMatrix :> {{-0.8483457835266612, 0.5294425668309403, 
       0.}, {-0.5294425668309403, -0.8483457835266612, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.058782329376076733`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25115232489895495`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.988016003445324`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.048420502761211195`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8483457835266612, 0.5294425668309403, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.560609031189221, 0.6257838054686258, 0.}, 
      Optica`Optica`RayEnd :> {6.650244092232106, 0.6137514666967877, 0.}, 
      RotationMatrix :> {{0.9911101824549541, -0.13304362530428523`, 0.}, {
       0.13304362530428523`, 0.9911101824549541, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09335831416062572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0904390476756689, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.69236531935299, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3668587852214282, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9911101824549541, -0.13304362530428523`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.650244092232106, 0.6137514666967877, 0.}, 
      Optica`Optica`RayEnd :> {6.885969195992962, 0.6114723626851394, 0.}, 
      RotationMatrix :> {{0.9999532635009123, -0.009668030506491315, 0.}, {
       0.009668030506491315, 0.9999532635009123, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09186435675773418, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23573612124187143`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.041254778790961`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10133506676439627`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999532635009123, -0.009668030506491315, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.441039746564652, 1.1369156045927298`, 0.}, 
      Optica`Optica`RayEnd :> {5.380342865732236, 1.1634631615150444`, 0.}, 
      RotationMatrix :> {{-0.9161979513995855, 0.4007259834989512, 
       0.}, {-0.4007259834989512, -0.9161979513995855, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05480909780125768, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06624865373219319, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.719772116605117`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2641150035082131, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9161979513995855, 0.4007259834989512, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.380342865732236, 1.1634631615150444`, 0.}, 
      Optica`Optica`RayEnd :> {5.0774646795014835`, 1.2986243324192273`, 0.}, 
      RotationMatrix :> {{-0.9131965765983617, 0.40751934001839873`, 
       0.}, {-0.40751934001839873`, -0.9131965765983617, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.054672499688885344`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33166811395523077`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.21064092525886, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17087999534510062`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9131965765983617, 0.40751934001839873`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.415740315443308, 0.8455727215350262, 0.}, 
      Optica`Optica`RayEnd :> {5.3671627411517635`, 0.8414132536242973, 0.}, 
      RotationMatrix :> {{-0.9963541918148147, -0.08531309660917358, 0.}, {
       0.08531309660917358, -0.9963541918148147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013133500391118599`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048755326861287536`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.668944006460654`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22098117361058392`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9963541918148147, -0.08531309660917358, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3671627411517635`, 0.8414132536242973, 0.}, 
      Optica`Optica`RayEnd :> {5.096699440575585, 0.8041596610668059, 0.}, 
      RotationMatrix :> {{-0.9906467387468849, -0.1364515995148461, 0.}, {
       0.1364515995148461, -0.9906467387468849, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0130814633506536, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2730168989586535, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.07300901691946, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15521969155453438`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9906467387468849, -0.1364515995148461, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.43041916475558, 0.3419012486380427, 0.}, 
      Optica`Optica`RayEnd :> {5.2825728163768, -0.02039618674577165, 0.}, 
      RotationMatrix :> {{-0.3778309366007295, -0.9258746045482693, 0.}, {
       0.9258746045482693, -0.3778309366007295, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008228011738788303, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3913029189957939, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.616711086214107`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24239916037906079`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3778309366007295, -0.9258746045482693, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.2825728163768, -0.02039618674577165, 0.}, 
      Optica`Optica`RayEnd :> {5.165712099764965, -0.3395329293425942, 0.}, 
      RotationMatrix :> {{-0.3438497716874839, -0.9390246719391688, 0.}, {
       0.9390246719391688, -0.3438497716874839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008201918012840724, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3398598057469318, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.119703598719566`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3873483668297971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3438497716874839, -0.9390246719391688, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.132844253351959, 1.133288049183445, 0.}, 
      Optica`Optica`RayEnd :> {6.826067983688849, 0.37884217744721077`, 0.}, 
      RotationMatrix :> {{0.6765983779426478, -0.7363522492431032, 0.}, {
       0.7363522492431032, 0.6765983779426478, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011090489861349362`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0245719660824408`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.337466595035487`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00935830214143607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6765983779426478, -0.7363522492431032, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.826067983688849, 0.37884217744721077`, 0.}, 
      Optica`Optica`RayEnd :> {6.9089651371026575`, 0.23662464116783447`, 0.},
       RotationMatrix :> {{0.5035851051673649, -0.8639456243616106, 0.}, {
       0.8639456243616106, 0.5035851051673649, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010209838977461047`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16461398989602394`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.581095300081602`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4303821269267826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5035851051673649, -0.8639456243616106, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.111402240816899, 1.6956126639955889`, 0.}, 
      Optica`Optica`RayEnd :> {6.028279707946844, 1.8198766499719492`, 0.}, 
      RotationMatrix :> {{-0.5559955581411162, 0.8311852617361231, 
       0.}, {-0.8311852617361231, -0.5559955581411162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19619541455157707`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14950215276532478`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.297551197860773`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23151073252779916`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5559955581411162, 0.8311852617361231, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.028279707946844, 1.8198766499719492`, 0.}, 
      Optica`Optica`RayEnd :> {5.871677664455433, 2.085412051030004, 0.}, 
      RotationMatrix :> {{-0.5079952315845788, 0.8613598810528204, 
       0.}, {-0.8613598810528204, -0.5079952315845788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1953461399360908, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3082746328207167, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.753797654435434`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26018430259494263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5079952315845788, 0.8613598810528204, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.184072372672007, 1.8586024464312514`, 0.}, 
      Optica`Optica`RayEnd :> {6.320906309499774, 2.0591489993432495`, 0.}, 
      RotationMatrix :> {{0.5636113683105038, 0.8260400871090703, 
       0.}, {-0.8260400871090703, 0.5636113683105038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.03188542930406, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24278065440366217`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.686659574033618`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16220125895256654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5636113683105038, 0.8260400871090703, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.320906309499774, 2.0591489993432495`, 0.}, 
      Optica`Optica`RayEnd :> {6.440837379378749, 2.2750571618804605`, 0.}, 
      RotationMatrix :> {{0.48558751948519985`, 0.8741880580974608, 
       0.}, {-0.8741880580974608, 0.48558751948519985`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.997855174516123, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24698136806753257`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.052191998773566`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31582907365587365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.48558751948519985`, 0.8741880580974608, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.440837379378749, 2.2750571618804605`, 0.}, 
      Optica`Optica`RayEnd :> {6.2077278035136985`, 2.356664280519256, 0.}, 
      RotationMatrix :> {{-0.9438346612498736, 0.33041811727466663`, 
       0.}, {-0.33041811727466663`, -0.9438346612498736, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033743029800710284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24698136806753254`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.417724423513514`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.430440949257498, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9438346612498736, 0.33041811727466663`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.36240697690967, 1.8520156282570719`, 0.}, 
      Optica`Optica`RayEnd :> {6.6517446872126405`, 1.7884474615593178`, 0.}, 
      RotationMatrix :> {{0.9767054381020376, -0.21458445233032525`, 0.}, {
       0.21458445233032525`, 0.9767054381020376, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17914775384064238`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29623845533738397`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.022408211262277`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2969069476831516, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9767054381020376, -0.21458445233032525`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.6517446872126405`, 1.7884474615593178`, 0.},
       Optica`Optica`RayEnd :> {6.897227864791424, 1.7236485654343994`, 0.}, 
      RotationMatrix :> {{0.9668822693443413, -0.2552227991922654, 0.}, {
       0.2552227991922654, 0.9668822693443413, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17853621610004966`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25389148747680557`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.39816761272795, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4000803530161025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9668822693443413, -0.2552227991922654, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.599442986112421, 1.1595858165884754`, 0.}, 
      Optica`Optica`RayEnd :> {5.578820183056489, 1.1362831538007814`, 0.}, 
      RotationMatrix :> {{-0.6627344808173159, -0.7488544637883929, 0.}, {
       0.7488544637883929, -0.6627344808173159, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012866851797439688`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.031117745722991082`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.11954789945399, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04713092590736069, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6627344808173159, -0.7488544637883929, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.578820183056489, 1.1362831538007814`, 0.}, 
      Optica`Optica`RayEnd :> {5.372007422895698, 0.8886497691912926, 0.}, 
      RotationMatrix :> {{-0.641010105957357, -0.7675324384418789, 0.}, {
       0.7675324384418789, -0.641010105957357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012829652935721525`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3226357248329388, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.597048772206739`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28576366472080317`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.641010105957357, -0.7675324384418789, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.162702661414744, 0.9438053337150264, 0.}, 
      Optica`Optica`RayEnd :> {7.19531982452479, 0.9402167803239351, 0.}, 
      RotationMatrix :> {{0.9940021516645783, -0.10936051612070777`, 0.}, {
       0.10936051612070777`, 0.9940021516645783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0860920888178808, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.032813976363557006`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.028456455161438`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4020756396476656, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9940021516645783, -0.10936051612070777`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.19531982452479, 0.9402167803239352, 0.}, 
      Optica`Optica`RayEnd :> {7.3821519417883765`, 0.8912266074744308, 0.}, 
      RotationMatrix :> {{0.9672986456923544, -0.25364015857457567`, 0.}, {
       0.25364015857457567`, 0.9672986456923544, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08394844419421651, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1931483292110468, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.314315982393786`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19467785151965156`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9672986456923544, -0.25364015857457567`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.395280740220098, 1.1447153361225655`, 0.}, 
      Optica`Optica`RayEnd :> {4.341300350337997, 1.1378960908493214`, 0.}, 
      RotationMatrix :> {{-0.9921148471854955, -0.1253320788708921, 0.}, {
       0.1253320788708921, -0.9921148471854955, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09775668342113808, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05440941644532004, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.131439043755275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.031361981041229586`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9921148471854955, -0.1253320788708921, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.341300350337997, 1.1378960908493214`, 0.}, 
      Optica`Optica`RayEnd :> {4.156171182713343, 1.1450378863667876`, 0.}, 
      RotationMatrix :> {{-0.9992567229584378, 0.03854869157782631, 
       0.}, {-0.03854869157782631, -0.9992567229584378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09441775778949685, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18526687223735094`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.405634014666555`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3939267703369243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9992567229584378, 0.03854869157782631, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.891581672955386, 0.3077814576649613, 0.}, 
      Optica`Optica`RayEnd :> {8.077006186780842, 0.27867406472608236`, 0.}, 
      RotationMatrix :> {{0.9879022325546919, -0.1550779768808405, 0.}, {
       0.1550779768808405, 0.9879022325546919, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07220329647274092, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18769520678777366`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.759645163644326`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19363874115934254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9879022325546919, -0.1550779768808405, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.077006186780842, 0.27867406472608236`, 0.}, 
      Optica`Optica`RayEnd :> {8.382099314299674, 0.22347529134967298`, 0.}, 
      RotationMatrix :> {{0.9840243442716078, -0.17803395710041184`, 0.}, {
       0.17803395710041184`, 0.9840243442716078, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07200528489167993, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3100463207997843, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.218513718428007`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4227489749749967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9840243442716078, -0.17803395710041184`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.503571201537513, 1.5849363906658709`, 0.}, 
      Optica`Optica`RayEnd :> {4.440374935192335, 1.6884978939291888`, 0.}, 
      RotationMatrix :> {{-0.5209018640525349, 0.8536165696766871, 
       0.}, {-0.8536165696766871, -0.5209018640525349, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27604757142353303`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12132086810655811`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.90805779452276, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3080050017382753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5209018640525349, 0.8536165696766871, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.440374935192335, 1.6884978939291888`, 0.}, 
      Optica`Optica`RayEnd :> {4.278409306365115, 1.9170346464985808`, 0.}, 
      RotationMatrix :> {{-0.5782204101559004, 0.8158806023427339, 
       0.}, {-0.8158806023427339, -0.5782204101559004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27456430801567877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28011053567540084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.322621387322354`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26957357194082854`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5782204101559004, 0.8158806023427339, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3847302367062975`, -0.6145580846091381, 0.},
       Optica`Optica`RayEnd :> {3.2969396556608648`, -0.6486966623067383, 0.},
       RotationMatrix :> {{-0.9320125746784562, -0.3624259381463129, 0.}, {
       0.3624259381463129, -0.9320125746784562, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014897967291963146`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09419463152170494, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.922491663925149`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009198146389188007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9320125746784562, -0.3624259381463129, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2969396556608648`, -0.6486966623067383, 0.},
       Optica`Optica`RayEnd :> {3.056035109608411, -0.7627206856098533, 0.}, 
      RotationMatrix :> {{-0.9038664875990404, -0.4278146474764203, 0.}, {
       0.4278146474764203, -0.9038664875990404, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014813936086023877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26652669322033823`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.316951169891249`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07207453439840122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9038664875990404, -0.4278146474764203, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.444584970458577, -2.17407961338191, 0.}, 
      Optica`Optica`RayEnd :> {4.401395049186998, -2.231397359948631, 0.}, 
      RotationMatrix :> {{-0.6017963705877412, -0.7986495654211688, 0.}, {
       0.7986495654211688, -0.6017963705877412, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012888896312588756`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07176833125363867, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.415890409329547`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42036918959038483`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6017963705877412, -0.7986495654211688, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.401395049186998, -2.231397359948631, 0.}, 
      Optica`Optica`RayEnd :> {4.250973596039403, -2.385515828997722, 0.}, 
      RotationMatrix :> {{-0.698471268595943, -0.7156380977463215, 0.}, {
       0.7156380977463215, -0.698471268595943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012667005466950527`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2153581112219131, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.734620413937979`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21782873369398403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.698471268595943, -0.7156380977463215, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.466710937071036, -2.126897206581193, 0.}, 
      Optica`Optica`RayEnd :> {5.3881037401442144`, -2.333911060676379, 0.}, 
      RotationMatrix :> {{-0.35498860602468074`, -0.9348706271953642, 0.}, {
       0.9348706271953642, -0.35498860602468074`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009188705645965512, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2214358308766559, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.236017226593207`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42251841516417676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.35498860602468074`, -0.9348706271953642, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3881037401442144`, -2.333911060676379, 0.}, 
      Optica`Optica`RayEnd :> {5.334963802773455, -2.54581248256604, 0.}, 
      RotationMatrix :> {{-0.24324460772902484`, -0.9699649791671617, 0.}, {
       0.9699649791671617, -0.24324460772902484`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009059551948214036, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2184629614891925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.559342409597212`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24636096547916925`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.24324460772902484`, -0.9699649791671617, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.1387084261467875`, -2.3126263188259486`, 
       0.}, Optica`Optica`RayEnd :> {6.225760321846037, -2.5817075108829264`, 
       0.}, RotationMatrix :> {{0.3078081730063904, -0.9514484371895662, 
       0.}, {0.9514484371895662, 0.3078081730063904, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0186150727243756, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28281216463164593`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.794369378077867`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2051884765800791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3078081730063904, -0.9514484371895662, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.225760321846037, -2.5817075108829264`, 0.}, 
      Optica`Optica`RayEnd :> {6.290875589312144, -2.815415160633884, 0.}, 
      RotationMatrix :> {{0.2683956153137737, -0.9633087738001458, 0.}, {
       0.9633087738001458, 0.2683956153137737, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01855211657722031, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24260928178719599`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.153431115122917`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.060147439528292115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.2683956153137737, -0.9633087738001458, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.275115027170251, -2.39160072839328, 0.}, 
      Optica`Optica`RayEnd :> {6.376396982301569, -2.4193695636149584`, 0.}, 
      RotationMatrix :> {{0.964408877523486, -0.26441542495453885`, 0.}, {
       0.26441542495453885`, 0.964408877523486, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09427569600372121, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1050197250272102, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.789403483505936`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10022876438808376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.964408877523486, -0.26441542495453885`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.376396982301569, -2.4193695636149584`, 0.}, 
      Optica`Optica`RayEnd :> {6.709709089406296, -2.50852625996953, 0.}, 
      RotationMatrix :> {{0.9660373307547429, -0.2584025456303619, 0.}, {
       0.2584025456303619, 0.9660373307547429, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09404150968592384, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34503025555370426`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.300048261725419`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33204873820822844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9660373307547429, -0.2584025456303619, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.415962670666085, -2.3208500429481655`, 0.}, 
      Optica`Optica`RayEnd :> {7.324472913554798, -1.5196546351294475`, 0.}, 
      RotationMatrix :> {{0.7500144622157977, 0.6614214287934339, 
       0.}, {-0.6614214287934339, 0.7500144622157977, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0136237096309247, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2113236326199166`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.505126694178173`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02128205638370639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7500144622157977, 0.6614214287934339, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.324472913554798, -1.5196546351294475`, 0.}, 
      Optica`Optica`RayEnd :> {7.529897953148777, -1.3640197673514542`, 0.}, 
      RotationMatrix :> {{0.7970737745559296, 0.6038819403783847, 
       0.}, {-0.6038819403783847, 0.7970737745559296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013542091135676294`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25772399764178144`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.88655821068801, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10273811919775393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7970737745559296, 0.6038819403783847, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.29649179032783, -1.714548594238228, 0.}, 
      Optica`Optica`RayEnd :> {6.511435683837266, -1.6634132159734705`, 0.}, 
      RotationMatrix :> {{0.9728487647744171, 0.2314417440240428, 
       0.}, {-0.2314417440240428, 0.9728487647744171, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008046808763596223, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22094276242338282`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.766849166651212`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3259910196651864, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 68, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9728487647744171, 0.2314417440240428, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.920460688392599, -1.3157020578048386`, 0.}, 
      Optica`Optica`RayEnd :> {7.111345118114919, -1.3251806879671508`, 0.}, 
      RotationMatrix :> {{0.9987693971707067, -0.04959527472716471, 0.}, {
       0.04959527472716471, 0.9987693971707067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011082820058220305`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.191119622069972, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.927471013278193`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12079041299555202`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9987693971707067, -0.04959527472716471, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.111345118114919, -1.3251806879671508`, 0.}, 
      Optica`Optica`RayEnd :> {7.41383491331418, -1.3315744125057838`, 0.}, 
      RotationMatrix :> {{0.9997766885978474, -0.021132272388992575`, 0.}, {
       0.021132272388992575`, 0.9997766885978474, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01105083673751191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30255735970748937`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.375255905645277`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34479952706222194`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9997766885978474, -0.021132272388992575`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.08320727731976, -1.3467014046111412`, 0.}, 
      Optica`Optica`RayEnd :> {3.061437346951778, -1.3534291110795635`, 0.}, 
      RotationMatrix :> {{-0.9554172643363621, -0.2952589558472727, 0.}, {
       0.2952589558472727, -0.9554172643363621, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17746113791708212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022785782904083552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.943894796439938`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11575200494268742`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9554172643363621, -0.2952589558472727, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.061437346951778, -1.3534291110795635`, 0.}, 
      Optica`Optica`RayEnd :> {2.866810299806632, -1.442451087010559, 0.}, 
      RotationMatrix :> {{-0.9093868035476544, -0.41595148939916005`, 0.}, {
       0.41595148939916005`, -0.9093868035476544, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1743001972414755, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21402009176499662`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.260644532252133`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2051774743209216, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9093868035476544, -0.41595148939916005`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0823029265595387`, 0.3204098587077727, 0.}, 
      Optica`Optica`RayEnd :> {2.875842145644434, 0.349209221182765, 0.}, 
      RotationMatrix :> {{-0.9904108814950988, 0.1381531245252942, 
       0.}, {-0.1381531245252942, -0.9904108814950988, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06436509829774531, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20845972593055223`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.09776471800674, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1904930564905135, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9904108814950988, 0.1381531245252942, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.875842145644434, 0.349209221182765, 0.}, 
      Optica`Optica`RayEnd :> {2.605303873416047, 0.3617660148907954, 0.}, 
      RotationMatrix :> {{-0.9989246023076666, 0.04636419852073553, 
       0.}, {-0.04636419852073553, -0.9989246023076666, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06381637470298848, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2708295216710074, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.498592410079832`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34048873294972054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9989246023076666, 0.04636419852073553, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.042768365054769, 2.0940943312606244`, 0.}, 
      Optica`Optica`RayEnd :> {5.073874337603238, 2.2330401138623297`, 0.}, 
      RotationMatrix :> {{0.21846370253545944`, 0.9758450751397465, 
       0.}, {-0.9758450751397465, 0.21846370253545944`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024500226390709316`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14238508359721702`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.401873207049817`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.008901681524375649, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.21846370253545944`, 0.9758450751397465, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.073874337603238, 2.2330401138623297`, 0.}, 
      Optica`Optica`RayEnd :> {5.1481400246627125`, 2.369639803748075, 0.}, 
      RotationMatrix :> {{0.4776460070452585, 0.8785523842968728, 
       0.}, {-0.8785523842968728, 0.4776460070452585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019871883268168213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15548269212776555`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.63198759139891, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4147306083904585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4776460070452585, 0.8785523842968728, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.540441563317021, 1.658662282854143, 0.}, 
      Optica`Optica`RayEnd :> {6.625737115933364, 1.7209443206159765`, 0.}, 
      RotationMatrix :> {{0.807613557412659, 0.5897120838877816, 
       0.}, {-0.5897120838877816, 0.807613557412659, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008731504250084504, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10561431495727215`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.430827837748662`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04977424646495686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.807613557412659, 0.5897120838877816, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.625737115933364, 1.7209443206159765`, 0.}, 
      Optica`Optica`RayEnd :> {6.811440419389403, 1.8345145594733225`, 0.}, 
      RotationMatrix :> {{0.8531082743851521, 0.5217339093595396, 
       0.}, {-0.5217339093595396, 0.8531082743851521, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008670982290149471, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2176784694649433, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.752991972556778`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07485768987151586, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8531082743851521, 0.5217339093595396, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3362231553334047`, -0.9367987626976133, 0.},
       Optica`Optica`RayEnd :> {2.1561864118925493`, -1.033264979160073, 0.}, 
      RotationMatrix :> {{-0.8814433638435615, -0.47228973769937743`, 0.}, {
       0.47228973769937743`, -0.8814433638435615, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21876763927652582`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20425219682385426`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.480274117099864`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41013641200942386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8814433638435615, -0.47228973769937743`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1561864118925493`, -1.033264979160073, 0.}, 
      Optica`Optica`RayEnd :> {1.8528470577585507`, -1.17291256256883, 0.}, 
      RotationMatrix :> {{-0.9083636665781958, -0.4181811201388893, 0.}, {
       0.4181811201388893, -0.9083636665781958, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2177562740382631, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33394043079318375`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.974505954673775`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40618175901635606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9083636665781958, -0.4181811201388893, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.258971730969517, 2.3682680267369927`, 0.}, 
      Optica`Optica`RayEnd :> {2.1707816353633187`, 2.6531790411572076`, 0.}, 
      RotationMatrix :> {{-0.2956939876231818, 0.9552827150553398, 
       0.}, {-0.9552827150553398, -0.2956939876231818, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013868686852757673`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2982478484431805, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.852289419220753`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3451138813922913, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2956939876231818, 0.9552827150553398, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1707816353633187`, 2.6531790411572076`, 0.},
       Optica`Optica`RayEnd :> {2.114866436608288, 2.87721879600748, 0.}, 
      RotationMatrix :> {{-0.24214945419698597`, 0.9702389612008485, 
       0.}, {-0.9702389612008485, -0.24214945419698597`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013809783044862618`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23091193387346767`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.194039081353486`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37346409153705185`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.24214945419698597`, 0.9702389612008485, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.261063463459581, 3.37564683895124, 0.}, 
      Optica`Optica`RayEnd :> {5.317602229717479, 3.5391865573943955`, 0.}, 
      RotationMatrix :> {{0.326743423889562, 0.9451130805067329, 
       0.}, {-0.9451130805067329, 0.326743423889562, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011298262679029265`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1730371971526112, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.22219724789063, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03543816198498518, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.326743423889562, 0.9451130805067329, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.317602229717479, 3.5391865573943955`, 0.}, 
      Optica`Optica`RayEnd :> {5.410142819605809, 3.6812770041790377`, 0.}, 
      RotationMatrix :> {{0.5457418248810821, 0.8379533761346549, 
       0.}, {-0.8379533761346549, 0.5457418248810821, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009928046162535169, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16956844000090188`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.473158539091965`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42362391460275006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5457418248810821, 0.8379533761346549, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0949401737714983`, 3.1903948146437107`, 0.},
       Optica`Optica`RayEnd :> {3.100638485469136, 3.2575318555276516`, 0.}, 
      RotationMatrix :> {{0.08457174768191165, 0.996417392207717, 
       0.}, {-0.996417392207717, 0.08457174768191165, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030408831817915934`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06737843137722456, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.26978900947584, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04977645693171608, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08457174768191165, 0.996417392207717, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.100638485469136, 3.2575318555276516`, 0.}, 
      Optica`Optica`RayEnd :> {3.1531498249152365`, 3.3914826324245704`, 0.}, 
      RotationMatrix :> {{0.36497682288163297`, 0.93101660498577, 
       0.}, {-0.93101660498577, 0.36497682288163297`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023802575426291463`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14387581937807264`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.482725222155388`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3746266545776469, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.36497682288163297`, 0.93101660498577, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4434141231202973`, -2.618182018279854, 0.}, 
      Optica`Optica`RayEnd :> {2.507203505473403, -2.8192627123809926`, 0.}, 
      RotationMatrix :> {{0.3023820744691531, -0.9531868028040101, 0.}, {
       0.9531868028040101, 0.3023820744691531, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008167407844043167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21095622968091335`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.325890928591372`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12676177390048393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {0.3023820744691531, -0.9531868028040101, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.507203505473403, -2.8192627123809926`, 0.}, 
      Optica`Optica`RayEnd :> {2.5716690254112136`, -3.0748271865089367`, 0.},
       RotationMatrix :> {{0.2445862027323238, -0.9696275519151577, 0.}, {
       0.9696275519151577, 0.2445862027323238, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008129882585708893, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2635697321339173, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.71597413214957, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11781401453620782`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {0.2445862027323238, -0.9696275519151577, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.131828495403569, -2.4140370798315542`, 0.}, 
      Optica`Optica`RayEnd :> {3.5736524678233232`, -2.793166685997226, 0.}, 
      RotationMatrix :> {{0.7588971863879019, -0.6512104579109012, 0.}, {
       0.6512104579109012, 0.7588971863879019, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029071058343938503`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5821921339868044, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.2383937877891, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15902395088447796`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7588971863879019, -0.6512104579109012, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5736524678233232`, -2.793166685997226, 0.}, 
      Optica`Optica`RayEnd :> {3.7370821451708434`, -2.897242151157988, 0.}, 
      RotationMatrix :> {{0.8434866731869127, -0.537150102072106, 0.}, {
       0.537150102072106, 0.8434866731869127, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02840872678841154, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1937549015801755, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.52515104212776, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19957137838754474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8434866731869127, -0.537150102072106, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4145530314090804`, -1.7368927213868033`, 
       0.}, Optica`Optica`RayEnd :> {
       3.6175598185970927`, -1.6842546957809021`, 0.}, 
      RotationMatrix :> {{0.9679892104712908, 0.25099180945036276`, 
       0.}, {-0.25099180945036276`, 0.9679892104712908, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009311596765202315, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20972009294315686`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.915695834740651`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39301418492394663`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9679892104712908, 0.25099180945036276`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6175598185970927`, -1.6842546957809021`, 
       0.}, Optica`Optica`RayEnd :> {3.767724301347901, -1.6731776431117509`, 
       0.}, RotationMatrix :> {{0.9972903324480155, 0.0735662477344537, 
       0.}, {-0.0735662477344537, 0.9972903324480155, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008892737407424346, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1505724841252647, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.138543111246044`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0022129279614545583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9972903324480155, 0.0735662477344537, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.108755056526315, -2.2415706126908783`, 0.}, 
      Optica`Optica`RayEnd :> {2.0154221800005097`, -2.3147975971414723`, 0.},
       RotationMatrix :> {{-0.7867521845269705, -0.6172689852422844, 0.}, {
       0.6172689852422844, -0.7867521845269705, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2561055404059701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11863059087903421`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.658258840142066`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23635324876137828`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7867521845269705, -0.6172689852422844, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0154221800005097`, -2.3147975971414723`, 
       0.}, Optica`Optica`RayEnd :> {1.841612151678042, -2.4839424729838475`, 
       0.}, RotationMatrix :> {{-0.7166591236509767, -0.6974236162389497, 
       0.}, {0.6974236162389497, -0.7166591236509767, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25319534593083126`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24252817355760856`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.017200537007326`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00201762286010565, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7166591236509767, -0.6974236162389497, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.6650107297416685`, 2.069805418458244, 0.}, 
      Optica`Optica`RayEnd :> {8.063843397574225, 2.219770844068518, 0.}, 
      RotationMatrix :> {{0.9360177276403691, 0.35195285698934203`, 
       0.}, {-0.35195285698934203`, 0.9360177276403691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010451198946883183`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.42609520744653434`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.414372799053039`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09569465958369894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9360177276403691, 0.35195285698934203`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.063843397574225, 2.219770844068518, 0.}, 
      Optica`Optica`RayEnd :> {8.34571974139002, 2.320663474652185, 0.}, 
      RotationMatrix :> {{0.9415062759833304, 0.3369954484618469, 
       0.}, {-0.3369954484618469, 0.9415062759833304, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010424100011493862`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2993887040438444, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.85746808103793, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26233494131475343`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9415062759833304, 0.3369954484618469, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6579620877190564`, 1.2411682766713321`, 0.},
       Optica`Optica`RayEnd :> {3.1701167073340666`, 1.0845330539530924`, 0.},
       RotationMatrix :> {{-0.9521264351354322, -0.3057045166763061, 0.}, {
       0.3057045166763061, -0.9521264351354322, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010491280187039336`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5123745779788142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.274481647875511`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23004189756137494`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9521264351354322, -0.3057045166763061, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1701167073340666`, 1.0845330539530924`, 0.},
       Optica`Optica`RayEnd :> {2.847931087938611, 0.9721552211046295, 0.}, 
      RotationMatrix :> {{-0.9442115730581255, -0.32933949854686456`, 0.}, {
       0.32933949854686456`, -0.9442115730581255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01046206966147482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34122184962418545`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.779489985319305`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.050961325834923375`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9442115730581255, -0.32933949854686456`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.64293783700036, 1.8804307999132586`, 0.}, 
      Optica`Optica`RayEnd :> {3.627751011380789, 1.9108336284133907`, 0.}, 
      RotationMatrix :> {{-0.44687014786224416`, 0.8945988324101348, 
       0.}, {-0.8945988324101348, -0.44687014786224416`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4050805738602362, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.033984873888359406`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.048595723171022`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1027272622670726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.44687014786224416`, 0.8945988324101348, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.627751011380789, 1.9108336284133907`, 0.}, 
      Optica`Optica`RayEnd :> {3.5075177202934777`, 2.1367499951643203`, 0.}, 
      RotationMatrix :> {{-0.4698109681336203, 0.8827670441409505, 
       0.}, {-0.8827670441409505, -0.4698109681336203, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4039430340575549, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25591844218740206`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.427355017608377`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3485071297125135, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4698109681336203, 0.8827670441409505, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.297582025844731, 1.9168082156473396`, 0.}, 
      Optica`Optica`RayEnd :> {4.376064366816332, 1.9628549605429493`, 0.}, 
      RotationMatrix :> {{0.8625068150575165, 0.5060454465552867, 
       0.}, {-0.5060454465552867, 0.8625068150575165, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009693114947455218, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09099329953279002, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.352448226475408`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.032562114814977006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8625068150575165, 0.5060454465552867, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.376064366816332, 1.9628549605429493`, 0.}, 
      Optica`Optica`RayEnd :> {4.637363154484737, 2.100095438023548, 0.}, 
      RotationMatrix :> {{0.8853161559889517, 0.4649895740174681, 
       0.}, {-0.4649895740174681, 0.8853161559889517, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009657370105847711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2951474294248223, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.789266422024145`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07230668967115318, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8853161559889517, 0.4649895740174681, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8550571286116426`, -0.5179270523033074, 0.},
       Optica`Optica`RayEnd :> {2.704601447193009, -0.5948348992005054, 0.}, 
      RotationMatrix :> {{-0.8904148320843857, -0.45514989487435353`, 0.}, {
       0.45514989487435353`, -0.8904148320843857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009410713779352138, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1689725687367868, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.737253863186783`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3063296168063141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8904148320843857, -0.45514989487435353`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.704601447193009, -0.5948348992005054, 0.}, 
      Optica`Optica`RayEnd :> {2.4748039084685063`, -0.6836136830671304, 0.}, 
      RotationMatrix :> {{-0.9328071800678015, -0.3603758660259533, 0.}, {
       0.3603758660259533, -0.9328071800678015, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009309332837770938, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24635052520479117`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.101852640489874`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4122383382710711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9328071800678015, -0.3603758660259533, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.118371926014607, -0.7916360463911913, 0.}, 
      Optica`Optica`RayEnd :> {3.8896606650171655`, -0.8454441103070542, 0.}, 
      RotationMatrix :> {{-0.9734231939642597, -0.2290137232840416, 0.}, {
       0.2290137232840416, -0.9734231939642597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0280588219837724, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23495563123580043`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.540347795255185`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10329770351956694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9734231939642597, -0.2290137232840416, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8896606650171655`, -0.8454441103070542, 0.},
       Optica`Optica`RayEnd :> {3.7044712285073365`, -0.8600566613744223, 0.},
       RotationMatrix :> {{-0.9969013862426118, -0.07866146520094322, 0.}, {
       0.07866146520094322, -0.9969013862426118, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027285911110495113`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18576505065141927`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.815280070219286`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41981160600186046`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9969013862426118, -0.07866146520094322, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.364103526572395, -0.9270059505467887, 0.}, 
      Optica`Optica`RayEnd :> {4.161058715726155, -0.9562585138170068, 0.}, 
      RotationMatrix :> {{-0.9897808004558247, -0.14259721963988975`, 0.}, {
       0.14259721963988975`, -0.9897808004558247, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013494465091201462`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20514118959746547`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.138152427404854`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3293879029946876, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9897808004558247, -0.14259721963988975`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.161058715726155, -0.9562585138170068, 0.}, 
      Optica`Optica`RayEnd :> {3.8477455568113452`, -1.0070624334439158`, 0.},
       RotationMatrix :> {{-0.9871072795811094, -0.16006004685111574`, 0.}, {
       0.16006004685111574`, -0.9871072795811094, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013459071982889852`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31740537770906513`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.60791238641427, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0032520609337078074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9871072795811094, -0.16006004685111574`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8600330983876, 0.07567180311158181, 0.}, 
      Optica`Optica`RayEnd :> {5.767312050664425, 0.12266667029449653`, 0.}, 
      RotationMatrix :> {{-0.8919729245770007, 0.4520888207217167, 
       0.}, {-0.4520888207217167, -0.8919729245770007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009472909390102981, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10395051819218161`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.233241160711506`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03935688335179436, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8919729245770007, 0.4520888207217167, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.767312050664425, 0.12266667029449653`, 0.}, 
      Optica`Optica`RayEnd :> {5.5831585270802275`, 0.2281089080558495, 0.}, 
      RotationMatrix :> {{-0.8678131663699074, 0.49689064015639883`, 
       0.}, {-0.49689064015639883`, -0.8678131663699074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00943571583997411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21220411342053958`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.547303248573904`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03578035635486027, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8678131663699074, 0.49689064015639883`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.626023718036561, -0.4492137686747103, 0.}, 
      Optica`Optica`RayEnd :> {7.72673538027961, -0.3799163735965593, 0.}, 
      RotationMatrix :> {{0.8238198860450582, 0.5668516519837505, 
       0.}, {-0.5668516519837505, 0.8238198860450582, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10072774736858355`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12224961299069746`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.249912410946635`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2965764545774041, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {0.8238198860450582, 0.5668516519837505, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.72673538027961, -0.3799163735965593, 0.}, 
      Optica`Optica`RayEnd :> {7.888559142148566, -0.24197956494456557`, 0.}, 
      RotationMatrix :> {{0.7610413645415925, 0.648703353973656, 
       0.}, {-0.648703353973656, 0.7610413645415925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09965710111863778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21263464695697465`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.564611688442957`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42060867034177307`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.7610413645415925, 0.648703353973656, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.334496159081358, -0.6055118865612469, 0.}, 
      Optica`Optica`RayEnd :> {7.342652343122805, -0.5507698702134257, 0.}, 
      RotationMatrix :> {{0.14736641259282302`, 0.9890819685139961, 
       0.}, {-0.9890819685139961, 0.14736641259282302`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02011784280062146, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05534628887236306, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.31083894550298, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23451835499540066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.14736641259282302`, 0.9890819685139961, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.342652343122805, -0.5507698702134257, 0.}, 
      Optica`Optica`RayEnd :> {7.397588857222164, -0.3497113918811222, 0.}, 
      RotationMatrix :> {{0.26357458552800483`, 0.9646390194594764, 
       0.}, {-0.9646390194594764, 0.26357458552800483`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019825809161793266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20842872232657986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.619313454546317`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42648564305437797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.26357458552800483`, 0.9646390194594764, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.416265530500333, -1.3702567653724946`, 0.}, 
      Optica`Optica`RayEnd :> {7.410231089580755, -1.3423576688021113`, 0.}, 
      RotationMatrix :> {{-0.21140655099458677`, 0.9773982147500438, 
       0.}, {-0.9773982147500438, -0.21140655099458677`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014082386259038229`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028544247523020136`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.94697997238299, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31764702296223885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.21140655099458677`, 0.9773982147500438, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.410231089580755, -1.3423576688021113`, 0.}, 
      Optica`Optica`RayEnd :> {7.341191770303148, -1.1511869589989376`, 0.}, 
      RotationMatrix :> {{-0.33966819212927735`, 0.940545330781897, 
       0.}, {-0.940545330781897, -0.33966819212927735`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013809884103596163`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2032551792524971, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.247797637676687`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00236947593980058, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.33966819212927735`, 0.940545330781897, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5948414737607, -1.6208355140056565`, 0.}, 
      Optica`Optica`RayEnd :> {7.666658242611352, -1.7260979029653378`, 0.}, 
      RotationMatrix :> {{0.5635883614852665, -0.8260557843138394, 0.}, {
       0.8260557843138394, 0.5635883614852665, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.231310510328191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12742770035454346`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.534879286390591`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21392833977752224`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5635883614852665, -0.8260557843138394, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.666658242611352, -1.7260979029653378`, 0.}, 
      Optica`Optica`RayEnd :> {7.823226157153527, -1.930649643545257, 0.}, 
      RotationMatrix :> {{0.6078076765327134, -0.7940842703063097, 0.}, {
       0.7940842703063097, 0.6078076765327134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.209477790497711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25759450001574175`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.91611914641389, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16941887823052035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6078076765327134, -0.7940842703063097, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.823226157153527, -1.930649643545257, 0.}, 
      Optica`Optica`RayEnd :> {7.898725692883722, -1.6843677998318296`, 0.}, 
      RotationMatrix :> {{0.29309451764529615`, 0.9560834711081827, 
       0.}, {-0.9560834711081827, 0.29309451764529615`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02174160161941837, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2575945000157418, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.297359006437187`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12333496680642272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.29309451764529615`, 0.9560834711081827, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.33511329940802, -1.4558495987725213`, 0.}, 
      Optica`Optica`RayEnd :> {7.307758015701156, -1.4376774421161653`, 0.}, 
      RotationMatrix :> {{-0.8329584375083858, 0.5533355594786841, 
       0.}, {-0.5533355594786841, -0.8329584375083858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014007074744085104`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.032841114844447364`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.863528749020421`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11743759570648026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8329584375083858, 0.5533355594786841, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.307758015701156, -1.4376774421161653`, 0.}, 
      Optica`Optica`RayEnd :> {7.106842406878487, -1.2806810371144008`, 0.}, 
      RotationMatrix :> {{-0.7879652245364943, 0.6157197454371199, 
       0.}, {-0.6157197454371199, -0.7879652245364943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013918848862568497`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2549802993410704, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.240899592045206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021148893998513885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7879652245364943, 0.6157197454371199, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.636570319863082, -1.3161057789349486`, 0.}, 
      Optica`Optica`RayEnd :> {6.443841666585319, -1.2947815133730185`, 0.}, 
      RotationMatrix :> {{-0.9939345881933329, 0.10997288026122386`, 
       0.}, {-0.10997288026122386`, -0.9939345881933329, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019989661948342154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19390476553198865`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.253232797202035`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3140220902068126, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9939345881933329, 0.10997288026122386`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.443841666585319, -1.2947815133730185`, 0.}, 
      Optica`Optica`RayEnd :> {6.119803288382871, -1.2507439383342212`, 0.}, 
      RotationMatrix :> {{-0.9908912591212323, 0.13466444444298797`, 
       0.}, {-0.13466444444298797`, -0.9908912591212323, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019934029997220225`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32701709215784336`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.737218093595644`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04892687975860997, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9908912591212323, 0.13466444444298797`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.489914395050555, -1.6575550106708106`, 0.}, 
      Optica`Optica`RayEnd :> {6.32590391948947, -1.7759094604061625`, 0.}, 
      RotationMatrix :> {{-0.8109081174130106, -0.5851735000097722, 0.}, {
       0.5851735000097722, -0.8109081174130106, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09632964697135038, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20225531356661824`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.788574426273378`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3873718976099119, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8109081174130106, -0.5851735000097722, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.32590391948947, -1.7759094604061625`, 0.}, 
      Optica`Optica`RayEnd :> {6.141316224293418, -1.8963876196907001`, 0.}, 
      RotationMatrix :> {{-0.8374135911182645, -0.5465697370056378, 0.}, {
       0.5465697370056378, -0.8374135911182645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09597518380971577, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22042596054544267`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.114804847880633`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41955287271902053`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8374135911182645, -0.5465697370056378, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3712579755478105`, -0.6419208330212081, 0.},
       Optica`Optica`RayEnd :> {5.1564270156805865`, -0.520304833930549, 0.}, 
      RotationMatrix :> {{-0.8702332913122522, 0.49263984683726586`, 
       0.}, {-0.49263984683726586`, -0.8702332913122522, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01348882622830329, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2468659404460081, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.407763121053192`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4251190135964414, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8702332913122522, 0.49263984683726586`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1564270156805865`, -0.520304833930549, 0.}, 
      Optica`Optica`RayEnd :> {4.909899322736532, -0.39632633971432635`, 0.}, 
      RotationMatrix :> {{-0.8933888699026219, 0.4492842386887352, 
       0.}, {-0.4492842386887352, -0.8933888699026219, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013437340610427924`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.275946680386701, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.816164208025508`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39202613399680103`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8933888699026219, 0.4492842386887352, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.41150589720002, 1.1926671838836118`, 0.}, 
      Optica`Optica`RayEnd :> {6.354979373850421, 1.4386060953362028`, 0.}, 
      RotationMatrix :> {{-0.22399930425752176`, 0.974589304113351, 
       0.}, {-0.974589304113351, -0.22399930425752176`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019043386185443257`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25235133446938235`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.466515559477012`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20656013731780043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22399930425752176`, 0.974589304113351, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.354979373850421, 1.4386060953362028`, 0.}, 
      Optica`Optica`RayEnd :> {6.362812811651092, 1.5853767994063988`, 0.}, 
      RotationMatrix :> {{0.053296089324221085`, 0.9985787534605091, 
       0.}, {-0.9985787534605091, 0.053296089324221085`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015376806516702356`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14697959831567786`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.684045364984215`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2538531940280179, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.053296089324221085`, 0.9985787534605091, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.966496046375656, 1.6530371043377268`, 0.}, 
      Optica`Optica`RayEnd :> {7.051610080316026, 1.9509057415606017`, 0.}, 
      RotationMatrix :> {{0.2747471187047909, 0.9615165213158926, 
       0.}, {-0.9615165213158926, 0.2747471187047909, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026517743192262206`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3097904514581028, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.334519329970359`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08594122820829884, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2747471187047909, 0.9615165213158926, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.051610080316026, 1.9509057415606017`, 0.}, 
      Optica`Optica`RayEnd :> {7.076721279197129, 2.116419354507405, 0.}, 
      RotationMatrix :> {{0.1500002879175425, 0.9886859529823685, 
       0.}, {-0.9886859529823685, 0.1500002879175425, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026059017545362138`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.167407671209985, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.582282683361136`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2281699085685243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1500002879175425, 0.9886859529823685, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.151550991487545, 0.3339560449741226, 0.}, 
      Optica`Optica`RayEnd :> {3.5911278109148954`, 0.404730043300868, 0.}, 
      RotationMatrix :> {{-0.9921199645349501, 0.1252915638467686, 
       0.}, {-0.1252915638467686, -0.9921199645349501, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11181417082318149`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5648744109643473, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.752285578213204`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19746199650696766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9921199645349501, 0.1252915638467686, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5911278109148954`, 0.40473004330086804`, 
       0.}, Optica`Optica`RayEnd :> {3.3223761266728817`, 
       0.45320832530609795`, 0.}, 
      RotationMatrix :> {{-0.9841175103565202, 0.17751824078016298`, 
       0.}, {-0.17751824078016298`, -0.9841175103565202, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11136090835582428`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27308901773798555`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.156457324465423`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14023527851212902`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9841175103565202, 0.17751824078016298`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.727886367284384, -0.8570999932866199, 0.}, 
      Optica`Optica`RayEnd :> {4.664926309399225, -0.9417618929029387, 0.}, 
      RotationMatrix :> {{-0.5967414467837574, -0.8024335771205164, 0.}, {
       0.8024335771205164, -0.5967414467837574, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04307269117795738, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1055064269869199, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.044505999507278`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3837323211066095, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5967414467837574, -0.8024335771205164, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.664926309399225, -0.9417618929029387, 0.}, 
      Optica`Optica`RayEnd :> {4.5046753581612275`, -1.1223702829451243`, 0.},
       RotationMatrix :> {{-0.6636930049804283, -0.7480050769480439, 0.}, {
       0.7480050769480439, -0.6636930049804283, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04274634605243103, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2414534280690859, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.401857073049525`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2725939856244508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6636930049804283, -0.7480050769480439, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.578707936680302, -1.6625646141888275`, 0.}, 
      Optica`Optica`RayEnd :> {5.567958176702326, -1.8050679294545213`, 0.}, 
      RotationMatrix :> {{-0.07522143833073767, -0.9971668542503077, 0.}, {
       0.9971668542503077, -0.07522143833073767, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023270915190478556`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14290819501098534`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.884238903717268`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.048717767343396154`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.07522143833073767, -0.9971668542503077, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.567958176702326, -1.8050679294545213`, 0.}, 
      Optica`Optica`RayEnd :> {5.532598262384877, -2.126137966057005, 0.}, 
      RotationMatrix :> {{-0.10946959338642762`, -0.993990144882639, 0.}, {
       0.993990144882639, -0.10946959338642762`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02319900721475991, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3230112876424874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.362295609428148`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15584409299606355`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10946959338642762`, -0.993990144882639, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.366015524438264, -0.8484054132965815, 0.}, 
      Optica`Optica`RayEnd :> {6.390699751889108, -0.8876621830023901, 0.}, 
      RotationMatrix :> {{0.5323036003626034, -0.8465535287511415, 0.}, {
       0.8465535287511415, 0.5323036003626034, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01201760350620879, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.046372460066076725`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.213857491089364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3123570708682646, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5323036003626034, -0.8465535287511415, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.390699751889108, -0.8876621830023901, 0.}, 
      Optica`Optica`RayEnd :> {6.558502686551672, -1.1361041517412096`, 0.}, 
      RotationMatrix :> {{0.5597125335674733, -0.8286868405902679, 0.}, {
       0.8286868405902679, 0.5597125335674733, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011981220273258689`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2998019958442395, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.657564444938838`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11474417792070478`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5597125335674733, -0.8286868405902679, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.940507675890693, 1.090761132862692, 0.}, 
      Optica`Optica`RayEnd :> {5.906650267057244, 1.1411021167992952`, 0.}, 
      RotationMatrix :> {{-0.5580820031231205, 0.8297858023550926, 
       0.}, {-0.8297858023550926, -0.5580820031231205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009696734588689125, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06066744428950892, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.618713409837273`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2151661369551212, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5580820031231205, 0.8297858023550926, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.906650267057244, 1.1411021167992952`, 0.}, 
      Optica`Optica`RayEnd :> {5.7072547024128575`, 1.4150411308714208`, 0.}, 
      RotationMatrix :> {{-0.5884943908323917, 0.80850129991164, 
       0.}, {-0.80850129991164, -0.5884943908323917, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009665706492078707, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3388232203239054, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.120171775916653`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36335824550513446`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5884943908323917, 0.80850129991164, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.975305451484222, 1.144078691628268, 0.}, 
      Optica`Optica`RayEnd :> {6.991925785457024, 1.3846612093021353`, 0.}, 
      RotationMatrix :> {{0.06891944920209155, 0.9976222278606665, 
       0.}, {-0.9976222278606665, 0.06891944920209155, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01623231525874228, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24115593152909232`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.393561583149067`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13207967455719077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.06891944920209155, 0.9976222278606665, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.991925785457024, 1.3846612093021353`, 0.}, 
      Optica`Optica`RayEnd :> {7.001660413572281, 1.6459442831685513`, 0.}, 
      RotationMatrix :> {{0.03723118665679459, 0.9993066790230745, 
       0.}, {-0.9993066790230745, 0.03723118665679459, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016183740011021297`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2614643525867826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.780528824977505`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09582970381108441, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.03723118665679459, 0.9993066790230745, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.438952443142733, -0.6266931228462786, 0.}, 
      Optica`Optica`RayEnd :> {7.470287291566744, -0.8397595192879214, 0.}, 
      RotationMatrix :> {{0.145501057396918, -0.9893580960887612, 0.}, {
       0.9893580960887612, 0.145501057396918, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1328868511375348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2153582179030626, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.342977812336551`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.421181276979638, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.145501057396918, -0.9893580960887612, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.470287291566744, -0.8397595192879214, 0.}, 
      Optica`Optica`RayEnd :> {7.523807089318023, -1.1364673427704632`, 0.}, 
      RotationMatrix :> {{0.17751406032210787`, -0.9841182644316478, 0.}, {
       0.9841182644316478, 0.17751406032210787`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1324858712460342, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30149610489537837`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.789192047581711`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30049237962175807`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.17751406032210787`, -0.9841182644316478, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.600626168023581, -0.20339427849454245`, 0.},
       Optica`Optica`RayEnd :> {7.538987903316532, -0.1919606194188685, 0.}, 
      RotationMatrix :> {{-0.9832272225985134, 0.18238483692789056`, 
       0.}, {-0.18238483692789056`, -0.9832272225985134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009020334217983232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06268974585970889, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.740944200499404`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1905596736229362, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9832272225985134, 0.18238483692789056`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.538987903316532, -0.1919606194188685, 0.}, 
      Optica`Optica`RayEnd :> {7.40231010193742, -0.133882634183127, 0.}, 
      RotationMatrix :> {{-0.9203553515386959, 0.3910831457555841, 
       0.}, {-0.3910831457555841, -0.9203553515386959, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008270635030373886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1485054671009489, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.960732291808808`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2964228544172283, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9203553515386959, 0.3910831457555841, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.882934929861941, -0.2757101473357457, 0.}, 
      Optica`Optica`RayEnd :> {8.129580112651137, -0.3380120252934028, 0.}, 
      RotationMatrix :> {{0.9695471136563382, -0.24490486806240447`, 0.}, {
       0.24490486806240447`, 0.9695471136563382, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.633570517660891, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2543921582717657, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.429132633492408`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2981447243338071, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9695471136563382, -0.24490486806240447`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.129580112651137, -0.3380120252934028, 0.}, 
      Optica`Optica`RayEnd :> {8.371022184652178, -0.3716808198235361, 0.}, 
      RotationMatrix :> {{0.9904165683159343, -0.1381123499376085, 0.}, {
       0.1381123499376085, 0.9904165683159343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.590303230054508, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24377830473048245`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.789924524493522`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06541995177479076, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9904165683159343, -0.1381123499376085, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.371022184652178, -0.3716808198235361, 0.}, 
      Optica`Optica`RayEnd :> {8.400837322111133, -0.12973264472074333`, 0.}, 
      RotationMatrix :> {{0.12230431043450568`, 0.9924926476549538, 
       0.}, {-0.9924926476549538, 0.12230431043450568`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0427520758696878, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2437783047304826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.150716415494635`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18380543768226706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12230431043450568`, 0.9924926476549538, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.605830110964485, -0.1854840910062472, 0.}, 
      Optica`Optica`RayEnd :> {7.583808442483033, -0.17839516500404123`, 0.}, 
      RotationMatrix :> {{-0.9518958370077016, 0.3064217934276332, 
       0.}, {-0.3064217934276332, -0.9518958370077016, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008975824316198333, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023134535970530057`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.550554619969601`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.034171954365296665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9518958370077016, 0.3064217934276332, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.583808442483033, -0.17839516500404123`, 0.},
       Optica`Optica`RayEnd :> {7.380663139819714, -0.0912541415179408, 0.}, 
      RotationMatrix :> {{-0.9190159886132998, 0.3942202590850948, 
       0.}, {-0.3942202590850948, -0.9190159886132998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008896853607336734, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22104653801490837`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.877703496231666`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15022112292948303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9190159886132998, 0.3942202590850948, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.8898389876045965`, 0.310250823629456, 0.}, 
      Optica`Optica`RayEnd :> {7.923392072908012, 0.37453662136558347`, 0.}, 
      RotationMatrix :> {{0.4627033282632306, 0.8865131865991214, 
       0.}, {-0.8865131865991214, 0.4627033282632306, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12386341584104354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07251533164751142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.565013774421109`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40973660908384657`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4627033282632306, 0.8865131865991214, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.923392072908012, 0.37453662136558347`, 0.}, 
      Optica`Optica`RayEnd :> {8.080195487154919, 0.6661707831798577, 0.}, 
      RotationMatrix :> {{0.4735603887564788, 0.8807613514459023, 
       0.}, {-0.8807613514459023, 0.4735603887564788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12354873668994602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3311159842964417, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.055065431179843`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07335736124784917, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4735603887564788, 0.8807613514459023, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.125657458194816, -0.41832732762270464`, 0.},
       Optica`Optica`RayEnd :> {6.080637716367729, -0.43385538527627593`, 0.},
       RotationMatrix :> {{-0.9453470365188422, -0.3260659144176867, 0.}, {
       0.3260659144176867, -0.9453470365188422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015961321692052968`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04762244983902242, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.627949976246173`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30477694808892464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9453470365188422, -0.3260659144176867, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.080637716367729, -0.43385538527627593`, 0.},
       Optica`Optica`RayEnd :> {5.825637039936708, -0.5234217821511212, 0.}, 
      RotationMatrix :> {{-0.943493038739633, -0.33139234428370995`, 0.}, {
       0.33139234428370995`, -0.943493038739633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01592172875302877, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.270272981315966, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.027953988593802`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14003068573575975`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.943493038739633, -0.33139234428370995`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.370259476906691, 0.6360526074102332, 0.}, 
      Optica`Optica`RayEnd :> {5.342481872083101, 0.6441757256033335, 0.}, 
      RotationMatrix :> {{-0.9598017725172795, 0.2806787442480967, 
       0.}, {-0.2806787442480967, -0.9598017725172795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009594863058565406, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028940980959784226`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.868207991457457`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10364977992379855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9598017725172795, 0.2806787442480967, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.342481872083101, 0.6441757256033335, 0.}, 
      Optica`Optica`RayEnd :> {5.091004786913011, 0.7337025154327036, 0.}, 
      RotationMatrix :> {{-0.9420813313156502, 0.33538450349789867`, 
       0.}, {-0.33538450349789867`, -0.9420813313156502, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009552742827458662, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2669377651491017, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.263275883878126`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0768724471146779, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9420813313156502, 0.33538450349789867`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.840886796903556, -0.5681950703666385, 0.}, 
      Optica`Optica`RayEnd :> {6.866761886098688, -0.694019397587685, 0.}, 
      RotationMatrix :> {{0.20142947378364678`, -0.9795030204604998, 0.}, {
       0.9795030204604998, 0.20142947378364678`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2841535494198482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12845731416110578`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.092386537853585`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1230844252937226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.20142947378364678`, -0.9795030204604998, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.866761886098688, -0.694019397587685, 0.}, 
      Optica`Optica`RayEnd :> {6.881191250877583, -0.8861829153964238, 0.}, 
      RotationMatrix :> {{0.07487819336356952, -0.9971926875777855, 0.}, {
       0.9971926875777855, 0.07487819336356952, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27922743402544303`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19270449954412555`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.37758919717889, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.194074445425734, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.07487819336356952, -0.9971926875777855, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.149448457539012, 0.10347078033821677`, 0.}, 
      Optica`Optica`RayEnd :> {7.238157393487466, -0.13316628934978925`, 0.}, 
      RotationMatrix :> {{0.35101948620910406`, -0.9363681542542419, 0.}, {
       0.9363681542542419, 0.35101948620910406`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2891501326551351, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2527179812906734, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.231164717785962`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2634139652097113, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35101948620910406`, -0.9363681542542419, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.238157393487466, -0.13316628934978925`, 0.},
       Optica`Optica`RayEnd :> {7.331543225782122, -0.40876767013290327`, 0.},
       RotationMatrix :> {{0.32092102678487916`, -0.9471059574130754, 0.}, {
       0.9471059574130754, 0.32092102678487916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2882825865942385, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29099318679811853`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.661834634247178`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04918996529189873, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32092102678487916`, -0.9471059574130754, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.390408105692144, 0.7150344162751484, 0.}, 
      Optica`Optica`RayEnd :> {7.419974370971576, 0.6397102217070847, 0.}, 
      RotationMatrix :> {{0.3653806175742206, -0.9308582084834834, 0.}, {
       0.9308582084834834, 0.3653806175742206, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.34313034499645995`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08091908507825142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.037855835560466`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34691769049453625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3653806175742206, -0.9308582084834834, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.419974370971576, 0.6397102217070847, 0.}, 
      Optica`Optica`RayEnd :> {7.548191576253571, 0.30072193789939994`, 0.}, 
      RotationMatrix :> {{0.35377471567299984`, -0.9353306637497176, 0.}, {
       0.9353306637497176, 0.35377471567299984`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.34225796082991805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3624261418402439, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.574246525484027`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021790061741466804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35377471567299984`, -0.9353306637497176, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3775247299827535`, 1.391018043860573, 0.}, 
      Optica`Optica`RayEnd :> {7.341954503215509, 1.3691737677150844`, 0.}, 
      RotationMatrix :> {{-0.8521401507293794, -0.5233136378071086, 0.}, {
       0.5233136378071086, -0.8521401507293794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20473374778223055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0417422260138772, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.860896150152962`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21373869997074604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8521401507293794, -0.5233136378071086, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.341954503215509, 1.3691737677150844`, 0.}, 
      Optica`Optica`RayEnd :> {7.055504511607546, 1.1912081890792554`, 0.}, 
      RotationMatrix :> {{-0.8494155018550746, -0.5277246490436948, 0.}, {
       0.5277246490436948, -0.8494155018550746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20422639908246404`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33723188590551084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.359999341293118`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24249082298861957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8494155018550746, -0.5277246490436948, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.543884862887944, 1.6644691373106297`, 0.}, 
      Optica`Optica`RayEnd :> {7.590368247538926, 1.7369085399029403`, 0.}, 
      RotationMatrix :> {{0.5400602485764446, 0.8416263588478844, 
       0.}, {-0.8416263588478844, 0.5400602485764446, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      73.79176807230742, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0860707389101667, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.39401472952739, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.003812841491004166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5400602485764446, 0.8416263588478844, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.590368247538926, 1.7369085399029403`, 0.}, 
      Optica`Optica`RayEnd :> {7.738157029364659, 1.911472297130765, 0.}, 
      RotationMatrix :> {{0.6461485639682196, 0.7632116569352217, 
       0.}, {-0.7632116569352217, 0.6461485639682196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      72.40537642210035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22872260354199592`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.732524182769543`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3150627694712295, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6461485639682196, 0.7632116569352217, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.738157029364659, 1.911472297130765, 0.}, 
      Optica`Optica`RayEnd :> {7.932904742021405, 1.7915249845889867`, 0.}, 
      RotationMatrix :> {{0.8514580965802399, -0.5244226442173853, 0.}, {
       0.5244226442173853, 0.8514580965802399, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.3603442758456952`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2287226035419961, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.071033636011698`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.336623410496395, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8514580965802399, -0.5244226442173853, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.932904742021405, 1.7915249845889867`, 0.}, 
      Optica`Optica`RayEnd :> {7.843510263820795, 1.5809955172019488`, 0.}, 
      RotationMatrix :> {{-0.390842342716668, -0.9204576378844092, 0.}, {
       0.9204576378844092, -0.390842342716668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02555799914688803, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22872260354199594`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.409543089253852`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.032228636559607275`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.390842342716668, -0.9204576378844092, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.512885661753796, 1.345893802643445, 0.}, 
      Optica`Optica`RayEnd :> {7.496842644551443, 1.2139061125156703`, 0.}, 
      RotationMatrix :> {{-0.12066127301569289`, -0.9926937378639151, 0.}, {
       0.9926937378639151, -0.12066127301569289`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20360550783162337`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13295912434361357`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.930563538101607`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3153071259485915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12066127301569289`, -0.9926937378639151, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.496842644551443, 1.2139061125156703`, 0.}, 
      Optica`Optica`RayEnd :> {7.464985043809726, 0.8755865366445774, 0.}, 
      RotationMatrix :> {{-0.09374950869195185, -0.9955958163933879, 0.}, {
       0.9955958163933879, -0.09374950869195185, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20302652711350602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3398161887588858, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.433491497464757`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3822028922825804, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.09374950869195185, -0.9955958163933879, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.57982954868064, 1.3401081333321252`, 0.}, 
      Optica`Optica`RayEnd :> {6.359754642466834, 1.3107156326557965`, 0.}, 
      RotationMatrix :> {{-0.991198859075352, -0.13238134977299332`, 0.}, {
       0.13238134977299332`, -0.991198859075352, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3405463895680606, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22202901486297502`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.157625778777994`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3551872908742769, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.991198859075352, -0.13238134977299332`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.359754642466834, 1.3107156326557965`, 0.}, 
      Optica`Optica`RayEnd :> {6.051399004163451, 1.2658168799102762`, 0.}, 
      RotationMatrix :> {{-0.9895649330016388, -0.1440876239427284, 0.}, {
       0.1440876239427284, -0.9895649330016388, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3396831595089225, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31160728115945924`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.618804554893995`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.016004541490973054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9895649330016388, -0.1440876239427284, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.883323261180942, 1.0085602719018325`, 0.}, 
      Optica`Optica`RayEnd :> {5.67637167252377, 0.978887154996747, 0.}, 
      RotationMatrix :> {{-0.9898766371963097, -0.14193041651782967`, 0.}, {
       0.14193041651782967`, -0.9898766371963097, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2914970015936533, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20906806048411672`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.347044410427246`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42481335503115414`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9898766371963097, -0.14193041651782967`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.67637167252377, 0.978887154996747, 0.}, 
      Optica`Optica`RayEnd :> {5.348678083172981, 0.9374527928655113, 0.}, 
      RotationMatrix :> {{-0.992100753197418, -0.12544359491466678`, 0.}, {
       0.12544359491466678`, -0.992100753197418, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2907377575713962, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3303027321516211, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.835892454011645`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13984459587215015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.992100753197418, -0.12544359491466678`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.858833762293857, 1.081384031628743, 0.}, 
      Optica`Optica`RayEnd :> {4.6671547952838885`, 1.099269044092898, 0.}, 
      RotationMatrix :> {{-0.9956751103125859, 0.0929035774554402, 
       0.}, {-0.0929035774554402, -0.9956751103125859, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2947920179144425, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1925115582630084, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.977105216279762`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2515807751427352, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9956751103125859, 0.0929035774554402, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6671547952838885`, 1.099269044092898, 0.}, 
      Optica`Optica`RayEnd :> {4.363292513720586, 1.1077631715094527`, 0.}, 
      RotationMatrix :> {{-0.9996095193434801, 0.027942956856708986`, 
       0.}, {-0.027942956856708986`, -0.9996095193434801, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2933092808604072, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3039809802560426, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.426997067058704`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2722686937850284, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9996095193434801, 0.027942956856708986`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.468322005052908, -0.690413361520776, 0.}, 
      Optica`Optica`RayEnd :> {6.4922024195277235`, -0.830163736610522, 0.}, 
      RotationMatrix :> {{0.16843760653728979`, -0.9857123174151716, 0.}, {
       0.9857123174151716, 0.16843760653728979`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009331740870556703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14177602594660943`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.999685987189553`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.305914784067169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.16843760653728979`, -0.9857123174151716, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.4922024195277235`, -0.830163736610522, 0.}, 
      Optica`Optica`RayEnd :> {6.544058705200856, -1.1397096353662313`, 0.}, 
      RotationMatrix :> {{0.16522137546057344`, -0.9862565067419911, 0.}, {
       0.9862565067419911, 0.16522137546057344`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009308691707241247, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3138594236283073, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.464197934159447`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16032071954724936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.16522137546057344`, -0.9862565067419911, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.902671251455068, 2.2927415826140214`, 0.}, 
      Optica`Optica`RayEnd :> {6.918722068695445, 2.3383097548097824`, 0.}, 
      RotationMatrix :> {{0.3322298308658552, 0.9431984624048346, 
       0.}, {-0.9431984624048346, 0.3322298308658552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1834808706876179, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04831239024666962, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.918313892769195`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4003867237326231, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3322298308658552, 0.9431984624048346, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.918722068695445, 2.3383097548097824`, 0.}, 
      Optica`Optica`RayEnd :> {7.023459793219201, 2.629803328498619, 0.}, 
      RotationMatrix :> {{0.33814789247765026`, 0.9410929830855835, 
       0.}, {-0.9410929830855835, 0.33814789247765026`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18302503380982799`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30973939762371777`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.376728201252297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11821454050873383`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33814789247765026`, 0.9410929830855835, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.287150018382918, 1.8816042394023436`, 0.}, 
      Optica`Optica`RayEnd :> {6.356777134173283, 2.0706436486224016`, 0.}, 
      RotationMatrix :> {{0.3456223921478206, 0.9383736793229109, 
       0.}, {-0.9383736793229109, 0.3456223921478206, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0951794286245165, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2014542962846744, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.492109113914577`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.048226539856705775`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3456223921478206, 0.9383736793229109, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.356777134173283, 2.0706436486224016`, 0.}, 
      Optica`Optica`RayEnd :> {6.42157587195393, 2.311129214326098, 0.}, 
      RotationMatrix :> {{0.2601704758698748, 0.9655626978532477, 
       0.}, {-0.9655626978532477, 0.2601704758698748, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0944078045663355, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24906261005978383`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.860721776803057`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2083418853260214, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2601704758698748, 0.9655626978532477, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.434632846005179, 2.0883302110018165`, 0.}, 
      Optica`Optica`RayEnd :> {5.377379804505068, 2.129866926644981, 0.}, 
      RotationMatrix :> {{-0.8094205353186699, 0.5872294245049692, 
       0.}, {-0.5872294245049692, -0.8094205353186699, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.013486573740879, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07073336912260426, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.090637694138042`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19913733719252197`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8094205353186699, 0.5872294245049692, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.377379804505068, 2.129866926644981, 0.}, 
      Optica`Optica`RayEnd :> {5.105130303168906, 2.32777283886906, 0.}, 
      RotationMatrix :> {{-0.8088685216600074, 0.5879895531959334, 
       0.}, {-0.5879895531959334, -0.8088685216600074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.006058013087019, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3365806605719258, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.588777071784492`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29034653810302113`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8088685216600074, 0.5879895531959334, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.216418216343868, 1.0764549847096392`, 0.}, 
      Optica`Optica`RayEnd :> {5.161659475834462, 1.054922119649615, 0.}, 
      RotationMatrix :> {{-0.930632857107919, -0.3659542119871698, 0.}, {
       0.3659542119871698, -0.930632857107919, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08460589303001663, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.058840325796766894`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.48610481992293, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.328609191229051, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.930632857107919, -0.3659542119871698, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.161659475834462, 1.054922119649615, 0.}, 
      Optica`Optica`RayEnd :> {4.851961525503718, 0.934645522777102, 0.}, 
      RotationMatrix :> {{-0.9321687772798607, -0.3620239918355801, 0.}, {
       0.3620239918355801, -0.9321687772798607, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08439661581420521, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.332233773410075, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.977810804569842`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19967196777475835`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9321687772798607, -0.3620239918355801, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.589348707423781, 1.1826893079768626`, 0.}, 
      Optica`Optica`RayEnd :> {5.518103669062487, 1.1512149591504777`, 0.}, 
      RotationMatrix :> {{-0.9147151604987089, -0.40409921449295166`, 0.}, {
       0.40409921449295166`, -0.9147151604987089, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15898512102382034`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07788767633680707, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.609452835421878`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22667185881366508`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9147151604987089, -0.40409921449295166`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.518103669062487, 1.1512149591504777`, 0.}, 
      Optica`Optica`RayEnd :> {5.461139648466303, 1.1443863509174352`, 0.}, 
      RotationMatrix :> {{-0.9928914176042102, -0.11902366507506512`, 0.}, {
       0.11902366507506512`, -0.9928914176042102, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12103378312832232`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057371853141438625`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.686331118631406`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3639647780656256, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9928914176042102, -0.11902366507506512`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.461139648466303, 1.1443863509174352`, 0.}, 
      Optica`Optica`RayEnd :> {5.409836078855042, 1.1187061391187512`, 0.}, 
      RotationMatrix :> {{-0.8942289084646228, -0.4476099409822895, 0.}, {
       0.4476099409822895, -0.8942289084646228, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028891974108604036`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057371853141438924`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.763209401840934`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40209558569383597`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8942289084646228, -0.4476099409822895, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.934336026432902, 0.3840163419848044, 0.}, 
      Optica`Optica`RayEnd :> {5.904292357145209, 0.1453567907485327, 0.}, 
      RotationMatrix :> {{-0.12489929648669358`, -0.9921694239075947, 0.}, {
       0.9921694239075947, -0.12489929648669358`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008658465574212347, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24054314261804854`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.537302600222638`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36058193007362177`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12489929648669358`, -0.9921694239075947, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.904292357145209, 0.1453567907485327, 0.}, 
      Optica`Optica`RayEnd :> {5.900457870164396, -0.1016796735186661, 0.}, 
      RotationMatrix :> {{-0.01552007778502694, -0.9998795563394353, 0.}, {
       0.9998795563394353, -0.01552007778502694, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008553618377615537, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24706622182735746`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.902960608527128`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34965775697463497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.01552007778502694, -0.9998795563394353, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.269243314924368, 0.10997104284251004`, 0.}, 
      Optica`Optica`RayEnd :> {7.3793113611938725`, -0.008201718506410174, 
       0.}, RotationMatrix :> {{0.6815682112711706, -0.7317545854892994, 
       0.}, {0.7317545854892994, 0.6815682112711706, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009356654266526165, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16149234141102387`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.360721967495898`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1346214152270417, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6815682112711706, -0.7317545854892994, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3793113611938725`, -0.008201718506410174, 
       0.}, Optica`Optica`RayEnd :> {7.5649167357676115`, -0.1860555186724132,
        0.}, RotationMatrix :> {{0.722023216690794, -0.6918688275673924, 
       0.}, {0.6918688275673924, 0.722023216690794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009316071866090764, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25706288978408826`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.741175044376348`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10342002454448615`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.722023216690794, -0.6918688275673924, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.874911054466808, 0.8967438186105634, 0.}, 
      Optica`Optica`RayEnd :> {4.67989996195875, 0.9497794729162449, 0.}, 
      RotationMatrix :> {{-0.964950969671903, 0.26243023097435564`, 
       0.}, {-0.26243023097435564`, -0.964950969671903, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16068274892785345`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2020943018217443, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.00277623757153, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32109725590572646`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.964950969671903, 0.26243023097435564`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.67989996195875, 0.9497794729162449, 0.}, 
      Optica`Optica`RayEnd :> {4.338030659768891, 1.0456952774415846`, 0.}, 
      RotationMatrix :> {{-0.9628231966015137, 0.2701323603088719, 
       0.}, {-0.2701323603088719, -0.9628231966015137, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16028158611906965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3550696570217231, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.528279329963679`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09797256259860301, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9628231966015137, 0.2701323603088719, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9514534114328006`, -1.1585364994661662`, 
       0.}, Optica`Optica`RayEnd :> {3.88193336815691, -1.17997311673636, 0.},
       RotationMatrix :> {{-0.9556017458036147, -0.2946613368209053, 0.}, {
       0.2946613368209053, -0.9556017458036147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19317516410929736`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07275001702453757, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.913279007887688`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07688209814455385, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9556017458036147, -0.2946613368209053, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.88193336815691, -1.17997311673636, 0.}, 
      Optica`Optica`RayEnd :> {3.6682505014656734`, -1.260811247870144, 0.}, 
      RotationMatrix :> {{-0.9353077634148139, -0.3538352550212848, 0.}, {
       0.3538352550212848, -0.9353077634148139, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1922473465867297, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22846262487021288`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.251403692695604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08433686445886855, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9353077634148139, -0.3538352550212848, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.0960916602283275`, 1.2544517791728071`, 0.},
       Optica`Optica`RayEnd :> {3.959387763546078, 1.3564299397503847`, 0.}, 
      RotationMatrix :> {{-0.8015445978580942, 0.5979349944973161, 
       0.}, {-0.5979349944973161, -0.8015445978580942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.058365449494218354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17055058077560867`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.21655378168464, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39700607306614477`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8015445978580942, 0.5979349944973161, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.959387763546078, 1.3564299397503847`, 0.}, 
      Optica`Optica`RayEnd :> {3.8700807173829546`, 1.4673964527622854`, 0.}, 
      RotationMatrix :> {{-0.6269776034599785, 0.7790372807251149, 
       0.}, {-0.7790372807251149, -0.6269776034599785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.050483767032209075`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14244056832378382`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.42736582280384, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0886885599666829, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.6269776034599785, 0.7790372807251149, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.885969195992962, 0.6114723626851394, 0.}, 
      Optica`Optica`RayEnd :> {7.2096543937444535`, 0.6485669109904696, 0.}, 
      RotationMatrix :> {{0.993497322128942, 0.11385548261994437`, 
       0.}, {-0.11385548261994437`, 0.993497322128942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09039430626384935, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32580379487875627`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.477831863928495`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3709921986806899, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.993497322128942, 0.11385548261994437`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.2096543937444535`, 0.6485669109904696, 0.}, 
      Optica`Optica`RayEnd :> {7.379052243606461, 0.6990117450102403, 0.}, 
      RotationMatrix :> {{0.9584075066608065, 0.28540331318366874`, 
       0.}, {-0.28540331318366874`, 0.9584075066608065, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08664499971912516, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17674929368219172`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.73942081857814, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17972683120558744`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9584075066608065, 0.28540331318366874`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0774646795014835`, 1.2986243324192273`, 0.},
       Optica`Optica`RayEnd :> {5.01246476383433, 1.3282117434903686`, 0.}, 
      RotationMatrix :> {{-0.9101448317519575, 0.41429021860912885`, 
       0.}, {-0.41429021860912885`, -0.9101448317519575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05453624201350348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07141711230951438, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.306339855753608`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22184313669905908`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9101448317519575, 0.41429021860912885`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.01246476383433, 1.3282117434903686`, 0.}, 
      Optica`Optica`RayEnd :> {4.842566133514247, 1.440068636143774, 0.}, 
      RotationMatrix :> {{-0.8352331187821285, 0.549896024071349, 
       0.}, {-0.549896024071349, -0.8352331187821285, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.052956282245871136`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20341462341413796`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.607393498406532`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16788655614302495`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8352331187821285, 0.549896024071349, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.096699440575585, 0.8041596610668059, 0.}, 
      Optica`Optica`RayEnd :> {4.895066441242999, 0.7657285500947084, 0.}, 
      RotationMatrix :> {{-0.9823163290099132, -0.18722881658678187`, 0.}, {
       0.18722881658678187`, -0.9823163290099132, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013029632489310678`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20526279913906506`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.348061167765808`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3377331067527859, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9823163290099132, -0.18722881658678187`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.895066441242999, 0.7657285500947084, 0.}, 
      Optica`Optica`RayEnd :> {4.588794290327433, 0.7038109943929166, 0.}, 
      RotationMatrix :> {{-0.9801704337530773, -0.1981563039529729, 0.}, {
       0.1981563039529729, -0.9801704337530773, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012996707814092888`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3124682609970676, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.810514194041469`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0466084092957007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9801704337530773, -0.1981563039529729, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.165712099764965, -0.3395329293425942, 0.}, 
      Optica`Optica`RayEnd :> {5.134211892678214, -0.4363437224036853, 0.}, 
      RotationMatrix :> {{-0.3094120967425376, -0.9509280490075919, 0.}, {
       0.9509280490075919, -0.3094120967425376, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00817590703866301, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10180664369099719`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.256124501265502`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23932452249613007`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3094120967425376, -0.9509280490075919, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.134211892678214, -0.4363437224036853, 0.}, 
      Optica`Optica`RayEnd :> {5.0400177056328745`, -0.6635405089458228, 0.}, 
      RotationMatrix :> {{-0.38298255360788336`, -0.923755575697372, 0.}, {
       0.923755575697372, -0.38298255360788336`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008122867838280187, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24594902863846785`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.620129063650435`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14150469786015826`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.38298255360788336`, -0.923755575697372, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9089651371026575`, 0.23662464116783447`, 
       0.}, Optica`Optica`RayEnd :> {6.947263191339536, 0.11802716847812038`, 
       0.}, RotationMatrix :> {{0.3072993205886305, -0.9516129084694918, 
       0.}, {0.9516129084694918, 0.3072993205886305, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0093991170136647, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12462785197024911`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.748096621721736`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31841399912839746`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3072993205886305, -0.9516129084694918, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.947263191339536, 0.11802716847812038`, 0.}, 
      Optica`Optica`RayEnd :> {7.021149725198444, -0.07154571447836382, 0.}, 
      RotationMatrix :> {{0.36314523141482674`, -0.9317325479453163, 0.}, {
       0.9317325479453163, 0.36314523141482674`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009356549167343929, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20346276769501692`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.049221517910361`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3068487622119464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36314523141482674`, -0.9317325479453163, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.871677664455433, 2.085412051030004, 0.}, 
      Optica`Optica`RayEnd :> {5.821416870401075, 2.182867931844339, 0.}, 
      RotationMatrix :> {{-0.4583619345440708, 0.8887656254384593, 
       0.}, {-0.8887656254384593, -0.4583619345440708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19450054159088923`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10965307165908508`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.900732770458609`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3741616564982686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4583619345440708, 0.8887656254384593, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.821416870401075, 2.182867931844339, 0.}, 
      Optica`Optica`RayEnd :> {5.728774910946679, 2.3223324043258624`, 0.}, 
      RotationMatrix :> {{-0.5533169026795729, 0.8329708309473285, 
       0.}, {-0.8329708309473285, -0.5533169026795729, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19212239195866207`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1674301995940386, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.148529465857786`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1606733280850331, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5533169026795729, 0.8329708309473285, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.320906309499774, 2.0591489993432495`, 0.}, 
      Optica`Optica`RayEnd :> {6.3633446608630795`, 2.0310033450348413`, 0.}, 
      RotationMatrix :> {{0.8333764188916647, -0.5527058389734122, 0.}, {
       0.5527058389734122, 0.8333764188916647, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03403025478793858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05092338876080178, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.754896914973092`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12476018724181169`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8333764188916647, -0.5527058389734122, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.3633446608630795`, 2.0310033450348413`, 0.},
       Optica`Optica`RayEnd :> {6.6258440355301405`, 1.8689699323790148`, 0.},
       RotationMatrix :> {{0.8509408023139001, -0.5252616024014841, 0.}, {
       0.5252616024014841, 0.8509408023139001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03392739336227029, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3084813584602668, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.211449325494286`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09606761870595609, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8509408023139001, -0.5252616024014841, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.440837379378749, 2.2750571618804605`, 0.}, 
      Optica`Optica`RayEnd :> {6.472040952293647, 2.3458184217531763`, 0.}, 
      RotationMatrix :> {{0.4034818471751288, 0.9149876496435048, 
       0.}, {-0.9149876496435048, 0.4034818471751288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9641121447154126`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0773357540949168, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.155821909260755`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23636461687306098`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4034818471751288, 0.9149876496435048, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.472040952293647, 2.3458184217531763`, 0.}, 
      Optica`Optica`RayEnd :> {6.583810886957185, 2.633564846050262, 0.}, 
      RotationMatrix :> {{0.3620763359734007, 0.9321484468302653, 
       0.}, {-0.9321484468302653, 0.3620763359734007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.949966292510657, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30869163090445084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.612685522999342`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12302529011468033`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3620763359734007, 0.9321484468302653, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.583810886957185, 2.633564846050262, 0.}, 
      Optica`Optica`RayEnd :> {6.299114145669607, 2.5142405463846695`, 0.}, 
      RotationMatrix :> {{-0.9222690633154838, -0.38654854139057243`, 0.}, {
       0.38654854139057243`, -0.9222690633154838, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014095373023719666`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3086916309044505, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.06954913673793, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.002410754160916017, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9222690633154838, -0.38654854139057243`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.2077278035136985`, 2.356664280519256, 0.}, 
      Optica`Optica`RayEnd :> {6.164941740114911, 2.3673631501433543`, 0.}, 
      RotationMatrix :> {{-0.9701299413364021, 0.24258585474554797`, 
       0.}, {-0.24258585474554797`, -0.9701299413364021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03345822907371311, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.044103435607654055`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.47682302722777, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11879992851789876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9701299413364021, 0.24258585474554797`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.164941740114911, 2.3673631501433543`, 0.}, 
      Optica`Optica`RayEnd :> {5.8856226064772645`, 2.454866553037327, 0.}, 
      RotationMatrix :> {{-0.9542694808522411, 0.2989477511438968, 
       0.}, {-0.2989477511438968, -0.9542694808522411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03330863362328728, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2927046701610862, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.910025939066177`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09939531833986566, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9542694808522411, 0.2989477511438968, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.897227864791424, 1.7236485654343994`, 0.}, 
      Optica`Optica`RayEnd :> {7.0821012120622076`, 1.6664828386215798`, 0.}, 
      RotationMatrix :> {{0.9553690195022145, -0.2954150242885018, 0.}, {
       0.2954150242885018, 0.9553690195022145, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1779267659011658, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19350988308905961`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.65747085606729, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15430224114937713`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9553690195022145, -0.2954150242885018, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.0821012120622076`, 1.6664828386215795`, 0.},
       Optica`Optica`RayEnd :> {7.354603703684484, 1.6013214427552687`, 0.}, 
      RotationMatrix :> {{0.9725807027695446, -0.23256563933715085`, 0.}, {
       0.23256563933715085`, 0.9725807027695446, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17703044897375564`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2801849664981954, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.072144606484619`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1304924617591747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9725807027695446, -0.23256563933715085`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.372007422895698, 0.8886497691912926, 0.}, 
      Optica`Optica`RayEnd :> {5.350843936590856, 0.8617804958970844, 0.}, 
      RotationMatrix :> {{-0.6187595802589355, -0.7855804108032383, 0.}, {
       0.7855804108032383, -0.6187595802589355, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012792561618205705`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03420308465524864, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.642880905644772`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14088169828340977`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6187595802589355, -0.7855804108032383, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.350843936590856, 0.8617804958970844, 0.}, 
      Optica`Optica`RayEnd :> {5.161374580802137, 0.6278061110068232, 0.}, 
      RotationMatrix :> {{-0.6293216643366328, -0.7771449303679262, 0.}, {
       0.7771449303679262, -0.6293216643366328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012759855650103761`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3010691773791664, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.088463288165938`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4257046735607984, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6293216643366328, -0.7771449303679262, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3821519417883765`, 0.8912266074744308, 0.}, 
      Optica`Optica`RayEnd :> {7.622852413903404, 0.7885214531920586, 0.}, 
      RotationMatrix :> {{0.9197694973635048, -0.3924590064193769, 0.}, {
       0.3924590064193769, 0.9197694973635048, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08185817511685006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2616965150562062, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.664989312569103`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09057078283433105, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9197694973635048, -0.3924590064193769, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.622852413903404, 0.7885214531920586, 0.}, 
      Optica`Optica`RayEnd :> {7.929742957745927, 0.6652030754613594, 0.}, 
      RotationMatrix :> {{0.927889430523467, -0.37285547430986565`, 0.}, {
       0.37285547430986565`, 0.927889430523467, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08163762128954866, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3307404241789785, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.15448514035399, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2242898854194647, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.927889430523467, -0.37285547430986565`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.156171182713343, 1.1450378863667876`, 0.}, 
      Optica`Optica`RayEnd :> {4.153496893426275, 1.1455877333499838`, 0.}, 
      RotationMatrix :> {{-0.9795106854531603, 0.20139219717525927`, 
       0.}, {-0.20139219717525927`, -0.9795106854531603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09119287473769258, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0027302298247324397`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.409292522631697`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16267424242793946`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9795106854531603, 0.20139219717525927`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.153496893426274, 1.1455877333499838`, 0.}, 
      Optica`Optica`RayEnd :> {3.934429269750753, 1.1647759852781359`, 0.}, 
      RotationMatrix :> {{-0.9961858812182052, 0.08725646143126976, 
       0.}, {-0.08725646143126976, -0.9961858812182052, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08995559488743221, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21990637270187996`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.734753954230479`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38870967193291345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9961858812182052, 0.08725646143126976, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.278409306365115, 1.9170346464985808`, 0.}, 
      Optica`Optica`RayEnd :> {4.201877408545196, 2.010677723111943, 0.}, 
      RotationMatrix :> {{-0.6328158740977575, 0.7743023114326155, 
       0.}, {-0.7743023114326155, -0.6328158740977575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2730890145034687, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12093865048666005`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.484679178974478`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36847250650310254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6328158740977575, 0.7743023114326155, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.201877408545196, 2.010677723111943, 0.}, 
      Optica`Optica`RayEnd :> {4.055325171769849, 2.140045002997775, 0.}, 
      RotationMatrix :> {{-0.7496944920831122, 0.6617840799990918, 
       0.}, {-0.6617840799990918, -0.7496944920831122, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2640567711830703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19548261101416897`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.773993443275447`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20813773997354443`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7496944920831122, 0.6617840799990918, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.055325171769849, 2.140045002997775, 0.}, 
      Optica`Optica`RayEnd :> {3.8871266030435763`, 2.040432289515257, 0.}, 
      RotationMatrix :> {{-0.8604272669249398, -0.5095732708179249, 0.}, {
       0.5095732708179249, -0.8604272669249398, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008733507688182688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19548261101416872`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.063307707576417`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19800392428989697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8604272669249398, -0.5095732708179249, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.056035109608411, -0.7627206856098533, 0.}, 
      Optica`Optica`RayEnd :> {2.9121687742877462`, -0.8438138098897752, 0.}, 
      RotationMatrix :> {{-0.8711397086299197, -0.49103524114688396`, 0.}, {
       0.49103524114688396`, -0.8711397086299197, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014730378853710223`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16514725926904378`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.538248497311768`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24597539727870438`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8711397086299197, -0.49103524114688396`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9121687742877462`, -0.8438138098897752, 0.},
       Optica`Optica`RayEnd :> {2.7442304120272185`, -0.9084906570121896, 0.},
       RotationMatrix :> {{-0.9331869478602629, -0.3593913192374669, 0.}, {
       0.3593913192374669, -0.9331869478602629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014371721753125401`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1799621851179975, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.804592531286405`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36771310959837716`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9331869478602629, -0.3593913192374669, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.250973596039403, -2.385515828997722, 0.}, 
      Optica`Optica`RayEnd :> {4.141155509164145, -2.4725244263466686`, 0.}, 
      RotationMatrix :> {{-0.7838051307544255, -0.6210068574525064, 0.}, {
       0.6210068574525064, -0.7838051307544255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012448934618477603`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14010891555348262`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.922366360779645`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4146701473950497, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7838051307544255, -0.6210068574525064, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.141155509164145, -2.4725244263466686`, 0.}, 
      Optica`Optica`RayEnd :> {3.9103644313012382`, -2.63264420570771, 0.}, 
      RotationMatrix :> {{-0.8216230753945222, -0.5700311587792786, 0.}, {
       0.5700311587792786, -0.8216230753945222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012388138816846063`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28089653853999463`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.338093237818837`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.406876123041199, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8216230753945222, -0.5700311587792786, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.334963802773455, -2.54581248256604, 0.}, 
      Optica`Optica`RayEnd :> {5.330985085163504, -2.576600492582407, 0.}, 
      RotationMatrix :> {{-0.12816369849168885`, -0.9917530269119077, 0.}, {
       0.9917530269119077, -0.12816369849168885`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008932213596201732, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.031044029290470954`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.600941408846444`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02361974803757773, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.12816369849168885`, -0.9917530269119077, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.330985085163504, -2.576600492582407, 0.}, 
      Optica`Optica`RayEnd :> {5.275954050371112, -2.8917611585853704`, 0.}, 
      RotationMatrix :> {{-0.172010068531061, -0.9850951915038157, 0.}, {
       0.9850951915038157, -0.172010068531061, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008900564346459292, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3199291486966342, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.074436548917463`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1470350690113048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.172010068531061, -0.9850951915038157, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.290875589312144, -2.815415160633884, 0.}, 
      Optica`Optica`RayEnd :> {6.329760945790908, -2.9810678518678104`, 0.}, 
      RotationMatrix :> {{0.22852839080867687`, -0.9735372486938526, 0.}, {
       0.9735372486938526, 0.22852839080867687`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0184893733476573, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17015547320472255`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.381439449217245`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15993778307378792`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.22852839080867687`, -0.9735372486938526, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.329760945790908, -2.9810678518678104`, 0.}, 
      Optica`Optica`RayEnd :> {6.402864922916759, -3.1706687047615048`, 0.}, 
      RotationMatrix :> {{0.35975305977712224`, -0.9330475529044583, 0.}, {
       0.9330475529044583, 0.35975305977712224`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018103943472246403`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20320599127396136`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.682184316302708`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4293661288225574, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.35975305977712224`, -0.9330475529044583, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.709709089406296, -2.50852625996953, 0.}, 
      Optica`Optica`RayEnd :> {6.863121642356406, -2.5485397701708075`, 0.}, 
      RotationMatrix :> {{0.9676282953832779, -0.2523796385876872, 0.}, {
       0.2523796385876872, 0.9676282953832779, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09380790510057467, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1585449223447353, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.512498457667364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3190913811098373, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9676282953832779, -0.2523796385876872, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.863121642356406, -2.5485397701708075`, 0.}, 
      Optica`Optica`RayEnd :> {7.065516021771263, -2.5757373891090496`, 0.}, 
      RotationMatrix :> {{0.9910915693396486, -0.1331822104632304, 0.}, {
       0.1331822104632304, 0.9910915693396486, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.092370580340839, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2042136021293262, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.814734588818768`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.043895313678140584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9910915693396486, -0.1331822104632304, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.529897953148777, -1.3640197673514542`, 0.}, 
      Optica`Optica`RayEnd :> {7.627798623920488, -1.3007128758044786`, 0.}, 
      RotationMatrix :> {{0.8397289580950468, 0.5430057798372013, 
       0.}, {-0.5430057798372013, 0.8397289580950468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013460961609948455`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11658603627746987`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.04278349929982, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16986962536921588`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8397289580950468, 0.5430057798372013, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.627798623920488, -1.3007128758044786`, 0.}, 
      Optica`Optica`RayEnd :> {7.907913549349928, -1.128131966537967, 0.}, 
      RotationMatrix :> {{0.8513834876466261, 0.5245437607699355, 
       0.}, {-0.5245437607699355, 0.8513834876466261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013424507334127814`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3290114613377421, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.529720462079677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1427264254675252, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8513834876466261, 0.5245437607699355, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.41383491331418, -1.3315744125057838`, 0.}, 
      Optica`Optica`RayEnd :> {7.641643426389006, -1.3299004596253732`, 0.}, 
      RotationMatrix :> {{0.999973004027504, 0.0073478715427765275`, 
       0.}, {-0.0073478715427765275`, 0.999973004027504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011018945715766977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22781466315320673`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.680527554270574`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2567152773757342, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.999973004027504, 0.0073478715427765275`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.641643426389006, -1.3299004596253732`, 0.}, 
      Optica`Optica`RayEnd :> {7.9396332096186235`, -1.3113566863266601`, 0.},
       RotationMatrix :> {{0.9980693464507662, 0.062109416961843335`, 
       0.}, {-0.062109416961843335`, 0.9980693464507662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010972780041362174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2985662111448456, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.122405546764945`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2955083537278272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9980693464507662, 0.062109416961843335`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.866810299806632, -1.442451087010559, 0.}, 
      Optica`Optica`RayEnd :> {2.419159283002482, -1.7220162844483655`, 0.}, 
      RotationMatrix :> {{-0.8481827774550288, -0.5297036681283912, 0.}, {
       0.5297036681283912, -0.8481827774550288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1711955592926065, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5277765933273558, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.96786516731079, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4177318517299221, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8481827774550288, -0.5297036681283912, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.419159283002482, -1.7220162844483655`, 0.}, 
      Optica`Optica`RayEnd :> {2.195908819104282, -1.8418698879684676`, 0.}, 
      RotationMatrix :> {{-0.8810604903992962, -0.4730036070236158, 0.}, {
       0.4730036070236158, -0.8810604903992962, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17032709141775013`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25338834998380516`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.342879925286823`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4321142913489444, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8810604903992962, -0.4730036070236158, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.605303873416047, 0.3617660148907954, 0.}, 
      Optica`Optica`RayEnd :> {2.300476159870274, 0.3477845166552455, 0.}, 
      RotationMatrix :> {{-0.9989497711377134, -0.04581871608753076, 0.}, {
       0.04581871608753076, -0.9989497711377134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06327232907177721, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3051481889811156, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.907490983314526`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20647503908971204`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9989497711377134, -0.04581871608753076, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.300476159870274, 0.3477845166552455, 0.}, 
      Optica`Optica`RayEnd :> {2.0921927069666446`, 0.3256054024297014, 0.}, 
      RotationMatrix :> {{-0.9943782110729956, -0.1058866060617143, 0.}, {
       0.1058866060617143, -0.9943782110729956, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0629808306555191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20946099842521557`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.217493260983844`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1990000177496967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9943782110729956, -0.1058866060617143, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1481400246627125`, 2.369639803748075, 0.}, 
      Optica`Optica`RayEnd :> {5.367259958218387, 2.59304855884162, 0.}, 
      RotationMatrix :> {{0.7002208840789133, 0.713926266150605, 
       0.}, {-0.713926266150605, 0.7002208840789133, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01611788145653439, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31292973194295737`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.051313432202473`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24744278357561406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7002208840789133, 0.713926266150605, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.367259958218387, 2.59304855884162, 0.}, 
      Optica`Optica`RayEnd :> {5.507286540201194, 2.678637279603003, 0.}, 
      RotationMatrix :> {{0.8532359548130628, 0.5215250764960783, 
       0.}, {-0.5215250764960783, 0.8532359548130628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014107026393222017`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1641123785195907, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.29419975241147, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2688809953594156, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8532359548130628, 0.5215250764960783, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.811440419389403, 1.8345145594733225`, 0.}, 
      Optica`Optica`RayEnd :> {6.985714678248692, 1.922396766792331, 0.}, 
      RotationMatrix :> {{0.8928950132488656, 0.45026491681598757`, 
       0.}, {-0.45026491681598757`, 0.8928950132488656, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008610879834978966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19517889144119943`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.014531687087985`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19622334658070756`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8928950132488656, 0.45026491681598757`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.985714678248692, 1.922396766792331, 0.}, 
      Optica`Optica`RayEnd :> {7.089412134823265, 2.004929234284356, 0.}, 
      RotationMatrix :> {{0.7824324652537326, 0.6227354472944082, 
       0.}, {-0.6227354472944082, 0.7824324652537326, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00802715695922945, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1325321496481421, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.210679268567233`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32232314721138144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7824324652537326, 0.6227354472944082, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.114866436608288, 2.87721879600748, 0.}, 
      Optica`Optica`RayEnd :> {2.0728522647269667`, 3.096887373596184, 0.}, 
      RotationMatrix :> {{-0.18785650791297345`, 0.9821964836196181, 
       0.}, {-0.9821964836196181, -0.18785650791297345`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013751129416283115`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22365034008182855`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.493730537063136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08599842168519688, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 72, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18785650791297345`, 0.9821964836196181, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5716690254112136`, -3.0748271865089367`, 
       0.}, Optica`Optica`RayEnd :> {2.599163998917913, -3.2201451736631674`, 
       0.}, RotationMatrix :> {{0.18590721312697273`, -0.9825673046195673, 
       0.}, {0.9825673046195673, 0.18590721312697273`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008092529737647243, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14789621685050403`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.914155062729247`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17662597823506612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 77, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.18590721312697273`, -0.9825673046195673, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7370821451708434`, -2.897242151157988, 0.}, 
      Optica`Optica`RayEnd :> {3.9134400662329862`, -2.9770441415149165`, 0.},
       RotationMatrix :> {{0.9110671280290425, -0.4122580359737234, 0.}, {
       0.4122580359737234, 0.9110671280290425, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02776148526105819, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19357291645860014`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.784538750182284`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23179945281138153`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9110671280290425, -0.4122580359737234, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9134400662329862`, -2.9770441415149165`, 
       0.}, Optica`Optica`RayEnd :> {4.16312011496545, -3.0916553002213503`, 
       0.}, RotationMatrix :> {{0.9088241314719134, -0.417179455455709, 0.}, {
       0.417179455455709, 0.9088241314719134, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02769265687691364, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2747286742134445, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.191137188018182`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3099326494486273, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9088241314719134, -0.417179455455709, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.767724301347901, -1.6731776431117509`, 0.}, 
      Optica`Optica`RayEnd :> {4.05889476923608, -1.7042871649611344`, 0.}, 
      RotationMatrix :> {{0.9943406949998522, -0.10623832767514307`, 0.}, {
       0.10623832767514307`, 0.9943406949998522, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008492719411232584, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2928276689794154, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.530932187678461`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07499872977128523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9943406949998522, -0.10623832767514307`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.05889476923608, -1.7042871649611344`, 0.}, 
      Optica`Optica`RayEnd :> {4.4193349084766895`, -1.7443209047785018`, 0.},
       RotationMatrix :> {{0.993888323284036, -0.11039022076093429`, 0.}, {
       0.11039022076093429`, 0.993888323284036, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00847171375373309, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.36265657901043896`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.06766392461391, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4142802936440285, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.993888323284036, -0.11039022076093429`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.847931087938611, 0.9721552211046295, 0.}, 
      Optica`Optica`RayEnd :> {2.413079136039623, 0.8082127062037942, 0.}, 
      RotationMatrix :> {{-0.935710112544709, -0.35276987581363584`, 0.}, {
       0.35276987581363584`, -0.935710112544709, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010432940465813664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4647293494738316, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.40222731361424, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40532944498584245`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.935710112544709, -0.35276987581363584`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.413079136039623, 0.8082127062037942, 0.}, 
      Optica`Optica`RayEnd :> {2.18705552402088, 0.7293805768078586, 0.}, 
      RotationMatrix :> {{-0.9442174808723289, -0.32932256044054026`, 0.}, {
       0.32932256044054026`, -0.9442174808723289, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01040388742614954, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23937664425565167`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.756504747112604`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2695006764497434, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9442174808723289, -0.32932256044054026`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5075177202934777`, 2.1367499951643203`, 0.},
       Optica`Optica`RayEnd :> {3.45669261763965, 2.226579398023197, 0.}, 
      RotationMatrix :> {{-0.49243876630098304`, 0.8703470925119279, 
       0.}, {-0.8703470925119279, -0.49243876630098304`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4028086886731848, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10321101044827802`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.56565777160907, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4268766833043448, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.49243876630098304`, 0.8703470925119279, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.45669261763965, 2.226579398023197, 0.}, 
      Optica`Optica`RayEnd :> {3.332308243559459, 2.3879252482139632`, 0.}, 
      RotationMatrix :> {{-0.6105497793950628, 0.7919778828228984, 
       0.}, {-0.7919778828228984, -0.6105497793950628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3936760800675188, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20372519699119673`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.867171063156041`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1431473004651249, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6105497793950628, 0.7919778828228984, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.332308243559459, 2.3879252482139632`, 0.}, 
      Optica`Optica`RayEnd :> {3.1486487051213468`, 2.299759893171285, 0.}, 
      RotationMatrix :> {{-0.9015062503341126, -0.43276608070472533`, 0.}, {
       0.43276608070472533`, -0.9015062503341126, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008925551155592217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20372519699119665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.168684354703013`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21407164684317193`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9015062503341126, -0.43276608070472533`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.637363154484737, 2.100095438023548, 0.}, 
      Optica`Optica`RayEnd :> {4.669297845975176, 2.114999261324612, 0.}, 
      RotationMatrix :> {{0.9061726216548176, 0.4229080039006534, 
       0.}, {-0.4229080039006534, 0.9061726216548176, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009621757078802242, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.035241289272370184`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.836489749649122`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3999221001396874, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9061726216548176, 0.4229080039006534, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.669297845975176, 2.114999261324612, 0.}, 
      Optica`Optica`RayEnd :> {4.888010749790684, 2.239795602771776, 0.}, 
      RotationMatrix :> {{0.8685551014139723, 0.4955926107275657, 
       0.}, {-0.4955926107275657, 0.8685551014139723, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009555005386657857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2518123530210715, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.209172032120307`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3968513728229452, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8685551014139723, 0.4955926107275657, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4748039084685063`, -0.6836136830671304, 0.},
       Optica`Optica`RayEnd :> {2.3839809742100564`, -0.7082420446104155, 0.},
       RotationMatrix :> {{-0.9651445870461537, -0.26171726365585657`, 0.}, {
       0.26171726365585657`, -0.9651445870461537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009209044065769745, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0941029307706274, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.227950567722514`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42022969473909666`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9651445870461537, -0.26171726365585657`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3839809742100564`, -0.7082420446104155, 0.},
       Optica`Optica`RayEnd :> {2.074965366139089, -0.7819802989291605, 0.}, 
      RotationMatrix :> {{-0.972690408371029, -0.23210637531744, 0.}, {
       0.23210637531744, -0.972690408371029, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009181855406227324, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31769163693973074`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.698134190393315`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24737728305757323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.972690408371029, -0.23210637531744, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7044712285073365`, -0.8600566613744223, 0.},
       Optica`Optica`RayEnd :> {3.6789730870763115`, -0.8581771474698388, 0.},
       RotationMatrix :> {{-0.9972943061801329, 0.07351235855750864, 
       0.}, {-0.07351235855750864, -0.9972943061801329, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026534290910731333`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02556731876740462, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.849540277367607`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20209266745903298`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9972943061801329, 0.07351235855750864, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6789730870763115`, -0.8581771474698388, 0.},
       Optica`Optica`RayEnd :> {3.4125453660218863`, -0.8593377419620716, 0.},
       RotationMatrix :> {{-0.9999905121892354, -0.004356091311139995, 0.}, {
       0.004356091311139995, -0.9999905121892354, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026363873661098672`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2664302488942087, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.243857045731037`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29149231801926656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999905121892354, -0.004356091311139995, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8477455568113452`, -1.0070624334439158`, 
       0.}, Optica`Optica`RayEnd :> {3.6896996591254667`, -1.035563739061351, 
       0.}, RotationMatrix :> {{-0.9841256844511959, -0.17747291963413825`, 
       0.}, {0.17747291963413825`, -0.9841256844511959, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013423771703164444`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16059523715613003`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.823110004203484`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2557291350339528, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9841256844511959, -0.17747291963413825`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6896996591254667`, -1.035563739061351, 0.}, 
      Optica`Optica`RayEnd :> {3.422089061304332, -1.0631783556271799`, 0.}, 
      RotationMatrix :> {{-0.9947181029425473, -0.10264451119460762`, 0.}, {
       0.10264451119460762`, -0.9947181029425473, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013341396477410651`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2690315950111859, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.22127676482004, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32817394982121334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9947181029425473, -0.10264451119460762`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5831585270802275`, 0.2281089080558495, 0.}, 
      Optica`Optica`RayEnd :> {5.169421741661696, 0.4938376082481516, 0.}, 
      RotationMatrix :> {{-0.841404993684461, 0.5404050671513475, 
       0.}, {-0.5404050671513475, -0.841404993684461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009398668323140206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4917213333935696, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.206209835321287`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32890915867528286`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.841404993684461, 0.5404050671513475, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.169421741661696, 0.4938376082481516, 0.}, 
      Optica`Optica`RayEnd :> {4.9164044126609205`, 0.6481537547206977, 0.}, 
      RotationMatrix :> {{-0.8537402464738157, 0.5206991372672214, 
       0.}, {-0.5206991372672214, -0.8537402464738157, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009372900830459567, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29636336115792616`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.644827609835017`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34665071138695697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8537402464738157, 0.5206991372672214, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.888559142148566, -0.24197956494456557`, 0.},
       Optica`Optica`RayEnd :> {7.960429604410104, -0.1666218653883848, 0.}, 
      RotationMatrix :> {{0.6901647206912055, 0.7236523048489721, 
       0.}, {-0.7236523048489721, 0.6901647206912055, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09859783488484906, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10413523048462901`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.70415289729236, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36423137010786266`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.6901647206912055, 0.7236523048489721, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.960429604410104, -0.1666218653883848, 0.}, 
      Optica`Optica`RayEnd :> {8.150256002333505, 0.05231239248044924, 0.}, 
      RotationMatrix :> {{0.6550948339893427, 0.755546662013985, 
       0.}, {-0.755546662013985, 0.6550948339893427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09823175194889973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2897693403677317, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.133011521036604`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28747412245786774`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.6550948339893427, 0.755546662013985, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.397588857222164, -0.3497113918811222, 0.}, 
      Optica`Optica`RayEnd :> {7.4653602179059835`, -0.18272877991268882`, 
       0.}, RotationMatrix :> {{0.3760658831069337, 0.9265929265664624, 
       0.}, {-0.9265929265664624, 0.3760658831069337, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019538014727289936`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18021140371446168`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.860796735523696`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39341626572882926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3760658831069337, 0.9265929265664624, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4653602179059835`, -0.18272877991268882`, 
       0.}, Optica`Optica`RayEnd :> {7.574921277472411, 0.08747559165130749, 
       0.}, RotationMatrix :> {{0.37576032805796444`, 0.926716880097568, 
       0.}, {-0.926716880097568, 0.37576032805796444`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019489859011447036`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29157165188956974`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.292322780320259`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0674069347873748, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.37576032805796444`, 0.926716880097568, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.341191770303148, -1.1511869589989376`, 0.}, 
      Optica`Optica`RayEnd :> {7.236059442686831, -0.9493030010524817, 0.}, 
      RotationMatrix :> {{-0.46188062005253916`, 0.8869421022929747, 
       0.}, {-0.8869421022929747, -0.46188062005253916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01354265501930516, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2276179667472473, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.552805713117998`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24471093749817607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.46188062005253916`, 0.8869421022929747, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.236059442686831, -0.9493030010524817, 0.}, 
      Optica`Optica`RayEnd :> {7.093124318394603, -0.6399737634313856, 0.}, 
      RotationMatrix :> {{-0.4194640540318645, 0.9077719467879324, 
       0.}, {-0.9077719467879324, -0.4194640540318645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013492489451439745`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34075655093289586`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.057125408498683`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32866065096462793`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4194640540318645, 0.9077719467879324, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.666658242611352, -1.7260979029653378`, 0.}, 
      Optica`Optica`RayEnd :> {7.3802853501272025`, -1.7513157008069478`, 0.},
       RotationMatrix :> {{-0.9961451839411424, -0.08771985243300023, 0.}, {
       0.08771985243300023, -0.9961451839411424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021832719830477885`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.287481079164732, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.920103932471331`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3361350398566757, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9961451839411424, -0.08771985243300023, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3802853501272025`, -1.7513157008069478`, 
       0.}, Optica`Optica`RayEnd :> {7.095556880334739, -1.782516190304264, 
       0.}, RotationMatrix :> {{-0.9940496676374372, -0.10892776629445923`, 
       0.}, {0.10892776629445923`, -0.9940496676374372, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021773850230226044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2864328403923505, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.344024536252011`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04575486992597548, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9940496676374372, -0.10892776629445923`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.823226157153527, -1.930649643545257, 0.}, 
      Optica`Optica`RayEnd :> {7.863139321655691, -1.9772863051707465`, 0.}, 
      RotationMatrix :> {{0.6502172287052222, -0.759748350110022, 0.}, {
       0.759748350110022, 0.6502172287052222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.1877361888782945`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06138435393605778, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.998374180688206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03569063237363223, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6502172287052222, -0.759748350110022, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.863139321655691, -1.9772863051707465`, 0.}, 
      Optica`Optica`RayEnd :> {8.022041265246742, -2.1317672179825253`, 0.}, 
      RotationMatrix :> {{0.7170109036000785, -0.697061951420818, 0.}, {
       0.697061951420818, 0.7170109036000785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.144021869820614, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.221617192699876, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.326367625884023`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20567912863196453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7170109036000785, -0.697061951420818, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.022041265246742, -2.1317672179825253`, 0.}, 
      Optica`Optica`RayEnd :> {8.147211336256754, -1.948883010289454, 0.}, 
      RotationMatrix :> {{0.5648030709400922, 0.8252257212766947, 
       0.}, {-0.8252257212766947, 0.5648030709400922, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04334596152732044, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22161719269987604`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.65436107107984, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35037400406929997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5648030709400922, 0.8252257212766947, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.898725692883722, -1.6843677998318296`, 0.}, 
      Optica`Optica`RayEnd :> {7.90382085132422, -1.663804587281601, 0.}, 
      RotationMatrix :> {{0.24050726356896748`, 0.9706473387232705, 
       0.}, {-0.9706473387232705, 0.24050726356896748`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021650863687520526`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.021185050151454908`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.325746973640136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3958055555865036, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.24050726356896748`, 0.9706473387232705, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.90382085132422, -1.663804587281601, 0.}, 
      Optica`Optica`RayEnd :> {7.981703858840445, -1.3971231822573906`, 0.}, 
      RotationMatrix :> {{0.28033479538585027`, 0.9599022879939259, 
       0.}, {-0.9599022879939259, 0.28033479538585027`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021577543430302697`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27782140782427006`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.736922657220056`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28752616543910364`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.28033479538585027`, 0.9599022879939259, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.106842406878487, -1.2806810371144008`, 0.}, 
      Optica`Optica`RayEnd :> {6.978182730931252, -1.1631478453094757`, 0.}, 
      RotationMatrix :> {{-0.7383102707158302, 0.6744612250941615, 
       0.}, {-0.6744612250941615, -0.7383102707158302, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013831178686387337`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17426234071279076`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.474411128600346`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1754707155506866, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7383102707158302, 0.6744612250941615, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.978182730931252, -1.1631478453094757`, 0.}, 
      Optica`Optica`RayEnd :> {6.81221724320332, -0.9879310810174107, 0.}, 
      RotationMatrix :> {{-0.6876805730651335, 0.7260133810260038, 
       0.}, {-0.7260133810260038, -0.6876805730651335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013751558650465753`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2413409571658974, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.831595745205874`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10874389157492037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6876805730651335, 0.7260133810260038, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.119803288382871, -1.2507439383342212`, 0.}, 
      Optica`Optica`RayEnd :> {5.918159887220145, -1.2182123801542875`, 0.}, 
      RotationMatrix :> {{-0.9872346325758475, 0.15927266006076196`, 
       0.}, {-0.15927266006076196`, -0.9872346325758475, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019878552871827406`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20425073686546766`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.01091408099537, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40631830944112113`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9872346325758475, 0.15927266006076196`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.918159887220145, -1.2182123801542875`, 0.}, 
      Optica`Optica`RayEnd :> {5.603984831371815, -1.169398971513567, 0.}, 
      RotationMatrix :> {{-0.9881442864571066, 0.15352807281463313`, 
       0.}, {-0.15352807281463313`, -0.9881442864571066, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019829222934472254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3179445149399925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.481471963106557`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10410283406555773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9881442864571066, 0.15352807281463313`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.141316224293418, -1.8963876196907001`, 0.}, 
      Optica`Optica`RayEnd :> {6.137011277797102, -1.8989182429969074`, 0.}, 
      RotationMatrix :> {{-0.8620827921270294, -0.5067674609902111, 0.}, {
       0.5067674609902111, -0.8620827921270294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09562202496234898, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.004993657843110863, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.121496349390402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21852151873018427`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8620827921270294, -0.5067674609902111, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.137011277797102, -1.8989182429969074`, 0.}, 
      Optica`Optica`RayEnd :> {5.930221352069838, -2.022155952212378, 0.}, 
      RotationMatrix :> {{-0.8590216946976411, -0.5119391839259746, 0.}, {
       0.5119391839259746, -0.8590216946976411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09538462304405353, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.240727244729309, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.47777267158978, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23088619338068733`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8590216946976411, -0.5119391839259746, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.909899322736532, -0.39632633971432635`, 0.},
       Optica`Optica`RayEnd :> {4.826113860211855, -0.35923044026463574`, 0.},
       RotationMatrix :> {{-0.914386119633283, 0.40484320943050006`, 
       0.}, {-0.40484320943050006`, -0.914386119633283, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013386051508454167`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09163028694954285, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.938948792537897`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08620884949118782, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.914386119633283, 0.40484320943050006`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.826113860211855, -0.35923044026463574`, 0.},
       Optica`Optica`RayEnd :> {4.561283549930273, -0.227086100596803, 0.}, 
      RotationMatrix :> {{-0.8947928975388386, 0.4464814335602877, 
       0.}, {-0.4464814335602877, -0.8947928975388386, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013337406193758792`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2959682749047379, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.376981839396908`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02586067579105672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8947928975388386, 0.4464814335602877, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.362812811651092, 1.5853767994063988`, 0.}, 
      Optica`Optica`RayEnd :> {6.367294364003814, 1.5983522727364021`, 0.}, 
      RotationMatrix :> {{0.3264627292543668, 0.9452100752783952, 
       0.}, {-0.9452100752783952, 0.3264627292543668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012416183568909675`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.013727607935391082`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.702440359617638`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07274340843747784, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3264627292543668, 0.9452100752783952, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.367294364003814, 1.5983522727364021`, 0.}, 
      Optica`Optica`RayEnd :> {6.407879210301261, 1.8004025358513511`, 0.}, 
      RotationMatrix :> {{0.19693160471978854`, 0.9804172290726477, 
       0.}, {-0.9804172290726477, 0.19693160471978854`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012172288816274489`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20608599800521998`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.007447636665365`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2581219859061583, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19693160471978854`, 0.9804172290726477, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.076721279197129, 2.116419354507405, 0.}, 
      Optica`Optica`RayEnd :> {7.078080013573787, 2.1759753661073877`, 0.}, 
      RotationMatrix :> {{0.022808459965970446`, 0.9997398532388216, 
       0.}, {-0.9997398532388216, 0.022808459965970446`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02560822731052177, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05957150893509081, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.662108505334158`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2915846693027989, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.022808459965970446`, 0.9997398532388216, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.078080013573787, 2.1759753661073877`, 0.}, 
      Optica`Optica`RayEnd :> {7.1079055127338115`, 2.388170150014077, 0.}, 
      RotationMatrix :> {{0.13918896777701611`, 0.990265838676246, 
       0.}, {-0.990265838676246, 0.13918896777701611`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025250848033238505`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2142806260896004, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.979243831946768`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39225619768046444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13918896777701611`, 0.990265838676246, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3223761266728817`, 0.45320832530609795`, 
       0.}, Optica`Optica`RayEnd :> {3.1763382067299815`, 0.4876034430521933, 
       0.}, RotationMatrix :> {{-0.9733677297130519, 0.22924934624390694`, 
       0.}, {-0.22924934624390694`, -0.9733677297130519, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11090948328405656`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15003365684411182`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.357502424636532`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.322699669043745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9733677297130519, 0.22924934624390694`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1763382067299815`, 0.4876034430521933, 0.}, 
      Optica`Optica`RayEnd :> {2.8863540324988484`, 0.559232777351813, 0.}, 
      RotationMatrix :> {{-0.9708213872776642, 0.23980374059691204`, 
       0.}, {-0.23980374059691204`, -0.9708213872776642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11062956885746135`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2986998206171521, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.799578159149917`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06911587041498038, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9708213872776642, 0.23980374059691204`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.5046753581612275`, -1.1223702829451243`, 
       0.}, Optica`Optica`RayEnd :> {4.415850647724226, -1.2065811131300719`, 
       0.}, RotationMatrix :> {{-0.7257033868234058, -0.6880076993413939, 
       0.}, {0.6880076993413939, -0.7257033868234058, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04242247351772829, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12239809273291526`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.565870517311632`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41901292147334795`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7257033868234058, -0.6880076993413939, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.415850647724226, -1.2065811131300719`, 0.}, 
      Optica`Optica`RayEnd :> {4.2133081495809765`, -1.3706139949046245`, 0.},
       RotationMatrix :> {{-0.7771136836854389, -0.6293602486881797, 0.}, {
       0.6293602486881797, -0.7771136836854389, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04214961154879319, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26063432210162296`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.951609314022035`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35393506171583844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7771136836854389, -0.6293602486881797, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.532598262384877, -2.126137966057005, 0.}, 
      Optica`Optica`RayEnd :> {5.5055179968266055`, -2.312780313975175, 0.}, 
      RotationMatrix :> {{-0.14358824289099748`, -0.9896375177323642, 0.}, {
       0.9896375177323642, -0.14358824289099748`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023127321437305916`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1885966776460118, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.615015157473804`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15517412490265503`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.14358824289099748`, -0.9896375177323642, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5055179968266055`, -2.312780313975175, 0.}, 
      Optica`Optica`RayEnd :> {5.458210494903547, -2.6254920219548468`, 0.}, 
      RotationMatrix :> {{-0.1495795547238638, -0.9887496937084785, 0.}, {
       0.9887496937084785, -0.1495795547238638, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02306989640155276, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31626984055670526`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.083094521497728`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28882441172969464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1495795547238638, -0.9887496937084785, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.558502686551672, -1.1361041517412096`, 0.}, 
      Optica`Optica`RayEnd :> {6.641624614133751, -1.2508878463061588`, 0.}, 
      RotationMatrix :> {{0.5865223123234584, -0.8099330695475667, 0.}, {
       0.8099330695475667, 0.5865223123234584, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011944947190359654`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1417199752432235, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.847469211764757`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15117443153664206`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5865223123234584, -0.8099330695475667, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.641624614133751, -1.2508878463061588`, 0.}, 
      Optica`Optica`RayEnd :> {6.796596113038852, -1.4367323507430918`, 0.}, 
      RotationMatrix :> {{0.6404308866499154, -0.7680158067545246, 0.}, {
       0.7680158067545246, 0.6404308866499154, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01188117040879269, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2419800514552863, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.20559968791858, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19338243777125963`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.6404308866499154, -0.7680158067545246, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.7072547024128575`, 1.4150411308714208`, 0.},
       Optica`Optica`RayEnd :> {5.655358674577875, 1.4810432047924222`, 0.}, 
      RotationMatrix :> {{-0.6180958665972741, 0.7861027284619766, 
       0.}, {-0.7861027284619766, -0.6180958665972741, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009634777680724621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0839611306910682, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.232679691042684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2597311724192647, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6180958665972741, 0.7861027284619766, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.655358674577875, 1.4810432047924222`, 0.}, 
      Optica`Optica`RayEnd :> {5.507576983832616, 1.6542440114158796`, 0.}, 
      RotationMatrix :> {{-0.6490777649630646, 0.7607220616168248, 
       0.}, {-0.7607220616168248, -0.6490777649630646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009602697319747713, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22767948421968945`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.569645327687825`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3810406006922477, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6490777649630646, 0.7607220616168248, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.001660413572281, 1.6459442831685513`, 0.}, 
      Optica`Optica`RayEnd :> {7.003201024612557, 1.9257747184821181`, 0.}, 
      RotationMatrix :> {{0.005505432926096704, 0.9999848449893105, 
       0.}, {-0.9999848449893105, 0.005505432926096704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016135310124861718`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27983467621107594`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.155507291100347`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12962972476097526`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.005505432926096704, 0.9999848449893105, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.003201024612557, 1.9257747184821181`, 0.}, 
      Optica`Optica`RayEnd :> {6.9982269963100165`, 2.1711805332934513`, 0.}, 
      RotationMatrix :> {{-0.020264421676917582`, 0.9997946555238727, 
       0.}, {-0.9997946555238727, -0.020264421676917582`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016090017719086726`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24545621788980798`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.518782493577262`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14909077654292677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.020264421676917582`, 0.9997946555238727, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.523807089318023, -1.1364673427704632`, 0.}, 
      Optica`Optica`RayEnd :> {7.578043295185931, -1.389808408822895, 0.}, 
      RotationMatrix :> {{0.2093402672976954, -0.977842856745259, 0.}, {
       0.977842856745259, 0.2093402672976954, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1320861012927029, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25908157359319994`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.136361356196598`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07138421385630347, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.2093402672976954, -0.977842856745259, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.578043295185931, -1.389808408822895, 0.}, 
      Optica`Optica`RayEnd :> {7.601329198023765, -1.6135517013908613`, 0.}, 
      RotationMatrix :> {{0.10351509522683813`, -0.9946278827079895, 0.}, {
       0.9946278827079895, 0.10351509522683813`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1305648895256623, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2249517598066921, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.469289960710503`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.171758696923204, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {0.10351509522683813`, -0.9946278827079895, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.129580112651137, -0.3380120252934028, 0.}, 
      Optica`Optica`RayEnd :> {8.112982644365966, -0.7014769110622621, 0.}, 
      RotationMatrix :> {{-0.04561703479556778, -0.9989590012290094, 0.}, {
       0.9989590012290094, -0.04561703479556778, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04326728760638411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36384364655775864`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.916683119879805`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17479131469489717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.04561703479556778, -0.9989590012290094, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.112982644365966, -0.7014769110622621, 0.}, 
      Optica`Optica`RayEnd :> {8.144168730365307, -0.8780716570571427, 0.}, 
      RotationMatrix :> {{0.17390597004042746`, -0.9847622624696267, 0.}, {
       0.9847622624696267, 0.17390597004042746`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03955961226727557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1793272881436473, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.182087506332403`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3246695159599802, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.17390597004042746`, -0.9847622624696267, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.400837322111133, -0.12973264472074342`, 0.},
       Optica`Optica`RayEnd :> {8.41846620837065, 1.152756908452858, 0.}, 
      RotationMatrix :> {{0.013744533810289991`, 0.9999055394337697, 
       0.}, {-0.9999055394337697, 0.013744533810289991`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04224299909425905, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2826107093074557`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.869414765966624`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11967169524720767`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.013744533810289991`, 0.9999055394337697, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.41846620837065, 1.152756908452858, 0.}, 
      Optica`Optica`RayEnd :> {8.397711101966816, 1.425990015523278, 0.}, 
      RotationMatrix :> {{-0.07574296177570125, 0.9971273758860725, 
       0.}, {-0.9971273758860725, -0.07574296177570125, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04190150848794057, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2740202642893226, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.274964757114823`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04496834886036661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.07574296177570125, 0.9971273758860725, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.380663139819714, -0.09125414151794078, 0.}, 
      Optica`Optica`RayEnd :> {7.153035130388449, 0.03280620533953821, 0.}, 
      RotationMatrix :> {{-0.8780583067374427, 0.47855366467030125`, 
       0.}, {-0.47855366467030125`, -0.8780583067374427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00881857769514655, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2592401981561465, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.225085361760902`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40737003389731197`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8780583067374427, 0.47855366467030125`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.153035130388449, 0.03280620533953821, 0.}, 
      Optica`Optica`RayEnd :> {6.9578493651101825`, 0.12924088828540214`, 0.},
       RotationMatrix :> {{-0.8965450447166521, 0.4429525739783169, 
       0.}, {-0.4429525739783169, -0.8965450447166521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008789188700428658, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2177088216911108, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.547294417863746`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36654759950546406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8965450447166521, 0.4429525739783169, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.080195487154919, 0.6661707831798577, 0.}, 
      Optica`Optica`RayEnd :> {8.087933797518698, 0.6801485323010795, 0.}, 
      RotationMatrix :> {{0.48434596087168846`, 0.874876557113791, 
       0.}, {-0.874876557113791, 0.48434596087168846`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12323485699175779`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01597682439604313, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.076474375870541`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29097362274858335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.48434596087168846`, 0.874876557113791, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.087933797518698, 0.6801485323010795, 0.}, 
      Optica`Optica`RayEnd :> {8.246315232740649, 0.938381580360709, 0.}, 
      RotationMatrix :> {{0.5228249532863644, 0.8524400672311869, 
       0.}, {-0.8524400672311869, 0.5228249532863644, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12279693417128397`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3029339633206085, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.524816641585042`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18218251749614758`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5228249532863644, 0.8524400672311869, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.825637039936708, -0.5234217821511212, 0.}, 
      Optica`Optica`RayEnd :> {5.652425320378326, -0.5853602408820765, 0.}, 
      RotationMatrix :> {{-0.9416090301801618, -0.3367082331680866, 0.}, {
       0.3367082331680866, -0.9416090301801618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015882234026474134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18395290827366034`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.274450885680507`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34483868575685017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9416090301801618, -0.3367082331680866, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.652425320378326, -0.5853602408820765, 0.}, 
      Optica`Optica`RayEnd :> {5.388581737806026, -0.6601193636767255, 0.}, 
      RotationMatrix :> {{-0.9621234351574744, -0.2726141880401323, 0.}, {
       0.2726141880401323, -0.9621234351574744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015798993829612164`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27423049156797197`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.680312013201105`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3717778607805181, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9621234351574744, -0.2726141880401323, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.091004786913011, 0.7337025154327036, 0.}, 
      Optica`Optica`RayEnd :> {4.850167520404469, 0.8353921946611623, 0.}, 
      RotationMatrix :> {{-0.9212456776211309, 0.3889812353628172, 
       0.}, {-0.3889812353628172, -0.9212456776211309, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009510807498820831, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2614256678310176, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.61358627877169, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10314699846981323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9212456776211309, 0.3889812353628172, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.850167520404469, 0.8353921946611623, 0.}, 
      Optica`Optica`RayEnd :> {4.690582381629045, 0.865765952717761, 0.}, 
      RotationMatrix :> {{-0.9823650457179294, 0.18697303803385784`, 
       0.}, {-0.18697303803385784`, -0.9823650457179294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008799909207814084, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16244993596936924`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.854012184006356`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.384994414323059, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9823650457179294, 0.18697303803385784`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.881191250877583, -0.8861829153964238, 0.}, 
      Optica`Optica`RayEnd :> {6.880779105955508, -0.8939636586819787, 0.}, 
      RotationMatrix :> {{-0.052895709496769625`, -0.9986000420172394, 0.}, {
       0.9986000420172394, -0.052895709496769625`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2743867182782657, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00779165126994914, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.388030009880623`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4315657686709443, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.052895709496769625`, -0.9986000420172394, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.880779105955508, -0.8939636586819787, 0.}, 
      Optica`Optica`RayEnd :> {6.882842248520935, -1.1463896616883769`, 0.}, 
      RotationMatrix :> {{0.0081729838968701, -0.9999666006093506, 0.}, {
       0.9999666006093506, 0.0081729838968701, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.273103411309412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2524344341626779, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.761632972441387`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4303417070310749, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0081729838968701, -0.9999666006093506, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.331543225782122, -0.40876767013290327`, 0.},
       Optica`Optica`RayEnd :> {7.335812371414638, -0.42283003841443123`, 0.},
       RotationMatrix :> {{0.29049483713537644`, -0.9568765592267847, 0.}, {
       0.9568765592267847, 0.29049483713537644`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28741764345854515`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.014696115341033338`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.681527428804163`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18609927342004415`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.29049483713537644`, -0.9568765592267847, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.335812371414638, -0.42283003841443123`, 0.},
       Optica`Optica`RayEnd :> {7.4207183716486735`, -0.620736054269777, 0.}, 
      RotationMatrix :> {{0.39426895496335795`, -0.9189950985462877, 0.}, {
       0.9189950985462877, 0.39426895496335795`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28387955112004487`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21535045852627865`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.000246107423056`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3924311888950628, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.39426895496335795`, -0.9189950985462877, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.548191576253571, 0.30072193789939994`, 0.}, 
      Optica`Optica`RayEnd :> {7.581851068272584, 0.2082720020311536, 0.}, 
      RotationMatrix :> {{0.34211408488869544`, -0.9396584235352599, 0.}, {
       0.9396584235352599, 0.34211408488869544`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3413877946372311, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09838674730379535, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.706084766871113`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.008027904207480617, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.34211408488869544`, -0.9396584235352599, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.581851068272584, 0.2082720020311536, 0.}, 
      Optica`Optica`RayEnd :> {7.675336249011812, 0.05918582749291684, 0.}, 
      RotationMatrix :> {{0.5312501308474284, -0.847215024934396, 0.}, {
       0.847215024934396, 0.5312501308474284, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3160805289196947, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17597206157879594`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.96652341800773, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4180954602671726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5312501308474284, -0.847215024934396, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.675336249011812, 0.05918582749291684, 0.}, 
      Optica`Optica`RayEnd :> {7.850782598441062, 0.07277791814304135, 0.}, 
      RotationMatrix :> {{0.9970125249154337, 0.07724004894969222, 
       0.}, {-0.07724004894969222, 0.9970125249154337, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023431224136205592`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17597206157879647`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.22696206914435, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0487908563198856, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9970125249154337, 0.07724004894969222, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.055504511607546, 1.1912081890792554`, 0.}, 
      Optica`Optica`RayEnd :> {6.983547199606125, 1.1459838153379867`, 0.}, 
      RotationMatrix :> {{-0.8466680200706099, -0.5321214746556583, 0.}, {
       0.5321214746556583, -0.8466680200706099, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20372030763855262`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08498881532742861, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.473884353831872`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3310675485959692, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8466680200706099, -0.5321214746556583, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.983547199606125, 1.1459838153379867`, 0.}, 
      Optica`Optica`RayEnd :> {6.863324853607964, 1.031608164437147, 0.}, 
      RotationMatrix :> {{-0.7245044629513491, -0.689270109001962, 0.}, {
       0.689270109001962, -0.7245044629513491, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19112322792901326`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16593734358574083`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.71947162233877, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12365334157095595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7245044629513491, -0.689270109001962, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.863324853607964, 1.031608164437147, 0.}, 
      Optica`Optica`RayEnd :> {6.914027006419358, 0.8736066021139147, 0.}, 
      RotationMatrix :> {{0.3055499848061395, -0.9521760377078218, 0.}, {
       0.9521760377078218, 0.3055499848061395, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011818137153208003`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16593734358574094`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.965058890845667`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38246465391684215`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3055499848061395, -0.9521760377078218, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.590368247538926, 1.7369085399029403`, 0.}, 
      Optica`Optica`RayEnd :> {7.503845818473073, 1.867324869727871, 0.}, 
      RotationMatrix :> {{-0.552833016831545, 0.8332920589450805, 
       0.}, {-0.8332920589450805, -0.552833016831545, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.38639165020708, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15650734748394624`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.603734575155878`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2223555251897767, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.552833016831545, 0.8332920589450805, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.503845818473073, 1.867324869727871, 0.}, 
      Optica`Optica`RayEnd :> {7.346007987984193, 2.1354637918059716`, 0.}, 
      RotationMatrix :> {{-0.5072804921099433, 0.8617810060129503, 
       0.}, {-0.8617810060129503, -0.5072804921099433, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3806870656860148`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3111450823436584, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.064229297024493`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2696017856103391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5072804921099433, 0.8617810060129503, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.738157029364659, 1.911472297130765, 0.}, 
      Optica`Optica`RayEnd :> {8.066377499692184, 2.2089179863153836`, 0.}, 
      RotationMatrix :> {{0.7409915707070802, 0.6715143275768979, 
       0.}, {-0.6715143275768979, 0.7409915707070802, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      71.04503214625467, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4429476438096654, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.326074025474496`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13153143423847657`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7409915707070802, 0.6715143275768979, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.066377499692184, 2.2089179863153836`, 0.}, 
      Optica`Optica`RayEnd :> {8.279619357017198, 2.3844659508650694`, 0.}, 
      RotationMatrix :> {{0.7720421118333067, 0.6355713788049043, 
       0.}, {-0.6355713788049043, 0.7720421118333067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      70.78086318727493, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2762049557356987, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.73485735996333, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.032029899424421304`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7720421118333067, 0.6355713788049043, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.279619357017198, 2.3844659508650694`, 0.}, 
      Optica`Optica`RayEnd :> {8.269418053371558, 2.1084494459656544`, 0.}, 
      RotationMatrix :> {{-0.03693381828891451, -0.9993177137760545, 0.}, {
       0.9993177137760545, -0.03693381828891451, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.26318669129995625`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2762049557356987, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.143640694452163`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06877532583830848, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.03693381828891451, -0.9993177137760545, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.932904742021405, 1.7915249845889867`, 0.}, 
      Optica`Optica`RayEnd :> {8.353376858084014, 1.4486758481567938`, 0.}, 
      RotationMatrix :> {{0.7750163029571825, -0.6319412394760926, 0.}, {
       0.6319412394760926, 0.7750163029571825, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.3347862766988072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5425332531176951, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.79802819518941, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0950816393370375, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7750163029571825, -0.6319412394760926, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.353376858084014, 1.4486758481567938`, 0.}, 
      Optica`Optica`RayEnd :> {8.471556087494077, 1.3036155224815655`, 0.}, 
      RotationMatrix :> {{0.6316148986198838, -0.7752822839723563, 0.}, {
       0.7752822839723563, 0.6316148986198838, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2472027523639106`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18710646260607772`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.074945759846404`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39733224814225104`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6316148986198838, -0.7752822839723563, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.471556087494077, 1.3036155224815655`, 0.}, 
      Optica`Optica`RayEnd :> {8.394212442133696, 1.133243022143843, 0.}, 
      RotationMatrix :> {{-0.41336704399791463`, -0.9105644880712325, 0.}, {
       0.9105644880712325, -0.41336704399791463`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08183663146610168, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18710646260607788`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.351863324503398`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03305449866544607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.41336704399791463`, -0.9105644880712325, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.843510263820795, 1.5809955172019488`, 0.}, 
      Optica`Optica`RayEnd :> {7.742433758337944, 1.4098870680789055`, 0.}, 
      RotationMatrix :> {{-0.5086061080389209, -0.8609993187369552, 0.}, {
       0.8609993187369552, -0.5086061080389209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02507781826033543, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19873238619288455`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.675844486752316`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.365149924853263, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5086061080389209, -0.8609993187369552, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.742433758337944, 1.4098870680789055`, 0.}, 
      Optica`Optica`RayEnd :> {7.6564143033686465`, 1.2250070433451765`, 0.}, 
      RotationMatrix :> {{-0.42184664525464016`, -0.9066671979769674, 0.}, {
       0.9066671979769674, -0.42184664525464016`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02483729915265739, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20391167249267317`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.977633762041473`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19685869335172057`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.42184664525464016`, -0.9066671979769674, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.464985043809726, 0.8755865366445774, 0.}, 
      Optica`Optica`RayEnd :> {7.449521888375906, 0.6445117044053194, 0.}, 
      RotationMatrix :> {{-0.06676905737327457, -0.9977684565957592, 0.}, {
       0.9977684565957592, -0.06676905737327457, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20244919280798096`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2315916390338213, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.743824293770079`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28338525963434236`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06676905737327457, -0.9977684565957592, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.449521888375906, 0.6445117044053194, 0.}, 
      Optica`Optica`RayEnd :> {7.430375912009466, 0.283208622726918, 0.}, 
      RotationMatrix :> {{-0.05291720985586097, -0.9985989029140127, 0.}, {
       0.9985989029140127, -0.05291720985586097, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20193058988788956`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36181001263278195`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.279303112466597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32533429090051263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05291720985586097, -0.9985989029140127, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.051399004163451, 1.2658168799102762`, 0.}, 
      Optica`Optica`RayEnd :> {5.9381947141431874`, 1.2479646951500007`, 0.}, 
      RotationMatrix :> {{-0.9877927582059827, -0.15577376812485502`, 0.}, {
       0.15577376812485502`, -0.9877927582059827, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.338822117598471, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11460327996923562`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.77237295005277, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42577419628540886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9877927582059827, -0.15577376812485502`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.9381947141431874`, 1.2479646951500007`, 0.},
       Optica`Optica`RayEnd :> {5.585010064392459, 1.196668184852395, 0.}, 
      RotationMatrix :> {{-0.9896166714303332, -0.1437318462524819, 0.}, {
       0.1437318462524819, -0.9896166714303332, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3379617789708981, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3568903596179884, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.300570682287393`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1286354027315862, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9896166714303332, -0.1437318462524819, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.348678083172981, 0.9374527928655113, 0.}, 
      Optica`Optica`RayEnd :> {5.146843271438939, 0.915336947551428, 0.}, 
      RotationMatrix :> {{-0.9940502934311412, -0.10892205529396426`, 0.}, {
       0.10892205529396426`, -0.9940502934311412, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28998049110459306`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20304285715501708`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.107969882599367`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24217716877345224`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9940502934311412, -0.10892205529396426`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.146843271438939, 0.915336947551428, 0.}, 
      Optica`Optica`RayEnd :> {4.869019545342316, 0.9045133912008863, 0.}, 
      RotationMatrix :> {{-0.9992419858973441, -0.03892882762081214, 0.}, {
       0.03892882762081214, -0.9992419858973441, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28837576716301516`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2780344801536043, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.519460913226702`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29029366928223693`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9992419858973441, -0.03892882762081214, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.363292513720586, 1.1077631715094527`, 0.}, 
      Optica`Optica`RayEnd :> {4.180835378956244, 1.1009827641266325`, 0.}, 
      RotationMatrix :> {{-0.999310220398237, -0.037136012274155875`, 0.}, {
       0.037136012274155875`, -0.999310220398237, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2918340016377845, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18258307684637706`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.67165839003285, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3078641541893153, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999310220398237, -0.037136012274155875`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.180835378956244, 1.1009827641266325`, 0.}, 
      Optica`Optica`RayEnd :> {3.8802831926153463`, 1.0795703200884155`, 0.}, 
      RotationMatrix :> {{-0.9974717891678294, -0.07106356179033355, 0.}, {
       0.07106356179033355, -0.9974717891678294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2909368741618161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30131397158775025`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.11760306798272, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11964794127866395`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9974717891678294, -0.07106356179033355, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.544058705200856, -1.1397096353662313`, 0.}, 
      Optica`Optica`RayEnd :> {6.585515200998242, -1.3922282078274029`, 0.}, 
      RotationMatrix :> {{0.1620033863814059, -0.9867902020191301, 0.}, {
       0.9867902020191301, 0.1620033863814059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009285699474774697, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2558989458392252, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.807102521584008`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08797364913753557, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1620033863814059, -0.9867902020191301, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.585515200998242, -1.3922282078274029`, 0.}, 
      Optica`Optica`RayEnd :> {6.613447268885137, -1.6437226269738707`, 0.}, 
      RotationMatrix :> {{0.11038563181077117`, -0.9938888329635944, 0.}, {
       0.9938888329635944, 0.11038563181077117`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009248513187835832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2530407937038165, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.181602896265655`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.022169775740473355`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.11038563181077117`, -0.9938888329635944, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.023459793219201, 2.629803328498619, 0.}, 
      Optica`Optica`RayEnd :> {7.10368184781019, 2.848736495535804, 0.}, 
      RotationMatrix :> {{0.3440526119583747, 0.9389503715344166, 
       0.}, {-0.9389503715344166, 0.3440526119583747, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1825703294057307, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23316798594946855`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.689173302424585`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0009243123761599743, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3440526119583747, 0.9389503715344166, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.10368184781019, 2.848736495535804, 0.}, 
      Optica`Optica`RayEnd :> {7.1516229963101905`, 3.04052253545903, 0.}, 
      RotationMatrix :> {{0.24251009927874215`, 0.9701488812279349, 
       0.}, {-0.9701488812279349, 0.24251009927874215`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18050619647547012`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19768722474892614`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.981750395052996`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23445490686064063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.24251009927874215`, 0.9701488812279349, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.42157587195393, 2.311129214326098, 0.}, 
      Optica`Optica`RayEnd :> {6.428421427838424, 2.3501891946211466`, 0.}, 
      RotationMatrix :> {{0.1726264578406715, 0.9849873633978163, 
       0.}, {-0.9849873633978163, 0.1726264578406715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.093642436100311, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03965531106948152, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.913859893636163`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3424804034714952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1726264578406715, 0.9849873633978163, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.428421427838424, 2.3501891946211466`, 0.}, 
      Optica`Optica`RayEnd :> {6.488034289750155, 2.6797783985379304`, 0.}, 
      RotationMatrix :> {{0.17798235830250506`, 0.9840336783530723, 
       0.}, {-0.9840336783530723, 0.17798235830250506`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09341025455145736, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33493691442390494`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.409566526983543`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19317845810091397`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17798235830250506`, 0.9840336783530723, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.105130303168906, 2.32777283886906, 0.}, 
      Optica`Optica`RayEnd :> {4.973860009185009, 2.4233855638274715`, 0.}, 
      RotationMatrix :> {{-0.8083157941629097, 0.5887491629775654, 
       0.}, {-0.5887491629775654, -0.8083157941629097, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      2.99864776461476, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16239976372086096`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.806392755170446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4199910842474747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8083157941629097, 0.5887491629775654, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.973860009185009, 2.4233855638274715`, 0.}, 
      Optica`Optica`RayEnd :> {4.911576044151911, 2.523739366932794, 0.}, 
      RotationMatrix :> {{-0.5273347317536183, 0.8496576255682865, 
       0.}, {-0.8496576255682865, -0.5273347317536183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.1357602968139426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11811087205649655`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.981196845814061`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05671313101578396, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5273347317536183, 0.8496576255682865, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.911576044151911, 2.523739366932794, 0.}, 
      Optica`Optica`RayEnd :> {4.949638783966609, 2.6355490531667902`, 0.}, 
      RotationMatrix :> {{0.32226279555782045`, 0.9466502472398438, 
       0.}, {-0.9466502472398438, 0.32226279555782045`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.7055825790302638, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649673`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.156000936457676`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34803479790858977`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.32226279555782045`, 0.9466502472398438, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.949638783966609, 2.6355490531667902`, 0.}, 
      Optica`Optica`RayEnd :> {5.0602158577717615`, 2.677056749400575, 0.}, 
      RotationMatrix :> {{0.9362141848572478, 0.3514299362206897, 
       0.}, {-0.3514299362206897, 0.9362141848572478, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.4383378933279654, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649688`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.33080502710129, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2133799816414947, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9362141848572478, 0.3514299362206897, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0602158577717615`, 2.677056749400575, 0.}, 
      Optica`Optica`RayEnd :> {5.162450707646214, 2.6179110515934285`, 0.}, 
      RotationMatrix :> {{0.8655837358101117, -0.5007642122805998, 0.}, {
       0.5007642122805998, 0.8655837358101117, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2723141336500434, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649717`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.505609117744907`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21417789671618312`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8655837358101117, -0.5007642122805998, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.162450707646214, 2.6179110515934285`, 0.}, 
      Optica`Optica`RayEnd :> {5.18158680607505, 2.5013606855070525`, 0.}, 
      RotationMatrix :> {{0.16201809448736626`, -0.9867877872464178, 0.}, {
       0.9867877872464178, 0.16201809448736626`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1691731162518658, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649728`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.680413208388522`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3474005277571894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.16201809448736626`, -0.9867877872464178, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.18158680607505, 2.5013606855070525`, 0.}, 
      Optica`Optica`RayEnd :> {5.1036313876707275`, 2.412630020912711, 0.}, 
      RotationMatrix :> {{-0.6600189893359888, -0.7512489159498992, 0.}, {
       0.7512489159498992, -0.6600189893359888, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10509753158513789`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649771`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.855217299032137`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05759000721346179, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6600189893359888, -0.7512489159498992, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1036313876707275`, 2.412630020912711, 0.}, 
      Optica`Optica`RayEnd :> {4.985587288433265, 2.416601007334562, 0.}, 
      RotationMatrix :> {{-0.9994346598422919, 0.03362083737685828, 
       0.}, {-0.03362083737685828, -0.9994346598422919, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06529105445361282, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649808`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.030021389675756`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4204693739853585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9994346598422919, 0.03362083737685828, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.985587288433265, 2.416601007334562, 0.}, 
      Optica`Optica`RayEnd :> {4.913771130957169, 2.5103699660752623`, 0.}, 
      RotationMatrix :> {{-0.6080401933002588, 0.7939062434137816, 
       0.}, {-0.7939062434137816, -0.6080401933002588, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.040561578634327314`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649821`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.204825480319375`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10510998723020021`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6080401933002588, 0.7939062434137816, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.913771130957169, 2.5103699660752623`, 0.}, 
      Optica`Optica`RayEnd :> {4.9406965792129025`, 2.6253708283945265`, 0.}, 
      RotationMatrix :> {{0.22796756798860668`, 0.973668725976838, 
       0.}, {-0.973668725976838, 0.22796756798860668`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025198576973167956`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649846`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.379629570962994`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3111899096394381, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22796756798860668`, 0.973668725976838, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.9406965792129025`, 2.6253708283945265`, 0.},
       Optica`Optica`RayEnd :> {5.046675111958901, 2.677512258130888, 0.}, 
      RotationMatrix :> {{0.8972800801547143, 0.44146172853096544`, 
       0.}, {-0.44146172853096544`, 0.8972800801547143, 0.}, {0., 0., 
       0.9999999999999994}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01565442724004946, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649877`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.554433661606613`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2566545173254848, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8972800801547143, 0.44146172853096544`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.046675111958901, 2.677512258130888, 0.}, 
      Optica`Optica`RayEnd :> {5.154212732686672, 2.6286672151259234`, 0.}, 
      RotationMatrix :> {{0.9104802873382325, -0.4135524711188265, 0.}, {
       0.4135524711188265, 0.9104802873382325, 0.}, {0., 0., 
       0.9999999999999993}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009725195691602856, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649919`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.72923775225023, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16888344154216936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9104802873382325, -0.4135524711188265, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.851961525503718, 0.934645522777102, 0.}, 
      Optica`Optica`RayEnd :> {4.424351740191631, 0.7706489542266817, 0.}, 
      RotationMatrix :> {{-0.9336880995517444, -0.35808732560012607`, 0.}, {
       0.35808732560012607`, -0.9336880995517444, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08418785625681557, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.45797926043758985`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.591503013556213`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3884436120195187, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9336880995517444, -0.35808732560012607`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.424351740191631, 0.7706489542266817, 0.}, 
      Optica`Optica`RayEnd :> {4.1188388464948025`, 0.6604338486612473, 0.}, 
      RotationMatrix :> {{-0.9406610586110866, -0.33934756933366816`, 0.}, {
       0.33934756933366816`, -0.9406610586110866, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08396323415536613, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32478531018167933`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.0721852726251, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2549014990698939, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9406610586110866, -0.33934756933366816`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.518103669062487, 1.1512149591504777`, 0.}, 
      Optica`Optica`RayEnd :> {5.398525796497053, 1.2200248889577248`, 0.}, 
      RotationMatrix :> {{-0.8667413351073741, 0.4987579152417394, 
       0.}, {-0.4987579152417394, -0.8667413351073741, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037951337895498025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13796258205525613`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.813637456863658`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39652744288799957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8667413351073741, 0.4987579152417394, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.398525796497053, 1.2200248889577248`, 0.}, 
      Optica`Optica`RayEnd :> {5.143855725421484, 1.3816868608239041`, 0.}, 
      RotationMatrix :> {{-0.8442627822724414, 0.5359294304939741, 
       0.}, {-0.5359294304939741, -0.8442627822724414, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03781867161783675, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30164787128255516`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.217845604382282`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42068866342773364`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8442627822724414, 0.5359294304939741, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.461139648466303, 1.1443863509174352`, 0.}, 
      Optica`Optica`RayEnd :> {5.3780326268083885`, 1.1592845253399489`, 0.}, 
      RotationMatrix :> {{-0.9843092237170148, 0.17645212411758365`, 
       0.}, {-0.17645212411758365`, -0.9843092237170148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09214180901971822, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08443182249586224, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.811290215925283`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2518142899996523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9843092237170148, 0.17645212411758365`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3780326268083885`, 1.1592845253399489`, 0.},
       Optica`Optica`RayEnd :> {5.072201536619233, 1.2023600096651306`, 0.}, 
      RotationMatrix :> {{-0.9902261997419257, 0.13947068991248052`, 
       0.}, {-0.13947068991248052`, -0.9902261997419257, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09184567454461695, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3088497257180846, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.225148848387516`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11863276947128498`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9902261997419257, 0.13947068991248052`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.409836078855042, 1.1187061391187512`, 0.}, 
      Optica`Optica`RayEnd :> {5.327993242796761, 1.1048759326021627`, 0.}, 
      RotationMatrix :> {{-0.9860207359744215, -0.1666226522068942, 0.}, {
       0.1666226522068942, -0.9860207359744215, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02199517103167116, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0830031591347835, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.886054077360413`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03966782184469018, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 77, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9860207359744215, -0.1666226522068942, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.900457870164396, -0.10167967351866608`, 0.},
       Optica`Optica`RayEnd :> {5.924279037284031, -0.35385045836149054`, 0.},
       RotationMatrix :> {{0.09404574284126331, -0.9955678772707737, 0.}, {
       0.9955678772707737, 0.09404574284126331, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008450040797966445, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2532934123327878, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.242373781053065`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3433015581739146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09404574284126331, -0.9955678772707737, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.924279037284031, -0.35385045836149054`, 0.},
       Optica`Optica`RayEnd :> {5.953065952582621, -0.6208304854292546, 0.}, 
      RotationMatrix :> {{0.10720285513377549`, -0.9942371688139435, 0.}, {
       0.9942371688139435, 0.10720285513377549`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008428470707011719, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26852750575222684`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.63979448956636, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25792000676534116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10720285513377549`, -0.9942371688139435, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5649167357676115`, -0.1860555186724132, 0.},
       Optica`Optica`RayEnd :> {7.598560623249983, -0.21481323580048364`, 0.},
       RotationMatrix :> {{0.7601479057897611, -0.6497500760472753, 0.}, {
       0.6497500760472753, 0.7601479057897611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009275665482763417, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04425965950326113, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.800482988110717`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06934719834630042, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7601479057897611, -0.6497500760472753, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.598560623249983, -0.21481323580048364`, 0.},
       Optica`Optica`RayEnd :> {7.8015864440438545`, -0.3685024860381718, 0.},
       RotationMatrix :> {{0.7973155032407722, -0.6035627459443745, 0.}, {
       0.6035627459443745, 0.7973155032407722, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009233652315384836, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25463674037272743`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.177345363862354`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05468217309789174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7973155032407722, -0.6035627459443745, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.338030659768891, 1.0456952774415846`, 0.}, 
      Optica`Optica`RayEnd :> {4.184804334084109, 1.0900086345508422`, 0.}, 
      RotationMatrix :> {{-0.9606339470634645, 0.277817241634259, 
       0.}, {-0.277817241634259, -0.9606339470634645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15988142485899107`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1595054246762524, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.742016599029856`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3360451726634594, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9606339470634645, 0.277817241634259, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.184804334084109, 1.0900086345508422`, 0.}, 
      Optica`Optica`RayEnd :> {3.9180161944865612`, 1.1494482120242693`, 0.}, 
      RotationMatrix :> {{-0.9760681243452357, 0.21746497795546982`, 
       0.}, {-0.21746497795546982`, -0.9760681243452357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1591171623905866, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2733294254194742, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.14654414865068, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34030775887257386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9760681243452357, 0.21746497795546982`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6682505014656734`, -1.260811247870144, 0.}, 
      Optica`Optica`RayEnd :> {3.515237747523003, -1.3299214132440937`, 0.}, 
      RotationMatrix :> {{-0.9113535491993664, -0.4116244749303874, 0.}, {
       0.4116244749303874, -0.9113535491993664, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1913239853583196, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16789615191282636`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47638453625879, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26551937528666164`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9113535491993664, -0.4116244749303874, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.515237747523003, -1.3299214132440937`, 0.}, 
      Optica`Optica`RayEnd :> {3.3631369823812154`, -1.436960415300968, 0.}, 
      RotationMatrix :> {{-0.8177934369899713, -0.5755118542794134, 0.}, {
       0.5755118542794134, -0.8177934369899713, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18133119751960128`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1859892220480766, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.751648584889946`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18572195727246302`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8177934369899713, -0.5755118542794134, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3631369823812154`, -1.436960415300968, 0.}, 
      Optica`Optica`RayEnd :> {3.3994379955641585`, -1.6193726603941647`, 0.},
       RotationMatrix :> {{0.19517804732555738`, -0.980767826675703, 0.}, {
       0.980767826675703, 0.19517804732555738`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009470867868241547, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18598922204807655`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.0269126335211, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34930096776510017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.19517804732555738`, -0.980767826675703, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8700807173829546`, 1.4673964527622854`, 0.},
       Optica`Optica`RayEnd :> {3.8010335980801604`, 1.619771714514598, 0.}, 
      RotationMatrix :> {{-0.4127406867748857, 0.9108485743967519, 
       0.}, {-0.9108485743967519, -0.4127406867748857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043666428612270575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16728934538128862`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.651533545614766`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16473589756409163`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4127406867748857, 0.9108485743967519, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8010335980801604`, 1.619771714514598, 0.}, 
      Optica`Optica`RayEnd :> {3.6764578941698423`, 1.912287471595425, 0.}, 
      RotationMatrix :> {{-0.39182388545016567`, 0.9200402397671176, 
       0.}, {-0.9200402397671176, -0.39182388545016567`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043547136433508146`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31793800361913416`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.122081790971086`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40770141397134113`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.39182388545016567`, 0.9200402397671176, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.379052243606461, 0.6990117450102403, 0.}, 
      Optica`Optica`RayEnd :> {7.634981857793197, 0.8273299019140062, 0.}, 
      RotationMatrix :> {{0.893932961776235, 0.4482006914876052, 
       0.}, {-0.4482006914876052, 0.893932961776235, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08305120407046669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28629620467088107`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.12305773283712, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20557137907765444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.893932961776235, 0.4482006914876052, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.634981857793197, 0.8273299019140062, 0.}, 
      Optica`Optica`RayEnd :> {7.8600772293281915`, 0.9108912178091552, 0.}, 
      RotationMatrix :> {{0.9374871593797277, 0.34801986437289506`, 
       0.}, {-0.34801986437289506`, 0.9374871593797277, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08205377451641607, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24010501827451688`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.478413159883406`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0436573213540275, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9374871593797277, 0.34801986437289506`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.842566133514247, 1.440068636143774, 0.}, 
      Optica`Optica`RayEnd :> {4.720940674311308, 1.5505265746309072`, 0.}, 
      RotationMatrix :> {{-0.7402752269538942, 0.6723039404602349, 
       0.}, {-0.6723039404602349, -0.7402752269538942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05142209521165748, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16429762171484166`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.82755231150442, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2384239020680438, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7402752269538942, 0.6723039404602349, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.720940674311308, 1.5505265746309072`, 0.}, 
      Optica`Optica`RayEnd :> {4.563509470794093, 1.7232149979237499`, 0.}, 
      RotationMatrix :> {{-0.673707106878165, 0.7389984669414758, 
       0.}, {-0.7389984669414758, -0.673707106878165, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05096531262506663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2336790007258816, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.173397232578724`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05931126402142739, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.673707106878165, 0.7389984669414758, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.588794290327433, 0.7038109943929166, 0.}, 
      Optica`Optica`RayEnd :> {4.405729173165847, 0.664674750076516, 0.}, 
      RotationMatrix :> {{-0.9779029828102619, -0.20905921699554758`, 0.}, {
       0.20905921699554758`, -0.9779029828102619, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012963866336481724`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18720171671375826`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.061364494437905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.257841331174208, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9779029828102619, -0.20905921699554758`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.405729173165847, 0.664674750076516, 0.}, 
      Optica`Optica`RayEnd :> {4.1420754931227135`, 0.6299410302479087, 0.}, 
      RotationMatrix :> {{-0.9914336388450469, -0.13061140748980546`, 0.}, {
       0.13061140748980546`, -0.9914336388450469, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012877801990218384`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2659317474342229, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.454943480640555`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3471204228680364, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9914336388450469, -0.13061140748980546`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0400177056328745`, -0.6635405089458228, 0.},
       Optica`Optica`RayEnd :> {4.818081978692056, -1.098864073309862, 0.}, 
      RotationMatrix :> {{-0.45419730185583845`, -0.8909011230135894, 0.}, {
       0.8909011230135894, -0.45419730185583845`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008070172716757851, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.48863286072813555`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.274897097026136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11881300353489305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.45419730185583845`, -0.8909011230135894, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.818081978692056, -1.098864073309862, 0.}, 
      Optica`Optica`RayEnd :> {4.6730830867006965`, -1.3644129827131524`, 0.},
       RotationMatrix :> {{-0.47924444759406676`, -0.8776814681023271, 0.}, {
       0.8776814681023271, -0.47924444759406676`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008046922784696818, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3025572705522026, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.722681857443396`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34433972769576576`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.47924444759406676`, -0.8776814681023271, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.021149725198444, -0.07154571447836386, 0.}, 
      Optica`Optica`RayEnd :> {7.098059280499725, -0.2388328067404872, 0.}, 
      RotationMatrix :> {{0.4177150518985496, -0.9085780843809691, 0.}, {
       0.9085780843809691, 0.4177150518985496, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009314174107381465, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1841196647133516, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.295941868626253`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15236421645060802`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4177150518985496, -0.9085780843809691, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.098059280499725, -0.2388328067404872, 0.}, 
      Optica`Optica`RayEnd :> {7.212311557604752, -0.4341530931148644, 0.}, 
      RotationMatrix :> {{0.5049107632945319, -0.8631715479030415, 0.}, {
       0.8631715479030415, 0.5049107632945319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009224364734456833, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.226282118367874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.630839403810706`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33201084514457474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5049107632945319, -0.8631715479030415, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.728774910946679, 2.3223324043258624`, 0.}, 
      Optica`Optica`RayEnd :> {5.6539520195670985`, 2.4117933223224775`, 0.}, 
      RotationMatrix :> {{-0.641560410640963, 0.7670725125424569, 
       0.}, {-0.7670725125424569, -0.641560410640963, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18977331985818377`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11662641606084558`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.30480886337932, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21176477877069377`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.641560410640963, 0.7670725125424569, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.6539520195670985`, 2.4117933223224775`, 0.},
       Optica`Optica`RayEnd :> {5.435909779053422, 2.6593680888455133`, 0.}, 
      RotationMatrix :> {{-0.6609292633781169, 0.750448205281656, 
       0.}, {-0.750448205281656, -0.6609292633781169, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18924189136883612`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3299025366182558, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.793064617574338`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4225560099967061, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6609292633781169, 0.750448205281656, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.6258440355301405`, 1.8689699323790148`, 0.},
       Optica`Optica`RayEnd :> {6.697475812834526, 1.8279146946195524`, 0.}, 
      RotationMatrix :> {{0.8676017472591461, -0.49725969890277216`, 0.}, {
       0.49725969890277216`, 0.8676017472591461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03382484285031562, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08256297031521495, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.322083705716674`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42410882006911516`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8676017472591461, -0.49725969890277216`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.697475812834526, 1.8279146946195524`, 0.}, 
      Optica`Optica`RayEnd :> {6.8978100437530285`, 1.696982269817469, 0.}, 
      RotationMatrix :> {{0.837075512912143, -0.5470873656765174, 0.}, {
       0.5470873656765174, 0.837075512912143, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033673916425846, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23932635446657577`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.676286710327206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41278743980301075`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.837075512912143, -0.5470873656765174, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.472040952293647, 2.3458184217531763`, 0.}, 
      Optica`Optica`RayEnd :> {6.577898380087658, 2.1413614120070266`, 0.}, 
      RotationMatrix :> {{0.4597785724559023, -0.8880335941339221, 0.}, {
       0.8880335941339221, 0.4597785724559023, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014145852204755924`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23023567024573188`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.464337707390037`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07725327014695917, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4597785724559023, -0.8880335941339221, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.577898380087658, 2.1413614120070266`, 0.}, 
      Optica`Optica`RayEnd :> {6.665193389335898, 1.9205603235213684`, 0.}, 
      RotationMatrix :> {{0.36766455575464896`, -0.929958479955818, 0.}, {
       0.929958479955818, 0.36766455575464896`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014001271585279368`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2374311254155649, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.815735773005073`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2814394980199925, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36766455575464896`, -0.929958479955818, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.583810886957185, 2.633564846050262, 0.}, 
      Optica`Optica`RayEnd :> {6.585555138189024, 2.638730032428786, 0.}, 
      RotationMatrix :> {{0.31994344624651766`, 0.9474366423164667, 
       0.}, {-0.9474366423164667, 0.31994344624651766`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.935870919486937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005451748589642052, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.619990866109463`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2982527551791751, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.31994344624651766`, 0.9474366423164667, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.585555138189024, 2.638730032428786, 0.}, 
      Optica`Optica`RayEnd :> {6.692367912281009, 2.8987001271996897`, 0.}, 
      RotationMatrix :> {{0.38003862587697507`, 0.9249706172855111, 
       0.}, {-0.9249706172855111, 0.38003862587697507`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9164072744211462`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2810576789280412, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.035956230922963`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31267457278251465`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.38003862587697507`, 0.9249706172855111, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.692367912281009, 2.8987001271996897`, 0.}, 
      Optica`Optica`RayEnd :> {6.872093610858287, 2.6826165966951008`, 0.}, 
      RotationMatrix :> {{0.6394619754306459, -0.7688227246760692, 0.}, {
       0.7688227246760692, 0.6394619754306459, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019367393565932853`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2810576789280412, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.451921595736463`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3266812722080029, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6394619754306459, -0.7688227246760692, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.299114145669607, 2.5142405463846695`, 0.}, 
      Optica`Optica`RayEnd :> {6.215984381681101, 2.4749307830443343`, 0.}, 
      RotationMatrix :> {{-0.904021599748348, -0.42748678013294916`, 0.}, {
       0.42748678013294916`, -0.904021599748348, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014045073976597542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09195550638574033, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.192769515294822`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4119881020004386, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.904021599748348, -0.42748678013294916`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.215984381681101, 2.4749307830443343`, 0.}, 
      Optica`Optica`RayEnd :> {5.939781396097772, 2.361951907883309, 0.}, 
      RotationMatrix :> {{-0.9255625216682942, -0.37859479457994005`, 0.}, {
       0.37859479457994005`, -0.9255625216682942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013987573944107053`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2984163458622785, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.634425707170994`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3774034803713181, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9255625216682942, -0.37859479457994005`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8856226064772645`, 2.454866553037327, 0.}, 
      Optica`Optica`RayEnd :> {5.683048452564097, 2.531613486608514, 0.}, 
      RotationMatrix :> {{-0.9351375769650296, 0.35428478960854654`, 
       0.}, {-0.35428478960854654`, -0.9351375769650296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033159707030700245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2166249746594699, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.200303405109867`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39591031719591274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9351375769650296, 0.35428478960854654`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.683048452564097, 2.531613486608514, 0.}, 
      Optica`Optica`RayEnd :> {5.391351704172249, 2.625593379193287, 0.}, 
      RotationMatrix :> {{-0.9518189895454611, 0.30666041665114885`, 
       0.}, {-0.30666041665114885`, -0.9518189895454611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03303044008086781, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.306462417324902, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.653867782750723`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34329127605646426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9518189895454611, 0.30666041665114885`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.354603703684484, 1.6013214427552687`, 0.}, 
      Optica`Optica`RayEnd :> {7.356213552333505, 1.6010458639601983`, 0.}, 
      RotationMatrix :> {{0.985662529018893, -0.1687287138814219, 0.}, {
       0.1687287138814219, 0.985662529018893, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17613864729749557`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001633265546396514, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.07433318231679, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28117393291136483`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.985662529018893, -0.1687287138814219, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.356213552333505, 1.6010458639601983`, 0.}, 
      Optica`Optica`RayEnd :> {7.653693099468152, 1.5369387176341482`, 0.}, 
      RotationMatrix :> {{0.9775583522657434, -0.2106648236310075, 0.}, {
       0.2106648236310075, 0.9775583522657434, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17552946217379214`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3043087366039695, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.524710112490665`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38360668169202117`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9775583522657434, -0.2106648236310075, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.161374580802137, 0.6278061110068232, 0.}, 
      Optica`Optica`RayEnd :> {5.155851148044681, 0.62117069692608, 0.}, 
      RotationMatrix :> {{-0.6397687619377657, -0.7685674539353179, 0.}, {
       0.7685674539353179, -0.6397687619377657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01272723329937115, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008633483042728039, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.100032155443193`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24215262722774614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6397687619377657, -0.7685674539353179, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.155851148044681, 0.62117069692608, 0.}, 
      Optica`Optica`RayEnd :> {4.963243164986898, 0.40461823168334243`, 0.}, 
      RotationMatrix :> {{-0.664589139688411, -0.7472089904492693, 0.}, {
       0.7472089904492693, -0.664589139688411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012688689233488683`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28981512269081816`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.528958537025604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40621819769638495`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.664589139688411, -0.7472089904492693, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.929742957745927, 0.6652030754613594, 0.}, 
      Optica`Optica`RayEnd :> {7.943743831431117, 0.6599192684195407, 0.}, 
      RotationMatrix :> {{0.9355915983682046, -0.3530840708143414, 0.}, {
       0.3530840708143414, 0.9355915983682046, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08141766170943962, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01496472788940086, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.174537875725788`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4184286972307555, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9355915983682046, -0.3530840708143414, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.943743831431117, 0.6599192684195407, 0.}, 
      Optica`Optica`RayEnd :> {8.18182694304322, 0.5465277883779298, 0.}, 
      RotationMatrix :> {{0.9028331827585994, -0.4299909814286531, 0.}, {
       0.4299909814286531, 0.9028331827585994, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08083291346468757, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2637066472065659, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.564823713591505`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37007219395645174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9028331827585994, -0.4299909814286531, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.934429269750753, 1.1647759852781359`, 0.}, 
      Optica`Optica`RayEnd :> {3.8711843852292245`, 1.1630018869658185`, 0.}, 
      RotationMatrix :> {{-0.9996067956140623, -0.02804022400382912, 0.}, {
       0.02804022400382912, -0.9996067956140623, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08873510210998069, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06326976246962861, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.819535435939782`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.003169483831530707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9996067956140623, -0.02804022400382912, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8711843852292245`, 1.1630018869658185`, 0.},
       Optica`Optica`RayEnd :> {3.693844003873882, 1.1857485126662142`, 0.}, 
      RotationMatrix :> {{-0.9918741290460972, 0.12722308017433315`, 
       0.}, {-0.12722308017433315`, -0.9918741290460972, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08613915523312513, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1787932320867104, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.084149419428114`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35811985627318654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9918741290460972, 0.12722308017433315`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.201877408545196, 2.010677723111943, 0.}, 
      Optica`Optica`RayEnd :> {4.220711907001162, 2.085100957738307, 0.}, 
      RotationMatrix :> {{0.2453382967133802, 0.9694375277271751, 
       0.}, {-0.9694375277271751, 0.2453382967133802, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0090322433203985, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07676950035227906, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.58755030944653, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2965461697084588, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2453382967133802, 0.9694375277271751, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.220711907001162, 2.085100957738307, 0.}, 
      Optica`Optica`RayEnd :> {4.2970211362664825`, 2.4039905965296344`, 0.}, 
      RotationMatrix :> {{0.23272613805335798`, 0.972542309962281, 
       0.}, {-0.972542309962281, 0.23272613805335798`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009009215361748977, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32789281815790106`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.072831680320224`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08219250258345595, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.23272613805335798`, 0.972542309962281, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.055325171769849, 2.140045002997775, 0.}, 
      Optica`Optica`RayEnd :> {3.8070783438029028`, 2.2959531760368335`, 0.}, 
      RotationMatrix :> {{-0.8468404285209505, 0.5318470537875085, 
       0.}, {-0.5318470537875085, -0.8468404285209505, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25532326349488754`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2931447526667114, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.16680741184884, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19777270721870926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8468404285209505, 0.5318470537875085, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8070783438029028`, 2.2959531760368335`, 0.},
       Optica`Optica`RayEnd :> {3.675134321503202, 2.346331015390589, 0.}, 
      RotationMatrix :> {{-0.9342202438713691, 0.3566967002103044, 
       0.}, {-0.3566967002103044, -0.9342202438713691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24035783209437522`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14123438575140534`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.37583430276092, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3313430962773228, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9342202438713691, 0.3566967002103044, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.675134321503202, 2.346331015390589, 0.}, 
      Optica`Optica`RayEnd :> {3.573380697926003, 2.248385357970332, 0.}, 
      RotationMatrix :> {{-0.7204592779289716, -0.6934972450169251, 0.}, {
       0.6934972450169251, -0.7204592779289716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014088252666628965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14123438575140515`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.584861193673, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11833331167738906`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7204592779289716, -0.6934972450169251, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8871266030435763`, 2.040432289515257, 0.}, 
      Optica`Optica`RayEnd :> {3.7699581791501924`, 1.9423212098599785`, 0.}, 
      RotationMatrix :> {{-0.7667042521487605, -0.6420004592965722, 0.}, {
       0.6420004592965722, -0.7667042521487605, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008444652544654986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1528208870173973, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.26808769617973, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2518331317774399, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7667042521487605, -0.6420004592965722, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7699581791501924`, 1.9423212098599785`, 0.},
       Optica`Optica`RayEnd :> {3.608033170338925, 1.7741434996327017`, 0.}, 
      RotationMatrix :> {{-0.6935885736702984, -0.7203713559505269, 0.}, {
       0.7203713559505269, -0.6935885736702984, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008347331480467958, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2334597410600356, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.613608112948583`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.016816929181173057`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6935885736702984, -0.7203713559505269, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7442304120272185`, -0.9084906570121896, 0.},
       Optica`Optica`RayEnd :> {2.6368300877082387`, -0.932727835487602, 0.}, 
      RotationMatrix :> {{-0.9754693042652878, -0.22013549562983972`, 0.}, {
       0.22013549562983972`, -0.9754693042652878, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014021797280334971`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11010118293765514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.952128116422863`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22134473650000538`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9754693042652878, -0.22013549562983972`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6368300877082387`, -0.932727835487602, 0.}, 
      Optica`Optica`RayEnd :> {2.30918847720457, -1.0191991468394757`, 0.}, 
      RotationMatrix :> {{-0.9668928365428473, -0.2551827632151642, 0.}, {
       0.2551827632151642, -0.9668928365428473, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013977533816082882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.338860314318969, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.453641381614936`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03623234819835638, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9668928365428473, -0.2551827632151642, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9103644313012382`, -2.63264420570771, 0.}, 
      Optica`Optica`RayEnd :> {3.8531464172669496`, -2.667180887666956, 0.}, 
      RotationMatrix :> {{-0.8561309317108144, -0.5167589648646382, 0.}, {
       0.5167589648646382, -0.8561309317108144, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012327639918492539`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06683325168493706, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.427649795076652`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2501257513969146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.8561309317108144, -0.5167589648646382, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8531464172669496`, -2.667180887666956, 0.}, 
      Optica`Optica`RayEnd :> {3.589108696355187, -2.8258811301481175`, 0.}, 
      RotationMatrix :> {{-0.8570951026520814, -0.515158213571149, 0.}, {
       0.515158213571149, -0.8570951026520814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012297234943880136`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30806117091879254`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.883580328036466`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2652016058101836, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.8570951026520814, -0.515158213571149, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.275954050371112, -2.8917611585853704`, 0.}, 
      Optica`Optica`RayEnd :> {5.232309234713183, -3.089513230492525, 0.}, 
      RotationMatrix :> {{-0.21551812384600966`, -0.9764998403962469, 0.}, {
       0.9764998403962469, -0.21551812384600966`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008869027238572677, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2025111154415652, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.34580144360916, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2989767468319127, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.21551812384600966`, -0.9764998403962469, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.232309234713183, -3.089513230492525, 0.}, 
      Optica`Optica`RayEnd :> {5.172461097552453, -3.4101727141824996`, 0.}, 
      RotationMatrix :> {{-0.18347252564124686`, -0.98302483810676, 0.}, {
       0.98302483810676, -0.18347252564124686`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008842181070358002, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3261967259215377, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.828572597973036`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42341086758475727`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.18347252564124686`, -0.98302483810676, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.402864922916759, -3.1706687047615048`, 0.}, 
      Optica`Optica`RayEnd :> {6.477872133810045, -3.3062105155783237`, 0.}, 
      RotationMatrix :> {{0.48419302735656633`, -0.8749612061453256, 0.}, {
       0.8749612061453256, 0.48419302735656633`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01772654827632767, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15491179479139797`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.88976612132318, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2652862888224462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.48419302735656633`, -0.8749612061453256, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.477872133810045, -3.3062105155783237`, 0.}, 
      Optica`Optica`RayEnd :> {6.601170038740591, -3.55634550583027, 0.}, 
      RotationMatrix :> {{0.442129979403896, -0.8969509915888995, 0.}, {
       0.8969509915888995, 0.442129979403896, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017660669639167025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27887252770504867`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.302497462326652`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17457695310418353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.442129979403896, -0.8969509915888995, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.065516021771263, -2.5757373891090496`, 0.}, 
      Optica`Optica`RayEnd :> {7.330498288687872, -2.5789224955651515`, 0.}, 
      RotationMatrix :> {{0.9999277667377791, -0.012019205747357237`, 0.}, {
       0.012019205747357237`, 0.9999277667377791, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09095527827165098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.265001408832863, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.169836476654805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12302103775279374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9999277667377791, -0.012019205747357237`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.330498288687872, -2.5789224955651515`, 0.}, 
      Optica`Optica`RayEnd :> {7.638935893568386, -2.5748739356299155`, 0.}, 
      RotationMatrix :> {{0.9999138648545481, 0.01312489510967778, 
       0.}, {-0.01312489510967778, 0.9999138648545481, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09070150533705124, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30846417448705005`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.62636345489564, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36722415684388077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999138648545481, 0.01312489510967778, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.907913549349928, -1.128131966537967, 0.}, 
      Optica`Optica`RayEnd :> {7.925750905818889, -1.1176724675766507`, 0.}, 
      RotationMatrix :> {{0.8626321846492808, 0.5058317052214195, 
       0.}, {-0.5058317052214195, 0.8626321846492808, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013388151781880133`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.020677823974552454`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.557428746205577`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3101158213115245, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8626321846492808, 0.5058317052214195, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.925750905818889, -1.1176724675766507`, 0.}, 
      Optica`Optica`RayEnd :> {8.17711503024882, -0.9657857867526604, 0.}, 
      RotationMatrix :> {{0.8558841096733909, 0.5171676621837321, 
       0.}, {-0.5171676621837321, 0.8558841096733909, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013353982074667318`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29368943948013176`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.992089116636173`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2942324078144845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8558841096733909, 0.5171676621837321, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.9396332096186235`, -1.3113566863266601`, 
       0.}, Optica`Optica`RayEnd :> {8.12417255435784, -1.2896757064740478`, 
       0.}, RotationMatrix :> {{0.9931690347974079, 0.11668448191419796`, 
       0.}, {-0.11668448191419796`, 0.9931690347974079, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010926807785597252`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18580859679828715`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.37138906647465, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20980926612965756`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9931690347974079, 0.11668448191419796`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.12417255435784, -1.2896757064740478`, 0.}, 
      Optica`Optica`RayEnd :> {8.40513098295746, -1.2478631540215561`, 0.}, 
      RotationMatrix :> {{0.9891067500316196, 0.14719998995206032`, 
       0.}, {-0.14719998995206032`, 0.9891067500316196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010894464334518713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2840526855070387, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.791787041025067`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39464326730127647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9891067500316196, 0.14719998995206032`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.195908819104282, -1.8418698879684676`, 0.}, 
      Optica`Optica`RayEnd :> {2.1672204988726462`, -1.8549278598035843`, 0.},
       RotationMatrix :> {{-0.9101533076202891, -0.4142715976600941, 0.}, {
       0.4142715976600941, -0.9101533076202891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16946302924391063`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0315203164032275, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.38511714926715, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2194773137373501, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9101533076202891, -0.4142715976600941, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1672204988726462`, -1.8549278598035843`, 
       0.}, Optica`Optica`RayEnd :> {
       1.8631456608056345`, -1.9991716919118454`, 0.}, 
      RotationMatrix :> {{-0.9034981553000941, -0.42859197772394964`, 0.}, {
       0.42859197772394964`, -0.9034981553000941, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1690240168438554, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3365528045444812, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.88321529999298, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.144463053777111, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9034981553000941, -0.42859197772394964`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.507286540201194, 2.678637279603003, 0.}, 
      Optica`Optica`RayEnd :> {5.573136455120478, 2.6991648220460918`, 0.}, 
      RotationMatrix :> {{0.9546884156727704, 0.29760717225936417`, 
       0.}, {-0.29760717225936417`, 0.9546884156727704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012347044132055179`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06897529480640045, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.386626647452047`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2964945010933336, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9546884156727704, 0.29760717225936417`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.573136455120478, 2.6991648220460918`, 0.}, 
      Optica`Optica`RayEnd :> {5.859102310574856, 2.798613824550409, 0.}, 
      RotationMatrix :> {{0.9445146091520907, 0.32846940968417854`, 
       0.}, {-0.32846940968417854`, 0.9445146091520907, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012309762312982598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30276488334160795`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.834718674797628`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4241054299314752, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9445146091520907, 0.32846940968417854`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0728522647269667`, 3.096887373596184, 0.}, 
      Optica`Optica`RayEnd :> {2.0379501329067837`, 3.357334989361348, 0.}, 
      RotationMatrix :> {{-0.13282095326280763`, 0.9911400478107818, 
       0.}, {-0.9911400478107818, -0.13282095326280763`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01369256098645535, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26277579676095003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.882638716269343`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1529552981465409, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13282095326280763`, 0.9911400478107818, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0379501329067837`, 3.357334989361348, 0.}, 
      Optica`Optica`RayEnd :> {2.0003485458539485`, 3.6568472194308046`, 0.}, 
      RotationMatrix :> {{-0.1245649482614858, 0.9922114561244559, 
       0.}, {-0.9922114561244559, -0.1245649482614858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013658338411207886`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3018633056700847, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.287135545867255`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26587832448302035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.1245649482614858, 0.9922114561244559, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.16312011496545, -3.0916553002213503`, 0.}, 
      Optica`Optica`RayEnd :> {4.204481116344392, -3.110912839801599, 0.}, 
      RotationMatrix :> {{0.906554550533619, -0.42208867185318727`, 0.}, {
       0.42208867185318727`, 0.906554550533619, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02762399913733004, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.045624393319294736`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.252273875066036`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28641713379642353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.906554550533619, -0.42208867185318727`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.204481116344392, -3.110912839801599, 0.}, 
      Optica`Optica`RayEnd :> {4.346900401770584, -3.2046491384338243`, 0.}, 
      RotationMatrix :> {{0.8353109600993406, -0.549777773230164, 0.}, {
       0.549777773230164, 0.8353109600993406, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02694271009682234, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17049852357887652`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.504611689962774`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.332299978648132, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8353109600993406, -0.549777773230164, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.4193349084766895`, -1.7443209047785018`, 
       0.}, Optica`Optica`RayEnd :> {4.617159875700941, -1.7671299287408804`, 
       0.}, RotationMatrix :> {{0.9934186153169569, -0.11454018832593424`, 
       0.}, {0.11454018832593424`, 0.9934186153169569, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008450760051046375, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19913555491521973`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.334505568200305`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20704344007000697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9934186153169569, -0.11454018832593424`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.617159875700941, -1.7671299287408804`, 0.}, 
      Optica`Optica`RayEnd :> {4.8834535086676665`, -1.782800960434623, 0.}, 
      RotationMatrix :> {{0.9982729004251172, -0.058747053345887125`, 0.}, {
       0.058747053345887125`, 0.9982729004251172, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008414614059508836, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2667543442813321, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.729301997736677`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24089503106559118`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9982729004251172, -0.058747053345887125`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.45669261763965, 2.226579398023197, 0.}, 
      Optica`Optica`RayEnd :> {3.5395831023513624`, 2.3579201842494855`, 0.}, 
      RotationMatrix :> {{0.5337094751864679, 0.8456678994121661, 
       0.}, {-0.8456678994121661, 0.5337094751864679, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009132608605665917, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1553101238885675, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.773773337619751`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04213175448860568, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5337094751864679, 0.8456678994121661, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5395831023513624`, 2.3579201842494855`, 0.},
       Optica`Optica`RayEnd :> {3.6246736316529993`, 2.5441255502263878`, 0.},
       RotationMatrix :> {{0.4156307765101584, 0.9095334285322136, 
       0.}, {-0.9095334285322136, 0.4156307765101584, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008953168700008701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20472624769536715`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.076768184208895`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3491103010786065, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.4156307765101584, 0.9095334285322136, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.332308243559459, 2.3879252482139632`, 0.}, 
      Optica`Optica`RayEnd :> {3.2156463427626463`, 2.5015423567450736`, 0.}, 
      RotationMatrix :> {{-0.7163936602428322, 0.6976962975133792, 
       0.}, {-0.6976962975133792, -0.7163936602428322, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3847505289119267, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1628460820790463, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.085384813141964`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4314431319893003, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7163936602428322, 0.6976962975133792, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2156463427626463`, 2.5015423567450736`, 0.},
       Optica`Optica`RayEnd :> {2.990766656968944, 2.68440669863797, 0.}, 
      RotationMatrix :> {{-0.7758613387984399, 0.6309034656410542, 
       0.}, {-0.6309034656410542, -0.7758613387984399, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3816464895602496, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2898452011308737, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.514355710815657`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33071218127597535`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7758613387984399, 0.6309034656410542, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1486487051213468`, 2.299759893171285, 0.}, 
      Optica`Optica`RayEnd :> {2.610436075581841, 1.9398455583721346`, 0.}, 
      RotationMatrix :> {{-0.8312611145805722, -0.5558821452306824, 0.}, {
       0.5558821452306824, -0.8312611145805722, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00872318817885908, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6474651828397756, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.03628769970831, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37641703803505566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8312611145805722, -0.5558821452306824, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.610436075581841, 1.9398455583721346`, 0.}, 
      Optica`Optica`RayEnd :> {2.427325078483299, 1.8400499517806694`, 0.}, 
      RotationMatrix :> {{-0.8780630737863054, -0.4785449179052535, 0.}, {
       0.4785449179052535, -0.8780630737863054, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008651437781788993, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20853968532003855`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.344926433981968`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39214820526829297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8780630737863054, -0.4785449179052535, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.888010749790684, 2.239795602771776, 0.}, 
      Optica`Optica`RayEnd :> {5.352094276162099, 2.5575525177369407`, 0.}, 
      RotationMatrix :> {{0.8251198862797183, 0.564957673871012, 
       0.}, {-0.564957673871012, 0.8251198862797183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009488716789597621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5624437540390202, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.962846662532595`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14290258356349017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8251198862797183, 0.564957673871012, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.352094276162099, 2.5575525177369407`, 0.}, 
      Optica`Optica`RayEnd :> {5.5648705308709445`, 2.67124674879148, 0.}, 
      RotationMatrix :> {{0.8819850976427333, 0.47127729367765875`, 
       0.}, {-0.47127729367765875`, 0.8819850976427333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00937395846192137, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2412469953035826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.3198922155819, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11112707057389765`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8819850976427333, 0.47127729367765875`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4125453660218863`, -0.8593377419620716, 0.},
       Optica`Optica`RayEnd :> {3.353904435352324, -0.8641742816307323, 0.}, 
      RotationMatrix :> {{-0.9966160107848178, -0.08219809637307021, 0.}, {
       0.08219809637307021, -0.9966160107848178, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026194550921173086`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058840044746404994`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.322702705691219`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.255050527271154, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9966160107848178, -0.08219809637307021, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.353904435352324, -0.8641742816307323, 0.}, 
      Optica`Optica`RayEnd :> {3.0780660610831423`, -0.8695988186114041, 0.}, 
      RotationMatrix :> {{-0.9998066874553039, -0.019661834086694537`, 0.}, {
       0.019661834086694537`, -0.9998066874553039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02606860083849863, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2758917075972379, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.73102243293513, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2618640892017596, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9998066874553039, -0.019661834086694537`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.422089061304332, -1.0631783556271799`, 0.}, 
      Optica`Optica`RayEnd :> {3.093326910640336, -1.0721338202571287`, 0.}, 
      RotationMatrix :> {{-0.9996291988972409, -0.027229849651815907`, 0.}, {
       0.027229849651815907`, -0.9996291988972409, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013259526748768102`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32888410125142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.661981460496943`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22985220725035893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9996291988972409, -0.027229849651815907`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.093326910640336, -1.0721338202571287`, 0.}, 
      Optica`Optica`RayEnd :> {2.844101538872602, -1.0632252089375354`, 0.}, 
      RotationMatrix :> {{-0.9993617518195836, 0.035722387939401565`, 
       0.}, {-0.035722387939401565`, -0.9993617518195836, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013195382163280214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2493845409972494, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.031070581172873`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23886775847440142`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9993617518195836, 0.035722387939401565`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.9164044126609205`, 0.6481537547206977, 0.}, 
      Optica`Optica`RayEnd :> {4.891964282972589, 0.6622910721049998, 0.}, 
      RotationMatrix :> {{-0.8656140679128932, 0.5007117788022301, 
       0.}, {-0.5007117788022301, -0.8656140679128932, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009347203982220907, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028234441414820517`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.682661761330877`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31503114351604095`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8656140679128932, 0.5007117788022301, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.891964282972589, 0.6622910721049998, 0.}, 
      Optica`Optica`RayEnd :> {4.620435270414352, 0.8139180346299864, 0.}, 
      RotationMatrix :> {{-0.8730938402384506, 0.48755219837231295`, 
       0.}, {-0.48755219837231295`, -0.8730938402384506, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009323085692243398, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31099636722219953`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.142936384819734`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.303787466415339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8730938402384506, 0.48755219837231295`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.150256002333505, 0.05231239248044925, 0.}, 
      Optica`Optica`RayEnd :> {8.164078058226643, 0.069870449653405, 0.}, 
      RotationMatrix :> {{0.6185528529147435, 0.7857431947850589, 
       0.}, {-0.7857431947850589, 0.6185528529147435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09786702823869965, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022345796043144555`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.162954887734417`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39369446430022625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.6185528529147435, 0.7857431947850589, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.164078058226643, 0.069870449653405, 0.}, 
      Optica`Optica`RayEnd :> {8.347403889598631, 0.3164039243675053, 0.}, 
      RotationMatrix :> {{0.5967154851049246, 0.8024528832498479, 
       0.}, {-0.8024528832498479, 0.5967154851049246, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09758750040512609, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3072248600013327, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.61764768053639, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1818522409356843, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.5967154851049246, 0.8024528832498479, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.574921277472411, 0.0874755916513075, 0.}, 
      Optica`Optica`RayEnd :> {7.596749065410667, 0.14135927252437472`, 0.}, 
      RotationMatrix :> {{0.3754547321525647, 0.9268407328685145, 
       0.}, {-0.9268407328685145, 0.3754547321525647, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019441821985911233`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0581369365438877, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.370226275289069`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20483538927066952`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3754547321525647, 0.9268407328685145, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.596749065410667, 0.14135927252437472`, 0.}, 
      Optica`Optica`RayEnd :> {7.71725703465744, 0.3774451573715266, 0.}, 
      RotationMatrix :> {{0.4546379289074377, 0.890676346154289, 
       0.}, {-0.890676346154289, 0.4546379289074377, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019292251155254413`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2650636068494575, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.762520413426266`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3328272989911809, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.4546379289074377, 0.890676346154289, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.093124318394603, -0.6399737634313856, 0.}, 
      Optica`Optica`RayEnd :> {7.067044428207292, -0.5757241701134088, 0.}, 
      RotationMatrix :> {{-0.3761108048562297, 0.9265746934113832, 
       0.}, {-0.9265746934113832, -0.3761108048562297, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013442509710075531`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06934097571932175, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.150042315962574`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0985376968777724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.3761108048562297, 0.9265746934113832, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.067044428207292, -0.5757241701134088, 0.}, 
      Optica`Optica`RayEnd :> {6.939023855942025, -0.28788288655888045`, 0.}, 
      RotationMatrix :> {{-0.4063799677637056, 0.9137041763067352, 
       0.}, {-0.9137041763067352, -0.4063799677637056, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013401727792807969`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31502677892751424`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.616281948775296`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29803730126526273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4063799677637056, 0.9137041763067352, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.095556880334739, -1.782516190304264, 0.}, 
      Optica`Optica`RayEnd :> {6.836140707000324, -1.8165518686022184`, 0.}, 
      RotationMatrix :> {{-0.9915026869781982, -0.13008620878099555`, 0.}, {
       0.13008620878099555`, -0.9915026869781982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02171513936557199, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2616394052597439, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.694621339300067`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24200760765449436`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9915026869781982, -0.13008620878099555`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.836140707000324, -1.8165518686022184`, 0.}, 
      Optica`Optica`RayEnd :> {6.603624631246455, -1.8298685568134114`, 0.}, 
      RotationMatrix :> {{-0.9983639758675461, -0.05717841979230881, 0.}, {
       0.05717841979230881, -0.9983639758675461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021587779468350228`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2328971010315358, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.03930904882674, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3051262849036108, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9983639758675461, -0.05717841979230881, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.863139321655691, -1.9772863051707465`, 0.}, 
      Optica`Optica`RayEnd :> {7.7142040229293976`, -2.10792373154992, 0.}, 
      RotationMatrix :> {{-0.7517780614626389, -0.6594162162879195, 0.}, {
       0.6594162162879195, -0.7517780614626389, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04371431905767775, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19811072756835818`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.263842555629806`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36966509257863345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7517780614626389, -0.6594162162879195, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.7142040229293976`, -2.10792373154992, 0.}, 
      Optica`Optica`RayEnd :> {7.608643324015406, -2.241089960054466, 0.}, 
      RotationMatrix :> {{-0.6211999935831811, -0.7836520707381913, 0.}, {
       0.7836520707381913, -0.6211999935831811, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04173424052011483, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16993029620799016`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.515339394017632`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03907315642172593, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6211999935831811, -0.7836520707381913, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.022041265246742, -2.1317672179825253`, 0.}, 
      Optica`Optica`RayEnd :> {8.079759756486173, -2.178409227415667, 0.}, 
      RotationMatrix :> {{0.7777881546394693, -0.6285265201266602, 0.}, {
       0.6285265201266602, 0.7777881546394693, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.100675908293293, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07420849867041822, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.425807014102384`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16379210594986893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7777881546394693, -0.6285265201266602, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.079759756486173, -2.178409227415667, 0.}, 
      Optica`Optica`RayEnd :> {8.33682100981092, -2.372116296911316, 0.}, 
      RotationMatrix :> {{0.7986392118474391, -0.6018101106658986, 0.}, {
       0.6018101106658986, 0.7986392118474391, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.085012741178588, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32187406968173615`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.902180637231353`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.044646344060852446`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7986392118474391, -0.6018101106658986, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.33682100981092, -2.372116296911316, 0.}, 
      Optica`Optica`RayEnd :> {8.241396205327685, -2.0647126153737987`, 0.}, 
      RotationMatrix :> {{-0.2964662688659263, 0.9550433243705314, 
       0.}, {-0.9550433243705314, -0.2964662688659263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015615068625707015`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3218740696817361, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.37855426036032, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24520890687167102`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2964662688659263, 0.9550433243705314, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.147211336256754, -1.948883010289454, 0.}, 
      Optica`Optica`RayEnd :> {8.177544675768603, -1.8944705060288458`, 0.}, 
      RotationMatrix :> {{0.48692020792912327`, 0.8734464557774902, 
       0.}, {-0.8734464557774902, 0.48692020792912327`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04298070795175712, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06229632497869996, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.737838146551299`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3454113891774642, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.48692020792912327`, 0.8734464557774902, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.177544675768603, -1.8944705060288458`, 0.}, 
      Optica`Optica`RayEnd :> {8.311903601845028, -1.6379705011059962`, 0.}, 
      RotationMatrix :> {{0.4640118201498591, 0.8858290076313909, 
       0.}, {-0.8858290076313909, 0.4640118201498591, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04285973902290488, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28955927466035736`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.16638587304863, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10051588586443531`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4640118201498591, 0.8858290076313909, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.981703858840445, -1.3971231822573906`, 0.}, 
      Optica`Optica`RayEnd :> {8.05729602739823, -1.1730735280725026`, 0.}, 
      RotationMatrix :> {{0.3196852847316798, 0.9475237826704008, 
       0.}, {-0.9475237826704008, 0.3196852847316798, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021504471470806186`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2364580797681406, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.053776484109363`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20345165643578467`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3196852847316798, 0.9475237826704008, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.05729602739823, -1.1730735280725026`, 0.}, 
      Optica`Optica`RayEnd :> {8.13369358484671, -0.909805201904108, 0.}, 
      RotationMatrix :> {{0.2786918270180039, 0.9603805837028189, 
       0.}, {-0.9603805837028189, 0.2786918270180039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02142982434960078, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.274129163621097, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.459487646268588`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07264294776889381, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2786918270180039, 0.9603805837028189, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.81221724320332, -0.9879310810174107, 0.}, 
      Optica`Optica`RayEnd :> {6.775781437771898, -0.9434245706739666, 0.}, 
      RotationMatrix :> {{-0.633460501286603, 0.7737750275821295, 
       0.}, {-0.7737750275821295, -0.633460501286603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013672396952207486`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05751866984195245, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.90867076279409, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21786678874391158`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.633460501286603, 0.7737750275821295, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.775781437771898, -0.9434245706739666, 0.}, 
      Optica`Optica`RayEnd :> {6.631251815124599, -0.7413559237850313, 0.}, 
      RotationMatrix :> {{-0.5817574793312943, 0.8133623025700775, 
       0.}, {-0.8133623025700775, -0.5817574793312943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013603579244059243`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2484362088708006, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.276356351922875`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19552234882288427`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5817574793312943, 0.8133623025700775, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.603984831371815, -1.169398971513567, 0.}, 
      Optica`Optica`RayEnd :> {5.574104318307114, -1.1649342600888264`, 0.}, 
      RotationMatrix :> {{-0.9890205136377064, 0.14777829205876963`, 
       0.}, {-0.14777829205876963`, -0.9890205136377064, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019780015412603533`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.030212227807891474`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.52195634836913, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0028833069767945363`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9890205136377064, 0.14777829205876963`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.574104318307114, -1.1649342600888264`, 0.}, 
      Optica`Optica`RayEnd :> {5.35587456765623, -1.1072220852942924`, 0.}, 
      RotationMatrix :> {{-0.9667649525711814, 0.2556668271012899, 
       0.}, {-0.2556668271012899, -0.9667649525711814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019538039861123544`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22573196315245736`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.856039653834767`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2503278691151229, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9667649525711814, 0.2556668271012899, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.930221352069838, -2.022155952212378, 0.}, 
      Optica`Optica`RayEnd :> {5.770604205594284, -2.118585400139093, 0.}, 
      RotationMatrix :> {{-0.8559295719511272, -0.517092417136009, 0.}, {
       0.517092417136009, -0.8559295719511272, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09514781052627358, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18648397217039694`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.727661194298111`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09511050747581218, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8559295719511272, -0.517092417136009, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.770604205594284, -2.118585400139093, 0.}, 
      Optica`Optica`RayEnd :> {5.56054423222673, -2.2685416838301906`, 0.}, 
      RotationMatrix :> {{-0.8138920576843389, -0.5810161085876645, 0.}, {
       0.5810161085876645, -0.8138920576843389, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0945532599995545, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2580931603697049, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.109639071645276`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0006841820076440297, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8138920576843389, -0.5810161085876645, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.561283549930273, -0.227086100596803, 0.}, 
      Optica`Optica`RayEnd :> {4.41769083502157, -0.14698272811855934`, 0.}, 
      RotationMatrix :> {{-0.8733048297376845, 0.4871741725059262, 
       0.}, {-0.4871741725059262, -0.8733048297376845, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013288937657603401`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16442450564693942`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.597310676963808`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23951891215589866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8733048297376845, 0.4871741725059262, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.41769083502157, -0.14698272811855936`, 0.}, 
      Optica`Optica`RayEnd :> {4.212331653106352, -0.06959946598404876, 0.}, 
      RotationMatrix :> {{-0.9357683423156423, 0.35261538468965703`, 
       0.}, {-0.35261538468965703`, -0.9357683423156423, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012947902499315668`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21945514998620091`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.922104298943385`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36762204148074035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9357683423156423, 0.35261538468965703`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.407879210301261, 1.8004025358513511`, 0.}, 
      Optica`Optica`RayEnd :> {6.412338370545742, 1.87009568796768, 0.}, 
      RotationMatrix :> {{0.06385219490892266, 0.9979593665101363, 
       0.}, {-0.9979593665101363, 0.06385219490892266, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01193318496013604, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06983566110516692, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.101027422546288`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3734257481909907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06385219490892266, 0.9979593665101363, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.412338370545742, 1.87009568796768, 0.}, 
      Optica`Optica`RayEnd :> {6.448658799778517, 2.1357213457488884`, 0.}, 
      RotationMatrix :> {{0.1354748029281862, 0.9907807919875963, 
       0.}, {-0.9907807919875963, 0.1354748029281862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011864851132445337`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26809730258126907`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.497811430366568`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4150522367631313, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1354748029281862, 0.9907807919875963, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1079055127338115`, 2.388170150014077, 0.}, 
      Optica`Optica`RayEnd :> {7.1101305241034725`, 2.3966544690921925`, 0.}, 
      RotationMatrix :> {{0.2536717482099696, 0.9672903618666412, 
       0.}, {-0.9672903618666412, 0.2536717482099696, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0248984562135517, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.008771222595191574, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.990997270224325`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2278372362831523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2536717482099696, 0.9672903618666412, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1101305241034725`, 2.3966544690921925`, 0.},
       Optica`Optica`RayEnd :> {7.1162682073205294`, 2.5548130859784597`, 0.},
       RotationMatrix :> {{0.03877794896386383, 0.9992478524741275, 
       0.}, {-0.9992478524741275, 0.03877794896386383, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022851189005179948`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15827766504042798`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.225248214484157`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2616441177358119, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.03877794896386383, 0.9992478524741275, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8863540324988484`, 0.559232777351813, 0.}, 
      Optica`Optica`RayEnd :> {2.8356563595576576`, 0.5723412860644501, 0.}, 
      RotationMatrix :> {{-0.9681606052909278, 0.25032986710079935`, 
       0.}, {-0.25032986710079935`, -0.9681606052909278, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11035036088160324`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05236494096550905, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.8697471800437, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01853531620247255, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9681606052909278, 0.25032986710079935`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8356563595576576`, 0.5723412860644501, 0.}, 
      Optica`Optica`RayEnd :> {2.6055738337734273`, 0.6567341618634729, 0.}, 
      RotationMatrix :> {{-0.9388376901079143, 0.3443599739122355, 
       0.}, {-0.3443599739122355, -0.9388376901079143, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10928234430771655`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24507167554999135`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.232453259857685`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18599999927855626`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9388376901079143, 0.3443599739122355, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.2133081495809765`, -1.3706139949046245`, 
       0.}, Optica`Optica`RayEnd :> {4.108618644472275, -1.4426546388240173`, 
       0.}, RotationMatrix :> {{-0.8237971538565243, -0.566884687831564, 
       0.}, {0.566884687831564, -0.8237971538565243, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0418785046320254, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12708165428662596`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.121898730766114`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3558327540485184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8237971538565243, -0.566884687831564, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.108618644472275, -1.4426546388240173`, 0.}, 
      Optica`Optica`RayEnd :> {3.8962224611401854`, -1.5783964706025564`, 0.},
       RotationMatrix :> {{-0.8426165682041946, -0.5385139914503481, 0.}, {
       0.5385139914503481, -0.8426165682041946, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041749658315437824`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2520674187367975, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.494958510496575`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38601016896151724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8426165682041946, -0.5385139914503481, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.458210494903547, -2.6254920219548468`, 0.}, 
      Optica`Optica`RayEnd :> {5.407019887660409, -2.9505475865878963`, 0.}, 
      RotationMatrix :> {{-0.1555653793730551, -0.9878255983423981, 0.}, {
       0.9878255983423981, -0.1555653793730551, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023012613951906694`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3290616938642841, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.52403719127587, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1843230379758143, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1555653793730551, -0.9878255983423981, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.407019887660409, -2.9505475865878963`, 0.}, 
      Optica`Optica`RayEnd :> {5.421649245250298, -3.0825725534329287`, 0.}, 
      RotationMatrix :> {{0.11013344497570929`, -0.99391680954584, 0.}, {
       0.99391680954584, 0.11013344497570929`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019248099947778104`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13283301537616585`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.720630054032593`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28160554191830983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.11013344497570929`, -0.99391680954584, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.796596113038852, -1.4367323507430918`, 0.}, 
      Optica`Optica`RayEnd :> {6.821543249800346, -1.4628040299671872`, 0.}, 
      RotationMatrix :> {{0.6913530092336669, -0.7225171393285791, 0.}, {
       0.7225171393285791, 0.6913530092336669, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011817734145923898`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036084513162308075`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.253952935556073`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21062870937050487`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.6913530092336669, -0.7225171393285791, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.821543249800346, -1.4628040299671872`, 0.}, 
      Optica`Optica`RayEnd :> {7.016042773262057, -1.6516751997741703`, 0.}, 
      RotationMatrix :> {{0.717410668429018, -0.6966505098140888, 0.}, {
       0.6966505098140888, 0.717410668429018, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011780119441163816`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2711132298710099, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.655200515765168`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.029686086210345193`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.717410668429018, -0.6966505098140888, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.507576983832616, 1.6542440114158796`, 0.}, 
      Optica`Optica`RayEnd :> {4.430740033522393, 2.8184667495682527`, 0.}, 
      RotationMatrix :> {{-0.6790185060664495, 0.7341211537745567, 
       0.}, {-0.7341211537745567, -0.6790185060664495, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00957072377488993, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5858727570597932`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.694714822147947`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39937818410191106`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.6790185060664495, 0.7341211537745567, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.430740033522393, 2.8184667495682527`, 0.}, 
      Optica`Optica`RayEnd :> {4.262747380025582, 2.9608335378144637`, 0.}, 
      RotationMatrix :> {{-0.7628953032524637, 0.6465220462407532, 
       0.}, {-0.6465220462407532, -0.7628953032524637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009424671261420842, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22020407358730074`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.020616851057152`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26829443529558317`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7628953032524637, 0.6465220462407532, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9982269963100165`, 2.1711805332934513`, 0.},
       Optica`Optica`RayEnd :> {6.991086841474694, 2.3261666890661976`, 0.}, 
      RotationMatrix :> {{-0.046020818240224595`, 0.9989404808538392, 
       0.}, {-0.9989404808538392, -0.046020818240224595`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01604485245075161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15515054074119894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.726684218170469`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21798751225293936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.046020818240224595`, 0.9989404808538392, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.991086841474694, 2.3261666890661976`, 0.}, 
      Optica`Optica`RayEnd :> {6.976035586645406, 2.6360109109681593`, 0.}, 
      RotationMatrix :> {{-0.04851963288570492, 0.9988222290401009, 
       0.}, {-0.9988222290401009, -0.04851963288570492, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016005257171484762`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3102095777340993, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.185794393216934`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2605754002817038, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.04851963288570492, 0.9988222290401009, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.601329198023765, -1.6135517013908613`, 0.}, 
      Optica`Optica`RayEnd :> {7.600403197491476, -1.8782348697021982`, 0.}, 
      RotationMatrix :> {{-0.0034985030263823547`, -0.999993880219561, 0.}, {
       0.999993880219561, -0.0034985030263823547`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1290611972797337, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2646847881241257, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.823967576796832`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20889186604847446`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.0034985030263823547`, -0.999993880219561, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.600403197491476, -1.8782348697021982`, 0.}, 
      Optica`Optica`RayEnd :> {7.575596281441464, -2.0742213214166454`, 0.}, 
      RotationMatrix :> {{-0.12557273527339094`, -0.9920844158416955, 0.}, {
       0.9920844158416955, -0.12557273527339094`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12705050018888117`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19755017676411113`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.116341838407717`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0891184469324538, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.12557273527339094`, -0.9920844158416955, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.144168730365307, -0.8780716570571427, 0.}, 
      Optica`Optica`RayEnd :> {8.229428519827426, -1.0824469116506141`, 0.}, 
      RotationMatrix :> {{0.38501333507895286`, -0.9229110096923657, 0.}, {
       0.9229110096923657, 0.38501333507895286`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03616965632267346, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22144632846193466`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.478825586471395`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3302335284224384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.38501333507895286`, -0.9229110096923657, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.229428519827426, -1.0824469116506141`, 0.}, 
      Optica`Optica`RayEnd :> {8.336491908698271, -1.3533739219868754`, 0.}, 
      RotationMatrix :> {{0.36751849608503284`, -0.9300162122433112, 0.}, {
       0.9300162122433112, 0.36751849608503284`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036073961902658234`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2913142876109145, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.909970732135548`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015616519867868273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.36751849608503284`, -0.9300162122433112, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.397711101966816, 1.425990015523278, 0.}, 
      Optica`Optica`RayEnd :> {8.355766015401802, 1.677308046114456, 0.}, 
      RotationMatrix :> {{-0.16462332222623183`, 0.986356508458883, 
       0.}, {-0.986356508458883, -0.16462332222623183`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04156277847714569, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25479431466807656`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.616389138770046`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2434128852324654, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.16462332222623183`, 0.986356508458883, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.355766015401802, 1.677308046114456, 0.}, 
      Optica`Optica`RayEnd :> {8.300925599643978, 1.8751161064027455`, 0.}, 
      RotationMatrix :> {{-0.267163216279225, 0.9636512937091614, 
       0.}, {-0.9636512937091614, -0.267163216279225, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041104093087562646`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20526933505885978`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.92018775465716, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01621912599831199, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.267163216279225, 0.9636512937091614, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9578493651101825`, 0.12924088828540214`, 
       0.}, Optica`Optica`RayEnd :> {6.888620916030578, 0.16005448555398563`, 
       0.}, RotationMatrix :> {{-0.9135890649744072, 0.4066386852713211, 
       0.}, {-0.4066386852713211, -0.9135890649744072, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00875989764815006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07577635474604133, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.648834733223442`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25631192999813884`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9135890649744072, 0.4066386852713211, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.888620916030578, 0.16005448555398563`, 0.}, 
      Optica`Optica`RayEnd :> {6.597317163585998, 0.2927098512295937, 0.}, 
      RotationMatrix :> {{-0.91007842184727, 0.4144360820295245, 
       0.}, {-0.4144360820295245, -0.91007842184727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008737986765164067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32008642931374326`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.122562648607783`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16942134467166378`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.91007842184727, 0.4144360820295245, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.246315232740649, 0.938381580360709, 0.}, 
      Optica`Optica`RayEnd :> {8.368445590996329, 1.1189421761208362`, 0.}, 
      RotationMatrix :> {{0.5602666458655181, 0.8283123115894159, 
       0.}, {-0.8283123115894159, 0.5602666458655181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12236056753711465`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21798613063429736`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.816918056635, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04991302059663104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5602666458655181, 0.8283123115894159, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.368445590996329, 1.1189421761208362`, 0.}, 
      Optica`Optica`RayEnd :> {8.468165047516123, 1.3220799330813995`, 0.}, 
      RotationMatrix :> {{0.4406635225216263, 0.8976723566640734, 
       0.}, {-0.8976723566640734, 0.4406635225216263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11976412636108417`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22629387599219705`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.15183299310345, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3630671791619965, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4406635225216263, 0.8976723566640734, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.388581737806026, -0.6601193636767255, 0.}, 
      Optica`Optica`RayEnd :> {5.32799048777566, -0.672957898133279, 0.}, 
      RotationMatrix :> {{-0.9782804914008488, -0.2072855039420589, 0.}, {
       0.2072855039420589, -0.9782804914008488, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015716189902003127`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06193647993900283, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.763306896319369`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19471617914471634`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9782804914008488, -0.2072855039420589, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.32799048777566, -0.672957898133279, 0.}, 
      Optica`Optica`RayEnd :> {5.063027041023098, -0.7413790643896072, 0.}, 
      RotationMatrix :> {{-0.9682388495753991, -0.2500270588814485, 0.}, {
       0.2500270588814485, -0.9682388495753991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015660870595436388`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2736550458275416, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.16831636414413, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07064577457098914, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9682388495753991, -0.2500270588814485, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.690582381629045, 0.865765952717761, 0.}, 
      Optica`Optica`RayEnd :> {4.613324960534719, 0.8639604577822312, 0.}, 
      RotationMatrix :> {{-0.9997270366802105, -0.02336347856388596, 0.}, {
       0.02336347856388596, -0.9997270366802105, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008142147980113375, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07727851529440923, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.957565394500865`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03869494710519531, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 90, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9997270366802105, -0.02336347856388596, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.882842248520935, -1.1463896616883769`, 0.}, 
      Optica`Optica`RayEnd :> {6.886544713685529, -1.1997565696185986`, 0.}, 
      RotationMatrix :> {{0.06921118182149412, -0.9976020310278398, 0.}, {
       0.9976020310278398, 0.06921118182149412, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2718261063685962, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05349518773055935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.833316524000336`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16127364133101244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06921118182149412, -0.9976020310278398, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.886544713685529, -1.1997565696185986`, 0.}, 
      Optica`Optica`RayEnd :> {6.87725476830333, -1.3985091703707337`, 0.}, 
      RotationMatrix :> {{-0.04669027658474571, -0.998909414347687, 0.}, {
       0.998909414347687, -0.04669027658474571, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26809663024753516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1989695941367472, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.127791523322722`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11642385447714701`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04669027658474571, -0.998909414347687, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4207183716486735`, -0.620736054269777, 0.}, 
      Optica`Optica`RayEnd :> {7.534987210262611, -0.8222687521754535, 0.}, 
      RotationMatrix :> {{0.49323138584329945`, -0.8698981549693606, 0.}, {
       0.8698981549693606, 0.49323138584329945`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28038501246615904`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23167389970240232`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.310689133024274`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2713283032349091, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.49323138584329945`, -0.8698981549693606, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.534987210262611, -0.8222687521754535, 0.}, 
      Optica`Optica`RayEnd :> {7.665234411496248, -1.0794506771927341`, 0.}, 
      RotationMatrix :> {{0.45180384358798825`, -0.8921173055821303, 0.}, {
       0.8921173055821303, 0.45180384358798825`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2793503516646433, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.288282632124777, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.737347428568944`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1779962289068613, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.45180384358798825`, -0.8921173055821303, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.581851068272584, 0.2082720020311536, 0.}, 
      Optica`Optica`RayEnd :> {7.545049759835014, 0.09611452520613893, 0.}, 
      RotationMatrix :> {{-0.3117676366633089, -0.9501583766558995, 0.}, {
       0.9501583766558995, -0.3117676366633089, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025307265717536664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11804082306757638`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.864259469781665`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17094515379046615`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3117676366633089, -0.9501583766558995, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.545049759835014, 0.09611452520613893, 0.}, 
      Optica`Optica`RayEnd :> {7.4586303530034055`, -0.17982614486075948`, 
       0.}, RotationMatrix :> {{-0.2988670927346044, -0.9542947452859439, 
       0.}, {0.9542947452859439, -0.2988670927346044, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02524255363827332, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28915664833113564`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.292211309311746`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4084276518379489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.2988670927346044, -0.9542947452859439, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.675336249011812, 0.0591858274929169, 0.}, 
      Optica`Optica`RayEnd :> {8.30451965388601, -0.5884010241932411, 0.}, 
      RotationMatrix :> {{0.6968421135372873, -0.7172245595354956, 0.}, {
       0.7172245595354956, 0.6968421135372873, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2926493047834892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9029066881167064, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.176418380084115`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18384836117138856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6968421135372873, -0.7172245595354956, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.30451965388601, -0.5884010241932411, 0.}, 
      Optica`Optica`RayEnd :> {8.454284569695465, -0.7830988991393053, 0.}, 
      RotationMatrix :> {{0.6097039055154245, -0.7926292623914648, 0.}, {
       0.7926292623914648, 0.6097039055154245, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28868765007548547`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24563548708589877`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.539958900971246`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4022529008240797, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.6097039055154245, -0.7926292623914648, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.850782598441062, 0.07277791814304138, 0.}, 
      Optica`Optica`RayEnd :> {7.87963114875032, 0.08133101104005919, 0.}, 
      RotationMatrix :> {{0.9587494486833137, 0.2842525191611169, 
       0.}, {-0.2842525191611169, 0.9587494486833137, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021694254553177014`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.030089769906910917`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.26728236081961, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30191480806864585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9587494486833137, 0.2842525191611169, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.87963114875032, 0.08133101104005919, 0.}, 
      Optica`Optica`RayEnd :> {8.093840169841501, 0.11788342776077729`, 0.}, 
      RotationMatrix :> {{0.9857515794176407, 0.1682076801921542, 
       0.}, {-0.1682076801921542, 0.9857515794176407, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021376871550046972`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21730527808814654`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.588894172390066`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03042043166249108, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9857515794176407, 0.1682076801921542, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.983547199606125, 1.1459838153379867`, 0.}, 
      Optica`Optica`RayEnd :> {6.852980997598422, 1.167184912738187, 0.}, 
      RotationMatrix :> {{-0.987071770600787, 0.16027888096385756`, 
       0.}, {-0.16027888096385756`, -0.987071770600787, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012597079709539365`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13227630036287347`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.651134596318123`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17495943617945622`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.987071770600787, 0.16027888096385756`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.852980997598422, 1.167184912738187, 0.}, 
      Optica`Optica`RayEnd :> {6.569808117033248, 1.2291413933762683`, 0.}, 
      RotationMatrix :> {{-0.9768910769012311, 0.21373774554521724`, 
       0.}, {-0.21373774554521724`, -0.9768910769012311, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012544637138556657`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28987149873803614`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.080144414450416`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12801544356389144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9768910769012311, 0.21373774554521724`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.863324853607964, 1.031608164437147, 0.}, 
      Optica`Optica`RayEnd :> {6.783168053508213, 0.9171501968809312, 0.}, 
      RotationMatrix :> {{-0.5736363085510192, -0.8191101180622536, 0.}, {
       0.8191101180622536, -0.5736363085510192, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1793050907758053, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1397345302326211, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.906715892850482`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2151216980163771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5736363085510192, -0.8191101180622536, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.783168053508213, 0.9171501968809312, 0.}, 
      Optica`Optica`RayEnd :> {6.61876224892598, 0.6526344388411479, 0.}, 
      RotationMatrix :> {{-0.5278810623375086, -0.8493183054811797, 0.}, {
       0.8493183054811797, -0.5278810623375086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.178553439888321, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3114447861687407, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.367654176380219`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2559629316601262, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5278810623375086, -0.8493183054811797, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.914027006419358, 0.8736066021139146, 0.}, 
      Optica`Optica`RayEnd :> {7.066867649932133, 0.6002952428894279, 0.}, 
      RotationMatrix :> {{0.48808372587206317`, -0.8727968128601548, 0.}, {
       0.8727968128601548, 0.48808372587206317`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011087360641710873`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31314431400000814`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.384672271605677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04680238617350885, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.48808372587206317`, -0.8727968128601548, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.066867649932133, 0.6002952428894279, 0.}, 
      Optica`Optica`RayEnd :> {7.150151747661281, 0.39767247546671286`, 0.}, 
      RotationMatrix :> {{0.3801689421901667, -0.9249170640625077, 0.}, {
       0.9249170640625077, 0.3801689421901667, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010922902169554315`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21907128249179036`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.708897769693527`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3168070746004548, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3801689421901667, -0.9249170640625077, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.346007987984193, 2.1354637918059716`, 0.}, 
      Optica`Optica`RayEnd :> {7.327120090947857, 2.1718958268236905`, 0.}, 
      RotationMatrix :> {{-0.4602636248299924, 0.8877822906875057, 
       0.}, {-0.8877822906875057, -0.4602636248299924, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.375005953813934, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04103712745779785, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.119219047817943`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1909326373843794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4602636248299924, 0.8877822906875057, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.327120090947857, 2.1718958268236905`, 0.}, 
      Optica`Optica`RayEnd :> {7.184201931052216, 2.420319605206351, 0.}, 
      RotationMatrix :> {{-0.4986664328231548, 0.8667939713538788, 
       0.}, {-0.8667939713538788, -0.4986664328231548, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3701762291127424`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2866007224238509, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.543388117005241`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30351008336906904`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4986664328231548, 0.8667939713538788, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.066377499692184, 2.2089179863153836`, 0.}, 
      Optica`Optica`RayEnd :> {7.898965312849362, 2.243527325900353, 0.}, 
      RotationMatrix :> {{-0.9792925141756927, 0.20245041782977324`, 
       0.}, {-0.20245041782977324`, -0.9792925141756927, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2641689589797744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17095217661674764`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.555149942140938`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35626855929039974`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9792925141756927, 0.20245041782977324`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.898965312849362, 2.243527325900353, 0.}, 
      Optica`Optica`RayEnd :> {7.585569373781221, 2.3098714954677755`, 0.}, 
      RotationMatrix :> {{-0.9783187999875878, 0.20710462474518854`, 
       0.}, {-0.20710462474518854`, -0.9783187999875878, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26351488861141836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3203413233724191, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.02925510073212, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08120817888912812, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9783187999875878, 0.20710462474518854`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.269418053371558, 2.1084494459656544`, 0.}, 
      Optica`Optica`RayEnd :> {8.251000233336963, 1.8908622107119537`, 0.}, 
      RotationMatrix :> {{-0.0843440637813451, -0.996436690866433, 0.}, {
       0.996436690866433, -0.0843440637813451, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2622080760166959, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21836533845868483`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.436250247986802`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19641972233657484`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.0843440637813451, -0.996436690866433, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.251000233336963, 1.8908622107119537`, 0.}, 
      Optica`Optica`RayEnd :> {8.226143229094154, 1.6084734436314265`, 0.}, 
      RotationMatrix :> {{-0.08768500806499306, -0.996148251697829, 0.}, {
       0.996148251697829, -0.08768500806499306, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2615603495313354, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28348066324387494`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.855801629587738`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27372447824114043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.08768500806499306, -0.996148251697829, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.394212442133696, 1.133243022143843, 0.}, 
      Optica`Optica`RayEnd :> {8.251696866129556, 0.9374730351937544, 0.}, 
      RotationMatrix :> {{-0.5885427671349389, -0.8084660854068948, 0.}, {
       0.8084660854068948, -0.5885427671349389, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07646682752923194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2421499064510034, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.676344199147742`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16662762065239073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5885427671349389, -0.8084660854068948, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.251696866129556, 0.9374730351937544, 0.}, 
      Optica`Optica`RayEnd :> {8.084613540559982, 0.6849672883762922, 0.}, 
      RotationMatrix :> {{-0.5518299997001511, -0.8339566244301503, 0.}, {
       0.8339566244301503, -0.5518299997001511, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07619447622862997, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3027804317640638, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.124459238158558`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27631933863722424`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5518299997001511, -0.8339566244301503, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.6564143033686465`, 1.2250070433451765`, 0.},
       Optica`Optica`RayEnd :> {7.6385450164797195`, 1.1740699618890027`, 0.},
       RotationMatrix :> {{-0.331032072091207, -0.9436195034265673, 0.}, {
       0.9436195034265673, -0.331032072091207, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024599086842187857`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.053980530575306974`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.049967673012382`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09111356000812504, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.331032072091207, -0.9436195034265673, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.6385450164797195`, 1.1740699618890027`, 0.},
       Optica`Optica`RayEnd :> {7.517440732883323, 0.8653015214522295, 0.}, 
      RotationMatrix :> {{-0.36513618755352245`, -0.9309541151629753, 0.}, {
       0.9309541151629753, -0.36513618755352245`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024521132686194165`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33166880666585735`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.54083750687785, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26741525767977314`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.36513618755352245`, -0.9309541151629753, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.430375912009466, 0.283208622726918, 0.}, 
      Optica`Optica`RayEnd :> {7.421668960201598, 0.06043892671619491, 0.}, 
      RotationMatrix :> {{-0.039055172424785595`, -0.9992370557114408, 0.}, {
       0.9992370557114408, -0.039055172424785595`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20141331544426683`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2229397866476384, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.57804242657443, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37003628811032757`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.039055172424785595`, -0.9992370557114408, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.421668960201598, 0.06043892671619491, 0.}, 
      Optica`Optica`RayEnd :> {7.432955462470727, -0.16461433324118624`, 0.}, 
      RotationMatrix :> {{0.050087414328705566`, -0.9987448377467908, 0.}, {
       0.9987448377467908, 0.050087414328705566`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19979764395859306`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22533609331599694`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.911539844682107`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4018224905042424, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.050087414328705566`, -0.9987448377467908, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.585010064392459, 1.196668184852395, 0.}, 
      Optica`Optica`RayEnd :> {5.38361273321551, 1.1699175830622408`, 0.}, 
      RotationMatrix :> {{-0.9912937903191394, -0.13166860398254848`, 0.}, {
       0.13166860398254848`, -0.9912937903191394, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.33710362491899387`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20316613817595922`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.57281330744318, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.282337305663464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9912937903191394, -0.13166860398254848`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.38361273321551, 1.1699175830622408`, 0.}, 
      Optica`Optica`RayEnd :> {5.095547716240053, 1.1493290099655205`, 0.}, 
      RotationMatrix :> {{-0.9974556228700514, -0.07129011435617845, 0.}, {
       0.07129011435617845, -0.9974556228700514, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.335538024806492, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28879983266482295`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.000237059787118`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2781222968970381, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9974556228700514, -0.07129011435617845, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.869019545342315, 0.9045133912008863, 0.}, 
      Optica`Optica`RayEnd :> {4.6601133026574955`, 0.9110461907966975, 0.}, 
      RotationMatrix :> {{-0.9995114067544852, 0.03125616367484854, 
       0.}, {-0.03125616367484854, -0.9995114067544852, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2867799236082485, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2090083627591193, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.79953211932392, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21859296494332575`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9995114067544852, 0.03125616367484854, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6601133026574955`, 0.9110461907966975, 0.}, 
      Optica`Optica`RayEnd :> {4.349677723758777, 0.9390518793580136, 0.}, 
      RotationMatrix :> {{-0.9959553731423793, 0.08984928886097476, 
       0.}, {-0.08984928886097476, -0.9959553731423793, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28549430929952446`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31169627402004, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.26084260487358, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20149839548184606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9959553731423793, 0.08984928886097476, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8802831926153463`, 1.0795703200884155`, 0.},
       Optica`Optica`RayEnd :> {3.6903964674858494`, 1.0595389433095326`, 0.},
       RotationMatrix :> {{-0.9944818182062075, -0.10490907137743066`, 0.}, {
       0.10490907137743066`, -0.9944818182062075, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2900425045471786, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19094036879628845`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.37346316216975, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3458520902351315, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9944818182062075, -0.10490907137743066`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6903964674858494`, 1.0595389433095326`, 0.},
       Optica`Optica`RayEnd :> {3.3824431749592, 1.0217437832545335`, 0.}, 
      RotationMatrix :> {{-0.9925526803510646, -0.12181615955166485`, 0.}, {
       0.12181615955166485`, -0.9925526803510646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2892851428382827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.310263927167802, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.832653774378095`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.019551243521048214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9925526803510646, -0.12181615955166485`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.613447268885137, -1.6437226269738707`, 0.}, 
      Optica`Optica`RayEnd :> {6.61359122751234, -1.6461805843378567`, 0.}, 
      RotationMatrix :> {{0.05846820418709955, -0.9982892712531446, 0.}, {
       0.9982892712531446, 0.05846820418709955, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009211475820204557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0024621694680747102`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.184902203352877`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3461926233389503, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.05846820418709955, -0.9982892712531446, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.61359122751234, -1.6461805843378567`, 0.}, 
      Optica`Optica`RayEnd :> {6.645263755494122, -1.866185420573217, 0.}, 
      RotationMatrix :> {{0.1424938298289274, -0.9897956902617245, 0.}, {
       0.9897956902617245, 0.1424938298289274, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009144178844074995, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22227297855498412`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.513866211614253`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4321216933131855, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1424938298289274, -0.9897956902617245, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1516229963101905`, 3.04052253545903, 0.}, 
      Optica`Optica`RayEnd :> {7.1594300176847945`, 3.096458406591349, 0.}, 
      RotationMatrix :> {{0.13823104713110107`, 0.9904000088898619, 
       0.}, {-0.9904000088898619, 0.13823104713110107`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17846540055055785`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05647806000629715, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.057430995461434`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37369849770671837`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13823104713110107`, 0.9904000088898619, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1594300176847945`, 3.096458406591349, 0.}, 
      Optica`Optica`RayEnd :> {7.211612833848461, 3.428151601916212, 0.}, 
      RotationMatrix :> {{0.15541105427626567`, 0.9878498895119332, 
       0.}, {-0.9878498895119332, 0.15541105427626567`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17799828216807748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33577287282862617`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.5543748472478, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25364979986025965`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15541105427626567`, 0.9878498895119332, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.488034289750155, 2.6797783985379304`, 0.}, 
      Optica`Optica`RayEnd :> {6.512358282793377, 2.8102062193222936`, 0.}, 
      RotationMatrix :> {{0.18333299134353187`, 0.9830508706496484, 
       0.}, {-0.9830508706496484, 0.18333299134353187`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09317864868467558, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1326765731850377, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.587353135051494`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18691044211969832`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.18333299134353187`, 0.9830508706496484, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.512358282793377, 2.8102062193222936`, 0.}, 
      Optica`Optica`RayEnd :> {6.560121556279733, 3.120599832514311, 0.}, 
      RotationMatrix :> {{0.15208956539625448`, 0.98836671539342, 
       0.}, {-0.98836671539342, 0.15208956539625448`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09289994309639356, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3140470114561326, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.05214271200657, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03884132054238387, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15208956539625448`, 0.98836671539342, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.973860009185009, 2.4233855638274715`, 0.}, 
      Optica`Optica`RayEnd :> {4.42036330315144, 2.7385215816048163`, 0.}, 
      RotationMatrix :> {{-0.8690183803972727, 0.49477980408632294`, 
       0.}, {-0.49477980408632294`, -0.8690183803972727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8628874678008174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6369217481689365, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.659867897716822`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3093443290327457, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8690183803972727, 0.49477980408632294`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.42036330315144, 2.7385215816048163`, 0.}, 
      Optica`Optica`RayEnd :> {4.138474141033417, 2.894172329501781, 0.}, 
      RotationMatrix :> {{-0.875412529266712, 0.4833765650120591, 
       0.}, {-0.4833765650120591, -0.875412529266712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8581358924226263`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3220072282426058, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.13643859551588, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2941238954880902, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.875412529266712, 0.4833765650120591, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.911576044151911, 2.523739366932794, 0.}, 
      Optica`Optica`RayEnd :> {4.88366247065081, 2.686708323647802, 0.}, 
      RotationMatrix :> {{-0.16882302749175626`, 0.9856463794832895, 
       0.}, {-0.9856463794832895, -0.16882302749175626`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4301777177836793, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16534221614088643`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.202755415442848`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22592954348268363`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.16882302749175626`, 0.9856463794832895, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.88366247065081, 2.686708323647802, 0.}, 
      Optica`Optica`RayEnd :> {4.821355136964984, 2.914793700563985, 0.}, 
      RotationMatrix :> {{-0.2635198202505637, 0.964653981661357, 
       0.}, {-0.964653981661357, -0.2635198202505637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4261380628670148, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23644268437410781`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.552690588316526`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03222273264261277, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2635198202505637, 0.964653981661357, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.949638783966609, 2.6355490531667902`, 0.}, 
      Optica`Optica`RayEnd :> {5.30327979785749, 3.0437173209918855`, 0.}, 
      RotationMatrix :> {{0.654819695027326, 0.7557851328283184, 
       0.}, {-0.7557851328283184, 0.654819695027326, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2672446857022981, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.540058609379676, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.879679473026442`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16952933755436228`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.654819695027326, 0.7557851328283184, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.30327979785749, 3.0437173209918855`, 0.}, 
      Optica`Optica`RayEnd :> {5.4372327959670805`, 3.147729248239088, 0.}, 
      RotationMatrix :> {{0.789848418083539, 0.6133021086307548, 
       0.}, {-0.6133021086307548, 0.789848418083539, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2514363227260545, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1695932979578646, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.13067755400408, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2901868960771059, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.789848418083539, 0.6133021086307548, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.4372327959670805`, 3.147729248239088, 0.}, 
      Optica`Optica`RayEnd :> {5.5885091764360935`, 3.0710654143640497`, 0.}, 
      RotationMatrix :> {{0.8919950392532463, -0.4520451857365578, 0.}, {
       0.4520451857365578, 0.8919950392532463, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014873248628385755`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16959329795786504`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.381675634981722`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24413388957996074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8919950392532463, -0.4520451857365578, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0602158577717615`, 2.677056749400575, 0.}, 
      Optica`Optica`RayEnd :> {5.1235570583401175`, 2.675363415373785, 0.}, 
      RotationMatrix :> {{0.9996428505520377, -0.02672398436227935, 0.}, {
       0.02672398436227935, 0.9996428505520377, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16602375967792204`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06336383092559178, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.415712560541586`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18639129420398548`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9996428505520377, -0.02672398436227935, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1235570583401175`, 2.675363415373785, 0.}, 
      Optica`Optica`RayEnd :> {5.3812716959614155`, 2.6789453650180284`, 0.}, 
      RotationMatrix :> {{0.9999034242994321, 0.013897556413578961`, 
       0.}, {-0.013897556413578961`, 0.9999034242994321, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16546651203471324`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2577395289968748, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.79716706345696, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31941925485884315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999034242994321, 0.013897556413578961`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.162450707646214, 2.6179110515934285`, 0.}, 
      Optica`Optica`RayEnd :> {5.522941060404558, 2.1538937358320926`, 0.}, 
      RotationMatrix :> {{0.6135036350833503, -0.7896918954500636, 0.}, {
       0.7896918954500636, 0.6135036350833503, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1031410173981778, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5875928554349433, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.29298354402773, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31354154005928025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6135036350833503, -0.7896918954500636, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.522941060404558, 2.1538937358320926`, 0.}, 
      Optica`Optica`RayEnd :> {5.644278954911342, 1.9798251660506894`, 0.}, 
      RotationMatrix :> {{0.5718477776437675, -0.8203597498682411, 0.}, {
       0.8203597498682411, 0.5718477776437675, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10273052734101643`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21218565368347314`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.607018311479273`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2569436647470679, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5718477776437675, -0.8203597498682411, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.18158680607505, 2.5013606855070525`, 0.}, 
      Optica`Optica`RayEnd :> {5.152322539864831, 2.372367037486031, 0.}, 
      RotationMatrix :> {{-0.22124387230273998`, -0.9752185134463391, 0.}, {
       0.9752185134463391, -0.22124387230273998`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06407558466672793, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13227153324352808`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.857657062934848`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.422833045095208, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.22124387230273998`, -0.9752185134463391, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.152322539864831, 2.372367037486031, 0.}, 
      Optica`Optica`RayEnd :> {5.118213821951841, 2.1161797360726418`, 0.}, 
      RotationMatrix :> {{-0.13197519710502423`, -0.9912530188347921, 0.}, {
       0.9912530188347921, -0.13197519710502423`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06354535848363348, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25844794068272753`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.240160015145285`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3382830137792641, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13197519710502423`, -0.9912530188347921, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1036313876707275`, 2.412630020912711, 0.}, 
      Optica`Optica`RayEnd :> {4.883622081333916, 2.302493471582756, 0.}, 
      RotationMatrix :> {{-0.894212655040459, -0.4476424103740527, 0.}, {
       0.4476424103740527, -0.894212655040459, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039806477131525075`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24603689636539197`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.18490674016176, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3506094819795322, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.894212655040459, -0.4476424103740527, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.883622081333916, 2.302493471582756, 0.}, 
      Optica`Optica`RayEnd :> {4.60282190644634, 2.1683820226624086`, 0.}, 
      RotationMatrix :> {{-0.9023646010421642, -0.43097346413209103`, 0.}, {
       0.43097346413209103`, -0.9023646010421642, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03970141247948349, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3111826135059738, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.6454570081506, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29094505234124396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9023646010421642, -0.43097346413209103`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.985587288433265, 2.416601007334562, 0.}, 
      Optica`Optica`RayEnd :> {4.384889466004231, 2.6844616944699413`, 0.}, 
      RotationMatrix :> {{-0.9133121062066911, 0.40726035487915657`, 
       0.}, {-0.40726035487915657`, -0.9133121062066911, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024729475819285418`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.6577136318973635, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.91135765641822, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13138239892680412`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9133121062066911, 0.40726035487915657`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.384889466004231, 2.6844616944699413`, 0.}, 
      Optica`Optica`RayEnd :> {4.108774052035784, 2.8195567145089377`, 0.}, 
      RotationMatrix :> {{-0.8982492005507269, 0.439486488654633, 
       0.}, {-0.439486488654633, -0.8982492005507269, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024651918776346305`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3073928858485561, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.366299127474086`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06419375227402802, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8982492005507269, 0.439486488654633, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.913771130957169, 2.5103699660752623`, 0.}, 
      Optica`Optica`RayEnd :> {4.870247198990103, 2.669012116609145, 0.}, 
      RotationMatrix :> {{-0.26457625775450316`, 0.9643647670008592, 
       0.}, {-0.9643647670008592, -0.26457625775450316`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015363001661159345`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16450429957873125`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.425261241754875`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16118539418227748`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.26457625775450316`, 0.9643647670008592, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.870247198990103, 2.669012116609145, 0.}, 
      Optica`Optica`RayEnd :> {4.781731117882949, 2.928205971915999, 0.}, 
      RotationMatrix :> {{-0.32317937065998037`, 0.9463377274418566, 
       0.}, {-0.9463377274418566, -0.32317937065998037`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015290852539424834`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27389149538347923`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.830620654922424`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16199385854257997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.32317937065998037`, 0.9463377274418566, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.9406965792129025`, 2.6253708283945265`, 0.},
       Optica`Optica`RayEnd :> {5.457306936761345, 3.355448852941872, 0.}, 
      RotationMatrix :> {{0.5776239750725581, 0.8163029728117959, 
       0.}, {-0.8163029728117959, 0.5776239750725581, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009544149733118451, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8943713901133485, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.578087233714882`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33092222357484724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5776239750725581, 0.8163029728117959, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.457306936761345, 3.355448852941872, 0.}, 
      Optica`Optica`RayEnd :> {5.634090986696744, 3.6286175405357364`, 0.}, 
      RotationMatrix :> {{0.5433115874088591, 0.8395311304455985, 
       0.}, {-0.8395311304455985, 0.5433115874088591, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009511743778559264, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3253824398969871, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.059653244762423`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20637755631611293`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5433115874088591, 0.8395311304455985, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1188388464948025`, 0.6604338486612473, 0.}, 
      Optica`Optica`RayEnd :> {4.1166751170879525`, 0.6597018252416424, 0.}, 
      RotationMatrix :> {{-0.947257940793193, -0.3204721416975875, 0.}, {
       0.3204721416975875, -0.947257940793193, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08373921136943206, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.002284202975420043, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.075246104612162`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13969541375954359`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.947257940793193, -0.3204721416975875, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1166751170879525`, 0.6597018252416424, 0.}, 
      Optica`Optica`RayEnd :> {3.832018778269499, 0.5492703607319532, 0.}, 
      RotationMatrix :> {{-0.9323011105486101, -0.3616830646710283, 0.}, {
       0.3616830646710283, -0.9323011105486101, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0834447391571244, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3053266113251198, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.52712948937334, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01194528956397733, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9323011105486101, -0.3616830646710283, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.143855725421484, 1.3816868608239041`, 0.}, 
      Optica`Optica`RayEnd :> {5.132335989322367, 1.3897219659560067`, 0.}, 
      RotationMatrix :> {{-0.8201910997557105, 0.5720896432216872, 
       0.}, {-0.5720896432216872, -0.8201910997557105, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03768646910093345, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01404518544830381, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.238632478845771`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17647035133200312`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8201910997557105, 0.5720896432216872, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.132335989322367, 1.3897219659560067`, 0.}, 
      Optica`Optica`RayEnd :> {4.8547025614206625`, 1.5800455557922033`, 0.}, 
      RotationMatrix :> {{-0.824803138715788, 0.5654200052744717, 
       0.}, {-0.5654200052744717, -0.824803138715788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037592344494505804`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3366056879147879, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.689684100651586`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24644121533762903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.824803138715788, 0.5654200052744717, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.072201536619233, 1.2023600096651306`, 0.}, 
      Optica`Optica`RayEnd :> {4.851498967343398, 1.2250555314779823`, 0.}, 
      RotationMatrix :> {{-0.9947542477803563, 0.10229362894597613`, 
       0.}, {-0.10229362894597613`, -0.9947542477803563, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09155049181583227, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22186642557023512`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.553511158231464`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2600849901396447, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9947542477803563, 0.10229362894597613`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.851498967343398, 1.2250555314779823`, 0.}, 
      Optica`Optica`RayEnd :> {4.613741195307599, 1.2388990593583549`, 0.}, 
      RotationMatrix :> {{-0.9983092025849776, 0.058126895961730075`, 
       0.}, {-0.058126895961730075`, -0.9983092025849776, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09122629485963236, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23816045311428494`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.872646165404605`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18723644239510345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9983092025849776, 0.058126895961730075`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.327993242796761, 1.1048759326021627`, 0.}, 
      Optica`Optica`RayEnd :> {5.210763959576821, 0.9057866227232705, 0.}, 
      RotationMatrix :> {{-0.5073992753760861, -0.8617110741703522, 0.}, {
       0.8617110741703522, -0.5073992753760861, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021995171031671156`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23103951643022994`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.227992561677153`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33121363392530756`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.5073992753760861, -0.8617110741703522, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.210763959576821, 0.9057866227232705, 0.}, 
      Optica`Optica`RayEnd :> {5.090100669028041, 0.7405292894550553, 0.}, 
      RotationMatrix :> {{-0.5896925977632256, -0.8076277856433979, 0.}, {
       0.8076277856433979, -0.5896925977632256, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02178238613968048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20462066338711055`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.502184250615882`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05438444296975686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.5896925977632256, -0.8076277856433979, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.953065952582621, -0.6208304854292546, 0.}, 
      Optica`Optica`RayEnd :> {5.979795162103256, -0.8413281452657155, 0.}, 
      RotationMatrix :> {{0.12034121974929338`, -0.9927325877743973, 0.}, {
       0.9927325877743973, 0.12034121974929338`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008406955677190412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2221118381242964, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.937424352652915`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3682198951635766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.12034121974929338`, -0.9927325877743973, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.979795162103256, -0.8413281452657155, 0.}, 
      Optica`Optica`RayEnd :> {6.021253812479882, -1.1394772355398624`, 0.}, 
      RotationMatrix :> {{0.1377282475702545, -0.9904700549846148, 0.}, {
       0.9904700549846148, 0.1377282475702545, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008384926219419794, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3010177731004477, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.382930656841577`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2619646707313838, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1377282475702545, -0.9904700549846148, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.8015864440438545`, -0.3685024860381718, 0.},
       Optica`Optica`RayEnd :> {7.865477093546045, -0.4111577264223858, 0.}, 
      RotationMatrix :> {{0.8316807760820552, -0.555254074001758, 0.}, {
       0.555254074001758, 0.8316807760820552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009191829442302282, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07682112096322759, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.28028566595308, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40498243212562635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8316807760820552, -0.555254074001758, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.865477093546045, -0.4111577264223858, 0.}, 
      Optica`Optica`RayEnd :> {8.090697161067123, -0.5731585137979203, 0.}, 
      RotationMatrix :> {{0.8118037281095526, -0.5839303957043434, 0.}, {
       0.5839303957043434, 0.8118037281095526, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009163249487429402, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2774316743353072, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.690884543969336`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3386792629141013, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8118037281095526, -0.5839303957043434, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9180161944865612`, 1.1494482120242693`, 0.},
       Optica`Optica`RayEnd :> {3.8621851503738815`, 1.158281382640382, 0.}, 
      RotationMatrix :> {{-0.9877145623329302, 0.1562688176043695, 
       0.}, {-0.1562688176043695, -0.9877145623329302, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15835655323663772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05652548442822359, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.222288297784498`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.037304268953977954`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9877145623329302, 0.1562688176043695, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8621851503738815`, 1.158281382640382, 0.}, 
      Optica`Optica`RayEnd :> {3.6713872384178625`, 1.2136497580075274`, 0.}, 
      RotationMatrix :> {{-0.9603793296253583, 0.2786961485710682, 
       0.}, {-0.2786961485710682, -0.9603793296253583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15573397530720887`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1986693237457004, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.516318896928134`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26432233112817677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9603793296253583, 0.2786961485710682, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.515237747523003, -1.3299214132440937`, 0.}, 
      Optica`Optica`RayEnd :> {3.3736817974158426`, -1.2779634997862737`, 0.},
       RotationMatrix :> {{-0.9387603764932424, 0.3445706829175469, 
       0.}, {-0.3445706829175469, -0.9387603764932424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009992787838718266, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15079029074058828`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.67844352585118, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3672774533768513, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9387603764932424, 0.3445706829175469, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3736817974158426`, -1.2779634997862737`, 
       0.}, Optica`Optica`RayEnd :> {3.062560437831467, -1.1680963505251802`, 
       0.}, RotationMatrix :> {{-0.9429336187983898, 0.33298076602075966`, 
       0.}, {-0.33298076602075966`, -0.9429336187983898, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00996739686590369, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3299504369998466, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.166770172610953`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2205118211543104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9429336187983898, 0.33298076602075966`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3631369823812154`, -1.436960415300968, 0.}, 
      Optica`Optica`RayEnd :> {3.2347894055906963`, -1.5697014360895865`, 0.},
       RotationMatrix :> {{-0.6951096006358186, -0.718903778752005, 0.}, {
       0.718903778752005, -0.6951096006358186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17186032965135978`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18464365428576912`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.999071081632877`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2948887374947094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6951096006358186, -0.718903778752005, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2347894055906963`, -1.5697014360895865`, 
       0.}, Optica`Optica`RayEnd :> {
       3.0912834629691233`, -1.7539364159912485`, 0.}, 
      RotationMatrix :> {{-0.614506272846346, -0.7889119346495471, 0.}, {
       0.7889119346495471, -0.614506272846346, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16989633312019414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23353047635602503`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.344696186639794`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06981704658450961, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.614506272846346, -0.7889119346495471, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3994379955641585`, -1.6193726603941647`, 
       0.}, Optica`Optica`RayEnd :> {3.4950612409166117`, -1.855056788319011, 
       0.}, RotationMatrix :> {{0.3759604613239186, -0.9266357059390197, 
       0.}, {0.9266357059390197, 0.3759604613239186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008976207603462818, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2543438876942609, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.36773344303141, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31923902102297824`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.3759604613239186, -0.9266357059390197, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4950612409166117`, -1.855056788319011, 0.}, 
      Optica`Optica`RayEnd :> {3.589344272267322, -2.1020351712178833`, 0.}, 
      RotationMatrix :> {{0.3566427811956743, -0.934240829026977, 0.}, {
       0.934240829026977, 0.3566427811956743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008952112530770833, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2643626517116611, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.758990167564665`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.018408157084473766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3566427811956743, -0.934240829026977, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6764578941698423`, 1.912287471595425, 0.}, 
      Optica`Optica`RayEnd :> {3.659701915750172, 1.9542676047755663`, 0.}, 
      RotationMatrix :> {{-0.3707025523354642, 0.928751644785608, 
       0.}, {-0.928751644785608, -0.3707025523354642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043428170148673055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04520060170642487, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.182650597257695`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.290109880341259, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3707025523354642, 0.928751644785608, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.659701915750172, 1.9542676047755663`, 0.}, 
      Optica`Optica`RayEnd :> {3.5671895390265544`, 2.1378958136711663`, 0.}, 
      RotationMatrix :> {{-0.44992833634526747`, 0.8930646629184136, 
       0.}, {-0.8930646629184136, -0.44992833634526747`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04309512000844569, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20561580423026468`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.486961987518486`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15460951095656747`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.44992833634526747`, 0.8930646629184136, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.8600772293281915`, 0.9108912178091552, 0.}, 
      Optica`Optica`RayEnd :> {7.917087917971804, 0.9252157528523273, 0.}, 
      RotationMatrix :> {{0.9698541668528468, 0.24368605835822812`, 
       0.}, {-0.24368605835822812`, 0.9698541668528468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08106832390627644, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058782743418642563`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.557182036064386`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36051648553621163`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9698541668528468, 0.24368605835822812`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.917087917971804, 0.9252157528523273, 0.}, 
      Optica`Optica`RayEnd :> {8.192257270270463, 1.011642970905468, 0.}, 
      RotationMatrix :> {{0.9540478274175413, 0.29965437256924604`, 
       0.}, {-0.29965437256924604`, 0.9540478274175413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08070835521041393, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2884230165310484, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.984048100530337`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3758270202900077, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9540478274175413, 0.29965437256924604`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.563509470794093, 1.7232149979237499`, 0.}, 
      Optica`Optica`RayEnd :> {4.491949144930795, 1.8183417237540334`, 0.}, 
      RotationMatrix :> {{-0.6011568217446502, 0.7991310753999431, 
       0.}, {-0.7991310753999431, -0.6011568217446502, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.050512587639212486`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11903770077102209`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.332907751611893`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36137455251421186`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6011568217446502, 0.7991310753999431, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.491949144930795, 1.8183417237540334`, 0.}, 
      Optica`Optica`RayEnd :> {4.380048048528092, 2.0105057011738268`, 0.}, 
      RotationMatrix :> {{-0.5032180906402802, 0.8641594489747535, 
       0.}, {-0.8641594489747535, -0.5032180906402802, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0497964265762504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2223709729122076, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.66201679152196, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11495528227187349`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5032180906402802, 0.8641594489747535, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1420754931227135`, 0.6299410302479087, 0.}, 
      Optica`Optica`RayEnd :> {4.13941268460613, 0.6298041521065122, 0.}, 
      RotationMatrix :> {{-0.9986814436190989, -0.05133589553978195, 0.}, {
       0.05133589553978195, -0.9986814436190989, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012792309006811277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0026663242153910473`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.458516355089179`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24445703644656896`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9986814436190989, -0.05133589553978195, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.13941268460613, 0.6298041521065122, 0.}, 
      Optica`Optica`RayEnd :> {3.84117167131676, 0.5997028117287332, 0.}, 
      RotationMatrix :> {{-0.9949451963960387, -0.10041940135475233`, 0.}, {
       0.10041940135475233`, -0.9949451963960387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012743424265618152`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2997562221212583, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.902155563828641`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16446731269684647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9949451963960387, -0.10041940135475233`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6730830867006965`, -1.3644129827131524`, 
       0.}, Optica`Optica`RayEnd :> {4.655793407407262, -1.394049582502252, 
       0.}, RotationMatrix :> {{-0.503907182357983, -0.8637578083977225, 
       0.}, {0.8637578083977225, -0.503907182357983, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008023739835011482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03431123805882087, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.768658916442217`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16817746641900874`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 90, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.503907182357983, -0.8637578083977225, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.212311557604752, -0.4341530931148644, 0.}, 
      Optica`Optica`RayEnd :> {7.338588345914811, -0.6082107515768171, 0.}, 
      RotationMatrix :> {{0.5872265901009059, -0.8094225916531254, 0.}, {
       0.8094225916531254, 0.5872265901009059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009135421323814214, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21503928881755788`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.918992050826233`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.036252769662518, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5872265901009059, -0.8094225916531254, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.338588345914811, -0.6082107515768171, 0.}, 
      Optica`Optica`RayEnd :> {7.418876778563906, -0.7867706051417519, 0.}, 
      RotationMatrix :> {{0.4100949289066539, -0.9120428439964025, 0.}, {
       0.9120428439964025, 0.4100949289066539, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008517132002126502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19578011574820176`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.20874662213357, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3970986612390407, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4100949289066539, -0.9120428439964025, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.435909779053422, 2.6593680888455133`, 0.}, 
      Optica`Optica`RayEnd :> {5.3888323111581675`, 2.7101479142359346`, 0.}, 
      RotationMatrix :> {{-0.6798675074497078, 0.7333349659699312, 
       0.}, {-0.7333349659699312, -0.6798675074497078, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18871195105622218`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06924506227963424, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.885853001029048`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3995978669464272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6798675074497078, 0.7333349659699312, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3888323111581675`, 2.7101479142359346`, 0.},
       Optica`Optica`RayEnd :> {5.224191606502897, 2.8622039459876105`, 0.}, 
      RotationMatrix :> {{-0.7346255172645006, 0.678472806664986, 
       0.}, {-0.678472806664986, -0.7346255172645006, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18750941602837956`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2241151454530695, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.217543416299591`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33129561524231455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7346255172645006, 0.678472806664986, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8978100437530285`, 1.696982269817469, 0.}, 
      Optica`Optica`RayEnd :> {6.956747605735684, 1.6533453290572493`, 0.}, 
      RotationMatrix :> {{0.8036909608752538, -0.595046922021625, 0.}, {
       0.595046922021625, 0.8036909608752538, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03352366343497384, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07333361310729362, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.774553751890979`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2517765652413333, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8036909608752538, -0.595046922021625, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.956747605735684, 1.6533453290572493`, 0.}, 
      Optica`Optica`RayEnd :> {7.093661954241497, 1.5245104065784694`, 0.}, 
      RotationMatrix :> {{0.728268057670746, -0.685292372769811, 0.}, {
       0.685292372769811, 0.728268057670746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03304788095536744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1879999363746826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.052793657725509`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41815534017111305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.728268057670746, -0.685292372769811, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.665193389335898, 1.9205603235213684`, 0.}, 
      Optica`Optica`RayEnd :> {6.69219454215379, 1.82495236190656, 0.}, 
      RotationMatrix :> {{0.2717846656745479, -0.96235809109924, 0.}, {
       0.96235809109924, 0.2717846656745479, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013858168682042577`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09934759472495487, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.948861549936513`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43055338997369896`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2717846656745479, -0.96235809109924, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.69219454215379, 1.82495236190656, 0.}, 
      Optica`Optica`RayEnd :> {6.7707649418967755`, 1.571081812287572, 0.}, 
      RotationMatrix :> {{0.2956542651189007, -0.9552950096786864, 0.}, {
       0.9552950096786864, 0.2956542651189007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013819595685257417`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26575094295151513`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.342172945504755`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22048174423647393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2956542651189007, -0.9552950096786864, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.585555138189024, 2.638730032428786, 0.}, 
      Optica`Optica`RayEnd :> {6.578523583257114, 2.6384968249285388`, 0.}, 
      RotationMatrix :> {{-0.9994504664902579, -0.033147624838056944`, 0.}, {
       0.033147624838056944`, -0.9994504664902579, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0194636450657914, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007035421131576518, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.629418330425775`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10202013897499644`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9994504664902579, -0.033147624838056944`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.578523583257114, 2.6384968249285388`, 0.}, 
      Optica`Optica`RayEnd :> {6.327120076572609, 2.606217434266993, 0.}, 
      RotationMatrix :> {{-0.9918576754896702, -0.12735129199276649`, 0.}, {
       0.12735129199276649`, -0.9918576754896702, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019289780411100174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25346731985553256`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.004549963811963`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2766489326989976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9918576754896702, -0.12735129199276649`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.692367912281009, 2.8987001271996897`, 0.}, 
      Optica`Optica`RayEnd :> {6.829041889572819, 3.1787664066759094`, 0.}, 
      RotationMatrix :> {{0.4385695084171239, 0.8986972717699554, 
       0.}, {-0.8986972717699554, 0.4385695084171239, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.8970398808552136`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31163584031432295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.453548256944156`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01487038613218572, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4385695084171239, 0.8986972717699554, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.829041889572819, 3.1787664066759094`, 0.}, 
      Optica`Optica`RayEnd :> {6.883506851961149, 3.3440089025840014`, 0.}, 
      RotationMatrix :> {{0.3130402146814892, 0.9497398717502419, 
       0.}, {-0.9497398717502419, 0.3130402146814892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.818583817398182, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17398711039010323`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.71104918032151, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30913122198391296`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3130402146814892, 0.9497398717502419, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.883506851961149, 3.3440089025840014`, 0.}, 
      Optica`Optica`RayEnd :> {6.730079919853941, 3.4260557860474723`, 0.}, 
      RotationMatrix :> {{-0.8818293019707185, 0.47156874598072546`, 
       0.}, {-0.47156874598072546`, -0.8818293019707185, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07687656874273986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17398711039010334`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.968550103698863`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3340267400652449, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8818293019707185, 0.47156874598072546`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.872093610858287, 2.6826165966951008`, 0.}, 
      Optica`Optica`RayEnd :> {6.91602272532324, 2.622319810077522, 0.}, 
      RotationMatrix :> {{0.5888457465127058, -0.8082454372366682, 0.}, {
       0.8082454372366682, 0.5888457465127058, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019271618048410034`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07460207486444824, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.551888376054825`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4060067008800814, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5888457465127058, -0.8082454372366682, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.91602272532324, 2.622319810077522, 0.}, 
      Optica`Optica`RayEnd :> {7.090703027845902, 2.372357661055526, 0.}, 
      RotationMatrix :> {{0.5728168804933994, -0.8196833665640711, 0.}, {
       0.8196833665640711, 0.5728168804933994, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01922031977264812, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30494964179861483`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.003213845916775`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13446549629732651`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5728168804933994, -0.8196833665640711, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.939781396097772, 2.361951907883309, 0.}, 
      Optica`Optica`RayEnd :> {5.772658749981498, 2.303802156351581, 0.}, 
      RotationMatrix :> {{-0.9444614831544184, -0.3286221338220463, 0.}, {
       0.3286221338220463, -0.9444614831544184, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013930309314701081`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1769501976492453, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.871538972020982`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.039480507426938864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9444614831544184, -0.3286221338220463, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.772658749981498, 2.303802156351581, 0.}, 
      Optica`Optica`RayEnd :> {5.589205417729699, 2.225663533370224, 0.}, 
      RotationMatrix :> {{-0.9200220035673978, -0.3918667030404979, 0.}, {
       0.3918667030404979, -0.9200220035673978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013856605921443037`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1994010268672453, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.166652491784504`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08105810909685572, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9200220035673978, -0.3918667030404979, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.391351704172249, 2.625593379193287, 0.}, 
      Optica`Optica`RayEnd :> {5.355124772949332, 2.6352776953953128`, 0.}, 
      RotationMatrix :> {{-0.9660767374370904, 0.2582551788113956, 
       0.}, {-0.2582551788113956, -0.9660767374370904, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03290167705419436, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03749902033561328, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.704116470000445`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15841110363229638`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9660767374370904, 0.2582551788113956, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.355124772949332, 2.6352776953953128`, 0.}, 
      Optica`Optica`RayEnd :> {5.1144186586145235`, 2.7118462900651146`, 0.}, 
      RotationMatrix :> {{-0.9529483280822111, 0.30313278279545663`, 
       0.}, {-0.30313278279545663`, -0.9529483280822111, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03278073812803582, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2525909403915164, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.07795106177989, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.054324310833512225`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9529483280822111, 0.30313278279545663`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.653693099468152, 1.5369387176341482`, 0.}, 
      Optica`Optica`RayEnd :> {7.849169220663623, 1.4859892362381888`, 0.}, 
      RotationMatrix :> {{0.9676708011649942, -0.252216614386715, 0.}, {
       0.252216614386715, 0.9676708011649942, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17492238395008286`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20200684050829573`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.79539927877178, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08123798996400766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9676708011649942, -0.252216614386715, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.849169220663623, 1.4859892362381888`, 0.}, 
      Optica`Optica`RayEnd :> {8.113793252067586, 1.4194705564399406`, 0.}, 
      RotationMatrix :> {{0.9698289482108617, -0.24378640489619624`, 0.}, {
       0.24378640489619624`, 0.9698289482108617, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17448462683892865`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27285639585427907`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.199226744636114`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32888742059579024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9698289482108617, -0.24378640489619624`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.963243164986898, 0.40461823168334243`, 0.}, 
      Optica`Optica`RayEnd :> {4.864035069368825, 0.3001735008972025, 0.}, 
      RotationMatrix :> {{-0.6886969216269891, -0.7250493432460354, 0.}, {
       0.7250493432460354, -0.6886969216269891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012650261897218986`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1440518935146431, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.721988074335226`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3775230612502488, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6886969216269891, -0.7250493432460354, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.864035069368825, 0.3001735008972025, 0.}, 
      Optica`Optica`RayEnd :> {4.694976960098423, 0.14421027926079488`, 0.}, 
      RotationMatrix :> {{-0.7349993366060027, -0.678067824917784, 0.}, {
       0.678067824917784, -0.7349993366060027, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012585585767993008`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23001124062378003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.06240471045842, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35714425377480075`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7349993366060027, -0.678067824917784, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.693844003873882, 1.1857485126662142`, 0.}, 
      Optica`Optica`RayEnd :> {3.4228500119969545`, 1.264608325084982, 0.}, 
      RotationMatrix :> {{-0.9601713484824793, 0.2794118493431083, 
       0.}, {-0.2794118493431083, -0.9601713484824793, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08361915282499986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28223503263789823`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.462344363162897`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4097938056501906, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9601713484824793, 0.2794118493431083, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4228500119969545`, 1.264608325084982, 0.}, 
      Optica`Optica`RayEnd :> {3.1565195605696372`, 1.3367049720306945`, 0.}, 
      RotationMatrix :> {{-0.9652579306141116, 0.2612989234316925, 
       0.}, {-0.2612989234316925, -0.9652579306141116, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08339803321601268, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.275916356634204, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.87070057098152, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2139773694789121, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9652579306141116, 0.2612989234316925, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.2970211362664825`, 2.4039905965296344`, 0.},
       Optica`Optica`RayEnd :> {4.354927469531008, 2.660660901539697, 0.}, 
      RotationMatrix :> {{0.22007471704656215`, 0.9754830182616588, 
       0.}, {-0.9754830182616588, 0.22007471704656215`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00898624611352839, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26312124373775087`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.42541414692881, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014751948952568705`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.22007471704656215`, 0.9754830182616588, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.354927469531008, 2.660660901539697, 0.}, 
      Optica`Optica`RayEnd :> {4.388221823160652, 2.9095274470816745`, 0.}, 
      RotationMatrix :> {{0.13260255922972647`, 0.9911692899226283, 
       0.}, {-0.9911692899226283, 0.13260255922972647`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008914558721356186, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25108379372952966`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.797018161648515`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14560753670908175`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13260255922972647`, 0.9911692899226283, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8070783438029028`, 2.2959531760368335`, 0.},
       Optica`Optica`RayEnd :> {3.7064987451471687`, 2.657886923554598, 0.}, 
      RotationMatrix :> {{-0.2677487632254505, 0.9634887647457243, 
       0.}, {-0.9634887647457243, -0.2677487632254505, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014965431400512286`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3756491624614669, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.670177289547205`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41122311092981323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.2677487632254505, 0.9634887647457243, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7064987451471687`, 2.657886923554598, 0.}, 
      Optica`Optica`RayEnd :> {3.675537600714022, 2.844785459439058, 0.}, 
      RotationMatrix :> {{-0.16343021893141432`, 0.9865548963641254, 
       0.}, {-0.9865548963641254, -0.16343021893141432`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014794145320095998`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18944565231317614`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.950556854970705`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2975398598932371, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.16343021893141432`, 0.9865548963641254, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.675134321503202, 2.346331015390589, 0.}, 
      Optica`Optica`RayEnd :> {3.5557058479751067`, 2.3666693537413117`, 0.}, 
      RotationMatrix :> {{-0.98580739253648, 0.16788026930055444`, 
       0.}, {-0.16788026930055444`, -0.98580739253648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22626957942774628`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12114787780278878`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.538172459016657`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015770831732549288`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.98580739253648, 0.16788026930055444`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5557058479751067`, 2.3666693537413117`, 0.},
       Optica`Optica`RayEnd :> {3.3314682700404803`, 2.4287451418733497`, 0.},
       RotationMatrix :> {{-0.9637529799935005, 0.26679616480310864`, 
       0.}, {-0.26679616480310864`, -0.9637529799935005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22395049021830984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23267121616177924`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.88252585893609, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2288987780263201, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9637529799935005, 0.26679616480310864`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.573380697926003, 2.248385357970332, 0.}, 
      Optica`Optica`RayEnd :> {3.4922244091376218`, 2.1318753049699684`, 0.}, 
      RotationMatrix :> {{-0.571566592858381, -0.8205556836243728, 0.}, {
       0.8205556836243728, -0.571566592858381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013262488590337719`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1419892096606314, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.775126734618246`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3895106707338082, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.571566592858381, -0.8205556836243728, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4922244091376218`, 2.1318753049699684`, 0.},
       Optica`Optica`RayEnd :> {3.4118601926906513`, 1.9774712451865195`, 0.},
       RotationMatrix :> {{-0.46168781947884624`, -0.8870424777567691, 0.}, {
       0.8870424777567691, -0.46168781947884624`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013029652756978094`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17406613962154224`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.03274462125813, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11957854284353497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46168781947884624`, -0.8870424777567691, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.608033170338925, 1.7741434996327017`, 0.}, 
      Optica`Optica`RayEnd :> {3.494865762782598, 1.6280956073710566`, 0.}, 
      RotationMatrix :> {{-0.6125050190984126, -0.7904666985896704, 0.}, {
       0.7904666985896704, -0.6125050190984126, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008251132000559797, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18476160035864853`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.861188657429173`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14624144031135453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6125050190984126, -0.7904666985896704, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.494865762782598, 1.6280956073710566`, 0.}, 
      Optica`Optica`RayEnd :> {3.345010882115403, 1.4163935745926908`, 0.}, 
      RotationMatrix :> {{-0.5777587149980167, -0.8162076128313435, 0.}, {
       0.8162076128313435, -0.5777587149980167, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008222372346247762, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2593727740960325, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.2450603630913, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26796663695041184`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5777587149980167, -0.8162076128313435, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.30918847720457, -1.0191991468394757`, 0.}, 
      Optica`Optica`RayEnd :> {2.1501325925922243`, -1.0673780166924594`, 0.},
       RotationMatrix :> {{-0.9570576031723645, -0.28989781684236343`, 0.}, {
       0.28989781684236343`, -0.9570576031723645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013933410081013042`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1661925928858642, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.676339456081994`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3520792556380051, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9570576031723645, -0.28989781684236343`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1501325925922243`, -1.0673780166924594`, 
       0.}, Optica`Optica`RayEnd :> {1.822712616640818, -1.1460593338038179`, 
       0.}, RotationMatrix :> {{-0.9723195189281357, -0.2336552013359822, 
       0.}, {0.2336552013359822, -0.9723195189281357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013871411983682134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3367411324955677, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.174716332175436`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33626819693811105`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9723195189281357, -0.2336552013359822, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.589108696355187, -2.8258811301481175`, 0.}, 
      Optica`Optica`RayEnd :> {3.5793722792052693`, -2.831708477702094, 0.}, 
      RotationMatrix :> {{-0.8580562805913345, -0.5135556633294629, 0.}, {
       0.5135556633294629, -0.8580562805913345, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012266904960303113`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.011347061224477793`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.898785390077267`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04854272279055603, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.8580562805913345, -0.5135556633294629, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5793722792052693`, -2.831708477702094, 0.}, 
      Optica`Optica`RayEnd :> {3.3311028726883682`, -2.9944225439346672`, 0.},
       RotationMatrix :> {{-0.8363764932857659, -0.5481554172668595, 0.}, {
       0.5481554172668595, -0.8363764932857659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012225610598768887`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2968392924836474, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.338107542953065`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10440376301568152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8363764932857659, -0.5481554172668595, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.172461097552453, -3.4101727141824996`, 0.}, 
      Optica`Optica`RayEnd :> {5.1639613154432675`, -3.465730359428305, 0.}, 
      RotationMatrix :> {{-0.15123070431164554`, -0.9884984947249053, 0.}, {
       0.9884984947249053, -0.15123070431164554`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008815416164352637, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05620407673080678, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.903886060792317`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.385944617000145, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.15123070431164554`, -0.9884984947249053, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1639613154432675`, -3.465730359428305, 0.}, 
      Optica`Optica`RayEnd :> {5.10378493535895, -3.621029082309203, 0.}, 
      RotationMatrix :> {{-0.36131127943792035`, -0.9324452580987974, 0.}, {
       0.9324452580987974, -0.36131127943792035`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00808866082489783, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16654996261929958`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.15038000546888, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07098924179340438, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.36131127943792035`, -0.9324452580987974, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.601170038740591, -3.55634550583027, 0.}, 
      Optica`Optica`RayEnd :> {6.628715581397982, -3.6196351682442374`, 0.}, 
      RotationMatrix :> {{0.39907087863225454`, -0.9169200803928769, 0.}, {
       0.9169200803928769, 0.39907087863225454`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017595035832233152`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06902418625934026, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.39498987191417, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39828731949020624`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.39907087863225454`, -0.9169200803928769, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.628715581397982, -3.6196351682442374`, 0.}, 
      Optica`Optica`RayEnd :> {6.770942851840212, -3.9269453409866735`, 0.}, 
      RotationMatrix :> {{0.42001180186032905`, -0.9075186423969698, 0.}, {
       0.9075186423969698, 0.42001180186032905`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01754692263322301, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3386268428941119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.896157599397455`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15056175770390537`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.42001180186032905`, -0.9075186423969698, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.638935893568386, -2.5748739356299155`, 0.}, 
      Optica`Optica`RayEnd :> {7.862015843501545, -2.566332486898788, 0.}, 
      RotationMatrix :> {{0.9992677914270247, 0.038260698066761814`, 
       0.}, {-0.038260698066761814`, 0.9992677914270247, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09044844045044562, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22324341067231224`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.925509625196536`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32685430425289225`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9992677914270247, 0.038260698066761814`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.862015843501545, -2.566332486898788, 0.}, 
      Optica`Optica`RayEnd :> {8.11164321715692, -2.5383145838870496`, 0.}, 
      RotationMatrix :> {{0.9937601082399834, 0.11153854612131314`, 
       0.}, {-0.11153854612131314`, 0.9937601082399834, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08991535508416518, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2511948020307275, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.297277932202014`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26485768119556047`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9937601082399834, 0.11153854612131314`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.17711503024882, -0.9657857867526604, 0.}, 
      Optica`Optica`RayEnd :> {8.229584526554289, -0.9331285216554779, 0.}, 
      RotationMatrix :> {{0.8489870762537798, 0.528413611060558, 
       0.}, {-0.528413611060558, 0.8489870762537798, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013319899576571198`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06180246763825286, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.07490442327143, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.360284012780347, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8489870762537798, 0.528413611060558, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.229584526554289, -0.9331285216554779, 0.}, 
      Optica`Optica`RayEnd :> {8.45538678793015, -0.7653751126454883, 0.}, 
      RotationMatrix :> {{0.8027190251372729, 0.596357415215629, 
       0.}, {-0.596357415215629, 0.8027190251372729, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013226833351632132`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2812967605162313, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.491223628835453`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4300166282610139, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8027190251372729, 0.596357415215629, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.859102310574856, 2.798613824550409, 0.}, 
      Optica`Optica`RayEnd :> {6.084440878437667, 2.8852840868237886`, 0.}, 
      RotationMatrix :> {{0.9333434102805019, 0.35898478865539984`, 
       0.}, {-0.35898478865539984`, 0.9333434102805019, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012272593066119079`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24143157318171796`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.15823698286113, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31740051551588583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9333434102805019, 0.35898478865539984`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.084440878437667, 2.8852840868237886`, 0.}, 
      Optica`Optica`RayEnd :> {6.2854634585950215`, 2.930051637924093, 0.}, 
      RotationMatrix :> {{0.9760883847367492, 0.21737402140551024`, 
       0.}, {-0.21737402140551024`, 0.9760883847367492, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011960144256608192`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2059471081725556, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.463038702956514`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03935930731727433, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9760883847367492, 0.21737402140551024`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.346900401770584, -3.2046491384338243`, 0.}, 
      Optica`Optica`RayEnd :> {4.4508501385809875`, -3.297385501936052, 0.}, 
      RotationMatrix :> {{0.7462082912063601, -0.6657125401664623, 0.}, {
       0.6657125401664623, 0.7462082912063601, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026278223647221502`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13930391558951113`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.691278936852719`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3524284632391846, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7462082912063601, -0.6657125401664623, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.4508501385809875`, -3.297385501936052, 0.}, 
      Optica`Optica`RayEnd :> {4.653245556053751, -3.501540898488227, 0.}, 
      RotationMatrix :> {{0.7040390830373959, -0.7101612278601686, 0.}, {
       0.7101612278601686, 0.7040390830373959, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026154910625220514`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.287477531218267, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.116745683055754`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3516101523972383, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7040390830373959, -0.7101612278601686, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8834535086676665`, -1.782800960434623, 0.}, 
      Optica`Optica`RayEnd :> {5.105640936272439, -1.7834163468424353`, 0.}, 
      RotationMatrix :> {{0.9999961644791919, -0.0027696618756466312`, 0.}, {
       0.0027696618756466312`, 0.9999961644791919, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008378622673319966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2221882798125435, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.027034292685485`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19973324558306274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999961644791919, -0.0027696618756466312`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.105640936272439, -1.7834163468424353`, 0.}, 
      Optica`Optica`RayEnd :> {5.421968446816875, -1.7712630858995746`, 0.}, 
      RotationMatrix :> {{0.9992627729603212, 0.038391543022520506`, 
       0.}, {-0.038391543022520506`, 0.9992627729603212, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008350282437598965, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31656088779061975`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.495544406615604`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3270774280243379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9992627729603212, 0.038391543022520506`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6246736316529993`, 2.5441255502263878`, 0.},
       Optica`Optica`RayEnd :> {3.6704688145865982`, 2.6952186852900835`, 0.},
       RotationMatrix :> {{0.2900618356378631, 0.9570079056655666, 
       0.}, {-0.9570079056655666, 0.2900618356378631, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008777254477004986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15788075957284362`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.288328402036505`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2696523370952972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2900618356378631, 0.9570079056655666, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6704688145865982`, 2.6952186852900835`, 0.},
       Optica`Optica`RayEnd :> {3.7481042170747867`, 2.8938741145769025`, 0.},
       RotationMatrix :> {{0.3639954406636548, 0.9314007296411532, 
       0.}, {-0.9314007296411532, 0.3639954406636548, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008720520321501175, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2132867443247079, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.603992783637073`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3515244692317782, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3639954406636548, 0.9314007296411532, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.990766656968944, 2.68440669863797, 0.}, 
      Optica`Optica`RayEnd :> {2.8845911525099703`, 2.7559991259945607`, 0.}, 
      RotationMatrix :> {{-0.8291239210694847, 0.5590648652082897, 
       0.}, {-0.5590648652082897, -0.8291239210694847, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3785674925660814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12805746132860127`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.685952708995982`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4251509010321577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8291239210694847, 0.5590648652082897, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8845911525099703`, 2.7559991259945607`, 0.},
       Optica`Optica`RayEnd :> {2.656496102702559, 2.8886382820148584`, 0.}, 
      RotationMatrix :> {{-0.8644647703860328, 0.5026934063237989, 
       0.}, {-0.5026934063237989, -0.8644647703860328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.37661141892337874`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2638569640097116, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.076461015730356`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4235043777685494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8644647703860328, 0.5026934063237989, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.427325078483299, 1.8400499517806694`, 0.}, 
      Optica`Optica`RayEnd :> {2.4097248437291436`, 1.8324302484370008`, 0.}, 
      RotationMatrix :> {{-0.917689966824735, -0.39729727508405777`, 0.}, {
       0.39729727508405777`, -0.917689966824735, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00858027754961896, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019178846223036998`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.370626087920837`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27359384862740427`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.917689966824735, -0.39729727508405777`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4097248437291436`, 1.8324302484370008`, 0.},
       Optica`Optica`RayEnd :> {2.1617716970949905`, 1.7234169393512568`, 0.},
       RotationMatrix :> {{-0.9154321402816424, -0.4024723550001566, 0.}, {
       0.4024723550001566, -0.9154321402816424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008558993392664983, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2708591229469698, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.77149758988235, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1762470992067214, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9154321402816424, -0.4024723550001566, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5648705308709445`, 2.67124674879148, 0.}, 
      Optica`Optica`RayEnd :> {5.588892206482666, 2.680871821839608, 0.}, 
      RotationMatrix :> {{0.92825796265734, 0.37193703064261335`, 
       0.}, {-0.37193703064261335`, 0.92825796265734, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009260588043070206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.025878232752190873`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.354569047469834`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35421427455487864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.92825796265734, 0.37193703064261335`, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.588892206482666, 2.680871821839608, 0.}, 
      Optica`Optica`RayEnd :> {5.858952183105744, 2.80193995526425, 0.}, 
      RotationMatrix :> {{0.9125007926334485, 0.4090749362199156, 
       0.}, {-0.4090749362199156, 0.9125007926334485, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009229627545588556, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2959558816860792, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.792583752365232`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41844773875045227`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9125007926334485, 0.4090749362199156, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0780660610831423`, -0.8695988186114041, 0.},
       Optica`Optica`RayEnd :> {3.0428885243697246`, -0.8680864942479819, 0.},
       RotationMatrix :> {{-0.9990771575790528, 0.04295152155350107, 
       0.}, {-0.04295152155350107, -0.9990771575790528, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025943256355949695`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03521003002276568, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.778203873165637`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0035006862417224513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9990771575790528, 0.04295152155350107, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0428885243697246`, -0.8680864942479819, 0.},
       Optica`Optica`RayEnd :> {2.8724930742377612`, -0.8881629628885982, 0.},
       RotationMatrix :> {{-0.9931303365945864, -0.1170133946842153, 0.}, {
       0.1170133946842153, -0.9931303365945864, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025117912326129387`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17157410649265215`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.032133550774763`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3654483235518655, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9931303365945864, -0.1170133946842153, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.844101538872602, -1.0632252089375354`, 0.}, 
      Optica`Optica`RayEnd :> {2.666467982513889, -1.0456368429455045`, 0.}, 
      RotationMatrix :> {{-0.9951337784093648, 0.09853305571584284, 
       0.}, {-0.09853305571584284, -0.9951337784093648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013131547885084987`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17850218755778227`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.2702635125003, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41300749439364215`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9951337784093648, 0.09853305571584284, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.666467982513889, -1.0456368429455045`, 0.}, 
      Optica`Optica`RayEnd :> {2.3099577862941993`, -1.0111371331343069`, 0.},
       RotationMatrix :> {{-0.9953503553543676, 0.09632066287113297, 
       0.}, {-0.09632066287113297, -0.9953503553543676, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013099150648358019`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3581755854125995, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.800363378910948`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05873580701699333, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9953503553543676, 0.09632066287113297, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.620435270414352, 0.8139180346299864, 0.}, 
      Optica`Optica`RayEnd :> {4.568674019498865, 0.8418032120599352, 0.}, 
      RotationMatrix :> {{-0.8803735679490369, 0.47428090922646554`, 
       0.}, {-0.47428090922646554`, -0.8803735679490369, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009299029633914253, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05879464445538948, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.221721208389955`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10100355650508407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8803735679490369, 0.47428090922646554`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.568674019498865, 0.8418032120599352, 0.}, 
      Optica`Optica`RayEnd :> {4.335307961329535, 0.9947123023651957, 0.}, 
      RotationMatrix :> {{-0.8364379841236406, 0.548061582958686, 
       0.}, {-0.548061582958686, -0.8364379841236406, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009229151067912247, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27899983333950834`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.634640961732426`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04519542216453377, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8364379841236406, 0.548061582958686, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.71725703465744, 0.3774451573715266, 0.}, 
      Optica`Optica`RayEnd :> {7.859452932420811, 0.6047336633735261, 0.}, 
      RotationMatrix :> {{0.530375951490463, 0.8477625552479806, 
       0.}, {-0.8477625552479806, 0.530375951490463, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01914383101064954, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2681039692010398, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.12177973215566, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.045688297999611376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.530375951490463, 0.8477625552479806, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.859452932420811, 0.6047336633735261, 0.}, 
      Optica`Optica`RayEnd :> {7.9507690227662335`, 0.8052219787546446, 0.}, 
      RotationMatrix :> {{0.4144989195895972, 0.9100498039442984, 
       0.}, {-0.9100498039442984, 0.4144989195895972, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018786695888718015`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22030477289503356`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.447830796040307`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34564760409268425`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.4144989195895972, 0.9100498039442984, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.939023855942025, -0.28788288655888045`, 0.},
       Optica`Optica`RayEnd :> {6.761532495199798, 0.0782594081300623, 0.}, 
      RotationMatrix :> {{-0.43620947938646315`, 0.899845147841222, 
       0.}, {-0.899845147841222, -0.43620947938646315`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013361069599816009`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.40689478136025764`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.16152095579804, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21373793523437157`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.43620947938646315`, 0.899845147841222, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.761532495199798, 0.0782594081300623, 0.}, 
      Optica`Optica`RayEnd :> {6.639163844367371, 0.35600074813492016`, 0.}, 
      RotationMatrix :> {{-0.40318702963914976`, 0.9151175985253258, 
       0.}, {-0.9151175985253258, -0.40318702963914976`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013318726843723708`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3035034409265285, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.610706048369302`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3664934676963052, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.40318702963914976`, 0.9151175985253258, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.603624631246455, -1.8298685568134114`, 0.}, 
      Optica`Optica`RayEnd :> {6.570468399754491, -1.8293367952577892`, 0.}, 
      RotationMatrix :> {{-0.9998714151570613, 0.016035995504339984`, 
       0.}, {-0.016035995504339984`, -0.9998714151570613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021461166540473097`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03316049542906071, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.083744112701684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.032392571869766976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9998714151570613, 0.016035995504339984`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.570468399754491, -1.8293367952577892`, 0.}, 
      Optica`Optica`RayEnd :> {6.364338814151551, -1.8536428419150592`, 0.}, 
      RotationMatrix :> {{-0.99311953644671, -0.11710502264152285`, 0.}, {
       0.11710502264152285`, -0.99311953644671, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021046991752128888`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20755767864607017`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.390929477097867`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3399470888392747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.99311953644671, -0.11710502264152285`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.608643324015406, -2.241089960054466, 0.}, 
      Optica`Optica`RayEnd :> {7.5302611664733945`, -2.388115128296302, 0.}, 
      RotationMatrix :> {{-0.47044213250485, -0.8824308471287076, 0.}, {
       0.8824308471287076, -0.47044213250485, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03984385138180222, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1666138131052795, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.738601903578706`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11357661473527231`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.47044213250485, -0.8824308471287076, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5302611664733945`, -2.388115128296302, 0.}, 
      Optica`Optica`RayEnd :> {7.388525244576338, -2.6663777250317304`, 0.}, 
      RotationMatrix :> {{-0.45387367276148965`, -0.891066040860045, 0.}, {
       0.891066040860045, -0.45387367276148965`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03973858991586621, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3122805538261264, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.200777123241373`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39871560456725885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.45387367276148965`, -0.891066040860045, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.079759756486173, -2.178409227415667, 0.}, 
      Optica`Optica`RayEnd :> {7.8944045676906915`, -2.180664402454299, 0.}, 
      RotationMatrix :> {{-0.9999259929988153, -0.012165875444566931`, 0.}, {
       0.012165875444566931`, -0.9999259929988153, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015663167114706073`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18536890739242967`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.67420135000824, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2622813532577894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999259929988153, -0.012165875444566931`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.8944045676906915`, -2.180664402454299, 0.}, 
      Optica`Optica`RayEnd :> {7.618630463181174, -2.1975476124328246`, 0.}, 
      RotationMatrix :> {{-0.9981312364158126, -0.061106749963001625`, 0.}, {
       0.061106749963001625`, -0.9981312364158126, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015603551854063535`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27629042599627973`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.08311118048273, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18206870889704702`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9981312364158126, -0.061106749963001625`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.241396205327685, -2.0647126153737987`, 0.}, 
      Optica`Optica`RayEnd :> {8.182546427716614, -1.895598670219838, 0.}, 
      RotationMatrix :> {{-0.3286578037792653, 0.9444490711600015, 
       0.}, {-0.9444490711600015, -0.3286578037792653, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015567117837656668`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1790609470834141, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.618495929452095`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33278382819808866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3286578037792653, 0.9444490711600015, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.182546427716614, -1.895598670219838, 0.}, 
      Optica`Optica`RayEnd :> {8.10977393330874, -1.6417027819848846`, 0.}, 
      RotationMatrix :> {{-0.27552897016149613`, 0.9612927684122798, 
       0.}, {-0.9612927684122798, -0.27552897016149613`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015500840483340902`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2641192117301588, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.00939236281273, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3614053737071096, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.27552897016149613`, 0.9612927684122798, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.13369358484671, -0.909805201904108, 0.}, 
      Optica`Optica`RayEnd :> {8.142056766957792, -0.8755510463406937, 0.}, 
      RotationMatrix :> {{0.23718397082460585`, 0.9714647517969308, 
       0.}, {-0.9714647517969308, 0.23718397082460585`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021355436346258933`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03526031747426134, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.5067364716841, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31754050249413374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.23718397082460585`, 0.9714647517969308, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.142056766957792, -0.8755510463406937, 0.}, 
      Optica`Optica`RayEnd :> {8.232240954122844, -0.5926830924116476, 0.}, 
      RotationMatrix :> {{0.30375642785201584`, 0.9527497218779878, 
       0.}, {-0.9527497218779878, 0.30375642785201584`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02123954235960414, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2968963909760879, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.94614313032871, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3548301354097768, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.30375642785201584`, 0.9527497218779878, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.631251815124599, -0.7413559237850313, 0.}, 
      Optica`Optica`RayEnd :> {6.605605728708971, -0.7000616123378564, 0.}, 
      RotationMatrix :> {{-0.5275875992442662, 0.8495006327976873, 
       0.}, {-0.8495006327976873, -0.5275875992442662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013535107918258687`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04861010086735206, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.341493887085125`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08529743818148174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5275875992442662, 0.8495006327976873, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.605605728708971, -0.7000616123378564, 0.}, 
      Optica`Optica`RayEnd :> {6.436956136237303, -0.4163147868373776, 0.}, 
      RotationMatrix :> {{-0.510930491153965, 0.8596220292716837, 
       0.}, {-0.8596220292716837, -0.510930491153965, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013499134451970375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3300832410505855, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.83001708383999, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37578139437696423`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.510930491153965, 0.8596220292716837, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.35587456765623, -1.1072220852942924`, 0.}, 
      Optica`Optica`RayEnd :> {5.178150371177928, -1.038544202537983, 0.}, 
      RotationMatrix :> {{-0.9327774609887539, 0.36045278230494116`, 
       0.}, {-0.36045278230494116`, -0.9327774609887539, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019299024477585434`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1905322586696206, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.11135288045206, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3567652211635249, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9327774609887539, 0.36045278230494116`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.178150371177928, -1.038544202537983, 0.}, 
      Optica`Optica`RayEnd :> {4.902025869288929, -0.9353251541593269, 0.}, 
      RotationMatrix :> {{-0.9366940784124226, 0.35014883045228357`, 
       0.}, {-0.35014883045228357`, -0.9366940784124226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019250282026786802`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29478621489418955`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.54763647849546, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22322174367013614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9366940784124226, 0.35014883045228357`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.56054423222673, -2.2685416838301906`, 0.}, 
      Optica`Optica`RayEnd :> {5.507209445819916, -2.3131470319159875`, 0.}, 
      RotationMatrix :> {{-0.7670905150254096, -0.6415388856164932, 0.}, {
       0.6415388856164932, -0.7670905150254096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0939624246432305, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06952867407707142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.20280749490855, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14997149424824296`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7670905150254096, -0.6415388856164932, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.507209445819916, -2.3131470319159875`, 0.}, 
      Optica`Optica`RayEnd :> {5.317042174504154, -2.496568643107816, 0.}, 
      RotationMatrix :> {{-0.7197572422136407, -0.6942258366562098, 0.}, {
       0.6942258366562098, -0.7197572422136407, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09343608168659631, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2642102922520029, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.593838727441515`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09091987148562042, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7197572422136407, -0.6942258366562098, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.212331653106352, -0.0695994659840488, 0.}, 
      Optica`Optica`RayEnd :> {4.165340332262248, -0.05949132258521739, 0.}, 
      RotationMatrix :> {{-0.9776376918757037, 0.21029632289687455`, 
       0.}, {-0.21029632289687455`, -0.9776376918757037, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012615619355837918`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04806619183630821, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.986512996004038`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23765759323416275`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9776376918757037, 0.21029632289687455`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.165340332262248, -0.05949132258521739, 0.}, 
      Optica`Optica`RayEnd :> {3.865264422165415, 0.015582195435765321`, 0.}, 
      RotationMatrix :> {{-0.9701009985748249, 0.24270157099641432`, 
       0.}, {-0.24270157099641432`, -0.9701009985748249, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012577171129079178`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30932440079710827`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.444313109183756`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0307684841697958, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9701009985748249, 0.24270157099641432`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.448658799778517, 2.1357213457488884`, 0.}, 
      Optica`Optica`RayEnd :> {6.493406679852289, 2.34785971181047, 0.}, 
      RotationMatrix :> {{0.20639547129876512`, 0.9784686553116354, 
       0.}, {-0.9784686553116354, 0.20639547129876512`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011796908609508758`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21680650157773018`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.788332142480726`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1781521566120714, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.20639547129876512`, 0.9784686553116354, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.493406679852289, 2.34785971181047, 0.}, 
      Optica`Optica`RayEnd :> {6.547614972963494, 2.660373650005636, 0.}, 
      RotationMatrix :> {{0.17090673844000404`, 0.9852872102873351, 
       0.}, {-0.9852872102873351, 0.17090673844000404`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011759641439691458`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3171805489122595, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.25775935487087, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.010404187125226614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17090673844000404`, 0.9852872102873351, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1162682073205294`, 2.5548130859784597`, 0.},
       Optica`Optica`RayEnd :> {7.065798112577622, 2.833912076653831, 0.}, 
      RotationMatrix :> {{-0.17794619375455054`, 0.9840402187554469, 
       0.}, {-0.9840402187554469, -0.17794619375455054`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020972257656129187`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2836255930965488, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.605306509233532`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1474531820625877, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.17794619375455054`, 0.9840402187554469, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.065798112577622, 2.833912076653831, 0.}, 
      Optica`Optica`RayEnd :> {7.015837296923768, 3.1035802932107157`, 0.}, 
      RotationMatrix :> {{-0.18216772268147102`, 0.9832674716541001, 
       0.}, {-0.9832674716541001, -0.18216772268147102`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02092037523015651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2742572334903296, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.01120721479922, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3088201502899563, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18216772268147102`, 0.9832674716541001, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6055738337734273`, 0.6567341618634729, 0.}, 
      Optica`Optica`RayEnd :> {2.4061119345070474`, 0.7531081223307664, 0.}, 
      RotationMatrix :> {{-0.9004066463864504, 0.43504927438521857`, 
       0.}, {-0.43504927438521857`, -0.9004066463864504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10822466444132209`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22152424137123883`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.529295743295144`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31970832488624273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9004066463864504, 0.43504927438521857`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4061119345070474`, 0.7531081223307664, 0.}, 
      Optica`Optica`RayEnd :> {2.1844334948319033`, 0.8577212354772984, 0.}, 
      RotationMatrix :> {{-0.9043563185988853, 0.4267782199342781, 
       0.}, {-0.4267782199342781, -0.9043563185988853, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1079533728649814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2451228958278188, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.892077629120315`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2520744910538141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9043563185988853, 0.4267782199342781, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8962224611401854`, -1.5783964706025564`, 
       0.}, Optica`Optica`RayEnd :> {3.750287447374651, -1.6648115713326714`, 
       0.}, RotationMatrix :> {{-0.8604593336881885, -0.509519121396713, 
       0.}, {0.509519121396713, -0.8604593336881885, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04162120841637863, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1696012909058852, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.722224240310462`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07376429116319622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8604593336881885, -0.509519121396713, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.750287447374651, -1.6648115713326714`, 0.}, 
      Optica`Optica`RayEnd :> {3.566128926377194, -1.7924870565715108`, 0.}, 
      RotationMatrix :> {{-0.8218137376088763, -0.569756246720761, 0.}, {
       0.569756246720761, -0.8218137376088763, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0413847438651463, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22408790772137577`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.053874343738098`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.008575502225023844, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8218137376088763, -0.569756246720761, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.421649245250298, -3.0825725534329287`, 0.}, 
      Optica`Optica`RayEnd :> {5.532067868258321, -3.3615206858124775`, 0.}, 
      RotationMatrix :> {{0.3680532172171919, -0.9298047264324234, 0.}, {
       0.9298047264324234, 0.3680532172171919, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01609940323919443, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3000072213547975, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.12263973064802, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11240053943223138`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3680532172171919, -0.9298047264324234, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.532067868258321, -3.3615206858124775`, 0.}, 
      Optica`Optica`RayEnd :> {5.613537725456426, -3.6216851368345666`, 0.}, 
      RotationMatrix :> {{0.2988379113159399, -0.9543038838652631, 0.}, {
       0.9543038838652631, 0.2988379113159399, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01600462836506241, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.272622228014343, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.52612062810925, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18555796744916417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2988379113159399, -0.9543038838652631, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.016042773262057, -1.6516751997741703`, 0.}, 
      Optica`Optica`RayEnd :> {7.108282798810705, -1.7348892010832604`, 0.}, 
      RotationMatrix :> {{0.7425011976910184, -0.6698447368065256, 0.}, {
       0.6698447368065256, 0.7425011976910184, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01174262446037085, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12422879025042678`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.82166709470074, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20869081012353552`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7425011976910184, -0.6698447368065256, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.108282798810705, -1.7348892010832604`, 0.}, 
      Optica`Optica`RayEnd :> {7.322692665885227, -1.9171446844618552`, 0.}, 
      RotationMatrix :> {{0.7619268734991144, -0.6476630601168056, 0.}, {
       0.6476630601168056, 0.7619268734991144, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011708367027352314`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2814047837554994, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.23814617465888, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0343394689202492, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7619268734991144, -0.6476630601168056, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.262747380025582, 2.9608335378144637`, 0.}, 
      Optica`Optica`RayEnd :> {3.930376204807889, 3.179382975753243, 0.}, 
      RotationMatrix :> {{-0.8355507338847508, 0.5494132971676727, 
       0.}, {-0.5494132971676727, -0.8355507338847508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00928084755918825, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3977869466673669, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.553651359591424`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25845238323337094`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8355507338847508, 0.5494132971676727, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.930376204807889, 3.179382975753243, 0.}, 
      Optica`Optica`RayEnd :> {3.6460075670016345`, 3.363384076381549, 0.}, 
      RotationMatrix :> {{-0.839573032911366, 0.5432468337763318, 
       0.}, {-0.5432468337763318, -0.839573032911366, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009257721782905237, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3387062550355585, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.05493661704405, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30045246954213983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.839573032911366, 0.5432468337763318, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.976035586645406, 2.6360109109681593`, 0.}, 
      Optica`Optica`RayEnd :> {6.965115949693173, 2.849766562718292, 0.}, 
      RotationMatrix :> {{-0.0510181438925025, 0.9986977265387977, 
       0.}, {-0.9986977265387977, -0.0510181438925025, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015965759604935754`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21403438304695957`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47260046649986, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4297214390702765, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.0510181438925025, 0.9986977265387977, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.965115949693173, 2.849766562718292, 0.}, 
      Optica`Optica`RayEnd :> {6.967666509375516, 3.0871540433788582`, 0.}, 
      RotationMatrix :> {{0.010743668832124131`, 0.9999422851245091, 
       0.}, {-0.9999422851245091, 0.010743668832124131`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015890154412593283`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2374011822402405, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.823954216215416`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4308799211257419, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {0.010743668832124131`, 0.9999422851245091, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.575596281441464, -2.0742213214166454`, 0.}, 
      Optica`Optica`RayEnd :> {7.497597923677322, -2.381853343242259, 0.}, 
      RotationMatrix :> {{-0.24576781199588527`, -0.9693287278249595, 0.}, {
       0.9693287278249595, -0.24576781199588527`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12507112856901748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3173660420814079, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.541612334796802`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2126192554037235, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.24576781199588527`, -0.9693287278249595, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.497597923677322, -2.381853343242259, 0.}, 
      Optica`Optica`RayEnd :> {7.425253906713074, -2.687134026360825, 0.}, 
      RotationMatrix :> {{-0.23058921052332987`, -0.9730511887820839, 0.}, {
       0.9730511887820839, -0.23058921052332987`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1247474454342944, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31373548137859986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.00594084723713, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39308645346398935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.23058921052332987`, -0.9730511887820839, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.300925599643978, 1.8751161064027455`, 0.}, 
      Optica`Optica`RayEnd :> {8.213321694087746, 2.097332886682772, 0.}, 
      RotationMatrix :> {{-0.3667563116383905, 0.9303170469648527, 
       0.}, {-0.9303170469648527, -0.3667563116383905, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040650469734116866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23886134410307297`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.24026195575528, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24754598962663643`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3667563116383905, 0.9303170469648527, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.213321694087746, 2.097332886682772, 0.}, 
      Optica`Optica`RayEnd :> {8.118134773638745, 2.367199620738484, 0.}, 
      RotationMatrix :> {{-0.33263316089710765`, 0.9430562975091142, 
       0.}, {-0.9430562975091142, -0.33263316089710765`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040521575965739895`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2861618492644697, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.663781492666693`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3911238325894945, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.33263316089710765`, 0.9430562975091142, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.597317163585998, 0.2927098512295937, 0.}, 
      Optica`Optica`RayEnd :> {6.363415043055312, 0.4016498220837778, 0.}, 
      RotationMatrix :> {{-0.9065012301352761, 0.4222031735589295, 
       0.}, {-0.4222031735589295, -0.9065012301352761, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008716130687246871, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25802736141437055`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.468319312903038`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16870288229024524`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9065012301352761, 0.4222031735589295, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.363415043055312, 0.4016498220837778, 0.}, 
      Optica`Optica`RayEnd :> {6.182146425329703, 0.4503276617857824, 0.}, 
      RotationMatrix :> {{-0.9657830781776701, 0.259351201858917, 
       0.}, {-0.259351201858917, -0.9657830781776701, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008365667326248064, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18769081983466027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.746101726258335`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38108435458283085`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9657830781776701, 0.259351201858917, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.063027041023098, -0.7413790643896072, 0.}, 
      Optica`Optica`RayEnd :> {4.900853631799341, -0.7909446785446752, 0.}, 
      RotationMatrix :> {{-0.9563307578392378, -0.2922866428878143, 0.}, {
       0.2922866428878143, -0.9563307578392378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015605746006908698`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16957878630838516`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.395551937797364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23792348753095166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9563307578392378, -0.2922866428878143, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.900853631799341, -0.7909446785446752, 0.}, 
      Optica`Optica`RayEnd :> {4.68166825234663, -0.834249674863952, 0.}, 
      RotationMatrix :> {{-0.9810359820309461, -0.1938256999486313, 0.}, {
       0.1938256999486313, -0.9810359820309461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015445256537428079`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22342236520107325`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.72621703829495, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40418897433777323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9810359820309461, -0.1938256999486313, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.87725476830333, -1.3985091703707337`, 0.}, 
      Optica`Optica`RayEnd :> {6.876882042036348, -1.4007800698946995`, 0.}, 
      RotationMatrix :> {{-0.1619644577872173, -0.9867965922183213, 0.}, {
       0.9867965922183213, -0.1619644577872173, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.264418322839897, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0023012843192544512`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.130875244310523`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42661951025617784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1619644577872173, -0.9867965922183213, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.876882042036348, -1.4007800698946995`, 0.}, 
      Optica`Optica`RayEnd :> {6.857503797053943, -1.631596318035911, 0.}, 
      RotationMatrix :> {{-0.08366096566611052, -0.9964942763627963, 0.}, {
       0.9964942763627963, -0.08366096566611052, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2626869904616622, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23162827285239468`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.473685088132068`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37716964211625614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.08366096566611052, -0.9964942763627963, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.665234411496248, -1.0794506771927341`, 0.}, 
      Optica`Optica`RayEnd :> {7.68024549226014, -1.1129053057541303`, 0.}, 
      RotationMatrix :> {{0.40937784560109597`, -0.9123649376927001, 0.}, {
       0.9123649376927001, 0.40937784560109597`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2783195089094803, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036668034006217154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.786482594137274`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38893890680898513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.40937784560109597`, -0.9123649376927001, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.68024549226014, -1.1129053057541303`, 0.}, 
      Optica`Optica`RayEnd :> {7.821491369572861, -1.4078409622156671`, 0.}, 
      RotationMatrix :> {{0.43192753445733145`, -0.901908312955153, 0.}, {
       0.901908312955153, 0.43192753445733145`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2775450987620716, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3270129038894914, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.270461691893722`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15246060768330844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.43192753445733145`, -0.901908312955153, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4586303530034055`, -0.17982614486075948`, 
       0.}, Optica`Optica`RayEnd :> {7.409973767999245, -0.34290258960178854`,
        0.}, RotationMatrix :> {{-0.2859116966586871, -0.958255968785872, 
       0.}, {0.958255968785872, -0.2859116966586871, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025178007031378655`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17018046331362782`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.520253130152007`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4151877154242266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.2859116966586871, -0.958255968785872, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.409973767999245, -0.34290258960178854`, 0.},
       Optica`Optica`RayEnd :> {7.360966391982671, -0.5777872347677663, 0.}, 
      RotationMatrix :> {{-0.20424612808853926`, -0.9789195672581273, 0.}, {
       0.9789195672581273, -0.20424612808853926`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024994843945423804`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23994274200062227`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.875368388312928`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32334119964894126`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.20424612808853926`, -0.9789195672581273, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.093840169841501, 0.11788342776077729`, 0.}, 
      Optica`Optica`RayEnd :> {8.099263833995069, 0.11815372593931085`, 0.}, 
      RotationMatrix :> {{0.9987604541717333, 0.04977504578272464, 
       0.}, {-0.04977504578272464, 0.9987604541717333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021064131802596874`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005430395377504411, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.596170902195922`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3117605499310523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9987604541717333, 0.04977504578272464, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.099263833995069, 0.11815372593931085`, 0.}, 
      Optica`Optica`RayEnd :> {8.367052651840087, 0.14943348693084343`, 0.}, 
      RotationMatrix :> {{0.993247021072944, 0.11601877059218449`, 
       0.}, {-0.11601877059218449`, 0.993247021072944, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02095541557519201, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26960948501586435`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.995192940019402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2850059605725839, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.993247021072944, 0.11601877059218449`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.569808117033248, 1.2291413933762683`, 0.}, 
      Optica`Optica`RayEnd :> {6.364174656875045, 1.2860135822578602`, 0.}, 
      RotationMatrix :> {{-0.9638173234752536, 0.26656362649280835`, 
       0.}, {-0.26656362649280835`, -0.9638173234752536, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012492412889860909`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2133531481014958, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.366037632906421`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4067793370673723, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9638173234752536, 0.26656362649280835`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.364174656875045, 1.2860135822578602`, 0.}, 
      Optica`Optica`RayEnd :> {6.075636979375578, 1.354708650666049, 0.}, 
      RotationMatrix :> {{-0.972809540916189, 0.23160655669136987`, 
       0.}, {-0.23160655669136987`, -0.972809540916189, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012452970345813984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29660243384097834`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.805009234991068`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2674582932997668, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.972809540916189, 0.23160655669136987`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.61876224892598, 0.6526344388411479, 0.}, 
      Optica`Optica`RayEnd :> {6.586204528821855, 0.5932172930600468, 0.}, 
      RotationMatrix :> {{-0.4805389649281757, -0.876973376554703, 0.}, {
       0.876973376554703, -0.4805389649281757, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1778049399379028, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06775250808015246, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.458442537207624`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25619570033372197`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4805389649281757, -0.876973376554703, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.586204528821855, 0.5932172930600468, 0.}, 
      Optica`Optica`RayEnd :> {6.462835957629652, 0.3962580859494457, 0.}, 
      RotationMatrix :> {{-0.5308312184649676, -0.8474775616516329, 0.}, {
       0.8474775616516329, -0.5308312184649676, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17701340302364668`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23240639755317058`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.802404005586316`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2745115317341724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5308312184649676, -0.8474775616516329, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.150151747661281, 0.39767247546671286`, 0.}, 
      Optica`Optica`RayEnd :> {7.1720769430198406`, 0.31847101385484194`, 0.},
       RotationMatrix :> {{0.2667941261135189, -0.9637535443625217, 0.}, {
       0.9637535443625217, 0.2667941261135189, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010760883104749801`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0821802026826879, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.819019241288329`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3588969220284815, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.2667941261135189, -0.9637535443625217, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1720769430198406`, 0.31847101385484194`, 
       0.}, Optica`Optica`RayEnd :> {7.234378837136803, 0.09399011306815416, 
       0.}, RotationMatrix :> {{0.267429019901665, -0.963577562687319, 0.}, {
       0.963577562687319, 0.267429019901665, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010734358805697898`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23296609373160737`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.163809060011108`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12814438205427953`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.267429019901665, -0.963577562687319, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.184201931052216, 2.420319605206351, 0.}, 
      Optica`Optica`RayEnd :> {7.133875783682815, 2.4995612934954696`, 0.}, 
      RotationMatrix :> {{-0.5361141523727072, 0.8441454943466159, 
       0.}, {-0.8441454943466159, -0.5361141523727072, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3653634688767773`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0938720739728087, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.669176696128805`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39981593282677375`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5361141523727072, 0.8441454943466159, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.133875783682815, 2.4995612934954696`, 0.}, 
      Optica`Optica`RayEnd :> {7.013927724321256, 2.6322695172548927`, 0.}, 
      RotationMatrix :> {{-0.6705404129683545, 0.7418730043452365, 
       0.}, {-0.7418730043452365, -0.6705404129683545, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3145257902223082`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17888266992077553`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.933923047611552`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14879189973604445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6705404129683545, 0.7418730043452365, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.013927724321256, 2.6322695172548927`, 0.}, 
      Optica`Optica`RayEnd :> {6.848681154583996, 2.563767102786102, 0.}, 
      RotationMatrix :> {{-0.9237707029442557, -0.38294606458596026`, 0.}, {
       0.38294606458596026`, -0.9237707029442557, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04894479838493547, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17888266992077556`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.1986693990943, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2670283460243132, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9237707029442557, -0.38294606458596026`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.585569373781221, 2.3098714954677755`, 0.}, 
      Optica`Optica`RayEnd :> {7.496013510024986, 2.3292753428951984`, 0.}, 
      RotationMatrix :> {{-0.9773229662449039, 0.2117541490744905, 
       0.}, {-0.2117541490744905, -0.9773229662449039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26286243769164735`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09163384761163247, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.152044456531705`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1333956446900742, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9773229662449039, 0.2117541490744905, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.496013510024986, 2.3292753428951984`, 0.}, 
      Optica`Optica`RayEnd :> {7.311736426290701, 2.4019540191871216`, 0.}, 
      RotationMatrix :> {{-0.9302625523342098, 0.36689451307513515`, 
       0.}, {-0.36689451307513515`, -0.9302625523342098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25418655224553155`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19809147780043143`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.445219843676345`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2680974061341959, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9302625523342098, 0.36689451307513515`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.311736426290701, 2.4019540191871216`, 0.}, 
      Optica`Optica`RayEnd :> {7.324263802301104, 2.5996489822677544`, 0.}, 
      RotationMatrix :> {{0.06324035818957935, 0.997998325197018, 
       0.}, {-0.997998325197018, 0.06324035818957935, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008389534193592906, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1980914778004315, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.738395230820984`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31922695164775433`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06324035818957935, 0.997998325197018, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.226143229094154, 1.6084734436314265`, 0.}, 
      Optica`Optica`RayEnd :> {8.210443865659897, 1.4367162884544131`, 0.}, 
      RotationMatrix :> {{-0.09102496632144297, -0.9958486107366817, 0.}, {
       0.9958486107366817, -0.09102496632144297, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2609142231095817, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17247315839498492`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.08691566183702, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4267916108066211, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.09102496632144297, -0.9958486107366817, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.210443865659897, 1.4367162884544131`, 0.}, 
      Optica`Optica`RayEnd :> {8.201544877431438, 1.1301121692279588`, 0.}, 
      RotationMatrix :> {{-0.02901214211915975, -0.9995790592092536, 0.}, {
       0.9995790592092536, -0.02901214211915975, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25967082701411404`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3067332357572619, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.540880850757766`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42435399882999014`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.02901214211915975, -0.9995790592092536, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.084613540559982, 0.6849672883762922, 0.}, 
      Optica`Optica`RayEnd :> {8.074604986041667, 0.6682651451625644, 0.}, 
      RotationMatrix :> {{-0.5140148994875186, -0.8577812559766247, 0.}, {
       0.8577812559766247, -0.5140148994875186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07592309495952186, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019471331528119692`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.150550822406238`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09102021759033675, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5140148994875186, -0.8577812559766247, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.074604986041667, 0.6682651451625644, 0.}, 
      Optica`Optica`RayEnd :> {7.911408050797058, 0.38375460538032846`, 0.}, 
      RotationMatrix :> {{-0.49756206815710197`, -0.8674283764848986, 0.}, {
       0.8674283764848986, -0.49756206815710197`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0757219415205776, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32799312023335564`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.635980640351605`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3820877203564579, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.49756206815710197`, -0.8674283764848986, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.517440732883323, 0.8653015214522295, 0.}, 
      Optica`Optica`RayEnd :> {7.419272103491942, 0.6395345000659645, 0.}, 
      RotationMatrix :> {{-0.39875704426700465`, -0.9170566065665966, 0.}, {
       0.9170566065665966, -0.39875704426700465`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024443425565811028`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24618657100298622`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.87072751202185, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34834329895625843`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39875704426700465`, -0.9170566065665966, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.419272103491942, 0.6395345000659645, 0.}, 
      Optica`Optica`RayEnd :> {7.3181519197722915`, 0.352797237396545, 0.}, 
      RotationMatrix :> {{-0.3325826152751267, -0.9430741243490653, 0.}, {
       0.9430741243490653, -0.3325826152751267, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024305773443645085`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30404530806879365`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.320714567963666`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30081704166295686`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3325826152751267, -0.9430741243490653, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.432955462470727, -0.16461433324118624`, 0.},
       Optica`Optica`RayEnd :> {7.455973551255673, -0.3288069164334586, 0.}, 
      RotationMatrix :> {{0.13883197427914748`, -0.9903159510569105, 0.}, {
       0.9903159510569105, 0.13883197427914748`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19819493285909787`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16579818089069295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.133709407075635`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3073894487485443, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.13883197427914748`, -0.9903159510569105, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.455973551255673, -0.3288069164334586, 0.}, 
      Optica`Optica`RayEnd :> {7.4981801653118625`, -0.6300356770624768, 0.}, 
      RotationMatrix :> {{0.13875936859639051`, -0.9903261269030168, 0.}, {
       0.9903261269030168, 0.13875936859639051`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19770644826205294`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3041712749425599, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.583882893990623`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18717165418607418`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13875936859639051`, -0.9903261269030168, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.095547716240053, 1.1493290099655205`, 0.}, 
      Optica`Optica`RayEnd :> {5.079872856413603, 1.1491620785190124`, 0.}, 
      RotationMatrix :> {{-0.999943297520989, -0.010649025441330812`, 0.}, {
       0.010649025441330812`, -0.999943297520989, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3339796957629762, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.015675748680260563`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.021242563018667`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026120558655982166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999943297520989, -0.010649025441330812`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.079872856413603, 1.1491620785190124`, 0.}, 
      Optica`Optica`RayEnd :> {4.884183329433145, 1.1158944386613112`, 0.}, 
      RotationMatrix :> {{-0.985855496842639, -0.1675975517278003, 0.}, {
       0.1675975517278003, -0.985855496842639, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.32382384725927527`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1984971708401334, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.315018375862063`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3454300311418324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.985855496842639, -0.1675975517278003, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.884183329433145, 1.1158944386613112`, 0.}, 
      Optica`Optica`RayEnd :> {4.859839177235601, 0.9188957354033456, 0.}, 
      RotationMatrix :> {{-0.12264231321034846`, -0.9924509373316214, 0.}, {
       0.9924509373316214, -0.12264231321034846`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00984702356572182, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19849717084013352`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.60879418870546, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2470390956721223, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.12264231321034846`, -0.9924509373316214, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.349677723758777, 0.9390518793580136, 0.}, 
      Optica`Optica`RayEnd :> {4.172850117231622, 0.9655380592388819, 0.}, 
      RotationMatrix :> {{-0.9889674768101342, 0.14813281139503, 
       0.}, {-0.14813281139503, -0.9889674768101342, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2842144583096899, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17880022414640354`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.50043490522976, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25943754088513055`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9889674768101342, 0.14813281139503, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.172850117231622, 0.9655380592388819, 0.}, 
      Optica`Optica`RayEnd :> {3.8771242751091632`, 1.0203648055844956`, 0.}, 
      RotationMatrix :> {{-0.9832446582159893, 0.1822908173488759, 
       0.}, {-0.1822908173488759, -0.9832446582159893, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2833336055578053, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3007652669672541, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.945567500341294`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06731073290374089, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9832446582159893, 0.1822908173488759, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3824431749592, 1.0217437832545335`, 0.}, 
      Optica`Optica`RayEnd :> {3.1976610322841617`, 0.995866649072636, 0.}, 
      RotationMatrix :> {{-0.9903361278218381, -0.1386879732739911, 0.}, {
       0.1386879732739911, -0.9903361278218381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28852975875938647`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1865852789612463, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.082678048186164`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4244514659287972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9903361278218381, -0.1386879732739911, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1976610322841617`, 0.995866649072636, 0.}, 
      Optica`Optica`RayEnd :> {2.851433958250631, 0.9509216586411364, 0.}, 
      RotationMatrix :> {{-0.9916792289351448, -0.1287334723317752, 0.}, {
       0.1287334723317752, -0.9916792289351448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2878040356395935, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3491321224962084, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.599393589480552`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11150058263939108`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9916792289351448, -0.1287334723317752, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.645263755494122, -1.866185420573217, 0.}, 
      Optica`Optica`RayEnd :> {6.699133125138902, -2.0989175663572746`, 0.}, 
      RotationMatrix :> {{0.2255031258269043, -0.9742424442828871, 0.}, {
       0.9742424442828871, 0.2255031258269043, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009077373524557748, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23888524581308446`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.833972441003787`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38503987735744505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2255031258269043, -0.9742424442828871, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.699133125138902, -2.0989175663572746`, 0.}, 
      Optica`Optica`RayEnd :> {6.773314947406275, -2.362531201942003, 0.}, 
      RotationMatrix :> {{0.27088258019182554`, -0.9626123974625603, 0.}, {
       0.9626123974625603, 0.27088258019182554`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009043961861891115, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27385231717315495`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.239273870420057`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30924098339056266`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.27088258019182554`, -0.9626123974625603, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.211612833848461, 3.428151601916212, 0.}, 
      Optica`Optica`RayEnd :> {7.235215586903052, 3.562892476138304, 0.}, 
      RotationMatrix :> {{0.1725441807826435, 0.9850017795303952, 
       0.}, {-0.9850017795303952, 0.1725441807826435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1775323864292164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13679251857426092`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.73767682213731, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39348733498682553`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1725441807826435, 0.9850017795303952, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.235215586903052, 3.562892476138304, 0.}, 
      Optica`Optica`RayEnd :> {7.295863451371103, 3.872524143458744, 0.}, 
      RotationMatrix :> {{0.19221843072580141`, 0.9813521665993861, 
       0.}, {-0.9813521665993861, 0.19221843072580141`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17705865641862906`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3155153449076142, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.204639532600577`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2480258638308131, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19221843072580141`, 0.9813521665993861, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.560121556279733, 3.120599832514311, 0.}, 
      Optica`Optica`RayEnd :> {6.598423449002021, 3.4356287083046526`, 0.}, 
      RotationMatrix :> {{0.12069337918833256`, 0.9926898348528108, 
       0.}, {-0.9926898348528108, 0.12069337918833256`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09262207114120274, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31734874754414283`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47739003371572, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22914184097202328`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12069337918833256`, 0.9926898348528108, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.598423449002021, 3.4356287083046526`, 0.}, 
      Optica`Optica`RayEnd :> {6.590262861182729, 3.6107477297384736`, 0.}, 
      RotationMatrix :> {{-0.04654972066873944, 0.99891597419686, 
       0.}, {-0.99891597419686, -0.04654972066873944, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08926632481016271, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17530906097944668`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.736847443965303`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1868199769463598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04654972066873944, 0.99891597419686, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.138474141033417, 2.894172329501781, 0.}, 
      Optica`Optica`RayEnd :> {4.080013278153141, 2.925462430168098, 0.}, 
      RotationMatrix :> {{-0.8816570535010593, 0.4718907076981169, 
       0.}, {-0.4718907076981169, -0.8816570535010593, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8533964366538942`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0663079398595281, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.22529123492765, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33679971398517483`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8816570535010593, 0.4718907076981169, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.080013278153141, 2.925462430168098, 0.}, 
      Optica`Optica`RayEnd :> {3.8485975650478776`, 3.044158711728051, 0.}, 
      RotationMatrix :> {{-0.8897838057480901, 0.45638227291213257`, 
       0.}, {-0.45638227291213257`, -0.8897838057480901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8485406563067763`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26008083268125864`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.610210867295912`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2984857007991393, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8897838057480901, 0.45638227291213257`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.821355136964984, 2.914793700563985, 0.}, 
      Optica`Optica`RayEnd :> {4.75847914606916, 3.0799802186572953`, 0.}, 
      RotationMatrix :> {{-0.3557373755010468, 0.9345859616277286, 
       0.}, {-0.9345859616277286, -0.3557373755010468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4221363429971257, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17674834084348112`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.78953336504679, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30150898145526744`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3557373755010468, 0.9345859616277286, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.75847914606916, 3.0799802186572953`, 0.}, 
      Optica`Optica`RayEnd :> {4.667391997490735, 3.360284447263403, 0.}, 
      RotationMatrix :> {{-0.30905008861815875`, 0.9510457626871103, 
       0.}, {-0.9510457626871103, -0.30905008861815875`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.420515972296579, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2947326402192554, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.225737672571288`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36513874472619706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.30905008861815875`, 0.9510457626871103, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.30327979785749, 3.0437173209918855`, 0.}, 
      Optica`Optica`RayEnd :> {5.300767807755573, 3.1573029335704743`, 0.}, 
      RotationMatrix :> {{-0.0221099836056744, 0.9997555444332158, 
       0.}, {-0.9997555444332158, -0.0221099836056744, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015808362976243297`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11361338600325836`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.031921410270808`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13064382831447385`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.0221099836056744, 0.9997555444332158, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.300767807755573, 3.1573029335704743`, 0.}, 
      Optica`Optica`RayEnd :> {5.277758717143984, 3.366557381576849, 0.}, 
      RotationMatrix :> {{-0.10929871360017601`, 0.9940089492581773, 
       0.}, {-0.9940089492581773, -0.10929871360017601`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015685949146524682`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21051565799537336`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.34348458410396, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0226527144928818, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10929871360017601`, 0.9940089492581773, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.4372327959670805`, 3.147729248239088, 0.}, 
      Optica`Optica`RayEnd :> {5.668793819653014, 3.263500829221451, 0.}, 
      RotationMatrix :> {{0.8944409893174275, 0.4471859978005355, 
       0.}, {-0.4471859978005355, 0.8944409893174275, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23656307409766864`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25888910107154606`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.47758894943995, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06448776702018966, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8944409893174275, 0.4471859978005355, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.668793819653014, 3.263500829221451, 0.}, 
      Optica`Optica`RayEnd :> {5.898000674453068, 3.368881404682121, 0.}, 
      RotationMatrix :> {{0.9085725735222924, 0.41772703843907166`, 
       0.}, {-0.41772703843907166`, 0.9085725735222924, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.235847264520867, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25227137763082674`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.850950588333575`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15474135213146342`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9085725735222924, 0.41772703843907166`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.5885091764360935`, 3.0710654143640497`, 0.},
       Optica`Optica`RayEnd :> {5.751131827436362, 2.943367950001699, 0.}, 
      RotationMatrix :> {{0.7865003355000915, -0.6175898495427553, 0.}, {
       0.6175898495427553, 0.7865003355000915, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013993449232803616`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2067674273741609, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.658743987663097`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09930163484113105, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7865003355000915, -0.6175898495427553, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.751131827436362, 2.943367950001699, 0.}, 
      Optica`Optica`RayEnd :> {5.8574455005292645`, 2.816628517706533, 0.}, 
      RotationMatrix :> {{0.6426693405359817, -0.7661436671637024, 0.}, {
       0.7661436671637024, 0.6426693405359817, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013015058505972097`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16542515160943796`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.903573212045064`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39115727417861346`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6426693405359817, -0.7661436671637024, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3812716959614155`, 2.6789453650180284`, 0.},
       Optica`Optica`RayEnd :> {5.58057510902941, 2.6898228005408806`, 0.}, 
      RotationMatrix :> {{0.9985139799401893, 0.054496163754909815`, 
       0.}, {-0.054496163754909815`, 0.9985139799401893, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1649111347559417, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.199600022705674, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.064631093882564`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32597131511329774`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9985139799401893, 0.054496163754909815`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.58057510902941, 2.6898228005408806`, 0.}, 
      Optica`Optica`RayEnd :> {5.8427720735431, 2.7228770601336127`, 0.}, 
      RotationMatrix :> {{0.9921470962123676, 0.1250765344793572, 
       0.}, {-0.1250765344793572, 0.9921470962123676, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16398664728395093`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2642722692175938, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.455754052324604`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2772924076062639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9921470962123676, 0.1250765344793572, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.644278954911342, 1.9798251660506894`, 0.}, 
      Optica`Optica`RayEnd :> {5.730922672863257, 1.8407078588253922`, 0.}, 
      RotationMatrix :> {{0.5286618112346851, -0.8488325449357259, 0.}, {
       0.8488325449357259, 0.5286618112346851, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10232167098973927`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16389252280122124`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.82663429203291, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17835237223782396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5286618112346851, -0.8488325449357259, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.730922672863257, 1.8407078588253922`, 0.}, 
      Optica`Optica`RayEnd :> {5.820946895856471, 1.666690518766145, 0.}, 
      RotationMatrix :> {{0.45948434116543396`, -0.8881858703130591, 0.}, {
       0.8881858703130591, 0.45948434116543396`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.101642624684561, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19592446342105305`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.116602497896068`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27821825781373793`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.45948434116543396`, -0.8881858703130591, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.118213821951841, 2.1161797360726418`, 0.}, 
      Optica`Optica`RayEnd :> {5.116121369485934, 2.0659492119851817`, 0.}, 
      RotationMatrix :> {{-0.04162089370699612, -0.999133475170875, 0.}, {
       0.999133475170875, -0.04162089370699612, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06301951992816199, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05027408783282901, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.307527292841275`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07495256615002514, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.04162089370699612, -0.999133475170875, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.116121369485934, 2.0659492119851817`, 0.}, 
      Optica`Optica`RayEnd :> {5.092211361633606, 1.8481257845740613`, 0.}, 
      RotationMatrix :> {{-0.10911246465281621`, -0.9940294110625634, 0.}, {
       0.9940294110625634, -0.10911246465281621`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06268682856734187, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21913177315174076`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.63184231710585, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03406756533917754, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.10911246465281621`, -0.9940294110625634, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.60282190644634, 2.1683820226624086`, 0.}, 
      Optica`Optica`RayEnd :> {4.528702525048912, 2.134656689007143, 0.}, 
      RotationMatrix :> {{-0.9102058556996427, -0.41415613028190246`, 0.}, {
       0.41415613028190246`, -0.9102058556996427, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03959662513359669, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08143144864790507, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.754575149338795`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27251486922707746`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9102058556996427, -0.41415613028190246`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.528702525048912, 2.1346566890071426`, 0.}, 
      Optica`Optica`RayEnd :> {4.387311192534063, 2.0334509906640714`, 0.}, 
      RotationMatrix :> {{-0.8131567068985361, -0.5820448178842651, 0.}, {
       0.5820448178842651, -0.8131567068985361, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037343383810377724`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1738795625927131, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.01191690197601, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18598942227035675`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8131567068985361, -0.5820448178842651, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.108774052035784, 2.8195567145089377`, 0.}, 
      Optica`Optica`RayEnd :> {4.033330609019542, 2.859855657210858, 0.}, 
      RotationMatrix :> {{-0.8820496370399158, 0.47115648971201873`, 
       0.}, {-0.47115648971201873`, -0.8820496370399158, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024574604969250673`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08553196991206077, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.48091196715625, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05908773368640745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8820496370399158, 0.47115648971201873`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.033330609019542, 2.859855657210858, 0.}, 
      Optica`Optica`RayEnd :> {3.8238202808915664`, 2.9838764681221184`, 0.}, 
      RotationMatrix :> {{-0.8605318478879331, 0.5093966418917364, 
       0.}, {-0.5093966418917364, -0.8605318478879331, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024488139417201616`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24346609441845965`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.84124178689557, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06988133071229813, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8605318478879331, 0.5093966418917364, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.781731117882949, 2.928205971915999, 0.}, 
      Optica`Optica`RayEnd :> {4.714349277427727, 3.0919392338751, 0.}, 
      RotationMatrix :> {{-0.38056755568133294`, 0.9247531214128094, 
       0.}, {-0.9247531214128094, -0.38056755568133294`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015219042250939311`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1770561873951337, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.067875946031904`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4005702204610636, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.38056755568133294`, 0.9247531214128094, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.714349277427727, 3.0919392338751, 0.}, 
      Optica`Optica`RayEnd :> {4.641487887169879, 3.3291496725314924`, 0.}, 
      RotationMatrix :> {{-0.2936203587050388, 0.9559221123888301, 
       0.}, {-0.9559221123888301, -0.2936203587050388, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015088822067630016`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24814829114435677`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.43513541692555, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26946774354414804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.2936203587050388, 0.9559221123888301, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.634090986696744, 3.6286175405357364`, 0.}, 
      Optica`Optica`RayEnd :> {5.647119825236141, 3.6507051496787444`, 0.}, 
      RotationMatrix :> {{0.508066395005652, 0.8613179077819987, 
       0.}, {-0.8613179077819987, 0.508066395005652, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009479447854324441, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02564396832278396, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.094016162314954`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3175939156204215, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.508066395005652, 0.8613179077819987, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.647119825236141, 3.6507051496787444`, 0.}, 
      Optica`Optica`RayEnd :> {5.825246023854241, 3.9303156676656474`, 0.}, 
      RotationMatrix :> {{0.537288136061813, 0.843398754354796, 
       0.}, {-0.843398754354796, 0.537288136061813, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009450198465022392, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3315282558139492, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.5846779809196, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13418791225451637`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.537288136061813, 0.843398754354796, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.832018778269499, 0.5492703607319532, 0.}, 
      Optica`Optica`RayEnd :> {3.6155978878735318`, 0.4541974514948907, 0.}, 
      RotationMatrix :> {{-0.915552353804271, -0.4021988158155837, 0.}, {
       0.4021988158155837, -0.915552353804271, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08315130246786985, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2363828671257334, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.843882531321825`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34794549194161534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.915552353804271, -0.4021988158155837, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6155978878735318`, 0.4541974514948907, 0.}, 
      Optica`Optica`RayEnd :> {3.3805055831974253`, 0.37158406636224844`, 0.},
       RotationMatrix :> {{-0.9434433379005137, -0.3315338115051555, 0.}, {
       0.3315338115051555, -0.9434433379005137, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08263711157970306, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24918539909271845`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.212676921979046`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40769294873696993`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9434433379005137, -0.3315338115051555, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8547025614206625`, 1.5800455557922033`, 0.},
       Optica`Optica`RayEnd :> {4.828195341595365, 1.5979025979241401`, 0.}, 
      RotationMatrix :> {{-0.8293609427671583, 0.5587131881496707, 
       0.}, {-0.5587131881496707, -0.8293609427671583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03749845497090089, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03196101776490246, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.736986406943641`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13902022239888723`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8293609427671583, 0.5587131881496707, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.828195341595365, 1.5979025979241401`, 0.}, 
      Optica`Optica`RayEnd :> {4.573649858233891, 1.7627108399105784`, 0.}, 
      RotationMatrix :> {{-0.8394161948553518, 0.5434891459951717, 
       0.}, {-0.5434891459951717, -0.8394161948553518, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037399703149124115`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3032410917510804, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.14332946989009, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18719197330907347`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8394161948553518, 0.5434891459951717, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.613741195307599, 1.2388990593583549`, 0.}, 
      Optica`Optica`RayEnd :> {4.409518578935311, 1.2417270050109548`, 0.}, 
      RotationMatrix :> {{-0.9999041389902599, 0.013846040233464488`, 
       0.}, {-0.013846040233464488`, -0.9999041389902599, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09090324594386706, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20424219523535453`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.17492461435293, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38185845370326477`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999041389902599, 0.013846040233464488`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.409518578935311, 1.2417270050109548`, 0.}, 
      Optica`Optica`RayEnd :> {4.098053619989534, 1.2406365255603116`, 0.}, 
      RotationMatrix :> {{-0.9999938710991453, -0.003501108987969863, 0.}, {
       0.003501108987969863, -0.9999938710991453, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09066534806994662, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31146686789533, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.59229021733267, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0920461940591869, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999938710991453, -0.003501108987969863, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.090100669028041, 0.7405292894550553, 0.}, 
      Optica`Optica`RayEnd :> {5.047734840827478, 0.6931117933551798, 0.}, 
      RotationMatrix :> {{-0.6662675572148171, -0.7457127746009183, 0.}, {
       0.7457127746009183, -0.6662675572148171, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02157165976363377, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06358680944583758, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.59629272859572, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18476800645312097`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.6662675572148171, -0.7457127746009183, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.047734840827478, 0.6931117933551798, 0.}, 
      Optica`Optica`RayEnd :> {4.875021438164752, 0.5253603907749506, 0.}, 
      RotationMatrix :> {{-0.7173361129061857, -0.6967272788693175, 0.}, {
       0.6967272788693175, -0.7173361129061857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02145096558646744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2407705391591159, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.918925251068936`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05784161080500666, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7173361129061857, -0.6967272788693175, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.021253812479882, -1.1394772355398624`, 0.}, 
      Optica`Optica`RayEnd :> {6.054017287501334, -1.3481992558309215`, 0.}, 
      RotationMatrix :> {{0.15507293390029694`, -0.9879030241737057, 0.}, {
       0.9879030241737057, 0.15507293390029694`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008362954487302588, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21127784325352855`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.666042966801307`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.046499940161154885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.15507293390029694`, -0.9879030241737057, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.054017287501334, -1.3481992558309215`, 0.}, 
      Optica`Optica`RayEnd :> {6.070713347817326, -1.596189391324968, 0.}, 
      RotationMatrix :> {{0.06717343464185534, -0.9977413140080026, 0.}, {
       0.9977413140080026, 0.06717343464185534, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008296795959606034, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2485515353652654, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.0338992391419, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1128115464460166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.06717343464185534, -0.9977413140080026, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.090697161067123, -0.5731585137979203, 0.}, 
      Optica`Optica`RayEnd :> {8.163270847579373, -0.6293038944579838, 0.}, 
      RotationMatrix :> {{0.7909383671724909, -0.611895823923087, 0.}, {
       0.611895823923087, 0.7909383671724909, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009134758395587078, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0917564370681516, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.813838169640658`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3789174036165124, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7909383671724909, -0.611895823923087, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.163270847579373, -0.6293038944579838, 0.}, 
      Optica`Optica`RayEnd :> {8.43413732121714, -0.8473346537407715, 0.}, 
      RotationMatrix :> {{0.7789888149763834, -0.6270378187491479, 0.}, {
       0.6270378187491479, 0.7789888149763834, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009110517163747832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34771548503681704`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.328457087495146`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26206623449405164`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7789888149763834, -0.6270378187491479, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6713872384178625`, 1.2136497580075274`, 0.},
       Optica`Optica`RayEnd :> {3.4149910609401246`, 1.324466377966882, 0.}, 
      RotationMatrix :> {{-0.9179318882511648, 0.39673800994062913`, 
       0.}, {-0.39673800994062913`, -0.9179318882511648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1531548304713613, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27931939260354205`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.89060688301688, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32195509422070084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9179318882511648, 0.39673800994062913`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4149910609401246`, 1.324466377966882, 0.}, 
      Optica`Optica`RayEnd :> {3.2065309528116637`, 1.3940584934118068`, 0.}, 
      RotationMatrix :> {{-0.9485393045002333, 0.31665941927915764`, 
       0.}, {-0.31665941927915764`, -0.9485393045002333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15200720131031964`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21976960484341174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.21586589818513, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41856377150820406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9485393045002333, 0.31665941927915764`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.062560437831467, -1.1680963505251802`, 0.}, 
      Optica`Optica`RayEnd :> {2.9761983032071324`, -1.13879043959612, 0.}, 
      RotationMatrix :> {{-0.9469637783524812, 0.3213403219149313, 
       0.}, {-0.3213403219149313, -0.9469637783524812, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00994207040976963, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09119898416240009, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.28897681138857, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23535632680775706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9469637783524812, 0.3213403219149313, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9761983032071324`, -1.13879043959612, 0.}, 
      Optica`Optica`RayEnd :> {2.843136121561057, -1.0614196196331982`, 0.}, 
      RotationMatrix :> {{-0.8644815345770532, 0.5026645764078687, 
       0.}, {-0.5026645764078687, -0.8644815345770532, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00932575546924344, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15392136942656143`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.51678043813988, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23263485172967396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8644815345770532, 0.5026645764078687, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0912834629691233`, -1.7539364159912485`, 
       0.}, Optica`Optica`RayEnd :> {
       3.0188197633552356`, -1.8708259074624283`, 0.}, 
      RotationMatrix :> {{-0.5268987789970127, -0.8499280420667719, 0.}, {
       0.8499280420667719, -0.5268987789970127, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16795478087493373`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13752869147244426`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.52898463321287, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32514655100111167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5268987789970127, -0.8499280420667719, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0188197633552356`, -1.8708259074624283`, 
       0.}, Optica`Optica`RayEnd :> {2.910787109517695, -2.0825841162416596`, 
       0.}, RotationMatrix :> {{-0.45444614768030106`, -0.8907742131755572, 
       0.}, {0.8907742131755572, -0.45444614768030106`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16675850431367437`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23772377516893506`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.880815820462892`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21429166085909046`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.45444614768030106`, -0.8907742131755572, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.589344272267322, -2.1020351712178833`, 0.}, 
      Optica`Optica`RayEnd :> {3.7667858207547886`, -2.597483960778643, 0.}, 
      RotationMatrix :> {{0.3371713842259424, -0.9414432843560789, 0.}, {
       0.9414432843560789, 0.3371713842259424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008928082137123013, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5262651481970391, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.4641854661487, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10571721623502901`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3371713842259424, -0.9414432843560789, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7667858207547886`, -2.597483960778643, 0.}, 
      Optica`Optica`RayEnd :> {3.836149343049395, -2.845038464983356, 0.}, 
      RotationMatrix :> {{0.26980399544400047`, -0.9629152631682877, 0.}, {
       0.9629152631682877, 0.26980399544400047`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008878183979121459, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25708856601793045`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.844676543855236`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16359889438290084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26980399544400047`, -0.9629152631682877, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5671895390265544`, 2.1378958136711663`, 0.},
       Optica`Optica`RayEnd :> {3.4381985078642834`, 2.3465934659157877`, 0.},
       RotationMatrix :> {{-0.5257570329490828, 0.850634787852329, 
       0.}, {-0.850634787852329, -0.5257570329490828, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042764624025935026`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24534342496330086`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.81572217696931, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3372606555892785, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.5257570329490828, 0.850634787852329, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4381985078642834`, 2.3465934659157877`, 0.},
       Optica`Optica`RayEnd :> {3.3278659338480487`, 2.5662557517157665`, 0.},
       RotationMatrix :> {{-0.4488447516147086, 0.8936097520438832, 
       0.}, {-0.8936097520438832, -0.4488447516147086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042428635352687254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24581455752644016`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.179527722108443`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20531036951850623`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4488447516147086, 0.8936097520438832, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.380048048528092, 2.0105057011738268`, 0.}, 
      Optica`Optica`RayEnd :> {4.3348175139279395`, 2.1146606225039792`, 0.}, 
      RotationMatrix :> {{-0.39832454111067855`, 0.9172445475166185, 
       0.}, {-0.9172445475166185, -0.39832454111067855`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04909041915403561, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11355196562590122`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.814176425460667`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0472606636631141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.39832454111067855`, 0.9172445475166185, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.3348175139279395`, 2.1146606225039792`, 0.},
       Optica`Optica`RayEnd :> {4.199617787190727, 2.409714096482288, 0.}, 
      RotationMatrix :> {{-0.41657038811013153`, 0.9091034659211091, 
       0.}, {-0.9091034659211091, -0.41657038811013153`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04895945632813861, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3245543384650491, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.294516846388941`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3461517631719023, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.41657038811013153`, 0.9091034659211091, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.84117167131676, 0.5997028117287332, 0.}, 
      Optica`Optica`RayEnd :> {3.605395170373543, 0.5641122271604382, 0.}, 
      RotationMatrix :> {{-0.9887980476343677, -0.14925957588865593`, 0.}, {
       0.14925957588865593`, -0.9887980476343677, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012694726333383463`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2384475793690091, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.221675320183113`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27590894883116757`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9887980476343677, -0.14925957588865593`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.605395170373543, 0.5641122271604382, 0.}, 
      Optica`Optica`RayEnd :> {3.3170462945642005`, 0.5115606526621097, 0.}, 
      RotationMatrix :> {{-0.9837950606213925, -0.17929662210133596`, 0.}, {
       0.17929662210133596`, -0.9837950606213925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012657291554271059`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2930985195506194, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.65546112911803, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05096740716949277, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9837950606213925, -0.17929662210133596`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.224191606502897, 2.8622039459876105`, 0.}, 
      Optica`Optica`RayEnd :> {5.137604686626926, 2.930542326395737, 0.}, 
      RotationMatrix :> {{-0.7849696794030547, 0.6195341817994099, 
       0.}, {-0.6195341817994099, -0.7849696794030547, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18631454395185035`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11030606932718484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.36535354919802, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.303417653563508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7849696794030547, 0.6195341817994099, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.137604686626926, 2.930542326395737, 0.}, 
      Optica`Optica`RayEnd :> {4.886521337520707, 3.1181709029604834`, 0.}, 
      RotationMatrix :> {{-0.8010461408400552, 0.5986026062800373, 
       0.}, {-0.5986026062800373, -0.8010461408400552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18578832793871375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3134443027750038, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.829251117305025`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38802754798609407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8010461408400552, 0.5986026062800373, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.093661954241497, 1.5245104065784694`, 0.}, 
      Optica`Optica`RayEnd :> {7.1663719160576385`, 1.4378542619639703`, 0.}, 
      RotationMatrix :> {{0.6427711275073402, -0.7660582730073093, 0.}, {
       0.7660582730073093, 0.6427711275073402, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032578850988604406`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1131195206264319, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.204373815364928`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3383152589810769, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6427711275073402, -0.7660582730073093, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1663719160576385`, 1.4378542619639703`, 0.},
       Optica`Optica`RayEnd :> {7.352014452126943, 1.193465846067691, 0.}, 
      RotationMatrix :> {{0.6048918704230016, -0.7963076196396474, 0.}, {
       0.7963076196396474, 0.6048918704230016, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03245583209334701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.306902018602901, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.65858880289722, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2639318359995088, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6048918704230016, -0.7963076196396474, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.7707649418967755`, 1.571081812287572, 0.}, 
      Optica`Optica`RayEnd :> {6.829062553610241, 1.3980842767110477`, 0.}, 
      RotationMatrix :> {{0.3193406639066718, -0.947639984580455, 0.}, {
       0.947639984580455, 0.3193406639066718, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013781130053024898`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1825561799749457, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.586798226671183`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07523538563416286, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3193406639066718, -0.947639984580455, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.829062553610241, 1.3980842767110477`, 0.}, 
      Optica`Optica`RayEnd :> {6.869205868538643, 1.1908184192383027`, 0.}, 
      RotationMatrix :> {{0.19014674174504642`, -0.9817556807086688, 0.}, {
       0.9817556807086688, 0.19014674174504642`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013513575193398476`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21111755352730163`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.899252205891589`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2543472147826863, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19014674174504642`, -0.9817556807086688, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.327120076572609, 2.606217434266993, 0.}, 
      Optica`Optica`RayEnd :> {6.191739739163332, 2.5756248385797793`, 0.}, 
      RotationMatrix :> {{-0.9754056301994296, -0.22041745977860344`, 0.}, {
       0.22041745977860344`, -0.9754056301994296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019117468852863858`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13879388555671698`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.190533770457963`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23788405852606698`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9754056301994296, -0.22041745977860344`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.191739739163332, 2.5756248385797793`, 0.}, 
      Optica`Optica`RayEnd :> {5.882439085046726, 2.4952029161458746`, 0.}, 
      RotationMatrix :> {{-0.9678196472706175, -0.25164484965318923`, 0.}, {
       0.25164484965318923`, -0.9678196472706175, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019059989290064604`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31958501254740584`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.663519589028123`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021294354986144765`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9678196472706175, -0.25164484965318923`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.829041889572819, 3.1787664066759094`, 0.}, 
      Optica`Optica`RayEnd :> {7.0636939052972245`, 3.176395837595149, 0.}, 
      RotationMatrix :> {{0.9999489737778557, -0.010101972114996749`, 0.}, {
       0.010101972114996749`, 0.9999489737778557, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07845606345703046, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.234663989741275, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.767998003197464`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23967687341805147`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9999489737778557, -0.010101972114996749`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.0636939052972245`, 3.176395837595149, 0.}, 
      Optica`Optica`RayEnd :> {7.36873589652042, 3.1892380843199777`, 0.}, 
      RotationMatrix :> {{0.999114974206817, 0.0420626712859562, 
       0.}, {-0.0420626712859562, 0.999114974206817, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07814151938321014, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3053122003955186, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.21986005978283, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29514962543502926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.999114974206817, 0.0420626712859562, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.883506851961149, 3.3440089025840014`, 0.}, 
      Optica`Optica`RayEnd :> {6.887209292294565, 3.364039245201363, 0.}, 
      RotationMatrix :> {{0.1817625789483115, 0.9833424453841386, 
       0.}, {-0.9833424453841386, 0.1817625789483115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.741707248655444, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02036965119464261, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.73834451292233, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42427826246217654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1817625789483115, 0.9833424453841386, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.887209292294565, 3.364039245201363, 0.}, 
      Optica`Optica`RayEnd :> {6.942088537623861, 3.6182506337634655`, 0.}, 
      RotationMatrix :> {{0.2110191476033463, 0.9774819278865241, 
       0.}, {-0.9774819278865241, 0.2110191476033463, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7307488563514473`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2600676097528972, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.12324457535662, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2773557601388137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.2110191476033463, 0.9774819278865241, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.942088537623861, 3.6182506337634655`, 0.}, 
      Optica`Optica`RayEnd :> {7.0291737225527635`, 3.3731969004548623`, 0.}, 
      RotationMatrix :> {{0.3348559438510854, -0.9422693335069319, 0.}, {
       0.9422693335069319, 0.3348559438510854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010926298301470265`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26006760975289706`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.508144637790906`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04737307256148052, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.3348559438510854, -0.9422693335069319, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.730079919853941, 3.4260557860474723`, 0.}, 
      Optica`Optica`RayEnd :> {6.614471715614493, 3.468972186371477, 0.}, 
      RotationMatrix :> {{-0.9374882242578014, 0.3480169958176652, 
       0.}, {-0.3480169958176652, -0.9374882242578014, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07532887276321726, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12331696681414196`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.133794839229814`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3301347058420965, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9374882242578014, 0.3480169958176652, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.614471715614493, 3.468972186371477, 0.}, 
      Optica`Optica`RayEnd :> {6.3305081301654775`, 3.5734870220448216`, 0.}, 
      RotationMatrix :> {{-0.9384538415383891, 0.34540467180082945`, 
       0.}, {-0.34540467180082945`, -0.9384538415383891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07514292080116731, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30258663013571285`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.581623051830668`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1851443533586183, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9384538415383891, 0.34540467180082945`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.090703027845902, 2.372357661055526, 0.}, 
      Optica`Optica`RayEnd :> {7.258892531326898, 2.1212958894635108`, 0.}, 
      RotationMatrix :> {{0.5565659042857912, -0.8308034630323458, 0.}, {
       0.8308034630323458, 0.5565659042857912, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019169158045519, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3021915323699611, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.408150499292525`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08102089467116462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 94, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5565659042857912, -0.8308034630323458, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.589205417729699, 2.225663533370224, 0.}, 
      Optica`Optica`RayEnd :> {5.358245643211889, 2.1082057756821846`, 0.}, 
      RotationMatrix :> {{-0.8913530322241144, -0.45330979687723005`, 0.}, {
       0.45330979687723005`, -0.8913530322241144, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013783292482927213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25911144761746746`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.51386183159191, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11772999314647845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8913530322241144, -0.45330979687723005`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.358245643211889, 2.1082057756821846`, 0.}, 
      Optica`Optica`RayEnd :> {5.195563023826857, 2.0683216790920302`, 0.}, 
      RotationMatrix :> {{-0.9712373410913343, -0.23811347561579527`, 0.}, {
       0.23811347561579527`, -0.9712373410913343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01242147399553092, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16750037555417, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.76176238741208, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3600836404604806, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9712373410913343, -0.23811347561579527`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1144186586145235`, 2.7118462900651146`, 0.},
       Optica`Optica`RayEnd :> {4.908658190760104, 2.788062173697886, 0.}, 
      RotationMatrix :> {{-0.9377364358890823, 0.3473476310643849, 
       0.}, {-0.3473476310643849, -0.9377364358890823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03266024374529178, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21942249440199552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.37197720427856, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40741475877840216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9377364358890823, 0.3473476310643849, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.908658190760104, 2.788062173697886, 0.}, 
      Optica`Optica`RayEnd :> {4.631857465184819, 2.876601243636376, 0.}, 
      RotationMatrix :> {{-0.9524612588409527, 0.30465972888963655`, 
       0.}, {-0.30465972888963655`, -0.9524612588409527, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03254310426332896, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29061625657312634`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.80208926400679, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3274025856261691, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9524612588409527, 0.30465972888963655`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.113793252067586, 1.4194705564399406`, 0.}, 
      Optica`Optica`RayEnd :> {8.169498280706339, 1.4059822232091812`, 0.}, 
      RotationMatrix :> {{0.9719136539600106, -0.2353377344288402, 0.}, {
       0.2353377344288402, 0.9719136539600106, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1740479652495941, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05731479171198518, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.276028565530176`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35243614001930773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9719136539600106, -0.2353377344288402, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.169498280706339, 1.4059822232091812`, 0.}, 
      Optica`Optica`RayEnd :> {8.469682112473555, 1.3151141464055818`, 0.}, 
      RotationMatrix :> {{0.9571099533512492, -0.28972493368015156`, 0.}, {
       0.28972493368015156`, 0.9571099533512492, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1732988597622128, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31363568074508624`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.740209373032904`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3765736727966392, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9571099533512492, -0.28972493368015156`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.694976960098423, 0.14421027926079488`, 0.}, 
      Optica`Optica`RayEnd :> {4.66760203244225, 0.12211145550534279`, 0.}, 
      RotationMatrix :> {{-0.7781036395990352, -0.6281359136705474, 0.}, {
       0.6281359136705474, -0.7781036395990352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012521240303991646`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03518159569370324, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.109548048687984`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20660387976428785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7781036395990352, -0.6281359136705474, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.66760203244225, 0.12211145550534279`, 0.}, 
      Optica`Optica`RayEnd :> {4.428739814516301, -0.06855911911277814, 0.}, 
      RotationMatrix :> {{-0.7815374283222268, -0.6238583558240435, 0.}, {
       0.6238583558240435, -0.7815374283222268, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01249019145047567, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3056311947064769, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.56188221685357, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3319852067486795, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7815374283222268, -0.6238583558240435, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1565195605696372`, 1.3367049720306945`, 0.},
       Optica`Optica`RayEnd :> {3.0764932009547103`, 1.3567604682757834`, 0.},
       RotationMatrix :> {{-0.9700028583470895, 0.24309351039975224`, 
       0.}, {-0.24309351039975224`, -0.9700028583470895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08317749832810706, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08250115855461902, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.981252123444708`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.008521146294501458, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9700028583470895, 0.24309351039975224`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0764932009547103`, 1.3567604682757834`, 0.},
       Optica`Optica`RayEnd :> {2.8263520093400993`, 1.444130763380094, 0.}, 
      RotationMatrix :> {{-0.9440689537504765, 0.32974810168442065`, 
       0.}, {-0.32974810168442065`, -0.9440689537504765, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08249257582622119, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26496072201175724`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.37339399202211, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17523877739088736`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9440689537504765, 0.32974810168442065`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.388221823160652, 2.9095274470816745`, 0.}, 
      Optica`Optica`RayEnd :> {4.388688848237903, 2.920111326351133, 0.}, 
      RotationMatrix :> {{0.044083180987473936`, 0.9990278640528631, 
       0.}, {-0.9990278640528631, 0.044083180987473936`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008843443212274158, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.010594178250966629`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.81121436050481, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24041229163728595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.044083180987473936`, 0.9990278640528631, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.388688848237903, 2.920111326351133, 0.}, 
      Optica`Optica`RayEnd :> {4.425356686909021, 3.1169129380419007`, 0.}, 
      RotationMatrix :> {{0.18316662920395643`, 0.9830818816080686, 
       0.}, {-0.9830818816080686, 0.18316662920395643`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008649489005714219, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20018842313404364`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.107493226743195`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3821670894424817, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.18316662920395643`, 0.9830818816080686, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.675537600714022, 2.844785459439058, 0.}, 
      Optica`Optica`RayEnd :> {3.6666652177736796`, 2.9995176613208825`, 0.}, 
      RotationMatrix :> {{-0.057246215911042814`, 0.9983600907307275, 
       0.}, {-0.9983600907307275, -0.057246215911042814`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014624819685761025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15498636545915181`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.158238584685968`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39829330182980005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.057246215911042814`, 0.9983600907307275, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6666652177736796`, 2.9995176613208825`, 0.},
       Optica`Optica`RayEnd :> {3.6155601683525647`, 3.140748752813215, 0.}, 
      RotationMatrix :> {{-0.3402624493683713, 0.9403305086775802, 
       0.}, {-0.9403305086775802, -0.3402624493683713, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011409047810579394`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1501930333951956, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.380524274110858`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11264254315645789`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3402624493683713, 0.9403305086775802, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3314682700404803`, 2.4287451418733497`, 0.},
       Optica`Optica`RayEnd :> {3.2138668225961746`, 2.4745554143657085`, 0.},
       RotationMatrix :> {{-0.9318001000897785, 0.36297186319696845`, 
       0.}, {-0.36297186319696845`, -0.9318001000897785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.221655169890112, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12620888045941908`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.05164575875171, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.394525768796124, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9318001000897785, 0.36297186319696845`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2138668225961746`, 2.4745554143657085`, 0.},
       Optica`Optica`RayEnd :> {2.868843846892141, 2.60011284487213, 0.}, 
      RotationMatrix :> {{-0.9397107067233132, 0.3419704485325761, 
       0.}, {-0.3419704485325761, -0.9397107067233132, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22105176618492475`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3671587151614967, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.595040657190726`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26563204640741234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9397107067233132, 0.3419704485325761, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4118601926906513`, 1.9774712451865195`, 0.},
       Optica`Optica`RayEnd :> {3.3814054766801434`, 1.8943963373611692`, 0.},
       RotationMatrix :> {{-0.34419404170582346`, -0.9388985364000786, 0.}, {
       0.9388985364000786, -0.34419404170582346`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012800904582199806`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08848124116145263, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.151309484414476`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09410929167048557, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.34419404170582346`, -0.9388985364000786, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3814054766801434`, 1.8943963373611692`, 0.},
       Optica`Optica`RayEnd :> {3.26131283152225, 1.5996640494127237`, 0.}, 
      RotationMatrix :> {{-0.3773414261297282, -0.9260742130771068, 0.}, {
       0.9260742130771068, -0.3773414261297282, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012760774007616042`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3182599016218429, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.622334138814804`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2758910734439414, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3773414261297282, -0.9260742130771068, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.345010882115403, 1.4163935745926908`, 0.}, 
      Optica`Optica`RayEnd :> {3.3381077552641885`, 1.405688281109693, 0.}, 
      RotationMatrix :> {{-0.5419320596946654, -0.8404223002009749, 0.}, {
       0.8404223002009749, -0.5419320596946654, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008193712934874038, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.012737993126119911`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.2621292738803, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06041730478714764, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5419320596946654, -0.8404223002009749, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3381077552641885`, 1.405688281109693, 0.}, 
      Optica`Optica`RayEnd :> {3.191782608675725, 1.1704668874483517`, 0.}, 
      RotationMatrix :> {{-0.5282112403161848, -0.8491129993137766, 0.}, {
       0.8491129993137766, -0.5282112403161848, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008172425749640224, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2770201302434879, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.672119066640665`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37901240317945506`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5282112403161848, -0.8491129993137766, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3311028726883682`, -2.9944225439346672`, 
       0.}, Optica`Optica`RayEnd :> {2.9000758278077194`, -3.30278184605173, 
       0.}, RotationMatrix :> {{-0.8133023357655823, -0.581841310529123, 
       0.}, {0.581841310529123, -0.8133023357655823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012184455247384334`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5299714828372059, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.04826932995492, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3828776813844237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8133023357655823, -0.581841310529123, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9000758278077194`, -3.30278184605173, 0.}, 
      Optica`Optica`RayEnd :> {2.69371070634779, -3.4233066182279197`, 0.}, 
      RotationMatrix :> {{-0.8635144946115043, -0.5043240204430458, 0.}, {
       0.5043240204430458, -0.8635144946115043, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012080212992138361`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23898281122979118`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.40196389057501, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37964280975541864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8635144946115043, -0.5043240204430458, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.770942851840212, -3.9269453409866735`, 0.}, 
      Optica`Optica`RayEnd :> {6.968359650415052, -4.329024738210822, 0.}, 
      RotationMatrix :> {{0.4407314169630475, -0.8976390243866093, 0.}, {
       0.8976390243866093, 0.4407314169630475, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01749894099858938, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4479299432184386, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.496383723310164`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3047167632123439, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.4407314169630475, -0.8976390243866093, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.968359650415052, -4.329024738210822, 0.}, 
      Optica`Optica`RayEnd :> {7.114318319292503, -4.651750633423436, 0.}, 
      RotationMatrix :> {{0.41208260825668297`, -0.9111464887559895, 0.}, {
       0.9111464887559895, 0.41208260825668297`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01744661169277578, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35419759522230027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.02059616423917, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09645709533979605, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.41208260825668297`, -0.9111464887559895, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.2854634585950215`, 2.930051637924093, 0.}, 
      Optica`Optica`RayEnd :> {6.330169129435359, 2.933234084288223, 0.}, 
      RotationMatrix :> {{0.9974758208408028, 0.07100694922305975, 
       0.}, {-0.07100694922305975, 0.9974758208408028, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011655650103300682`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04481880152508711, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.52309589700013, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12003839343910121`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9974758208408028, 0.07100694922305975, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.330169129435359, 2.933234084288223, 0.}, 
      Optica`Optica`RayEnd :> {6.65303976200892, 2.961530386470526, 0.}, 
      RotationMatrix :> {{0.9961816188604269, 0.08730511007162572, 
       0.}, {-0.08730511007162572, 0.9961816188604269, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011625347850951798`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3241082012162659, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.002776034800203`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4151331797928702, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9961816188604269, 0.08730511007162572, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.653245556053751, -3.501540898488227, 0.}, 
      Optica`Optica`RayEnd :> {4.773889911495325, -3.6391532943810976`, 0.}, 
      RotationMatrix :> {{0.6592269628729996, -0.7519440214678486, 0.}, {
       0.7519440214678486, 0.6592269628729996, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026032176261107487`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18300883039703075`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.361977515787775`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.021455025231947426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6592269628729996, -0.7519440214678486, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.773889911495325, -3.6391532943810976`, 0.}, 
      Optica`Optica`RayEnd :> {4.854366695460026, -3.7783913530293813`, 0.}, 
      RotationMatrix :> {{0.5004087189011744, -0.8657893011857358, 0.}, {
       0.8657893011857358, 0.5004087189011744, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02451448565971566, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.160822105860619, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.59999423246149, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42213949969867476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5004087189011744, -0.8657893011857358, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.421968446816875, -1.7712630858995746`, 0.}, 
      Optica`Optica`RayEnd :> {5.607815702618099, -1.7564436272019612`, 0.}, 
      RotationMatrix :> {{0.996835848229259, 0.07948768259959767, 
       0.}, {-0.07948768259959767, 0.996835848229259, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00832203806118468, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18643717130694734`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.745370216166915`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.078136602580048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.996835848229259, 0.07948768259959767, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.607815702618099, -1.7564436272019612`, 0.}, 
      Optica`Optica`RayEnd :> {5.921928558588366, -1.7290781022400192`, 0.}, 
      RotationMatrix :> {{0.9962265159529583, 0.08679129514087686, 
       0.}, {-0.08679129514087686, 0.9962265159529583, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008301303467120947, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3153026454729496, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.21201813146688, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42872995490205845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9962265159529583, 0.08679129514087686, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7481042170747867`, 2.8938741145769025`, 0.},
       Optica`Optica`RayEnd :> {3.8509603849960232`, 3.1063593674367422`, 0.},
       RotationMatrix :> {{0.4357007000298271, 0.9000916064454325, 
       0.}, {-0.9000916064454325, 0.4357007000298271, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008664152882538302, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23607069695824523`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.920327517561121`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.051632270254747384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.4357007000298271, 0.9000916064454325, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8509603849960232`, 3.1063593674367422`, 0.},
       Optica`Optica`RayEnd :> {3.933775921915895, 3.33685800507418, 0.}, 
      RotationMatrix :> {{0.33812672914295605`, 0.9411005870995336, 
       0.}, {-0.9411005870995336, 0.33812672914295605`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008566952064386606, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24492454982716932`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.282815851305333`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.276684014825025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.33812672914295605`, 0.9411005870995336, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.656496102702559, 2.8886382820148584`, 0.}, 
      Optica`Optica`RayEnd :> {2.6041384557393847`, 2.9145896264108724`, 0.}, 
      RotationMatrix :> {{-0.8959788788014028, 0.44409666598813996`, 
       0.}, {-0.44409666598813996`, -0.8959788788014028, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3746654523928048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0584362513469244, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.154765592535234`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2876486435537588, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8959788788014028, 0.44409666598813996`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6041384557393847`, 2.9145896264108724`, 0.},
       Optica`Optica`RayEnd :> {2.319455317078221, 3.0548251894317278`, 0.}, 
      RotationMatrix :> {{-0.8970659319687213, 0.44189672289019044`, 
       0.}, {-0.44189672289019044`, -0.8970659319687213, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3737409020829626, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31734918083043406`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.624442380164275`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23141890697453307`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8970659319687213, 0.44189672289019044`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1617716970949905`, 1.7234169393512568`, 0.},
       Optica`Optica`RayEnd :> {2.0981549132147475`, 1.6950179459541808`, 0.},
       RotationMatrix :> {{-0.9131451304642116, -0.4076346044063221, 0.}, {
       0.4076346044063221, -0.9131451304642116, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00853776203299345, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06966776885499273, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.86485240014804, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011244414421406598`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9131451304642116, -0.4076346044063221, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0981549132147475`, 1.6950179459541808`, 0.},
       Optica`Optica`RayEnd :> {1.8170903467914052`, 1.5473035894966969`, 0.},
       RotationMatrix :> {{-0.8851963146167892, -0.46521767441581063`, 0.}, {
       0.46521767441581063`, -0.8851963146167892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008495656917114966, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3175166477562872, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.334777038827347`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028457526285340436`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8851963146167892, -0.46521767441581063`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.858952183105744, 2.80193995526425, 0.}, 
      Optica`Optica`RayEnd :> {6.340608338011412, 3.0416477975838894`, 0.}, 
      RotationMatrix :> {{0.8952585162200147, 0.4455470672505177, 
       0.}, {-0.4455470672505177, 0.8952585162200147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009198770556912162, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5380079007115509, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.51351433931871, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21044852593345847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8952585162200147, 0.4455470672505177, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.340608338011412, 3.0416477975838894`, 0.}, 
      Optica`Optica`RayEnd :> {6.558434112117004, 3.121394561388964, 0.}, 
      RotationMatrix :> {{0.9390471480478572, 0.3437883851196627, 
       0.}, {-0.3437883851196627, 0.9390471480478572, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009084833907498703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2319646830922386, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.856822070295223`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04450746035349828, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9390471480478572, 0.3437883851196627, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8724930742377612`, -0.8881629628885982, 0.},
       Optica`Optica`RayEnd :> {2.8708371103867525`, -0.888634715180869, 0.}, 
      RotationMatrix :> {{-0.9617354057140762, -0.27397994341918835`, 0.}, {
       0.27397994341918835`, -0.9617354057140762, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02431882532272911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.001721849732441992, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.034440829416233`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04505228967684855, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9617354057140762, -0.27397994341918835`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8708371103867525`, -0.888634715180869, 0.}, 
      Optica`Optica`RayEnd :> {2.7207957282082207`, -0.8988499529645195, 0.}, 
      RotationMatrix :> {{-0.9976903921488153, -0.06792555788466942, 0.}, {
       0.06792555788466942, -0.9976903921488153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022553581274540324`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15038872114962845`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.257016136717684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42113181004879857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9976903921488153, -0.06792555788466942, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3099577862941993`, -1.0111371331343069`, 
       0.}, Optica`Optica`RayEnd :> {2.1558050837059786`, -0.9965654936102184,
        0.}, RotationMatrix :> {{-0.9955620136883198, 0.09410779404947259, 
       0.}, {-0.09410779404947259, -0.9955620136883198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013066833339828143`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15483987985552186`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.007848817917345`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4041053895860915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9955620136883198, 0.09410779404947259, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1558050837059786`, -0.9965654936102184, 0.},
       Optica`Optica`RayEnd :> {1.779063316539821, -0.9682283827490923, 0.}, 
      RotationMatrix :> {{-0.9971832026650952, 0.07500440202137448, 
       0.}, {-0.07500440202137448, -0.9971832026650952, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013032187873623657`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3778059700156086, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.567001653540448`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12672250502905924`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9971832026650952, 0.07500440202137448, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.335307961329535, 0.9947123023651957, 0.}, 
      Optica`Optica`RayEnd :> {4.167880082384757, 1.1262556643233088`, 0.}, 
      RotationMatrix :> {{-0.7863345707225942, 0.6178008925912246, 
       0.}, {-0.6178008925912246, -0.7863345707225942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009159797611967821, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21292193574920976`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.919956355636366`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23253167011342857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.7863345707225942, 0.6178008925912246, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.167880082384757, 1.1262556643233088`, 0.}, 
      Optica`Optica`RayEnd :> {4.019750937957919, 1.1993746870569428`, 0.}, 
      RotationMatrix :> {{-0.8967050361352947, 0.44262860071351035`, 
       0.}, {-0.44262860071351035`, -0.8967050361352947, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008516651925285315, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16519272052408576`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.164441582012014`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.288008522853316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8967050361352947, 0.44262860071351035`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.9507690227662335`, 0.8052219787546446, 0.}, 
      Optica`Optica`RayEnd :> {7.976217467467496, 0.8887484947175992, 0.}, 
      RotationMatrix :> {{0.2914480770145259, 0.9565866497105917, 
       0.}, {-0.9565866497105917, 0.2914480770145259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018436223252223514`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08731725033819457, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.56483591149349, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3800158870255161, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2914480770145259, 0.9565866497105917, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.976217467467496, 0.8887484947175992, 0.}, 
      Optica`Optica`RayEnd :> {8.073286747564538, 1.2026505553483355`, 0.}, 
      RotationMatrix :> {{0.2954313016560805, 0.9553639861339724, 
       0.}, {-0.9553639861339724, 0.2954313016560805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01839062436127478, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32856802766973575`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.051116592444696`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13025389974567617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2954313016560805, 0.9553639861339724, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.639163844367371, 0.35600074813492016`, 0.}, 
      Optica`Optica`RayEnd :> {6.5917685741927246`, 0.47514305546185914`, 0.},
       RotationMatrix :> {{-0.36963086915041304`, 0.9291786806481895, 
       0.}, {-0.9291786806481895, -0.36963086915041304`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013276518276663214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1282232468396993, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.7825251991345, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29543795323830857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.36963086915041304`, 0.9291786806481895, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5917685741927246`, 0.47514305546185914`, 
       0.}, Optica`Optica`RayEnd :> {6.499397579882815, 0.6579562769550734, 
       0.}, RotationMatrix :> {{-0.4509763026128048, 0.8925359233564125, 
       0.}, {-0.8925359233564125, -0.4509763026128048, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013169861514621333`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20482449692975804`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.085665454590544`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14946618197562028`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.4509763026128048, 0.8925359233564125, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.364338814151551, -1.8536428419150592`, 0.}, 
      Optica`Optica`RayEnd :> {6.301717809521697, -1.869685007195425, 0.}, 
      RotationMatrix :> {{-0.9687178195714703, -0.24816483643879983`, 0.}, {
       0.24816483643879983`, -0.9687178195714703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02064081004072096, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06464318438733353, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.477551344176895`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18614808159145155`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9687178195714703, -0.24816483643879983`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.301717809521697, -1.869685007195425, 0.}, 
      Optica`Optica`RayEnd :> {6.135532990828835, -1.892394399522408, 0.}, 
      RotationMatrix :> {{-0.990791955746978, -0.1353931328652912, 0.}, {
       0.1353931328652912, -0.990791955746978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02036317876011437, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16772927730077414`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.72579067458204, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40299208607459047`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.990791955746978, -0.1353931328652912, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.388525244576338, -2.6663777250317304`, 0.}, 
      Optica`Optica`RayEnd :> {7.385285491719142, -2.67304322521958, 0.}, 
      RotationMatrix :> {{-0.4371467746017095, -0.8993901808755316, 0.}, {
       0.8993901808755316, -0.4371467746017095, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03963360653490009, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.00741113293160617, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.210708041369724`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07385284752311151, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.4371467746017095, -0.8993901808755316, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.385285491719142, -2.67304322521958, 0.}, 
      Optica`Optica`RayEnd :> {7.249945292601955, -2.9372034400351885`, 0.}, 
      RotationMatrix :> {{-0.4559789567159755, -0.8899905567095697, 0.}, {
       0.8899905567095697, -0.4559789567159755, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039526969423696795`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29681237943944977`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.64999036294011, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35822335389180543`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.4559789567159755, -0.8899905567095697, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.618630463181174, -2.1975476124328246`, 0.}, 
      Optica`Optica`RayEnd :> {7.383847382218892, -2.223507775755651, 0.}, 
      RotationMatrix :> {{-0.9939425315822856, -0.10990106419774384`, 0.}, {
       0.10990106419774384`, -0.9939425315822856, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015544163493847673`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23621393944026484`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.399637859332685`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39613135691610957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9939425315822856, -0.10990106419774384`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.383847382218892, -2.223507775755651, 0.}, 
      Optica`Optica`RayEnd :> {7.071484832429513, -2.258721142881024, 0.}, 
      RotationMatrix :> {{-0.9937056387893299, -0.11202278088982245`, 0.}, {
       0.11202278088982245`, -0.9937056387893299, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015505816997499491`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3143411263821975, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.864862726378337`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04584933297711024, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9937056387893299, -0.11202278088982245`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.10977393330874, -1.6417027819848846`, 0.}, 
      Optica`Optica`RayEnd :> {8.10964461137912, -1.6411335578766304`, 0.}, 
      RotationMatrix :> {{-0.2215442380076121, 0.9751503220558491, 
       0.}, {-0.9751503220558491, -0.2215442380076121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015434845306351783`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0005837296008416803, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.010174560477857`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17293571268103983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2215442380076121, 0.9751503220558491, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.10964461137912, -1.6411335578766304`, 0.}, 
      Optica`Optica`RayEnd :> {8.037465293458888, -1.4027113492410619`, 0.}, 
      RotationMatrix :> {{-0.2897506183835745, 0.9571021780073096, 
       0.}, {-0.9571021780073096, -0.2897506183835745, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015348831316798414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24910841717230692`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.37885501789287, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1163072992474806, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2897506183835745, 0.9571021780073096, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.232240954122844, -0.5926830924116476, 0.}, 
      Optica`Optica`RayEnd :> {8.307891776053028, -0.40206142026351155`, 0.}, 
      RotationMatrix :> {{0.3688762777852217, 0.9294785052314658, 
       0.}, {-0.9294785052314658, 0.3688762777852217, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02112427731894346, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20508454049797095`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.220956414595992`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13883420446247152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3688762777852217, 0.9294785052314658, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.307891776053028, -0.40206142026351155`, 0.},
       Optica`Optica`RayEnd :> {8.397117182488653, -0.1252058009954891, 0.}, 
      RotationMatrix :> {{0.30674476237418513`, 0.9517918106161687, 
       0.}, {-0.9517918106161687, 0.30674476237418513`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02101616993305529, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29087833723720774`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.65145635370706, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16776878347075422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.30674476237418513`, 0.9517918106161687, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.436956136237303, -0.4163147868373776, 0.}, 
      Optica`Optica`RayEnd :> {6.378723026894536, -0.3138436879739406, 0.}, 
      RotationMatrix :> {{-0.49407927959086817`, 0.8694168536892807, 
       0.}, {-0.8694168536892807, -0.49407927959086817`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013463256595579277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11786187308034282`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.98795199376765, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37056464549402474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.49407927959086817`, 0.8694168536892807, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.378723026894536, -0.3138436879739406, 0.}, 
      Optica`Optica`RayEnd :> {6.236712677796566, -0.11373154791280835`, 0.}, 
      RotationMatrix :> {{-0.5787342186384962, 0.8155162194444011, 
       0.}, {-0.8155162194444011, -0.5787342186384962, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013327980320105749`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24538094435137728`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.351115791407686`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19452518929351054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5787342186384962, 0.8155162194444011, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.902025869288929, -0.9353251541593269, 0.}, 
      Optica`Optica`RayEnd :> {4.425748637850462, -0.7632457802846241, 0.}, 
      RotationMatrix :> {{-0.9404968769060976, 0.33980233155450307`, 
       0.}, {-0.33980233155450307`, -0.9404968769060976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01920166268202976, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5064102211644242, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.22622617485579, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41219354276899456`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9404968769060976, 0.33980233155450307`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.425748637850462, -0.7632457802846241, 0.}, 
      Optica`Optica`RayEnd :> {4.152490345497259, -0.6774240377395112, 0.}, 
      RotationMatrix :> {{-0.9540530532323976, 0.2996377339687704, 
       0.}, {-0.2996377339687704, -0.9540530532323976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0191355626097128, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28641834060211363`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.650125318946916`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3169961919554478, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9540530532323976, 0.2996377339687704, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.317042174504154, -2.496568643107816, 0.}, 
      Optica`Optica`RayEnd :> {5.267414443626319, -2.551733145538712, 0.}, 
      RotationMatrix :> {{-0.6688134126227949, -0.7434303054731164, 0.}, {
       0.7434303054731164, -0.6688134126227949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09291268710968995, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07420265494260385, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.693270285064603`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17083853329016216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6688134126227949, -0.7434303054731164, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.267414443626319, -2.551733145538712, 0.}, 
      Optica`Optica`RayEnd :> {5.077151719566918, -2.7896193673170946`, 0.}, 
      RotationMatrix :> {{-0.6246024562837295, -0.7809428734576761, 0.}, {
       0.7809428734576761, -0.6246024562837295, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09250139933565829, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3046141143783355, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.14409917434454, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19307286888728054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6246024562837295, -0.7809428734576761, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.865264422165415, 0.01558219543576532, 0.}, 
      Optica`Optica`RayEnd :> {3.5553008412191462`, 0.10418403203907302`, 0.},
       RotationMatrix :> {{-0.9614904986836407, 0.2748381722779496, 
       0.}, {-0.2748381722779496, -0.9614904986836407, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012538840079773187`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3223782048503175, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.876299903683183`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08914264829423911, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9614904986836407, 0.2748381722779496, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5553008412191462`, 0.10418403203907302`, 
       0.}, Optica`Optica`RayEnd :> {3.3735957448722327`, 
       0.12285257957385658`, 0.}, 
      RotationMatrix :> {{-0.9947635717067949, 0.10220291779171578`, 
       0.}, {-0.10220291779171578`, -0.9947635717067949, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01201232796385104, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18266159066837112`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.14663905787237, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4264924455783983, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9947635717067949, 0.10220291779171578`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.547614972963494, 2.660373650005636, 0.}, 
      Optica`Optica`RayEnd :> {6.554837225932531, 2.7133042740968643`, 0.}, 
      RotationMatrix :> {{0.13519481114784568`, 0.9908190364737133, 
       0.}, {-0.9908190364737133, 0.13519481114784568`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011722491999187169`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.053421081088234124`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.329343603529104`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07092163032217683, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13519481114784568`, 0.9908190364737133, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.554837225932531, 2.7133042740968643`, 0.}, 
      Optica`Optica`RayEnd :> {6.613477516367497, 2.8636309481357225`, 0.}, 
      RotationMatrix :> {{0.36341459999046116`, 0.931627515970719, 
       0.}, {-0.931627515970719, 0.36341459999046116`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010454560928429111`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16135920361070896`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.568155224872953`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3873322002346191, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36341459999046116`, 0.931627515970719, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.015837296923768, 3.1035802932107157`, 0.}, 
      Optica`Optica`RayEnd :> {6.969200230953496, 3.3494134145434793`, 0.}, 
      RotationMatrix :> {{-0.1863858963622646, 0.9824766142953404, 
       0.}, {-0.9824766142953404, -0.1863858963622646, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020868621154033862`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25021778407324435`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.346499045457367`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1887059261323159, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1863858963622646, 0.9824766142953404, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.969200230953496, 3.3494134145434793`, 0.}, 
      Optica`Optica`RayEnd :> {6.920138022643766, 3.6150100035364083`, 0.}, 
      RotationMatrix :> {{-0.18165128204723766`, 0.9833630111665758, 
       0.}, {-0.9833630111665758, -0.18165128204723766`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020816945212477858`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27009007454718953`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.746232355787207`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34167112076384437`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18165128204723766`, 0.9833630111665758, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1844334948319033`, 0.8577212354772984, 0.}, 
      Optica`Optica`RayEnd :> {2.1176780270552102`, 0.888479135663443, 0.}, 
      RotationMatrix :> {{-0.908230015608811, 0.41847131173739793`, 
       0.}, {-0.41847131173739793`, -0.908230015608811, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10768276134729257`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0735006183779835, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.990568457746814`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1569378188093941, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.908230015608811, 0.41847131173739793`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1176780270552102`, 0.888479135663443, 0.}, 
      Optica`Optica`RayEnd :> {1.8258596958523285`, 1.0332433360189008`, 0.}, 
      RotationMatrix :> {{-0.8958287043132981, 0.4443995190460462, 
       0.}, {-0.4443995190460462, -0.8958287043132981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10737113842549359`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32575237854939726`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.472681977999923`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09594243510198663, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.8958287043132981, 0.4443995190460462, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.566128926377194, -1.7924870565715108`, 0.}, 
      Optica`Optica`RayEnd :> {3.4861205041345973`, -1.8568951960375732`, 0.},
       RotationMatrix :> {{-0.7789588170193912, -0.6270750843302183, 0.}, {
       0.6270750843302183, -0.7789588170193912, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04114962275121717, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1027120054289146, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.191508431012842`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34455795576006365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7789588170193912, -0.6270750843302183, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4861205041345973`, -1.8568951960375732`, 
       0.}, Optica`Optica`RayEnd :> {3.383789456511689, -1.9729749954037983`, 
       0.}, RotationMatrix :> {{-0.6612861880588224, -0.7501337064034862, 
       0.}, {0.7501337064034862, -0.6612861880588224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03958053518457367, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1547454785397783, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.420531739251714`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05535498409423818, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6612861880588224, -0.7501337064034862, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.613537725456426, -3.6216851368345666`, 0.}, 
      Optica`Optica`RayEnd :> {5.625609448203834, -3.6732339857997185`, 0.}, 
      RotationMatrix :> {{0.2280115800109916, -0.9736584202793556, 0.}, {
       0.9736584202793556, 0.2280115800109916, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015910411416999663`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.052943463427720126`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.597064869102397`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28952738998638844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2280115800109916, -0.9736584202793556, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.625609448203834, -3.6732339857997185`, 0.}, 
      Optica`Optica`RayEnd :> {5.7020451715431815`, -3.9112365439015684`, 0.},
       RotationMatrix :> {{0.30577313590065663`, -0.9521044004527431, 0.}, {
       0.9521044004527431, 0.30577313590065663`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01580250332956923, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24997527370808828`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.96702827419037, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3773922554431888, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.30577313590065663`, -0.9521044004527431, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.322692665885227, -1.9171446844618552`, 0.}, 
      Optica`Optica`RayEnd :> {7.338693997548402, -1.9299532556065953`, 0.}, 
      RotationMatrix :> {{0.7806901425322303, -0.6249183157445511, 0.}, {
       0.6249183157445511, 0.7806901425322303, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011674209535511395`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.020496392603694923`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.26561134074783, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11203329150872493`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7806901425322303, -0.6249183157445511, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.338693997548402, -1.9299532556065953`, 0.}, 
      Optica`Optica`RayEnd :> {7.555889127695717, -2.088286515364006, 0.}, 
      RotationMatrix :> {{0.808075164501131, -0.5890793906736771, 0.}, {
       0.5890793906736771, 0.808075164501131, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011632371798397366`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26878085070390806`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.663406999789615`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.006672053105183043, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.808075164501131, -0.5890793906736771, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6460075670016345`, 3.363384076381549, 0.}, 
      Optica`Optica`RayEnd :> {3.641308145352485, 3.366375990633749, 0.}, 
      RotationMatrix :> {{-0.843549823586792, 0.5370509241465758, 
       0.}, {-0.5370509241465758, -0.843549823586792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009234653630834382, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0055710066172109845`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.062401765911112`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16080849674918357`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.843549823586792, 0.5370509241465758, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.641308145352485, 3.366375990633749, 0.}, 
      Optica`Optica`RayEnd :> {3.3690487587760924`, 3.5453326097585736`, 0.}, 
      RotationMatrix :> {{-0.8356444685436416, 0.5492707184917233, 
       0.}, {-0.5492707184917233, -0.8356444685436416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009210907228012639, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3258076811671901, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.544597134038554`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21442604707248403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.8356444685436416, 0.5492707184917233, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.967666509375516, 3.0871540433788582`, 0.}, 
      Optica`Optica`RayEnd :> {6.9869882325984545`, 3.3530902027251317`, 0.}, 
      RotationMatrix :> {{0.07246448295973265, 0.9973709935171456, 
       0.}, {-0.9973709935171456, 0.07246448295973265, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015814907245503013`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.266637150142568, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.18124799740646, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12493104467522997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {0.07246448295973265, 0.9973709935171456, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9869882325984545`, 3.3530902027251317`, 0.},
       Optica`Optica`RayEnd :> {6.996997111901896, 3.6103894700818837`, 0.}, 
      RotationMatrix :> {{0.038870360244440946`, 0.999244261977254, 
       0.}, {-0.999244261977254, 0.038870360244440946`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015766487599311256`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2574938652613538, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.562338917993262`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08694452269421526, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {0.038870360244440946`, 0.999244261977254, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.425253906713074, -2.687134026360825, 0.}, 
      Optica`Optica`RayEnd :> {7.419796584842048, -2.7118805555779257`, 0.}, 
      RotationMatrix :> {{-0.2153542884066502, -0.976535985238058, 0.}, {
       0.976535985238058, -0.2153542884066502, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12442459998907568`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02534113395838486, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.039897966741368`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23671385137181408`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.2153542884066502, -0.976535985238058, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.419796584842048, -2.7118805555779257`, 0.}, 
      Optica`Optica`RayEnd :> {7.34954007318907, -2.9311449148270943`, 0.}, 
      RotationMatrix :> {{-0.3051378352078038, -0.9523081967119125, 0.}, {
       0.9523081967119125, -0.3051378352078038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12334643097475351`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23024516643481038`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.380660813064885`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0633235699830008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3051378352078038, -0.9523081967119125, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.118134773638745, 2.367199620738484, 0.}, 
      Optica`Optica`RayEnd :> {8.117789784286584, 2.3683044252525343`, 0.}, 
      RotationMatrix :> {{-0.2980687130854866, 0.9545444160852663, 
       0.}, {-0.9545444160852663, -0.2980687130854866, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04039309089137395, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0011574155119794063`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.665332429452747`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15482502063696824`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.2980687130854866, 0.9545444160852663, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.117789784286584, 2.3683044252525343`, 0.}, 
      Optica`Optica`RayEnd :> {8.023701590059098, 2.6198351822922343`, 0.}, 
      RotationMatrix :> {{-0.3503534036569916, 0.9366175807371765, 
       0.}, {-0.9366175807371765, -0.3503534036569916, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040222472700680044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2685522482310544, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.062789756834707`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19520266955550478`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3503534036569916, 0.9366175807371765, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.182146425329703, 0.4503276617857824, 0.}, 
      Optica`Optica`RayEnd :> {6.0872471334290434`, 0.4587794600283177, 0.}, 
      RotationMatrix :> {{-0.9960575327698552, 0.08870959030696235, 
       0.}, {-0.08870959030696235, -0.9960575327698552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008029295604281504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0952749101116298, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.873770105807917`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25185218665475984`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9960575327698552, 0.08870959030696235, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.0872471334290434`, 0.4587794600283177, 0.}, 
      Optica`Optica`RayEnd :> {5.809237141424264, 0.4956500394430211, 0.}, 
      RotationMatrix :> {{-0.9913198802536617, 0.1314720312989272, 
       0.}, {-0.1314720312989272, -0.9913198802536617, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00800139876845557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28044428195431914`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.28882764310031, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12641710048814306`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9913198802536617, 0.1314720312989272, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.68166825234663, -0.834249674863952, 0.}, 
      Optica`Optica`RayEnd :> {4.601379121612772, -0.8417789523378222, 0.}, 
      RotationMatrix :> {{-0.995631723246744, -0.09336740150994154, 0.}, {
       0.09336740150994154, -0.995631723246744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015286417541420677`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08064139466351666, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.834276507144065`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.043532402266835656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.995631723246744, -0.09336740150994154, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.601379121612772, -0.8417789523378222, 0.}, 
      Optica`Optica`RayEnd :> {4.382315238116761, -0.8858538580442203, 0.}, 
      RotationMatrix :> {{-0.9803544347472161, -0.197243966375314, 0.}, {
       0.197243966375314, -0.9803544347472161, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015117817506643988`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22345375889740962`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.16498807031223, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26683346308666, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9803544347472161, -0.197243966375314, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.857503797053943, -1.631596318035911, 0.}, 
      Optica`Optica`RayEnd :> {6.855348031303997, -2.0773063315811187`, 0.}, 
      RotationMatrix :> {{-0.0048366437128158635`, -0.9999883033703916, 0.}, {
       0.9999883033703916, -0.0048366437128158635`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2609669943318832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4457152269111276, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.07094349219298, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.053253505460570935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.0048366437128158635`, -0.9999883033703916, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.855348031303997, -2.0773063315811187`, 0.}, 
      Optica`Optica`RayEnd :> {6.842558002495407, -2.3562116887071047`, 0.}, 
      RotationMatrix :> {{-0.04580981056320023, -0.9989501795666103, 0.}, {
       0.9989501795666103, -0.04580981056320023, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26008655888193055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791984653799128, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.484157220955254`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0985314199792425, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.04580981056320023, -0.9989501795666103, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.821491369572861, -1.4078409622156671`, 0.}, 
      Optica`Optica`RayEnd :> {7.85970811237031, -1.482799807515262, 0.}, 
      RotationMatrix :> {{0.4542103657545514, -0.8908944626840577, 0.}, {
       0.8908944626840577, 0.4542103657545514, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27677284337226055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08413886093057672, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.383207765540696`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21085965657959999`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4542103657545514, -0.8908944626840577, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.85970811237031, -1.482799807515262, 0.}, 
      Optica`Optica`RayEnd :> {7.987758823987346, -1.6947174978191548`, 0.}, 
      RotationMatrix :> {{0.5171662547329607, -0.8558849601234279, 0.}, {
       0.8558849601234279, 0.5171662547329607, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27518630244426884`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24760067085806958`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.74965675841064, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2706493881412343, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5171662547329607, -0.8558849601234279, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.360966391982671, -0.5777872347677663, 0.}, 
      Optica`Optica`RayEnd :> {7.355657786762561, -0.6212897865834256, 0.}, 
      RotationMatrix :> {{-0.12113117805618308`, -0.9926365083466961, 0.}, {
       0.9926365083466961, -0.12113117805618308`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024813013320613118`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0438252587426144, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.934094235028033`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09336985562265566, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.12113117805618308`, -0.9926365083466961, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.355657786762561, -0.6212897865834256, 0.}, 
      Optica`Optica`RayEnd :> {7.296808618032822, -0.9383558163661906, 0.}, 
      RotationMatrix :> {{-0.18248870914519663`, -0.9832079490293593, 0.}, {
       0.9832079490293593, -0.18248870914519663`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024694866876892138`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3224811496853522, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.411366336562352`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08911714646312384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.18248870914519663`, -0.9832079490293593, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.075636979375578, 1.354708650666049, 0.}, 
      Optica`Optica`RayEnd :> {6.024587853821008, 1.3649310161556567`, 0.}, 
      RotationMatrix :> {{-0.9805343269254088, 0.19634773673494355`, 
       0.}, {-0.19634773673494355`, -0.9805343269254088, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012413652334497018`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05206255829374305, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.874773063104684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2369110221618389, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9805343269254088, 0.19634773673494355`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.024587853821008, 1.3649310161556567`, 0.}, 
      Optica`Optica`RayEnd :> {5.892238369604698, 1.4306052722726568`, 0.}, 
      RotationMatrix :> {{-0.8957780569485854, 0.44450160032267144`, 
       0.}, {-0.44450160032267144`, -0.8957780569485854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01047614904650106, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14774807575344187`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.09344021521978, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2903498417558497, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8957780569485854, 0.44450160032267144`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.462835957629652, 0.3962580859494457, 0.}, 
      Optica`Optica`RayEnd :> {6.401800641306805, 0.31038149519909297`, 0.}, 
      RotationMatrix :> {{-0.579319010082128, -0.8151009045249935, 0.}, {
       0.8151009045249935, -0.579319010082128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17622538980612734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10535700583033701`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.943582393398968`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4078661896051633, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.579319010082128, -0.8151009045249935, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.401800641306805, 0.31038149519909297`, 0.}, 
      Optica`Optica`RayEnd :> {6.243269221268635, 0.13022919532730273`, 0.}, 
      RotationMatrix :> {{-0.6606217797948594, -0.7507188981640676, 0.}, {
       0.7507188981640676, -0.6606217797948594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17433134228123778`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23997304492049482`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.2987424998813, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2350037134851809, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6606217797948594, -0.7507188981640676, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.234378837136803, 0.09399011306815414, 0.}, 
      Optica`Optica`RayEnd :> {7.300742584987046, -0.14451621421034622`, 0.}, 
      RotationMatrix :> {{0.26806379760949606`, -0.9634011627620005, 0.}, {
       0.9634011627620005, 0.26806379760949606`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010707899885893532`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24756699129853665`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.495548828351147`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06656660202986077, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.26806379760949606`, -0.9634011627620005, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.300742584987046, -0.14451621421034622`, 0.},
       Optica`Optica`RayEnd :> {7.35088627346321, -0.39228288094063185`, 0.}, 
      RotationMatrix :> {{0.19836115866556006`, -0.9801289969860375, 0.}, {
       0.9801289969860375, 0.19836115866556006`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01064693246405689, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25278985469482557`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.86967781329949, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13136064076226314`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19836115866556006`, -0.9801289969860375, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.133875783682815, 2.4995612934954696`, 0.}, 
      Optica`Optica`RayEnd :> {7.180237032875569, 2.637246016100087, 0.}, 
      RotationMatrix :> {{0.3191152439008292, 0.9477159179364423, 
       0.}, {-0.9477159179364423, 0.3191152439008292, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0508376786544684, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14528058461275178`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.863852679509892`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3728781464642147, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3191152439008292, 0.9477159179364423, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.180237032875569, 2.637246016100087, 0.}, 
      Optica`Optica`RayEnd :> {7.267663358684314, 2.8974339656723194`, 0.}, 
      RotationMatrix :> {{0.3185122630380613, 0.9479187403434811, 
       0.}, {-0.9479187403434811, 0.3185122630380613, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05071237055720806, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2744833902935105, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.27008809714429, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09607383659973731, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3185122630380613, 0.9479187403434811, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.013927724321256, 2.6322695172548927`, 0.}, 
      Optica`Optica`RayEnd :> {6.881221144900748, 2.7367065227106515`, 0.}, 
      RotationMatrix :> {{-0.7858361007661335, 0.6184348168826508, 
       0.}, {-0.6184348168826508, -0.7858361007661335, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2655809918373722`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1688731012626278, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.160213003303472`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43280381465935236`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7858361007661335, 0.6184348168826508, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.881221144900748, 2.7367065227106515`, 0.}, 
      Optica`Optica`RayEnd :> {6.656119914545259, 2.8887936551931834`, 0.}, 
      RotationMatrix :> {{-0.828603130264842, 0.5598364515778727, 
       0.}, {-0.5598364515778727, -0.828603130264842, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.258255220130773, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27166350467869993`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.562274990227948`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39326919422045026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.828603130264842, 0.5598364515778727, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.848681154583996, 2.563767102786102, 0.}, 
      Optica`Optica`RayEnd :> {6.592467754632565, 2.4023860998368267`, 0.}, 
      RotationMatrix :> {{-0.8461413189894492, -0.5329585990476124, 0.}, {
       0.5329585990476124, -0.8461413189894492, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.047122397252328675`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3028021374224195, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.604424263240343`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15892534375867276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8461413189894492, -0.5329585990476124, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.592467754632565, 2.4023860998368267`, 0.}, 
      Optica`Optica`RayEnd :> {6.435364607407312, 2.3487108780900354`, 0.}, 
      RotationMatrix :> {{-0.9462941314626605, -0.32330700078923097`, 0.}, {
       0.32330700078923097`, -0.9462941314626605, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04227214269382524, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1660193612132241, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.850132917835914`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.326756013061517, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9462941314626605, -0.32330700078923097`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.496013510024986, 2.3292753428951984`, 0.}, 
      Optica`Optica`RayEnd :> {7.340774332740918, 2.1929983763609657`, 0.}, 
      RotationMatrix :> {{-0.7515136748118328, -0.6597175127058656, 0.}, {
       0.6597175127058656, -0.7515136748118328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008675885446115741, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20656866599658005`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.428846468967123`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26304447881591897`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7515136748118328, -0.6597175127058656, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.340774332740918, 2.1929983763609657`, 0.}, 
      Optica`Optica`RayEnd :> {7.198132313286852, 2.111419819714874, 0.}, 
      RotationMatrix :> {{-0.8680626442618957, -0.4964546763170277, 0.}, {
       0.4964546763170277, -0.8680626442618957, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008125914795933447, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16432226452429957`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.672043420463087`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2665130266571361, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8680626442618957, -0.4964546763170277, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.311736426290701, 2.4019540191871216`, 0.}, 
      Optica`Optica`RayEnd :> {7.132449862213479, 2.5089289844678593`, 0.}, 
      RotationMatrix :> {{-0.8587518476613214, 0.5123917096697269, 
       0.}, {-0.5123917096697269, -0.8587518476613214, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24579701805193852`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20877575351422145`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.7249793533854, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38074162206078854`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8587518476613214, 0.5123917096697269, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.132449862213479, 2.5089289844678593`, 0.}, 
      Optica`Optica`RayEnd :> {6.90909050153152, 2.6189814743779674`, 0.}, 
      RotationMatrix :> {{-0.8970258737658832, 0.4419780331583832, 
       0.}, {-0.4419780331583832, -0.8970258737658832, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24414790491148575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24899990871417554`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.09349921828238, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41997490984837604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8970258737658832, 0.4419780331583832, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.324263802301104, 2.5996489822677544`, 0.}, 
      Optica`Optica`RayEnd :> {7.351885704301527, 2.7200123734695314`, 0.}, 
      RotationMatrix :> {{0.22367331126865916`, 0.9746641728442227, 
       0.}, {-0.9746641728442227, 0.22367331126865916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008112634084741051, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12349216741037865`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.903874735150893`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3194470450564253, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 98, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.22367331126865916`, 0.9746641728442227, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.201544877431438, 1.1301121692279588`, 0.}, 
      Optica`Optica`RayEnd :> {8.20785455614225, 0.9396647794255726, 0.}, 
      RotationMatrix :> {{0.033112654637445366`, -0.9994516256942404, 0.}, {
       0.9994516256942404, 0.033112654637445366`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25843335636736947`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19055188355924405`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.796220374727152`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28542616390423853`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.033112654637445366`, -0.9994516256942404, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.20785455614225, 0.9396647794255726, 0.}, 
      Optica`Optica`RayEnd :> {8.220310908486281, 0.6114199351966487, 0.}, 
      RotationMatrix :> {{0.03792106161120104, -0.9992807378741362, 0.}, {
       0.9992807378741362, 0.03792106161120104, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25779341729664584`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32848110824914906`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.282372414935892`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25349247671982983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03792106161120104, -0.9992807378741362, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.911408050797058, 0.38375460538032846`, 0.}, 
      Optica`Optica`RayEnd :> {7.878705842196716, 0.3241365905784629, 0.}, 
      RotationMatrix :> {{-0.4809282423586497, -0.8767599589977975, 0.}, {
       0.8767599589977975, -0.4809282423586497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07552132102494946, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0679981039166221, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.72709809959988, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1568126090387138, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4809282423586497, -0.8767599589977975, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.878705842196716, 0.3241365905784629, 0.}, 
      Optica`Optica`RayEnd :> {7.713475040829654, 0.0453881684976358, 0.}, 
      RotationMatrix :> {{-0.509908708624229, -0.8602285213065018, 0.}, {
       0.8602285213065018, -0.509908708624229, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.075290895035326, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3240399674931356, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.20667725148972, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34123945429526403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.509908708624229, -0.8602285213065018, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3181519197722915`, 0.352797237396545, 0.}, 
      Optica`Optica`RayEnd :> {7.29714803826906, 0.27628610566998607`, 0.}, 
      RotationMatrix :> {{-0.26472665979378435`, -0.9643234911555485, 0.}, {
       0.9643234911555485, -0.26472665979378435`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024168896503610877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07934176905187244, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.427032538493176`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19656857478251194`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.26472665979378435`, -0.9643234911555485, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.29714803826906, 0.27628610566998607`, 0.}, 
      Optica`Optica`RayEnd :> {7.232629346704844, 0.09353097316202831, 0.}, 
      RotationMatrix :> {{-0.33289756534755255`, -0.9429629955547945, 0.}, {
       0.9429629955547945, -0.33289756534755255`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024031922073260648`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19380944254385435`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.71387051345808, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13563319038442664`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.33289756534755255`, -0.9429629955547945, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4981801653118625`, -0.6300356770624768, 0.},
       Optica`Optica`RayEnd :> {7.5252117425817255`, -0.8230631277620202, 0.},
       RotationMatrix :> {{0.1386867621677835, -0.9903362974259884, 0.}, {
       0.9903362974259884, 0.1386867621677835, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19721916761708747`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19491101275520897`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.845063651082604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.296898156278706, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1386867621677835, -0.9903362974259884, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5252117425817255`, -0.8230631277620201, 0.},
       Optica`Optica`RayEnd :> {7.5681643822077485`, -1.1355830966992775`, 
       0.}, RotationMatrix :> {{0.13615967560637937`, -0.9906869044954438, 
       0.}, {0.9906869044954438, 0.13615967560637937`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1967324479978787, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3154578580973808, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.311941281066726`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1773536303881728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13615967560637937`, -0.9906869044954438, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.079872856413603, 1.1491620785190124`, 0.}, 
      Optica`Optica`RayEnd :> {4.946357056947727, 1.3371832328657298`, 0.}, 
      RotationMatrix :> {{-0.5789818274170899, 0.8153404463908106, 
       0.}, {-0.8153404463908106, -0.5789818274170899, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010155848503700847`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23060447347977475`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.330252557481565`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3780266807750048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5789818274170899, 0.8153404463908106, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.946357056947727, 1.3371832328657298`, 0.}, 
      Optica`Optica`RayEnd :> {4.837885967467196, 1.5380887190130017`, 0.}, 
      RotationMatrix :> {{-0.47508830550282766`, 0.8799381239464801, 
       0.}, {-0.8799381239464801, -0.47508830550282766`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00999760033494628, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22831774266833715`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.668162816630705`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12225015066235223`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.47508830550282766`, 0.8799381239464801, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.884183329433145, 1.1158944386613112`, 0.}, 
      Optica`Optica`RayEnd :> {4.6865304189315635`, 1.0490457747668551`, 0.}, 
      RotationMatrix :> {{-0.9472876166194051, -0.320384411917194, 0.}, {
       0.320384411917194, -0.9472876166194051, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3139768236935531, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2086514243762072, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.59461128452618, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36921827541586166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9472876166194051, -0.320384411917194, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6865304189315635`, 1.0490457747668551`, 0.},
       Optica`Optica`RayEnd :> {4.349692745732636, 0.9390177742939605, 0.}, 
      RotationMatrix :> {{-0.9505719857162861, -0.3105042672354053, 0.}, {
       0.3105042672354053, -0.9505719857162861, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.31318590669708823`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3543526195389712, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.11905316144386, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20159416771332878`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9505719857162861, -0.3105042672354053, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.859839177235601, 0.9188957354033456, 0.}, 
      Optica`Optica`RayEnd :> {4.8632038120715215`, 0.8222252776510854, 0.}, 
      RotationMatrix :> {{0.034784139860007474`, -0.9993948487030532, 0.}, {
       0.9993948487030532, 0.034784139860007474`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009547589555766872, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09672899342808547, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.738411039899095`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16002530480200122`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.034784139860007474`, -0.9993948487030532, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8632038120715215`, 0.8222252776510854, 0.}, 
      Optica`Optica`RayEnd :> {4.846694276822012, 0.5984956863594586, 0.}, 
      RotationMatrix :> {{-0.07359226871754465, -0.9972884126394951, 0.}, {
       0.9972884126394951, -0.07359226871754465, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00943484333847693, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22433790311419338`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.070431136508102`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08875967490034764, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.07359226871754465, -0.9972884126394951, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8771242751091632`, 1.0203648055844956`, 0.},
       Optica`Optica`RayEnd :> {3.689696749116665, 1.0618743042281937`, 0.}, 
      RotationMatrix :> {{-0.9763424179664082, 0.21623016181723217`, 
       0.}, {-0.21623016181723217`, -0.9763424179664082, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2824554827921963, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19196904952965702`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.202806026711034`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3402096343608371, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9763424179664082, 0.21623016181723217`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.689696749116665, 1.0618743042281937`, 0.}, 
      Optica`Optica`RayEnd :> {3.412383262155191, 1.1080402052512859`, 0.}, 
      RotationMatrix :> {{-0.9864244861439053, 0.16421550820714606`, 
       0.}, {-0.16421550820714606`, -0.9864244861439053, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2813076860894983, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28112997077509405`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.618878383458174`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29408261163931665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9864244861439053, 0.16421550820714606`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.851433958250631, 0.9509216586411364, 0.}, 
      Optica`Optica`RayEnd :> {2.5742653848532453`, 0.9177688138836663, 0.}, 
      RotationMatrix :> {{-0.9929222735714449, -0.11876598269585402`, 0.}, {
       0.11876598269585402`, -0.9929222735714449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.287080137891467, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791442802470702, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.973446925011626`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28219020577833964`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9929222735714449, -0.11876598269585402`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5742653848532453`, 0.9177688138836663, 0.}, 
      Optica`Optica`RayEnd :> {2.3595970983370855`, 0.9048842717050697, 0.}, 
      RotationMatrix :> {{-0.9982036095551594, -0.059912885684549264`, 0.}, {
       0.059912885684549264`, -0.9982036095551594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2857843220414894, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21505460856009578`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.291727745680568`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26872596041064906`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9982036095551594, -0.059912885684549264`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.773314947406275, -2.362531201942003, 0.}, 
      Optica`Optica`RayEnd :> {6.925505318214823, -2.8200025049527064`, 0.}, 
      RotationMatrix :> {{0.31566756841363075`, -0.9488698468450901, 0.}, {
       0.9488698468450901, 0.31566756841363075`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009010673179643778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4821222895128935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.885317738367334`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39261714754540966`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.31566756841363075`, -0.9488698468450901, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.925505318214823, -2.8200025049527064`, 0.}, 
      Optica`Optica`RayEnd :> {7.028902406669837, -3.1251692495618935`, 0.}, 
      RotationMatrix :> {{0.32090213629222714`, -0.9471123581302717, 0.}, {
       0.9471123581302717, 0.32090213629222714`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00898832765291629, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3222075416813558, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.36218490005574, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12356183492562456`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32090213629222714`, -0.9471123581302717, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.590262861182729, 3.6107477297384736`, 0.}, 
      Optica`Optica`RayEnd :> {6.58082047593546, 3.654169993663881, 0.}, 
      RotationMatrix :> {{-0.2124890085030096, 0.9771634567795744, 
       0.}, {-0.9771634567795744, -0.2124890085030096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08603215893289086, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.044437052597641684`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.79639309444614, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2818006060381996, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2124890085030096, 0.9771634567795744, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.58082047593546, 3.654169993663881, 0.}, 
      Optica`Optica`RayEnd :> {6.576370351743306, 3.840641917987641, 0.}, 
      RotationMatrix :> {{-0.02385805534812324, 0.9997153560864238, 
       0.}, {-0.9997153560864238, -0.02385805534812324, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08144387988438724, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18652501753473108`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.072450120397544`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26177753467596154`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.02385805534812324, 0.9997153560864238, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8485975650478776`, 3.044158711728051, 0.}, 
      Optica`Optica`RayEnd :> {3.7427671292921243`, 3.096120721976002, 0.}, 
      RotationMatrix :> {{-0.8976377897407678, 0.4407339315611046, 
       0.}, {-0.4407339315611046, -0.8976377897407678, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8436975977941865`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11789881950749474`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.768195285435954`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3426606075450049, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8976377897407678, 0.4407339315611046, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7427671292921243`, 3.096120721976002, 0.}, 
      Optica`Optica`RayEnd :> {3.622847132670974, 3.201489704433622, 0.}, 
      RotationMatrix :> {{-0.751212287394225, 0.6600606784742866, 
       0.}, {-0.6600606784742866, -0.751212287394225, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.5501949375025736`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1596352970172039, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.004455525021417`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17634448375421105`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.751212287394225, 0.6600606784742866, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.622847132670974, 3.201489704433622, 0.}, 
      Optica`Optica`RayEnd :> {3.643384671488563, 3.3597983825061997`, 0.}, 
      RotationMatrix :> {{0.1286528681396562, 0.991689689126311, 
       0.}, {-0.991689689126311, 0.1286528681396562, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2467792650334446, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1596352970172039, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.24071576460688, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28989220179070785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1286528681396562, 0.991689689126311, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.643384671488563, 3.3597983825061997`, 0.}, 
      Optica`Optica`RayEnd :> {3.7862216760573277`, 3.4310796435752473`, 0.}, 
      RotationMatrix :> {{0.8947708134584463, 0.44652568949939386`, 
       0.}, {-0.44652568949939386`, 0.8947708134584463, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.039285385455173426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15963529701720408`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.47697600419234, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23840578480252717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8947708134584463, 0.44652568949939386`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.667391997490735, 3.360284447263403, 0.}, 
      Optica`Optica`RayEnd :> {4.649074573465307, 3.427865298501506, 0.}, 
      RotationMatrix :> {{-0.26160543499422373`, 0.9651749045543415, 
       0.}, {-0.9651749045543415, -0.26160543499422373`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4189018213903022, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07001927932358322, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.31956350686489, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11872504343656423`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.26160543499422373`, 0.9651749045543415, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.649074573465307, 3.427865298501506, 0.}, 
      Optica`Optica`RayEnd :> {4.5651883069599, 3.6848540105536114`, 0.}, 
      RotationMatrix :> {{-0.3103067966117484, 0.9506364667824153, 
       0.}, {-0.9506364667824153, -0.3103067966117484, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4172591163243085, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27033331986718906`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.719656820268327`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19069129466634083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3103067966117484, 0.9506364667824153, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.277758717143984, 3.366557381576849, 0.}, 
      Optica`Optica`RayEnd :> {5.233858861547429, 3.5865970474625457`, 0.}, 
      RotationMatrix :> {{-0.19565295906544738`, 0.9806731971502706, 
       0.}, {-0.9806731971502706, -0.19565295906544738`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015564483242010537`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2243761392940154, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.64414861075794, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24724148189527462`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.19565295906544738`, 0.9806731971502706, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.233858861547429, 3.5865970474625457`, 0.}, 
      Optica`Optica`RayEnd :> {5.1726285273595956`, 3.9255726373682482`, 0.}, 
      RotationMatrix :> {{-0.17775677486930547`, 0.9840744529699276, 
       0.}, {-0.9840744529699276, -0.17775677486930547`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015523502650433552`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34446132493601184`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.15395137166324, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3836604459901514, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.17775677486930547`, 0.9840744529699276, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.898000674453068, 3.368881404682121, 0.}, 
      Optica`Optica`RayEnd :> {5.899134242939919, 3.3693583566555887`, 0.}, 
      RotationMatrix :> {{0.921734227468036, 0.38782214211401317`, 
       0.}, {-0.38782214211401317`, 0.921734227468036, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2351336208922049, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0012298214095449928`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.852598549022364`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39682561532341465`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.921734227468036, 0.38782214211401317`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.899134242939919, 3.3693583566555887`, 0.}, 
      Optica`Optica`RayEnd :> {6.111585282110616, 3.472367027206931, 0.}, 
      RotationMatrix :> {{0.8998106054272417, 0.43628072884400926`, 
       0.}, {-0.43628072884400926`, 0.8998106054272417, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.234174851383517, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23610639604522374`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.202036015169295`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4295049131756125, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8998106054272417, 0.43628072884400926`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8574455005292645`, 2.816628517706533, 0.}, 
      Optica`Optica`RayEnd :> {5.958198181637355, 2.6281149491080376`, 0.}, 
      RotationMatrix :> {{0.4713606375584698, -0.88194055885897, 0.}, {
       0.88194055885897, 0.4713606375584698, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012105074674283072`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21374861004509083`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.189996349505485`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4189779487234311, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4713606375584698, -0.88194055885897, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.958198181637355, 2.6281149491080376`, 0.}, 
      Optica`Optica`RayEnd :> {6.1176548356263805`, 2.335555256105638, 0.}, 
      RotationMatrix :> {{0.47857139049110675`, -0.8780486456930551, 0.}, {
       0.8780486456930551, 0.47857139049110675`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01207483296882638, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33319303484772006`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.68312204108011, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05131666543930639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.47857139049110675`, -0.8780486456930551, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8427720735431, 2.7228770601336127`, 0.}, 
      Optica`Optica`RayEnd :> {6.047190372337455, 2.7635250484531877`, 0.}, 
      RotationMatrix :> {{0.9807975248163596, 0.19502875509550233`, 
       0.}, {-0.19502875509550233`, 0.9807975248163596, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16306734246434534`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2084204880437782, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.735037506303268`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04691241289294572, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9807975248163596, 0.19502875509550233`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.047190372337455, 2.7635250484531877`, 0.}, 
      Optica`Optica`RayEnd :> {6.374197998047203, 2.8252555391612586`, 0.}, 
      RotationMatrix :> {{0.9826447112364727, 0.18549763200372227`, 
       0.}, {-0.18549763200372227`, 0.9826447112364727, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16265773361049068`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3327831737864548, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.22755660350722, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34735047492610494`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9826447112364727, 0.18549763200372227`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.820946895856471, 1.666690518766145, 0.}, 
      Optica`Optica`RayEnd :> {5.867096760510475, 1.5568645856293863`, 0.}, 
      RotationMatrix :> {{0.3873964023573893, -0.921913242903339, 0.}, {
       0.921913242903339, 0.3873964023573893, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10096808479410525`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11912827370923622`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.276234384666445`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11227261225243237`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3873964023573893, -0.921913242903339, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.867096760510475, 1.5568645856293863`, 0.}, 
      Optica`Optica`RayEnd :> {5.9726659601126935`, 1.3721407739913314`, 0.}, 
      RotationMatrix :> {{0.4961840624403958, -0.8682173553783318, 0.}, {
       0.8682173553783318, 0.4961840624403958, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09942613898925415, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21276217354300664`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.591122401510095`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36880455438215115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.4961840624403958, -0.8682173553783318, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.092211361633606, 1.8481257845740613`, 0.}, 
      Optica`Optica`RayEnd :> {5.088297965282513, 1.8262510277303763`, 0.}, 
      RotationMatrix :> {{-0.17610417354517233`, -0.9843715355799204, 0.}, {
       0.9843715355799204, -0.17610417354517233`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06235589354395006, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.022222053414819656`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.661619868681708`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22573669467050947`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17610417354517233`, -0.9843715355799204, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.088297965282513, 1.8262510277303763`, 0.}, 
      Optica`Optica`RayEnd :> {5.095108047103927, 1.6972718055676446`, 0.}, 
      RotationMatrix :> {{0.052726391575694254`, -0.9986089963701535, 0.}, {
       0.9986089963701535, 0.052726391575694254`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05621955499857236, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12915888263730704`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.85277501498492, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27146306987165825`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.052726391575694254`, -0.9986089963701535, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.387311192534063, 2.0334509906640714`, 0.}, 
      Optica`Optica`RayEnd :> {4.277659440999164, 1.9169985646153616`, 0.}, 
      RotationMatrix :> {{-0.6855286792117156, -0.7280456235554472, 0.}, {
       0.7280456235554472, -0.6855286792117156, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035218362921186554`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15995209954014775`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.22625271535981, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2714703170168967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6855286792117156, -0.7280456235554472, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.277659440999164, 1.9169985646153616`, 0.}, 
      Optica`Optica`RayEnd :> {4.122848840957539, 1.7180552732101344`, 0.}, 
      RotationMatrix :> {{-0.6141307436348971, -0.789204301637065, 0.}, {
       0.789204301637065, -0.6141307436348971, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034906898048323344`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25208085028496974`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.599332373781564`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09830151008711174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6141307436348971, -0.789204301637065, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8238202808915664`, 2.9838764681221184`, 0.},
       Optica`Optica`RayEnd :> {3.648140038558968, 3.098566661548034, 0.}, 
      RotationMatrix :> {{-0.837357255695888, 0.5466560402423538, 
       0.}, {-0.5466560402423538, -0.837357255695888, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02440197809350946, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20980321259245377`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.12237809176946, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2621270636500597, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.837357255695888, 0.5466560402423538, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.648140038558968, 3.098566661548034, 0.}, 
      Optica`Optica`RayEnd :> {3.4661872280868278`, 3.180921472328808, 0.}, 
      RotationMatrix :> {{-0.911027383384556, 0.41234585813790825`, 
       0.}, {-0.41234585813790825`, -0.911027383384556, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023717147410956534`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19972265794708385`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.417967625531144`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3404465869310849, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.911027383384556, 0.41234585813790825`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.641487887169879, 3.3291496725314924`, 0.}, 
      Optica`Optica`RayEnd :> {4.624830179117953, 3.40901924966295, 0.}, 
      RotationMatrix :> {{-0.20416819217873344`, 0.9789358249152323, 
       0.}, {-0.9789358249152323, -0.20416819217873344`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014959716100042153`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0815881645136172, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.5444635573738, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.017295826952048152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20416819217873344`, 0.9789358249152323, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.624830179117953, 3.40901924966295, 0.}, 
      Optica`Optica`RayEnd :> {4.557058154927904, 3.6857111952687807`, 0.}, 
      RotationMatrix :> {{-0.2379042687822157, 0.9712886074155291, 
       0.}, {-0.9712886074155291, -0.2379042687822157, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014913376547723609`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2848709883894051, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.96607262019012, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2155974218977402, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2379042687822157, 0.9712886074155291, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3805055831974253`, 0.37158406636224844`, 
       0.}, Optica`Optica`RayEnd :> {3.3641239810316463`, 0.3671921510397863, 
       0.}, RotationMatrix :> {{-0.9658892861064563, -0.25895537643532174`, 
       0.}, {0.25895537643532174`, -0.9658892861064563, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08212610034430937, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01696012410678428, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.235403488282138`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17920193491565167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9658892861064563, -0.25895537643532174`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3641239810316463`, 0.3671921510397863, 0.}, 
      Optica`Optica`RayEnd :> {3.072694552474338, 0.27587203506025676`, 0.}, 
      RotationMatrix :> {{-0.9542481123344863, -0.29901595292905137`, 0.}, {
       0.29901595292905137`, -0.9542481123344863, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08184612156414703, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3054021535807402, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.687398675581633`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.036625872626962694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9542481123344863, -0.29901595292905137`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.573649858233891, 1.7627108399105784`, 0.}, 
      Optica`Optica`RayEnd :> {4.47360863487234, 1.8249231390726355`, 0.}, 
      RotationMatrix :> {{-0.8491920224549151, 0.5280841874161071, 
       0.}, {-0.5280841874161071, -0.8491920224549151, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037301211389323546`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11780754024554142`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.317684629453492`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4003589092353319, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 98, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8491920224549151, 0.5280841874161071, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.098053619989534, 1.2406365255603116`, 0.}, 
      Optica`Optica`RayEnd :> {3.9358161488169614`, 1.2372535926012982`, 0.}, 
      RotationMatrix :> {{-0.9997826734144489, -0.02084720461493538, 0.}, {
       0.02084720461493538, -0.9997826734144489, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09042807278543785, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.162272737352509, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.832453868614383`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.309806455163185, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9997826734144489, -0.02084720461493538, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9358161488169614`, 1.2372535926012982`, 0.},
       Optica`Optica`RayEnd :> {3.667818548636428, 1.2196932435683943`, 0.}, 
      RotationMatrix :> {{-0.9978601724923594, -0.06538406651102652, 0.}, {
       0.06538406651102652, -0.9978601724923594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09010655765813673, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26857229857281006`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.192340748701948`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2440055322926938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9978601724923594, -0.06538406651102652, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.875021438164752, 0.5253603907749506, 0.}, 
      Optica`Optica`RayEnd :> {4.73748714802897, 0.40950604122527534`, 0.}, 
      RotationMatrix :> {{-0.7648125533709097, -0.6442528682173398, 0.}, {
       0.6442528682173398, -0.7648125533709097, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021330946697367084`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17982744860763508`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.185069875008235`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22992858044152598`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7648125533709097, -0.6442528682173398, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.73748714802897, 0.40950604122527534`, 0.}, 
      Optica`Optica`RayEnd :> {4.605132568154086, 0.3230387054496063, 0.}, 
      RotationMatrix :> {{-0.8371787205440416, -0.5469294194576125, 0.}, {
       0.5469294194576125, -0.8371787205440416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021005434590515924`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15809596759563296`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.396918471586382`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17971069776688858`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8371787205440416, -0.5469294194576125, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.070713347817326, -1.596189391324968, 0.}, 
      Optica`Optica`RayEnd :> {6.065334003334559, -1.8492591456462795`, 0.}, 
      RotationMatrix :> {{-0.021251570047966267`, -0.9997741598833687, 0.}, {
       0.9997741598833687, -0.021251570047966267`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008231160805651819, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25312692053456737`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.37308931265822, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14188855322169655`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.021251570047966267`, -0.9997741598833687, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.065334003334559, -1.8492591456462795`, 0.}, 
      Optica`Optica`RayEnd :> {6.055440525207455, -2.0856520759379458`, 0.}, 
      RotationMatrix :> {{-0.04181523064408571, -0.9991253607461784, 0.}, {
       0.9991253607461784, -0.04181523064408571, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008209098769605051, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23659986982526449`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.723257119999612`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18145351327879142`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.04181523064408571, -0.9991253607461784, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2065309528116637`, 1.3940584934118068`, 0.},
       Optica`Optica`RayEnd :> {3.1330446222023243`, 1.4117656203703455`, 0.},
       RotationMatrix :> {{-0.972175531095755, 0.23425357358786675`, 
       0.}, {-0.23425357358786675`, -0.972175531095755, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15086817163443453`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07558957025642454, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.317155922328737`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23037308019209482`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.972175531095755, 0.23425357358786675`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1330446222023243`, 1.4117656203703455`, 0.},
       Optica`Optica`RayEnd :> {2.8155000203866543`, 1.49926532461838, 0.}, 
      RotationMatrix :> {{-0.9640694783622232, 0.2656502228314335, 
       0.}, {-0.2656502228314335, -0.9640694783622232, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1504130030912096, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3293793745603479, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.804637396678054`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01530020613625066, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9640694783622232, 0.2656502228314335, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.843136121561057, -1.0614196196331982`, 0.}, 
      Optica`Optica`RayEnd :> {2.374937088589322, -0.6456031838817202, 0.}, 
      RotationMatrix :> {{-0.7476951024239715, 0.664042192794408, 
       0.}, {-0.664042192794408, -0.7476951024239715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008747646263565279, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6261897817089727, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.3558747456299, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32642827625792276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7476951024239715, 0.664042192794408, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.374937088589322, -0.6456031838817202, 0.}, 
      Optica`Optica`RayEnd :> {2.205090409605016, -0.5352505042925035, 0.}, 
      RotationMatrix :> {{-0.8385511235229239, 0.5448229191567119, 
       0.}, {-0.5448229191567119, -0.8385511235229239, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008516627514714629, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20254779251949004`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.655645478558746`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2848707001583598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8385511235229239, 0.5448229191567119, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.910787109517695, -2.0825841162416596`, 0.}, 
      Optica`Optica`RayEnd :> {2.8685673441515807`, -2.1857190069215964`, 0.},
       RotationMatrix :> {{-0.37884975176662417`, -0.9254581922412088, 0.}, {
       0.9254581922412088, -0.37884975176662417`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16557074836494867`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11144197711424661`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.030148069795985`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3836205989284074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.37884975176662417`, -0.9254581922412088, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8685673441515807`, -2.1857190069215964`, 
       0.}, Optica`Optica`RayEnd :> {
       2.7646409666322525`, -2.3652591978116506`, 0.}, 
      RotationMatrix :> {{-0.5009714870291998, -0.8654637884878554, 0.}, {
       0.8654637884878554, -0.5009714870291998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16220192185862228`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2074496856809549, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.337173604603798`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08701138785721907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5009714870291998, -0.8654637884878554, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.836149343049395, -2.845038464983356, 0.}, 
      Optica`Optica`RayEnd :> {3.9074945903586378`, -3.192587711922769, 0.}, 
      RotationMatrix :> {{0.20108774561412218`, -0.979573232874311, 0.}, {
       0.979573232874311, 0.20108774561412218`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008828564696933742, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3547965943491708, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.320103980283125`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18328817275211315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.20108774561412218`, -0.979573232874311, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9074945903586378`, -3.192587711922769, 0.}, 
      Optica`Optica`RayEnd :> {3.9147952493490976`, -3.3708372984770985`, 0.},
       RotationMatrix :> {{0.04092319838287775, -0.9991622950422592, 0.}, {
       0.9991622950422592, 0.04092319838287775, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00854113758069572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17839903230815005`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.584134548099186`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22071682084557165`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.04092319838287775, -0.9991622950422592, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3278659338480487`, 2.5662557517157665`, 0.},
       Optica`Optica`RayEnd :> {3.311936366792392, 2.6064483382348436`, 0.}, 
      RotationMatrix :> {{-0.368448381763378, 0.9296482076441324, 
       0.}, {-0.9296482076441324, -0.368448381763378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042095286440483146`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.043234189221889714`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.237461535665776`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20330118199658279`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.368448381763378, 0.9296482076441324, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.311936366792392, 2.6064483382348436`, 0.}, 
      Optica`Optica`RayEnd :> {3.2063272730200887`, 2.8948686695957933`, 0.}, 
      RotationMatrix :> {{-0.34383839732409816`, 0.9390288368977788, 
       0.}, {-0.9390288368977788, -0.34383839732409816`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0419764609277312, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30714746984106395`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.692039791030552`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4134746198441448, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.34383839732409816`, 0.9390288368977788, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.199617787190727, 2.409714096482288, 0.}, 
      Optica`Optica`RayEnd :> {4.180860665318691, 2.4485790599121247`, 0.}, 
      RotationMatrix :> {{-0.43464994515023925`, 0.9005994810019007, 
       0.}, {-0.9005994810019007, -0.43464994515023925`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04882884288328304, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0431545478869255, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.352343940557422`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3116224633321494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.43464994515023925`, 0.9005994810019007, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.180860665318691, 2.4485790599121247`, 0.}, 
      Optica`Optica`RayEnd :> {4.044827874469686, 2.678623059659469, 0.}, 
      RotationMatrix :> {{-0.5090002446473454, 0.8607663741974017, 
       0.}, {-0.8607663741974017, -0.5090002446473454, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04847285641668143, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26725486339059423`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.7478811383755, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19247820006633098`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5090002446473454, 0.8607663741974017, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3170462945642005`, 0.5115606526621097, 0.}, 
      Optica`Optica`RayEnd :> {3.1737449217559712`, 0.4809086478989754, 0.}, 
      RotationMatrix :> {{-0.977879845679431, -0.20916741479965506`, 0.}, {
       0.20916741479965506`, -0.977879845679431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01261996716451644, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1465429249220937, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.851828648513637`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30407453621626784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.977879845679431, -0.20916741479965506`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1737449217559712`, 0.4809086478989754, 0.}, 
      Optica`Optica`RayEnd :> {2.918979408019427, 0.4432405576931465, 0.}, 
      RotationMatrix :> {{-0.9892456100535173, -0.14626388135778154`, 0.}, {
       0.14626388135778154`, -0.9892456100535173, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01255782721996194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2575351471337448, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.23298066627158, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3171302613678137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9892456100535173, -0.14626388135778154`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.886521337520707, 3.1181709029604834`, 0.}, 
      Optica`Optica`RayEnd :> {4.885546272031111, 3.1188602060507615`, 0.}, 
      RotationMatrix :> {{-0.8165646067797965, 0.5772540540823904, 
       0.}, {-0.5772540540823904, -0.8165646067797965, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18526359813962467`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0011941069714507821`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.83085122064677, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09636773684976796, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8165646067797965, 0.5772540540823904, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.885546272031111, 3.1188602060507615`, 0.}, 
      Optica`Optica`RayEnd :> {4.630191771136144, 3.308284194420784, 0.}, 
      RotationMatrix :> {{-0.8031470556818607, 0.5957808380181062, 
       0.}, {-0.5957808380181062, -0.8031470556818607, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18475735323859188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31794239808072816`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.301405969806247`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20535225858617845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8031470556818607, 0.5957808380181062, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.352014452126943, 1.193465846067691, 0.}, 
      Optica`Optica`RayEnd :> {7.38442038266304, 1.146214917856264, 0.}, 
      RotationMatrix :> {{0.5655912014693352, -0.8246857539817652, 0.}, {
       0.8246857539817652, 0.5655912014693352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03233327772179539, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057295676545022205`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.73536500946755, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.300836793500639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5655912014693352, -0.8246857539817652, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.38442038266304, 1.146214917856264, 0.}, 
      Optica`Optica`RayEnd :> {7.583154901338565, 0.8752202076403494, 0.}, 
      RotationMatrix :> {{0.5913734637399662, -0.8063978090150007, 0.}, {
       0.8063978090150007, 0.5913734637399662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03223665902254091, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33605586124660886`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.232727684112533`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09112701384723391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5913734637399662, -0.8063978090150007, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.869205868538643, 1.1908184192383027`, 0.}, 
      Optica`Optica`RayEnd :> {6.876421105352835, 1.0656697795973613`, 0.}, 
      RotationMatrix :> {{0.057557758970160716`, -0.9983421780042813, 0.}, {
       0.9983421780042813, 0.057557758970160716`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01325121479914858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12535645833487424`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.06722986006032, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23276110059866295`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.057557758970160716`, -0.9983421780042813, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.876421105352835, 1.0656697795973613`, 0.}, 
      Optica`Optica`RayEnd :> {6.915310280175682, 0.8725376930146247, 0.}, 
      RotationMatrix :> {{0.19739840638543144`, -0.980323349286597, 0.}, {
       0.980323349286597, 0.19739840638543144`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012955010863459836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19700855510917198`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.358802521621893`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3858886335455032, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19739840638543144`, -0.980323349286597, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.882439085046726, 2.4952029161458746`, 0.}, 
      Optica`Optica`RayEnd :> {5.665748465648419, 2.431360896350264, 0.}, 
      RotationMatrix :> {{-0.9592341998806472, -0.2826123666426035, 0.}, {
       0.2826123666426035, -0.9592341998806472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019002682548268236`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22589959722585803`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.966225049310772`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2706666722619532, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9592341998806472, -0.2826123666426035, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.665748465648419, 2.431360896350264, 0.}, 
      Optica`Optica`RayEnd :> {5.405927012198225, 2.3787519570622178`, 0.}, 
      RotationMatrix :> {{-0.980110239282221, -0.19845382045742072`, 0.}, {
       0.19845382045742072`, -0.980110239282221, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018857482624384282`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26509411190364995`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.358564334928175`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3836870245590635, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.980110239282221, -0.19845382045742072`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.36873589652042, 3.1892380843199777`, 0.}, 
      Optica`Optica`RayEnd :> {7.586433657280547, 3.2098175772256794`, 0.}, 
      RotationMatrix :> {{0.9955615379628855, 0.09411282659113651, 
       0.}, {-0.09411282659113651, 0.9955615379628855, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07782823637156928, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21866831176059676`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.51287559754203, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16070743195131865`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9955615379628855, 0.09411282659113651, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.586433657280547, 3.2098175772256794`, 0.}, 
      Optica`Optica`RayEnd :> {7.8855943003165185`, 3.2448708046005024`, 0.}, 
      RotationMatrix :> {{0.9932052560071191, 0.11637576826742119`, 
       0.}, {-0.11637576826742119`, 0.9932052560071191, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07761646722590164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30120726931979425`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.958662356135328`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4076521210722545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9932052560071191, 0.11637576826742119`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.887209292294565, 3.364039245201363, 0.}, 
      Optica`Optica`RayEnd :> {6.878341464867088, 3.355366615909915, 0.}, 
      RotationMatrix :> {{-0.7149315172114481, -0.6991944834577399, 0.}, {
       0.6991944834577399, -0.7149315172114481, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01095839230399624, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.012403743874749882`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.754965529714495`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27158284886806755`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7149315172114481, -0.6991944834577399, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.878341464867088, 3.355366615909915, 0.}, 
      Optica`Optica`RayEnd :> {6.686899135231831, 3.1787974319452377`, 0.}, 
      RotationMatrix :> {{-0.7350843405284594, -0.6779756723584106, 0.}, {
       0.6779756723584106, -0.7350843405284594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010926500070207843`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2604358698453927, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.140410617085674`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4252712154423237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7350843405284594, -0.6779756723584106, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.0291737225527635`, 3.3731969004548623`, 0.},
       Optica`Optica`RayEnd :> {7.05028264096431, 3.3076631218756067`, 0.}, 
      RotationMatrix :> {{0.3065947980470925, -0.9518401282833485, 0.}, {
       0.9518401282833485, 0.3065947980470925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01089429829311552, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06884956478715216, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.60040305460569, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14598671499747515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3065947980470925, -0.9518401282833485, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.05028264096431, 3.3076631218756067`, 0.}, 
      Optica`Optica`RayEnd :> {7.146594245946951, 3.101302362746748, 0.}, 
      RotationMatrix :> {{0.42292122604456045`, -0.9061664508030325, 0.}, {
       0.9061664508030325, 0.42292122604456045`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010715530046262984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2277294187463948, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.937442594350355`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39924186119446836`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.42292122604456045`, -0.9061664508030325, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.3305081301654775`, 3.5734870220448216`, 0.},
       Optica`Optica`RayEnd :> {6.316650533579623, 3.5785436319596386`, 0.}, 
      RotationMatrix :> {{-0.939412179557728, 0.34278966859956184`, 
       0.}, {-0.34278966859956184`, -0.939412179557728, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07495742786805175, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01475134864908688, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.601389859020443`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.028896209853356947`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.939412179557728, 0.34278966859956184`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.316650533579623, 3.5785436319596386`, 0.}, 
      Optica`Optica`RayEnd :> {6.083933215616448, 3.682061863205232, 0.}, 
      RotationMatrix :> {{-0.9136828206976415, 0.40642798028925126`, 
       0.}, {-0.40642798028925126`, -0.9136828206976415, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07455453200892936, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2547025211500459, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.978349590322512`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07585129267114783, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9136828206976415, 0.40642798028925126`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.258892531326898, 2.1212958894635108`, 0.}, 
      Optica`Optica`RayEnd :> {7.319072018686604, 2.0270369739297505`, 0.}, 
      RotationMatrix :> {{0.5381258095419099, -0.8428645283228279, 0.}, {
       0.8428645283228279, 0.5381258095419099, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019117156574398258`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11183163173484231`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.573661314260093`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04120271220745798, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5381258095419099, -0.8428645283228279, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.319072018686604, 2.0270369739297505`, 0.}, 
      Optica`Optica`RayEnd :> {7.341081509098933, 1.9555372819863597`, 0.}, 
      RotationMatrix :> {{0.2942028916843109, -0.9557429876931289, 0.}, {
       0.9557429876931289, 0.2942028916843109, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015863803786497575`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07481058492092023, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.673907498054128`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24615593580903725`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2942028916843109, -0.9557429876931289, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.195563023826857, 2.0683216790920302`, 0.}, 
      Optica`Optica`RayEnd :> {5.114170409498007, 2.067477533124626, 0.}, 
      RotationMatrix :> {{-0.9999462225662196, -0.010370726857229312`, 0.}, {
       0.010370726857229312`, -0.9999462225662196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011194206058731483`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08139699165017854, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.87083435622332, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06549368070971351, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9999462225662196, -0.010370726857229312`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.114170409498007, 2.067477533124626, 0.}, 
      Optica`Optica`RayEnd :> {4.933471172038791, 2.0451250526433418`, 0.}, 
      RotationMatrix :> {{-0.9924358634829188, -0.12276423287306484`, 0.}, {
       0.12276423287306484`, -0.9924358634829188, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011050292583148413`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18207648887763667`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.14030755976222, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3103688516414922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9924358634829188, -0.12276423287306484`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.631857465184819, 2.876601243636376, 0.}, 
      Optica`Optica`RayEnd :> {4.630982662709606, 2.876838106199413, 0.}, 
      RotationMatrix :> {{-0.9652439395626448, 0.2613506019460916, 
       0.}, {-0.2613506019460916, -0.9652439395626448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032426384914735054`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0009063019609420408, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.803303708634452`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0954766397679761, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9652439395626448, 0.2613506019460916, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.630982662709606, 2.876838106199413, 0.}, 
      Optica`Optica`RayEnd :> {4.372429286979578, 2.9644152224685603`, 0.}, 
      RotationMatrix :> {{-0.9471416974195437, 0.3208155311222085, 
       0.}, {-0.3208155311222085, -0.9471416974195437, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03227175994160671, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27298278223252975`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.207318226338597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.100257483009242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9471416974195437, 0.3208155311222085, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.428739814516301, -0.06855911911277818, 0.}, 
      Optica`Optica`RayEnd :> {4.382351075793916, -0.10517391641614338`, 0.}, 
      RotationMatrix :> {{-0.7849477018298978, -0.6195620270739327, 0.}, {
       0.6195620270739327, -0.7849477018298978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012459219588637941`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05909787188909807, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.641073365184962`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09509362523411857, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7849477018298978, -0.6195620270739327, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.382351075793916, -0.10517391641614338`, 0.},
       Optica`Optica`RayEnd :> {4.110370663361457, -0.32787980772381814`, 0.},
       RotationMatrix :> {{-0.7737112161334537, -0.633538439267335, 0.}, {
       0.633538439267335, -0.7737112161334537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012426480776489567`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.351527038462301, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.161333382109166`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2468726410049547, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7737112161334537, -0.633538439267335, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8263520093400993`, 1.444130763380094, 0.}, 
      Optica`Optica`RayEnd :> {2.6487928585431653`, 1.524816379995089, 0.}, 
      RotationMatrix :> {{-0.9104110681980194, 0.4137048306492681, 
       0.}, {-0.4137048306492681, -0.9104110681980194, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08181329329720088, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19503184550290845`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.634736664996005`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3670079867315677, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9104110681980194, 0.4137048306492681, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6487928585431653`, 1.524816379995089, 0.}, 
      Optica`Optica`RayEnd :> {2.379458000813778, 1.6251160758509406`, 0.}, 
      RotationMatrix :> {{-0.9371284812077398, 0.34898454078837515`, 
       0.}, {-0.34898454078837515`, -0.9371284812077398, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08136198035884218, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28740440945971174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.06009519099638, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40258306743213845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9371284812077398, 0.34898454078837515`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.425356686909021, 3.1169129380419007`, 0.}, 
      Optica`Optica`RayEnd :> {4.516830552912185, 3.3890059587277985`, 0.}, 
      RotationMatrix :> {{0.31866028991525525`, 0.9478689886430117, 
       0.}, {-0.9478689886430117, 0.31866028991525525`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008459788598646096, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28705762499460163`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.49215044423596, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32793527010988066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.31866028991525525`, 0.9478689886430117, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.516830552912185, 3.3890059587277985`, 0.}, 
      Optica`Optica`RayEnd :> {4.608146945359943, 3.6724081726290074`, 0.}, 
      RotationMatrix :> {{0.3066873819293489, 0.9518103013549087, 
       0.}, {-0.9518103013549087, 0.3066873819293489, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008438262258830306, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29775073194499335`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.93282152751455, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04589221665190732, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3066873819293489, 0.9518103013549087, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6155601683525647`, 3.140748752813215, 0.}, 
      Optica`Optica`RayEnd :> {3.488082437448585, 3.3130000643458306`, 0.}, 
      RotationMatrix :> {{-0.5948784662564055, 0.8038156569664632, 
       0.}, {-0.8038156569664632, -0.5948784662564055, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008900374482621383, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21429205818493033`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.667675632078666`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3237231819402243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5948784662564055, 0.8038156569664632, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.488082437448585, 3.3130000643458306`, 0.}, 
      Optica`Optica`RayEnd :> {3.360907336975386, 3.524693212670782, 0.}, 
      RotationMatrix :> {{-0.5149697168951541, 0.8572083706316248, 
       0.}, {-0.8572083706316248, -0.5149697168951541, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008818277576626286, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24695646423630666`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.0331711991484, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15168223980370824`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5149697168951541, 0.8572083706316248, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.868843846892141, 2.60011284487213, 0.}, 
      Optica`Optica`RayEnd :> {2.8116934041868635`, 2.6194695648763573`, 0.}, 
      RotationMatrix :> {{-0.9471480401673776, 0.3207968048579909, 
       0.}, {-0.3207968048579909, -0.9471480401673776, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22045000510342017`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0603395037328882, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.675895592192795`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.017850736627147843`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9471480401673776, 0.3207968048579909, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8116934041868635`, 2.6194695648763573`, 0.},
       Optica`Optica`RayEnd :> {2.577113124496869, 2.7190939695865692`, 0.}, 
      RotationMatrix :> {{-0.9204328871097435, 0.39090062717629737`, 
       0.}, {-0.39090062717629737`, -0.9204328871097435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21911161364479734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2548586463773603, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.05308638883129, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1033831840835808, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9204328871097435, 0.39090062717629737`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.26131283152225, 1.5996640494127237`, 0.}, 
      Optica`Optica`RayEnd :> {3.0638595987935724`, 1.1604254624250783`, 0.}, 
      RotationMatrix :> {{-0.4100121481991377, -0.9120800613592691, 0.}, {
       0.9120800613592691, -0.4100121481991377, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012720769241564482`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4815789814909997, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.267649974012745`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14051012253734957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4100121481991377, -0.9120800613592691, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0638595987935724`, 1.1604254624250783`, 0.},
       Optica`Optica`RayEnd :> {2.9275913020691573`, 0.8424886120484518, 0.}, 
      RotationMatrix :> {{-0.3939428586564471, -0.9191349324846632, 0.}, {
       0.9191349324846632, -0.3939428586564471, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01268743223333858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.345908787861168, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.779594980047275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42065530243978333`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3939428586564471, -0.9191349324846632, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.191782608675725, 1.1704668874483517`, 0.}, 
      Optica`Optica`RayEnd :> {3.153448928015458, 1.10655298156924, 0.}, 
      RotationMatrix :> {{-0.514351084551279, -0.8575797116425522, 0.}, {
       0.8575797116425522, -0.514351084551279, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00815119386830329, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07452823919620839, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.771986907163583`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1574962628352757, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.514351084551279, -0.8575797116425522, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.153448928015458, 1.10655298156924, 0.}, 
      Optica`Optica`RayEnd :> {2.9713169457996758`, 0.8222603747779084, 0.}, 
      RotationMatrix :> {{-0.5394417555634347, -0.8420229167633382, 0.}, {
       0.8420229167633382, -0.5394417555634347, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008127404314064142, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3376304862154197, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.271680026762404`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3652654934623542, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5394417555634347, -0.8420229167633382, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.69371070634779, -3.4233066182279197`, 0.}, 
      Optica`Optica`RayEnd :> {2.670413320797123, -3.4341668154465013`, 0.}, 
      RotationMatrix :> {{-0.9063607097504638, -0.4225047500568897, 0.}, {
       0.4225047500568897, -0.9063607097504638, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011976862565665873`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02570431981443799, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.436407679126358`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2821041017325495, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.9063607097504638, -0.4225047500568897, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.670413320797123, -3.4341668154465013`, 0.}, 
      Optica`Optica`RayEnd :> {2.3865127223489795`, -3.5668852488817966`, 0.},
       RotationMatrix :> {{-0.9058998759128252, -0.4234919300543133, 0.}, {
       0.4234919300543133, -0.9058998759128252, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011947336524091232`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3133907024350482, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.90022591873023, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20701157903933753`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.9058998759128252, -0.4234919300543133, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.65303976200892, 2.961530386470526, 0.}, 
      Optica`Optica`RayEnd :> {6.899423196141074, 2.98718877936853, 0.}, 
      RotationMatrix :> {{0.9946211325466305, 0.10357993382725013`, 
       0.}, {-0.10357993382725013`, 0.9946211325466305, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011595124378120948`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24771586493574024`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.334715293814096`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0709269569708325, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9946211325466305, 0.10357993382725013`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.899423196141074, 2.98718877936853, 0.}, 
      Optica`Optica`RayEnd :> {7.166293012942752, 3.0086036193514536`, 0.}, 
      RotationMatrix :> {{0.9967958743024367, 0.0799874050938041, 
       0.}, {-0.0799874050938041, 0.9967958743024367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011563207725312523`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26772764984449327`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.730952215583947`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33888211362475074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9967958743024367, 0.0799874050938041, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.854366695460026, -3.7783913530293813`, 0.}, 
      Optica`Optica`RayEnd :> {4.903634815891672, -3.9230067389810745`, 0.}, 
      RotationMatrix :> {{0.3224828772478805, -0.946575297523619, 0.}, {
       0.946575297523619, 0.3224828772478805, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023085277278882387`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15277747721710913`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.804716051932417`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30838748363961277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3224828772478805, -0.946575297523619, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.903634815891672, -3.9230067389810745`, 0.}, 
      Optica`Optica`RayEnd :> {5.000414990405947, -4.159206389957394, 0.}, 
      RotationMatrix :> {{0.37914639967101615`, -0.9253366995945344, 0.}, {
       0.9253366995945344, 0.37914639967101615`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022978405695244324`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2552580602064282, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.18249798103793, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30339220644372855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.37914639967101615`, -0.9253366995945344, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.921928558588366, -1.7290781022400192`, 0.}, 
      Optica`Optica`RayEnd :> {6.121394253571286, -1.7102266949563503`, 0.}, 
      RotationMatrix :> {{0.9955636723237634, 0.09409024577087062, 
       0.}, {-0.09409024577087062, 0.9955636723237634, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008280620533886911, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20035453334425504`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.480493206148182`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35249856099240445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9955636723237634, 0.09409024577087062, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.121394253571286, -1.7102266949563503`, 0.}, 
      Optica`Optica`RayEnd :> {6.294542797162495, -1.712435348389325, 0.}, 
      RotationMatrix :> {{0.9999186543238591, -0.012754792635057716`, 0.}, {
       0.012754792635057716`, 0.9999186543238591, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00818566325929982, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17316262962239773`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.73677389798933, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14311444845473817`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9999186543238591, -0.012754792635057716`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.933775921915895, 3.33685800507418, 0.}, 
      Optica`Optica`RayEnd :> {3.9501014524724933`, 3.4038499652223475`, 0.}, 
      RotationMatrix :> {{0.23676492187781567`, 0.971566967207198, 
       0.}, {-0.971566967207198, 0.23676492187781567`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008470841716264398, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06895248851526758, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.375212185915792`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37003895023805444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.23676492187781567`, 0.971566967207198, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9501014524724933`, 3.4038499652223475`, 0.},
       Optica`Optica`RayEnd :> {4.021738605429321, 3.6895005923389186`, 0.}, 
      RotationMatrix :> {{0.24325302242326757`, 0.9699628689191901, 
       0.}, {-0.9699628689191901, 0.24325302242326757`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008449774780802957, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29449645576110106`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.81106694044222, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16756809171022174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.24325302242326757`, 0.9699628689191901, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.319455317078221, 3.0548251894317278`, 0.}, 
      Optica`Optica`RayEnd :> {2.2762663904675184`, 3.0759686155040873`, 0.}, 
      RotationMatrix :> {{-0.898147583512537, 0.4396941189401907, 
       0.}, {-0.4396941189401907, -0.898147583512537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.37281863325722814`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048086670168166035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.688878518189618`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22882342123301577`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.898147583512537, 0.4396941189401907, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2762663904675184`, 3.0759686155040873`, 0.},
       Optica`Optica`RayEnd :> {2.11741073100309, 3.1862318942371473`, 0.}, 
      RotationMatrix :> {{-0.8214987206026011, 0.570210357717474, 
       0.}, {-0.570210357717474, -0.8214987206026011, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3627022135869865, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19337298461999008`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.975070535427204`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15206287442552502`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8214987206026011, 0.570210357717474, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.11741073100309, 3.1862318942371473`, 0.}, 
      Optica`Optica`RayEnd :> {2.1829895557969965`, 3.368145414678848, 0.}, 
      RotationMatrix :> {{0.3391312644978799, 0.9407390634177307, 
       0.}, {-0.9407390634177307, 0.3391312644978799, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009841911000837502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19337298461999014`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.26126255266479, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4210073586716423, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3391312644978799, 0.9407390634177307, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.558434112117004, 3.121394561388964, 0.}, 
      Optica`Optica`RayEnd :> {6.726026292771315, 3.1624269201018165`, 0.}, 
      RotationMatrix :> {{0.9713115362892392, 0.23781063784330134`, 
       0.}, {-0.23781063784330134`, 0.9713115362892392, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008972308485813917, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17254214985912128`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.088028551106447`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34530780742901773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9713115362892392, 0.23781063784330134`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.726026292771315, 3.1624269201018165`, 0.}, 
      Optica`Optica`RayEnd :> {6.874329786784559, 3.224916746452884, 0.}, 
      RotationMatrix :> {{0.9215325589344704, 0.38830109814895775`, 
       0.}, {-0.38830109814895775`, 0.9215325589344704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00869483209502335, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16093136653220447`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.32620697357411, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24527334216673008`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9215325589344704, 0.38830109814895775`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7207957282082207`, -0.8988499529645195, 0.},
       Optica`Optica`RayEnd :> {2.580453695055914, -0.8788474812033391, 0.}, 
      RotationMatrix :> {{-0.9899952557837117, 0.14110065033777655`, 
       0.}, {-0.14110065033777655`, -0.9899952557837117, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02091647197415751, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1417603087816897, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.44697495048515, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009866272778698172, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9899952557837117, 0.14110065033777655`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.580453695055914, -0.8788474812033391, 0.}, 
      Optica`Optica`RayEnd :> {2.38258625282617, -0.8872404335930295, 0.}, 
      RotationMatrix :> {{-0.9991016092171261, -0.04237893887002406, 0.}, {
       0.04237893887002406, -0.9991016092171261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019911736844423877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19804536435967537`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.74008208973747, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4045680491657107, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9991016092171261, -0.04237893887002406, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.073286747564538, 1.2026505553483355`, 0.}, 
      Optica`Optica`RayEnd :> {8.201736972220186, 1.6119815177360024`, 0.}, 
      RotationMatrix :> {{0.2994093973193583, 0.9541247364977273, 
       0.}, {-0.9541247364977273, 0.2994093973193583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01834513825149751, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4290120009781779, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.625992673755455`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34206221326027547`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2994093973193583, 0.9541247364977273, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.201736972220186, 1.6119815177360024`, 0.}, 
      Optica`Optica`RayEnd :> {8.28456357642351, 1.882574819793523, 0.}, 
      RotationMatrix :> {{0.2926881654351931, 0.9562079469520111, 
       0.}, {-0.9562079469520111, 0.2926881654351931, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018299469443057163`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2829858326528849, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.044811706081724`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07932774358284016, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2926881654351931, 0.9562079469520111, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.499397579882815, 0.6579562769550734, 0.}, 
      Optica`Optica`RayEnd :> {6.417094863371823, 0.7900791931475404, 0.}, 
      RotationMatrix :> {{-0.5287320678865597, 0.8487887843205767, 
       0.}, {-0.8487887843205767, -0.5287320678865597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0130640615784921, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15566053490943138`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.294250571369183`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2745042776888274, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 103, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.5287320678865597, 0.8487887843205767, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.135532990828835, -1.892394399522408, 0.}, 
      Optica`Optica`RayEnd :> {6.132323290557163, -1.8924612836515469`, 0.}, 
      RotationMatrix :> {{-0.9997829569963212, -0.020833600257567933`, 0.}, {
       0.020833600257567933`, -0.9997829569963212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020089281786825147`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0032103970658944195`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.730092606650338`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1882948942690248, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9997829569963212, -0.020833600257567933`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.132323290557163, -1.8924612836515469`, 0.}, 
      Optica`Optica`RayEnd :> {5.930327422316176, -1.9106077982607501`, 0.}, 
      RotationMatrix :> {{-0.9959890022819746, -0.08947573600343672, 0.}, {
       0.08947573600343672, -0.9959890022819746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019981090247845213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2028093360249775, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.030250423967306`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23172921481580155`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9959890022819746, -0.08947573600343672, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.249945292601955, -2.9372034400351885`, 0.}, 
      Optica`Optica`RayEnd :> {7.163782036569682, -3.096999373830829, 0.}, 
      RotationMatrix :> {{-0.47460913832044954`, -0.8801966631513207, 0.}, {
       0.8801966631513207, -0.47460913832044954`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03942061922742455, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18154571641243358`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.89326162293277, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3744211579702791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.47460913832044954`, -0.8801966631513207, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.163782036569682, -3.096999373830829, 0.}, 
      Optica`Optica`RayEnd :> {7.069476274145186, -3.3210102154751135`, 0.}, 
      RotationMatrix :> {{-0.3880060039609695, -0.9216568455180265, 0.}, {
       0.9216568455180265, -0.3880060039609695, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039057655766644425`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24305232770053103`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.252979067929555`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21799917270550612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3880060039609695, -0.9216568455180265, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.071484832429513, -2.258721142881024, 0.}, 
      Optica`Optica`RayEnd :> {6.931722774464518, -2.2747790926863147`, 0.}, 
      RotationMatrix :> {{-0.9934642168848846, -0.11414398700458298`, 0.}, {
       0.11414398700458298`, -0.9934642168848846, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015467565099601897`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.140681521880309, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.053375965697953`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29512706772905967`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9934642168848846, -0.11414398700458298`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.931722774464518, -2.2747790926863147`, 0.}, 
      Optica`Optica`RayEnd :> {6.6658613148600745`, -2.290693316004209, 0.}, 
      RotationMatrix :> {{-0.9982132452323058, -0.05975213002720404, 0.}, {
       0.05975213002720404, -0.9982132452323058, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015402976513957261`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26633733911492147`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.447555227588037`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2550922965522542, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9982132452323058, -0.05975213002720404, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.037465293458888, -1.4027113492410619`, 0.}, 
      Optica`Optica`RayEnd :> {7.931161121804959, -1.1241284316455704`, 0.}, 
      RotationMatrix :> {{-0.3565146648527769, 0.9342897268754011, 
       0.}, {-0.9342897268754011, -0.3565146648527769, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015263296658670286`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29817615412209675`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.77841106441648, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3319252182600775, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3565146648527769, 0.9342897268754011, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.931161121804959, -1.1241284316455704`, 0.}, 
      Optica`Optica`RayEnd :> {7.905259287943307, -0.9688719174246986, 0.}, 
      RotationMatrix :> {{-0.1645581458566042, 0.986367384209472, 
       0.}, {-0.986367384209472, -0.1645581458566042, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014321783793023742`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15740231956808146`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.011366497377242`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19255895038528037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1645581458566042, 0.986367384209472, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.236712677796566, -0.11373154791280835`, 0.},
       Optica`Optica`RayEnd :> {6.183012615094738, -0.052204520762133305`, 
       0.}, RotationMatrix :> {{-0.657560298798442, 0.7534019202551205, 
       0.}, {-0.7534019202551205, -0.657560298798442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013194063275259375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08166560967861675, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.46054770837703, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29029054697578766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.657560298798442, 0.7534019202551205, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.183012615094738, -0.052204520762133305`, 
       0.}, Optica`Optica`RayEnd :> {5.960741327726372, 0.18163303324655297`, 
       0.}, RotationMatrix :> {{-0.6889540837119661, 0.7248049879357928, 
       0.}, {-0.7248049879357928, -0.6889540837119661, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01314859414084821, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3226213366365531, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.93802728659913, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3918647286874737, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6889540837119661, 0.7248049879357928, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.152490345497259, -0.6774240377395112, 0.}, 
      Optica`Optica`RayEnd :> {4.017570463917072, -0.6412550494577799, 0.}, 
      RotationMatrix :> {{-0.965894829789618, 0.25893469791761087`, 
       0.}, {-0.25893469791761087`, -0.965894829789618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019069690081209758`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13968382210884578`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.83730164057277, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13270526034461752`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.965894829789618, 0.25893469791761087`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.017570463917072, -0.6412550494577799, 0.}, 
      Optica`Optica`RayEnd :> {3.844581130049851, -0.5661312995344663, 0.}, 
      RotationMatrix :> {{-0.9172425347815059, 0.3983291759181061, 
       0.}, {-0.3983291759181061, -0.9172425347815059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018586723648170465`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18859715648536515`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.11642543217111, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23814833789159082`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9172425347815059, 0.3983291759181061, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.077151719566918, -2.7896193673170946`, 0.}, 
      Optica`Optica`RayEnd :> {5.04843387188945, -2.830133321013055, 0.}, 
      RotationMatrix :> {{-0.5782917105219344, -0.8158300665834861, 0.}, {
       0.8158300665834861, -0.5782917105219344, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09209193217018218, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04965979479724701, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.21064329937285, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0931734262398794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5782917105219344, -0.8158300665834861, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.04843387188945, -2.830133321013055, 0.}, 
      Optica`Optica`RayEnd :> {4.8796782695141685`, -3.08245491405061, 0.}, 
      RotationMatrix :> {{-0.555933905218987, -0.831226499233492, 0.}, {
       0.831226499233492, -0.555933905218987, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09182984584338193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30355335551769724`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.659902265539042`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33268166486698825`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.555933905218987, -0.831226499233492, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3735957448722327`, 0.12285257957385659`, 
       0.}, Optica`Optica`RayEnd :> {3.3126918097624993`, 
       0.11835838566538617`, 0.}, 
      RotationMatrix :> {{-0.9972884743976943, -0.07359143179419202, 0.}, {
       0.07359143179419202, -0.9972884743976943, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011507924352898182`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06106952669488741, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.228472223643518`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.020538085226272092`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9972884743976943, -0.07359143179419202, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3126918097624993`, 0.11835838566538617`, 
       0.}, Optica`Optica`RayEnd :> {3.1309275385333617`, 0.1380248759012769, 
       0.}, RotationMatrix :> {{-0.994197517225027, 0.10756996208789857`, 
       0.}, {-0.10756996208789857`, -0.994197517225027, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010978168210542209`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18282511078530167`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.499053387605766`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3830426767876267, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.994197517225027, 0.10756996208789857`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.613477516367497, 2.8636309481357225`, 0.}, 
      Optica`Optica`RayEnd :> {6.836228146190559, 3.1835285607538286`, 0.}, 
      RotationMatrix :> {{0.5714329314397656, 0.8206487707089772, 
       0.}, {-0.8206487707089772, 0.5714329314397656, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009323772130858846, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3898106279276325, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.09050146629598, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.046694693248807255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5714329314397656, 0.8206487707089772, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.836228146190559, 3.1835285607538286`, 0.}, 
      Optica`Optica`RayEnd :> {6.891693862377186, 3.3137983546813343`, 0.}, 
      RotationMatrix :> {{0.391745088204695, 0.9200737937075999, 
       0.}, {-0.9200737937075999, 0.391745088204695, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008686223664738335, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14158624538425393`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.300049109464677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39122193355662593`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.391745088204695, 0.9200737937075999, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.920138022643766, 3.6150100035364083`, 0.}, 
      Optica`Optica`RayEnd :> {6.893635248830319, 3.7624543145467406`, 0.}, 
      RotationMatrix :> {{-0.17691245300973274`, 0.984226591781628, 
       0.}, {-0.984226591781628, -0.17691245300973274`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020765397233517745`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14980728243018848`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.94697411424366, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41509121271089167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.17691245300973274`, 0.984226591781628, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.893635248830319, 3.7624543145467406`, 0.}, 
      Optica`Optica`RayEnd :> {6.8194450232654305`, 3.8923426367631024`, 0.}, 
      RotationMatrix :> {{-0.49597931021011643`, 0.8683343387448739, 
       0.}, {-0.8683343387448739, -0.49597931021011643`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012562704846381669`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1495833072824322, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.16835740902166, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03847977810733971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.49597931021011643`, 0.8683343387448739, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.383789456511689, -1.9729749954037983`, 0.}, 
      Optica`Optica`RayEnd :> {3.330907938269609, -2.058829454821125, 0.}, 
      RotationMatrix :> {{-0.5244426925882708, -0.851445748236941, 0.}, {
       0.851445748236941, -0.5244426925882708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.038071278926875105`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10083374025309619`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.555648951190864`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10218692747978585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5244426925882708, -0.851445748236941, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.330907938269609, -2.058829454821125, 0.}, 
      Optica`Optica`RayEnd :> {3.182742657092213, -2.311972613455932, 0.}, 
      RotationMatrix :> {{-0.5051383704352685, -0.8630383692015097, 0.}, {
       0.8630383692015097, -0.5051383704352685, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03796757085197436, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2933162274917363, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.989756967878634`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36879236579901187`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5051383704352685, -0.8630383692015097, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.7020451715431815`, -3.9112365439015684`, 
       0.}, Optica`Optica`RayEnd :> {5.771706365735673, -4.080001974130683, 
       0.}, RotationMatrix :> {{0.3815436697856473, -0.924350814380828, 0.}, {
       0.924350814380828, 0.3815436697856473, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01569532709972737, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18257725054546692`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.211681789921293`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20550434984204222`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3815436697856473, -0.924350814380828, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.771706365735673, -4.080001974130683, 0.}, 
      Optica`Optica`RayEnd :> {5.875281126091442, -4.37143559027782, 0.}, 
      RotationMatrix :> {{0.3348773969043811, -0.9422617094218275, 0.}, {
       0.9422617094218275, 0.3348773969043811, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0156346115766811, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3092915834667216, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.66943333345204, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1282454830875747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3348773969043811, -0.9422617094218275, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.555889127695717, -2.088286515364006, 0.}, 
      Optica`Optica`RayEnd :> {7.648601230646284, -2.149668120186087, 0.}, 
      RotationMatrix :> {{0.8338162642311701, -0.5520420613536402, 0.}, {
       0.5520420613536402, 0.8338162642311701, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011590683998308326`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11119008698643344`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.812401716351435`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33930769163525015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8338162642311701, -0.5520420613536402, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.648601230646284, -2.149668120186087, 0.}, 
      Optica`Optica`RayEnd :> {7.897226245942283, -2.319820684585405, 0.}, 
      RotationMatrix :> {{0.8252442794911413, -0.5647759548415172, 0.}, {
       0.5647759548415172, 0.8252442794911413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011560738412840877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3012744486387783, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.258287900336825`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27932197335488046`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8252442794911413, -0.5647759548415172, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3690487587760924`, 3.5453326097585736`, 0.},
       Optica`Optica`RayEnd :> {3.2605448101087156`, 3.61893592385977, 0.}, 
      RotationMatrix :> {{-0.8275621089502703, 0.5613741674051096, 
       0.}, {-0.5613741674051096, -0.8275621089502703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00918722188775691, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13111275576042242`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.72028822675752, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09889100783543281, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.8275621089502703, 0.5613741674051096, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2605448101087156`, 3.61893592385977, 0.}, 
      Optica`Optica`RayEnd :> {3.057522303906609, 3.7785231599775653`, 0.}, 
      RotationMatrix :> {{-0.7861874761608554, 0.6179880681112082, 
       0.}, {-0.6179880681112082, -0.7861874761608554, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009136442549007983, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25823675949852937`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.102478630815344`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04298177175312878, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.7861874761608554, 0.6179880681112082, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.34954007318907, -2.9311449148270943`, 0.}, 
      Optica`Optica`RayEnd :> {7.277103947723624, -3.1009969653937595`, 0.}, 
      RotationMatrix :> {{-0.39228252834130706`, -0.9198447792742812, 0.}, {
       0.9198447792742812, -0.39228252834130706`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12227760455364485`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18465294840361154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.628095763925725`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06499574337091711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.39228252834130706`, -0.9198447792742812, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.277103947723624, -3.1009969653937595`, 0.}, 
      Optica`Optica`RayEnd :> {7.150433843677726, -3.3987902081105528`, 0.}, 
      RotationMatrix :> {{-0.39142323175282867`, -0.920210765881475, 0.}, {
       0.920210765881475, -0.39142323175282867`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12197617804681277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32361416944686083`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.107044734707078`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40221515214550135`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.39142323175282867`, -0.920210765881475, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.023701590059098, 2.6198351822922343`, 0.}, 
      Optica`Optica`RayEnd :> {7.889445456338815, 2.926024376894937, 0.}, 
      RotationMatrix :> {{-0.4015677434562001, 0.9158293222077439, 
       0.}, {-0.9158293222077439, -0.4015677434562001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04005257519182435, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33432997522353586`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.510791923634244`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3636674681723822, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4015677434562001, 0.9158293222077439, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.889445456338815, 2.926024376894937, 0.}, 
      Optica`Optica`RayEnd :> {7.850770231733905, 3.0919020319561095`, 0.}, 
      RotationMatrix :> {{-0.22706501560791226`, 0.9738796017408818, 
       0.}, {-0.9738796017408818, -0.22706501560791226`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03812215150147079, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1703266551272396, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.76287537322256, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17440673340732865`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22706501560791226`, 0.9738796017408818, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.382315238116761, -0.8858538580442203, 0.}, 
      Optica`Optica`RayEnd :> {4.378244028380549, -0.8871292544932251, 0.}, 
      RotationMatrix :> {{-0.9542699775058238, -0.29894616577409755`, 0.}, {
       0.29894616577409755`, -0.9542699775058238, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014951077029324087`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0042663081016685225`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.170704923168465`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11728735847559851`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9542699775058238, -0.29894616577409755`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.378244028380549, -0.8871292544932251, 0.}, 
      Optica`Optica`RayEnd :> {4.200021876269678, -0.9119070393901738, 0.}, 
      RotationMatrix :> {{-0.9904735532204886, -0.13770308773146467`, 0.}, {
       0.13770308773146467`, -0.9904735532204886, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01442919213850764, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17993630575131309`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.437010655680407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4228017050502978, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9904735532204886, -0.13770308773146467`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.842558002495407, -2.3562116887071047`, 0.}, 
      Optica`Optica`RayEnd :> {6.838998481869474, -2.3971098311794203`, 0.}, 
      RotationMatrix :> {{-0.0867060225159269, -0.9962339412304054, 0.}, {
       0.9962339412304054, -0.0867060225159269, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2592090937945081, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04105274953973577, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.5391679053385, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18368766880467272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.0867060225159269, -0.9962339412304054, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.838998481869474, -2.3971098311794203`, 0.}, 
      Optica`Optica`RayEnd :> {6.860468037503002, -2.5452454429729006`, 0.}, 
      RotationMatrix :> {{0.14343317098433256`, -0.9896600049822053, 0.}, {
       0.9896600049822053, 0.14343317098433256`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2333391156040766, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14968333674971912`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.760699243728084`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3081535262199577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14343317098433256`, -0.9896600049822053, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.860468037503002, -2.5452454429729006`, 0.}, 
      Optica`Optica`RayEnd :> {6.999102128718822, -2.6016873604925377`, 0.}, 
      RotationMatrix :> {{0.9261825279030604, -0.37707548979892075`, 0.}, {
       0.37707548979892075`, 0.9261825279030604, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023288063482978356`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1496833367497192, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.98223058211767, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19014988671592675`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9261825279030604, -0.37707548979892075`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.987758823987346, -1.6947174978191548`, 0.}, 
      Optica`Optica`RayEnd :> {8.249651997048355, -2.065005472982989, 0.}, 
      RotationMatrix :> {{0.5774385115272428, -0.8164341770193122, 0.}, {
       0.8164341770193122, 0.5774385115272428, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2736088560216683, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.45354296229452834`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.35740432788531, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22363568069121093`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5774385115272428, -0.8164341770193122, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.249651997048355, -2.065005472982989, 0.}, 
      Optica`Optica`RayEnd :> {8.393442965850957, -2.303851857405552, 0.}, 
      RotationMatrix :> {{0.5157694425745449, -0.8567274257932581, 0.}, {
       0.8567274257932581, 0.5157694425745449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2719906318120623, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2787892359129408, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.77001239703646, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2905578071219675, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5157694425745449, -0.8567274257932581, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.296808618032822, -0.9383558163661906, 0.}, 
      Optica`Optica`RayEnd :> {7.2484503078147435`, -1.131275623238627, 0.}, 
      RotationMatrix :> {{-0.24314299365088438`, -0.9699904559522662, 0.}, {
       0.9699904559522662, -0.24314299365088438`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024577282984038457`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19888835574473954`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.6778767332603, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.290307996385847, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.24314299365088438`, -0.9699904559522662, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.2484503078147435`, -1.131275623238627, 0.}, 
      Optica`Optica`RayEnd :> {7.185536517567847, -1.4233285737793353`, 0.}, 
      RotationMatrix :> {{-0.21058831332872877`, -0.9775748371809497, 0.}, {
       0.9775748371809497, -0.21058831332872877`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024502237353548752`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29875252454626033`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.120030469588766`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43217050512082145`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.21058831332872877`, -0.9775748371809497, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.892238369604698, 1.4306052722726568`, 0.}, 
      Optica`Optica`RayEnd :> {5.701552488729594, 1.5990694274151984`, 0.}, 
      RotationMatrix :> {{-0.7494245357347973, 0.6620897712838363, 
       0.}, {-0.6620897712838363, -0.7494245357347973, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008841048217494886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2544430716938555, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.434393931289545`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28505659053987464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.7494245357347973, 0.6620897712838363, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.701552488729594, 1.5990694274151984`, 0.}, 
      Optica`Optica`RayEnd :> {5.589911053871509, 1.723989415994277, 0.}, 
      RotationMatrix :> {{-0.6663668469371244, 0.7456240509151204, 
       0.}, {-0.7456240509151204, -0.6663668469371244, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008715109357626271, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16753749885852218`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.68234942960016, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.014548213874234883`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6663668469371244, 0.7456240509151204, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.243269221268635, 0.13022919532730276`, 0.}, 
      Optica`Optica`RayEnd :> {6.188201289061612, 0.0793996632269098, 0.}, 
      RotationMatrix :> {{-0.7348194413020738, -0.6782627725922362, 0.}, {
       0.6782627725922362, -0.7348194413020738, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17245765173232358`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07494076655000352, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.399163127058305`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3214406869958149, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7348194413020738, -0.6782627725922362, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.188201289061612, 0.0793996632269098, 0.}, 
      Optica`Optica`RayEnd :> {5.940248911892806, -0.1320508901896091, 0.}, 
      RotationMatrix :> {{-0.7608918862770071, -0.6488786769480235, 0.}, {
       0.6488786769480235, -0.7608918862770071, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17188949785270988`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32587070731167894`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.88145177387959, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42893724654496335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7608918862770071, -0.6488786769480235, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.35088627346321, -0.39228288094063185`, 0.}, 
      Optica`Optica`RayEnd :> {7.351114219330654, -0.3940541335758071, 0.}, 
      RotationMatrix :> {{0.12763928488179715`, -0.9918206556403546, 0.}, {
       0.9918206556403546, 0.12763928488179715`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01058631217158876, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0017858597974365236`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.872070865428054`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28070353136331366`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12763928488179715`, -0.9918206556403546, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.351114219330654, -0.3940541335758071, 0.}, 
      Optica`Optica`RayEnd :> {7.401924794015256, -0.6117164683421243, 0.}, 
      RotationMatrix :> {{0.22732591563266707`, -0.9738187347149206, 0.}, {
       0.9738187347149206, 0.22732591563266707`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01047791027299739, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2235142198512298, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.202871910807875`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43111307889272144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.22732591563266707`, -0.9738187347149206, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.267663358684314, 2.8974339656723194`, 0.}, 
      Optica`Optica`RayEnd :> {7.359469019374845, 3.1712319685556047`, 0.}, 
      RotationMatrix :> {{0.31790915326593716`, 0.9481211791062015, 
       0.}, {-0.9481211791062015, 0.31790915326593716`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05058737132769413, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28877954518577015`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.65705268769322, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24512012022416524`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.31790915326593716`, 0.9481211791062015, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.359469019374845, 3.1712319685556047`, 0.}, 
      Optica`Optica`RayEnd :> {7.367555068531391, 3.3293246155986482`, 0.}, 
      RotationMatrix :> {{0.05108076294629277, 0.9986945256968337, 
       0.}, {-0.9986945256968337, 0.05108076294629277, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04165783591531445, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15829930271494708`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.89133565571134, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28830418892855986`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.05108076294629277, 0.9986945256968337, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.656119914545259, 2.8887936551931834`, 0.}, 
      Optica`Optica`RayEnd :> {6.636500606390305, 2.9000693577730754`, 0.}, 
      RotationMatrix :> {{-0.8670093977920703, 0.49829178614565794`, 
       0.}, {-0.49829178614565794`, -0.8670093977920703, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2509718533997882`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.022628714527105773`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.59259746769427, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27779164415046803`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8670093977920703, 0.49829178614565794`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.636500606390305, 2.9000693577730754`, 0.}, 
      Optica`Optica`RayEnd :> {6.351578364845772, 3.0615498507624155`, 0.}, 
      RotationMatrix :> {{-0.8699900225279154, 0.49306932646624446`, 
       0.}, {-0.49306932646624446`, -0.8699900225279154, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.247866025183471, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32750058525572306`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.07729833387274, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27111767971682005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8699900225279154, 0.49306932646624446`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.435364607407312, 2.3487108780900354`, 0.}, 
      Optica`Optica`RayEnd :> {6.3900416727379525`, 2.3443304094935713`, 0.}, 
      RotationMatrix :> {{-0.9953618433719982, -0.09620187502900568, 0.}, {
       0.09620187502900568, -0.9953618433719982, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037921119300415765`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04553412909200792, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.911148650819204`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07239215867908182, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9953618433719982, -0.09620187502900568, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.3900416727379525`, 2.3443304094935713`, 0.},
       Optica`Optica`RayEnd :> {6.149841575224362, 2.298041295074627, 0.}, 
      RotationMatrix :> {{-0.9819329966218261, -0.18922893580338013`, 0.}, {
       0.18922893580338013`, -0.9819329966218261, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037585883610391155`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24461964140115297`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.27318572009291, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24893841933497116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9819329966218261, -0.18922893580338013`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.90909050153152, 2.6189814743779674`, 0.}, 
      Optica`Optica`RayEnd :> {6.851180149953768, 2.6419531208205154`, 0.}, 
      RotationMatrix :> {{-0.9295383144216405, 0.36872553752374493`, 
       0.}, {-0.36872553752374493`, -0.9295383144216405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24250985607999634`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.062300123275482795`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.176981383471524`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2094911482515482, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9295383144216405, 0.36872553752374493`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.851180149953768, 2.6419531208205154`, 0.}, 
      Optica`Optica`RayEnd :> {6.556008619207015, 2.7669057467627027`, 0.}, 
      RotationMatrix :> {{-0.9208862180370004, 0.3898314679826517, 
       0.}, {-0.3898314679826517, -0.9208862180370004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2418475581176971, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3205298602208997, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.651365576598455`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0924763848980405, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9208862180370004, 0.3898314679826517, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.220310908486281, 0.6114199351966487, 0.}, 
      Optica`Optica`RayEnd :> {8.230386758025595, 0.3758248157132166, 0.}, 
      RotationMatrix :> {{0.04272859071324378, -0.9990867167246588, 0.}, {
       0.9990867167246588, 0.04272859071324378, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25715506285888134`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23581048125210968`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.59835845981372, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2307603047238681, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.04272859071324378, -0.9990867167246588, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.230386758025595, 0.3758248157132166, 0.}, 
      Optica`Optica`RayEnd :> {8.241317660936481, 0.05937870694277017, 0.}, 
      RotationMatrix :> {{0.03452210999587167, -0.9994039343135644, 0.}, {
       0.9994039343135644, 0.03452210999587167, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25651258153130724`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31663484393604635`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.06697802883907, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19960294862255606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.03452210999587167, -0.9994039343135644, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.713475040829654, 0.0453881684976358, 0.}, 
      Optica`Optica`RayEnd :> {7.6645860830738215`, -0.031147231682318602`, 
       0.}, RotationMatrix :> {{-0.5383215670242137, -0.8427395151982577, 
       0.}, {0.8427395151982577, -0.5383215670242137, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07506117210724828, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09081738639245975, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.328372549255615`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40233258935798827`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5383215670242137, -0.8427395151982577, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.6645860830738215`, -0.031147231682318602`, 
       0.}, Optica`Optica`RayEnd :> {7.534634195919815, -0.19247479425545638`,
        0.}, RotationMatrix :> {{-0.6273107220740926, -0.7787690658795328, 
       0.}, {0.7787690658795328, -0.6273107220740926, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07415323361893261, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2071571273711755, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.634965097764955`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20437270565078453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6273107220740926, -0.7787690658795328, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.232629346704844, 0.0935309731620283, 0.}, 
      Optica`Optica`RayEnd :> {7.053641669446334, -0.3173519697819334, 0.}, 
      RotationMatrix :> {{-0.39936951381659, -0.916790047630263, 0.}, {
       0.916790047630263, -0.39936951381659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023895723929679133`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.44817561447794935`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.314425836858533`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04728878318013305, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39936951381659, -0.916790047630263, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.053641669446334, -0.31735196978193336`, 0.},
       Optica`Optica`RayEnd :> {6.918235140502793, -0.6120523874165424, 0.}, 
      RotationMatrix :> {{-0.4175094243233421, -0.9086725926323467, 0.}, {
       0.9086725926323467, -0.4175094243233421, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02383202775510653, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32431969449071535`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.79441898470479, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3468762233432972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4175094243233421, -0.9086725926323467, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5681643822077485`, -1.1355830966992775`, 
       0.}, Optica`Optica`RayEnd :> {7.606344688347924, -1.4187334913977332`, 
       0.}, RotationMatrix :> {{0.13363170276914646`, -0.9910310630928869, 
       0.}, {0.9910310630928869, 0.13363170276914646`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1962469295600287, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28571293599494035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.694796615299946`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19569297640575828`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13363170276914646`, -0.9910310630928869, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.606344688347924, -1.4187334913977334`, 0.}, 
      Optica`Optica`RayEnd :> {7.603390235694879, -1.6110348748944543`, 0.}, 
      RotationMatrix :> {{-0.015361844900005833`, -0.9998819998986217, 0.}, {
       0.9998819998986217, -0.015361844900005833`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1911250966889257, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19232407775739377`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.97943625038089, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18146590414442818`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.015361844900005833`, -0.9998819998986217, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.837885967467196, 1.5380887190130017`, 0.}, 
      Optica`Optica`RayEnd :> {4.818216791195257, 1.5884045492762944`, 0.}, 
      RotationMatrix :> {{-0.36408426811985567`, 0.93136601060358, 
       0.}, {-0.93136601060358, -0.36408426811985567`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009841817985064952, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0540236917500189, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.74055456357573, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09566344247645209, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.36408426811985567`, 0.93136601060358, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.818216791195257, 1.5884045492762944`, 0.}, 
      Optica`Optica`RayEnd :> {4.701971665894905, 1.8586035155755987`, 0.}, 
      RotationMatrix :> {{-0.39519866075757065`, 0.9185956773986156, 
       0.}, {-0.9185956773986156, -0.39519866075757065`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009811690677919238, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2941435203184108, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.17588697364698, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2905397115895493, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.39519866075757065`, 0.9185956773986156, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.349692745732636, 0.9390177742939605, 0.}, 
      Optica`Optica`RayEnd :> {4.257659461780888, 0.9100120270629408, 0.}, 
      RotationMatrix :> {{-0.9537533086851039, -0.30059046254366767`, 0.}, {
       0.30059046254366767`, -0.9537533086851039, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.31239698204415983`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09649590005473262, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.2483576675172, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25887788525506367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9537533086851039, -0.30059046254366767`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.257659461780888, 0.9100120270629408, 0.}, 
      Optica`Optica`RayEnd :> {4.117167632438771, 0.8261175470069844, 0.}, 
      RotationMatrix :> {{-0.8585711449721746, -0.5126944402089497, 0.}, {
       0.5126944402089497, -0.8585711449721746, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2801784840613447, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1636344642664061, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.490536674631482`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24617295542055428`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8585711449721746, -0.5126944402089497, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.117167632438771, 0.8261175470069844, 0.}, 
      Optica`Optica`RayEnd :> {4.117643865374875, 0.662483775743396, 0.}, 
      RotationMatrix :> {{0.0029103461684538146`, -0.9999957649336215, 0.}, {
       0.9999957649336215, 0.0029103461684538146`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.028895701438889386`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1636344642664063, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.732715681745763`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24870193867446239`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0029103461684538146`, -0.9999957649336215, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.846694276822012, 0.5984956863594586, 0.}, 
      Optica`Optica`RayEnd :> {4.807577656537465, 0.386077457015285, 0.}, 
      RotationMatrix :> {{-0.18110397674729442`, -0.9834639544011334, 0.}, {
       0.9834639544011334, -0.18110397674729442`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009323428526295995, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2159898473081533, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.359857531901028`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.037868098235734005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.18110397674729442`, -0.9834639544011334, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.807577656537465, 0.386077457015285, 0.}, 
      Optica`Optica`RayEnd :> {4.751781410101081, 0.14079931650843228`, 0.}, 
      RotationMatrix :> {{-0.22181469945662813`, -0.9750888365195066, 0.}, {
       0.9750888365195066, -0.22181469945662813`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00929171402085879, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2515444042845894, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.73214325024222, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18152608725239186`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22181469945662813`, -0.9750888365195066, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.412383262155191, 1.1080402052512859`, 0.}, 
      Optica`Optica`RayEnd :> {3.109795497765404, 1.1420644005632679`, 0.}, 
      RotationMatrix :> {{-0.9937374908387939, 0.1117398733730132, 
       0.}, {-0.1117398733730132, -0.9937374908387939, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28016455361656745`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3044946650190065, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.026901234583644`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0009134636894602144, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9937374908387939, 0.1117398733730132, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.109795497765404, 1.1420644005632679`, 0.}, 
      Optica`Optica`RayEnd :> {2.9148613770099985`, 1.1285672376053026`, 0.}, 
      RotationMatrix :> {{-0.9976115226093712, -0.06907423511709103, 0.}, {
       0.06907423511709103, -0.9976115226093712, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2673399707217089, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19540083122289148`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.316094464793522`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3949867928813339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9976115226093712, -0.06907423511709103, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9148613770099985`, 1.1285672376053026`, 0.},
       Optica`Optica`RayEnd :> {2.853419889646802, 0.9430775385026428, 0.}, 
      RotationMatrix :> {{-0.3144382087766592, -0.9492779428920305, 0.}, {
       0.9492779428920305, -0.3144382087766592, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012237535303347718`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19540083122289204`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.6052876950034, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1338650447632489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.3144382087766592, -0.9492779428920305, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3595970983370855`, 0.9048842717050697, 0.}, 
      Optica`Optica`RayEnd :> {2.3474023378701885`, 0.9048738988616299, 0.}, 
      RotationMatrix :> {{-0.9999996382413978, -0.0008505980675463098, 0.}, {
       0.0008505980675463098, -0.9999996382413978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2844943552158621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01219476487845818, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.308068730617702`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02223633820901364, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999996382413978, -0.0008505980675463098, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3474023378701885`, 0.9048738988616299, 0.}, 
      Optica`Optica`RayEnd :> {2.202642609176679, 0.8816321711879552, 0.}, 
      RotationMatrix :> {{-0.9873551808366898, -0.15852364768370225`, 0.}, {
       0.15852364768370225`, -0.9873551808366898, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27574864497424645`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1466136315513524, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.525056905313704`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3492482972953295, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9873551808366898, -0.15852364768370225`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.202642609176679, 0.8816321711879552, 0.}, 
      Optica`Optica`RayEnd :> {2.1829116023236583`, 0.7363522884607112, 0.}, 
      RotationMatrix :> {{-0.13457825608875892`, -0.9909029685030253, 0.}, {
       0.9909029685030253, -0.13457825608875892`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008476856233695713, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1466136315513524, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.742045080009706`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24116770924494785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13457825608875892`, -0.9909029685030253, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.028902406669837, -3.1251692495618935`, 0.}, 
      Optica`Optica`RayEnd :> {7.058316122578409, -3.2104291544489056`, 0.}, 
      RotationMatrix :> {{0.32612692003556276`, -0.9453259924640373, 0.}, {
       0.9453259924640373, 0.32612692003556276`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008966037540757144, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09019100878076788, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.48304085182197, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12369366132346574`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32612692003556276`, -0.9453259924640373, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.058316122578409, -3.2104291544489056`, 0.}, 
      Optica`Optica`RayEnd :> {7.152935114196686, -3.3998557454180136`, 0.}, 
      RotationMatrix :> {{0.44685726479991894`, -0.8946052676435202, 0.}, {
       0.8946052676435202, 0.44685726479991894`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00880072066566727, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21174320990538809`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.796420802481943`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39716800017164133`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.44685726479991894`, -0.8946052676435202, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7427671292921243`, 3.096120721976002, 0.}, 
      Optica`Optica`RayEnd :> {3.6491189382290914`, 3.096727167638321, 0.}, 
      RotationMatrix :> {{-0.9999790327560727, 0.006475650409698108, 
       0.}, {-0.006475650409698108, -0.9999790327560727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29350266029161254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09365015464866927, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.89368649266517, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2674857119277927, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999790327560727, 0.006475650409698108, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6491189382290914`, 3.096727167638321, 0.}, 
      Optica`Optica`RayEnd :> {3.350901074353575, 3.083822610252523, 0.}, 
      RotationMatrix :> {{-0.9990650690534624, -0.043231791510411705`, 0.}, {
       0.043231791510411705`, -0.9990650690534624, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2923722035278479, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2984969379002057, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.335461960757478`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1929730162620329, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9990650690534624, -0.043231791510411705`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.622847132670974, 3.201489704433622, 0.}, 
      Optica`Optica`RayEnd :> {3.548730151265034, 3.313291298098303, 0.}, 
      RotationMatrix :> {{-0.5525439897088618, 0.8334837367559205, 
       0.}, {-0.8334837367559205, -0.5525439897088618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.3034156724691288`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13413770267412084`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.18420004660474, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16361212327918773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5525439897088618, 0.8334837367559205, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.548730151265034, 3.313291298098303, 0.}, 
      Optica`Optica`RayEnd :> {3.3885589709624035`, 3.5767400067352, 0.}, 
      RotationMatrix :> {{-0.5194998236855053, 0.854470557240405, 
       0.}, {-0.854470557240405, -0.5194998236855053, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2991297679476463`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3083180647999504, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.640510782508667`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30990459493573497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5194998236855053, 0.854470557240405, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.643384671488563, 3.3597983825061997`, 0.}, 
      Optica`Optica`RayEnd :> {3.651399080236819, 3.37910346651708, 0.}, 
      RotationMatrix :> {{0.38341756859857107`, 0.9235751014887523, 
       0.}, {-0.9235751014887523, 0.38341756859857107`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2074938795782712, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.020902560040609145`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.268725195061297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20672086756239041`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.38341756859857107`, 0.9235751014887523, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.651399080236819, 3.37910346651708, 0.}, 
      Optica`Optica`RayEnd :> {3.6715545154570086`, 3.532753025731774, 0.}, 
      RotationMatrix :> {{0.13006368413568622`, 0.9915056419754008, 
       0.}, {-0.9915056419754008, 0.13006368413568622`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17507661322311674`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15496589500849858`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.498074719673873`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.317147855198903, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13006368413568622`, 0.9915056419754008, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6715545154570086`, 3.532753025731774, 0.}, 
      Optica`Optica`RayEnd :> {3.5550668598930115`, 3.63495407620088, 0.}, 
      RotationMatrix :> {{-0.7516986596154482, 0.6595067286482661, 
       0.}, {-0.6595067286482661, -0.7516986596154482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02735263909927003, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1549658950084988, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.72742424428645, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14487709455361908`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7516986596154482, 0.6595067286482661, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7862216760573277`, 3.4310796435752473`, 0.},
       Optica`Optica`RayEnd :> {3.881455294618198, 3.4502254001223314`, 0.}, 
      RotationMatrix :> {{0.9803841289227637, 0.19709632101171412`, 
       0.}, {-0.19709632101171412`, 0.9803841289227637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03303145034375969, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09713908635537816, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.60714237990855, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3190770961339321, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9803841289227637, 0.19709632101171412`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.881455294618198, 3.4502254001223314`, 0.}, 
      Optica`Optica`RayEnd :> {4.139812661650813, 3.5158217226159985`, 0.}, 
      RotationMatrix :> {{0.9692470990023642, 0.24608953873641212`, 
       0.}, {-0.24608953873641212`, 0.9692470990023642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032903138430371154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2665546972475228, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.00164333183488, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3764266220094934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9692470990023642, 0.24608953873641212`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.111585282110616, 3.472367027206931, 0.}, 
      Optica`Optica`RayEnd :> {6.264634592188302, 3.5569056035555873`, 0.}, 
      RotationMatrix :> {{0.8753415273128048, 0.4835051298194109, 
       0.}, {-0.4835051298194109, 0.8753415273128048, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2332199913071227, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1748452521697781, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.436328653076796`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15566681443737976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8753415273128048, 0.4835051298194109, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.264634592188302, 3.5569056035555873`, 0.}, 
      Optica`Optica`RayEnd :> {6.377435097169095, 3.658150991890274, 0.}, 
      RotationMatrix :> {{0.7441958247012045, 0.6679615067481759, 
       0.}, {-0.6679615067481759, 0.7441958247012045, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21124556975227035`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15157368697423523`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.660657709798663`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33430240163745334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7441958247012045, 0.6679615067481759, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.377435097169095, 3.658150991890274, 0.}, 
      Optica`Optica`RayEnd :> {6.345897813530606, 3.8064074667022325`, 0.}, 
      RotationMatrix :> {{-0.20806568915783674`, 0.9781148547053529, 
       0.}, {-0.9781148547053529, -0.20806568915783674`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019903950666125318`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15157368697423523`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.88498676652053, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15402233373085797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20806568915783674`, 0.9781148547053529, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.1176548356263805`, 2.335555256105638, 0.}, 
      Optica`Optica`RayEnd :> {6.144325840184996, 2.2875612976895767`, 0.}, 
      RotationMatrix :> {{0.48575001120931177`, -0.8740977786324325, 0.}, {
       0.8740977786324325, 0.48575001120931177`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01204466681521663, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.054906853202567316`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.75669722437155, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2164913164700943, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.48575001120931177`, -0.8740977786324325, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.144325840184996, 2.2875612976895767`, 0.}, 
      Optica`Optica`RayEnd :> {6.29350856581124, 2.0561842066253853`, 0.}, 
      RotationMatrix :> {{0.5418887891793814, -0.84045020088147, 0.}, {
       0.84045020088147, 0.5418887891793814, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011983669133454427`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27530136922035553`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.164143250817677`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24025246980439569`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5418887891793814, -0.84045020088147, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.374197998047203, 2.8252555391612586`, 0.}, 
      Optica`Optica`RayEnd :> {6.406564721915494, 2.8310406851140684`, 0.}, 
      RotationMatrix :> {{0.9843992790639394, 0.17594902494300865`, 
       0.}, {-0.17594902494300865`, 0.9843992790639394, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16224915365310683`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03287967043115754, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.271615361884972`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4315633901078284, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9843992790639394, 0.17594902494300865`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.406564721915494, 2.8310406851140684`, 0.}, 
      Optica`Optica`RayEnd :> {6.635004169707646, 2.8971105400953423`, 0.}, 
      RotationMatrix :> {{0.9606286565997035, 0.27783553429942703`, 
       0.}, {-0.27783553429942703`, 0.9606286565997035, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1604729420220983, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23780203330676072`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.623562371178977`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2693312705855209, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9606286565997035, 0.27783553429942703`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.9726659601126935`, 1.3721407739913314`, 0.},
       Optica`Optica`RayEnd :> {6.051377142344828, 1.2665536430853388`, 0.}, 
      RotationMatrix :> {{0.5976688838433689, -0.8017430419314038, 0.}, {
       0.8017430419314038, 0.5976688838433689, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09790774118840805, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1316969719520516, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.767596343925845`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013655111657401579`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5976688838433689, -0.8017430419314038, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.051377142344828, 1.2665536430853388`, 0.}, 
      Optica`Optica`RayEnd :> {6.1972652318558445`, 1.114415438426117, 0.}, 
      RotationMatrix :> {{0.692125371029753, -0.7217772999872785, 0.}, {
       0.7217772999872785, 0.692125371029753, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09633888958622767, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21078275066547975`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.079554814910754`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27936331635533895`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.692125371029753, -0.7217772999872785, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.095108047103927, 1.6972718055676446`, 0.}, 
      Optica`Optica`RayEnd :> {5.117654458232004, 1.619604436013454, 0.}, 
      RotationMatrix :> {{0.27878533419369556`, -0.9603534440186635, 0.}, {
       0.9603534440186635, 0.27878533419369556`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.050687083202645936`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0808737346004468, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.961145819349518`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1155240018941103, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.27878533419369556`, -0.9603534440186635, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.117654458232004, 1.619604436013454, 0.}, 
      Optica`Optica`RayEnd :> {5.14685598326838, 1.4104281174482072`, 0.}, 
      RotationMatrix :> {{0.1382616639185478, -0.9903957351940048, 0.}, {
       0.9903957351940048, 0.1382616639185478, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.049494744637069245`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21120478525109163`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.273728901521135`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.244335878499472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1382616639185478, -0.9903957351940048, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.122848840957539, 1.7180552732101344`, 0.}, 
      Optica`Optica`RayEnd :> {4.06868495637522, 1.6330362242929266`, 0.}, 
      RotationMatrix :> {{-0.5373050903862896, -0.8433879533435252, 0.}, {
       0.8433879533435252, -0.5373050903862896, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034598187714824896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10080657256267238`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.734413181015544`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08201161348994922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5373050903862896, -0.8433879533435252, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.06868495637522, 1.6330362242929266`, 0.}, 
      Optica`Optica`RayEnd :> {3.9166370419365357`, 1.3835162247723365`, 0.}, 
      RotationMatrix :> {{-0.5203618490470424, -0.8539458683408112, 0.}, {
       0.8539458683408112, -0.5203618490470424, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034505898670755424`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2921965065600693, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.166864010724446`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37067446051738795`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5203618490470424, -0.8539458683408112, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4661872280868278`, 3.180921472328808, 0.}, 
      Optica`Optica`RayEnd :> {3.397482177038022, 3.200061181694977, 0.}, 
      RotationMatrix :> {{-0.9633188753831106, 0.26835935670406175`, 
       0.}, {-0.26835935670406175`, -0.9633188753831106, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02305153619749623, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07132119260248267, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.51353802361847, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26770781230317336`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9633188753831106, 0.26835935670406175`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.397482177038022, 3.200061181694977, 0.}, 
      Optica`Optica`RayEnd :> {3.1006670786341908`, 3.289236112860523, 0.}, 
      RotationMatrix :> {{-0.9577104027753924, 0.2877338777686674, 
       0.}, {-0.2877338777686674, -0.9577104027753924, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022989948179846304`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30992155618616757`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.972221926773997`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05067376644040157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9577104027753924, 0.2877338777686674, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.072694552474338, 0.27587203506025676`, 0.}, 
      Optica`Optica`RayEnd :> {2.9111937313212852`, 0.21776340620799062`, 0.},
       RotationMatrix :> {{-0.9409461969091942, -0.33855613201081286`, 0.}, {
       0.33855613201081286`, -0.9409461969091942, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08156709726881975, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17163661608235242`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.917391741131986`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3966826737763327, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9409461969091942, -0.33855613201081286`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9111937313212852`, 0.21776340620799062`, 
       0.}, Optica`Optica`RayEnd :> {2.602454551891017, 0.12321755953209027`, 
       0.}, RotationMatrix :> {{-0.9561706057727767, -0.29281013072658607`, 
       0.}, {0.29281013072658607`, -0.9561706057727767, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08126037382539143, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3228913099464557, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.395270879852742`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3316458935354622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9561706057727767, -0.29281013072658607`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.47360863487234, 1.8249231390726355`, 0.}, 
      Optica`Optica`RayEnd :> {4.428650990937275, 1.8365678135129835`, 0.}, 
      RotationMatrix :> {{-0.9680544705093873, 0.25073998908588324`, 
       0.}, {-0.25073998908588324`, -0.9680544705093873, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03730121138932358, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04644123373699054, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.38641765538424, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24218385757812247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9680544705093873, 0.25073998908588324`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.428650990937275, 1.8365678135129835`, 0.}, 
      Optica`Optica`RayEnd :> {4.237518902676637, 1.909981509090571, 0.}, 
      RotationMatrix :> {{-0.9335069385173002, 0.35855933363957593`, 
       0.}, {-0.35855933363957593`, -0.9335069385173002, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036816131696574134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20474629633092487`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.66077769246768, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36536461538396436`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9335069385173002, 0.35855933363957593`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.667818548636428, 1.2196932435683943`, 0.}, 
      Optica`Optica`RayEnd :> {3.392784632189184, 1.1893133403696, 0.}, 
      RotationMatrix :> {{-0.9939546958182265, -0.10979099535433828`, 0.}, {
       0.10979099535433828`, -0.9939546958182265, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08978618567116699, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27670669257298003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.60186665370996, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18262275955702234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9939546958182265, -0.10979099535433828`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.392784632189184, 1.1893133403696, 0.}, 
      Optica`Optica`RayEnd :> {3.2213753721831653`, 1.1509229207014182`, 0.}, 
      RotationMatrix :> {{-0.9758246736838111, -0.2185548128728425, 0.}, {
       0.2185548128728425, -0.9758246736838111, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08868550331442777, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17565579619844596`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.837245420615876`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4153677425603935, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9758246736838111, -0.2185548128728425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.605132568154086, 0.3230387054496063, 0.}, 
      Optica`Optica`RayEnd :> {4.461195578242246, 0.2522018687756769, 0.}, 
      RotationMatrix :> {{-0.897231063817922, -0.44156134128811564`, 0.}, {
       0.44156134128811564`, -0.897231063817922, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02068488982680287, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16042354719569718`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.634345321436015`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4134747569444483, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.897231063817922, -0.44156134128811564`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.461195578242246, 0.2522018687756769, 0.}, 
      Optica`Optica`RayEnd :> {4.226784094955743, 0.11802907473082361`, 0.}, 
      RotationMatrix :> {{-0.8678866612784639, -0.49676226021601166`, 0.}, {
       0.49676226021601166`, -0.8678866612784639, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020585614942961496`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27009458002407366`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.996272058668275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41556308172707135`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8678866612784639, -0.49676226021601166`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.055440525207455, -2.0856520759379458`, 0.}, 
      Optica`Optica`RayEnd :> {6.035374206978884, -2.406801521780479, 0.}, 
      RotationMatrix :> {{-0.06236119147705871, -0.9980536467533, 0.}, {
       0.9980536467533, -0.06236119147705871, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008187095866582905, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32177573508923324`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.154436605019185`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1967641789806866, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06236119147705871, -0.9980536467533, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.035374206978884, -2.406801521780479, 0.}, 
      Optica`Optica`RayEnd :> {6.017758252410186, -2.666329052544557, 0.}, 
      RotationMatrix :> {{-0.06772119052733802, -0.9977042850231521, 0.}, {
       0.9977042850231521, -0.06772119052733802, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00816679943348881, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2601247029404664, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.539421165371074`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25707340637659587`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.06772119052733802, -0.9977042850231521, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8155000203866543`, 1.49926532461838, 0.}, 
      Optica`Optica`RayEnd :> {2.6393669072293284`, 1.554001809947269, 0.}, 
      RotationMatrix :> {{-0.954949747376776, 0.29676755210944356`, 
       0.}, {-0.29676755210944356`, -0.954949747376776, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14995920778927538`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18444228467640225`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.051790058144434`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3007562926843254, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.954949747376776, 0.29676755210944356`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6393669072293284`, 1.554001809947269, 0.}, 
      Optica`Optica`RayEnd :> {2.3678358241441186`, 1.6157500856389455`, 0.}, 
      RotationMatrix :> {{-0.9751043920839296, 0.22174630670798018`, 
       0.}, {-0.22174630670798018`, -0.9751043920839296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14900047646286538`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2784636037839101, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.46391619174462, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3753147689264824, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9751043920839296, 0.22174630670798018`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.205090409605016, -0.5352505042925035, 0.}, 
      Optica`Optica`RayEnd :> {2.1486604500619717`, -0.509633451286922, 0.}, 
      RotationMatrix :> {{-0.9105665345612087, 0.41336253596230765`, 
       0.}, {-0.41336253596230765`, -0.9105665345612087, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0082917097970114, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06197236270080701, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.73868844457783, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30981297756934884`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9105665345612087, 0.41336253596230765`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1486604500619717`, -0.509633451286922, 0.}, 
      Optica`Optica`RayEnd :> {1.8591223699710941`, -0.379751604104828, 0.}, 
      RotationMatrix :> {{-0.9124047082188516, 0.4092891990024551, 
       0.}, {-0.4092891990024551, -0.9124047082188516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00827119083604342, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3173351446816823, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.20834445870672, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22395138533701914`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9124047082188516, 0.4092891990024551, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7646409666322525`, -2.3652591978116506`, 
       0.}, Optica`Optica`RayEnd :> {2.687346924834199, -2.4646689242798066`, 
       0.}, RotationMatrix :> {{-0.6138187137543981, -0.789447013196513, 
       0.}, {0.789447013196513, -0.6138187137543981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15890164002061336`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12592324096032811`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.50591074749064, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40785773608175424`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6138187137543981, -0.789447013196513, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.687346924834199, -2.4646689242798066`, 0.}, 
      Optica`Optica`RayEnd :> {2.5207053132081034`, -2.6411097727657418`, 0.},
       RotationMatrix :> {{-0.6866301372053787, -0.7270069151537156, 0.}, {
       0.7270069151537156, -0.6866301372053787, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1574414362572255, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24269486961981523`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.865099154527964`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26547540069261244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6866301372053787, -0.7270069151537156, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9147952493490976`, -3.3708372984770985`, 
       0.}, Optica`Optica`RayEnd :> {
       3.9063545629573095`, -3.4404873654517356`, 0.}, 
      RotationMatrix :> {{-0.12030684216510365`, -0.9927367544965079, 0.}, {
       0.9927367544965079, -0.12030684216510365`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008263068083729345, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0701596537643676, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.67814848414344, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09420639684830437, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 103, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12030684216510365`, -0.9927367544965079, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2063272730200887`, 2.8948686695957933`, 0.},
       Optica`Optica`RayEnd :> {3.1824858594920125`, 2.9657044306250255`, 0.},
       RotationMatrix :> {{-0.318989910226595, 0.9477581111093846, 
       0.}, {-0.9477581111093846, -0.318989910226595, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041857970832639396`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07474033743305718, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.79219184319085, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.261002589713039, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.318989910226595, 0.9477581111093846, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1824858594920125`, 2.9657044306250255`, 0.},
       Optica`Optica`RayEnd :> {3.0835451215110132`, 3.193820375821446, 0.}, 
      RotationMatrix :> {{-0.397913825914371, 0.9174227962865253, 
       0.}, {-0.9174227962865253, -0.397913825914371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04155156283495627, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2486486559084547, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.160191853935363`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1330203559274653, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.397913825914371, 0.9174227962865253, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.044827874469686, 2.678623059659469, 0.}, 
      Optica`Optica`RayEnd :> {3.9333640797218736`, 2.8352853936772213`, 0.}, 
      RotationMatrix :> {{-0.5797291888964751, 0.8148092215613627, 
       0.}, {-0.8148092215613627, -0.5797291888964751, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04811946526786577, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19226872974946352`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.005521236239783`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3158075292072025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5797291888964751, 0.8148092215613627, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9333640797218736`, 2.8352853936772213`, 0.},
       Optica`Optica`RayEnd :> {3.830651011562688, 3.011017350880267, 0.}, 
      RotationMatrix :> {{-0.5046140646140347, 0.8633450328771816, 
       0.}, {-0.8633450328771816, -0.5046140646140347, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.047731239538056386`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20354777118181985`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.306771937588877`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17280590742657184`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5046140646140347, 0.8633450328771816, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.918979408019427, 0.4432405576931465, 0.}, 
      Optica`Optica`RayEnd :> {2.5876291796852042`, 0.4157227093399586, 0.}, 
      RotationMatrix :> {{-0.996569282123331, -0.08276270856000137, 0.}, {
       0.08276270856000137, -0.996569282123331, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012495993248684466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3324909108458916, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.678518486805075`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10688051352353245`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.996569282123331, -0.08276270856000137, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5876291796852042`, 0.4157227093399586, 0.}, 
      Optica`Optica`RayEnd :> {2.363445515092777, 0.42283839082818514`, 0.}, 
      RotationMatrix :> {{-0.9994966534700039, 0.03172443383674241, 
       0.}, {-0.03172443383674241, -0.9994966534700039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012329205797224829`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2242965634893494, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.01047740076931, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3474621672767122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9994966534700039, 0.03172443383674241, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.630191771136144, 3.308284194420784, 0.}, 
      Optica`Optica`RayEnd :> {4.528763188868726, 3.3871844873446237`, 0.}, 
      RotationMatrix :> {{-0.7893092398961589, 0.6139958662845758, 
       0.}, {-0.6139958662845758, -0.7893092398961589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18425249168486746`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1285029708771212, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47359995078159, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2965147147573379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7893092398961589, 0.6139958662845758, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.528763188868726, 3.3871844873446237`, 0.}, 
      Optica`Optica`RayEnd :> {4.395953481947561, 3.52396953458935, 0.}, 
      RotationMatrix :> {{-0.6966043288416454, 0.7174555101461549, 
       0.}, {-0.7174555101461549, -0.6966043288416454, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18029339692309035`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1906530026048044, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.7557663946367, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04081862575431711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6966043288416454, 0.7174555101461549, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.583154901338565, 0.8752202076403494, 0.}, 
      Optica`Optica`RayEnd :> {7.630096466793213, 0.8152795720390332, 0.}, 
      RotationMatrix :> {{0.6165648410338225, -0.7873041323408229, 0.}, {
       0.7873041323408229, 0.6165648410338225, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03214032904047513, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07613402894647564, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.33474728290081, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16986278555773598`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6165648410338225, -0.7873041323408229, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.630096466793213, 0.8152795720390332, 0.}, 
      Optica`Optica`RayEnd :> {7.825791340319894, 0.5933320850040109, 0.}, 
      RotationMatrix :> {{0.6613533985442243, -0.7500744511273552, 0.}, {
       0.7500744511273552, 0.6613533985442243, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.031997405606215196`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2959006092014427, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.772680184518947`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14896652648729372`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6613533985442243, -0.7500744511273552, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.915310280175682, 0.8725376930146247, 0.}, 
      Optica`Optica`RayEnd :> {7.006439621925628, 0.6147688300325258, 0.}, 
      RotationMatrix :> {{0.33331475673094735`, -0.9428156091969355, 0.}, {
       0.9428156091969355, 0.33331475673094735`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01266542796386836, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2734032619609037, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.725162892649504`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23234195069737817`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33331475673094735`, -0.9428156091969355, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.006439621925628, 0.6147688300325258, 0.}, 
      Optica`Optica`RayEnd :> {7.096466395184083, 0.3260823219419739, 0.}, 
      RotationMatrix :> {{0.297709276667724, -0.9546565804444967, 0.}, {
       0.9546565804444967, 0.297709276667724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012624684158436088`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3023982801816929, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.17271234731841, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.060504782285835654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.297709276667724, -0.9546565804444967, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.405927012198225, 2.3787519570622178`, 0.}, 
      Optica`Optica`RayEnd :> {5.334621434201527, 2.3706567906970477`, 0.}, 
      RotationMatrix :> {{-0.9936173493343103, -0.11280320519319283`, 0.}, {
       0.11280320519319283`, -0.9936173493343103, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018713392176377876`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07176362011439326, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.45472758588146, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.029057688168084767`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9936173493343103, -0.11280320519319283`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.334621434201527, 2.3706567906970477`, 0.}, 
      Optica`Optica`RayEnd :> {5.098600632748835, 2.3179016869850884`, 0.}, 
      RotationMatrix :> {{-0.975918342820759, -0.21813616881659476`, 0.}, {
       0.21813616881659476`, -0.975918342820759, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018499332020293288`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24184482563418805`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.81265792782006, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2610199782890495, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.975918342820759, -0.21813616881659476`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.8855943003165185`, 3.2448708046005024`, 0.},
       Optica`Optica`RayEnd :> {8.080559990141701, 3.272152460207569, 0.}, 
      RotationMatrix :> {{0.9903511888766862, 0.13858038349829246`, 
       0.}, {-0.13858038349829246`, 0.9903511888766862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07740527430003738, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19686520500502802`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.222461730842067`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11356562525633869`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9903511888766862, 0.13858038349829246`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.080559990141701, 3.272152460207569, 0.}, 
      Optica`Optica`RayEnd :> {8.370476193877607, 3.3020565011722733`, 0.}, 
      RotationMatrix :> {{0.9947224043468047, 0.10260281814117737`, 
       0.}, {-0.10260281814117737`, 0.9947224043468047, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07716041610470682, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2914543821160678, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.653814216373846`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28745707745835636`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9947224043468047, 0.10260281814117737`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.686899135231831, 3.1787974319452377`, 0.}, 
      Optica`Optica`RayEnd :> {6.59454673071253, 3.0984915207788184`, 0.}, 
      RotationMatrix :> {{-0.7546076565578103, -0.6561762603632721, 0.}, {
       0.6561762603632721, -0.7546076565578103, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010894700652459226`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12238466402603518`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.30440606688056, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08573780341429345, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7546076565578103, -0.6561762603632721, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.59454673071253, 3.0984915207788184`, 0.}, 
      Optica`Optica`RayEnd :> {6.352822588729898, 2.881774653529568, 0.}, 
      RotationMatrix :> {{-0.7445714753446027, -0.6675427462740949, 0.}, {
       0.6675427462740949, -0.7445714753446027, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010866584956333542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3246486737498994, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.78488610403041, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27690663664476406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7445714753446027, -0.6675427462740949, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.146594245946951, 3.101302362746748, 0.}, 
      Optica`Optica`RayEnd :> {7.277212258579763, 2.893757354530947, 0.}, 
      RotationMatrix :> {{0.5326425030401796, -0.8463403357722536, 0.}, {
       0.8463403357722536, 0.5326425030401796, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010539695268388717`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24522641713209106`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.26604599330736, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05924935674544442, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5326425030401796, -0.8463403357722536, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.277212258579763, 2.893757354530947, 0.}, 
      Optica`Optica`RayEnd :> {7.35450132886719, 2.727795098489933, 0.}, 
      RotationMatrix :> {{0.4221677508163196, -0.9065177274442506, 0.}, {
       0.9065177274442506, 0.4221677508163196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010363912059326562`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18307668015374873`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.536999479934906`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.341876255409508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4221677508163196, -0.9065177274442506, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.083933215616448, 3.682061863205232, 0.}, 
      Optica`Optica`RayEnd :> {5.955770445167616, 3.749961683916154, 0.}, 
      RotationMatrix :> {{-0.8836483394894041, 0.4681512705500406, 
       0.}, {-0.4681512705500406, -0.8836483394894041, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07415380171335308, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14503820662741046`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.172700787203244`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41558839112671864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8836483394894041, 0.4681512705500406, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.955770445167616, 3.749961683916154, 0.}, 
      Optica`Optica`RayEnd :> {5.6634007260393116`, 3.889464890278438, 0.}, 
      RotationMatrix :> {{-0.9025252960797181, 0.4306368422885063, 
       0.}, {-0.4306368422885063, -0.9025252960797181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07389998680337813, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3239462875979925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.652141292848274`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3670769943273006, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9025252960797181, 0.4306368422885063, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.341081509098933, 1.9555372819863597`, 0.}, 
      Optica`Optica`RayEnd :> {7.344366407822268, 1.8424170849010477`, 0.}, 
      RotationMatrix :> {{0.0290267756292118, -0.9995786343737896, 0.}, {
       0.9995786343737896, 0.0290267756292118, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013164105739109632`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11316788214083712`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.841395963622567`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08910656867066244, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0290267756292118, -0.9995786343737896, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.344366407822268, 1.8424170849010477`, 0.}, 
      Optica`Optica`RayEnd :> {7.372508919400013, 1.6226560092947893`, 0.}, 
      RotationMatrix :> {{0.1270222823745124, -0.9918998637868484, 0.}, {
       0.9918998637868484, 0.1270222823745124, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013037210331737627`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2215557070118554, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.138280611018452`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21020763131723297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1270222823745124, -0.9918998637868484, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.933471172038791, 2.0451250526433418`, 0.}, 
      Optica`Optica`RayEnd :> {4.698023718464621, 1.9885595114614367`, 0.}, 
      RotationMatrix :> {{-0.9723327778135763, -0.23360001966894872`, 0.}, {
       0.23360001966894872`, -0.9723327778135763, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0109082292690101, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24214698809558383`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.4647845238103, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40758716889535074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9723327778135763, -0.23360001966894872`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.698023718464621, 1.9885595114614365`, 0.}, 
      Optica`Optica`RayEnd :> {4.385537894137745, 1.9179248820281938`, 0.}, 
      RotationMatrix :> {{-0.9753918105496805, -0.22047860647376866`, 0.}, {
       0.22047860647376866`, -0.9753918105496805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010880347429740273`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32036953862753303`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.93893144097905, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17165687274849073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9753918105496805, -0.22047860647376866`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.372429286979578, 2.9644152224685603`, 0.}, 
      Optica`Optica`RayEnd :> {3.9123037629453368`, 3.1528852667350202`, 0.}, 
      RotationMatrix :> {{-0.9253799185733668, 0.37904090320326694`, 
       0.}, {-0.37904090320326694`, -0.9253799185733668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03211787229650239, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.49722877576985286`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.8736047858702, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1733385228829717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9253799185733668, 0.37904090320326694`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9123037629453368`, 3.1528852667350202`, 0.},
       Optica`Optica`RayEnd :> {3.613683131266335, 3.285649020901551, 0.}, 
      RotationMatrix :> {{-0.9137621713212519, 0.4062495467840799, 
       0.}, {-0.4062495467840799, -0.9137621713212519, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03202407014881213, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32680345176383474`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.357273894480674`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07151407488869597, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9137621713212519, 0.4062495467840799, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.110370663361457, -0.32787980772381814`, 0.},
       Optica`Optica`RayEnd :> {4.064677983430684, -0.3666837619941653, 0.}, 
      RotationMatrix :> {{-0.7622259059090589, -0.6473111063168259, 0.}, {
       0.6473111063168259, -0.7622259059090589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012393827991384323`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0599463749218518, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.241661524504448`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03556835759380125, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7622259059090589, -0.6473111063168259, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.064677983430684, -0.3666837619941653, 0.}, 
      Optica`Optica`RayEnd :> {3.8437336950449588`, -0.5645446446200453, 0.}, 
      RotationMatrix :> {{-0.7449499008220651, -0.6671204128680173, 0.}, {
       0.6671204128680173, -0.7449499008220651, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012358861385522885`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2965894594279557, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.680613924457823`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23295928892487966`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7449499008220651, -0.6671204128680173, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.379458000813778, 1.6251160758509406`, 0.}, 
      Optica`Optica`RayEnd :> {2.326056895709007, 1.6408456934842706`, 0.}, 
      RotationMatrix :> {{-0.9592515880289835, 0.28255334162573903`, 
       0.}, {-0.28255334162573903`, -0.9592515880289835, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.080913157032625, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05566955089904688, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.134692389201103`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.121037072191267, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9592515880289835, 0.28255334162573903`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.326056895709007, 1.6408456934842706`, 0.}, 
      Optica`Optica`RayEnd :> {2.1664863383255795`, 1.7124017880902116`, 0.}, 
      RotationMatrix :> {{-0.9124570975934192, 0.4091723903825767, 
       0.}, {-0.4091723903825767, -0.9124570975934192, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07930040003714685, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1748800659278012, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.39351488677425, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21685531750188353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9124570975934192, 0.4091723903825767, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.608146945359943, 3.6724081726290074`, 0.}, 
      Optica`Optica`RayEnd :> {4.6303386272555365`, 3.744375749694504, 0.}, 
      RotationMatrix :> {{0.29466574608085605`, 0.955600386190071, 
       0.}, {-0.955600386190071, 0.29466574608085605`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008416790693823655, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07531137293950635, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.03373876725349, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06673016614274432, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 103, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.29466574608085605`, 0.955600386190071, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.360907336975386, 3.524693212670782, 0.}, 
      Optica`Optica`RayEnd :> {3.304799005122269, 3.6423960631976082`, 0.}, 
      RotationMatrix :> {{-0.4303046093344581, 0.9026837448328842, 
       0.}, {-0.9026837448328842, -0.4303046093344581, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008736937931124794, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13039212370952444`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.20789664491916, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06323292578893362, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4303046093344581, 0.9026837448328842, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.304799005122269, 3.6423960631976082`, 0.}, 
      Optica`Optica`RayEnd :> {3.1688661246212564`, 3.9136726985842807`, 0.}, 
      RotationMatrix :> {{-0.44799005259810437`, 0.894038540988669, 
       0.}, {-0.894038540988669, -0.44799005259810437`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008713682529030067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30342834559087617`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.656970596393656`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35945272881703105`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.44799005259810437`, 0.894038540988669, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.577113124496869, 2.7190939695865692`, 0.}, 
      Optica`Optica`RayEnd :> {2.3044227199070897`, 2.8599001531862447`, 0.}, 
      RotationMatrix :> {{-0.8885373119752599, 0.45880436487437676`, 
       0.}, {-0.45880436487437676`, -0.8885373119752599, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2177813478003957, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30689809073248275`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.464329830412815`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1882381531880209, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8885373119752599, 0.45880436487437676`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3044227199070897`, 2.8599001531862447`, 0.},
       Optica`Optica`RayEnd :> {2.1626895965014343`, 2.9042839244054353`, 0.},
       RotationMatrix :> {{-0.9543031299420431, 0.29884031887083173`, 
       0.}, {-0.29884031887083173`, -0.9543031299420431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20907787479473, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1485200236263115, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.684139465379758`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.367691922148825, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9543031299420431, 0.29884031887083173`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1626895965014343`, 2.9042839244054353`, 0.},
       Optica`Optica`RayEnd :> {2.0713890407219795`, 2.787141251001066, 0.}, 
      RotationMatrix :> {{-0.614735666950704, -0.7887331993638111, 0.}, {
       0.7887331993638111, -0.614735666950704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008355645043696427, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14852002362631156`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.9039491003467, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.027955120783770167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.614735666950704, -0.7887331993638111, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9275913020691573`, 0.8424886120484518, 0.}, 
      Optica`Optica`RayEnd :> {2.906504493089363, 0.790802834633577, 0.}, 
      RotationMatrix :> {{-0.377752237363337, -0.9259067162338724, 0.}, {
       0.9259067162338724, -0.377752237363337, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012654182590593201`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05582179771317225, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.854396188982925`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2782332252722311, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.377752237363337, -0.9259067162338724, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.906504493089363, 0.790802834633577, 0.}, 
      Optica`Optica`RayEnd :> {2.7875435276326748`, 0.5557776983030938, 0.}, 
      RotationMatrix :> {{-0.4516069835327995, -0.8922169760906847, 0.}, {
       0.8922169760906847, -0.4516069835327995, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012567539497110194`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2634170192101291, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.244253377413916`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1700411359257293, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4516069835327995, -0.8922169760906847, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9713169457996758`, 0.8222603747779084, 0.}, 
      Optica`Optica`RayEnd :> {2.9206628938257806`, 0.7481077742418967, 0.}, 
      RotationMatrix :> {{-0.5640622730717434, -0.825732252063063, 0.}, {
       0.825732252063063, -0.5640622730717434, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008103684190499815, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08980223353362311, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.39201501969746, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38017714005443976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5640622730717434, -0.825732252063063, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9206628938257806`, 0.7481077742418967, 0.}, 
      Optica`Optica`RayEnd :> {2.7596905406228465`, 0.5532177507000103, 0.}, 
      RotationMatrix :> {{-0.6368255909716009, -0.7710078901565607, 0.}, {
       0.7710078901565607, -0.6368255909716009, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008036156829238536, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25277305982214, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.766119148234228`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2470892452441294, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6368255909716009, -0.7710078901565607, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3865127223489795`, -3.5668852488817966`, 
       0.}, Optica`Optica`RayEnd :> {2.3275229689816683`, -3.594540250413836, 
       0.}, RotationMatrix :> {{-0.9054379668698006, -0.42447860741229515`, 
       0.}, {0.42447860741229515`, -0.9054379668698006, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011917883271790598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0651505188933541, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.987527614047323`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13139206371632955`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9054379668698006, -0.42447860741229515`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3275229689816683`, -3.594540250413836, 0.}, 
      Optica`Optica`RayEnd :> {2.057599674808473, -3.732319033051137, 0.}, 
      RotationMatrix :> {{-0.8906779434447962, -0.4546347996589658, 0.}, {
       0.4546347996589658, -0.8906779434447962, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011881426859347045`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30305375378359223`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.43604716964704, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08095868586914129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8906779434447962, -0.4546347996589658, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.166293012942752, 3.0086036193514536`, 0.}, 
      Optica`Optica`RayEnd :> {7.375858465854501, 3.0204314211510552`, 0.}, 
      RotationMatrix :> {{0.9984110777385308, 0.05634997647723504, 
       0.}, {-0.05634997647723504, 0.9984110777385308, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011531378926044368`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2098989660515668, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.012216830093045`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22158658304988846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9984110777385308, 0.05634997647723504, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.375858465854501, 3.0204314211510552`, 0.}, 
      Optica`Optica`RayEnd :> {7.63197961151276, 3.0213397653388454`, 0.}, 
      RotationMatrix :> {{0.9999937110821879, 0.003546518866896553, 
       0.}, {-0.003546518866896553, 0.9999937110821879, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01148464108005055, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2561227563932238, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.391278509555015`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27441716945061084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999937110821879, 0.003546518866896553, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.294542797162495, -1.712435348389325, 0.}, 
      Optica`Optica`RayEnd :> {6.574341747354627, -1.7460994912691292`, 0.}, 
      RotationMatrix :> {{0.9928397383975927, -0.11945398217975066`, 0.}, {
       0.11945398217975066`, 0.9928397383975927, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008091794898757283, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.281816832436338, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.114408453454022`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00809880085283897, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9928397383975927, -0.11945398217975066`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.574341747354627, -1.7460994912691292`, 0.}, 
      Optica`Optica`RayEnd :> {6.852640212802115, -1.7759387147053527`, 0.}, 
      RotationMatrix :> {{0.9943010026269105, -0.1066091749106095, 0.}, {
       0.1066091749106095, 0.9943010026269105, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008071171132543742, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2798935782144769, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.528650949211446`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3646762144011254, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9943010026269105, -0.1066091749106095, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2762663904675184`, 3.0759686155040873`, 0.},
       Optica`Optica`RayEnd :> {2.155549579335169, 3.0016635362683948`, 0.}, 
      RotationMatrix :> {{-0.8516022288570628, -0.5241885574921326, 0.}, {
       0.5241885574921326, -0.8516022288570628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010116419670241383`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14175257771972233`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.878826972334046`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3713297385691143, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8516022288570628, -0.5241885574921326, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.155549579335169, 3.0016635362683948`, 0.}, 
      Optica`Optica`RayEnd :> {1.939751687198152, 2.8785860260273344`, 0.}, 
      RotationMatrix :> {{-0.8686513221746648, -0.4954239401605525, 0.}, {
       0.4954239401605525, -0.8686513221746648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010085525454068142`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24842866939610228`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.246501403040277`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36777597843138315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8686513221746648, -0.4954239401605525, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1829895557969965`, 3.368145414678848, 0.}, 
      Optica`Optica`RayEnd :> {2.3023266289224917`, 3.587895943765453, 0.}, 
      RotationMatrix :> {{0.47722754227161457`, 0.8787797635911938, 
       0.}, {-0.8787797635911938, 0.47722754227161457`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009574851113911351, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2500632561093346, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.596347315851297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013875246829043734`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.47722754227161457`, 0.8787797635911938, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3023266289224917`, 3.587895943765453, 0.}, 
      Optica`Optica`RayEnd :> {2.3669117145038703`, 3.764223584864702, 0.}, 
      RotationMatrix :> {{0.3439336281848025, 0.938993961324373, 
       0.}, {-0.938993961324373, 0.3439336281848025, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009338512798426355, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18778357301739523`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.87426700391704, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33341985661248136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3439336281848025, 0.938993961324373, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.874329786784559, 3.224916746452884, 0.}, 
      Optica`Optica`RayEnd :> {7.066713849244671, 3.3448531121491145`, 0.}, 
      RotationMatrix :> {{0.8485997763269044, 0.5290353670766516, 
       0.}, {-0.5290353670766516, 0.8485997763269044, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008425936901320234, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22670765162445747`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.629995226750882`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2552509934552784, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8485997763269044, 0.5290353670766516, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.066713849244671, 3.3448531121491145`, 0.}, 
      Optica`Optica`RayEnd :> {7.253210388579181, 3.423351419153272, 0.}, 
      RotationMatrix :> {{0.9216822990790403, 0.38794553685327304`, 
       0.}, {-0.38794553685327304`, 0.9216822990790403, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008163537134455279, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20234362699691702`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.92946379470632, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14075814548772397`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9216822990790403, 0.38794553685327304`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.38258625282617, -0.8872404335930295, 0.}, 
      Optica`Optica`RayEnd :> {2.1419537588121385`, -0.9426588754758249, 0.}, 
      RotationMatrix :> {{-0.9744905959312655, -0.22442833698427472`, 0.}, {
       0.22442833698427472`, -0.9744905959312655, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01895526476221411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24693157124217574`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.070970395201986`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30270019387446273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9744905959312655, -0.22442833698427472`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1419537588121385`, -0.9426588754758249, 0.},
       Optica`Optica`RayEnd :> {1.7735416284485892`, -1.0338422441077806`, 
       0.}, RotationMatrix :> {{-0.9707099782257054, -0.2402543197802087, 
       0.}, {0.2402543197802087, -0.9707099782257054, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018906009797879823`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3795285292492251, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.63267261849084, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04410606867567773, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9707099782257054, -0.2402543197802087, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.930327422316176, -1.9106077982607501`, 0.}, 
      Optica`Optica`RayEnd :> {5.66751611441676, -1.9525769503209212`, 0.}, 
      RotationMatrix :> {{-0.9874878671997882, -0.15769499717243246`, 0.}, {
       0.15769499717243246`, -0.9874878671997882, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01987348137823251, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2661413032290399, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.386879770294218`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42196980324362976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9874878671997882, -0.15769499717243246`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.66751611441676, -1.9525769503209212`, 0.}, 
      Optica`Optica`RayEnd :> {5.333169237688875, -2.0022077378949565`, 0.}, 
      RotationMatrix :> {{-0.9891614269649492, -0.1468321197989915, 0.}, {
       0.1468321197989915, -0.9891614269649492, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019823295162250266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3380104274322174, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.8871352028939, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12472760010314288`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9891614269649492, -0.1468321197989915, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.069476274145186, -3.3210102154751135`, 0.}, 
      Optica`Optica`RayEnd :> {7.05875444315332, -3.3553768685733916`, 0.}, 
      RotationMatrix :> {{-0.2978258230048031, -0.9546202277091718, 0.}, {
       0.9546202277091718, -0.2978258230048031, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03869803427452041, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03600034034555122, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.301219523992593`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16152647344256182`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.2978258230048031, -0.9546202277091718, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.05875444315332, -3.3553768685733916`, 0.}, 
      Optica`Optica`RayEnd :> {6.965978042793, -3.6638144368616565`, 0.}, 
      RotationMatrix :> {{-0.2880460321741571, -0.9576165638441744, 0.}, {
       0.9576165638441744, -0.2880460321741571, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03860062655474068, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3220887983078523, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.777910945488216`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39577008637556166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.2880460321741571, -0.9576165638441744, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.6658613148600745`, -2.290693316004209, 0.}, 
      Optica`Optica`RayEnd :> {6.603155983884158, -2.2910182688181258`, 0.}, 
      RotationMatrix :> {{-0.9999865725689109, -0.005182150314458081, 0.}, {
       0.005182150314458081, -0.9999865725689109, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015338657633684406`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06270617295873251, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.53158149935274, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09185231604268562, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999865725689109, -0.005182150314458081, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.603155983884158, -2.2910182688181258`, 0.}, 
      Optica`Optica`RayEnd :> {6.426423131981197, -2.3289619051770183`, 0.}, 
      RotationMatrix :> {{-0.9777203802288598, -0.20991154824147568`, 0.}, {
       0.20991154824147568`, -0.9777203802288598, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014280252355921732`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1807601186155008, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.79910647490368, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3617926081104624, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9777203802288598, -0.20991154824147568`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.905259287943307, -0.9688719174246986, 0.}, 
      Optica`Optica`RayEnd :> {7.915357255053708, -0.671240002641347, 0.}, 
      RotationMatrix :> {{0.033908192610710736`, 0.9994249518967767, 
       0.}, {-0.9994249518967767, 0.033908192610710736`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013438347927123846`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2978031659290529, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.410422739722172`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.348545593455585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.033908192610710736`, 0.9994249518967767, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.915357255053708, -0.671240002641347, 0.}, 
      Optica`Optica`RayEnd :> {7.930958569340212, -0.3847901262935921, 0.}, 
      RotationMatrix :> {{0.0543837763711063, 0.998520107392744, 
       0.}, {-0.998520107392744, 0.0543837763711063, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013402351513102574`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2868744196806511, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.834996880849534`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3075493693714524, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0543837763711063, 0.998520107392744, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.960741327726372, 0.18163303324655294`, 0.}, 
      Optica`Optica`RayEnd :> {5.66440582370264, 0.4679941414438552, 0.}, 
      RotationMatrix :> {{-0.7191054403372897, 0.6949009754470865, 
       0.}, {-0.6949009754470865, -0.7191054403372897, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013103281701318744`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4120890865249725, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.490226662542593`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36579502642407863`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7191054403372897, 0.6949009754470865, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.66440582370264, 0.4679941414438552, 0.}, 
      Optica`Optica`RayEnd :> {5.427593108847438, 0.6724781669937853, 0.}, 
      RotationMatrix :> {{-0.7568799954786049, 0.6535538787615807, 
       0.}, {-0.6535538787615807, -0.7568799954786049, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013047235194754725`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31288013459182096`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.953289261738487`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39054216872140696`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7568799954786049, 0.6535538787615807, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.844581130049851, -0.5661312995344663, 0.}, 
      Optica`Optica`RayEnd :> {3.675606847818308, -0.4607875571318453, 0.}, 
      RotationMatrix :> {{-0.8485963096295119, 0.5290409277959249, 
       0.}, {-0.5290409277959249, -0.8485963096295119, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01811598901200094, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19912210354216067`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.383249050917605`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2857984944017683, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8485963096295119, 0.5290409277959249, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.675606847818308, -0.4607875571318453, 0.}, 
      Optica`Optica`RayEnd :> {3.4805411901108987`, -0.372600169719215, 0.}, 
      RotationMatrix :> {{-0.9112071854386372, 0.41194837686899155`, 
       0.}, {-0.41194837686899155`, -0.9112071854386372, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017769936436893032`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21407388004025518`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.700078393377183`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3609229264811985, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9112071854386372, 0.41194837686899155`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8796782695141685`, -3.08245491405061, 0.}, 
      Optica`Optica`RayEnd :> {4.8505075852022514`, -3.1287419660385773`, 0.},
       RotationMatrix :> {{-0.533166420215159, -0.8460103831247893, 0.}, {
       0.8460103831247893, -0.533166420215159, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09156850539345801, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.054712155915868775`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.733216554466306`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011813668357485988`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.533166420215159, -0.8460103831247893, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8505075852022514`, -3.1287419660385773`, 
       0.}, Optica`Optica`RayEnd :> {4.676768144014921, -3.4053014779424857`, 
       0.}, RotationMatrix :> {{-0.5319565231228804, -0.8467716678698082, 
       0.}, {0.8467716678698082, -0.5319565231228804, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09134272639066464, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32660458822345667`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.21659134503702, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4197074364069751, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5319565231228804, -0.8467716678698082, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1309275385333617`, 0.13802487590127688`, 
       0.}, Optica`Optica`RayEnd :> {2.9088502337360813`, 
       0.20410577926362702`, 0.}, 
      RotationMatrix :> {{-0.9584680451368133, 0.2851999411844535, 
       0.}, {-0.2851999411844535, -0.9584680451368133, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010472798878679407`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23170026995065957`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.80953174933965, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37172339107988556`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9584680451368133, 0.2851999411844535, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9088502337360813`, 0.20410577926362702`, 
       0.}, Optica`Optica`RayEnd :> {2.568817617378096, 0.3024773324586582, 
       0.}, RotationMatrix :> {{-0.9606087260561901, 0.27790443577730783`, 
       0.}, {-0.27790443577730783`, -0.9606087260561901, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010446684103274234`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3539761894043998, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.333416509658164`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17343681739067493`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9606087260561901, 0.27790443577730783`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.891693862377186, 3.3137983546813343`, 0.}, 
      Optica`Optica`RayEnd :> {6.900480009785586, 3.357864598318122, 0.}, 
      RotationMatrix :> {{0.19553615734683383`, 0.9806964928916763, 
       0.}, {-0.9806964928916763, 0.19553615734683383`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0080922700056281, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04493362009162912, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.36026016038746, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3931903451350043, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19553615734683383`, 0.9806964928916763, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.900480009785586, 3.357864598318122, 0.}, 
      Optica`Optica`RayEnd :> {6.957214733053927, 3.6183783225821378`, 0.}, 
      RotationMatrix :> {{0.21279244352007798`, 0.9770974239965807, 
       0.}, {-0.9770974239965807, 0.21279244352007798`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008071051389010852, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2666200092908312, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.75485777413789, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22914223079130422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.21279244352007798`, 0.9770974239965807, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.182742657092213, -2.311972613455932, 0.}, 
      Optica`Optica`RayEnd :> {3.129136823338847, -2.408480019606195, 0.}, 
      RotationMatrix :> {{-0.4855779200362494, -0.8741933902594264, 0.}, {
       0.8741933902594264, -0.4855779200362494, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037864145283075586`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11039594582341014`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.137687535282005`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2733035216702759, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4855779200362494, -0.8741933902594264, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.129136823338847, -2.408480019606195, 0.}, 
      Optica`Optica`RayEnd :> {2.9681142684318607`, -2.6598401862157806`, 0.},
       RotationMatrix :> {{-0.5394149917009823, -0.8420400624247217, 0.}, {
       0.8420400624247217, -0.5394149917009823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03768178656136339, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29851331050184665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.57948723482474, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.266091685434798, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5394149917009823, -0.8420400624247217, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.875281126091442, -4.37143559027782, 0.}, 
      Optica`Optica`RayEnd :> {5.883357522681043, -4.39835420285686, 0.}, 
      RotationMatrix :> {{0.28737441905475214`, -0.9578183247740369, 0.}, {
       0.9578183247740369, 0.28737441905475214`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015574130924479852`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028104090183688618`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.707092814298182`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4027598226098324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.28737441905475214`, -0.9578183247740369, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.883357522681043, -4.39835420285686, 0.}, 
      Optica`Optica`RayEnd :> {5.988617948777935, -4.710701163914752, 0.}, 
      RotationMatrix :> {{0.31935188425828565`, -0.9476362034138847, 0.}, {
       0.9476362034138847, 0.31935188425828565`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015526499000413602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32960640373663924`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.194910291828407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2431071566866736, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.31935188425828565`, -0.9476362034138847, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.897226245942283, -2.319820684585405, 0.}, 
      Optica`Optica`RayEnd :> {7.91112926995619, -2.329652284028459, 0.}, 
      RotationMatrix :> {{0.8164778416445574, -0.5773767696257319, 0.}, {
       0.5773767696257319, 0.8164778416445574, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011530870194514922`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.017028048165891495`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.28110548487912, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41320691833686696`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8164778416445574, -0.5773767696257319, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.91112926995619, -2.329652284028459, 0.}, 
      Optica`Optica`RayEnd :> {8.12604817160651, -2.498956565176562, 0.}, 
      RotationMatrix :> {{0.7855374446359147, -0.6188141264344872, 0.}, {
       0.6188141264344872, 0.7855374446359147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011484988558032566`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27359472564663195`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.686025678836135`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3704534669430535, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7855374446359147, -0.6188141264344872, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.150433843677726, -3.3987902081105528`, 0.}, 
      Optica`Optica`RayEnd :> {7.147521702715067, -3.405654255286705, 0.}, 
      RotationMatrix :> {{-0.3905635937111233, -0.9205759497550715, 0.}, {
       0.9205759497550715, -0.3905635937111233, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12167549458642282`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0074562529881195124`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.11703611371116, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15369247795974417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3905635937111233, -0.9205759497550715, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.147521702715067, -3.405654255286705, 0.}, 
      Optica`Optica`RayEnd :> {7.018810165197388, -3.6757171600667142`, 0.}, 
      RotationMatrix :> {{-0.43023370064809774`, -0.9027175432141785, 0.}, {
       0.9027175432141785, -0.43023370064809774`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12124974700989788`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29916656301863176`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.559802626978733`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27278100877848455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.43023370064809774`, -0.9027175432141785, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.850770231733905, 3.0919020319561095`, 0.}, 
      Optica`Optica`RayEnd :> {7.84782261656146, 3.157509579376103, 0.}, 
      RotationMatrix :> {{-0.04488271346979933, 0.9989922632491144, 
       0.}, {-0.9989922632491144, -0.04488271346979933, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03628476891038316, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06567372925052722, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.850878170418266`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1596358907850144, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04488271346979933, 0.9989922632491144, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.84782261656146, 3.157509579376103, 0.}, 
      Optica`Optica`RayEnd :> {7.815550438724145, 3.3888616835434866`, 0.}, 
      RotationMatrix :> {{-0.13815609264931433`, 0.9904104674648154, 
       0.}, {-0.9904104674648154, -0.13815609264931433`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03596607957172944, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.233592143628674, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.196594542988702`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02387198622571368, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13815609264931433`, 0.9904104674648154, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.200021876269678, -0.9119070393901738, 0.}, 
      Optica`Optica`RayEnd :> {4.136410550081083, -0.9101697603019961, 0.}, 
      RotationMatrix :> {{-0.9996272673628381, 0.027300665645813932`, 
       0.}, {-0.027300665645813932`, -0.9996272673628381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013925524252307543`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06363504504675131, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.522281616043053`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19148581895349887`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9996272673628381, 0.027300665645813932`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.136410550081083, -0.9101697603019961, 0.}, 
      Optica`Optica`RayEnd :> {3.872301017939595, -0.9226557924440155, 0.}, 
      RotationMatrix :> {{-0.9988843614748387, -0.04722321887592411, 0.}, {
       0.04722321887592411, -0.9988843614748387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013841783394522045`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2644045120013029, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.91360029380498, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26546808413336664`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9988843614748387, -0.04722321887592411, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.838998481869474, -2.3971098311794203`, 0.}, 
      Optica`Optica`RayEnd :> {6.66306013011406, -2.6212220089192915`, 0.}, 
      RotationMatrix :> {{-0.6174964511576694, -0.7865736664850174, 0.}, {
       0.7865736664850174, -0.6174964511576694, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02586997819043141, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2849220451802905, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.920963445880087`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41838694045389846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6174964511576694, -0.7865736664850174, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.66306013011406, -2.6212220089192915`, 0.}, 
      Optica`Optica`RayEnd :> {6.575543885995159, -2.7837733642724407`, 0.}, 
      RotationMatrix :> {{-0.47405191455560786`, -0.880496895114436, 0.}, {
       0.880496895114436, -0.47405191455560786`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024862725998632637`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1846132067643726, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.194190991891357`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.057500844261770004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.47405191455560786`, -0.880496895114436, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.860468037503002, -2.5452454429729006`, 0.}, 
      Optica`Optica`RayEnd :> {6.964529303640744, -2.809863803943051, 0.}, 
      RotationMatrix :> {{0.36596936437717137`, -0.9306268985675025, 0.}, {
       0.9306268985675025, 0.36596936437717137`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21005105212109818`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28434419999838, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.141720471725915`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30358636799490524`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36596936437717137`, -0.9306268985675025, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.964529303640744, -2.809863803943051, 0.}, 
      Optica`Optica`RayEnd :> {7.072749319436245, -3.105403635144691, 0.}, 
      RotationMatrix :> {{0.34384965636123105`, -0.9390247141690482, 0.}, {
       0.9390247141690482, 0.34384965636123105`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20947303678310183`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3147306207623793, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.607521790454236`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02475459467436472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.34384965636123105`, -0.9390247141690482, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.999102128718822, -2.6016873604925377`, 0.}, 
      Optica`Optica`RayEnd :> {7.261874385091049, -2.6429865621305675`, 0.}, 
      RotationMatrix :> {{0.9878734246662967, -0.15526138231408942`, 0.}, {
       0.15526138231408942`, 0.9878734246662967, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020963832933877245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26599789994451156`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.338667768043315`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3288078804027443, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9878734246662967, -0.15526138231408942`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.261874385091049, -2.6429865621305675`, 0.}, 
      Optica`Optica`RayEnd :> {7.410905318833086, -2.699039979861575, 0.}, 
      RotationMatrix :> {{0.9359842801040459, -0.3520417977997926, 0.}, {
       0.3520417977997926, 0.9359842801040459, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0195717957129455, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15922375718262038`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.574318928673595`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19007353450983422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9359842801040459, -0.3520417977997926, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.185536517567847, -1.4233285737793353`, 0.}, 
      Optica`Optica`RayEnd :> {7.136704245799847, -1.693602331480489, 0.}, 
      RotationMatrix :> {{-0.17779833635601422`, -0.9840669446684167, 0.}, {
       0.9840669446684167, -0.17779833635601422`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02442742087152347, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2746497676458617, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.48806115823422, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3499366672850245, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.17779833635601422`, -0.9840669446684167, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.136704245799847, -1.693602331480489, 0.}, 
      Optica`Optica`RayEnd :> {7.1268187889837655`, -1.8870016953381006`, 0.},
       RotationMatrix :> {{-0.051047574224750536`, -0.9986962226652144, 0.}, {
       0.9986962226652144, -0.051047574224750536`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024005506395813808`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19365184274101657`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.774665885490926`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31169884021107686`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.051047574224750536`, -0.9986962226652144, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.589911053871509, 1.723989415994277, 0.}, 
      Optica`Optica`RayEnd :> {5.333991827929522, 2.0890188684700233`, 0.}, 
      RotationMatrix :> {{-0.5740622815766303, 0.818811636990482, 
       0.}, {-0.818811636990482, -0.5740622815766303, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008590964470150397, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.44580393827498743`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.279726706888642`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02682567051861831, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5740622815766303, 0.818811636990482, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.333991827929522, 2.0890188684700233`, 0.}, 
      Optica`Optica`RayEnd :> {5.14175033611594, 2.3651174583367935`, 0.}, 
      RotationMatrix :> {{-0.5714107762893368, 0.820664197306314, 
       0.}, {-0.820664197306314, -0.5714107762893368, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008569745768531502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33643308770263775`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.777647676688545`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40129500991499195`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5714107762893368, 0.820664197306314, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.940248911892806, -0.1320508901896091, 0.}, 
      Optica`Optica`RayEnd :> {5.863056968970465, -0.19280845491380338`, 0.}, 
      RotationMatrix :> {{-0.7857901248228142, -0.618493233375229, 0.}, {
       0.618493233375229, -0.7857901248228142, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1713232157301778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09823480912253361, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.013086418103786`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12301058580213159`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7857901248228142, -0.618493233375229, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.863056968970465, -0.19280845491380338`, 0.},
       Optica`Optica`RayEnd :> {5.653980257328887, -0.3616574428833441, 0.}, 
      RotationMatrix :> {{-0.7779787634610963, -0.6282905725884665, 0.}, {
       0.6282905725884665, -0.7779787634610963, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17088743869980935`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2687434689237931, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.410826752111, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26562848471722494`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7779787634610963, -0.6282905725884665, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.401924794015256, -0.6117164683421243, 0.}, 
      Optica`Optica`RayEnd :> {7.478801711368002, -0.8356664099524582, 0.}, 
      RotationMatrix :> {{0.3246798429761937, -0.9458239791657609, 0.}, {
       0.9458239791657609, 0.3246798429761937, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010370618390002365`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2367776103624091, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.520153908693505`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4042992703009932, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3246798429761937, -0.9458239791657609, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.478801711368002, -0.8356664099524582, 0.}, 
      Optica`Optica`RayEnd :> {7.583398214968567, -1.132330017951795, 0.}, 
      RotationMatrix :> {{0.33251395142016654`, -0.9430983363949629, 0.}, {
       0.9430983363949629, 0.33251395142016654`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010344701171262202`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3145627518900595, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.985706781490794`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.130390117151073, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33251395142016654`, -0.9430983363949629, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.359469019374845, 3.1712319685556047`, 0.}, 
      Optica`Optica`RayEnd :> {7.505099127366551, 3.3287697191965226`, 0.}, 
      RotationMatrix :> {{0.6788100684338169, 0.7343138913250081, 
       0.}, {-0.7343138913250081, 0.6788100684338169, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00892953541237966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21453734227559557`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.94453272634252, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2895737411407822, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6788100684338169, 0.7343138913250081, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.505099127366551, 3.3287697191965226`, 0.}, 
      Optica`Optica`RayEnd :> {7.666072835015382, 3.5295693043040495`, 0.}, 
      RotationMatrix :> {{0.6254861645496833, 0.780235258083692, 
       0.}, {-0.780235258083692, 0.6254861645496833, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008879945190229206, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25735774310007925`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.325422186130638`, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33485804115902573`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6254861645496833, 0.780235258083692, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.367555068531391, 3.3293246155986482`, 0.}, 
      Optica`Optica`RayEnd :> {7.31726555061554, 3.552830485456761, 0.}, 
      RotationMatrix :> {{-0.21951509176531597`, 0.9756091043482856, 
       0.}, {-0.9756091043482856, -0.21951509176531597`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03430451607983149, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22909366964898956`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.198321173040988`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18794353512308382`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.21951509176531597`, 0.9756091043482856, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.31726555061554, 3.552830485456761, 0.}, 
      Optica`Optica`RayEnd :> {7.249413289851313, 3.865881414191816, 0.}, 
      RotationMatrix :> {{-0.21182658040094715`, 0.9773072699185452, 
       0.}, {-0.9773072699185452, -0.21182658040094715`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03421890285377395, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3203198608776811, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.672394567139957`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3629152639312949, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.21182658040094715`, 0.9773072699185452, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.351578364845772, 3.0615498507624155`, 0.}, 
      Optica`Optica`RayEnd :> {6.332726271625041, 3.072085061703826, 0.}, 
      RotationMatrix :> {{-0.8729391899827773, 0.48782903828309687`, 
       0.}, {-0.48782903828309687`, -0.8729391899827773, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2447679079071583`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.021596112807242662`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.106237125034447`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09124073817999669, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8729391899827773, 0.48782903828309687`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.332726271625041, 3.072085061703826, 0.}, 
      Optica`Optica`RayEnd :> {6.111084384355568, 3.220486449041145, 0.}, 
      RotationMatrix :> {{-0.8309410077156206, 0.5563605321161336, 
       0.}, {-0.5563605321161336, -0.8309410077156206, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.236378070327634, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26673600798545144`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.501006416852913`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.025343360264649943`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8309410077156206, 0.5563605321161336, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.111084384355568, 3.220486449041145, 0.}, 
      Optica`Optica`RayEnd :> {6.316562790117922, 3.3905650271201493`, 0.}, 
      RotationMatrix :> {{0.7703437091761597, 0.6376288651972357, 
       0.}, {-0.6376288651972357, 0.7703437091761597, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00833328938755617, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2667360079854512, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.89577570867138, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14054351298540005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7703437091761597, 0.6376288651972357, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.149841575224362, 2.298041295074627, 0.}, 
      Optica`Optica`RayEnd :> {5.823748620050392, 2.202715441043321, 0.}, 
      RotationMatrix :> {{-0.9598293924660981, -0.28058427852992773`, 0.}, {
       0.28058427852992773`, -0.9598293924660981, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03725361151875023, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3397405390307294, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.72843804239409, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42473235913566754`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9598293924660981, -0.28058427852992773`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.823748620050392, 2.202715441043321, 0.}, 
      Optica`Optica`RayEnd :> {5.604405943891403, 2.1458756573122315`, 0.}, 
      RotationMatrix :> {{-0.9680256633999604, -0.2508511809800098, 0.}, {
       0.2508511809800098, -0.9680256633999604, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0371432684417718, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22658766647631987`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.06378778877904, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25678766822153254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9680256633999604, -0.2508511809800098, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.556008619207015, 2.7669057467627027`, 0.}, 
      Optica`Optica`RayEnd :> {6.455720919383612, 2.812084139995091, 0.}, 
      RotationMatrix :> {{-0.911754966989617, 0.4107345616937556, 
       0.}, {-0.4107345616937556, -0.911754966989617, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2411870689008152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10999413598428458`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.798757718817395`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33356965181665604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.911754966989617, 0.4107345616937556, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.455720919383612, 2.812084139995091, 0.}, 
      Optica`Optica`RayEnd :> {6.337832227099149, 2.9099046679207174`, 0.}, 
      RotationMatrix :> {{-0.7695681227408792, 0.638564722217786, 
       0.}, {-0.638564722217786, -0.7695681227408792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2002580428142613, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15318811785575603`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.025476133243913`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1911554755099804, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7695681227408792, 0.638564722217786, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.337832227099149, 2.9099046679207174`, 0.}, 
      Optica`Optica`RayEnd :> {6.352145538186897, 3.0624226294134362`, 0.}, 
      RotationMatrix :> {{0.09343617042952096, 0.9956252719047787, 
       0.}, {-0.9956252719047787, 0.09343617042952096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033983441549087716`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15318811785575626`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.25219454767043, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27377824652983335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.09343617042952096, 0.9956252719047787, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.241317660936481, 0.0593787069427702, 0.}, 
      Optica`Optica`RayEnd :> {8.24463024279155, -0.06646771856770184, 0.}, 
      RotationMatrix :> {{0.026313300867390893`, -0.9996537451525206, 0.}, {
       0.9996537451525206, 0.026313300867390893`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2558717053918702, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12589001553860144`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.235670649660797`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30418534800349234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.026313300867390893`, -0.9996537451525206, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.24463024279155, -0.06646771856770184, 0.}, 
      Optica`Optica`RayEnd :> {8.256952250972121, -0.40676657913585323`, 0.}, 
      RotationMatrix :> {{0.03618565835686322, -0.9993450846075538, 0.}, {
       0.9993450846075538, 0.03618565835686322, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2552285554710081, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3405218735846263, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.739643022566042`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2746886981156694, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03618565835686322, -0.9993450846075538, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.534634195919815, -0.19247479425545638`, 0.},
       Optica`Optica`RayEnd :> {7.38369793090081, -0.3427039428852845, 0.}, 
      RotationMatrix :> {{-0.7087650673113328, -0.7054445969451899, 0.}, {
       0.7054445969451899, -0.7087650673113328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07325627753703859, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2129566932405044, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.92032706670723, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30627914619674623`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7087650673113328, -0.7054445969451899, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.38369793090081, -0.3427039428852845, 0.}, 
      Optica`Optica`RayEnd :> {7.245025077907684, -0.43724862593718694`, 0.}, 
      RotationMatrix :> {{-0.826241179343275, -0.5633165305203048, 0.}, {
       0.5633165305203048, -0.826241179343275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06969638555442212, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16783580443587667`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.16872405727233, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24395859027890443`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.826241179343275, -0.5633165305203048, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.918235140502793, -0.6120523874165424, 0.}, 
      Optica`Optica`RayEnd :> {6.8745919970061, -0.7022677679808029, 0.}, 
      RotationMatrix :> {{-0.435484439721424, -0.9001962579129712, 0.}, {
       0.9001962579129712, -0.435484439721424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023768501368344793`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10021745788348106`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.928710378268654`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16054907491963774`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.435484439721424, -0.9001962579129712, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8745919970061, -0.7022677679808029, 0.}, 
      Optica`Optica`RayEnd :> {6.746337843806928, -0.9425816125023615, 0.}, 
      RotationMatrix :> {{-0.4708362157263496, -0.882220640180499, 0.}, {
       0.882220640180499, -0.4708362157263496, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02368978988878191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2723965339015319, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.331857248442923`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30401941488603873`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4708362157263496, -0.882220640180499, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.603390235694879, -1.6110348748944543`, 0.}, 
      Optica`Optica`RayEnd :> {7.564839912479123, -1.8428960138801187`, 0.}, 
      RotationMatrix :> {{-0.1640131703547319, -0.986458149112363, 0.}, {
       0.986458149112363, -0.1640131703547319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18613693812303794`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2350440707436987, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.294395305177446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.043078291303067534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1640131703547319, -0.986458149112363, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.564839912479123, -1.8428960138801187`, 0.}, 
      Optica`Optica`RayEnd :> {7.508878933533153, -2.1061952972400784`, 0.}, 
      RotationMatrix :> {{-0.20789387825478625`, -0.9781513867414304, 0.}, {
       0.9781513867414304, -0.20789387825478625`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18547431890347077`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2691805040905813, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.692782451231505`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16324092864823342`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20789387825478625`, -0.9781513867414304, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.701971665894905, 1.8586035155755987`, 0.}, 
      Optica`Optica`RayEnd :> {4.681822241294973, 1.9014125722190873`, 0.}, 
      RotationMatrix :> {{-0.4258660098712992, 0.9047862408526653, 
       0.}, {-0.9047862408526653, -0.4258660098712992, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009781655595059446, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04731400049048671, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.23928773430423, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27626946698470084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4258660098712992, 0.9047862408526653, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.681822241294973, 1.9014125722190873`, 0.}, 
      Optica`Optica`RayEnd :> {4.550720203660656, 2.1343176423314136`, 0.}, 
      RotationMatrix :> {{-0.490525363487636, 0.8714269147641249, 
       0.}, {-0.8714269147641249, -0.490525363487636, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009724803632390321, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26726862134544965`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.634845293895495`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2129596554288672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.490525363487636, 0.8714269147641249, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.257659461780888, 0.9100120270629408, 0.}, 
      Optica`Optica`RayEnd :> {4.1537787624621005`, 0.9380983931909275, 0.}, 
      RotationMatrix :> {{-0.9653388091912309, 0.26099996833190514`, 
       0.}, {-0.26099996833190514`, -0.9653388091912309, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032218497982814835`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1076106112483129, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.39255588658994, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16395820549626977`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9653388091912309, 0.26099996833190514`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1537787624621005`, 0.9380983931909275, 0.}, 
      Optica`Optica`RayEnd :> {3.876393431753907, 1.0266974747121043`, 0.}, 
      RotationMatrix :> {{-0.9525877177234453, 0.3042640958812541, 
       0.}, {-0.3042640958812541, -0.9525877177234453, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03210303400659668, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29119137854423194`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.823519126835404`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.047313483761430394`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9525877177234453, 0.3042640958812541, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.117167632438771, 0.8261175470069844, 0.}, 
      Optica`Optica`RayEnd :> {3.998399544867169, 0.7106453352719848, 0.}, 
      RotationMatrix :> {{-0.7169851498443802, -0.697088441234418, 0.}, {
       0.697088441234418, -0.7169851498443802, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2512827826224551, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16564929914849685`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.712506735490468`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24711467970045575`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7169851498443802, -0.697088441234418, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.998399544867169, 0.7106453352719848, 0.}, 
      Optica`Optica`RayEnd :> {3.834142400424299, 0.5186169949293943, 0.}, 
      RotationMatrix :> {{-0.6500186501956464, -0.7599182550760503, 0.}, {
       0.7599182550760503, -0.6500186501956464, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2491558155402798, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25269604863403744`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.086496887468844`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08075917503435626, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6500186501956464, -0.7599182550760503, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.117643865374875, 0.662483775743396, 0.}, 
      Optica`Optica`RayEnd :> {4.118875553318521, 0.6573601836489971, 0.}, 
      RotationMatrix :> {{0.2337364405484218, -0.972299992985577, 0.}, {
       0.972299992985577, 0.2337364405484218, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0259155955094754, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.005269558913259179, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.73977689068953, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14899948387274115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2337364405484218, -0.972299992985577, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.118875553318521, 0.6573601836489971, 0.}, 
      Optica`Optica`RayEnd :> {4.13623424416586, 0.45570602404111304`, 0.}, 
      RotationMatrix :> {{0.08576432028060216, -0.996315452739144, 0.}, {
       0.996315452739144, 0.08576432028060216, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025230996322651453`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2023999116479438, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.039328759928488`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22837362206079803`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08576432028060216, -0.996315452739144, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.751781410101081, 0.14079931650843222`, 0.}, 
      Optica`Optica`RayEnd :> {4.6926775436207055`, -0.07678088209334444, 0.},
       RotationMatrix :> {{-0.26214223604311854`, -0.9650292472678292, 0.}, {
       0.9650292472678292, -0.26214223604311854`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009260107395248438, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2254648749950171, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.034266182735543`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3256921365628906, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.26214223604311854`, -0.9650292472678292, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.6926775436207055`, -0.07678088209334447, 
       0.}, Optica`Optica`RayEnd :> {4.627965300614364, -0.36629352393380893`,
        0.}, RotationMatrix :> {{-0.21813842701252312`, -0.9759178380686057, 
       0.}, {0.9759178380686057, -0.21813842701252312`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009226806826398662, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2966567784163322, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.473318214791714`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.405299586865242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.21813842701252312`, -0.9759178380686057, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.109795497765404, 1.1420644005632679`, 0.}, 
      Optica`Optica`RayEnd :> {2.967594342453163, 1.3333641745595262`, 0.}, 
      RotationMatrix :> {{-0.5965747204949516, 0.8025575386639697, 
       0.}, {-0.8025575386639697, -0.5965747204949516, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012824582894858435`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23836269024987042`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.34630723951847, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2989930459730202, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5965747204949516, 0.8025575386639697, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.967594342453163, 1.3333641745595262`, 0.}, 
      Optica`Optica`RayEnd :> {2.825680949044306, 1.5631240269047626`, 0.}, 
      RotationMatrix :> {{-0.5255006441925789, 0.850793202225537, 
       0.}, {-0.850793202225537, -0.5255006441925789, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012728163364922, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2700537001755795, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.74598671577833, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16994602375061915`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5255006441925789, 0.850793202225537, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9148613770099985`, 1.1285672376053026`, 0.},
       Optica`Optica`RayEnd :> {2.906428365600408, 1.1264118496109896`, 0.}, 
      RotationMatrix :> {{-0.968854928538453, -0.24762901172267418`, 0.}, {
       0.24762901172267418`, -0.968854928538453, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.255102435418361, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.008704101265513275, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.32775796048931, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22563811909003537`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.968854928538453, -0.24762901172267418`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.906428365600408, 1.1264118496109896`, 0.}, 
      Optica`Optica`RayEnd :> {2.648326616778112, 1.086860197629454, 0.}, 
      RotationMatrix :> {{-0.9884614912065425, -0.1514723750448822, 0.}, {
       0.1514723750448822, -0.9884614912065425, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2526513120101845, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2611146221864952, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.714207601325324`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38636085648179286`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9884614912065425, -0.1514723750448822, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.853419889646802, 0.9430775385026428, 0.}, 
      Optica`Optica`RayEnd :> {2.841861157799778, 0.8603137646950654, 0.}, 
      RotationMatrix :> {{-0.13831691127762624`, -0.9903880209567442, 0.}, {
       0.9903880209567442, -0.13831691127762624`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011677359921056776`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08356701823556499, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.717267499439057`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.003003581729338316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13831691127762624`, -0.9903880209567442, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.841861157799778, 0.8603137646950654, 0.}, 
      Optica`Optica`RayEnd :> {2.78724020649285, 0.5557238620463394, 0.}, 
      RotationMatrix :> {{-0.1765105587688012, -0.9842987466430732, 0.}, {
       0.9842987466430732, -0.1765105587688012, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011639207662630451`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30944863405294604`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.175251477837417`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17091956428039032`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1765105587688012, -0.9842987466430732, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3474023378701885`, 0.90487389886163, 0.}, 
      Optica`Optica`RayEnd :> {2.2410664177084985`, 1.0564604651676346`, 0.}, 
      RotationMatrix :> {{-0.5742787610984205, 0.8186598222407536, 
       0.}, {-0.8186598222407536, -0.5742787610984205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00874571024161575, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18516429191687586`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.556188881786316`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2644373866596266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5742787610984205, 0.8186598222407536, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2410664177084985`, 1.0564604651676346`, 0.},
       Optica`Optica`RayEnd :> {2.0974595866669437`, 1.2948117347041475`, 0.},
       RotationMatrix :> {{-0.5160699265246083, 0.8565464557961141, 
       0.}, {-0.8565464557961141, -0.5160699265246083, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008697978940488392, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27827010190005147`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.968028632598394`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21865635136722344`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5160699265246083, 0.8565464557961141, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1829116023236583`, 0.7363522884607112, 0.}, 
      Optica`Optica`RayEnd :> {2.190827813661015, 0.3974883048398931, 0.}, 
      RotationMatrix :> {{0.023354657078453828`, -0.999727242798128, 0.}, {
       0.999727242798128, 0.023354657078453828`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008216267132293393, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3389564364299751, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.196246704825874`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2912072712764672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.023354657078453828`, -0.999727242798128, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.190827813661015, 0.39748830483989306`, 0.}, 
      Optica`Optica`RayEnd :> {2.198137492260498, 0.1574141637177774, 0.}, 
      RotationMatrix :> {{0.030433484755909183`, -0.9995367942230097, 0.}, {
       0.9995367942230097, 0.030433484755909183`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008195810767901284, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24018539638527, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.551721091476075`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.265940165626275, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.030433484755909183`, -0.9995367942230097, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.152935114196686, -3.3998557454180136`, 0.}, 
      Optica`Optica`RayEnd :> {7.343013019922998, -3.681121789661831, 0.}, 
      RotationMatrix :> {{0.5599247188369961, -0.828543486628982, 0.}, {
       0.828543486628982, 0.5599247188369961, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008638451922939694, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33947046688904475`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.251311228113263`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07478803530895871, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5599247188369961, -0.828543486628982, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.343013019922998, -3.681121789661831, 0.}, 
      Optica`Optica`RayEnd :> {7.415501185784918, -3.8244870407543035`, 0.}, 
      RotationMatrix :> {{0.45122052577328914`, -0.8924124814909727, 0.}, {
       0.8924124814909727, 0.45122052577328914`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008493593975680641, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1606490877995666, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.48907187805662, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3538104732977979, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.45122052577328914`, -0.8924124814909727, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.350901074353575, 3.083822610252523, 0.}, 
      Optica`Optica`RayEnd :> {3.199044104206012, 3.069664227035078, 0.}, 
      RotationMatrix :> {{-0.9956817510751641, -0.09283237891971846, 0.}, {
       0.09283237891971846, -0.9956817510751641, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2912461008387395, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.152515570345227, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.53983282502008, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38057929088244635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9956817510751641, -0.09283237891971846, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.199044104206012, 3.069664227035078, 0.}, 
      Optica`Optica`RayEnd :> {2.8860657647081065`, 3.0378135942946987`, 0.}, 
      RotationMatrix :> {{-0.9948616913238995, -0.10124334613271857`, 0.}, {
       0.10124334613271857`, -0.9948616913238995, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29051786504563903`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31459482481571255`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.005433165747334`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01036640260581839, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9948616913238995, -0.10124334613271857`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3885589709624035`, 3.5767400067352, 0.}, 
      Optica`Optica`RayEnd :> {3.3350883661874784`, 3.6729827736237035`, 0.}, 
      RotationMatrix :> {{-0.48565959507213724`, 0.8741480181950692, 
       0.}, {-0.8741480181950692, -0.48565959507213724`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.294857956380511, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11009893620444781`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.788043357022627`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19772709418363274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.48565959507213724`, 0.8741480181950692, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3350883661874784`, 3.6729827736237035`, 0.},
       Optica`Optica`RayEnd :> {3.1854391618308204`, 3.917440606065164, 0.}, 
      RotationMatrix :> {{-0.5221060081607413, 0.8528805990538507, 
       0.}, {-0.8528805990538507, -0.5221060081607413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2904129674601188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2866260912871644, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.21224997212763, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3190678655317089, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5221060081607413, 0.8528805990538507, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.651399080236819, 3.37910346651708, 0.}, 
      Optica`Optica`RayEnd :> {3.847707350386743, 3.5520993251997077`, 0.}, 
      RotationMatrix :> {{0.7502497559912606, 0.6611545232659707, 
       0.}, {-0.6611545232659707, 0.7502497559912606, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03241726635515453, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2616572262533472, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.619345878240782`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.026143390714226444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.7502497559912606, 0.6611545232659707, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.847707350386743, 3.5520993251997077`, 0.}, 
      Optica`Optica`RayEnd :> {4.03176716932845, 3.687293224962993, 0.}, 
      RotationMatrix :> {{0.8059522630023497, 0.5919805315729485, 
       0.}, {-0.5919805315729485, 0.8059522630023497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03215893897230612, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22837558425116095`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.9573417429325, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1343971790024413, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8059522630023497, 0.5919805315729485, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6715545154570086`, 3.532753025731774, 0.}, 
      Optica`Optica`RayEnd :> {3.6447050878359932`, 3.7340071536615724`, 0.}, 
      RotationMatrix :> {{-0.13223893935422507`, 0.9912178685427684, 
       0.}, {-0.9912178685427684, -0.13223893935422507`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14772397412384664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2030372275528793, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.77014460459473, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1592331182164257, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13223893935422507`, 0.9912178685427684, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6447050878359932`, 3.7340071536615724`, 0.},
       Optica`Optica`RayEnd :> {3.666413661944249, 3.8758765752816933`, 0.}, 
      RotationMatrix :> {{0.15125742965120914`, 0.9884944056368296, 
       0.}, {-0.9884944056368296, 0.15125742965120914`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11735526001872232`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14352071272342987`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.982555259425407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2936793847791384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15125742965120914`, 0.9884944056368296, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.666413661944249, 3.8758765752816933`, 0.}, 
      Optica`Optica`RayEnd :> {3.7945631340613906`, 3.9404978394038013`, 0.}, 
      RotationMatrix :> {{0.8928987996603012, 0.45025740811805953`, 
       0.}, {-0.45025740811805953`, 0.8928987996603012, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024125592080625955`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14352071272343012`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.194965914256084`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24613735795334646`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8928987996603012, 0.45025740811805953`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5550668598930115`, 3.63495407620088, 0.}, 
      Optica`Optica`RayEnd :> {3.3616401828882223`, 3.7300898723231537`, 0.}, 
      RotationMatrix :> {{-0.8973354110899051, 0.4413492494658966, 
       0.}, {-0.4413492494658966, -0.8973354110899051, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023079270704020948`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21555671894175318`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.0162702476684, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3646859538281703, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8973354110899051, 0.4413492494658966, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3616401828882223`, 3.7300898723231537`, 0.},
       Optica`Optica`RayEnd :> {3.0875717529220807`, 3.857537429702332, 0.}, 
      RotationMatrix :> {{-0.9067541685199693, 0.4216596706725204, 
       0.}, {-0.4216596706725204, -0.9067541685199693, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023016772023067712`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30225218640404367`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.463603483546382`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2989006728103102, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9067541685199693, 0.4216596706725204, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.139812661650813, 3.5158217226159985`, 0.}, 
      Optica`Optica`RayEnd :> {4.409143393975804, 3.598808626479347, 0.}, 
      RotationMatrix :> {{0.9556633319278517, 0.29446153570297706`, 
       0.}, {-0.29446153570297706`, 0.9556633319278517, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0327753249494446, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2818259561991061, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.379290113141682`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20872275062350026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9556633319278517, 0.29446153570297706`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.409143393975804, 3.598808626479347, 0.}, 
      Optica`Optica`RayEnd :> {4.642666223636448, 3.6503448995112304`, 0.}, 
      RotationMatrix :> {{0.9765027599997455, 0.21550489486988128`, 
       0.}, {-0.21550489486988128`, 0.9765027599997455, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032548757325003466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23914200678829084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.733220283188352`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09057098904417094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9765027599997455, 0.21550489486988128`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.264634592188302, 3.5569056035555873`, 0.}, 
      Optica`Optica`RayEnd :> {6.323640786141722, 3.551542038427968, 0.}, 
      RotationMatrix :> {{0.9958941717030609, -0.09052512782577593, 0.}, {
       0.09052512782577593, 0.9958941717030609, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02197442155485222, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05924946207137043, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.515722932252434`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11264547509694858`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9958941717030609, -0.09052512782577593, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.323640786141722, 3.551542038427968, 0.}, 
      Optica`Optica`RayEnd :> {6.622413844330305, 3.520465895530815, 0.}, 
      RotationMatrix :> {{0.9946341952370779, -0.1034544231296538, 0.}, {
       0.1034544231296538, 0.9946341952370779, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02191839661334862, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30038486472644227`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.960292532047568`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42793627963736136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9946341952370779, -0.1034544231296538, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.29350856581124, 2.0561842066253853`, 0.}, 
      Optica`Optica`RayEnd :> {6.360070698942792, 1.9664371853324578`, 0.}, 
      RotationMatrix :> {{0.5957062662864553, -0.803202368215539, 0.}, {
       0.803202368215539, 0.5957062662864553, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011922980361622036`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11173649984662878`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.313870160612158`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07514299483739728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5957062662864553, -0.803202368215539, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.360070698942792, 1.9664371853324578`, 0.}, 
      Optica`Optica`RayEnd :> {6.498313174423297, 1.8306402663680825`, 0.}, 
      RotationMatrix :> {{0.7133886703771295, -0.7007685816141807, 0.}, {
       0.7007685816141807, 0.7133886703771295, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011570571696116201`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19378283006292119`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.60066874910528, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3052170676734803, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7133886703771295, -0.7007685816141807, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.635004169707646, 2.8971105400953423`, 0.}, 
      Optica`Optica`RayEnd :> {6.903575285557843, 3.006320190988968, 0.}, 
      RotationMatrix :> {{0.926343085771204, 0.3766808827693319, 
       0.}, {-0.3766808827693319, 0.926343085771204, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.15871617534773266`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28992618391122904`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.012063457620023`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14062537091908253`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.926343085771204, 0.3766808827693319, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.903575285557843, 3.006320190988968, 0.}, 
      Optica`Optica`RayEnd :> {7.119367256792085, 3.0761878458813996`, 0.}, 
      RotationMatrix :> {{0.9513765706480471, 0.3080302271238338, 
       0.}, {-0.3080302271238338, 0.9513765706480471, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.15778811140663979`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2268207751713401, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.347758204873607`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0677195114466511, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9513765706480471, 0.3080302271238338, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.1972652318558445`, 1.114415438426117, 0.}, 
      Optica`Optica`RayEnd :> {6.294695493609805, 1.0352192052585532`, 0.}, 
      RotationMatrix :> {{0.7759808868482246, -0.6307564214863308, 0.}, {
       0.6307564214863308, 0.7759808868482246, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0947951769089147, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1255575535496627, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.2478019366673, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.015125621308418852`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7759808868482246, -0.6307564214863308, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.294695493609805, 1.0352192052585532`, 0.}, 
      Optica`Optica`RayEnd :> {6.529350429469603, 0.870475889649174, 0.}, 
      RotationMatrix :> {{0.8184366525022222, -0.5745967680390797, 0.}, {
       0.5745967680390797, 0.8184366525022222, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09426843411389882, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28671117690340825`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.672134478484345`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0731214897963346, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8184366525022222, -0.5745967680390797, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.14685598326838, 1.4104281174482072`, 0.}, 
      Optica`Optica`RayEnd :> {5.146718110808978, 1.3834846388450577`, 0.}, 
      RotationMatrix :> {{-0.005117032451289333, -0.9999869079037441, 0.}, {
       0.9999869079037441, -0.005117032451289333, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.048330454070413295`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02694383135438313, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.30983363553601, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42609544000434585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.005117032451289333, -0.9999869079037441, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.146718110808978, 1.3834846388450577`, 0.}, 
      Optica`Optica`RayEnd :> {5.162084544223142, 1.0917722028025019`, 0.}, 
      RotationMatrix :> {{0.05260371574833612, -0.9986154660776424, 0.}, {
       0.9986154660776424, 0.05260371574833612, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.048117425433559805`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2921168817746659, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.742166620562514`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4121545521403653, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.05260371574833612, -0.9986154660776424, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9166370419365357`, 1.3835162247723365`, 0.},
       Optica`Optica`RayEnd :> {3.915972049864252, 1.3823742354471145`, 0.}, 
      RotationMatrix :> {{-0.5032112211373739, -0.8641634491931673, 0.}, {
       0.8641634491931673, -0.5032112211373739, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03441385580338529, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001321496906966141, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.16863481657978, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1930735144003248, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5032112211373739, -0.8641634491931673, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9159720498642523`, 1.3823742354471145`, 0.},
       Optica`Optica`RayEnd :> {3.7662921383577954`, 1.1468848888748389`, 0.},
       RotationMatrix :> {{-0.5364240580681338, -0.8439485943620704, 0.}, {
       0.8439485943620704, -0.5364240580681338, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034301104467841105`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27903280856848733`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.58160337326114, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33564114993202293`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5364240580681338, -0.8439485943620704, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1006670786341908`, 3.289236112860523, 0.}, 
      Optica`Optica`RayEnd :> {2.692734014232927, 3.4208220106492813`, 0.}, 
      RotationMatrix :> {{-0.951712307687501, 0.3069913409139257, 
       0.}, {-0.3069913409139257, -0.951712307687501, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022928524710185104`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.42863064931089473`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.546586996850596`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34771290537948846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.951712307687501, 0.3069913409139257, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.692734014232927, 3.4208220106492813`, 0.}, 
      Optica`Optica`RayEnd :> {2.3617301027851787`, 3.5264239061816407`, 0.}, 
      RotationMatrix :> {{-0.9526905938827075, 0.3039418239193364, 
       0.}, {-0.3039418239193364, -0.9526905938827075, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022871896228055025`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3474411457120989, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.0607998925045, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16649357689875735`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9526905938827075, 0.3039418239193364, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.602454551891017, 0.12321755953209025`, 0.}, 
      Optica`Optica`RayEnd :> {2.5955754033611145`, 0.12146873893754633`, 0.},
       RotationMatrix :> {{-0.9691724158954226, -0.2463834983667313, 0.}, {
       0.2463834983667313, -0.9691724158954226, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08095480377927528, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.00709796153612876, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.404782148311153`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08080161186286922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9691724158954226, -0.2463834983667313, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5955754033611145`, 0.1214687389375463, 0.}, 
      Optica`Optica`RayEnd :> {2.319178571095467, 0.03075668096407757, 0.}, 
      RotationMatrix :> {{-0.9501377603525242, -0.31183046091151606`, 0.}, {
       0.31183046091151606`, -0.9501377603525242, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08052361116729567, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2909018500255139, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.835316886348913`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12401425519295403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9501377603525242, -0.31183046091151606`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.237518902676637, 1.909981509090571, 0.}, 
      Optica`Optica`RayEnd :> {4.19964115086494, 1.929701256250354, 0.}, 
      RotationMatrix :> {{-0.8869932076680759, 0.4617824699473733, 
       0.}, {-0.4617824699473733, -0.8869932076680759, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03633736017183194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04270354212889497, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.723978934818444`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3492579221667085, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8869932076680759, 0.4617824699473733, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.19964115086494, 1.929701256250354, 0.}, 
      Optica`Optica`RayEnd :> {3.915873650154078, 2.085425531623274, 0.}, 
      RotationMatrix :> {{-0.8766693052251213, 0.481093472493758, 
       0.}, {-0.481093472493758, -0.8766693052251213, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03623889957405221, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3236881900843929, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.15772110953153, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33340761833788857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8766693052251213, 0.481093472493758, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2213753721831653`, 1.1509229207014182`, 0.},
       Optica`Optica`RayEnd :> {3.1376643673154043`, 1.1221886645158219`, 0.},
       RotationMatrix :> {{-0.9458303158864312, -0.32466138290559504`, 0.}, {
       0.32466138290559504`, -0.9458303158864312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08759831414309759, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08850530952722423, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.968233278716166`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09623251129964805, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9458303158864312, -0.32466138290559504`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1376643673154043`, 1.1221886645158219`, 0.},
       Optica`Optica`RayEnd :> {2.8556411871541107`, 1.0443451746924912`, 0.},
       RotationMatrix :> {{-0.9639540617396426, -0.26606872581279606`, 0.}, {
       0.26606872581279606`, -0.9639540617396426, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08718679004135797, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29256910817132514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.360275883665743`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15486029013140679`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9639540617396426, -0.26606872581279606`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.226784094955743, 0.11802907473082361`, 0.}, 
      Optica`Optica`RayEnd :> {4.177832688135187, 0.08579016512972962, 0.}, 
      RotationMatrix :> {{-0.8351503533567652, -0.5500217152877418, 0.}, {
       0.5500217152877418, -0.8351503533567652, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020486816518151044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05861388506129856, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.083020608558996`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3092666653308184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8351503533567652, -0.5500217152877418, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.177832688135187, 0.08579016512972962, 0.}, 
      Optica`Optica`RayEnd :> {3.9173878228281183`, -0.09386285124665285, 0.},
       RotationMatrix :> {{-0.8231598000828025, -0.5678097775907351, 0.}, {
       0.5678097775907351, -0.8231598000828025, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020431511625259153`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31639648253093733`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.506991895150453`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.368074419126379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8231598000828025, -0.5678097775907351, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.017758252410186, -2.666329052544557, 0.}, 
      Optica`Optica`RayEnd :> {6.006534413084269, -2.8195029085434435`, 0.}, 
      RotationMatrix :> {{-0.07307923571001632, -0.9973261378847138, 0.}, {
       0.9973261378847138, -0.07307923571001632, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008146553316795431, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15358451982794913`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.745224421940527`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24237858997247122`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.07307923571001632, -0.9973261378847138, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.006534413084269, -2.8195029085434435`, 0.}, 
      Optica`Optica`RayEnd :> {5.982587617186125, -3.1717560561794467`, 0.}, 
      RotationMatrix :> {{-0.06782523249632422, -0.9976972175148224, 0.}, {
       0.9976972175148224, -0.06782523249632422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00812636191240054, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35306618225661207`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.267762371680313`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2993352276995865, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06782523249632422, -0.9976972175148224, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3678358241441186`, 1.6157500856389455`, 0.},
       Optica`Optica`RayEnd :> {2.1502410153074516`, 1.6477252730810639`, 0.},
       RotationMatrix :> {{-0.9893748698070719, 0.14538695606635105`, 
       0.}, {-0.14538695606635105`, -0.9893748698070719, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1480478745750526, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21993161083533302`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.758624550263967`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19687834988375277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9893748698070719, 0.14538695606635105`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1502410153074516`, 1.6477252730810639`, 0.},
       Optica`Optica`RayEnd :> {1.866738553866757, 1.6632737373389903`, 0.}, 
      RotationMatrix :> {{-0.9984994414256234, 0.054761898001416245`, 
       0.}, {-0.054761898001416245`, -0.9984994414256234, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.146813265913905, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2839285128050942, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.178838749215508`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3415727601915217, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9984994414256234, 0.054761898001416245`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5207053132081034`, -2.6411097727657418`, 
       0.}, Optica`Optica`RayEnd :> {2.42761242653415, -2.722429377510061, 
       0.}, RotationMatrix :> {{-0.7531243785336321, -0.6578781577604849, 
       0.}, {0.6578781577604849, -0.7531243785336321, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15599465082627487`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12360891418122621`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.03073509953081, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4053938557699811, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7531243785336321, -0.6578781577604849, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.42761242653415, -2.722429377510061, 0.}, 
      Optica`Optica`RayEnd :> {2.2264786672156953`, -2.866480413713278, 0.}, 
      RotationMatrix :> {{-0.8129985681898351, -0.5822656851655241, 0.}, {
       0.5822656851655241, -0.8129985681898351, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1545458112842911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2473974336342129, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.396883301309444`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.340698142050024, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8129985681898351, -0.5822656851655241, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0835451215110132`, 3.193820375821446, 0.}, 
      Optica`Optica`RayEnd :> {2.980971346924826, 3.384369921390081, 0.}, 
      RotationMatrix :> {{-0.47399296979371064`, 0.8805286279196937, 
       0.}, {-0.8805286279196937, -0.47399296979371064`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041247397799824295`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21640357794932905`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.450172648387465`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3099558981218884, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.47399296979371064`, 0.8805286279196937, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.980971346924826, 3.384369921390081, 0.}, 
      Optica`Optica`RayEnd :> {2.873754933729199, 3.6211107541915326`, 0.}, 
      RotationMatrix :> {{-0.4125491176473166, 0.910935357491639, 
       0.}, {-0.910935357491639, -0.4125491176473166, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04102605515943896, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2598876318220244, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.83480634348406, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2720279575756967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4125491176473166, 0.910935357491639, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.830651011562688, 3.011017350880267, 0.}, 
      Optica`Optica`RayEnd :> {3.792604485067973, 3.091943737459184, 0.}, 
      RotationMatrix :> {{-0.42546303357306015`, 0.9049758046836435, 
       0.}, {-0.9049758046836435, -0.42546303357306015`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04734614599636355, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08942381239375449, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.42659984619651, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2216992180516342, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.42546303357306015`, 0.9049758046836435, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.792604485067973, 3.091943737459184, 0.}, 
      Optica`Optica`RayEnd :> {3.667143186592133, 3.386655018692026, 0.}, 
      RotationMatrix :> {{-0.3916932562927931, 0.9200958607529691, 
       0.}, {-0.9200958607529691, -0.3916932562927931, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.047194885599491566`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3203049745182661, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.900651208483545`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3689879860055504, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3916932562927931, 0.9200958607529691, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.363445515092777, 0.42283839082818514`, 0.}, 
      Optica`Optica`RayEnd :> {2.1629977363500927`, 0.45237841394074313`, 0.},
       RotationMatrix :> {{-0.9893147513698121, 0.14579548251604355`, 
       0.}, {-0.14579548251604355`, -0.9893147513698121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01216464450365523, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20261274631268025`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.281978480828304`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42156681939633117`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9893147513698121, 0.14579548251604355`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1629977363500927`, 0.45237841394074313`, 
       0.}, Optica`Optica`RayEnd :> {1.9255244467780555`, 0.4850253643387584, 
       0.}, RotationMatrix :> {{-0.990682007383404, 0.1361953018528472, 
       0.}, {-0.1361953018528472, -0.990682007383404, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012134089490406542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23970687647719896`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.636744658014557`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11356368556592997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.990682007383404, 0.1361953018528472, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.395953481947561, 3.52396953458935, 0.}, 
      Optica`Optica`RayEnd :> {4.330377895951577, 3.613602019872441, 0.}, 
      RotationMatrix :> {{-0.5904562788743081, 0.8070696269454724, 
       0.}, {-0.8070696269454724, -0.5904562788743081, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17641937255134932`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11105917295181089`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.904585686392128`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10894213973027161`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5904562788743081, 0.8070696269454724, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.330377895951577, 3.613602019872441, 0.}, 
      Optica`Optica`RayEnd :> {4.1545226228344525`, 3.848702210669975, 0.}, 
      RotationMatrix :> {{-0.5989752460106281, 0.8007675409671062, 
       0.}, {-0.8007675409671062, -0.5989752460106281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17597462123819133`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2935935571434351, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.339104150964413`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42854641467272564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5989752460106281, 0.8007675409671062, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.825791340319894, 0.5933320850040109, 0.}, 
      Optica`Optica`RayEnd :> {7.8593814876447174`, 0.5594364396521986, 0.}, 
      RotationMatrix :> {{0.7038986029689855, -0.7103004693355545, 0.}, {
       0.7103004693355545, 0.7038986029689855, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03185511773197192, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04772015057728987, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.836625186292515`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1448612827484081, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7038986029689855, -0.7103004693355545, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.8593814876447174`, 0.5594364396521986, 0.}, 
      Optica`Optica`RayEnd :> {8.081675417603904, 0.3567032731689679, 0.}, 
      RotationMatrix :> {{0.7388674572776949, -0.6738507850971105, 0.}, {
       0.6738507850971105, 0.7388674572776949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03173083555516049, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3008576541971589, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.28189451450431, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06862367939365573, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7388674572776949, -0.6738507850971105, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.096466395184083, 0.3260823219419739, 0.}, 
      Optica`Optica`RayEnd :> {7.110169719282886, 0.2755412943464901, 0.}, 
      RotationMatrix :> {{0.2616846342054193, -0.9651534345485049, 0.}, {
       0.9651534345485049, 0.2616846342054193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012584071423006818`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05236579572358528, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.242882513588015`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2966651469506515, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2616846342054193, -0.9651534345485049, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.110169719282886, 0.2755412943464901, 0.}, 
      Optica`Optica`RayEnd :> {7.173986439691582, 0.0938575404021978, 0.}, 
      RotationMatrix :> {{0.3314022724160611, -0.9434895515253309, 0.}, {
       0.9434895515253309, 0.3314022724160611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012510582246910786`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1925657296899216, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.5278797935291, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3529264295548655, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3314022724160611, -0.9434895515253309, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.098600632748835, 2.3179016869850884`, 0.}, 
      Optica`Optica`RayEnd :> {4.888769269933546, 2.2467869132101863`, 0.}, 
      RotationMatrix :> {{-0.9470857787319488, -0.3209805721904308, 0.}, {
       0.3209805721904308, -0.9470857787319488, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01828772047160128, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22155476043176536`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.109541306798626`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40999086619675196`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9470857787319488, -0.3209805721904308, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.888769269933546, 2.2467869132101863`, 0.}, 
      Optica`Optica`RayEnd :> {4.60623413005632, 2.1637909267630078`, 0.}, 
      RotationMatrix :> {{-0.9594597505872762, -0.2818456794116243, 0.}, {
       0.2818456794116243, -0.9594597505872762, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018225971422683965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29447315502738725`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.54536157623916, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3054721818284637, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9594597505872762, -0.2818456794116243, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.352822588729898, 2.881774653529568, 0.}, 
      Optica`Optica`RayEnd :> {6.348498540963568, 2.8777780362125003`, 0.}, 
      RotationMatrix :> {{-0.7343641008168107, -0.6787557494647953, 0.}, {
       0.6787557494647953, -0.7343641008168107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01083854181771943, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00588815243218031, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.79277622828953, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2021817831637771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7343641008168107, -0.6787557494647953, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.348498540963568, 2.8777780362125003`, 0.}, 
      Optica`Optica`RayEnd :> {6.101941934037496, 2.654840751506858, 0.}, 
      RotationMatrix :> {{-0.7417419004547231, -0.6706854352897598, 0.}, {
       0.6706854352897598, -0.7417419004547231, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010811178194709677`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33240215602613354`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.284731419208207`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.372104653423426, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7417419004547231, -0.6706854352897598, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.35450132886719, 2.727795098489933, 0.}, 
      Optica`Optica`RayEnd :> {7.381310718910736, 2.6440872337303665`, 0.}, 
      RotationMatrix :> {{0.30501177626524056`, -0.9523485792185137, 0.}, {
       0.9523485792185137, 0.30501177626524056`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010191060598839815`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08789624575095821, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.65478044924119, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41212332800107226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.30501177626524056`, -0.9523485792185137, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.381310718910736, 2.6440872337303665`, 0.}, 
      Optica`Optica`RayEnd :> {7.4872954362059225`, 2.3272620760423, 0.}, 
      RotationMatrix :> {{0.3172414024712971, -0.9483448173307234, 0.}, {
       0.9483448173307234, 0.3172414024712971, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010165094290472217`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3340822366487162, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.14922215948129, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15881643570515486`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3172414024712971, -0.9483448173307234, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.372508919400013, 1.6226560092947893`, 0.}, 
      Optica`Optica`RayEnd :> {7.372752225477329, 1.6215963790450416`, 0.}, 
      RotationMatrix :> {{0.22379048930244588`, -0.9746372745271805, 0.}, {
       0.9746372745271805, 0.22379048930244588`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012911538132742338`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0010872047247133423`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.139889674011027`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3437631203317326, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22379048930244588`, -0.9746372745271805, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.372752225477329, 1.6215963790450416`, 0.}, 
      Optica`Optica`RayEnd :> {7.412708949979767, 1.3649542899157536`, 0.}, 
      RotationMatrix :> {{0.1538371526891288, -0.9880962151797265, 0.}, {
       0.9880962151797265, 0.1538371526891288, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01283864572793367, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25973390565270693`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.487933107585654`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42798323464862476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1538371526891288, -0.9880962151797265, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.385537894137745, 1.917924882028194, 0.}, 
      Optica`Optica`RayEnd :> {4.339896425545627, 1.9082524771412326`, 0.}, 
      RotationMatrix :> {{-0.9782737812243631, -0.2073171699811325, 0.}, {
       0.2073171699811325, -0.9782737812243631, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010852536857487473`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04665510766832144, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.0014492852546, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09640920155447227, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9782737812243631, -0.2073171699811325, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.339896425545627, 1.9082524771412326`, 0.}, 
      Optica`Optica`RayEnd :> {4.1432445512089, 1.8362821881632283`, 0.}, 
      RotationMatrix :> {{-0.9390851245691655, -0.3436846356951585, 0.}, {
       0.3436846356951585, -0.9390851245691655, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010605829287655058`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20940793245654563`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.31137302529029, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2568774382126144, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9390851245691655, -0.3436846356951585, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.613683131266335, 3.285649020901551, 0.}, 
      Optica`Optica`RayEnd :> {3.553902918326969, 3.314373845341771, 0.}, 
      RotationMatrix :> {{-0.9013446241806102, 0.4331026073123016, 
       0.}, {-0.4331026073123016, -0.9013446241806102, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03193054195584809, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0663233699249173, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.44614721018006, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1483482087506938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9013446241806102, 0.4331026073123016, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.553902918326969, 3.314373845341771, 0.}, 
      Optica`Optica`RayEnd :> {3.357456586428072, 3.437434345337315, 0.}, 
      RotationMatrix :> {{-0.8474519892797346, 0.5308720428368965, 
       0.}, {-0.5308720428368965, -0.8474519892797346, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03152819925925279, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23180821377959193`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.789223366573857`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11358488651662255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8474519892797346, 0.5308720428368965, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8437336950449588`, -0.5645446446200453, 0.},
       Optica`Optica`RayEnd :> {3.823958396045145, -0.5832133566231358, 0.}, 
      RotationMatrix :> {{-0.7271592329585688, -0.686468826621504, 0.}, {
       0.686468826621504, -0.7271592329585688, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012323993430661468`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.027195280075527493`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.71705559975903, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13957125768279116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7271592329585688, -0.686468826621504, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.823958396045145, -0.5832133566231358, 0.}, 
      Optica`Optica`RayEnd :> {3.6415973214998734`, -0.7773224395460558, 0.}, 
      RotationMatrix :> {{-0.6847077299146068, -0.7288177581502693, 0.}, {
       0.7288177581502693, -0.6847077299146068, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01226749733389535, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26633418402916864`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.111230192122196`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14923485715234588`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6847077299146068, -0.7288177581502693, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3044227199070897`, 2.8599001531862447`, 0.},
       Optica`Optica`RayEnd :> {2.2541150612332057`, 3.0764472252778026`, 0.},
       RotationMatrix :> {{-0.22629105081664275`, 0.9740597313924337, 
       0.}, {-0.9740597313924337, -0.22629105081664275`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008703473005665709, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22231395582075883`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.762230531212634`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28850243532644365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22629105081664275`, 0.9740597313924337, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2541150612332057`, 3.0764472252778026`, 0.},
       Optica`Optica`RayEnd :> {2.1945212760539454`, 3.3748669079486944`, 0.},
       RotationMatrix :> {{-0.19583127438790868`, 0.9806376048120978, 
       0.}, {-0.9806376048120978, -0.19583127438790868`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008677599357854674, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3043118897404233, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.21261212802846, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4232208494565384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.19583127438790868`, 0.9806376048120978, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1626895965014343`, 2.9042839244054353`, 0.},
       Optica`Optica`RayEnd :> {2.1397724922646493`, 2.907287161873985, 0.}, 
      RotationMatrix :> {{-0.991522268748585, 0.12993687150173883`, 
       0.}, {-0.12993687150173883`, -0.991522268748585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20072222975103354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023113050467045204`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.7151109530056, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24223287895171272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.991522268748585, 0.12993687150173883`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1397724922646493`, 2.907287161873985, 0.}, 
      Optica`Optica`RayEnd :> {1.9002821581533915`, 2.948691825759078, 0.}, 
      RotationMatrix :> {{-0.9853820079345198, 0.17035932154987707`, 
       0.}, {-0.17035932154987707`, -0.9853820079345198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20004600485478619`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24304313675592526`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.074814795404368`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09887230540803715, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9853820079345198, 0.17035932154987707`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0713890407219795`, 2.787141251001066, 0.}, 
      Optica`Optica`RayEnd :> {1.9981921232715614`, 2.649539852330109, 0.}, 
      RotationMatrix :> {{-0.46963639850118194`, -0.8828599284160763, 0.}, {
       0.8828599284160763, -0.46963639850118194`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008021717772985479, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15585869767339552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.11279975522905, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16896694098583442`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 107, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46963639850118194`, -0.8828599284160763, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7875435276326748`, 0.5557776983030938, 0.}, 
      Optica`Optica`RayEnd :> {2.7013439460896578`, 0.41510805924679106`, 0.},
       RotationMatrix :> {{-0.5224858554935209, -0.8526479524453239, 0.}, {
       0.8526479524453239, -0.5224858554935209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012481489648239759`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16497974181826602`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.46532623145039, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3281409675753054, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5224858554935209, -0.8526479524453239, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7013439460896578`, 0.41510805924679106`, 
       0.}, Optica`Optica`RayEnd :> {2.5751762563305114`, 0.164338020188098, 
       0.}, RotationMatrix :> {{-0.4494426675801423, -0.8933091785929692, 
       0.}, {0.8933091785929692, -0.4494426675801423, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012391837481959015`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2807203206550224, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.880792306019824`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2157847976320557, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4494426675801423, -0.8933091785929692, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.63197961151276, 3.0213397653388454`, 0.}, 
      Optica`Optica`RayEnd :> {7.843513348210977, 3.0109054965819593`, 0.}, 
      RotationMatrix :> {{0.9987856521124829, -0.0492668360486221, 0.}, {
       0.0492668360486221, 0.9987856521124829, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011438092667277355`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21179092456005216`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.675078348465483`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08832995699317445, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9987856521124829, -0.0492668360486221, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.843513348210977, 3.0109054965819593`, 0.}, 
      Optica`Optica`RayEnd :> {8.145218465973057, 3.002605801682305, 0.}, 
      RotationMatrix :> {{0.9996218339839488, -0.027498891297038884`, 0.}, {
       0.027498891297038884`, 0.9996218339839488, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011407129365692659`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30181925554751854`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.121770846675812`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36372589932130606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9996218339839488, -0.027498891297038884`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.852640212802115, -1.7759387147053527`, 0.}, 
      Optica`Optica`RayEnd :> {7.094971761813688, -1.7987569508849908`, 0.}, 
      RotationMatrix :> {{0.9955960949306272, -0.09374655065060256, 0.}, {
       0.09374655065060256, 0.9955960949306272, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008050599930654703, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24340347480818406`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.85481160545441, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.009806139451817283, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9955960949306272, -0.09374655065060256, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.094971761813688, -1.7987569508849908`, 0.}, 
      Optica`Optica`RayEnd :> {7.3847323755227645`, -1.8228940275480667`, 0.},
       RotationMatrix :> {{0.9965485018075169, -0.08301255052818128, 0.}, {
       0.08301255052818128, 0.9965485018075169, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00803028887204484, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29076418577070284`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.28514260039505, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37936707602522246`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9965485018075169, -0.08301255052818128, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.333169237688875, -2.0022077378949565`, 0.}, 
      Optica`Optica`RayEnd :> {5.102642866096751, -2.0338418521312005`, 0.}, 
      RotationMatrix :> {{-0.9907154931541226, -0.13595150467863054`, 0.}, {
       0.13595150467863054`, -0.9907154931541226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019773235680795632`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23268675334651415`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.19893545237823, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36062262664418643`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9907154931541226, -0.13595150467863054`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.102642866096751, -2.0338418521312005`, 0.}, 
      Optica`Optica`RayEnd :> {4.810627423020948, -2.0628701227823787`, 0.}, 
      RotationMatrix :> {{-0.9950954799898472, -0.0989190866505334, 0.}, {
       0.0989190866505334, -0.9950954799898472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019709822162423958`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29345469751182257`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.633248404695728`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21286179894511673`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9950954799898472, -0.0989190866505334, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.965978042793, -3.6638144368616565`, 0.}, 
      Optica`Optica`RayEnd :> {6.904023761744716, -3.8776898950459926`, 0.}, 
      RotationMatrix :> {{-0.27823610529390685`, -0.9605127118944742, 0.}, {
       0.9605127118944742, -0.27823610529390685`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03850346402219204, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2226680142134686, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.076286084534264`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40813554378036243`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.27823610529390685`, -0.9605127118944742, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.904023761744716, -3.8776898950459926`, 0.}, 
      Optica`Optica`RayEnd :> {6.866622737248663, -4.094535006342286, 0.}, 
      RotationMatrix :> {{-0.16996842134717036`, -0.9854495094852653, 0.}, {
       0.9854495094852653, -0.16996842134717036`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03802347580759137, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2200469016515713, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.40195549897859, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.287797226131891, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.16996842134717036`, -0.9854495094852653, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.426423131981197, -2.3289619051770183`, 0.}, 
      Optica`Optica`RayEnd :> {6.399416597563361, -2.340950662209046, 0.}, 
      RotationMatrix :> {{-0.9139891548545009, -0.4057386163632378, 0.}, {
       0.4057386163632378, -0.9139891548545009, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013294879657590014`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0295479812581973, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.838700769789664`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13814184693628806`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9139891548545009, -0.4057386163632378, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.399416597563361, -2.340950662209046, 0.}, 
      Optica`Optica`RayEnd :> {6.2235295923556375`, -2.3817523947534873`, 0.},
       RotationMatrix :> {{-0.9741327857444745, -0.22597636101528254`, 0.}, {
       0.22597636101528254`, -0.9741327857444745, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012590715941711086`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18055752540276424`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.105925907385757`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38256147749764463`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9741327857444745, -0.22597636101528254`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.930958569340212, -0.3847901262935921, 0.}, 
      Optica`Optica`RayEnd :> {7.947664964619279, -0.16217757645068404`, 0.}, 
      RotationMatrix :> {{0.07483651523243859, 0.9971958162707385, 
       0.}, {-0.9971958162707385, 0.07483651523243859, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013366451520295392`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22323855175749027`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.134136540204572`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3920401040970934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.07483651523243859, 0.9971958162707385, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.947664964619279, -0.16217757645068404`, 0.},
       Optica`Optica`RayEnd :> {7.979510040500845, 0.1419831973646408, 0.}, 
      RotationMatrix :> {{0.10412900796387392`, 0.9945637987079858, 
       0.}, {-0.9945637987079858, 0.10412900796387392`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013327488754502318`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3058232907838117, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.586755010564612`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3192611151366776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.10412900796387392`, 0.9945637987079858, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.427593108847438, 0.6724781669937853, 0.}, 
      Optica`Optica`RayEnd :> {5.383963743079979, 0.7060783323082914, 0.}, 
      RotationMatrix :> {{-0.7922805969527562, 0.6101569107141082, 
       0.}, {-0.6101569107141082, -0.7922805969527562, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012991428415227772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05506807302269434, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.027080479588896`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32394417616536214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7922805969527562, 0.6101569107141082, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.383963743079979, 0.7060783323082914, 0.}, 
      Optica`Optica`RayEnd :> {5.14771009037063, 0.8767832613979392, 0.}, 
      RotationMatrix :> {{-0.8105533458047524, 0.5856648133571978, 
       0.}, {-0.5856648133571978, -0.8105533458047524, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012953072608805799`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29147205909659896`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.458459127051864`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3944483257408247, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8105533458047524, 0.5856648133571978, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4805411901108987`, -0.372600169719215, 0.}, 
      Optica`Optica`RayEnd :> {3.4060816265724547`, -0.350241541182473, 0.}, 
      RotationMatrix :> {{-0.9577527612186518, 0.2875928517506091, 
       0.}, {-0.2875928517506091, -0.9577527612186518, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01743049417627911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07774403432019454, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.804255399366244`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2838067308718287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9577527612186518, 0.2875928517506091, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4060816265724547`, -0.350241541182473, 0.}, 
      Optica`Optica`RayEnd :> {3.1066298187111636`, -0.2555800674312975, 0.}, 
      RotationMatrix :> {{-0.9534932515709246, 0.3014143646356378, 
       0.}, {-0.3014143646356378, -0.9534932515709246, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017385696064913338`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3140576059326377, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.26906065614655, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08397903591990157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9534932515709246, 0.3014143646356378, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.676768144014921, -3.4053014779424857`, 0.}, 
      Optica`Optica`RayEnd :> {4.657676669171288, -3.4357880667505545`, 0.}, 
      RotationMatrix :> {{-0.5307455390278161, -0.8475312223169559, 0.}, {
       0.8475312223169559, -0.5307455390278161, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09111750408755619, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0359710509834968, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.264792553354905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3961270499818145, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5307455390278161, -0.8475312223169559, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.657676669171288, -3.4357880667505545`, 0.}, 
      Optica`Optica`RayEnd :> {4.510555217834851, -3.622696215050899, 0.}, 
      RotationMatrix :> {{-0.6185102748664343, -0.7857767112129552, 0.}, {
       0.7857767112129552, -0.6185102748664343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09006462351004987, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23786419937519662`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.616831568430197`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2035133583730158, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6185102748664343, -0.7857767112129552, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.568817617378096, 0.30247733245865827`, 0.}, 
      Optica`Optica`RayEnd :> {2.1565119128098553`, 0.41836773618834916`, 0.},
       RotationMatrix :> {{-0.9626938771495936, 0.2705928655724006, 
       0.}, {-0.2705928655724006, -0.9626938771495936, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01042063444718457, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.4282832937392539, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.907316123268764`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32759579642646397`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9626938771495936, 0.2705928655724006, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1565119128098553`, 0.41836773618834916`, 
       0.}, Optica`Optica`RayEnd :> {1.9254498630377734`, 0.4847035724536128, 
       0.}, RotationMatrix :> {{-0.9611736271136957, 0.2759443033314921, 
       0.}, {-0.2759443033314921, -0.9611736271136957, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010394789967959126`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2403957445918873, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.26310182526476, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11222698636021325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9611736271136957, 0.2759443033314921, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9681142684318607`, -2.6598401862157806`, 
       0.}, Optica`Optica`RayEnd :> {2.919631614244007, -2.7259929176539672`, 
       0.}, RotationMatrix :> {{-0.5911309397152238, -0.8065756084282468, 
       0.}, {0.8065756084282468, -0.5911309397152238, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0375003061033261, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08201677653889992, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.689389715386866`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.396521269393742, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5911309397152238, -0.8065756084282468, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.919631614244007, -2.7259929176539672`, 0.}, 
      Optica`Optica`RayEnd :> {2.7454803212975145`, -2.9218814178830406`, 0.},
       RotationMatrix :> {{-0.6644238989482181, -0.7473559275916986, 0.}, {
       0.7473559275916986, -0.6644238989482181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03716721373871164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26210871285962745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.077310610419115`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25606288174611513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6644238989482181, -0.7473559275916986, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.12604817160651, -2.498956565176562, 0.}, 
      Optica`Optica`RayEnd :> {8.246993911727618, -2.6048101806406474`, 0.}, 
      RotationMatrix :> {{0.7524962355808932, -0.6585965498213493, 0.}, {
       0.6585965498213493, 0.7524962355808932, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011439289485791308`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16072604008144134`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.901398572545265`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3262713960568977, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7524962355808932, -0.6585965498213493, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.246993911727618, -2.6048101806406474`, 0.}, 
      Optica`Optica`RayEnd :> {8.464967287231055, -2.8252742464879286`, 0.}, 
      RotationMatrix :> {{0.7030784801708138, -0.7111122630926138, 0.}, {
       0.7111122630926138, 0.7030784801708138, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011373621288093732`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3100270903619173, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.360238666280903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37514461666279353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7030784801708138, -0.7111122630926138, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.018810165197388, -3.6757171600667142`, 0.}, 
      Optica`Optica`RayEnd :> {6.9154365070604165`, -3.8703378116629303`, 0.},
       RotationMatrix :> {{-0.4690895300443783, -0.8831506172803955, 0.}, {
       0.8831506172803955, -0.4690895300443783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12082548914171178`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22037084930715187`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.855099565050317`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43173098350604344`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.4690895300443783, -0.8831506172803955, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9154365070604165`, -3.8703378116629303`, 
       0.}, Optica`Optica`RayEnd :> {6.847230167096772, -4.057055011384567, 
       0.}, RotationMatrix :> {{-0.34311638534040234`, -0.9392928968702658, 
       0.}, {0.9392928968702658, -0.34311638534040234`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11827831057451985`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1987848522476649, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.14930114637686, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16751064668679447`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.34311638534040234`, -0.9392928968702658, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.815550438724145, 3.3888616835434866`, 0.}, 
      Optica`Optica`RayEnd :> {7.770634920213825, 3.578721628612756, 0.}, 
      RotationMatrix :> {{-0.23021734961239082`, 0.9731392356376586, 
       0.}, {-0.9731392356376586, -0.23021734961239082`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035650189283410655`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1951004934508287, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.458029204212814`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26204406558031257`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23021734961239082`, 0.9731392356376586, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.770634920213825, 3.578721628612756, 0.}, 
      Optica`Optica`RayEnd :> {7.705414945740973, 3.888998368063742, 0.}, 
      RotationMatrix :> {{-0.20570409401938303`, 0.9786142374315147, 
       0.}, {-0.9786142374315147, -0.20570409401938303`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03555074778499699, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3170572505314687, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.927273934999388`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41131189964980786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.20570409401938303`, 0.9786142374315147, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.872301017939595, -0.9226557924440155, 0.}, 
      Optica`Optica`RayEnd :> {3.710162616831017, -0.9425001262725878, 0.}, 
      RotationMatrix :> {{-0.9925932909728907, -0.12148480857953395`, 0.}, {
       0.12148480857953395`, -0.9925932909728907, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013758546110687195`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1633482742459984, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.132486981294615`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4123736863427169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9925932909728907, -0.12148480857953395`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.710162616831017, -0.9425001262725878, 0.}, 
      Optica`Optica`RayEnd :> {3.3837451970089263`, -0.9810609906121149, 0.}, 
      RotationMatrix :> {{-0.9930944213508657, -0.1173178174097564, 0.}, {
       0.1173178174097564, -0.9930944213508657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013724514919912245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32868719509880895`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.618944030040854`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07854086547728707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9930944213508657, -0.1173178174097564, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.575543885995159, -2.7837733642724407`, 0.}, 
      Optica`Optica`RayEnd :> {6.541654341085413, -2.88528378636298, 0.}, 
      RotationMatrix :> {{-0.3166712434025284, -0.94853535706472, 0.}, {
       0.94853535706472, -0.3166712434025284, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023894691349671197`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10701806878835497`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.337595204067753`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06357594400929724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.3166712434025284, -0.94853535706472, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.541654341085413, -2.88528378636298, 0.}, 
      Optica`Optica`RayEnd :> {6.43912162825665, -3.185392938272045, 0.}, 
      RotationMatrix :> {{-0.3233031654339461, -0.9462954418258549, 0.}, {
       0.9462954418258549, -0.3233031654339461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023835213525979424`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3171410731198405, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.806963992285116`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35374247413301174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.3233031654339461, -0.9462954418258549, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.072749319436245, -3.105403635144691, 0.}, 
      Optica`Optica`RayEnd :> {7.08799960753779, -3.150314265218908, 0.}, 
      RotationMatrix :> {{0.3215374596607615, -0.9468968592380606, 0.}, {
       0.9468968592380606, 0.3215374596607615, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2088966120190522, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047429273458943884`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.67107701688922, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.309447231398791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3215374596607615, -0.9468968592380606, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.08799960753779, -3.150314265218908, 0.}, 
      Optica`Optica`RayEnd :> {7.194421264377078, -3.4109465853670002`, 0.}, 
      RotationMatrix :> {{0.37802219224761435`, -0.9257965338930078, 0.}, {
       0.9257965338930078, 0.37802219224761435`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2079332617048073, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28152224663460734`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.08772994190844, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3032863692117086, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.37802219224761435`, -0.9257965338930078, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.410905318833086, -2.699039979861575, 0.}, 
      Optica`Optica`RayEnd :> {7.588084346100509, -2.811015656833259, 0.}, 
      RotationMatrix :> {{0.8453313323148948, -0.5342423968637495, 0.}, {
       0.5342423968637495, 0.8453313323148948, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018272192334172897`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20959713723402162`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.855179092567184`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13831160977245785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8453313323148948, -0.5342423968637495, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.588084346100509, -2.811015656833259, 0.}, 
      Optica`Optica`RayEnd :> {7.757347622260808, -2.895465567414296, 0.}, 
      RotationMatrix :> {{0.8948111421221451, -0.4464448677429961, 0.}, {
       0.4464448677429961, 0.8948111421221451, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018087030809893354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18916089462059216`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.13513721660566, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07899637174040669, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8948111421221451, -0.4464448677429961, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1268187889837655`, -1.8870016953381006`, 
       0.}, Optica`Optica`RayEnd :> {7.128881658595486, -1.9138761945120275`, 
       0.}, RotationMatrix :> {{0.07653423074927396, -0.9970669543835137, 
       0.}, {0.9970669543835137, 0.07653423074927396, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023590879297095364`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.026953555180798672`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.810783649433194`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16242483784326145`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.07653423074927396, -0.9970669543835137, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.128881658595486, -1.9138761945120275`, 0.}, 
      Optica`Optica`RayEnd :> {7.120352531365677, -2.119608947377167, 0.}, 
      RotationMatrix :> {{-0.041421732818142265`, -0.9991417517301243, 0.}, {
       0.9991417517301243, -0.041421732818142265`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023253661275712302`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20590947431522152`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.115529671419722`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12272584329561054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.041421732818142265`, -0.9991417517301243, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.14175033611594, 2.3651174583367935`, 0.}, 
      Optica`Optica`RayEnd :> {5.1076434555438315`, 2.4144414593341925`, 0.}, 
      RotationMatrix :> {{-0.568753292639561, 0.8225081714558568, 
       0.}, {-0.8225081714558568, -0.568753292639561, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008548579474683583, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.059967794496307916`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.858004521313596`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04173354572395346, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.568753292639561, 0.8225081714558568, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1076434555438315`, 2.4144414593341925`, 0.},
       Optica`Optica`RayEnd :> {4.9558269679507205`, 2.6415458060438706`, 0.},
       RotationMatrix :> {{-0.5557479167780192, 0.8313508603453124, 
       0.}, {-0.8313508603453124, -0.5557479167780192, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008526442329211152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27317509073767876`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.26230365560536, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36974287516935567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5557479167780192, 0.8313508603453124, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.653980257328887, -0.3616574428833441, 0.}, 
      Optica`Optica`RayEnd :> {5.594967418142435, -0.41055009918854746`, 0.}, 
      RotationMatrix :> {{-0.7700452553709346, -0.6379892669008717, 0.}, {
       0.6379892669008717, -0.7700452553709346, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17045277011011184`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07663554677448846, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.513518384788814`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06279200931718391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7700452553709346, -0.6379892669008717, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.594967418142435, -0.41055009918854746`, 0.},
       Optica`Optica`RayEnd :> {5.3552372974225495`, -0.6182436607527533, 0.},
       RotationMatrix :> {{-0.7558022645744128, -0.6547999212463215, 0.}, {
       0.6547999212463215, -0.7558022645744128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16999037541435172`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31718629588239666`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.982954102694762`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24258373136558842`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7558022645744128, -0.6547999212463215, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.583398214968567, -1.132330017951795, 0.}, 
      Optica`Optica`RayEnd :> {7.618430132596749, -1.2291221078227457`, 0.}, 
      RotationMatrix :> {{0.3403251821117306, -0.9403078062106136, 0.}, {
       0.9403078062106136, 0.3403251821117306, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010318848722259188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10293660143162836`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.123641827409177`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04314379023835174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3403251821117306, -0.9403078062106136, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.618430132596749, -1.2291221078227457`, 0.}, 
      Optica`Optica`RayEnd :> {7.71366100941622, -1.3953709118801847`, 0.}, 
      RotationMatrix :> {{0.4970497708881461, -0.8677220322545931, 0.}, {
       0.8677220322545931, 0.4970497708881461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009908168301184886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1915922356212119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.40719833612857, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4117658974756776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4970497708881461, -0.8677220322545931, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.666072835015382, 3.5295693043040495`, 0.}, 
      Optica`Optica`RayEnd :> {7.709587383961219, 3.592447385020252, 0.}, 
      RotationMatrix :> {{0.5690647214197703, 0.8222927354874529, 
       0.}, {-0.8222927354874529, 0.5690647214197703, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0088306303676398, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07646678366789703, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.42788767624562, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4031507270939057, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5690647214197703, 0.8222927354874529, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.709587383961219, 3.592447385020252, 0.}, 
      Optica`Optica`RayEnd :> {7.88750394744357, 3.8598451511704264`, 0.}, 
      RotationMatrix :> {{0.5539485254413076, 0.83255091805931, 
       0.}, {-0.83255091805931, 0.5539485254413076, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00880737111655251, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32117887368797005`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.90323240930382, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11706642771861589`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5539485254413076, 0.83255091805931, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.332726271625041, 3.072085061703826, 0.}, 
      Optica`Optica`RayEnd :> {6.27728416674348, 2.933684843818274, 0.}, 
      RotationMatrix :> {{-0.3718648646289101, -0.9282868750847019, 0.}, {
       0.9282868750847019, -0.3718648646289101, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008389837579523699, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14909207659854462`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.306020507676497`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06598906172033718, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3718648646289101, -0.9282868750847019, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.27728416674348, 2.933684843818274, 0.}, 
      Optica`Optica`RayEnd :> {6.152706677785381, 2.623570492538123, 0.}, 
      RotationMatrix :> {{-0.372761911264312, -0.9279270216512588, 0.}, {
       0.9279270216512588, -0.372761911264312, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008369155533173411, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33420122923923223`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.800638326950562`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3905206819431717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.372761911264312, -0.9279270216512588, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.111084384355568, 3.220486449041145, 0.}, 
      Optica`Optica`RayEnd :> {5.954758455371051, 3.344437558261244, 0.}, 
      RotationMatrix :> {{-0.7835746033926111, 0.6212977071566503, 
       0.}, {-0.6212977071566503, -0.7835746033926111, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2280447809400767`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19950356776199543`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.76834119765399, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32667581952402985`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 113, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7835746033926111, 0.6212977071566503, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.954758455371051, 3.344437558261244, 0.}, 
      Optica`Optica`RayEnd :> {5.848099970795353, 3.4606262406768167`, 0.}, 
      RotationMatrix :> {{-0.6762488067293465, 0.7366733003150946, 
       0.}, {-0.7366733003150946, -0.6762488067293465, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1907037301657544`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1577207730562187, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.001767941777192`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05137183529418522, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 113, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6762488067293465, 0.7366733003150946, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.848099970795353, 3.4606262406768167`, 0.}, 
      Optica`Optica`RayEnd :> {5.928757673475447, 3.59616286765204, 0.}, 
      RotationMatrix :> {{0.5113955575867246, 0.8593454390875428, 
       0.}, {-0.8593454390875428, 0.5113955575867246, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0362056246933072, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15772077305621876`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.235194685900396`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3971497990540176, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 113, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5113955575867246, 0.8593454390875428, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.316562790117922, 3.3905650271201493`, 0.}, 
      Optica`Optica`RayEnd :> {6.356524519002311, 3.4185556272910147`, 0.}, 
      RotationMatrix :> {{0.8190644360576276, 0.5737015335395216, 
       0.}, {-0.5737015335395216, 0.8190644360576276, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008277122335031238, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04878948117529679, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.961153613446278`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3266971008560266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8190644360576276, 0.5737015335395216, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.356524519002311, 3.4185556272910147`, 0.}, 
      Optica`Optica`RayEnd :> {6.601745336365228, 3.5938447090001717`, 0.}, 
      RotationMatrix :> {{0.813527310642658, 0.5815267103397079, 
       0.}, {-0.5815267103397079, 0.813527310642658, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008256340871542143, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3014291151076432, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.40726870380559, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24759296463374425`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.813527310642658, 0.5815267103397079, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.604405943891403, 2.1458756573122315`, 0.}, 
      Optica`Optica`RayEnd :> {5.592964444774758, 2.143284465560271, 0.}, 
      RotationMatrix :> {{-0.9753011135250474, -0.22087946476936615`, 0.}, {
       0.22087946476936615`, -0.9753011135250474, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03703325219470707, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01173124787614827, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.079507660933082`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0343035987609327, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9753011135250474, -0.22087946476936615`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.592964444774758, 2.143284465560271, 0.}, 
      Optica`Optica`RayEnd :> {5.434749207937504, 2.0885718099516564`, 0.}, 
      RotationMatrix :> {{-0.9450860289970411, -0.32682166053461503`, 0.}, {
       0.32682166053461503`, -0.9450860289970411, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03658015217719984, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16740829086761222`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.327271931417147`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2174744355829651, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9450860289970411, -0.32682166053461503`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.455720919383612, 2.812084139995091, 0.}, 
      Optica`Optica`RayEnd :> {6.377552899821237, 2.8113232883593313`, 0.}, 
      RotationMatrix :> {{-0.9999526324539878, -0.009733080105449432, 0.}, {
       0.009733080105449432, -0.9999526324539878, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040929026086553834`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07817172236503182, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.903507826786537`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3768869706456195, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999526324539878, -0.009733080105449432, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.377552899821237, 2.8113232883593313`, 0.}, 
      Optica`Optica`RayEnd :> {6.048061583993393, 2.8023330118719088`, 0.}, 
      RotationMatrix :> {{-0.9996279633349783, -0.027275170370912635`, 0.}, {
       0.027275170370912635`, -0.9996279633349783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04082176782059912, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32961394430042545`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.391336464351166`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06920416447048656, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9996279633349783, -0.027275170370912635`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.337832227099149, 2.9099046679207174`, 0.}, 
      Optica`Optica`RayEnd :> {6.225713861223167, 3.070734819407332, 0.}, 
      RotationMatrix :> {{-0.5718771929138912, 0.8203392445963603, 
       0.}, {-0.8203392445963603, -0.5718771929138912, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1662746012651736, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19605322133009676`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.288187449826243`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3718051419643379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5718771929138912, 0.8203392445963603, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.225713861223167, 3.070734819407332, 0.}, 
      Optica`Optica`RayEnd :> {6.116955393542976, 3.2735007709854105`, 0.}, 
      RotationMatrix :> {{-0.47267335600626365`, 0.8812377082954264, 
       0.}, {-0.8812377082954264, -0.47267335600626365`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.163970710004797, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.230092232401502, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.628723953780465`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13399073815016527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.47267335600626365`, 0.8812377082954264, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.352145538186897, 3.0624226294134362`, 0.}, 
      Optica`Optica`RayEnd :> {6.360730456802546, 3.0850282812256205`, 0.}, 
      RotationMatrix :> {{0.3550287914666034, 0.9348553670112623, 
       0.}, {-0.9348553670112623, 0.3550287914666034, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028216510626910527`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02418090820236142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.284596964661596`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.001099821546759097, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3550287914666034, 0.9348553670112623, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.360730456802546, 3.0850282812256205`, 0.}, 
      Optica`Optica`RayEnd :> {6.420110121692732, 3.3141384967822844`, 0.}, 
      RotationMatrix :> {{0.2508858287998734, 0.968016684209213, 
       0.}, {-0.968016684209213, 0.2508858287998734, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027877254482644786`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23668002762145296`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.634883405541345`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24382244844843423`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2508858287998734, 0.968016684209213, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.256952250972121, -0.4067665791358533, 0.}, 
      Optica`Optica`RayEnd :> {8.26526151421365, -0.5869975905894367, 0.}, 
      RotationMatrix :> {{0.04605448562006194, -0.9989389292415578, 0.}, {
       0.9989389292415578, 0.04605448562006194, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2545870221486679, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18042245244203597`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.98140910883837, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.281990704625553, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.04605448562006194, -0.9989389292415578, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.26526151421365, -0.5869975905894367, 0.}, 
      Optica`Optica`RayEnd :> {8.282525643195672, -0.9400201055250266, 0.}, 
      RotationMatrix :> {{0.04884538790947418, -0.9988063516417843, 0.}, {
       0.9988063516417843, 0.04884538790947418, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2539585588019182, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.35344440326727017`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.504506825673932`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24035735408571804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.04884538790947418, -0.9988063516417843, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.245025077907684, -0.43724862593718694`, 0.},
       Optica`Optica`RayEnd :> {7.117777238390527, -0.4931210008312532, 0.}, 
      RotationMatrix :> {{-0.9156242450712245, -0.40203512512932194`, 0.}, {
       0.40203512512932194`, -0.9156242450712245, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06630948667702445, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13897386422664898`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.354949035336038`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35674503537998986`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9156242450712245, -0.40203512512932194`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.117777238390528, -0.4931210008312532, 0.}, 
      Optica`Optica`RayEnd :> {6.860004043903626, -0.5846922603434024, 0.}, 
      RotationMatrix :> {{-0.9423086162407691, -0.3347453834758687, 0.}, {
       0.3347453834758687, -0.9423086162407691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06592681237779134, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27355495858167794`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.75981037403692, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40241851796666517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9423086162407691, -0.3347453834758687, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.746337843806928, -0.9425816125023615, 0.}, 
      Optica`Optica`RayEnd :> {6.480883233853334, -1.3957434313766623`, 0.}, 
      RotationMatrix :> {{-0.5054474271491045, -0.8628574032760857, 0.}, {
       0.8628574032760857, -0.5054474271491045, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0236113390691958, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5251873799236603, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.035608337540626`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40303950211288886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5054474271491045, -0.8628574032760857, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.480883233853334, -1.3957434313766623`, 0.}, 
      Optica`Optica`RayEnd :> {6.404594217038392, -1.5717003663107687`, 0.}, 
      RotationMatrix :> {{-0.39778746683151855`, -0.9174775916782723, 0.}, {
       0.9174775916782723, -0.39778746683151855`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02325496386566611, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19178335964831755`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.319447709820135`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16612616892775015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39778746683151855`, -0.9174775916782723, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.508878933533153, -2.1061952972400784`, 0.}, 
      Optica`Optica`RayEnd :> {7.435440312755351, -2.388980126571918, 0.}, 
      RotationMatrix :> {{-0.2513599379006648, -0.9678936830140866, 0.}, {
       0.9678936830140866, -0.2513599379006648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18481405850765223`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2921651771207228, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.084283788573273`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37108033566249166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2513599379006648, -0.9678936830140866, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.435440312755351, -2.388980126571918, 0.}, 
      Optica`Optica`RayEnd :> {7.381736509769126, -2.6609417351921207`, 0.}, 
      RotationMatrix :> {{-0.19372736634367638`, -0.9810554049234641, 0.}, {
       0.9810554049234641, -0.19372736634367638`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18397945415253414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27721330238369124`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.494559476101138`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38157914659693526`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.19372736634367638`, -0.9810554049234641, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.550720203660656, 2.1343176423314136`, 0.}, 
      Optica`Optica`RayEnd :> {4.428443316827227, 2.3187447737060687`, 0.}, 
      RotationMatrix :> {{-0.5525880344424392, 0.8334545363671858, 
       0.}, {-0.8334545363671858, -0.5525880344424392, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00966828209902613, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22128037382641844`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.931360994822896`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39879975991584665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5525880344424392, 0.8334545363671858, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.428443316827227, 2.3187447737060687`, 0.}, 
      Optica`Optica`RayEnd :> {4.337253499543261, 2.5050236894144997`, 0.}, 
      RotationMatrix :> {{-0.4396775345062212, 0.8981557023426002, 
       0.}, {-0.8981557023426002, -0.4396775345062212, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009492820494557604, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2074015844052116, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.23831533974261, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1288354157689644, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4396775345062212, 0.8981557023426002, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.876393431753907, 1.0266974747121043`, 0.}, 
      Optica`Optica`RayEnd :> {3.6701262197708275`, 1.1029914289804044`, 0.}, 
      RotationMatrix :> {{-0.9378987055543281, 0.346909236140399, 
       0.}, {-0.346909236140399, -0.9378987055543281, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03198798382775079, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21992482851457718`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.118218397044938`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22088967115999542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9378987055543281, 0.346909236140399, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6701262197708275`, 1.1029914289804044`, 0.},
       Optica`Optica`RayEnd :> {3.4621819624918184`, 1.1524391197069026`, 0.},
       RotationMatrix :> {{-0.9728724262760617, 0.2313422620096207, 
       0.}, {-0.2313422620096207, -0.9728724262760617, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031504984949511365`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21374257473302333`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.434557407649812`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.43066057614994935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9728724262760617, 0.2313422620096207, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.834142400424299, 0.5186169949293943, 0.}, 
      Optica`Optica`RayEnd :> {3.73333375410169, 0.37613382223822867`, 0.}, 
      RotationMatrix :> {{-0.5775711298579703, -0.8163403640360967, 0.}, {
       0.8163403640360967, -0.5775711298579703, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24704685203527538`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1745389288197261, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.320379052087276`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33034045125106426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5775711298579703, -0.8163403640360967, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.73333375410169, 0.37613382223822867`, 0.}, 
      Optica`Optica`RayEnd :> {3.6118972978118684`, 0.16418018278816915`, 0.},
       RotationMatrix :> {{-0.49712642813402036`, -0.8676781168444379, 0.}, {
       0.8676781168444379, -0.49712642813402036`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24479880758501874`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24427680649696468`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.681908725702783`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.163015439494401, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.49712642813402036`, -0.8676781168444379, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.13623424416586, 0.45570602404111304`, 0.}, 
      Optica`Optica`RayEnd :> {4.117262062815048, 0.16049933262649818`, 0.}, 
      RotationMatrix :> {{-0.06413513787571673, -0.9979412227629751, 0.}, {
       0.9979412227629751, -0.06413513787571673, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024564481846496396`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2958157100648506, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.435721811415387`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03247440536848928, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06413513787571673, -0.9979412227629751, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.117262062815048, 0.16049933262649818`, 0.}, 
      Optica`Optica`RayEnd :> {4.08319075266063, -0.12669712854553145`, 0.}, 
      RotationMatrix :> {{-0.11780803501146538`, -0.9930363874938001, 0.}, {
       0.9930363874938001, -0.11780803501146538`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024463118315835128`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2892104104028339, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.86375321881158, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08516765923709735, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.11780803501146538`, -0.9930363874938001, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.627965300614364, -0.36629352393380893`, 0.},
       Optica`Optica`RayEnd :> {4.616643151682505, -0.43049006424632213`, 0.},
       RotationMatrix :> {{-0.17368636606581844`, -0.984801018603682, 0.}, {
       0.984801018603682, -0.17368636606581844`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009193626010791307, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06518732119462609, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.560669225192512`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1387609688074649, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17368636606581844`, -0.984801018603682, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.616643151682505, -0.43049006424632213`, 0.},
       Optica`Optica`RayEnd :> {4.552047754432303, -0.6922139549788413, 0.}, 
      RotationMatrix :> {{-0.2396172809362806, -0.9708674259015505, 0.}, {
       0.9708674259015505, -0.2396172809362806, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009145360169150624, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26957737354251166`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.959643738035428`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10067183708024866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2396172809362806, -0.9708674259015505, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.825680949044306, 1.5631240269047626`, 0.}, 
      Optica`Optica`RayEnd :> {2.7959855139893546`, 1.6219647450608035`, 0.}, 
      RotationMatrix :> {{-0.4505493171656737, 0.8927515403523782, 
       0.}, {-0.8927515403523782, -0.4505493171656737, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012632468749458765`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06590939975619171, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.834305311451626`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18907505355612486`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4505493171656737, 0.8927515403523782, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7959855139893546`, 1.6219647450608035`, 0.},
       Optica`Optica`RayEnd :> {2.6709939753795493`, 1.8909537908995016`, 0.},
       RotationMatrix :> {{-0.4213990892193527, 0.9068752988173726, 
       0.}, {-0.9068752988173726, -0.4213990892193527, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012594372275134429`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2966108418538668, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.27328935739535, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3711923770207043, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4213990892193527, 0.9068752988173726, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.648326616778112, 1.086860197629454, 0.}, 
      Optica`Optica`RayEnd :> {2.5204903062092607`, 1.0799653130267683`, 0.}, 
      RotationMatrix :> {{-0.9985486595922276, -0.053856981224022965`, 0.}, {
       0.053856981224022965`, -0.9985486595922276, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25022373994894936`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12802211423633078`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.885757234402007`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02029136354033412, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9985486595922276, -0.053856981224022965`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5204903062092607`, 1.0799653130267683`, 0.},
       Optica`Optica`RayEnd :> {2.3688715306818175`, 1.0498166231520185`, 0.},
       RotationMatrix :> {{-0.9807978536342336, -0.1950271014666418, 0.}, {
       0.1950271014666418, -0.9807978536342336, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24449284781285735`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15458718120725637`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.114546262588746`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3202776824437015, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9807978536342336, -0.1950271014666418, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.78724020649285, 0.5557238620463394, 0.}, 
      Optica`Optica`RayEnd :> {2.756798215815996, 0.4170659713737852, 0.}, 
      RotationMatrix :> {{-0.21444017577005045`, -0.9767371248272019, 0.}, {
       0.9767371248272019, -0.21444017577005045`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01160118005522395, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14196029530165, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.36547827354163, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19558448151508578`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.21444017577005045`, -0.9767371248272019, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.756798215815996, 0.4170659713737852, 0.}, 
      Optica`Optica`RayEnd :> {2.6840645451323115`, 0.07101065378714078, 0.}, 
      RotationMatrix :> {{-0.20568530325815487`, -0.97861818704927, 0.}, {
       0.97861818704927, -0.20568530325815487`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011572121172541583`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3536162746270539, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.88883035998967, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3642840886671952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.20568530325815487`, -0.97861818704927, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0974595866669437`, 1.2948117347041475`, 0.},
       Optica`Optica`RayEnd :> {2.0631151281931768`, 1.361958894730527, 0.}, 
      RotationMatrix :> {{-0.45537174328954216`, 0.8903013958280883, 
       0.}, {-0.8903013958280883, -0.45537174328954216`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00865050814160092, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07542070622491223, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.069092378939775`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09302967904923388, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.45537174328954216`, 0.8903013958280883, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0631151281931768`, 1.361958894730527, 0.}, 
      Optica`Optica`RayEnd :> {1.8999957360474449`, 1.691340859919253, 0.}, 
      RotationMatrix :> {{-0.4437897350829148, 0.8961309452502103, 
       0.}, {-0.8961309452502103, -0.4437897350829148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008628455971146688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36756008364018544`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.61308130272725, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4173529830790826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4437897350829148, 0.8961309452502103, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.198137492260498, 0.1574141637177774, 0.}, 
      Optica`Optica`RayEnd :> {2.2090268470570162`, -0.13268082458635444`, 
       0.}, RotationMatrix :> {{0.03751078631363271, -0.9992962228038953, 
       0.}, {0.9992962228038953, 0.03751078631363271, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00817540533452656, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2902992943275247, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.940722145874958`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39448520044766305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03751078631363271, -0.9992962228038953, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2090268470570162`, -0.13268082458635444`, 
       0.}, Optica`Optica`RayEnd :> {2.2306487365576024`, -0.434011017903535, 
       0.}, RotationMatrix :> {{0.07157079221217699, -0.9974355225788385, 
       0.}, {0.9974355225788385, 0.07157079221217699, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008150231902771919, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30210493460078564`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.38783744908412, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34658124117431144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.07157079221217699, -0.9974355225788385, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.415501185784918, -3.8244870407543035`, 0.}, 
      Optica`Optica`RayEnd :> {7.422972368351319, -3.8454761566998754`, 0.}, 
      RotationMatrix :> {{0.33534379887241306`, -0.9420958213248893, 0.}, {
       0.9420958213248893, 0.33534379887241306`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00835116514709602, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022279173169513104`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.51892597010377, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4292041457288197, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33534379887241306`, -0.9420958213248893, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.422972368351319, -3.8454761566998754`, 0.}, 
      Optica`Optica`RayEnd :> {7.5064694967424925`, -4.068756492661345, 0.}, 
      RotationMatrix :> {{0.350266384033954, -0.9366501268967927, 0.}, {
       0.9366501268967927, 0.350266384033954, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008329517840496571, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23838179225066478`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.87173102263475, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15559628120604832`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.350266384033954, -0.9366501268967927, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8860657647081065`, 3.0378135942946987`, 0.},
       Optica`Optica`RayEnd :> {2.616602416028211, 3.0080884991397507`, 0.}, 
      RotationMatrix :> {{-0.9939705816670893, -0.10964708286310039`, 0.}, {
       0.10964708286310039`, -0.9939705816670893, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28979145014342367`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27109791139688566`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.36870436701916, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3847369153164286, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9939705816670893, -0.10964708286310039`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.616602416028211, 3.0080884991397507`, 0.}, 
      Optica`Optica`RayEnd :> {2.301734612303231, 2.9715636864263844`, 0.}, 
      RotationMatrix :> {{-0.9933390932043606, -0.11522780008287037`, 0.}, {
       0.11522780008287037`, -0.9933390932043606, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2890726448865627, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31697917244882046`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.837833542243413`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.030874345442535193`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9933390932043606, -0.11522780008287037`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.03176716932845, 3.687293224962993, 0.}, 
      Optica`Optica`RayEnd :> {4.083036431691981, 3.7183520146823694`, 0.}, 
      RotationMatrix :> {{0.8552975713600854, 0.5181371096780647, 
       0.}, {-0.5181371096780647, 0.8552975713600854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03190267015405101, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.059943187120246946`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.03766561367363, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013171700001029893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8552975713600854, 0.5181371096780647, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.083036431691981, 3.7183520146823694`, 0.}, 
      Optica`Optica`RayEnd :> {4.315560330733823, 3.842826281431774, 0.}, 
      RotationMatrix :> {{0.8816252968873786, 0.4719500353726452, 
       0.}, {-0.4719500353726452, 0.8816252968873786, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03177263621721155, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2637445861215409, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.428007601133512`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.045208836086587594`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8816252968873786, 0.4719500353726452, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.642666223636448, 3.6503448995112304`, 0.}, 
      Optica`Optica`RayEnd :> {4.648119115760208, 3.6510884643268637`, 0.}, 
      RotationMatrix :> {{0.9908304449457652, 0.13511117410701498`, 
       0.}, {-0.13511117410701498`, 0.9908304449457652, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032323755905886736`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005503355444490935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.74059477948397, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24432435097256217`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9908304449457652, 0.13511117410701498`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.648119115760208, 3.6510884643268637`, 0.}, 
      Optica`Optica`RayEnd :> {4.926853849632756, 3.6996533119034503`, 0.}, 
      RotationMatrix :> {{0.9851584628316913, 0.17164732188734683`, 
       0.}, {-0.17164732188734683`, 0.9851584628316913, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03222052453646206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2829339079840676, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.15933696330039, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3858978715259379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9851584628316913, 0.17164732188734683`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.622413844330305, 3.520465895530815, 0.}, 
      Optica`Optica`RayEnd :> {6.816371544651145, 3.497741381394294, 0.}, 
      RotationMatrix :> {{0.9932063700555314, -0.1163662600632752, 0.}, {
       0.1163662600632752, 0.9932063700555314, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021862514510374933`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19528439020180163`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.22197361491798, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.053254585519778616`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9932063700555314, -0.1163662600632752, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.816371544651145, 3.497741381394294, 0.}, 
      Optica`Optica`RayEnd :> {7.08493018736672, 3.4665318756219445`, 0.}, 
      RotationMatrix :> {{0.9933151195164045, -0.11543428147699442`, 0.}, {
       0.11543428147699442`, 0.9933151195164045, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021808621140697426`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2703660071602689, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.62211530551518, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3985643131925717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9933151195164045, -0.11543428147699442`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.498313174423297, 1.8306402663680825`, 0.}, 
      Optica`Optica`RayEnd :> {6.628465941339579, 1.7376646769887718`, 0.}, 
      RotationMatrix :> {{0.8137058895356496, -0.5812768061216587, 0.}, {
       0.5812768061216587, 0.8137058895356496, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011228579207082773`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15995062662082427`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.815002588777187`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11098838817738571`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8137058895356496, -0.5812768061216587, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.628465941339579, 1.7376646769887718`, 0.}, 
      Optica`Optica`RayEnd :> {6.8423809303975185`, 1.5972051673966625`, 0.}, 
      RotationMatrix :> {{0.8359084340958439, -0.5488689186020952, 0.}, {
       0.5488689186020952, 0.8359084340958439, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011191586991407477`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2559072026702533, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.19374524872916, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05440102770973036, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8359084340958439, -0.5488689186020952, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.119367256792085, 3.0761878458813996`, 0.}, 
      Optica`Optica`RayEnd :> {7.180006138502992, 3.0910293230434465`, 0.}, 
      RotationMatrix :> {{0.9713300967135802, 0.2377348170091756, 
       0.}, {-0.2377348170091756, 0.9713300967135802, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.15686547415048863`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06242870669412381, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.431412671843734`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3293202615565758, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9713300967135802, 0.2377348170091756, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.180006138502992, 3.0910293230434465`, 0.}, 
      Optica`Optica`RayEnd :> {7.358079660061334, 3.168928479704756, 0.}, 
      RotationMatrix :> {{0.9161724655226419, 0.40078424796661216`, 
       0.}, {-0.40078424796661216`, 0.9161724655226419, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1506862901766112, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1943668122101415, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.719075553914745`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23820122787813414`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9161724655226419, 0.40078424796661216`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.529350429469603, 0.870475889649174, 0.}, 
      Optica`Optica`RayEnd :> {6.612412203942919, 0.8204946137409735, 0.}, 
      RotationMatrix :> {{0.8568359197854291, -0.5155891839104628, 0.}, {
       0.5155891839104628, 0.8568359197854291, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09374461823965194, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0969401171861668, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.80203423551381, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22278126786644295`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8568359197854291, -0.5155891839104628, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.612412203942919, 0.8204946137409735, 0.}, 
      Optica`Optica`RayEnd :> {6.913412393865279, 0.6424620335464204, 0.}, 
      RotationMatrix :> {{0.8607150079816966, -0.5090870996549285, 0.}, {
       0.5090870996549285, 0.8607150079816966, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09351088110400799, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34970947076684494`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.319604252248737`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21331004674402515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8607150079816966, -0.5090870996549285, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.162084544223142, 1.0917722028025019`, 0.}, 
      Optica`Optica`RayEnd :> {5.183607526553527, 0.8975625777593969, 0.}, 
      RotationMatrix :> {{0.11014910600937614`, -0.9939150740608244, 0.}, {
       0.9939150740608244, 0.11014910600937614`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.047905335774023894`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19539861112039028`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.00400075946384, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3951391892720212, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.11014910600937614`, -0.9939150740608244, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.183607526553527, 0.8975625777593969, 0.}, 
      Optica`Optica`RayEnd :> {5.223831140464143, 0.6062246397799318, 0.}, 
      RotationMatrix :> {{0.13676776349662986`, -0.9906031389351281, 0.}, {
       0.9906031389351281, 0.13676776349662986`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04776944736918801, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2941015695676529, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.439271082423964`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29734002501418305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13676776349662986`, -0.9906031389351281, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7662921383577954`, 1.1468848888748389`, 0.},
       Optica`Optica`RayEnd :> {3.6942946472059317`, 1.0427846718180966`, 0.},
       RotationMatrix :> {{-0.5688259651058152, -0.8224579146810107, 0.}, {
       0.8224579146810107, -0.5688259651058152, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03418872254349396, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.126572089827985, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.75120997363064, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38324162656485505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5688259651058152, -0.8224579146810107, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6942946472059317`, 1.0427846718180966`, 0.},
       Optica`Optica`RayEnd :> {3.5400266537753016`, 0.8584285114380503, 0.}, 
      RotationMatrix :> {{-0.641749053479274, -0.7669146969242763, 0.}, {
       0.7669146969242763, -0.641749053479274, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03390025856023029, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24038678763024046`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.106982419323398`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24852940236472076`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.641749053479274, -0.7669146969242763, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3617301027851787`, 3.5264239061816407`, 0.},
       Optica`Optica`RayEnd :> {2.2362153506393723`, 3.5660250924968926`, 0.},
       RotationMatrix :> {{-0.9536591087137046, 0.3008891895156445, 
       0.}, {-0.3008891895156445, -0.9536591087137046, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02281540760599134, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13161385551604543`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.237162458896, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21114952731151207`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9536591087137046, 0.3008891895156445, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2362153506393723`, 3.5660250924968926`, 0.},
       Optica`Optica`RayEnd :> {2.089830620806531, 3.644610377272796, 0.}, 
      RotationMatrix :> {{-0.8810665135324797, 0.4729923876044093, 
       0.}, {-0.4729923876044093, -0.8810665135324797, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021661359017307216`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16614492502494252`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.483056947932916`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23875108882604285`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8810665135324797, 0.4729923876044093, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.319178571095467, 0.030756680964077566`, 0.},
       Optica`Optica`RayEnd :> {2.1509732346100674`, -0.037460808890576236`, 
       0.}, RotationMatrix :> {{-0.9266891229598846, -0.37582877668938447`, 
       0.}, {0.37582877668938447`, -0.9266891229598846, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0800947152327206, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1815121515057223, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.078543169366583`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4108951723023795, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9266891229598846, -0.37582877668938447`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1509732346100674`, -0.037460808890576236`, 
       0.}, Optica`Optica`RayEnd :> {1.8184609758976726`, -0.1543466785264378,
        0.}, RotationMatrix :> {{-0.943409339866201, -0.3316305436072168, 
       0.}, {0.3316305436072168, -0.943409339866201, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07979802317557987, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3524580949766229, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.600181149931984`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3439944803296771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.943409339866201, -0.3316305436072168, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.915873650154078, 2.085425531623274, 0.}, 
      Optica`Optica`RayEnd :> {3.811957347798449, 2.145449446476206, 0.}, 
      RotationMatrix :> {{-0.8659250417956497, 0.5001737917876161, 
       0.}, {-0.5001737917876161, -0.8659250417956497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036140705767510724`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1200061175504753, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.33533016350623, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22710023953627012`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8659250417956497, 0.5001737917876161, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.811957347798449, 2.145449446476206, 0.}, 
      Optica`Optica`RayEnd :> {3.58339473401461, 2.2758211254393754`, 0.}, 
      RotationMatrix :> {{-0.8686284628196504, 0.4954640184509571, 
       0.}, {-0.4954640184509571, -0.8686284628196504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03605109866124203, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2631304678203876, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.68792499038555, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22242865000929885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8686284628196504, 0.4954640184509571, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8556411871541107`, 1.0443451746924912`, 0.},
       Optica`Optica`RayEnd :> {2.585297879846851, 0.987296686739908, 0.}, 
      RotationMatrix :> {{-0.9784518272705149, -0.20647523268176735`, 0.}, {
       0.20647523268176735`, -0.9784518272705149, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08677719921981861, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2762970028492953, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.7691954478827, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3961022925593427, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9784518272705149, -0.20647523268176735`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.585297879846851, 0.987296686739908, 0.}, 
      Optica`Optica`RayEnd :> {2.345772548463666, 0.9347785088876049, 0.}, 
      RotationMatrix :> {{-0.976796029176284, -0.21417170071100364`, 0.}, {
       0.21417170071100364`, -0.976796029176284, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08656063162434105, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24521530005109965`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.097783949951175`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14723607616413303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.976796029176284, -0.21417170071100364`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9173878228281183`, -0.09386285124665286, 
       0.}, Optica`Optica`RayEnd :> {
       3.8483375195141334`, -0.14371255809062766`, 0.}, 
      RotationMatrix :> {{-0.8107904381118781, -0.5853365403478142, 0.}, {
       0.5853365403478142, -0.8107904381118781, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020376356029900882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08516418061710875, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.633034882463775`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20938971596118144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8107904381118781, -0.5853365403478142, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8483375195141334`, -0.14371255809062766`, 
       0.}, Optica`Optica`RayEnd :> {
       3.5719528092812887`, -0.34369219067637297`, 0.}, 
      RotationMatrix :> {{-0.810166279235525, -0.5862001364633628, 0.}, {
       0.5862001364633628, -0.810166279235525, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020326123603821886`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34114566023858967`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.090170067183486`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2976441762551221, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.810166279235525, -0.5862001364633628, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.982587617186125, -3.1717560561794467`, 0.}, 
      Optica`Optica`RayEnd :> {5.969952656087857, -3.3732957056206274`, 0.}, 
      RotationMatrix :> {{-0.06256934765806425, -0.9980406187794381, 0.}, {
       0.9980406187794381, -0.06256934765806425, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008106220552827743, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20193531771047077`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.538355697412342`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37991000911731987`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.06256934765806425, -0.9980406187794381, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.969952656087857, -3.3732957056206274`, 0.}, 
      Optica`Optica`RayEnd :> {5.96350433554662, -3.6571197780856823`, 0.}, 
      RotationMatrix :> {{-0.022713566564969034`, -0.9997420136684754, 0.}, {
       0.9997420136684754, -0.022713566564969034`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008079289286411688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28389731409164704`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.95852372226798, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39428105372533784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.022713566564969034`, -0.9997420136684754, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2264786672156953`, -2.866480413713278, 0.}, 
      Optica`Optica`RayEnd :> {2.181353800596747, -2.892619305560026, 0.}, 
      RotationMatrix :> {{-0.8653101113460568, -0.5012368813268572, 0.}, {
       0.5012368813268572, -0.8653101113460568, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15311042820384177`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05214877998912177, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.466762666494866`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23084267716959267`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8653101113460568, -0.5012368813268572, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.181353800596747, -2.892619305560026, 0.}, 
      Optica`Optica`RayEnd :> {1.8925223693054563`, -3.0614739192830824`, 0.},
       RotationMatrix :> {{-0.863297685624581, -0.5046950623844475, 0.}, {
       0.5046950623844475, -0.863297685624581, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15273183879548274`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33456759597626684`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.961922708539742`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23564555493217942`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.863297685624581, -0.5046950623844475, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.873754933729199, 3.6211107541915326`, 0.}, 
      Optica`Optica`RayEnd :> {2.860348670364729, 3.65708926283423, 0.}, 
      RotationMatrix :> {{-0.3491663192320349, 0.937060767247222, 
       0.}, {-0.937060767247222, -0.3491663192320349, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04080590029251491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.038395064546763974`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.886255729976725`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19189874608025784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3491663192320349, 0.937060767247222, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.860348670364729, 3.65708926283423, 0.}, 
      Optica`Optica`RayEnd :> {2.735202566971461, 3.941086772914109, 0.}, 
      RotationMatrix :> {{-0.4032439061750188, 0.9150925374696879, 
       0.}, {-0.9150925374696879, -0.4032439061750188, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04062403406869375, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3103484057089541, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.345571370425976`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2112549414354954, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4032439061750188, 0.9150925374696879, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.667143186592133, 3.386655018692026, 0.}, 
      Optica`Optica`RayEnd :> {3.6629156674126215`, 3.3977027496627663`, 0.}, 
      RotationMatrix :> {{-0.35738724547931544`, 0.9339562927507402, 
       0.}, {-0.9339562927507402, -0.35738724547931544`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.047044108445915965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.011828959295517078`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.91650201393954, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2653117328698939, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.35738724547931544`, 0.9339562927507402, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6629156674126215`, 3.3977027496627663`, 0.},
       Optica`Optica`RayEnd :> {3.5490640983277992`, 3.6362395798778353`, 0.},
       RotationMatrix :> {{-0.4307432849935779, 0.9024744996025872, 
       0.}, {-0.9024744996025872, -0.4307432849935779, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04673044047412252, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2643142053544015, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.307687037864053`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1626346452830975, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4307432849935779, 0.9024744996025872, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.081675417603904, 0.3567032731689679, 0.}, 
      Optica`Optica`RayEnd :> {8.112777383536885, 0.3310916078713156, 0.}, 
      RotationMatrix :> {{0.7719511649691657, -0.6356818377952499, 0.}, {
       0.6356818377952499, 0.7719511649691657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03160703826305748, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.040290069300205, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.335883207366585`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35867570374320334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7719511649691657, -0.6356818377952499, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.112777383536885, 0.3310916078713156, 0.}, 
      Optica`Optica`RayEnd :> {8.35458679363506, 0.12765032623837, 0.}, 
      RotationMatrix :> {{0.7652037672676134, -0.6437881596918746, 0.}, {
       0.6437881596918746, 0.7652037672676134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03152737399264827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31600655987571297`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.80357291598264, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21672326563423663`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7652037672676134, -0.6437881596918746, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.173986439691582, 0.09385754040219779, 0.}, 
      Optica`Optica`RayEnd :> {7.274268209074545, -0.1363595633154113, 0.}, 
      RotationMatrix :> {{0.39935357863419385`, -0.9167969891050374, 0.}, {
       0.9167969891050374, 0.39935357863419385`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012437522237085495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25111023100364155`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.86436750307398, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15535145159505648`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.39935357863419385`, -0.9167969891050374, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.274268209074545, -0.1363595633154113, 0.}, 
      Optica`Optica`RayEnd :> {7.361821664728799, -0.379995678727669, 0.}, 
      RotationMatrix :> {{0.33818752863485885`, -0.9410787403165826, 0.}, {
       0.9410787403165826, 0.33818752863485885`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012374114899797433`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25889025537894683`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.24752508103482, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18269331148006157`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33818752863485885`, -0.9410787403165826, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.60623413005632, 2.1637909267630078`, 0.}, 
      Optica`Optica`RayEnd :> {4.18329341596266, 2.0581945319702597`, 0.}, 
      RotationMatrix :> {{-0.9702173637646916, -0.2422359738963035, 0.}, {
       0.2422359738963035, -0.9702173637646916, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01816443087132368, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4359236701892672, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.129499294292778`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24853913617775875`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9702173637646916, -0.2422359738963035, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.18329341596266, 2.0581945319702597`, 0.}, 
      Optica`Optica`RayEnd :> {3.8735678907445887`, 1.9718076657689771`, 0.}, 
      RotationMatrix :> {{-0.9632350724931865, -0.26865999910489896`, 0.}, {
       0.26865999910489896`, -0.9632350724931865, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01811263836004397, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3215471841327312, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.60538912680922, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00851659129313348, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9632350724931865, -0.26865999910489896`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.101941934037496, 2.654840751506858, 0.}, 
      Optica`Optica`RayEnd :> {6.0951283677385755`, 2.6488139974837615`, 0.}, 
      RotationMatrix :> {{-0.7490310160229084, -0.6625349326908645, 0.}, {
       0.6625349326908645, -0.7490310160229084, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010783883655519206`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.009096507558656772, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.296920739336805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12195104992226961`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7490310160229084, -0.6625349326908645, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.0951283677385755`, 2.6488139974837615`, 0.},
       Optica`Optica`RayEnd :> {5.888508547977647, 2.4429143369798125`, 0.}, 
      RotationMatrix :> {{-0.708340139240514, -0.7058712681082352, 0.}, {
       0.7058712681082352, -0.708340139240514, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010734899908417542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29169576636228384`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.728630473552986`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13515731918315965`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.708340139240514, -0.7058712681082352, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4872954362059225`, 2.3272620760423, 0.}, 
      Optica`Optica`RayEnd :> {7.527369175267768, 2.2124021505044738`, 0.}, 
      RotationMatrix :> {{0.3294184954469545, -0.944184015357951, 0.}, {
       0.944184015357951, 0.3294184954469545, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010139194142948596`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12164993652670725`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.312233074427077`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1595243117333467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.3294184954469545, -0.944184015357951, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.527369175267768, 2.2124021505044738`, 0.}, 
      Optica`Optica`RayEnd :> {7.613073684194516, 1.9149759269957787`, 0.}, 
      RotationMatrix :> {{0.2768876861157384, -0.9609022891415501, 0.}, {
       0.9609022891415501, 0.2768876861157384, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010096473093018712`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3095280621866445, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.77033460646331, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11709329342760322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2768876861157384, -0.9609022891415501, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.412708949979767, 1.3649542899157536`, 0.}, 
      Optica`Optica`RayEnd :> {7.4275612104463455`, 1.1868517104206138`, 0.}, 
      RotationMatrix :> {{0.08310315215522004, -0.9965409505393468, 0.}, {
       0.9965409505393468, 0.08310315215522004, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012766164838981913`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17872078352499937`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.752439867202654`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41662552361977245`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.08310315215522004, -0.9965409505393468, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4275612104463455`, 1.1868517104206138`, 0.},
       Optica`Optica`RayEnd :> {7.4349281815717845`, 0.8897875450281161, 0.}, 
      RotationMatrix :> {{0.024791636529180268`, -0.9996926401440612, 0.}, {
       0.9996926401440612, 0.024791636529180268`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012709240607369532`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2971554990638811, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.150628235948254`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4298163411073512, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.024791636529180268`, -0.9996926401440612, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1432445512089, 1.8362821881632283`, 0.}, 
      Optica`Optica`RayEnd :> {3.920732809479422, 1.7167830393253625`, 0.}, 
      RotationMatrix :> {{-0.8809909597118113, -0.47313309851040924`, 0.}, {
       0.47313309851040924`, -0.8809909597118113, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01036473004938714, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2525698354524159, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.649816604796527`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30287915534211807`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8809909597118113, -0.47313309851040924`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.920732809479422, 1.7167830393253625`, 0.}, 
      Optica`Optica`RayEnd :> {3.7061559660456895`, 1.6302363202035928`, 0.}, 
      RotationMatrix :> {{-0.9274057934900721, -0.37405680611512543`, 0.}, {
       0.37405680611512543`, -0.9274057934900721, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010239825751505265`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23137319708368756`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.992248936480383`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4011555675664575, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9274057934900721, -0.37405680611512543`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.357456586428072, 3.437434345337315, 0.}, 
      Optica`Optica`RayEnd :> {3.1387202755849977`, 3.6112018223763473`, 0.}, 
      RotationMatrix :> {{-0.7829973241199374, 0.6220250721803879, 
       0.}, {-0.6220250721803879, -0.7829973241199374, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.031130926305780807`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2793576735258023, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.16356264909843, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25993269525961166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7829973241199374, 0.6220250721803879, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1387202755849977`, 3.6112018223763473`, 0.},
       Optica`Optica`RayEnd :> {2.9882413674549433`, 3.6907620563599965`, 0.},
       RotationMatrix :> {{-0.8840430358851412, 0.46740550991936547`, 
       0.}, {-0.46740550991936547`, -0.8840430358851412, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.029610080232268826`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1702167225144062, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.415483398419752`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29099900246449706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8840430358851412, 0.46740550991936547`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6415973214998734`, -0.7773224395460558, 0.},
       Optica`Optica`RayEnd :> {3.617055429827024, -0.8068031282257101, 0.}, 
      RotationMatrix :> {{-0.6397943176989501, -0.7685461801610449, 0.}, {
       0.7685461801610449, -0.6397943176989501, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012211260228580977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.038359033511137494`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.162631297027122`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.039003946123868545`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6397943176989501, -0.7685461801610449, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.617055429827024, -0.8068031282257101, 0.}, 
      Optica`Optica`RayEnd :> {3.417849472132508, -1.058102453305081, 0.}, 
      RotationMatrix :> {{-0.6212024913802895, -0.7836500907311373, 0.}, {
       0.7836500907311373, -0.6212024913802895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012177567440452109`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3206779761167526, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.637234701679915`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3127434357970288, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6212024913802895, -0.7836500907311373, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1945212760539454`, 3.3748669079486944`, 0.},
       Optica`Optica`RayEnd :> {2.160334222458122, 3.5789906596311543`, 0.}, 
      RotationMatrix :> {{-0.16518133278877967`, 0.9862632140043159, 
       0.}, {-0.9862632140043159, -0.16518133278877967`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008651802627114628, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2069668104660415, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.489947654052955`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40661537070879544`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.16518133278877967`, 0.9862632140043159, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.160334222458122, 3.5789906596311543`, 0.}, 
      Optica`Optica`RayEnd :> {2.133292155381548, 3.839095338540685, 0.}, 
      RotationMatrix :> {{-0.10340872469098916`, 0.9946389473863287, 
       0.}, {-0.9946389473863287, -0.10340872469098916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008610412978161293, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26150662971023114`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.876977466024098`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4030479034907626, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.10340872469098916`, 0.9946389473863287, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5751762563305114`, 0.164338020188098, 0.}, 
      Optica`Optica`RayEnd :> {2.565815094168653, 0.1410710166466319, 0.}, 
      RotationMatrix :> {{-0.37325848548829177`, -0.9277273861490705, 0.}, {
       0.9277273861490705, -0.37325848548829177`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012302829270137653`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02507956958999104, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.914398929270412`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02230159788342379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.37325848548829177`, -0.9277273861490705, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.565815094168653, 0.14107101664663185`, 0.}, 
      Optica`Optica`RayEnd :> {2.4346059552727373`, -0.17662184558167104`, 
       0.}, RotationMatrix :> {{-0.3817307629595219, -0.9242735658939625, 
       0.}, {0.9242735658939625, -0.3817307629595219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012271991089420805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34372167932881276`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.423107014677054`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3682746097830654, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3817307629595219, -0.9242735658939625, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3847323755227645`, -1.8228940275480667`, 
       0.}, Optica`Optica`RayEnd :> {7.429132867141638, -1.8261112150576801`, 
       0.}, RotationMatrix :> {{0.997385183655039, -0.07226891050378742, 
       0.}, {0.07226891050378742, 0.997385183655039, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008010029056709446, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04451689512386983, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.344795239861035`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.387698295495279, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 115, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.997385183655039, -0.07226891050378742, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.810627423020948, -2.0628701227823787`, 0.}, 
      Optica`Optica`RayEnd :> {4.655261269437338, -2.072482187679916, 0.}, 
      RotationMatrix :> {{-0.9980917027042592, -0.06174911329657099, 0.}, {
       0.06174911329657099, -0.9980917027042592, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019646612013615936`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15566320525724975`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.84183709974044, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3254701126351182, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9980917027042592, -0.06174911329657099, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.655261269437338, -2.072482187679916, 0.}, 
      Optica`Optica`RayEnd :> {4.34509924734631, -2.079337547647544, 0.}, 
      RotationMatrix :> {{-0.9997558289291749, -0.02209711569726721, 0.}, {
       0.02209711569726721, -0.9997558289291749, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019581525776108916`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31023777318031504`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.30098900404731, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18665436597648663`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9997558289291749, -0.02209711569726721, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.866622737248663, -4.094535006342286, 0.}, 
      Optica`Optica`RayEnd :> {6.859571591560801, -4.212627155441221, 0.}, 
      RotationMatrix :> {{-0.05960269220454964, -0.9982221792176174, 0.}, {
       0.9982221792176174, -0.05960269220454964, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03754947117633854, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11830246968815375`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.560480808360715`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32790379044579476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.05960269220454964, -0.9982221792176174, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.859571591560801, -4.212627155441221, 0.}, 
      Optica`Optica`RayEnd :> {6.816528145569681, -4.383112257242901, 0.}, 
      RotationMatrix :> {{-0.24479468348539785`, -0.9695749393096355, 0.}, {
       0.9695749393096355, -0.24479468348539785`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0356307897580996, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17583488897007823`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.82071644403643, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10942513187173403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.24479468348539785`, -0.9695749393096355, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.2235295923556375`, -2.3817523947534873`, 
       0.}, Optica`Optica`RayEnd :> {
       5.8106301849454995`, -2.3974929692183786`, 0.}, 
      RotationMatrix :> {{-0.999274145473604, -0.03809438525554418, 0.}, {
       0.03809438525554418, -0.999274145473604, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011923848279014368`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.41319933001413267`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.659613009604694`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.046774507340203504`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.999274145473604, -0.03809438525554418, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8106301849454995`, -2.3974929692183786`, 
       0.}, Optica`Optica`RayEnd :> {5.604807374485697, -2.3781584461875953`, 
       0.}, RotationMatrix :> {{-0.9956168409963081, 0.0935259639059213, 
       0.}, {-0.0935259639059213, -0.9956168409963081, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011700911716802006`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20672893625808533`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.965571835266662`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34669598060675005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9956168409963081, 0.0935259639059213, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.979510040500845, 0.14198319736464082`, 0.}, 
      Optica`Optica`RayEnd :> {8.006806903401426, 0.34488466422178027`, 0.}, 
      RotationMatrix :> {{0.1333314314310333, 0.9910715056909623, 
       0.}, {-0.9910715056909623, 0.1333314314310333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013288639563887815`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20472939206912127`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.861092395937234`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28082683796415703`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1333314314310333, 0.9910715056909623, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.006806903401426, 0.34488466422178027`, 0.}, 
      Optica`Optica`RayEnd :> {8.049286457408408, 0.6750501916120701, 0.}, 
      RotationMatrix :> {{0.12760951205765939`, 0.9918244867074041, 
       0.}, {-0.9918244867074041, 0.12760951205765939`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0132556663911243, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3328870498916118, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.35376522977682, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1669633468142008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12760951205765939`, 0.9918244867074041, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.14771009037063, 0.8767832613979392, 0.}, 
      Optica`Optica`RayEnd :> {5.128144313032029, 0.8900298355245744, 0.}, 
      RotationMatrix :> {{-0.8280692354580034, 0.5606258478593344, 
       0.}, {-0.5606258478593344, -0.8280692354580034, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01291483004381035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023628190132893977`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.490120901829943`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1554194817855335, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8280692354580034, 0.5606258478593344, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.128144313032029, 0.8900298355245744, 0.}, 
      Optica`Optica`RayEnd :> {4.857304483961946, 1.0785491778117529`, 0.}, 
      RotationMatrix :> {{-0.8207502869363063, 0.5712871138875536, 
       0.}, {-0.5712871138875536, -0.8207502869363063, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01288191299428509, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3299905383902721, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.978506898647545`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2331150071327467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8207502869363063, 0.5712871138875536, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1066298187111636`, -0.2555800674312975, 0.},
       Optica`Optica`RayEnd :> {2.913926441095321, -0.19158357221137529`, 0.},
       RotationMatrix :> {{-0.9490342924542482, 0.31517282837494764`, 
       0.}, {-0.31517282837494764`, -0.9490342924542482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017341013089169174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20305207003374137`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.541150429991763`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3070473401524301, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9490342924542482, 0.31517282837494764`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.913926441095321, -0.19158357221137529`, 0.},
       Optica`Optica`RayEnd :> {2.6677729820998963`, -0.13071392041402335`, 
       0.}, RotationMatrix :> {{-0.9707598462244589, 0.2400527462002147, 
       0.}, {-0.2400527462002147, -0.9707598462244589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017229021097724437`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2535678210762226, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.91643080518457, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3824221342801126, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9707598462244589, 0.2400527462002147, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.510555217834851, -3.622696215050899, 0.}, 
      Optica`Optica`RayEnd :> {4.346861212778436, -3.790094402998322, 0.}, 
      RotationMatrix :> {{-0.6991520803106008, -0.7149729845227435, 0.}, {
       0.7149729845227435, -0.6991520803106008, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08902390917350449, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23413218621003476`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.930568697951642`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4116638537516605, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6991520803106008, -0.7149729845227435, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.346861212778436, -3.790094402998322, 0.}, 
      Optica`Optica`RayEnd :> {4.199850853875885, -3.9113342055346747`, 0.}, 
      RotationMatrix :> {{-0.7714859543560042, -0.6362463534130514, 0.}, {
       0.6362463534130514, -0.7714859543560042, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08800349095817998, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1905548092904256, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.212589815701474`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2966696842364763, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7714859543560042, -0.6362463534130514, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7454803212975145`, -2.9218814178830406`, 
       0.}, Optica`Optica`RayEnd :> {2.4385228322540007`, -3.207733694584439, 
       0.}, RotationMatrix :> {{-0.7318175523500778, -0.6815006016668959, 
       0.}, {0.6815006016668959, -0.7318175523500778, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036837080030569444`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4194453768672051, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.63936741542117, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43152753205807376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7318175523500778, -0.6815006016668959, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4385228322540007`, -3.207733694584439, 0.}, 
      Optica`Optica`RayEnd :> {2.2504504448487164`, -3.355483321000886, 0.}, 
      RotationMatrix :> {{-0.7863620796138583, -0.6177658777768225, 0.}, {
       0.6177658777768225, -0.7863620796138583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03657096042967973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23916767133231648`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.993335568992997`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34753191926910004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7863620796138583, -0.6177658777768225, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.847230167096772, -4.057055011384567, 0.}, 
      Optica`Optica`RayEnd :> {6.825875960104849, -4.156169652824735, 0.}, 
      RotationMatrix :> {{-0.2106167591096555, -0.9775687089827214, 0.}, {
       0.9775687089827214, -0.2106167591096555, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11578483026834266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10138892594394595`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.285162307141746`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14917807690267273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.2106167591096555, -0.9775687089827214, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.825875960104849, -4.156169652824735, 0.}, 
      Optica`Optica`RayEnd :> {6.750818439690522, -4.419688470805187, 0.}, 
      RotationMatrix :> {{-0.273932923319292, -0.9617487995946479, 0.}, {
       0.9617487995946479, -0.273932923319292, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11520049002439489`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27399963284749385`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.690681763756036`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12466585939320929`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.273932923319292, -0.9617487995946479, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3837451970089263`, -0.9810609906121149, 0.},
       Optica`Optica`RayEnd :> {3.1151139283275167`, -1.0116527439306593`, 
       0.}, RotationMatrix :> {{-0.9935780584231843, -0.11314875969278287`, 
       0.}, {0.11314875969278287`, -0.9935780584231843, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01369056790387031, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2703675533130526, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.981236551480343`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3993756024923282, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9935780584231843, -0.11314875969278287`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1151139283275167`, -1.0116527439306593`, 
       0.}, Optica`Optica`RayEnd :> {2.833124009085632, -1.0373182512021093`, 
       0.}, RotationMatrix :> {{-0.9958836290091447, -0.09064103635537263, 
       0.}, {0.09064103635537263, -0.9958836290091447, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013653239158579933`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2831554922962741, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.400306680078828`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1494367615048074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9958836290091447, -0.09064103635537263, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.43912162825665, -3.185392938272045, 0.}, 
      Optica`Optica`RayEnd :> {6.4054814356495156`, -3.2816487654920232`, 0.},
       RotationMatrix :> {{-0.3299192457363408, -0.9440091584792827, 0.}, {
       0.9440091584792827, -0.3299192457363408, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02377588375239048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10196492942402993`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.943596997713318`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3846709356054306, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3299192457363408, -0.9440091584792827, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.4054814356495156`, -3.2816487654920232`, 
       0.}, Optica`Optica`RayEnd :> {6.323627665433101, -3.3923747599303007`, 
       0.}, RotationMatrix :> {{-0.5944512590188872, -0.8041316438561906, 
       0.}, {0.8041316438561906, -0.5944512590188872, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017845064802731653`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1376963526858541, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.147387599688383`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028275587434804066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5944512590188872, -0.8041316438561906, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.194421264377078, -3.4109465853670002`, 0.}, 
      Optica`Optica`RayEnd :> {7.321252999872217, -3.674877994366107, 0.}, 
      RotationMatrix :> {{0.4331325311233923, -0.9013302449616584, 0.}, {
       0.9013302449616584, 0.4331325311233923, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.206974353989315, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29282431214802346`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.480114520186792`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1658925130781099, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4331325311233923, -0.9013302449616584, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.321252999872217, -3.674877994366107, 0.}, 
      Optica`Optica`RayEnd :> {7.396788952294392, -3.863917628126922, 0.}, 
      RotationMatrix :> {{0.371052293978078, -0.9286119723186889, 0.}, {
       0.9286119723186889, 0.371052293978078, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2058791164333152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20357225557709954`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.7814014584409, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20483338923583563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.371052293978078, -0.9286119723186889, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.757347622260808, -2.895465567414296, 0.}, 
      Optica`Optica`RayEnd :> {7.85372094736996, -2.9319571685943555`, 0.}, 
      RotationMatrix :> {{0.9352026614542621, -0.3541129509194261, 0.}, {
       0.3541129509194261, 0.9352026614542621, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01790374562258787, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10305073871292172`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.273225206480976`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28248924125063846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9352026614542621, -0.3541129509194261, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.85372094736996, -2.9319571685943555`, 0.}, 
      Optica`Optica`RayEnd :> {8.166895214856064, -3.0588244373516718`, 0.}, 
      RotationMatrix :> {{0.9268374086576752, -0.37546293813467735`, 0.}, {
       0.37546293813467735`, 0.9268374086576752, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01785479870312892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3378955840158289, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.773310670824404`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3846715748511858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9268374086576752, -0.37546293813467735`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.120352531365677, -2.119608947377167, 0.}, 
      Optica`Optica`RayEnd :> {7.118421919627566, -2.1316120902231095`, 0.}, 
      RotationMatrix :> {{-0.15880119226528078`, -0.987310579977306, 0.}, {
       0.987310579977306, -0.15880119226528078`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022921263591566918`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01215741337059176, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.131820605336316`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3584328759875169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.15880119226528078`, -0.987310579977306, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.118421919627566, -2.1316120902231095`, 0.}, 
      Optica`Optica`RayEnd :> {7.109466376042483, -2.3475363475123796`, 0.}, 
      RotationMatrix :> {{-0.04143976652157272, -0.9991410039382012, 0.}, {
       0.9991410039382012, -0.04143976652157272, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022593734368124205`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21610989483785112`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.451663249696335`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3283343831540146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.04143976652157272, -0.9991410039382012, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.9558269679507205`, 2.6415458060438706`, 0.},
       Optica`Optica`RayEnd :> {4.9018847525001386`, 2.7250518604226603`, 0.},
       RotationMatrix :> {{-0.5426050861458167, 0.8399879287755808, 
       0.}, {-0.8399879287755808, -0.5426050861458167, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008504362509427871, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09941339811931968, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.39551760908525, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3365020494431064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5426050861458167, 0.8399879287755808, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.9018847525001386`, 2.7250518604226603`, 0.},
       Optica`Optica`RayEnd :> {4.745581720203257, 2.93105649072293, 0.}, 
      RotationMatrix :> {{-0.6044445481357582, 0.7966472169216173, 
       0.}, {-0.7966472169216173, -0.6044445481357582, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008452235239997557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25858953113061456`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.77823011515856, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2655397176408497, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6044445481357582, 0.7966472169216173, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3552372974225495`, -0.6182436607527533, 0.},
       Optica`Optica`RayEnd :> {5.313269548490573, -0.656253555064122, 0.}, 
      RotationMatrix :> {{-0.7411923613406239, -0.6712926958416198, 0.}, {
       0.6712926958416198, -0.7411923613406239, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16952923507693698`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.056621939351976056`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.05882750142641, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12353055223992801`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7411923613406239, -0.6712926958416198, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.313269548490573, -0.656253555064122, 0.}, 
      Optica`Optica`RayEnd :> {5.0950691582980365`, -0.8562053790945715, 0.}, 
      RotationMatrix :> {{-0.7372638654789411, -0.6756049086996403, 0.}, {
       0.6756049086996403, -0.7372638654789411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1691085201095186, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29595969694078084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.496847852898767`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31673065781625476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7372638654789411, -0.6756049086996403, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.71366100941622, -1.3953709118801847`, 0.}, 
      Optica`Optica`RayEnd :> {7.846069552065707, -1.5547823287806197`, 0.}, 
      RotationMatrix :> {{0.638946723154656, -0.7692509895800766, 0.}, {
       0.7692509895800766, 0.638946723154656, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009513832572507326, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2072293946445952, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.684885724952327`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.030400776388372124`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.638946723154656, -0.7692509895800766, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.846069552065707, -1.5547823287806197`, 0.}, 
      Optica`Optica`RayEnd :> {7.994065167912832, -1.694889300567602, 0.}, 
      RotationMatrix :> {{0.7261961568709083, -0.6874875575208055, 0.}, {
       0.6874875575208055, 0.7261961568709083, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009373462859084827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.203795647287394, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.98650328293767, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25263240093561307`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7261961568709083, -0.6874875575208055, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.152706677785381, 2.623570492538123, 0.}, 
      Optica`Optica`RayEnd :> {6.151437642763765, 2.620420253012436, 0.}, 
      RotationMatrix :> {{-0.3736586096702163, -0.92756630136035, 0.}, {
       0.92756630136035, -0.3736586096702163, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008348524470770927, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.003396241887040037, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.805189291079195`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06643676951656123, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3736586096702163, -0.92756630136035, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.151437642763765, 2.6204202530124365`, 0.}, 
      Optica`Optica`RayEnd :> {6.022441816341458, 2.3231662784791007`, 0.}, 
      RotationMatrix :> {{-0.3980900499464742, -0.9173463425193411, 0.}, {
       0.9173463425193411, -0.3980900499464742, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008324924162037084, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3240368013208358, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.284763757034032`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3165687988328613, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3980900499464742, -0.9173463425193411, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.954758455371051, 3.344437558261244, 0.}, 
      Optica`Optica`RayEnd :> {5.920544336604041, 3.3340937605348855`, 0.}, 
      RotationMatrix :> {{-0.9572114708667486, -0.2893893571662825, 0.}, {
       0.2893893571662825, -0.9572114708667486, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037341050774322045`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03574353192406814, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.81623753043224, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2944749349077164, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9572114708667486, -0.2893893571662825, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.920544336604041, 3.3340937605348855`, 0.}, 
      Optica`Optica`RayEnd :> {5.6701500886058795`, 3.255165769425571, 0.}, 
      RotationMatrix :> {{-0.9537399007267549, -0.30063300178409974`, 0.}, {
       0.30063300178409974`, -0.9537399007267549, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037246420574836535`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2625393441202988, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.20479575973028, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09603641027115631, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9537399007267549, -0.30063300178409974`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.848099970795353, 3.4606262406768167`, 0.}, 
      Optica`Optica`RayEnd :> {5.763727798657249, 3.5880340962695576`, 0.}, 
      RotationMatrix :> {{-0.5521315127176641, 0.8337570345514949, 
       0.}, {-0.8337570345514949, -0.5521315127176641, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1544981054724472`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15281173089145536`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.206535661171742`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29350846887258425`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5521315127176641, 0.8337570345514949, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.763727798657249, 3.5880340962695576`, 0.}, 
      Optica`Optica`RayEnd :> {5.624661889022492, 3.837040565238847, 0.}, 
      RotationMatrix :> {{-0.4875948647352788, 0.8730700131626237, 
       0.}, {-0.8730700131626237, -0.4875948647352788, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1474144156040729`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2852079045382443, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.628643359888343`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21674423622453948`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.4875948647352788, 0.8730700131626237, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.601745336365228, 3.5938447090001717`, 0.}, 
      Optica`Optica`RayEnd :> {6.624242981949835, 3.610254629137234, 0.}, 
      RotationMatrix :> {{0.8079154276406527, 0.5892984488187795, 
       0.}, {-0.5892984488187795, 0.8079154276406527, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008235611584305526, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.027846535435406484`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.444583061289038`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4098168330640591, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8079154276406527, 0.5892984488187795, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.624242981949835, 3.610254629137234, 0.}, 
      Optica`Optica`RayEnd :> {6.882779322650426, 3.811935048904515, 0.}, 
      RotationMatrix :> {{0.7884696577494501, 0.61507365315746, 
       0.}, {-0.61507365315746, 0.7884696577494501, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008210805481025828, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32789637262458154`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.92986969277342, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31556536173977406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7884696577494501, 0.61507365315746, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.434749207937504, 2.0885718099516564`, 0.}, 
      Optica`Optica`RayEnd :> {5.164801340599267, 1.9604416019457573`, 0.}, 
      RotationMatrix :> {{-0.9034007186940066, -0.4287973197947387, 0.}, {
       0.4287973197947387, -0.9034007186940066, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03613259581610135, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29881298714095006`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.72768133418602, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42475087657213983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9034007186940066, -0.4287973197947387, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.164801340599267, 1.9604416019457573`, 0.}, 
      Optica`Optica`RayEnd :> {4.946889611226584, 1.869578185063331, 0.}, 
      RotationMatrix :> {{-0.9229763465958096, -0.3848566793296579, 0.}, {
       0.3848566793296579, -0.9229763465958096, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03599695695836152, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23609676475069027`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.07710454601704, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3663437208438175, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9229763465958096, -0.3848566793296579, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.048061583993393, 2.8023330118719088`, 0.}, 
      Optica`Optica`RayEnd :> {5.8591954719604376`, 2.793861627005079, 0.}, 
      RotationMatrix :> {{-0.9989955783992226, -0.04480886451140724, 0.}, {
       0.04480886451140724, -0.9989955783992226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040714790634765664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18905600396709665`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.644671509667077`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43185728692092806`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9989955783992226, -0.04480886451140724, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8591954719604376`, 2.793861627005079, 0.}, 
      Optica`Optica`RayEnd :> {5.542744171328283, 2.780874315517512, 0.}, 
      RotationMatrix :> {{-0.9991589020922901, -0.04100595529588886, 0.}, {
       0.04100595529588886, -0.9991589020922901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04061414788246977, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3167176912195738, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.113413692672047`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.038677117416907394`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9991589020922901, -0.04100595529588886, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.116955393542976, 3.2735007709854105`, 0.}, 
      Optica`Optica`RayEnd :> {6.07412909135062, 3.3820288297901584`, 0.}, 
      RotationMatrix :> {{-0.3670647837153119, 0.9301953797756847, 
       0.}, {-0.9301953797756847, -0.3670647837153119, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16169874132850273`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11667232622776416`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.78506487092567, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13575788167523348`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3670647837153119, 0.9301953797756847, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.07412909135062, 3.3820288297901584`, 0.}, 
      Optica`Optica`RayEnd :> {5.974551438823336, 3.606204375382554, 0.}, 
      RotationMatrix :> {{-0.40594808017870554`, 0.9138961408164618, 
       0.}, {-0.9138961408164618, -0.40594808017870554`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1611439538202129, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24529652285446835`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.148103724750282`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26604385072503045`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.40594808017870554`, 0.9138961408164618, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.420110121692732, 3.3141384967822844`, 0.}, 
      Optica`Optica`RayEnd :> {6.428544256025292, 3.3722030476344838`, 0.}, 
      RotationMatrix :> {{0.14374592711972045`, 0.9896146262240119, 
       0.}, {-0.9896146262240119, 0.14374592711972045`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027542077323656298`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058673901247550696`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.713506433213063`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36166095170921575`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14374592711972045`, 0.9896146262240119, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.428544256025292, 3.3722030476344838`, 0.}, 
      Optica`Optica`RayEnd :> {6.475677707174433, 3.668722634526091, 0.}, 
      RotationMatrix :> {{0.15698472216016346`, 0.9876010312916319, 
       0.}, {-0.9876010312916319, 0.15698472216016346`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027471709648714253`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30024228154541766`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.15786500990028, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23677962853672294`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15698472216016346`, 0.9876010312916319, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.282525643195672, -0.9400201055250266, 0.}, 
      Optica`Optica`RayEnd :> {8.289914658878898, -1.0829276038966589`, 0.}, 
      RotationMatrix :> {{0.0516359088769905, -0.9986659766480712, 0.}, {
       0.9986659766480712, 0.0516359088769905, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25333164685466586`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1430983949721486, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.69625867493661, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15246406641523658`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0516359088769905, -0.9986659766480712, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.289914658878898, -1.0829276038966589`, 0.}, 
      Optica`Optica`RayEnd :> {8.297399842444705, -1.3703794401746636`, 0.}, 
      RotationMatrix :> {{0.02603095952395477, -0.9996611371591181, 0.}, {
       0.9996611371591181, 0.02603095952395477, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2526215490268054, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2875492760425778, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.121831603479627`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1274746000844721, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.02603095952395477, -0.9996611371591181, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.860004043903626, -0.5846922603434024, 0.}, 
      Optica`Optica`RayEnd :> {6.690008009051376, -0.6315445677566753, 0.}, 
      RotationMatrix :> {{-0.9640553232453094, -0.26570158773026104`, 0.}, {
       0.26570158773026104`, -0.9640553232453094, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06554634650493328, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1763343147984393, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.996098355866827`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23443674854003382`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9640553232453094, -0.26570158773026104`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.690008009051376, -0.6315445677566753, 0.}, 
      Optica`Optica`RayEnd :> {6.443488422529625, -0.6741042190569693, 0.}, 
      RotationMatrix :> {{-0.9854224271073452, -0.1701253659918721, 0.}, {
       0.1701253659918721, -0.9854224271073452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06491907621816267, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2501664055337123, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.36634463605672, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3920039755703967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9854224271073452, -0.1701253659918721, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.404594217038392, -1.5717003663107687`, 0.}, 
      Optica`Optica`RayEnd :> {6.259408443254719, -2.061249027219967, 0.}, 
      RotationMatrix :> {{-0.2843301392285424, -0.9587264322664087, 0.}, {
       0.9587264322664087, -0.2843301392285424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022903967572892772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5106239323681893, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.00368377919351, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30190410272754625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2843301392285424, -0.9587264322664087, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.259408443254719, -2.061249027219967, 0.}, 
      Optica`Optica`RayEnd :> {6.183785132830618, -2.3608905041613863`, 0.}, 
      RotationMatrix :> {{-0.2447062895083108, -0.9695972524069331, 0.}, {
       0.9695972524069331, -0.2447062895083108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022826583892989208`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3090370524437728, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.46105861681029, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40719917782648263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2447062895083108, -0.9695972524069331, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.381736509769126, -2.6609417351921207`, 0.}, 
      Optica`Optica`RayEnd :> {7.380574323379593, -2.669444910492241, 0.}, 
      RotationMatrix :> {{-0.13541776719137386`, -0.990788589119244, 0.}, {
       0.990788589119244, -0.13541776719137386`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18314861879873123`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008582229744570586, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.50605966395886, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.054433685649638255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.13541776719137386`, -0.990788589119244, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.380574323379593, -2.669444910492241, 0.}, 
      Optica`Optica`RayEnd :> {7.329947657622755, -2.9378162837687634`, 0.}, 
      RotationMatrix :> {{-0.18537447331988607`, -0.9826679523833949, 0.}, {
       0.9826679523833949, -0.18537447331988607`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18243289297965154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27310483935657565`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.910254826206593`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13038623708287855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.18537447331988607`, -0.9826679523833949, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.337253499543261, 2.5050236894144997`, 0.}, 
      Optica`Optica`RayEnd :> {4.292422481352895, 2.6380683363991775`, 0.}, 
      RotationMatrix :> {{-0.3193210859054464, 0.9476465818522037, 
       0.}, {-0.9476465818522037, -0.3193210859054464, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009320543196703987, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14039479435955748`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.426444364184416`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.186863801493845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3193210859054464, 0.9476465818522037, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.292422481352895, 2.6380683363991775`, 0.}, 
      Optica`Optica`RayEnd :> {4.1955955310933275`, 2.9430773810869217`, 0.}, 
      RotationMatrix :> {{-0.3025753911695591, 0.9531254548371831, 
       0.}, {-0.9531254548371831, -0.3025753911695591, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009296105364908028, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3200093367980051, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.900058182645463`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42014331123749876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3025753911695591, 0.9531254548371831, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4621819624918184`, 1.1524391197069026`, 0.},
       Optica`Optica`RayEnd :> {3.3656486830671053`, 1.1633589103542972`, 0.},
       RotationMatrix :> {{-0.993662750169364, 0.11240257526344834`, 
       0.}, {-0.11240257526344834`, -0.993662750169364, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03102927905721432, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09714893650613302, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.564736982568032`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05250296593163904, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.993662750169364, 0.11240257526344834`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3656486830671053`, 1.1633589103542972`, 0.},
       Optica`Optica`RayEnd :> {3.1615855378483713`, 1.207032031787801, 0.}, 
      RotationMatrix :> {{-0.9778560797788836, 0.20927849206135068`, 
       0.}, {-0.20927849206135068`, -0.9778560797788836, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03073100693773136, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20868423220815616`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.873589646236102`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24858045863710684`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9778560797788836, 0.20927849206135068`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6118972978118684`, 0.16418018278816915`, 
       0.}, Optica`Optica`RayEnd :> {3.5755001570220437`, 0.08372018670784769,
        0.}, RotationMatrix :> {{-0.4121544383350768, -0.9111139988830688, 
       0.}, {0.9111139988830688, -0.4121544383350768, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24257121959396685`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08830947189809074, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.800243418046225`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17490384175741275`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4121544383350768, -0.9111139988830688, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5755001570220437`, 0.08372018670784769, 0.},
       Optica`Optica`RayEnd :> {3.4410452598506835`, -0.18049458499323162`, 
       0.}, RotationMatrix :> {{-0.4535371941517372, -0.8912373497116066, 
       0.}, {0.8912373497116066, -0.4535371941517372, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24169118025090436`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29645836968858613`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.23900180518533, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27572215856844484`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4535371941517372, -0.8912373497116066, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.08319075266063, -0.12669712854553145`, 0.}, 
      Optica`Optica`RayEnd :> {4.043580714792697, -0.35473242622201256`, 0.}, 
      RotationMatrix :> {{-0.17113871897334665`, -0.9852469430899855, 0.}, {
       0.9852469430899855, -0.17113871897334665`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024362173054340373`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23144989109157166`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.17389607287429, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04372800066416959, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17113871897334665`, -0.9852469430899855, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.043580714792697, -0.35473242622201256`, 0.},
       Optica`Optica`RayEnd :> {3.9852894961017116`, -0.6460686592447719, 0.},
       RotationMatrix :> {{-0.1961937153598228, -0.9805651564548417, 0.}, {
       0.9805651564548417, -0.1961937153598228, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02429397479168017, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2971105296827628, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.61361965680478, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2320052385474224, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1961937153598228, -0.9805651564548417, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.552047754432303, -0.6922139549788413, 0.}, 
      Optica`Optica`RayEnd :> {4.51316159899305, -0.8138720656466969, 0.}, 
      RotationMatrix :> {{-0.30446008641579947`, -0.9525250945669006, 0.}, {
       0.9525250945669006, -0.30446008641579947`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009097347719530306, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12772168561414302`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.13079079675838, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24913865691997217`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.30446008641579947`, -0.9525250945669006, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.51316159899305, -0.8138720656466969, 0.}, 
      Optica`Optica`RayEnd :> {4.43125834980598, -1.0992574212415742`, 0.}, 
      RotationMatrix :> {{-0.27585618264631917`, -0.9611989213975428, 0.}, {
       0.9611989213975428, -0.27585618264631917`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00907068872064511, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2969056136475255, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.570211104956716`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4244296644080807, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.27585618264631917`, -0.9611989213975428, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6709939753795493`, 1.8909537908995016`, 0.},
       Optica`Optica`RayEnd :> {2.4586418271341675`, 2.389602901024031, 0.}, 
      RotationMatrix :> {{-0.3918067224619082, 0.9200475488982383, 
       0.}, {-0.9200475488982383, -0.3918067224619082, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012556390690574295`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5419818907421298, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.999545090989802`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3612034305076296, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3918067224619082, 0.9200475488982383, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4586418271341675`, 2.389602901024031, 0.}, 
      Optica`Optica`RayEnd :> {2.3767600525366226`, 2.6307316791079334`, 0.}, 
      RotationMatrix :> {{-0.32154363381967604`, 0.9468947626584683, 
       0.}, {-0.9468947626584683, -0.32154363381967604`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01247986905247673, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25465214044158146`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.376430258843342`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2955410813216125, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.32154363381967604`, 0.9468947626584683, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3688715306818175`, 1.0498166231520185`, 0.},
       Optica`Optica`RayEnd :> {2.1586051450993393`, 0.9757481031880711, 0.}, 
      RotationMatrix :> {{-0.9431916837700561, -0.33224907474213605`, 0.}, {
       0.33224907474213605`, -0.9431916837700561, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23889321070749203`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22293070348332242`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.413273405256398`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39106535582575297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9431916837700561, -0.33224907474213605`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1586051450993393`, 0.9757481031880711, 0.}, 
      Optica`Optica`RayEnd :> {1.8654612149900247`, 0.8885482619526972, 0.}, 
      RotationMatrix :> {{-0.9584926323213071, -0.2851172982927738, 0.}, {
       0.2851172982927738, -0.9584926323213071, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23797549081717562`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3058384803640791, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.865914356195233`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.332456445176114, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9584926323213071, -0.2851172982927738, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6840645451323115`, 0.07101065378714078, 0.},
       Optica`Optica`RayEnd :> {2.636307215419951, -0.16676976387992273`, 0.},
       RotationMatrix :> {{-0.1969139376258959, -0.9804207776096261, 0.}, {
       0.9804207776096261, -0.1969139376258959, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011543135077166946`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24252894583364326`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.21381914740675, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2673897909783519, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1969139376258959, -0.9804207776096261, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.636307215419951, -0.16676976387992273`, 0.},
       Optica`Optica`RayEnd :> {2.6361714884051755`, -0.33417672375082363`, 
       0.}, RotationMatrix :> {{-0.000810760617549533, -0.999999671333556, 
       0.}, {0.999999671333556, -0.000810760617549533, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010851675001839178`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16740701489196907`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.461581529446864`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2667043537664936, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.000810760617549533, -0.999999671333556, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2306487365576024`, -0.434011017903535, 0.}, 
      Optica`Optica`RayEnd :> {2.2415014762410768`, -0.5362599279497503, 0.}, 
      RotationMatrix :> {{0.10554752218691077`, -0.994414260034621, 0.}, {
       0.994414260034621, 0.10554752218691077`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008125135984197411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10282325400548396`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.52562060945147, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1880458124487504, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10554752218691077`, -0.994414260034621, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2415014762410768`, -0.5362599279497503, 0.},
       Optica`Optica`RayEnd :> {2.2680396580060287`, -0.8580522163487847, 0.},
       RotationMatrix :> {{0.082190883944062, -0.9966166056194794, 0.}, {
       0.9966166056194794, 0.082190883944062, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008102817684153265, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3228847347963, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.003490016949993`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10960622008288345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.082190883944062, -0.9966166056194794, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.5064694967424925`, -4.068756492661345, 0.}, 
      Optica`Optica`RayEnd :> {7.578285539175333, -4.251879845857825, 0.}, 
      RotationMatrix :> {{0.36510058327889333`, -0.9309680789852094, 0.}, {
       0.9309680789852094, 0.36510058327889333`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008307926646532274, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19670207532366912`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.135311803568467`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09630785352300217, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.36510058327889333`, -0.9309680789852094, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.578285539175333, -4.251879845857825, 0.}, 
      Optica`Optica`RayEnd :> {7.671016338206515, -4.418310300182402, 0.}, 
      RotationMatrix :> {{0.4867232275226071, -0.8735562373367702, 0.}, {
       0.8735562373367702, 0.4867232275226071, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00814390780893489, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19052059525323364`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.41728228454325, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3866084871337704, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4867232275226071, -0.8735562373367702, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.301734612303231, 2.9715636864263844`, 0.}, 
      Optica`Optica`RayEnd :> {2.15678870259673, 2.953924326936628, 0.}, 
      RotationMatrix :> {{-0.9926762716654618, -0.12080488265114837`, 0.}, {
       0.12080488265114837`, -0.9926762716654618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2883556225704925, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14601528599380956`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.033494025475118`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38820002512029717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9926762716654618, -0.12080488265114837`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.15678870259673, 2.953924326936628, 0.}, 
      Optica`Optica`RayEnd :> {1.905450895359237, 2.9302119632853034`, 0.}, 
      RotationMatrix :> {{-0.995579039798007, -0.09392750137674251, 0.}, {
       0.09392750137674251, -0.995579039798007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28753592812209033`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25245389586394545`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.407125791353756`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1697552126022934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.995579039798007, -0.09392750137674251, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.926853849632756, 3.6996533119034503`, 0.}, 
      Optica`Optica`RayEnd :> {5.06111150636273, 3.728195983954255, 0.}, 
      RotationMatrix :> {{0.9781397085355926, 0.20794881722651154`, 
       0.}, {-0.20794881722651154`, 0.9781397085355926, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03211762285383692, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13725816011597783`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.3432628978558, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09500645166121784, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9781397085355926, 0.20794881722651154`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.06111150636273, 3.728195983954255, 0.}, 
      Optica`Optica`RayEnd :> {5.403187952588996, 3.800301315581602, 0.}, 
      RotationMatrix :> {{0.9784982959218707, 0.20625490267626237`, 
       0.}, {-0.20625490267626237`, 0.9784982959218707, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03203841564892293, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34959329786464916`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.86066097869548, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3665540732785064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9784982959218707, 0.20625490267626237`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.08493018736672, 3.4665318756219445`, 0.}, 
      Optica`Optica`RayEnd :> {7.373505533449265, 3.4332706036957727`, 0.}, 
      RotationMatrix :> {{0.9934229944521727, -0.11450220126127418`, 0.}, {
       0.11450220126127418`, 0.9934229944521727, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02175486062377545, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2904858732826903, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.011366375713987`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15851277062347668`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9934229944521727, -0.11450220126127418`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.373505533449265, 3.4332706036957727`, 0.}, 
      Optica`Optica`RayEnd :> {7.657254405218824, 3.413101570340565, 0.}, 
      RotationMatrix :> {{0.9974833084155922, -0.0709016885009356, 0.}, {
       0.0709016885009356, 0.9974833084155922, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021678417844706352`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2844647818922069, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.432374252914453`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27513330192645297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9974833084155922, -0.0709016885009356, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8423809303975185`, 1.5972051673966625`, 0.},
       Optica`Optica`RayEnd :> {6.845562438732375, 1.5952906131564648`, 0.}, 
      RotationMatrix :> {{0.8568209845663062, -0.515614003307537, 0.}, {
       0.515614003307537, 0.8568209845663062, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011154716645471472`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0037131540802158506`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.19872087519665, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28745428280240115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8568209845663062, -0.515614003307537, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.845562438732375, 1.5952906131564648`, 0.}, 
      Optica`Optica`RayEnd :> {7.078171501620103, 1.4531793955188055`, 0.}, 
      RotationMatrix :> {{0.8533451043439757, -0.5213464614746782, 0.}, {
       0.5213464614746782, 0.8533451043439757, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011126973395551534`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27258498549253396`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.6021466537256, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26679252274759024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8533451043439757, -0.5213464614746782, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.358079660061334, 3.168928479704756, 0.}, 
      Optica`Optica`RayEnd :> {7.592570358476737, 3.3241435725362685`, 0.}, 
      RotationMatrix :> {{0.8338709518205207, 0.5519594511464933, 
       0.}, {-0.5519594511464933, 0.8338709518205207, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.14475051422345883`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28120741932964405`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.09589349581647, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21046700974563964`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8338709518205207, 0.5519594511464933, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.592570358476737, 3.3241435725362685`, 0.}, 
      Optica`Optica`RayEnd :> {7.76948545282574, 3.4087582852440135`, 0.}, 
      RotationMatrix :> {{0.9021279777585824, 0.43146855244062665`, 
       0.}, {-0.43146855244062665`, 0.9021279777585824, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.14166595628413695`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19610864390722574`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.386134288799163`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1379458335733581, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9021279777585824, 0.43146855244062665`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.913412393865279, 0.6424620335464204, 0.}, 
      Optica`Optica`RayEnd :> {6.966790918559761, 0.6114333462384633, 0.}, 
      RotationMatrix :> {{0.8645447561851359, -0.5025558322741694, 0.}, {
       0.5025558322741694, 0.8645447561851359, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09327772675433729, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06174177139193824, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.402338225913933`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33409621574196025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8645447561851359, -0.5025558322741694, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.966790918559761, 0.6114333462384633, 0.}, 
      Optica`Optica`RayEnd :> {7.159514962471937, 0.47210629384999775`, 0.}, 
      RotationMatrix :> {{0.8104047751287944, -0.5858703785381605, 0.}, {
       0.5858703785381605, 0.8104047751287944, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09235911634911008, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23781207839199622`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.75430010193409, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40274039196553957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8104047751287944, -0.5858703785381605, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.223831140464143, 0.6062246397799318, 0.}, 
      Optica`Optica`RayEnd :> {5.25788395479941, 0.40047914863717937`, 0.}, 
      RotationMatrix :> {{0.16328801359094808`, -0.9865784432155008, 0.}, {
       0.9865784432155008, 0.16328801359094808`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04763394442576827, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2085444827602125, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.718720689322648`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11128472568575565`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.16328801359094808`, -0.9865784432155008, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.25788395479941, 0.40047914863717937`, 0.}, 
      Optica`Optica`RayEnd :> {5.2919813439335, 0.11115117115553971`, 0.}, 
      RotationMatrix :> {{0.11704033464006319`, -0.9931271620831548, 0.}, {
       0.9931271620831548, 0.11704033464006319`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04745898715223935, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2913302430222062, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.149889448995513`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005084499066106306, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.11704033464006319`, -0.9931271620831548, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5400266537753016`, 0.8584285114380503, 0.}, 
      Optica`Optica`RayEnd :> {3.418791294547206, 0.7379370981728014, 0.}, 
      RotationMatrix :> {{-0.7092796363126475, -0.7049272285223469, 0.}, {
       0.7049272285223469, -0.7092796363126475, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033614228463448755`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17092744951534972`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.336025201673966`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4131063989225416, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7092796363126475, -0.7049272285223469, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.418791294547206, 0.7379370981728014, 0.}, 
      Optica`Optica`RayEnd :> {3.2337022530914274`, 0.5807779500679296, 0.}, 
      RotationMatrix :> {{-0.7622776705350989, -0.6472501471638163, 0.}, {
       0.6472501471638163, -0.7622776705350989, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03339658625640332, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24281052510150344`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.69538477882419, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34493088612662637`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7622776705350989, -0.6472501471638163, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.58339473401461, 2.2758211254393754`, 0.}, 
      Optica`Optica`RayEnd :> {3.4639266872794554`, 2.343108263921816, 0.}, 
      RotationMatrix :> {{-0.8713062675992993, 0.4907396336573778, 
       0.}, {-0.4907396336573778, -0.8713062675992993, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035961713726436834`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1371137235869123, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.89085330129418, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27240695222391803`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8713062675992993, 0.4907396336573778, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4639266872794554`, 2.343108263921816, 0.}, 
      Optica`Optica`RayEnd :> {3.419021162144573, 2.3521030916458017`, 0.}, 
      RotationMatrix :> {{-0.9805230105928674, 0.1964042405293196, 
       0.}, {-0.1964042405293196, -0.9805230105928674, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02528997250968048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.045797523005330194`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.952221982121323`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38100426459125786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9805230105928674, 0.1964042405293196, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.345772548463666, 0.9347785088876049, 0.}, 
      Optica`Optica`RayEnd :> {2.1109418660443935`, 0.8813486848297772, 0.}, 
      RotationMatrix :> {{-0.9750796919137752, -0.22185489495915298`, 0.}, {
       0.22185489495915298`, -0.9750796919137752, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0863446045109698, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2408322974693211, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.45421575020577, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12911044878720043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9750796919137752, -0.22185489495915298`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1109418660443935`, 0.8813486848297772, 0.}, 
      Optica`Optica`RayEnd :> {2.001820259253169, 0.8322686305099309, 0.}, 
      RotationMatrix :> {{-0.9119986429370895, -0.41019321700987044`, 0.}, {
       0.41019321700987044`, -0.9119986429370895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08104188262691892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11965106268118829`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.61454817419856, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22333767204424324`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9119986429370895, -0.41019321700987044`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5719528092812887`, -0.3436921906763729, 0.},
       Optica`Optica`RayEnd :> {3.540315837718936, -0.3666346889023103, 0.}, 
      RotationMatrix :> {{-0.8095412005186755, -0.587063067023281, 0.}, {
       0.587063067023281, -0.8095412005186755, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020276015012280636`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.039080125313057004`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.148008652646812`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2128213487562865, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8095412005186755, -0.587063067023281, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.540315837718936, -0.3666346889023103, 0.}, 
      Optica`Optica`RayEnd :> {3.381604823976741, -0.45247289711526967`, 0.}, 
      RotationMatrix :> {{-0.8795941161068204, -0.4757249109624818, 0.}, {
       0.4757249109624818, -0.8795941161068204, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019897858517167778`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1804366478082729, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.389793760709896`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2376449881890385, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8795941161068204, -0.4757249109624818, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.96350433554662, -3.6571197780856823`, 0.}, 
      Optica`Optica`RayEnd :> {5.966474220943696, -3.8299795327438115`, 0.}, 
      RotationMatrix :> {{0.017178360398971373`, -0.9998524410801838, 0.}, {
       0.9998524410801838, 0.017178360398971373`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008052447493641963, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.172885265421147, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.190189977932317`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2653737343136274, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.017178360398971373`, -0.9998524410801838, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.966474220943696, -3.8299795327438115`, 0.}, 
      Optica`Optica`RayEnd :> {5.972389363345108, -4.14210818712324, 0.}, 
      RotationMatrix :> {{0.01894757313664845, -0.9998204786221527, 0.}, {
       0.9998204786221527, 0.01894757313664845, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00803258833253827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31218469820659317`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.652223331278073`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24912743632861215`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.01894757313664845, -0.9998204786221527, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.361821664728799, -0.379995678727669, 0.}, 
      Optica`Optica`RayEnd :> {7.361840882167571, -0.3800627190973369, 0.}, 
      RotationMatrix :> {{0.27555682594912473`, -0.9612847838558786, 0.}, {
       0.9612847838558786, 0.27555682594912473`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012311030817442746`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00006974038369671678, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.247618533148973`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32670199402627537`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.27555682594912473`, -0.9612847838558786, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.361840882167571, -0.3800627190973369, 0.}, 
      Optica`Optica`RayEnd :> {7.449908629578593, -0.6290946221239575, 0.}, 
      RotationMatrix :> {{0.3334062676755047, -0.9427832522243325, 0.}, {
       0.9427832522243325, 0.3334062676755047, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012253810099394923`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26414544640994975`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.638553793835698`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32306166742378556`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3334062676755047, -0.9427832522243325, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8735678907445887`, 1.9718076657689771`, 0.},
       Optica`Optica`RayEnd :> {3.7775506922884885`, 1.9421761779742046`, 0.},
       RotationMatrix :> {{-0.9555332624427406, -0.29488334026447, 0.}, {
       0.29488334026447, -0.9555332624427406, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018060993525520194`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10048545898929809`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.74003964185488, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23140427267455219`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9555332624427406, -0.29488334026447, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7775506922884885`, 1.9421761779742046`, 0.},
       Optica`Optica`RayEnd :> {3.6290617411838237`, 1.8597836212114276`, 0.},
       RotationMatrix :> {{-0.874410412562537, -0.485187005599091, 0.}, {
       0.485187005599091, -0.874410412562537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016796250386695615`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1698160828957931, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.991367444540657`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24635635303624326`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.874410412562537, -0.485187005599091, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.888508547977647, 2.4429143369798125`, 0.}, 
      Optica`Optica`RayEnd :> {5.767552045297535, 2.3071249030370566`, 0.}, 
      RotationMatrix :> {{-0.6651461404011543, -0.7467132059294563, 0.}, {
       0.7467132059294563, -0.6651461404011543, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010686138660700773`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18184951446484035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.972308822935872`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01371941215994596, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6651461404011543, -0.7467132059294563, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.767552045297535, 2.3071249030370566`, 0.}, 
      Optica`Optica`RayEnd :> {5.615425364229257, 2.1304326170238865`, 0.}, 
      RotationMatrix :> {{-0.6524615402765672, -0.7578218382046853, 0.}, {
       0.7578218382046853, -0.6524615402765672, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010658263821516021`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2331580816300594, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.31738278374836, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32217812862911277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6524615402765672, -0.7578218382046853, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.613073684194516, 1.9149759269957787`, 0.}, 
      Optica`Optica`RayEnd :> {7.628545758690353, 1.8475056952641078`, 0.}, 
      RotationMatrix :> {{0.2235154188146933, -0.9747003937375274, 0.}, {
       0.9747003937375274, 0.2235154188146933, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010053932046359442`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06922150864529095, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.863091428048, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31143274742071214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2235154188146933, -0.9747003937375274, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.628545758690353, 1.8475056952641078`, 0.}, 
      Optica`Optica`RayEnd :> {7.713787371339179, 1.570713499858081, 0.}, 
      RotationMatrix :> {{0.29432171939134344`, -0.9557064013045649, 0.}, {
       0.9557064013045649, 0.29432171939134344`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009994875061707703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2896205309791773, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.291729813897184`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36710539145247967`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.29432171939134344`, -0.9557064013045649, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4349281815717845`, 0.8897875450281161, 0.}, 
      Optica`Optica`RayEnd :> {7.4265704102400125`, 0.6412175565394289, 0.}, 
      RotationMatrix :> {{-0.033604422692884536`, -0.9994352118949364, 0.}, {
       0.9994352118949364, -0.033604422692884536`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012652570200471572`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2487104571965166, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.518719712599097`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3333316026936311, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.033604422692884536`, -0.9994352118949364, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.4265704102400125`, 0.6412175565394289, 0.}, 
      Optica`Optica`RayEnd :> {7.405720745714707, 0.28962841116119903`, 0.}, 
      RotationMatrix :> {{-0.059197221765541985`, -0.9982463067476082, 0.}, {
       0.9982463067476082, -0.059197221765541985`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01261710592430744, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3522068080810077, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.990676835427646`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3750412161586659, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.059197221765541985`, -0.9982463067476082, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7061559660456895`, 1.6302363202035928`, 0.},
       Optica`Optica`RayEnd :> {3.5630614227640534`, 1.590029904485815, 0.}, 
      RotationMatrix :> {{-0.9627191639699857, -0.2705028859826277, 0.}, {
       0.2705028859826277, -0.9627191639699857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010116426662495704`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14863581056343989`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.19142092263539, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1323215166263694, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9627191639699857, -0.2705028859826277, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5630614227640534`, 1.590029904485815, 0.}, 
      Optica`Optica`RayEnd :> {3.3243323955771182`, 1.5094446611867771`, 0.}, 
      RotationMatrix :> {{-0.9474752060920884, -0.3198292260578346, 0.}, {
       0.3198292260578346, -0.9474752060920884, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010076230151400516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2519633502301189, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.564326680975967`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06395695819730429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9474752060920884, -0.3198292260578346, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9882413674549433`, 3.6907620563599965`, 0.},
       Optica`Optica`RayEnd :> {2.8913015105007416`, 3.7208958175518165`, 0.},
       RotationMatrix :> {{-0.9549274580843691, 0.29683926592774856`, 
       0.}, {-0.29683926592774856`, -0.9549274580843691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028163532390573003`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10151541474016001`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.551514054171566`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35769053445700855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9549274580843691, 0.29683926592774856`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8913015105007416`, 3.7208958175518165`, 0.},
       Optica`Optica`RayEnd :> {2.553007083039228, 3.824253879775438, 0.}, 
      RotationMatrix :> {{-0.956359217959928, 0.2921935081809215, 
       0.}, {-0.2921935081809215, -0.956359217959928, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02809378635381146, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.353731548887197, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.075036746524617`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16816212982258202`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.956359217959928, 0.2921935081809215, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.417849472132508, -1.058102453305081, 0.}, 
      Optica`Optica`RayEnd :> {3.3495126332599936`, -1.148684791261067, 0.}, 
      RotationMatrix :> {{-0.6022542289365352, -0.7983043553232425, 0.}, {
       0.7983043553232425, -0.6022542289365352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01214396761602647, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11346842510875207`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.789282391325642`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2198971986316589, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6022542289365352, -0.7983043553232425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3495126332599936`, -1.148684791261067, 0.}, 
      Optica`Optica`RayEnd :> {3.1502362259938024`, -1.3957048186924736`, 0.},
       RotationMatrix :> {{-0.6278797980688219, -0.7783103231854591, 0.}, {
       0.7783103231854591, -0.6278797980688219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012107295987815172`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31737986773759597`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.259004595577284`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3923718369870991, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6278797980688219, -0.7783103231854591, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4346059552727373`, -0.17662184558167104`, 
       0.}, Optica`Optica`RayEnd :> {2.416036833516986, -0.22044205134953043`,
        0.}, RotationMatrix :> {{-0.39017108637467096`, -0.9207423762145461, 
       0.}, {0.9207423762145461, -0.39017108637467096`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012241230207459314`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04759225479337407, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.486880636100175`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3080928216644907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39017108637467096`, -0.9207423762145461, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.416036833516986, -0.22044205134953043`, 0.},
       Optica`Optica`RayEnd :> {2.3009531280733664`, -0.43534944114653396`, 
       0.}, RotationMatrix :> {{-0.47207716973739045`, -0.8815572277582067, 
       0.}, {0.8815572277582067, -0.47207716973739045`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0121397315140795, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24378155272291438`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.847677334130086`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1569987779615445, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.47207716973739045`, -0.8815572277582067, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.34509924734631, -2.079337547647544, 0.}, 
      Optica`Optica`RayEnd :> {4.312866981451187, -2.0787705044848455`, 0.}, 
      RotationMatrix :> {{-0.9998452895060842, 0.017589685969188626`, 
       0.}, {-0.017589685969188626`, -0.9998452895060842, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01951665515940765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03223725333650933, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.344186923518233`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026270956288119332`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9998452895060842, 0.017589685969188626`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.312866981451187, -2.0787705044848455`, 0.}, 
      Optica`Optica`RayEnd :> {4.126212024936174, -2.1067733899757095`, 0.}, 
      RotationMatrix :> {{-0.9889327446168814, -0.14836450594573464`, 0.}, {
       0.14836450594573464`, -0.9889327446168814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01882252703547951, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18874383271364312`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.623527795934425`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35935148224696367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9889327446168814, -0.14836450594573464`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.604807374485697, -2.3781584461875953`, 0.}, 
      Optica`Optica`RayEnd :> {5.603160721611645, -2.3777808238799247`, 0.}, 
      RotationMatrix :> {{-0.9746982364379461, 0.22352482610385216`, 
       0.}, {-0.22352482610385216`, -0.9746982364379461, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011482143331641896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001689397613019067, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.96783562806811, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21433690823740337`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9746982364379461, 0.22352482610385216`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.603160721611645, -2.3777808238799247`, 0.}, 
      Optica`Optica`RayEnd :> {5.3692815675533225`, -2.347872509711066, 0.}, 
      RotationMatrix :> {{-0.9919223728749347, 0.12684638816363125`, 
       0.}, {-0.12684638816363125`, -0.9919223728749347, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011371672798873451`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23578372708789622`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.316795544158197`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3784482749077905, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9919223728749347, 0.12684638816363125`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.049286457408408, 0.6750501916120701, 0.}, 
      Optica`Optica`RayEnd :> {8.058839754670561, 0.7528464829549052, 0.}, 
      RotationMatrix :> {{0.12188334235067892`, 0.9925444326867321, 
       0.}, {-0.9925444326867321, 0.12188334235067892`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01322277503487157, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07838066365678686, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.458795319076913`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06989241287478717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.12188334235067892`, 0.9925444326867321, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.058839754670561, 0.7528464829549052, 0.}, 
      Optica`Optica`RayEnd :> {8.11598951992452, 0.901805773284278, 0.}, 
      RotationMatrix :> {{0.3582021527121857, 0.9336440530482458, 
       0.}, {-0.9336440530482458, 0.3582021527121857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01162506070492232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15954612450326974`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.69492358334175, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3831066033530075, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3582021527121857, 0.9336440530482458, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.857304483961946, 1.0785491778117529`, 0.}, 
      Optica`Optica`RayEnd :> {4.747626960664649, 1.1570154792815404`, 0.}, 
      RotationMatrix :> {{-0.8132940846717733, 0.5818528437997893, 
       0.}, {-0.5818528437997893, -0.8132940846717733, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012849079843049296`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1348559215717901, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.159213833553743`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21044710198179672`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8132940846717733, 0.5818528437997893, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.747626960664649, 1.1570154792815404`, 0.}, 
      Optica`Optica`RayEnd :> {4.604221962285013, 1.2840482842581151`, 0.}, 
      RotationMatrix :> {{-0.7485442664776367, 0.6630848219673381, 
       0.}, {-0.6630848219673381, -0.7485442664776367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012710497532463748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19157851419321434`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.4427500345597, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01587916643524523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7485442664776367, 0.6630848219673381, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6677729820998963`, -0.13071392041402335`, 
       0.}, Optica`Optica`RayEnd :> {
       2.6187428803404096`, -0.12258995378609708`, 0.}, 
      RotationMatrix :> {{-0.9865491778753382, 0.16346473513725854`, 
       0.}, {-0.16346473513725854`, -0.9865491778753382, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017117752374642584`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.049698588635063885`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.983026913955555`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1721999555104056, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9865491778753382, 0.16346473513725854`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6187428803404096`, -0.12258995378609706`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3194844998904247`, -0.055999695094600184`, 0.}, 
      RotationMatrix :> {{-0.9761259628159862, 0.21720521337335313`, 
       0.}, {-0.21720521337335313`, -0.9761259628159862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017046098949106227`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3065776260951673, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.436761800576402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12742723894881894`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9761259628159862, 0.21720521337335313`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.199850853875885, -3.9113342055346747`, 0.}, 
      Optica`Optica`RayEnd :> {4.167172969626897, -3.932868198177771, 0.}, 
      RotationMatrix :> {{-0.8350016885656263, -0.5502473808138962, 0.}, {
       0.5502473808138962, -0.8350016885656263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08699476907638912, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03913511157698678, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.265030865214637`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.306567259350702, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8350016885656263, -0.5502473808138962, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.167172969626897, -3.932868198177771, 0.}, 
      Optica`Optica`RayEnd :> {3.9464350153265713`, -4.072481409782038, 0.}, 
      RotationMatrix :> {{-0.8451434075116823, -0.5345396343953763, 0.}, {
       0.5345396343953763, -0.8451434075116823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08676491918242181, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2611840219522444, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.65158321770396, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3374210378795287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8451434075116823, -0.5345396343953763, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2504504448487164`, -3.355483321000886, 0.}, 
      Optica`Optica`RayEnd :> {2.135404990293597, -3.4311843999347778`, 0.}, 
      RotationMatrix :> {{-0.8353728035433183, -0.5496837991974808, 0.}, {
       0.5496837991974808, -0.8353728035433183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03630676333844383, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13771750057835544`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.177877019767994`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3218598943033048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8353728035433183, -0.5496837991974808, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.135404990293597, -3.4311843999347778`, 0.}, 
      Optica`Optica`RayEnd :> {1.8717760217040529`, -3.596276373248007, 0.}, 
      RotationMatrix :> {{-0.8475300229769619, -0.5307474542121425, 0.}, {
       0.5307474542121425, -0.8475300229769619, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03620787450596532, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31105561035294477`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.638239323090353`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34846804336426, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8475300229769619, -0.5307474542121425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.833124009085632, -1.0373182512021093`, 0.}, 
      Optica`Optica`RayEnd :> {2.6662098907927887`, -1.0487093524605482`, 0.},
       RotationMatrix :> {{-0.9976793935544608, -0.06808691266905283, 0.}, {
       0.06808691266905283, -0.9976793935544608, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013616012193963287`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16730236123066894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.624491844127924`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40809546063626817`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9976793935544608, -0.06808691266905283, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6662098907927887`, -1.0487093524605482`, 
       0.}, Optica`Optica`RayEnd :> {2.312220468657105, -1.0674312255994285`, 
       0.}, RotationMatrix :> {{-0.9986043449149646, -0.05281441391281659, 
       0.}, {0.05281441391281659, -0.9986043449149646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013580844600214552`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3544841597558116, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.149128400566525`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09839761371996662, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9986043449149646, -0.05281441391281659, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.323627665433101, -3.3923747599303007`, 0.}, 
      Optica`Optica`RayEnd :> {6.171777647535761, -3.5039883632184616`, 0.}, 
      RotationMatrix :> {{-0.8057543795997262, -0.5922498457204187, 0.}, {
       0.5922498457204187, -0.8057543795997262, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013393669868598643`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18845695629079176`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.399919921118045`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41106624891518406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8057543795997262, -0.5922498457204187, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.171777647535761, -3.5039883632184616`, 0.}, 
      Optica`Optica`RayEnd :> {5.947765141123858, -3.6496665162900763`, 0.}, 
      RotationMatrix :> {{-0.8383238539382697, -0.5451725560940188, 0.}, {
       0.5451725560940188, -0.8383238539382697, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013335137780755424`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26721475878270573`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.795397764116448`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42690378629183534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8383238539382697, -0.5451725560940188, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.396788952294392, -3.863917628126922, 0.}, 
      Optica`Optica`RayEnd :> {7.3970953867840885`, -3.8648666770073263`, 0.},
       RotationMatrix :> {{0.30726586618167195`, -0.9516237110747221, 0.}, {
       0.9516237110747221, 0.30726586618167195`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20478967450020755`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0009972942764665176, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.782737832771364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35630300619569294`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.30726586618167195`, -0.9516237110747221, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.3970953867840885`, -3.8648666770073263`, 
       0.}, Optica`Optica`RayEnd :> {7.474559788528993, -4.071123810438171, 
       0.}, RotationMatrix :> {{0.35159284951882536`, -0.9361530153597925, 
       0.}, {0.9361530153597925, 0.35159284951882536`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20403468454437404`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22032416714651426`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.108817600148203`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2751173148731689, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35159284951882536`, -0.9361530153597925, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.109466376042483, -2.3475363475123796`, 0.}, 
      Optica`Optica`RayEnd :> {7.112100941858732, -2.3818749918280813`, 0.}, 
      RotationMatrix :> {{0.07649823817592728, -0.9970697164972858, 0.}, {
       0.9970697164972858, 0.07649823817592728, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02227088531389559, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03443956199605927, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.497812262771053`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.265406231437242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.07649823817592728, -0.9970697164972858, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.112100941858732, -2.3818749918280813`, 0.}, 
      Optica`Optica`RayEnd :> {7.094646516432469, -2.548964716506338, 0.}, 
      RotationMatrix :> {{-0.10389606482015926`, -0.9945881598505404, 0.}, {
       0.9945881598505404, -0.10389606482015926`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021259099729042108`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16799890791316674`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.74645064648254, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17210214615451272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.10389606482015926`, -0.9945881598505404, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.745581720203257, 2.93105649072293, 0.}, 
      Optica`Optica`RayEnd :> {4.685296765772567, 2.999156445129354, 0.}, 
      RotationMatrix :> {{-0.6628371431104071, 0.7487635953445073, 
       0.}, {-0.7487635953445073, -0.6628371431104071, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008400427483313232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09094987367153033, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.900102945878412`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4281091507152007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6628371431104071, 0.7487635953445073, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.685296765772567, 2.999156445129354, 0.}, 
      Optica`Optica`RayEnd :> {4.516406202241529, 3.153786736063154, 0.}, 
      RotationMatrix :> {{-0.7375587421667732, 0.675282979093481, 
       0.}, {-0.675282979093481, -0.7375587421667732, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008308138995562058, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2289859151216578, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.239002100258467`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2791790926339829, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.7375587421667732, 0.675282979093481, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0950691582980365`, -0.8562053790945715, 0.},
       Optica`Optica`RayEnd :> {5.0876498459533925`, -0.8630842502231568, 0.},
       RotationMatrix :> {{-0.7333102818111602, -0.6798941318985157, 0.}, {
       0.6798941318985157, -0.7333102818111602, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16868884921620195`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.010117562140707113`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.510405386167314`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07861014300807383, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7333102818111602, -0.6798941318985157, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.0876498459533925`, -0.8630842502231568, 0.},
       Optica`Optica`RayEnd :> {4.897134594666521, -1.0567814332362302`, 0.}, 
      RotationMatrix :> {{-0.7012266887331211, -0.71293837812842, 0.}, {
       0.71293837812842, -0.7012266887331211, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16807545660187906`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2716885343184359, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.912504416958598`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18652144281746566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7012266887331211, -0.71293837812842, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.994065167912832, -1.694889300567602, 0.}, 
      Optica`Optica`RayEnd :> {8.063713541240318, -1.7465703138020194`, 0.}, 
      RotationMatrix :> {{0.8030626394513577, -0.5958946191378292, 0.}, {
       0.5958946191378292, 0.8030626394513577, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009235164199183203, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08672844421584516, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.102719398186903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009925796641217203, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8030626394513577, -0.5958946191378292, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.063713541240318, -1.7465703138020194`, 0.}, 
      Optica`Optica`RayEnd :> {8.277153594740588, -1.8841482342927005`, 0.}, 
      RotationMatrix :> {{0.8405214273201772, -0.5417783035667374, 0.}, {
       0.5417783035667374, 0.8405214273201772, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009188077088564358, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25393767078702134`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.478547150951695`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.038986547176246826`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8405214273201772, -0.5417783035667374, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.022441816341458, 2.3231662784791007`, 0.}, 
      Optica`Optica`RayEnd :> {5.941956888865805, 2.150378709482794, 0.}, 
      RotationMatrix :> {{-0.4222422926194505, -0.9064830093959119, 0.}, {
       0.9064830093959119, -0.4222422926194505, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008301390568634113, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19061313582860587`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.540185359044365`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41865930534237367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4222422926194505, -0.9064830093959119, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.941956888865805, 2.150378709482794, 0.}, 
      Optica`Optica`RayEnd :> {5.863954869871214, 1.9176321217127803`, 0.}, 
      RotationMatrix :> {{-0.31776660707684423`, -0.9481689635433492, 0.}, {
       0.9481689635433492, -0.31776660707684423`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008195005765858115, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24546952781520026`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.903480260210863`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21986088142379073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.31776660707684423`, -0.9481689635433492, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.6701500886058795`, 3.255165769425571, 0.}, 
      Optica`Optica`RayEnd :> {5.1265156431039856`, 3.076744775513107, 0.}, 
      RotationMatrix :> {{-0.9501362649413275, -0.3118350173462598, 0.}, {
       0.3118350173462598, -0.9501362649413275, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037152030188491524`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5721647152742501, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.971496478197775`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24000601658690845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9501362649413275, -0.3118350173462598, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1265156431039856`, 3.076744775513107, 0.}, 
      Optica`Optica`RayEnd :> {4.828233618459975, 2.9715138482660324`, 0.}, 
      RotationMatrix :> {{-0.9430350567706494, -0.332693374898835, 0.}, {
       0.332693374898835, -0.9430350567706494, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03705124552272197, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31630003837339227`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.439620534990397`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06570307794150876, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9430350567706494, -0.332693374898835, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.946889611226584, 1.869578185063331, 0.}, 
      Optica`Optica`RayEnd :> {4.81685376611325, 1.822561236102724, 0.}, 
      RotationMatrix :> {{-0.9404162209911077, -0.3400254862459626, 0.}, {
       0.3400254862459626, -0.9404162209911077, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03586182727798118, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13827477898699828`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.262392749859618`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08994369250033289, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9404162209911077, -0.3400254862459626, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.81685376611325, 1.822561236102724, 0.}, 
      Optica`Optica`RayEnd :> {4.56275376786472, 1.7150572909505666`, 0.}, 
      RotationMatrix :> {{-0.9209671213465274, -0.3896402974522657, 0.}, {
       0.3896402974522657, -0.9209671213465274, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03571534524504367, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2759056130874848, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.670733057229096`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03289801894516491, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9209671213465274, -0.3896402974522657, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.542744171328283, 2.780874315517512, 0.}, 
      Optica`Optica`RayEnd :> {5.3812344063793915`, 2.7748615939355155`, 0.}, 
      RotationMatrix :> {{-0.999307749178721, -0.03720245195356709, 0.}, {
       0.03720245195356709, -0.999307749178721, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040513753908650474`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1616216476672258, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.32998670054613, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3191200598589422, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.999307749178721, -0.03720245195356709, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3812344063793915`, 2.7748615939355155`, 0.},
       Optica`Optica`RayEnd :> {5.116889302356681, 2.756812497992865, 0.}, 
      RotationMatrix :> {{-0.9976771396171857, -0.06811993162995192, 0.}, {
       0.06811993162995192, -0.9976771396171857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04039359241338009, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26496057043478116`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.722128344789606`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10845210097262414`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9976771396171857, -0.06811993162995192, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.974551438823336, 3.606204375382554, 0.}, 
      Optica`Optica`RayEnd :> {5.93698715466518, 3.681988704384638, 0.}, 
      RotationMatrix :> {{-0.444109773104113, 0.895972382070682, 
       0.}, {-0.895972382070682, -0.444109773104113, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.160591069784868, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08458333149392293, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.26144538895214, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27148130606596466`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.444109773104113, 0.895972382070682, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.93698715466518, 3.681988704384638, 0.}, 
      Optica`Optica`RayEnd :> {5.78884187988963, 3.9356753447342863`, 0.}, 
      RotationMatrix :> {{-0.5042808865591344, 0.8635396849312325, 
       0.}, {-0.8635396849312325, -0.5042808865591344, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15973254664361652`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2937753119821585, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.696232850685735`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23227969258019304`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5042808865591344, 0.8635396849312325, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.297399842444705, -1.3703794401746636`, 0.}, 
      Optica`Optica`RayEnd :> {8.297504651474537, -1.6266875117243267`, 0.}, 
      RotationMatrix :> {{0.000408918144616216, -0.9999999163929715, 0.}, {
       0.9999999163929715, 0.000408918144616216, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25191344162900536`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2563080929788209, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.465284448071248`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03981292037230377, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.000408918144616216, -0.9999999163929715, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.297504651474537, -1.6266875117243267`, 0.}, 
      Optica`Optica`RayEnd :> {8.281273842308778, -1.8821019026795236`, 0.}, 
      RotationMatrix :> {{-0.06341904332383455, -0.9979869863599868, 0.}, {
       0.9979869863599868, -0.06341904332383455, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.250674451114743, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25592958069201266`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.844060227495426`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02359775129189428, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06341904332383455, -0.9979869863599868, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.443488422529625, -0.6741042190569693, 0.}, 
      Optica`Optica`RayEnd :> {6.362490433178861, -0.6800261468809501, 0.}, 
      RotationMatrix :> {{-0.9973379825359436, -0.07291740938303592, 0.}, {
       0.07291740938303592, -0.9973379825359436, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06429780882909183, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08121418292403663, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.475171641174928`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21376074467518474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9973379825359436, -0.07291740938303592, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.362490433178861, -0.6800261468809501, 0.}, 
      Optica`Optica`RayEnd :> {6.093639983498253, -0.7145902088797783, 0.}, 
      RotationMatrix :> {{-0.9918369065110022, -0.12751294398093427`, 0.}, {
       0.12751294398093427`, -0.9918369065110022, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06402806781700361, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2710631636267163, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.876345123342468`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17132027927708257`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9918369065110022, -0.12751294398093427`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.183785132830618, -2.3608905041613863`, 0.}, 
      Optica`Optica`RayEnd :> {6.149600281557578, -2.5243795802136213`, 0.}, 
      RotationMatrix :> {{-0.20466932070892938`, -0.9788311750044256, 0.}, {
       0.9788311750044256, -0.20466932070892938`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02274946166271862, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16702479470118595`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.68487184170988, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4087290784535339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20466932070892938`, -0.9788311750044256, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.149600281557578, -2.5243795802136213`, 0.}, 
      Optica`Optica`RayEnd :> {6.094872903973718, -2.6425988951424286`, 0.}, 
      RotationMatrix :> {{-0.42009963071948586`, -0.9074779888621821, 0.}, {
       0.9074779888621821, -0.42009963071948586`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0205864070092409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1302723772694845, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.87767496006872, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04487646532755613, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.42009963071948586`, -0.9074779888621821, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.329947657622755, -2.9378162837687634`, 0.}, 
      Optica`Optica`RayEnd :> {7.28916863721412, -3.106593666353948, 0.}, 
      RotationMatrix :> {{-0.2348563210038703, -0.9720300964911149, 0.}, {
       0.9720300964911149, -0.2348563210038703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18171996414288846`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.173633906187109, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.14292426049732, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02406382493574675, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2348563210038703, -0.9720300964911149, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.28916863721412, -3.106593666353948, 0.}, 
      Optica`Optica`RayEnd :> {7.207895388041592, -3.412112857650837, 0.}, 
      RotationMatrix :> {{-0.2570763065418839, -0.9663911074791524, 0.}, {
       0.9663911074791524, -0.2570763065418839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1812231873625461, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3161444563514672, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.610818055897493`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26903152084021387`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2570763065418839, -0.9663911074791524, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1955955310933275`, 2.9430773810869217`, 0.},
       Optica`Optica`RayEnd :> {4.135076293354458, 3.146048459213462, 0.}, 
      RotationMatrix :> {{-0.2857357660362537, 0.9583084430430915, 
       0.}, {-0.9583084430430915, -0.2857357660362537, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009271731607448755, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21180140861746843`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.18387207019287, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38115934594242784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2857357660362537, 0.9583084430430915, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.135076293354458, 3.146048459213462, 0.}, 
      Optica`Optica`RayEnd :> {4.097702904223805, 3.381360299048231, 0.}, 
      RotationMatrix :> {{-0.15685885216810086`, 0.9876210308091383, 
       0.}, {-0.9876210308091383, -0.15685885216810086`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009096705829027354, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23826126873987588`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.536498747927887`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2621400917739142, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.15685885216810086`, 0.9876210308091383, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1615855378483713`, 1.207032031787801, 0.}, 
      Optica`Optica`RayEnd :> {2.924273756208271, 1.2827967015776476`, 0.}, 
      RotationMatrix :> {{-0.9526279674156846, 0.30413805368197594`, 
       0.}, {-0.30413805368197594`, -0.9526279674156846, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030435601989512576`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24911275939534525`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.207400743825865`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32036014624921505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9526279674156846, 0.30413805368197594`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.924273756208271, 1.2827967015776476`, 0.}, 
      Optica`Optica`RayEnd :> {2.6408519376863855`, 1.35138276775199, 0.}, 
      RotationMatrix :> {{-0.9719460191479248, 0.235204030285412, 
       0.}, {-0.235204030285412, -0.9719460191479248, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030262615454523963`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2916024274376397, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.63897233643357, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3678225185763918, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9719460191479248, 0.235204030285412, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4410452598506835`, -0.18049458499323162`, 
       0.}, Optica`Optica`RayEnd :> {
       3.4127101159956346`, -0.23037049313153385`, 0.}, 
      RotationMatrix :> {{-0.49396406878211296`, -0.86948231652646, 0.}, {
       0.86948231652646, -0.49396406878211296`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24081433365777574`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.057362763095118535`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.31586790773279, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32746324322922815`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.49396406878211296`, -0.86948231652646, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4127101159956346`, -0.23037049313153385`, 
       0.}, Optica`Optica`RayEnd :> {
       3.2698138327236355`, -0.44057771756705405`, 0.}, 
      RotationMatrix :> {{-0.5621899504673565, -0.8270081375618443, 0.}, {
       0.8270081375618443, -0.5621899504673565, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23919154037313073`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25417793959711876`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.692051258336527`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23087964933557037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5621899504673565, -0.8270081375618443, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9852894961017116`, -0.6460686592447719, 0.},
       Optica`Optica`RayEnd :> {3.935730260460921, -0.8646476621391642, 0.}, 
      RotationMatrix :> {{-0.22112125018873496`, -0.9752463241227676, 0.}, {
       0.9752463241227676, -0.22112125018873496`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024225967439864368`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22412696924646575`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.913949795595045`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41912897044569847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22112125018873496`, -0.9752463241227676, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.935730260460921, -0.8646476621391642, 0.}, 
      Optica`Optica`RayEnd :> {3.8973613008508083`, -1.124342701262884, 0.}, 
      RotationMatrix :> {{-0.14615957433425164`, -0.9892610266408102, 0.}, {
       0.9892610266408102, -0.14615957433425164`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02407531150051946, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2625141718213184, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.302470769890597`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36108852960486226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.14615957433425164`, -0.9892610266408102, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.43125834980598, -1.0992574212415742`, 0.}, 
      Optica`Optica`RayEnd :> {4.411462985290634, -1.1769154495360734`, 0.}, 
      RotationMatrix :> {{-0.24700582383709843`, -0.9690139952500972, 0.}, {
       0.9690139952500972, -0.24700582383709843`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009044107843674506, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08014128658116643, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.677600428975477`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3611290669829394, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.24700582383709843`, -0.9690139952500972, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.411462985290634, -1.1769154495360734`, 0.}, 
      Optica`Optica`RayEnd :> {4.3351822088776855`, -1.3548246086900826`, 0.},
       RotationMatrix :> {{-0.3940676562402403, -0.9190814339901132, 0.}, {
       0.9190814339901132, -0.3940676562402403, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008780237424073651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19357279189247886`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.964088160976345`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.001522321435101948, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3940676562402403, -0.9190814339901132, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3767600525366226`, 2.6307316791079334`, 0.},
       Optica`Optica`RayEnd :> {2.262077448055811, 3.075918410771986, 0.}, 
      RotationMatrix :> {{-0.24946135595581131`, 0.968384754054238, 
       0.}, {-0.968384754054238, -0.24946135595581131`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01240381375548319, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.459720921669031, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.992456293879844`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26761253151999564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.24946135595581131`, 0.968384754054238, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.262077448055811, 3.075918410771986, 0.}, 
      Optica`Optica`RayEnd :> {2.1941208268320462`, 3.3746548047126277`, 0.}, 
      RotationMatrix :> {{-0.22181348773922488`, 0.9750891121620422, 
       0.}, {-0.9750891121620422, -0.22181348773922488`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012368030325712107`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3063683003066874, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.44588137833374, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4239792607723065, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22181348773922488`, 0.9750891121620422, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6361714884051755`, -0.33417672375082363`, 
       0.}, Optica`Optica`RayEnd :> {2.648156598461509, -0.3943550324390119, 
       0.}, RotationMatrix :> {{0.19532390616220205`, -0.9807387887106018, 
       0.}, {0.9807387887106018, 0.19532390616220205`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010201634959507322`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06136018008149338, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.543804170756065`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05515371701502966, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.19532390616220205`, -0.9807387887106018, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.648156598461509, -0.3943550324390119, 0.}, 
      Optica`Optica`RayEnd :> {2.6728400483340056`, -0.6450395782798753, 0.}, 
      RotationMatrix :> {{0.09799031463795742, -0.9951873684071525, 0.}, {
       0.9951873684071525, 0.09799031463795742, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010103089830228935`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2518968324950674, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.916611482848765`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1510181505997587, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09799031463795742, -0.9951873684071525, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2680396580060287`, -0.8580522163487847, 0.},
       Optica`Optica`RayEnd :> {2.284457958746897, -1.1368441939427059`, 0.}, 
      RotationMatrix :> {{0.058789009246110885`, -0.9982704304905861, 0.}, {
       0.9982704304905861, 0.058789009246110885`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008080560688500561, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27927500312406606`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.37771852113624, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10870934512255903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.058789009246110885`, -0.9982704304905861, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.284457958746897, -1.1368441939427059`, 0.}, 
      Optica`Optica`RayEnd :> {2.291385780639463, -1.436690548982074, 0.}, 
      RotationMatrix :> {{0.02309840825739662, -0.9997331961758467, 0.}, {
       0.9997331961758467, 0.02309840825739662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008055170324611846, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2999263765435943, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.82160955842076, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08605350143966095, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.02309840825739662, -0.9997331961758467, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.403187952588996, 3.800301315581602, 0.}, 
      Optica`Optica`RayEnd :> {5.630284451455838, 3.8477598192669125`, 0.}, 
      RotationMatrix :> {{0.9788539498373788, 0.20456036978789777`, 
       0.}, {-0.20456036978789777`, 0.9788539498373788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03195940378166947, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2320024339734955, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.171544240219966`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24748292521340567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9788539498373788, 0.20456036978789777`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.630284451455838, 3.8477598192669125`, 0.}, 
      Optica`Optica`RayEnd :> {5.907182003757885, 3.882611126529649, 0.}, 
      RotationMatrix :> {{0.9921720677417031, 0.12487829272196431`, 
       0.}, {-0.12487829272196431`, 0.9921720677417031, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.031742246390203614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2790821887702377, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.584585879599917`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13769323614870027`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9921720677417031, 0.12487829272196431`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.657254405218824, 3.413101570340565, 0.}, 
      Optica`Optica`RayEnd :> {7.709790060700965, 3.4116739007042938`, 0.}, 
      RotationMatrix :> {{0.9996309572496823, -0.027165222400764487`, 0.}, {
       0.027165222400764487`, 0.9996309572496823, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02160224367220629, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.052555050542536855`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.502798020641453`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3105222937858641, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9996309572496823, -0.027165222400764487`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.709790060700965, 3.4116739007042938`, 0.}, 
      Optica`Optica`RayEnd :> {7.841941765830849, 3.367434628351651, 0.}, 
      RotationMatrix :> {{0.9482762923819039, -0.31744617387272006`, 0.}, {
       0.31744617387272006`, 0.9482762923819039, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.016496266149675438`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.139359916715772, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.709050697380796`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1328584613198646, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9482762923819039, -0.31744617387272006`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.078171501620103, 1.4531793955188055`, 0.}, 
      Optica`Optica`RayEnd :> {7.126234424523609, 1.4233713146992655`, 0.}, 
      RotationMatrix :> {{0.8498308723862412, -0.5270554888616937, 0.}, {
       0.5270554888616937, 0.8498308723862412, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011099299146749298`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05655586830889065, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.677931517259516`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41981645286879665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8498308723862412, -0.5270554888616937, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.126234424523609, 1.4233713146992655`, 0.}, 
      Optica`Optica`RayEnd :> {7.370656595532074, 1.2520823986515497`, 0.}, 
      RotationMatrix :> {{0.8189273909513205, -0.5738971409143468, 0.}, {
       0.5738971409143468, 0.8189273909513205, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01105173183287477, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2984662299847218, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.119661537636905`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39854839999744496`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8189273909513205, -0.5738971409143468, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.76948545282574, 3.4087582852440135`, 0.}, 
      Optica`Optica`RayEnd :> {7.826222303376928, 3.426778123712218, 0.}, 
      RotationMatrix :> {{0.9530848248658594, 0.3027033475375076, 
       0.}, {-0.3027033475375076, 0.9530848248658594, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1386471286652363, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05952969669742953, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.46590408237372, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18272978717372174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9530848248658594, 0.3027033475375076, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.826222303376928, 3.426778123712218, 0.}, 
      Optica`Optica`RayEnd :> {8.135770010216715, 3.527245556395318, 0.}, 
      RotationMatrix :> {{0.9511564472577715, 0.3087092691189774, 
       0.}, {-0.3087092691189774, 0.9511564472577715, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1383026528670347, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32544352480838373`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.947560499090127`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35645969378039755`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9511564472577715, 0.3087092691189774, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.159514962471937, 0.4721062938499978, 0.}, 
      Optica`Optica`RayEnd :> {7.812765773017162, -0.10705713229944788`, 0.}, 
      RotationMatrix :> {{0.7482641125037156, -0.6634009480992817, 0.}, {
       0.6634009480992817, 0.7482641125037156, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09144955253095094, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8730217040069262, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.92414918530337, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.012056916493254022`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 120, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7482641125037156, -0.6634009480992817, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.812765773017162, -0.10705713229944788`, 0.},
       Optica`Optica`RayEnd :> {7.888113141749456, -0.22169323589710352`, 0.},
       RotationMatrix :> {{0.5492546179126727, -0.8356550512631411, 0.}, {
       0.8356550512631411, 0.5492546179126727, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07698969842798983, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13718112925228712`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.127177256596756`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4083206338810696, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 120, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5492546179126727, -0.8356550512631411, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.888113141749456, -0.22169323589710352`, 0.},
       Optica`Optica`RayEnd :> {7.834918368184336, -0.348140767657468, 0.}, 
      RotationMatrix :> {{-0.3877703431591529, -0.9217560203037634, 0.}, {
       0.9217560203037634, -0.3877703431591529, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012173485554484881`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13718112925228718`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.33020532789014, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0792367368174972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 120, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3877703431591529, -0.9217560203037634, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.2919813439335, 0.11115117115553974`, 0.}, 
      Optica`Optica`RayEnd :> {5.30137660267463, -0.021712658906653276`, 0.}, 
      RotationMatrix :> {{0.07053730486706028, -0.9975091421245672, 0.}, {
       0.9975091421245672, 0.07053730486706028, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04728467248867965, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13319560137485048`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.328371554837812`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19529437649992146`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.07053730486706028, -0.9975091421245672, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.30137660267463, -0.021712658906653276`, 0.},
       Optica`Optica`RayEnd :> {5.319840476503305, -0.3754533054975368, 0.}, 
      RotationMatrix :> {{0.05212511910524949, -0.9986405619432159, 0.}, {
       0.9986405619432159, 0.05212511910524949, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04715996806817774, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.35422218971614083`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.8526203956177, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1463137933445844, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.05212511910524949, -0.9986405619432159, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2337022530914274`, 0.5807779500679296, 0.}, 
      Optica`Optica`RayEnd :> {3.1850486011279524`, 0.5456290314456834, 0.}, 
      RotationMatrix :> {{-0.8105987978701225, -0.5856019030805065, 0.}, {
       0.5856019030805065, -0.8105987978701225, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033180353218404846`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06002186542999344, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.77581407850038, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4206130330766771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8105987978701225, -0.5856019030805065, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1850486011279524`, 0.5456290314456834, 0.}, 
      Optica`Optica`RayEnd :> {2.9646265652922676`, 0.4058709806656777, 0.}, 
      RotationMatrix :> {{-0.8445463127652619, -0.5354825166096453, 0.}, {
       0.5354825166096453, -0.8445463127652619, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033026689297777176`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26099461036537636`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.16208610184114, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4239172017107622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8445463127652619, -0.5354825166096453, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4639266872794554`, 2.343108263921816, 0.}, 
      Optica`Optica`RayEnd :> {3.42524535983107, 2.32639715513739, 0.}, 
      RotationMatrix :> {{-0.9179948967023107, -0.39659219562229525`, 0.}, {
       0.39659219562229525`, -0.9179948967023107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01067174121675637, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04213675651938724, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.953215700942874`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20056275077039487`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9179948967023107, -0.39659219562229525`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.42524535983107, 2.32639715513739, 0.}, 
      Optica`Optica`RayEnd :> {3.1344910450342534`, 2.2090378699962967`, 0.}, 
      RotationMatrix :> {{-0.9273090701478099, -0.37429652472552155`, 0.}, {
       0.37429652472552155`, -0.9273090701478099, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010642239483722064`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31354628586828265`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.37336772400637, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06621675941768955, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9273090701478099, -0.37429652472552155`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.419021162144573, 2.3521030916458017`, 0.}, 
      Optica`Optica`RayEnd :> {3.4036866376173576`, 2.350292019126975, 0.}, 
      RotationMatrix :> {{-0.9930978166288, -0.11728907283762441`, 0.}, {
       0.11728907283762441`, -0.9930978166288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0177851009661479, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.015441101843593331`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.97507481284984, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10596803888209858`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9930978166288, -0.11728907283762441`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4036866376173576`, 2.350292019126975, 0.}, 
      Optica`Optica`RayEnd :> {3.1808192602493235`, 2.3452581568970534`, 0.}, 
      RotationMatrix :> {{-0.9997450156546742, -0.022581046778982497`, 0.}, {
       0.022581046778982497`, -0.9997450156546742, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017624845741933917`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2229242195542142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.273793267052486`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3546398945632902, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9997450156546742, -0.022581046778982497`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.381604823976741, -0.45247289711526967`, 0.},
       Optica`Optica`RayEnd :> {3.1315529398097395`, -0.5477796894646114, 0.},
       RotationMatrix :> {{-0.9344268904857381, -0.35615500324599436`, 0.}, {
       0.35615500324599436`, -0.9344268904857381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019526754805094863`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26759919552081624`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.785840570080705`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2220702000986015, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.9344268904857381, -0.35615500324599436`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1315529398097395`, -0.5477796894646114, 0.},
       Optica`Optica`RayEnd :> {3.013239309426549, -0.6172267168862021, 0.}, 
      RotationMatrix :> {{-0.8624091952823405, -0.5062117935138076, 0.}, {
       0.5062117935138076, -0.8624091952823405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0188306493500104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13718966707498562`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.969674723961184`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21560757158673968`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8624091952823405, -0.5062117935138076, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.972389363345108, -4.14210818712324, 0.}, 
      Optica`Optica`RayEnd :> {5.977006599338496, -4.3649351408674555`, 0.}, 
      RotationMatrix :> {{0.020716726546972965`, -0.9997853855909162, 0.}, {
       0.9997853855909162, 0.020716726546972965`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008012778148628164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22287478588468754`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.950875544363555`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2718712698955239, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 118, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.020716726546972965`, -0.9997853855909162, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.449908629578593, -0.6290946221239575, 0.}, 
      Optica`Optica`RayEnd :> {7.531812469884396, -0.8224597114203069, 0.}, 
      RotationMatrix :> {{0.3900258188300474, -0.9208039208463171, 0.}, {
       0.9208039208463171, 0.3900258188300474, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01219685533881422, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2099959447594731, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.919948359813393`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2797387303235964, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3900258188300474, -0.9208039208463171, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.531812469884396, -0.8224597114203069, 0.}, 
      Optica`Optica`RayEnd :> {7.640428094261788, -1.1038480785083356`, 0.}, 
      RotationMatrix :> {{0.36010326028797185`, -0.9329124513747111, 0.}, {
       0.9329124513747111, 0.36010326028797185`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012160121274981043`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3016235517849326, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.366351216455094`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07125752057194615, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.36010326028797185`, -0.9329124513747111, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6290617411838237`, 1.8597836212114276`, 0.},
       Optica`Optica`RayEnd :> {3.4058226965187366`, 1.6664153391472372`, 0.},
       RotationMatrix :> {{-0.7558659433172943, -0.6547264128878989, 0.}, {
       0.6547264128878989, -0.7558659433172943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015620072431449951`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2953421127632108, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.38712587564336, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19596962259890865`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7558659433172943, -0.6547264128878989, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4058226965187366`, 1.6664153391472372`, 0.},
       Optica`Optica`RayEnd :> {3.264465092946304, 1.5995015474563508`, 0.}, 
      RotationMatrix :> {{-0.9038493066549784, -0.4278509446750276, 0.}, {
       0.4278509446750276, -0.9038493066549784, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01288808963587158, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1563951009660865, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.618590625073168`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2680070637549204, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9038493066549784, -0.4278509446750276, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.615425364229257, 2.1304326170238865`, 0.}, 
      Optica`Optica`RayEnd :> {5.614686661186413, 2.1295447813128416`, 0.}, 
      RotationMatrix :> {{-0.639591444819751, -0.7687150211316168, 0.}, {
       0.7687150211316168, -0.639591444819751, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010630461693970548`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0011549607938424065`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.31893043121211, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07444097978982671, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.639591444819751, -0.7687150211316168, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.614686661186413, 2.1295447813128416`, 0.}, 
      Optica`Optica`RayEnd :> {5.4640233858549445`, 1.9477339013071668`, 0.}, 
      RotationMatrix :> {{-0.6380680221594668, -0.769979999154202, 0.}, {
       0.769979999154202, -0.6380680221594668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01060424037599711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23612415933581152`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.66839418702911, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37887547461278925`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6380680221594668, -0.769979999154202, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.713787371339179, 1.570713499858081, 0.}, 
      Optica`Optica`RayEnd :> {7.774328954197708, 1.4155775426289767`, 0.}, 
      RotationMatrix :> {{0.36354624558892756`, -0.9315761521841325, 0.}, {
       0.9315761521841325, 0.36354624558892756`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009936164978887019, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16653062325112034`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.514880849053686`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27465772060659976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.36354624558892756`, -0.9315761521841325, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.774328954197708, 1.4155775426289767`, 0.}, 
      Optica`Optica`RayEnd :> {7.862360376716455, 1.1678882075169161`, 0.}, 
      RotationMatrix :> {{0.33488843327098233`, -0.9422577870526228, 0.}, {
       0.9422577870526228, 0.33488843327098233`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00990682077110572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2628679099451451, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.9039253557725, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05062751713307724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.33488843327098233`, -0.9422577870526228, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.405720745714707, 0.28962841116119903`, 0.}, 
      Optica`Optica`RayEnd :> {7.380816080976115, -0.003170653943217791, 0.}, 
      RotationMatrix :> {{-0.0847511634941402, -0.996402147873231, 0.}, {
       0.996402147873231, -0.0847511634941402, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012581741052048121`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2938563166783423, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.425584184111592`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1518763145766984, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 118, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.0847511634941402, -0.996402147873231, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3243323955771182`, 1.5094446611867771`, 0.},
       Optica`Optica`RayEnd :> {3.1473289708149186`, 1.439324730597311, 0.}, 
      RotationMatrix :> {{-0.9297057851935557, -0.36830307218055175`, 0.}, {
       0.36830307218055175`, -0.9297057851935557, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010036193356730718`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19038649385767697`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.819444582745255`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30623148472941686`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9297057851935557, -0.36830307218055175`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1473289708149186`, 1.439324730597311, 0.}, 
      Optica`Optica`RayEnd :> {2.8900303313193105`, 1.3625771376378866`, 0.}, 
      RotationMatrix :> {{-0.9582781695172926, -0.28583727858098873`, 0.}, {
       0.28583727858098873`, -0.9582781695172926, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009958635797187197, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2685009923843043, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.216826051474026`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4118158007478157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9582781695172926, -0.28583727858098873`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1502362259938024`, -1.3957048186924736`, 
       0.}, Optica`Optica`RayEnd :> {3.140939782144625, -1.4064915027523015`, 
       0.}, RotationMatrix :> {{-0.6528420554462854, -0.7574940598055324, 
       0.}, {0.7574940598055324, -0.6528420554462854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01207073509839684, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.014239958611156626`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.278086140116233`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17776872752267456`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6528420554462854, -0.7574940598055324, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.140939782144625, -1.4064915027523015`, 0.}, 
      Optica`Optica`RayEnd :> {2.9274205586807724`, -1.6459941452217333`, 0.},
       RotationMatrix :> {{-0.6654564534182777, -0.746436674208848, 0.}, {
       0.746436674208848, -0.6654564534182777, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012039266566667994`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32086130109199373`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.752960865732383`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4211870845758388, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6654564534182777, -0.746436674208848, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3009531280733664`, -0.43534944114653396`, 
       0.}, Optica`Optica`RayEnd :> {2.234991679446133, -0.5354867968672238, 
       0.}, RotationMatrix :> {{-0.5500914100365971, -0.8351044489187853, 
       0.}, {0.8351044489187853, -0.5500914100365971, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012039074401536185`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1199099775487225, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.008356704045376`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20625234357241923`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5500914100365971, -0.8351044489187853, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.234991679446133, -0.5354867968672238, 0.}, 
      Optica`Optica`RayEnd :> {2.0824279862392947`, -0.7938827603812862, 0.}, 
      RotationMatrix :> {{-0.5084209424008613, -0.8611086721942938, 0.}, {
       0.8611086721942938, -0.5084209424008613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011993146577347942`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3000735817183362, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.452465604988515`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28334919592339247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5084209424008613, -0.8611086721942938, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.126212024936174, -2.1067733899757095`, 0.}, 
      Optica`Optica`RayEnd :> {4.074089590001083, -2.1237816255091575`, 0.}, 
      RotationMatrix :> {{-0.9506664412051905, -0.31021495380825514`, 0.}, {
       0.31021495380825514`, -0.9506664412051905, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018153086228537434`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05482725872706014, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.696996322628685`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1280433166103064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9506664412051905, -0.31021495380825514`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.074089590001083, -2.1237816255091575`, 0.}, 
      Optica`Optica`RayEnd :> {3.9177412468353956`, -2.1479226278260843`, 0.},
       RotationMatrix :> {{-0.9882885108884978, -0.15259691755011148`, 0.}, {
       0.15259691755011148`, -0.9882885108884978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017554742480894805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15820111378723467`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.93113397103379, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42067559933648413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9882885108884978, -0.15259691755011148`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3692815675533225`, -2.347872509711066, 0.}, 
      Optica`Optica`RayEnd :> {5.3459786044157145`, -2.3471977292237662`, 0.},
       RotationMatrix :> {{-0.9995810137920084, 0.028944720875148905`, 
       0.}, {-0.028944720875148905`, -0.9995810137920084, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011262265111103337`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.023312730850305243`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.348034603497606`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15807765722757314`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.9995810137920084, 0.028944720875148905`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3459786044157145`, -2.3471977292237662`, 
       0.}, Optica`Optica`RayEnd :> {5.071169419359076, -2.318045595221131, 
       0.}, RotationMatrix :> {{-0.9944204192182169, 0.10548947739876847`, 
       0.}, {-0.10548947739876847`, -0.9944204192182169, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01119160099071891, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2763511083900355, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.75703424391486, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24589795856639607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9944204192182169, 0.10548947739876847`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.11598951992452, 0.901805773284278, 0.}, 
      Optica`Optica`RayEnd :> {8.117465107955368, 0.9039147885466935, 0.}, 
      RotationMatrix :> {{0.5732739033397004, 0.8193637969483785, 
       0.}, {-0.8193637969483785, 0.5732739033397004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010220398973492943`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0025739668634008612`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.69837269893871, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015043930706857413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5732739033397004, 0.8193637969483785, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.117465107955368, 0.9039147885466935, 0.}, 
      Optica`Optica`RayEnd :> {8.193310352004639, 1.0700518446392056`, 0.}, 
      RotationMatrix :> {{0.4152926498610976, 0.9096878667825287, 
       0.}, {-0.9096878667825287, 0.4152926498610976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009743557485578981, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1826308365309098, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.968666337004453`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3874703826466261, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4152926498610976, 0.9096878667825287, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.604221962285013, 1.2840482842581151`, 0.}, 
      Optica`Optica`RayEnd :> {4.563582880352831, 1.3283827761195492`, 0.}, 
      RotationMatrix :> {{-0.6757167774312312, 0.7371613369527404, 
       0.}, {-0.7371613369527404, -0.6757167774312312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012573409885857397`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.060142182774673, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.523340559477763`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14341699602760505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6757167774312312, 0.7371613369527404, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.563582880352831, 1.3283827761195492`, 0.}, 
      Optica`Optica`RayEnd :> {4.413118909568857, 1.5107447399974474`, 0.}, 
      RotationMatrix :> {{-0.6364215877137476, 0.7713414047566177, 
       0.}, {-0.7713414047566177, -0.6364215877137476, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01252307649637794, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2364218525718051, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.873244901284036`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2056020096197454, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6364215877137476, 0.7713414047566177, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3194844998904247`, -0.05599969509460018, 
       0.}, Optica`Optica`RayEnd :> {2.151209848715848, -0.008757463641831466,
        0.}, RotationMatrix :> {{-0.9627776082507783, 0.2702947965664726, 
       0.}, {-0.2702947965664726, -0.9627776082507783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016974745458589298`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1747803955269654, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.670967530582537`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4155360384698536, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9627776082507783, 0.2702947965664726, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.151209848715848, -0.008757463641831466, 0.},
       Optica`Optica`RayEnd :> {1.7936828751715792`, 0.0789026636679371, 0.}, 
      RotationMatrix :> {{-0.9712329432561193, 0.23813141316100145`, 
       0.}, {-0.23813141316100145`, -0.9712329432561193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0169230207771294, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3681166048030011, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.21578010569098, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2600841237612672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9712329432561193, 0.23813141316100145`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9464350153265713`, -4.072481409782038, 0.}, 
      Optica`Optica`RayEnd :> {3.835722394194781, -4.13964075830178, 0.}, 
      RotationMatrix :> {{-0.8549896746664141, -0.5186450194630421, 0.}, {
       0.5186450194630421, -0.8549896746664141, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08653567657754005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1294900095430818, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.825099830491688`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10131044451618136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8549896746664141, -0.5186450194630421, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.835722394194781, -4.13964075830178, 0.}, 
      Optica`Optica`RayEnd :> {3.6249144125819277`, -4.291219948717063, 0.}, 
      RotationMatrix :> {{-0.8119041005421057, -0.5837908285704002, 0.}, {
       0.5837908285704002, -0.8119041005421057, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0859778359737021, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25964640586504917`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.20937651117196, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0022256067509563993`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8119041005421057, -0.5837908285704002, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.312220468657105, -1.0674312255994285`, 0.}, 
      Optica`Optica`RayEnd :> {2.1483285684874125`, -1.0735863512073813`, 0.},
       RotationMatrix :> {{-0.9992955182516792, -0.03752955105124175, 0.}, {
       0.03752955105124175, -0.9992955182516792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013545767837733614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16400744041805604`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.36889837072672, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3399298229661263, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9992955182516792, -0.03752955105124175, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1483285684874125`, -1.0735863512073813`, 
       0.}, Optica`Optica`RayEnd :> {
       1.7818741487236447`, -1.0752584328605608`, 0.}, 
      RotationMatrix :> {{-0.9999895902989325, -0.00456281642990445, 0.}, {
       0.00456281642990445, -0.9999895902989325, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013504632056860493`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3664582344844425, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.911256557763693`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15193493755212842`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9999895902989325, -0.00456281642990445, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.947765141123858, -3.6496665162900763`, 0.}, 
      Optica`Optica`RayEnd :> {5.887302745128805, -3.684232142683669, 0.}, 
      RotationMatrix :> {{-0.8681461059175205, -0.49630871318187103`, 0.}, {
       0.49630871318187103`, -0.8681461059175205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01327686148578607, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06964541519327791, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.88872262047544, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24567237732635805`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8681461059175205, -0.49630871318187103`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.887302745128805, -3.684232142683669, 0.}, 
      Optica`Optica`RayEnd :> {5.616473148431152, -3.839546036759751, 0.}, 
      RotationMatrix :> {{-0.8674775466060445, -0.497476337260736, 0.}, {
       0.497476337260736, -0.8674775466060445, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013244126484075079`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3122035812422552, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.35078392071398, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24313229655591895`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8674775466060445, -0.497476337260736, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.474559788528993, -4.071123810438171, 0.}, 
      Optica`Optica`RayEnd :> {7.579937962894859, -4.3161032824231205`, 0.}, 
      RotationMatrix :> {{0.3951448435018557, -0.9186188288152454, 0.}, {
       0.9186188288152454, 0.3951448435018557, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2032824779800118, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26668239785690256`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.466172013276452`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12141121896530604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3951448435018557, -0.9186188288152454, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.579937962894859, -4.3161032824231205`, 0.}, 
      Optica`Optica`RayEnd :> {7.666259953006467, -4.416423503191367, 0.}, 
      RotationMatrix :> {{0.6522416527857493, -0.7580110991082606, 0.}, {
       0.7580110991082606, 0.6522416527857493, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15014819618983194`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13234663830947194`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.66204503797447, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3973743663672349, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6522416527857493, -0.7580110991082606, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.666259953006467, -4.416423503191367, 0.}, 
      Optica`Optica`RayEnd :> {7.798279980013547, -4.407131294580484, 0.}, 
      RotationMatrix :> {{0.9975321526367094, 0.07021114196458983, 
       0.}, {-0.07021114196458983, 0.9975321526367094, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03924596278987575, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13234663830947208`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.85791806267249, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005966776588013199, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9975321526367094, 0.07021114196458983, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.798279980013547, -4.407131294580484, 0.}, 
      Optica`Optica`RayEnd :> {7.869698474112256, -4.295708534910429, 0.}, 
      RotationMatrix :> {{0.5396320980341672, 0.8419009435623896, 
       0.}, {-0.8419009435623896, 0.5396320980341672, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01025816915813612, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13234663830947227`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.05379108737051, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4045036046313473, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5396320980341672, 0.8419009435623896, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.094646516432469, -2.548964716506338, 0.}, 
      Optica`Optica`RayEnd :> {7.017709930673849, -2.8118212473725794`, 0.}, 
      RotationMatrix :> {{-0.2809087314073877, -0.9597344865217103, 0.}, {
       0.9597344865217103, -0.2809087314073877, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02029328043853616, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27388463638405985`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.11345605923718, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15781397617745008`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.2809087314073877, -0.9597344865217103, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.017709930673849, -2.8118212473725794`, 0.}, 
      Optica`Optica`RayEnd :> {6.929734262581606, -3.1213235621942435`, 0.}, 
      RotationMatrix :> {{-0.2734176384847101, -0.9618954178939846, 0.}, {
       0.9618954178939846, -0.2734176384847101, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02024264715887027, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3217629578684364, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.589665236882464`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3837739641524802, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.2734176384847101, -0.9618954178939846, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.516406202241529, 3.153786736063154, 0.}, 
      Optica`Optica`RayEnd :> {4.4247886751073, 3.2215031330595845`, 0.}, 
      RotationMatrix :> {{-0.8041799413059671, 0.5943859200899115, 
       0.}, {-0.5943859200899115, -0.8041799413059671, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008216864404423688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11392665052729894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.39166381196505, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3182232513163667, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8041799413059671, 0.5943859200899115, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.4247886751073, 3.2215031330595845`, 0.}, 
      Optica`Optica`RayEnd :> {4.134348357352752, 3.424274933828437, 0.}, 
      RotationMatrix :> {{-0.8199427405765038, 0.5724455451620631, 
       0.}, {-0.5724455451620631, -0.8199427405765038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00819351101102162, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3542202441481941, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.915909773304378`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3794608370593763, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8199427405765038, 0.5724455451620631, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.897134594666521, -1.0567814332362302`, 0.}, 
      Optica`Optica`RayEnd :> {4.838260177596472, -1.1224294320918338`, 0.}, 
      RotationMatrix :> {{-0.6676555980982528, -0.7444702830389295, 0.}, {
       0.7444702830389295, -0.6676555980982528, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16746429442840072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08818081843056016, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.03066671365555, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21217034812265417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6676555980982528, -0.7444702830389295, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.838260177596472, -1.1224294320918338`, 0.}, 
      Optica`Optica`RayEnd :> {4.628548247530289, -1.346088855764899, 0.}, 
      RotationMatrix :> {{-0.6839953224615645, -0.7294863938763354, 0.}, {
       0.7294863938763354, -0.6839953224615645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1670094770389857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3065984856613794, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.484432472434392`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4276624486339197, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6839953224615645, -0.7294863938763354, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.863954869871214, 1.9176321217127803`, 0.}, 
      Optica`Optica`RayEnd :> {5.828851133311871, 1.7536027718809188`, 0.}, 
      RotationMatrix :> {{-0.20927025635826918`, -0.9778578423287011, 0.}, {
       0.9778578423287011, -0.20927025635826918`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008089984316145455, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16774355405407054`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.128256622643317`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3485991792265264, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 122, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.20927025635826918`, -0.9778578423287011, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.828233618459975, 2.9715138482660324`, 0.}, 
      Optica`Optica`RayEnd :> {4.657936910198665, 2.9071816910221346`, 0.}, 
      RotationMatrix :> {{-0.9354760067422158, -0.35339021040435814`, 0.}, {
       0.35339021040435814`, -0.9354760067422158, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03695073426189968, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18204283918982125`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.683557939504755`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2173178923832607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9354760067422158, -0.35339021040435814`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.657936910198665, 2.9071816910221346`, 0.}, 
      Optica`Optica`RayEnd :> {4.451625246734025, 2.8573328742422452`, 0.}, 
      RotationMatrix :> {{-0.9720290431632368, -0.234860680504764, 0.}, {
       0.234860680504764, -0.9720290431632368, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.036355405316505024`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21224845586223207`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.99768565418086, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4267540257788779, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9720290431632368, -0.234860680504764, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.56275376786472, 1.7150572909505666`, 0.}, 
      Optica`Optica`RayEnd :> {4.411361324814766, 1.641264663471477, 0.}, 
      RotationMatrix :> {{-0.898902569966389, -0.4381485703592111, 0.}, {
       0.4381485703592111, -0.898902569966389, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03556946153593966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1684191903641075, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.896414772317, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1615701835074436, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.898902569966389, -0.4381485703592111, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.411361324814766, 1.641264663471477, 0.}, 
      Optica`Optica`RayEnd :> {4.234404632860996, 1.5925539569764573`, 0.}, 
      RotationMatrix :> {{-0.9641390342726762, -0.26539766877602866`, 0.}, {
       0.26539766877602866`, -0.9641390342726762, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03383326130557584, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18353856203660604`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.168051844131178`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3719912655655078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9641390342726762, -0.26539766877602866`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.116889302356681, 2.756812497992865, 0.}, 
      Optica`Optica`RayEnd :> {4.90488330168855, 2.735726286789342, 0.}, 
      RotationMatrix :> {{-0.99509020719508, -0.09897211498422952, 0.}, {
       0.09897211498422952, -0.99509020719508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04027378731028649, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21305204205126782`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.007618081138304`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3616012612033896, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.99509020719508, -0.09897211498422952, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.90488330168855, 2.735726286789342, 0.}, 
      Optica`Optica`RayEnd :> {4.604009722506619, 2.7158150708953386`, 0.}, 
      RotationMatrix :> {{-0.9978174016951613, -0.06603357384176489, 0.}, {
       0.06603357384176489, -0.9978174016951613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040151370201531866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30153170176305266`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.453884999747622`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1812424150488707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9978174016951613, -0.06603357384176489, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.281273842308778, -1.8821019026795236`, 0.}, 
      Optica`Optica`RayEnd :> {8.257770156028219, -2.0656888230253854`, 0.}, 
      RotationMatrix :> {{-0.12698837809342683`, -0.9919042049659835, 0.}, {
       0.9919042049659835, -0.12698837809342683`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2494415543503198, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1850853332678006, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.092074574074278`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20183758213272723`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12698837809342683`, -0.9919042049659835, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.257770156028219, -2.0656888230253854`, 0.}, 
      Optica`Optica`RayEnd :> {8.215440038407017, -2.401181598702991, 0.}, 
      RotationMatrix :> {{-0.12518048485338798`, -0.9921339860179519, 0.}, {
       0.9921339860179519, -0.12518048485338798`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24882635126203284`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3381526894609726, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.592540554476518`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3091389752869406, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12518048485338798`, -0.9921339860179519, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.093639983498253, -0.7145902088797783, 0.}, 
      Optica`Optica`RayEnd :> {5.914514873020996, -0.7476928139270784, 0.}, 
      RotationMatrix :> {{-0.9833494747882516, -0.1817245454903358, 0.}, {
       0.1817245454903358, -0.9833494747882516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06375945841756175, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1821581391659642, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.12043702982486, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3827905442214018, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9833494747882516, -0.1817245454903358, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.914514873020996, -0.7476928139270784, 0.}, 
      Optica`Optica`RayEnd :> {5.630380699138552, -0.7899309361355071, 0.}, 
      RotationMatrix :> {{-0.989130583555903, -0.1470397520208671, 0.}, {
       0.1470397520208671, -0.989130583555903, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06356053230102765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28725648423587163`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.54557662649395, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22662282740847353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.989130583555903, -0.1470397520208671, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.094872903973718, -2.6425988951424286`, 0.}, 
      Optica`Optica`RayEnd :> {5.951171420434094, -2.8273803728010924`, 0.}, 
      RotationMatrix :> {{-0.6138941814285392, -0.7893883290296246, 0.}, {
       0.7893883290296246, -0.6138941814285392, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01862901899980518, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2340818464922212, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.191344634368296`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3668629702629064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6138941814285392, -0.7893883290296246, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.951171420434094, -2.8273803728010924`, 0.}, 
      Optica`Optica`RayEnd :> {5.8301339973671515`, -3.0309964858953027`, 0.},
       RotationMatrix :> {{-0.5109767769477629, -0.8595945168625003, 0.}, {
       0.8595945168625003, -0.5109767769477629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018325650740303748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2368746066894473, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.54191905226868, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09833675776944412, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5109767769477629, -0.8595945168625003, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.207895388041592, -3.412112857650837, 0.}, 
      Optica`Optica`RayEnd :> {7.186656610075415, -3.4851689095687415`, 0.}, 
      RotationMatrix :> {{-0.2791611918085472, -0.9602442548581224, 0.}, {
       0.9602442548581224, -0.2791611918085472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18072776864525777`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07608069670637979, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.712766189484043`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38126659351057646`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2791611918085472, -0.9602442548581224, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.186656610075415, -3.4851689095687415`, 0.}, 
      Optica`Optica`RayEnd :> {7.104736350691827, -3.6563018927554336`, 0.}, 
      RotationMatrix :> {{-0.4317731081157472, -0.9019822521025934, 0.}, {
       0.9019822521025934, -0.4317731081157472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17462954874357203`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18972987859546797`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.993566409805336`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012846370735146662`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4317731081157472, -0.9019822521025934, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.097702904223805, 3.381360299048231, 0.}, 
      Optica`Optica`RayEnd :> {4.09629675294918, 3.437049686041319, 0.}, 
      RotationMatrix :> {{-0.02524185152241268, 0.9996813737045017, 
       0.}, {-0.9996813737045017, -0.02524185152241268, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008924984074536874, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.055707136751703815`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.61114631117517, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11525283235822181`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.02524185152241268, 0.9996813737045017, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.09629675294918, 3.437049686041319, 0.}, 
      Optica`Optica`RayEnd :> {4.07115545095173, 3.6707940629447973`, 0.}, 
      RotationMatrix :> {{-0.10694213546302186`, 0.9942652461303311, 
       0.}, {-0.9942652461303311, -0.10694213546302186`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008863020427805972, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.235092574957446, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.95908332211219, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009151109288428938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10694213546302186`, 0.9942652461303311, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6408519376863855`, 1.35138276775199, 0.}, 
      Optica`Optica`RayEnd :> {2.5958833832665844`, 1.3589087179036896`, 0.}, 
      RotationMatrix :> {{-0.9862827632600667, 0.16506456584042017`, 
       0.}, {-0.16506456584042017`, -0.9862827632600667, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030090612121421702`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04559397780729916, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.700068266695354`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10265984172907322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9862827632600667, 0.16506456584042017`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5958833832665844`, 1.3589087179036896`, 0.},
       Optica`Optica`RayEnd :> {2.3206781979850604`, 1.4260747983155784`, 0.},
       RotationMatrix :> {{-0.9714854947706674, 0.2370989950425576, 
       0.}, {-0.2370989950425576, -0.9714854947706674, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02991307961919179, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2832828557532808, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.11932689321021, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17690899351729944`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9714854947706674, 0.2370989950425576, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2698138327236355`, -0.4405777175670541, 0.},
       Optica`Optica`RayEnd :> {2.937998642286805, -0.8530764190411502, 0.}, 
      RotationMatrix :> {{-0.6267847446279597, -0.7791924562658845, 0.}, {
       0.7791924562658845, -0.6267847446279597, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23757968272510135`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5293925758097158, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.401437309921548`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3429791231981707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6267847446279597, -0.7791924562658845, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.937998642286805, -0.8530764190411502, 0.}, 
      Optica`Optica`RayEnd :> {2.8297096805049433`, -1.02433477027403, 0.}, 
      RotationMatrix :> {{-0.534436713382981, -0.8452084946262647, 0.}, {
       0.8452084946262647, -0.534436713382981, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2344716387877651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2026226100680719, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.701318772822294`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10461769570048607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.534436713382981, -0.8452084946262647, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8973613008508083`, -1.124342701262884, 0.}, 
      Optica`Optica`RayEnd :> {3.892751312928141, -1.1897116440320903`, 0.}, 
      RotationMatrix :> {{-0.07034788339783582, -0.9975225186939108, 0.}, {
       0.9975225186939108, -0.07034788339783582, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023925592457177423`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0655312953283461, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.390282705630582`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13061622351406893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.07034788339783582, -0.9975225186939108, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.892751312928141, -1.1897116440320903`, 0.}, 
      Optica`Optica`RayEnd :> {3.860881282240003, -1.4002161107014388`, 0.}, 
      RotationMatrix :> {{-0.149692492782456, -0.9887326016697202, 0.}, {
       0.9887326016697202, -0.149692492782456, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023766055741274536`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2129033333318426, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.70537963896171, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.018103913453952517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.149692492782456, -0.9887326016697202, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.3351822088776855`, -1.3548246086900826`, 
       0.}, Optica`Optica`RayEnd :> {4.21139443529494, -1.5520424102655443`, 
       0.}, RotationMatrix :> {{-0.531624402114722, -0.8469802211835668, 
       0.}, {0.8469802211835668, -0.531624402114722, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008524065674097695, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23284817831976093`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.276104719924824`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31146848537731064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.531624402114722, -0.8469802211835668, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.21139443529494, -1.5520424102655443`, 0.}, 
      Optica`Optica`RayEnd :> {4.07555611396809, -1.8117704305492082`, 0.}, 
      RotationMatrix :> {{-0.46344552409379275`, -0.8861254122286693, 0.}, {
       0.8861254122286693, -0.46344552409379275`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008468562486519738, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29310526106054124`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.709900506294424`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22114233384823362`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46344552409379275`, -0.8861254122286693, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1941208268320462`, 3.3746548047126277`, 0.},
       Optica`Optica`RayEnd :> {2.1530100585787526`, 3.5825554779714337`, 0.},
       RotationMatrix :> {{-0.19398609410323048`, 0.9810042789379522, 
       0.}, {-0.9810042789379522, -0.19398609410323048`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012332350126598257`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21192636742000948`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.729862710676553`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42166499762799825`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.19398609410323048`, 0.9810042789379522, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1530100585787526`, 3.5825554779714337`, 0.},
       Optica`Optica`RayEnd :> {2.1227029962502155`, 3.8305644736481965`, 0.},
       RotationMatrix :> {{-0.12129912815654423`, 0.9926159990189868, 
       0.}, {-0.9926159990189868, -0.12129912815654423`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012259491984874664`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24985391724682332`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.09964650820185, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3748961098718803, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.12129912815654423`, 0.9926159990189868, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6728400483340056`, -0.6450395782798753, 0.},
       Optica`Optica`RayEnd :> {2.6728293627882644`, -0.6816242794814096, 0.},
       RotationMatrix :> {{-0.0002920768773361643, -0.9999999573455477, 0.}, {
       0.9999999573455477, -0.0002920768773361643, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01000549662116167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03658470276203468, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.96563498454989, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3058762579477174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.0002920768773361643, -0.9999999573455477, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6728293627882644`, -0.6816242794814096, 0.},
       Optica`Optica`RayEnd :> {2.6958045992808475`, -0.8824309136322641, 0.},
       RotationMatrix :> {{0.11367311546407693`, -0.9935182045743751, 0.}, {
       0.9935182045743751, 0.11367311546407693`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009872945037530766, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2021167133388164, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.26476772029134, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38730962955085735`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.11367311546407693`, -0.9935182045743751, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.291385780639463, -1.436690548982074, 0.}, 
      Optica`Optica`RayEnd :> {2.2897548956541605`, -1.5658933942645108`, 0.},
       RotationMatrix :> {{-0.012621665345882955`, -0.9999203436093775, 0.}, {
       0.9999203436093775, -0.012621665345882955`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00802985974114967, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12921313793462563`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.99475516325316, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19250178139996174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.012621665345882955`, -0.9999203436093775, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2897548956541605`, -1.5658933942645108`, 
       0.}, Optica`Optica`RayEnd :> {2.282771181374178, -1.8615689193742373`, 
       0.}, RotationMatrix :> {{-0.02361293532375934, -0.9997211757712222, 
       0.}, {0.9997211757712222, -0.02361293532375934, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008009581870598843, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29575798960308214`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.432476987865723`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2140737725895545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.02361293532375934, -0.9997211757712222, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.907182003757885, 3.882611126529649, 0.}, 
      Optica`Optica`RayEnd :> {6.679674476361992, 3.916929071821072, 0.}, 
      RotationMatrix :> {{0.9990146698030343, 0.04438118428268492, 
       0.}, {-0.04438118428268492, 0.9990146698030343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03152656453729881, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7732543834981032, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.620746753487374`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3502095970290269, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9990146698030343, 0.04438118428268492, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.679674476361992, 3.916929071821072, 0.}, 
      Optica`Optica`RayEnd :> {6.834619754427745, 3.8806501516394767`, 0.}, 
      RotationMatrix :> {{0.9736670759847911, -0.22797461512902334`, 0.}, {
       0.22797461512902334`, 0.9736670759847911, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025818944992908193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1591357886976278, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.856267720759863`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09383090943251704, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9736670759847911, -0.22797461512902334`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.841941765830849, 3.367434628351651, 0.}, 
      Optica`Optica`RayEnd :> {8.081998778109991, 3.196453475142506, 0.}, 
      RotationMatrix :> {{0.8145161025074987, -0.5801409473188331, 0.}, {
       0.5801409473188331, 0.8145161025074987, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012597154305367621`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2947234702176215, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.10398014747241, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13198686301736623`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8145161025074987, -0.5801409473188331, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.081998778109991, 3.196453475142506, 0.}, 
      Optica`Optica`RayEnd :> {8.27378532912938, 3.089154647252922, 0.}, 
      RotationMatrix :> {{0.8727031149068092, -0.488251239867296, 0.}, {
       0.488251239867296, 0.8727031149068092, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012447299934343995`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21976150622525217`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.42922717668578, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11890559529573949`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8727031149068092, -0.488251239867296, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.370656595532074, 1.2520823986515497`, 0.}, 
      Optica`Optica`RayEnd :> {7.442301448445294, 1.1956261762702811`, 0.}, 
      RotationMatrix :> {{0.7854449716037487, -0.618931495872027, 0.}, {
       0.618931495872027, 0.7854449716037487, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011004368374155358`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0912156236317011, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.241890473303386`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4238507979522624, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7854449716037487, -0.618931495872027, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.442301448445294, 1.1956261762702811`, 0.}, 
      Optica`Optica`RayEnd :> {7.690322061937462, 0.9829898218117369, 0.}, 
      RotationMatrix :> {{0.7591851221426102, -0.65087475778164, 0.}, {
       0.65087475778164, 0.7591851221426102, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01096704909811298, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32669319545171355`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.72539640257192, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32685739275256764`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7591851221426102, -0.65087475778164, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.135770010216715, 3.527245556395318, 0.}, 
      Optica`Optica`RayEnd :> {8.25819076382651, 3.567834013922942, 0.}, 
      RotationMatrix :> {{0.9491902233874245, 0.3147029072406709, 
       0.}, {-0.3147029072406709, 0.9491902233874245, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.13795903293636302`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1289738880504959, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.120385509077792`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32614883586916266`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9491902233874245, 0.3147029072406709, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.25819076382651, 3.567834013922942, 0.}, 
      Optica`Optica`RayEnd :> {8.495946585525004, 3.6887914096803205`, 0.}, 
      RotationMatrix :> {{0.8912872611747825, 0.4534391007263867, 
       0.}, {-0.4534391007263867, 0.8912872611747825, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1342857484716806, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2667555479084419, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.515183719982286`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2842389815716897, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8912872611747825, 0.4534391007263867, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.812765773017162, -0.10705713229944788`, 0.},
       Optica`Optica`RayEnd :> {7.898297320087702, -0.13106147713959804`, 0.},
       RotationMatrix :> {{0.9628015998079162, -0.2702093251672048, 0.}, {
       0.2702093251672048, 0.9628015998079162, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014459854102961163`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08883610817389934, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.043189570256395`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3668042699636638, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9628015998079162, -0.2702093251672048, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.898297320087702, -0.13106147713959804`, 0.},
       Optica`Optica`RayEnd :> {8.085192016271241, -0.15233612156201284`, 0.},
       RotationMatrix :> {{0.9935834008051853, -0.11310183749347974`, 0.}, {
       0.11310183749347974`, 0.9935834008051853, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013999677330604303`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18810166920268867`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.321580040676373`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.001554021194934196, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9935834008051853, -0.11310183749347974`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.888113141749456, -0.22169323589710355`, 0.},
       Optica`Optica`RayEnd :> {7.9413563276372345`, -0.3837138304238663, 0.},
       RotationMatrix :> {{0.31219482035439217`, -0.9500181020085291, 0.}, {
       0.9500181020085291, 0.31219482035439217`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06481621287350493, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17054474455193916`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.355707214296356`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2785859887355446, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.31219482035439217`, -0.9500181020085291, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.9413563276372345`, -0.3837138304238663, 0.},
       Optica`Optica`RayEnd :> {8.023749465279174, -0.6564234254441896, 0.}, 
      RotationMatrix :> {{0.28921598344717814`, -0.9572638690134924, 0.}, {
       0.9572638690134924, 0.28921598344717814`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06463714399228207, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28488445437866977`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.777336206776788`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0020804093334473033`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.28921598344717814`, -0.9572638690134924, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.834918368184336, -0.34814076765746804`, 0.},
       Optica`Optica`RayEnd :> {7.220197575325882, -1.1366431247685609`, 0.}, 
      RotationMatrix :> {{-0.6148383549377238, -0.7886531539894281, 0.}, {
       0.7886531539894281, -0.6148383549377238, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010248633872102194`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9998087918908676, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.669949109023904`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3597912876602244, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6148383549377238, -0.7886531539894281, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.220197575325882, -1.1366431247685609`, 0.}, 
      Optica`Optica`RayEnd :> {7.110066133937232, -1.3196122735009896`, 0.}, 
      RotationMatrix :> {{-0.515700160526837, -0.856769131349043, 0.}, {
       0.856769131349043, -0.515700160526837, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010095283466440808`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21355712062633594`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.98601364755088, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10302899520380335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.515700160526837, -0.856769131349043, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.319840476503305, -0.3754533054975368, 0.}, 
      Optica`Optica`RayEnd :> {5.329960608744796, -0.6756262338699552, 0.}, 
      RotationMatrix :> {{0.03369519575465825, -0.9994321556679342, 0.}, {
       0.9994321556679342, 0.03369519575465825, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04703559253210442, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3003434767133428, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.25508065441358, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20497303622615626`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03369519575465825, -0.9994321556679342, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.329960608744796, -0.6756262338699552, 0.}, 
      Optica`Optica`RayEnd :> {5.311374477317961, -0.8702033506379357, 0.}, 
      RotationMatrix :> {{-0.09508782877901711, -0.9954688869161561, 0.}, {
       0.9954688869161561, -0.09508782877901711, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.046203128067370994`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19546278073115575`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.54436556989569, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11492887780492672`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.09508782877901711, -0.9954688869161561, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9646265652922676`, 0.4058709806656777, 0.}, 
      Optica`Optica`RayEnd :> {2.871601740402528, 0.35450208351356993`, 0.}, 
      RotationMatrix :> {{-0.875399083411589, -0.48340091514409506`, 0.}, {
       0.48340091514409506`, -0.875399083411589, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03287373702118617, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10626561833627353`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.304482030411748`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17268939012050002`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.875399083411589, -0.48340091514409506`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.871601740402528, 0.35450208351356993`, 0.}, 
      Optica`Optica`RayEnd :> {2.568609747241561, 0.17993281888803214`, 0.}, 
      RotationMatrix :> {{-0.8664748581881636, -0.4992207128393218, 0.}, {
       0.4992207128393218, -0.8664748581881636, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032787214709693056`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3496835370324953, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.822013665219842`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17184486021544004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8664748581881636, -0.4992207128393218, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1344910450342534`, 2.2090378699962967`, 0.},
       Optica`Optica`RayEnd :> {2.605605904911915, 2.0102812707078206`, 0.}, 
      RotationMatrix :> {{-0.9360818334808005, -0.35178232051543135`, 0.}, {
       0.35178232051543135`, -0.9360818334808005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01061281930741165, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5649988293819249, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.20956599149162, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32796742749639435`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9360818334808005, -0.35178232051543135`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.605605904911915, 2.0102812707078206`, 0.}, 
      Optica`Optica`RayEnd :> {2.352085693409248, 1.914169228756334, 0.}, 
      RotationMatrix :> {{-0.9350596388448165, -0.35449043965021126`, 0.}, {
       0.35449043965021126`, -0.9350596388448165, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010586617895193861`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2711273174146073, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.572876596827193`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19146272063299447`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9350596388448165, -0.35449043965021126`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1808192602493235`, 2.3452581568970534`, 0.},
       Optica`Optica`RayEnd :> {3.1380886835098276`, 2.34835699848299, 0.}, 
      RotationMatrix :> {{-0.9973807176024674, 0.0723305202164796, 
       0.}, {-0.0723305202164796, -0.9973807176024674, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017466034520592713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0428427941159851, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.337200602344144`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0517094355627241, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9973807176024674, 0.0723305202164796, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1380886835098276`, 2.34835699848299, 0.}, 
      Optica`Optica`RayEnd :> {2.9377092946462433`, 2.335707755262018, 0.}, 
      RotationMatrix :> {{-0.998013459705856, -0.06300106543501682, 0.}, {
       0.06300106543501682, -0.998013459705856, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01711559636621599, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20077824293335875`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.606243447874846`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4272833743107952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.998013459705856, -0.06300106543501682, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.013239309426549, -0.6172267168862021, 0.}, 
      Optica`Optica`RayEnd :> {2.9142006442519786`, -0.7002105201445175, 0.}, 
      RotationMatrix :> {{-0.7664996704176925, -0.6422447004449072, 0.}, {
       0.6422447004449072, -0.7664996704176925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01815935922186763, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12920901208033217`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.160904061840075`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2581930716791184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7664996704176925, -0.6422447004449072, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9142006442519786`, -0.7002105201445175, 0.},
       Optica`Optica`RayEnd :> {2.7009504064931456`, -0.886442425745927, 0.}, 
      RotationMatrix :> {{-0.7532100811450123, -0.6577800344047574, 0.}, {
       0.6577800344047574, -0.7532100811450123, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018110736853952092`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28312185816028257`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.540287351774854`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4011573970635167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7532100811450123, -0.6577800344047574, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.640428094261788, -1.1038480785083356`, 0.}, 
      Optica`Optica`RayEnd :> {7.653211682028765, -1.1404403509867747`, 0.}, 
      RotationMatrix :> {{0.3298054827835016, -0.9440489094988357, 0.}, {
       0.9440489094988357, 0.3298054827835016, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012123497845521093`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03876099226454786, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.418290946089588`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30701026992928165`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3298054827835016, -0.9440489094988357, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.653211682028765, -1.1404403509867747`, 0.}, 
      Optica`Optica`RayEnd :> {7.766147741904659, -1.4105064288629432`, 0.}, 
      RotationMatrix :> {{0.3858042009256227, -0.92258068403156, 0.}, {
       0.92258068403156, 0.3858042009256227, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012067911144361454`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29272895319682385`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.851529796820888`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29903547629841165`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3858042009256227, -0.92258068403156, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.264465092946304, 1.5995015474563508`, 0.}, 
      Optica`Optica`RayEnd :> {3.1433883712892046`, 1.578667178518207, 0.}, 
      RotationMatrix :> {{-0.9855158418705532, -0.16958338781311558`, 0.}, {
       0.16958338781311558`, -0.9855158418705532, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010633936250374093`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12285619014230179`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.78321791986385, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2834046276482186, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9855158418705532, -0.16958338781311558`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1433883712892046`, 1.578667178518207, 0.}, 
      Optica`Optica`RayEnd :> {2.8156411223846534`, 1.5132813511973178`, 0.}, 
      RotationMatrix :> {{-0.9806747138124245, -0.19564535693166354`, 0.}, {
       0.19564535693166354`, -0.9806747138124245, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01060386785010563, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3342058730467478, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.27784261197304, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.025358560621933583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9806747138124245, -0.19564535693166354`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.4640233858549445`, 1.9477339013071668`, 0.},
       Optica`Optica`RayEnd :> {5.332146241952127, 1.7879499890282105`, 0.}, 
      RotationMatrix :> {{-0.6365420976434009, -0.7712419580959907, 0.}, {
       0.7712419580959907, -0.6365420976434009, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010578083736072108`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2071774111893809, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.946011918022883`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3886535976914831, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6365420976434009, -0.7712419580959907, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.332146241952127, 1.7879499890282105`, 0.}, 
      Optica`Optica`RayEnd :> {5.1875130680893315`, 1.639042991257376, 0.}, 
      RotationMatrix :> {{-0.6967377540287782, -0.7173259385460228, 0.}, {
       0.7173259385460228, -0.6967377540287782, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010506174175654186`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20758624464725173`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.253239560100816`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3031124080926821, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6967377540287782, -0.7173259385460228, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.862360376716455, 1.1678882075169161`, 0.}, 
      Optica`Optica`RayEnd :> {7.880779110920352, 1.1105665064762662`, 0.}, 
      RotationMatrix :> {{0.30591737718627754`, -0.9520580645819181, 0.}, {
       0.9520580645819181, 0.30591737718627754`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009877563224781047, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06020819861005196, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.98460434190997, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20315234547840683`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.30591737718627754`, -0.9520580645819181, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.880779110920352, 1.1105665064762662`, 0.}, 
      Optica`Optica`RayEnd :> {7.977761929985089, 0.8882111978820659, 0.}, 
      RotationMatrix :> {{0.39978878678824076`, -0.9166072910240162, 0.}, {
       0.9166072910240162, 0.39978878678824076`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009778346537379792, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2425851406285336, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.3436303500402, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37676527711457697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.39978878678824076`, -0.9166072910240162, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.380816080976115, -0.003170653943217805, 0.},
       Optica`Optica`RayEnd :> {7.29815300656839, -0.1434792057361047, 0.}, 
      RotationMatrix :> {{-0.507606841033086, -0.8615888201087628, 0.}, {
       0.8615888201087628, -0.507606841033086, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012581741052048123`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16284862166059086`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.666600144169266`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07564419902996472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.507606841033086, -0.8615888201087628, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.29815300656839, -0.1434792057361047, 0.}, 
      Optica`Optica`RayEnd :> {7.14183109987971, -0.3988120264075526, 0.}, 
      RotationMatrix :> {{-0.5221433883431844, -0.852857714985036, 0.}, {
       0.852857714985036, -0.5221433883431844, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012548900588498939`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29938501602923023`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.067776065648435`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3735867639902099, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.5221433883431844, -0.852857714985036, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8900303313193105`, 1.3625771376378866`, 0.},
       Optica`Optica`RayEnd :> {2.8701993775974306`, 1.3585039727833168`, 0.},
       RotationMatrix :> {{-0.9795513602740505, -0.20119426578621982`, 0.}, {
       0.20119426578621982`, -0.9795513602740505, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00988167758590537, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0202449351061407, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.243954264516255`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07891825959789969, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9795513602740505, -0.20119426578621982`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8701993775974306`, 1.3585039727833168`, 0.},
       Optica`Optica`RayEnd :> {2.5939123039010066`, 1.2797169994967676`, 0.},
       RotationMatrix :> {{-0.9616637503119198, -0.27423134637749275`, 0.}, {
       0.27423134637749275`, -0.9616637503119198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009821481803894826, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28730112121498697`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.669159923914435`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1634954135062128, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9616637503119198, -0.27423134637749275`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9274205586807724`, -1.6459941452217333`, 
       0.}, Optica`Optica`RayEnd :> {2.880748875491625, -1.6966098945074817`, 
       0.}, RotationMatrix :> {{-0.677883599389129, -0.735169249682845, 0.}, {
       0.735169249682845, -0.677883599389129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01200788007372809, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06884911101434685, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.84521867449161, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36692350339243246`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.677883599389129, -0.735169249682845, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.880748875491625, -1.6966098945074817`, 0.}, 
      Optica`Optica`RayEnd :> {2.6744488706177325`, -1.8935461606096162`, 0.},
       RotationMatrix :> {{-0.7233318425115661, -0.6905005761104196, 0.}, {
       0.6905005761104196, -0.7233318425115661, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011948967157664725`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2852079678361369, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.26732646688909, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35632309782163374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7233318425115661, -0.6905005761104196, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0824279862392947`, -0.7938827603812862, 0.},
       Optica`Optica`RayEnd :> {2.0544620146035415`, -0.8470505500838811, 0.},
       RotationMatrix :> {{-0.46552383424891314`, -0.8850353437836197, 0.}, {
       0.8850353437836197, -0.46552383424891314`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011947393963060755`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.060074199382023435`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.532965032160426`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.019030763755236903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46552383424891314`, -0.8850353437836197, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0544620146035415`, -0.8470505500838811, 0.},
       Optica`Optica`RayEnd :> {1.8756163776684474`, -1.1869631499097286`, 
       0.}, RotationMatrix :> {{-0.4656328046451193, -0.8849780173757535, 
       0.}, {0.8849780173757535, -0.4656328046451193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011917947551899127`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3840915741995471, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.101420561975758`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.422554701070049, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4656328046451193, -0.8849780173757535, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9177412468353956`, -2.1479226278260843`, 
       0.}, Optica`Optica`RayEnd :> {3.9031775651540577`, -2.147791139500906, 
       0.}, RotationMatrix :> {{-0.9999592455078385, 0.009028140638815546, 
       0.}, {-0.009028140638815546, -0.9999592455078385, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016976120737314512`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.014564275240979084`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.950650099856702`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2402778847021325, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999592455078385, 0.009028140638815546, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9031775651540577`, -2.147791139500906, 0.}, 
      Optica`Optica`RayEnd :> {3.6672522571574695`, -2.159269702104077, 0.}, 
      RotationMatrix :> {{-0.9988185216654466, -0.04859589260474449, 0.}, {
       0.04859589260474449, -0.9988185216654466, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01690142703356013, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23620437835213806`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.300232579817866`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2168878890818213, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9988185216654466, -0.04859589260474449, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.071169419359076, -2.318045595221131, 0.}, 
      Optica`Optica`RayEnd :> {4.914250378235094, -2.2890980576784323`, 0.}, 
      RotationMatrix :> {{-0.9834069330711055, 0.1814133511836486, 
       0.}, {-0.1814133511836486, -0.9834069330711055, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011121380246321502`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15956674276632934`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.97085367922174, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3539632176268873, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9834069330711055, 0.1814133511836486, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.914250378235094, -2.2890980576784323`, 0.}, 
      Optica`Optica`RayEnd :> {4.626555883353152, -2.233817827673968, 0.}, 
      RotationMatrix :> {{-0.982035323206953, 0.1886971753201807, 
       0.}, {-0.1886971753201807, -0.982035323206953, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011093664199602598`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29295737951914097`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.404430600910068`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05937510435279242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.982035323206953, 0.1886971753201807, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.193310352004639, 1.0700518446392056`, 0.}, 
      Optica`Optica`RayEnd :> {8.207500799389074, 1.1265603554403336`, 0.}, 
      RotationMatrix :> {{0.24355835151179914`, 0.9698862456024699, 
       0.}, {-0.9698862456024699, 0.24355835151179914`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009288963446633084, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05826302935766061, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.046738796343718`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43165766588515453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.24355835151179914`, 0.9698862456024699, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.207500799389074, 1.1265603554403336`, 0.}, 
      Optica`Optica`RayEnd :> {8.300156147257562, 1.4583259666974322`, 0.}, 
      RotationMatrix :> {{0.26898640737317486`, 0.963143972959636, 
       0.}, {-0.963143972959636, 0.26898640737317486`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009262750743684305, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3444610780646004, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.556541191879326`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23844875780145916`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.26898640737317486`, 0.963143972959636, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.413118909568857, 1.5107447399974474`, 0.}, 
      Optica`Optica`RayEnd :> {4.349313759099647, 1.5968430133600238`, 0.}, 
      RotationMatrix :> {{-0.5954001751014709, 0.8034292946421218, 
       0.}, {-0.8034292946421218, -0.5954001751014709, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012472944599581818`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10716347279934299`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.016843954835156`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0665866277763446, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5954001751014709, 0.8034292946421218, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.349313759099647, 1.5968430133600238`, 0.}, 
      Optica`Optica`RayEnd :> {4.162346604277734, 1.862138328747747, 0.}, 
      RotationMatrix :> {{-0.5760658396245705, 0.8174032960648239, 
       0.}, {-0.8174032960648239, -0.5760658396245705, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012438560679173198`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3245586562531845, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.49719076608987, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33455481669739323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5760658396245705, 0.8174032960648239, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6249144125819277`, -4.291219948717063, 0.}, 
      Optica`Optica`RayEnd :> {3.5146907617059844`, -4.384345781536437, 0.}, 
      RotationMatrix :> {{-0.7638656328061989, -0.6453753133003969, 0.}, {
       0.6453753133003969, -0.7638656328061989, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08542359141431197, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1442971723587258, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.402734722132653`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08537311844803064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7638656328061989, -0.6453753133003969, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5146907617059844`, -4.384345781536437, 0.}, 
      Optica`Optica`RayEnd :> {3.2909883109441656`, -4.5946589053852165`, 0.},
       RotationMatrix :> {{-0.7285743230550108, -0.6849667552406707, 0.}, {
       0.6849667552406707, -0.7285743230550108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08507614425715486, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3070413596567665, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.857155934424668`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14313498468183122`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7285743230550108, -0.6849667552406707, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.616473148431152, -3.839546036759751, 0.}, 
      Optica`Optica`RayEnd :> {5.580849709699812, -3.8600389169282856`, 0.}, 
      RotationMatrix :> {{-0.866807416884748, -0.4986430607494606, 0.}, {
       0.4986430607494606, -0.866807416884748, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013211472192729126`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04109729339807446, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.4058542938674, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05502141007377193, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.866807416884748, -0.4986430607494606, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.580849709699812, -3.8600389169282856`, 0.}, 
      Optica`Optica`RayEnd :> {5.362099643024295, -4.006547355628791, 0.}, 
      RotationMatrix :> {{-0.830864996548899, -0.5564740402838192, 0.}, {
       0.5564740402838192, -0.830864996548899, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013141193910169713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2632799162127695, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.7955085698623, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01140318736123791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.830864996548899, -0.5564740402838192, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.579937962894859, -4.3161032824231205`, 0.}, 
      Optica`Optica`RayEnd :> {7.583838827532015, -4.362254507597883, 0.}, 
      RotationMatrix :> {{0.08422321423816159, -0.9964469128776464, 0.}, {
       0.9964469128776464, 0.08422321423816159, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.053134281790179844`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.046315789208962684`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.528235170816462`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04524728368670884, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.08422321423816159, -0.9964469128776464, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.583838827532015, -4.362254507597883, 0.}, 
      Optica`Optica`RayEnd :> {7.592086742145651, -4.625886100022921, 0.}, 
      RotationMatrix :> {{0.031270459561902705`, -0.9995109595991364, 0.}, {
       0.9995109595991364, 0.031270459561902705`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.052918151944205384`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26376058200579416`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.91860083218504, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.014031868827100887`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.031270459561902705`, -0.9995109595991364, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.666259953006467, -4.416423503191367, 0.}, 
      Optica`Optica`RayEnd :> {7.813075213571055, -4.507642203723091, 0.}, 
      RotationMatrix :> {{0.849401620577258, -0.527746991427452, 0.}, {
       0.527746991427452, 0.849401620577258, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11090223339995614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17284551501657283`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.893658028096677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014668424167825656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.849401620577258, -0.527746991427452, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.813075213571055, -4.507642203723091, 0.}, 
      Optica`Optica`RayEnd :> {8.074781152017092, -4.648738151644846, 0.}, 
      RotationMatrix :> {{0.8802219591084146, -0.4745622221620085, 0.}, {
       0.4745622221620085, 0.8802219591084146, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11037993616003676`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2973181204330792, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.333688846337633`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014459614682136687`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8802219591084146, -0.4745622221620085, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.798279980013547, -4.407131294580484, 0.}, 
      Optica`Optica`RayEnd :> {7.862689890837578, -4.381808975953809, 0.}, 
      RotationMatrix :> {{0.9306608602189673, 0.36588299120960904`, 
       0.}, {-0.36588299120960904`, 0.9306608602189673, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028987793631739634`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06920878869761084, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.950657839527288`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.351813195550991, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9306608602189673, 0.36588299120960904`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.862689890837578, -4.381808975953809, 0.}, 
      Optica`Optica`RayEnd :> {8.051406858091678, -4.344427070346459, 0.}, 
      RotationMatrix :> {{0.9809403562038274, 0.19430907742745201`, 
       0.}, {-0.19430907742745201`, 0.9809403562038274, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02770677081002304, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19238373267098713`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.23538576388035, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06203807834490353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9809403562038274, 0.19430907742745201`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.929734262581606, -3.1213235621942435`, 0.}, 
      Optica`Optica`RayEnd :> {6.9071799002491305`, -3.203089436157028, 0.}, 
      RotationMatrix :> {{-0.26590992557074056`, -0.9639978793975441, 0.}, {
       0.9639978793975441, -0.26590992557074056`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020192140213091986`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0848195579163353, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.703323444490355`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3879035494053713, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.26590992557074056`, -0.9639978793975441, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9071799002491305`, -3.203089436157028, 0.}, 
      Optica`Optica`RayEnd :> {6.8268878473143895`, -3.3719473963555866`, 0.},
       RotationMatrix :> {{-0.42942560920243233`, -0.9031022346119617, 0.}, {
       0.9031022346119617, -0.42942560920243233`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019363456096660202`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.186975464932951, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.98004713259112, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0001399542236404927, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.42942560920243233`, -0.9031022346119617, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.134348357352752, 3.424274933828437, 0.}, 
      Optica`Optica`RayEnd :> {4.103650192613267, 3.4444959002671793`, 0.}, 
      RotationMatrix :> {{-0.8351071080054805, 0.5500873732042233, 
       0.}, {-0.5500873732042233, -0.8351071080054805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008170223990989801, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03675955388860637, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.96516757551511, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14944949831076743`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8351071080054805, 0.5500873732042233, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.103650192613267, 3.4444959002671793`, 0.}, 
      Optica`Optica`RayEnd :> {3.862323337613243, 3.6088293415498454`, 0.}, 
      RotationMatrix :> {{-0.8265581445262079, 0.5628513424674335, 
       0.}, {-0.5628513424674335, -0.8265581445262079, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008149113919701217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2919659755314063, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.397277219301593`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21838457361184738`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.8265581445262079, 0.5628513424674335, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.628548247530289, -1.346088855764899, 0.}, 
      Optica`Optica`RayEnd :> {4.614717322515146, -1.3601992666660045`, 0.}, 
      RotationMatrix :> {{-0.6999988607116395, -0.7141439595784637, 0.}, {
       0.7141439595784637, -0.6999988607116395, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1665558948911391, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01975849646538294, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.510908857698006`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00586320199882984, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6999988607116395, -0.7141439595784637, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.614717322515146, -1.3601992666660045`, 0.}, 
      Optica`Optica`RayEnd :> {4.414914889031484, -1.574690063371122, 0.}, 
      RotationMatrix :> {{-0.6816087460521115, -0.731716828633364, 0.}, {
       0.731716828633364, -0.6816087460521115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16608988290248408`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29313361168107127`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.94474660298599, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2751612624956993, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6816087460521115, -0.731716828633364, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.451625246734025, 2.8573328742422452`, 0.}, 
      Optica`Optica`RayEnd :> {4.42224035122515, 2.8539994316229933`, 0.}, 
      RotationMatrix :> {{-0.9936270492845508, -0.11271773121419411`, 0.}, {
       0.11271773121419411`, -0.9936270492845508, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03576966796814638, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.029573365107193435`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.0373139634245, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3219477493569971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9936270492845508, -0.11271773121419411`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.42224035122515, 2.8539994316229933`, 0.}, 
      Optica`Optica`RayEnd :> {4.107906924151698, 2.811140438077034, 0.}, 
      RotationMatrix :> {{-0.9908321325761488, -0.1350987973839866, 0.}, {
       0.1350987973839866, -0.9908321325761488, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03567219812241412, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31724185837230456`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.50683191381551, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03825875669029738, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9908321325761488, -0.1350987973839866, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.234404632860996, 1.5925539569764573`, 0.}, 
      Optica`Optica`RayEnd :> {4.134558778891135, 1.5841778176651693`, 0.}, 
      RotationMatrix :> {{-0.9964996395519825, -0.08359705959403269, 0.}, {
       0.08359705959403269, -0.9964996395519825, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032181807683953075`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10019657810890047`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.302315258797105`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19189723191103558`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9964996395519825, -0.08359705959403269, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.134558778891135, 1.5841778176651693`, 0.}, 
      Optica`Optica`RayEnd :> {3.8776235649819144`, 1.547137372789917, 0.}, 
      RotationMatrix :> {{-0.9897677918521672, -0.14268748442692544`, 0.}, {
       0.14268748442692544`, -0.9897677918521672, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032035557953147414`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2595914072212974, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.686510541484626`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1793819458434333, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9897677918521672, -0.14268748442692544`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.604009722506619, 2.7158150708953386`, 0.}, 
      Optica`Optica`RayEnd :> {4.405039731031097, 2.7092409194679954`, 0.}, 
      RotationMatrix :> {{-0.9994545953506369, -0.03302289860829227, 0.}, {
       0.03302289860829227, -0.9994545953506369, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0400293251945714, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19907856985310834`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.720650283350786`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2233359914106789, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9994545953506369, -0.03302289860829227, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.405039731031097, 2.7092409194679954`, 0.}, 
      Optica`Optica`RayEnd :> {4.128791118712853, 2.7182553933505633`, 0.}, 
      RotationMatrix :> {{-0.9994680094775336, 0.032614383805547924`, 
       0.}, {-0.032614383805547924`, -0.9994680094775336, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03982590242782695, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2763956521856576, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.12971584858556, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2479691546986304, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9994680094775336, 0.032614383805547924`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.215440038407017, -2.401181598702991, 0.}, 
      Optica`Optica`RayEnd :> {8.187344793038829, -2.6271694339600202`, 0.}, 
      RotationMatrix :> {{-0.12337217585412556`, -0.9923604719178498, 0.}, {
       0.9923604719178498, -0.12337217585412556`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24821266546239837`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22772756639558797`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.897695493446605`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43141987757580913`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12337217585412556`, -0.9923604719178498, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.187344793038829, -2.6271694339600202`, 0.}, 
      Optica`Optica`RayEnd :> {8.170792281269932, -2.938696871178345, 0.}, 
      RotationMatrix :> {{-0.05305855591377279, -0.9985914027490643, 0.}, {
       0.9985914027490643, -0.05305855591377279, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24682851916630746`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3119668728978719, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.359406465335457`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40220867158495044`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05305855591377279, -0.9985914027490643, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.630380699138552, -0.7899309361355071, 0.}, 
      Optica`Optica`RayEnd :> {5.345367726580626, -0.8221047988375817, 0.}, 
      RotationMatrix :> {{-0.9936886757633983, -0.11217315035062214`, 0.}, {
       0.11217315035062214`, -0.9936886757633983, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06336222682338886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2868232068147148, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.92991972362567, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2953762281667847, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9936886757633983, -0.11217315035062214`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.345367726580626, -0.8221047988375817, 0.}, 
      Optica`Optica`RayEnd :> {5.081982035900316, -0.837429909266994, 0.}, 
      RotationMatrix :> {{-0.9983115358056259, -0.05808680984020139, 0.}, {
       0.05808680984020139, -0.9983115358056259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06309905247534335, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2638311601475806, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.32038984064409, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25338999816964786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9983115358056259, -0.05808680984020139, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.8301339973671515`, -3.0309964858953027`, 
       0.}, Optica`Optica`RayEnd :> {5.78627592501987, -3.131449517541143, 
       0.}, 
      RotationMatrix :> {{-0.4001285525216335, -0.9164590233376184, 0.}, {
       0.9164590233376184, -0.4001285525216335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0180272227463565, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10960995427815691`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.688796391001407`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.016742188603198354`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4001285525216335, -0.9164590233376184, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.78627592501987, -3.131449517541143, 0.}, 
      Optica`Optica`RayEnd :> {5.656320172600433, -3.4231682308452736`, 0.}, 
      RotationMatrix :> {{-0.40693057346067935`, -0.9134590896055289, 0.}, {
       0.9134590896055289, -0.40693057346067935`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01798229336808007, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3193560791322432, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.161443388117128`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38270341611072156`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.40693057346067935`, -0.9134590896055289, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.104736350691827, -3.6563018927554336`, 0.}, 
      Optica`Optica`RayEnd :> {6.968545787671244, -3.8511629426954896`, 0.}, 
      RotationMatrix :> {{-0.5728632203601849, -0.8196509810636217, 0.}, {
       0.8196509810636217, -0.5728632203601849, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16873709847124718`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2377366152690919, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.31213347426592, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31744161868268717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5728632203601849, -0.8196509810636217, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.968545787671244, -3.8511629426954896`, 0.}, 
      Optica`Optica`RayEnd :> {6.848439921609096, -4.060339923633495, 0.}, 
      RotationMatrix :> {{-0.4979385631224341, -0.8672123081204307, 0.}, {
       0.8672123081204307, -0.4979385631224341, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1673942821251315, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2412061948144733, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.66911864259134, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17805309362806498`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4979385631224341, -0.8672123081204307, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3206781979850604`, 1.4260747983155784`, 0.},
       Optica`Optica`RayEnd :> {2.1758216835623503`, 1.4729453427395387`, 0.},
       RotationMatrix :> {{-0.9514345122462747, 0.3078512122871897, 
       0.}, {-0.3078512122871897, -0.9514345122462747, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029736594546280398`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15225064106694364`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.323342752239917`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3203347252448892, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9514345122462747, 0.3078512122871897, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1758216835623503`, 1.4729453427395387`, 0.},
       Optica`Optica`RayEnd :> {1.8240741026616254`, 1.588190619940066, 0.}, 
      RotationMatrix :> {{-0.9502949429359593, 0.3113511224170245, 
       0.}, {-0.3113511224170245, -0.9502949429359593, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029663102732973772`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3701456937295615, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.871158378959667`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1388510399541724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9502949429359593, 0.3113511224170245, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8297096805049433`, -1.02433477027403, 0.}, 
      Optica`Optica`RayEnd :> {2.800016384379107, -1.0857634080385206`, 0.}, 
      RotationMatrix :> {{-0.4352017830402683, -0.9003329428820043, 0.}, {
       0.9003329428820043, -0.4352017830402683, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23140425462825842`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06822880163404325, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.79274536701191, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2385430603092584, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4352017830402683, -0.9003329428820043, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.800016384379107, -1.0857634080385206`, 0.}, 
      Optica`Optica`RayEnd :> {2.690471506059175, -1.3392204971550752`, 0.}, 
      RotationMatrix :> {{-0.3967336079335279, -0.9179337908237418, 0.}, {
       0.9179337908237418, -0.3967336079335279, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23060867096257184`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27611696143041575`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.201398469928925`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35204738587886847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3967336079335279, -0.9179337908237418, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.860881282240003, -1.4002161107014388`, 0.}, 
      Optica`Optica`RayEnd :> {3.792643879086505, -1.6915080459494076`, 0.}, 
      RotationMatrix :> {{-0.22808313740624536`, -0.9736416601763315, 0.}, {
       0.9736416601763315, -0.22808313740624536`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023607582821963784`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2991777644305136, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.106277843298596`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1118689625916523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22808313740624536`, -0.9736416601763315, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.792643879086505, -1.6915080459494076`, 0.}, 
      Optica`Optica`RayEnd :> {3.7253197317359628`, -1.9226930520229284`, 0.},
       RotationMatrix :> {{-0.2795988123777768, -0.9601169221073733, 0.}, {
       0.9601169221073733, -0.2795988123777768, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023511201945448527`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24078838811224115`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.46264465770471, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16726408989599084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2795988123777768, -0.9601169221073733, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.07555611396809, -1.8117704305492082`, 0.}, 
      Optica`Optica`RayEnd :> {4.035231998209413, -1.9062904564970764`, 0.}, 
      RotationMatrix :> {{-0.39240222582405593`, -0.9197937231620609, 0.}, {
       0.9197937231620609, -0.39240222582405593`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008413420699703935, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10276219935805601`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.84760185343422, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0472410527495915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39240222582405593`, -0.9197937231620609, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.035231998209413, -1.9062904564970764`, 0.}, 
      Optica`Optica`RayEnd :> {3.9291983209491628`, -2.1531670824734057`, 0.},
       RotationMatrix :> {{-0.3946405111871178, -0.9188356038650057, 0.}, {
       0.9188356038650057, -0.3946405111871178, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008392659555218038, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.268684218306151, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.245254496527323`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3935139420333731, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3946405111871178, -0.9188356038650057, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6958045992808475`, -0.8824309136322641, 0.},
       Optica`Optica`RayEnd :> {2.7450952301165734`, -1.0947326431897753`, 
       0.}, RotationMatrix :> {{0.22615713822353045`, -0.9740908319199715, 
       0.}, {0.9740908319199715, 0.22615713822353045`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00974214948091065, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21794859637376535`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.556818839432186`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38333085627640495`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.22615713822353045`, -0.9740908319199715, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7450952301165734`, -1.0947326431897753`, 
       0.}, Optica`Optica`RayEnd :> {2.81530561668199, -1.3819969648385397`, 
       0.}, RotationMatrix :> {{0.23742188021794114`, -0.9714066351398764, 
       0.}, {0.9714066351398764, 0.23742188021794114`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00971748232989414, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29571995007775514`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.99448436554726, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19203645807285535`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.23742188021794114`, -0.9714066351398764, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.834619754427745, 3.8806501516394767`, 0.}, 
      Optica`Optica`RayEnd :> {7.134549649453645, 3.7150840089529598`, 0.}, 
      RotationMatrix :> {{0.8754695343480123, -0.4832733123486892, 0.}, {
       0.4832733123486892, 0.8754695343480123, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021144641997327355`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.342593183724282, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.3153425869504, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009874740023431137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8754695343480123, -0.4832733123486892, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.134549649453645, 3.7150840089529598`, 0.}, 
      Optica`Optica`RayEnd :> {7.396143214128973, 3.5870377413582615`, 0.}, 
      RotationMatrix :> {{0.8981728028524918, -0.4396426005474198, 0.}, {
       0.4396426005474198, 0.8981728028524918, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021063892986337974`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29125081926833685`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.74639379946754, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07795412601090408, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8981728028524918, -0.4396426005474198, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.690322061937462, 0.9829898218117369, 0.}, 
      Optica`Optica`RayEnd :> {7.7545209504678905`, 0.9231714981215575, 0.}, 
      RotationMatrix :> {{0.7316271028101149, -0.6817050553088748, 0.}, {
       0.6817050553088748, 0.7316271028101149, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010929856383479403`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08774810047884439, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.842978857213573`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3327395403348699, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7316271028101149, -0.6817050553088748, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.7545209504678905`, 0.9231714981215575, 0.}, 
      Optica`Optica`RayEnd :> {7.951636345348979, 0.7137730150913497, 0.}, 
      RotationMatrix :> {{0.6854282558257283, -0.7281401692776593, 0.}, {
       0.7281401692776593, 0.6854282558257283, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010874451028889988`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28757990818984525`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.268597121334544`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3524378508410988, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6854282558257283, -0.7281401692776593, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.085192016271241, -0.15233612156201284`, 0.},
       Optica`Optica`RayEnd :> {8.118623229274593, -0.15076632007160554`, 0.},
       RotationMatrix :> {{0.9988993790932295, 0.04690448216492202, 
       0.}, {-0.04690448216492202, 0.9988993790932295, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013554145426743982`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.033468048637392, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.36642722585048, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24929529848182583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9988993790932295, 0.04690448216492202, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.118623229274593, -0.15076632007160554`, 0.},
       Optica`Optica`RayEnd :> {8.417195633114394, -0.1544898434743955, 0.}, 
      RotationMatrix :> {{0.9999222450233339, -0.01247012058861402, 0.}, {
       0.01247012058861402, 0.9999222450233339, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013492646147050695`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2985956211353542, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.808348745130804`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.261414514679726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999222450233339, -0.01247012058861402, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.023749465279174, -0.6564234254441896, 0.}, 
      Optica`Optica`RayEnd :> {8.086800653178619, -0.8848543317206131, 0.}, 
      RotationMatrix :> {{0.26606924853890035`, -0.9639539174576469, 0.}, {
       0.9639539174576469, 0.26606924853890035`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06445856982777903, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2369728491574494, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.09487982464777, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1066906987568117, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26606924853890035`, -0.9639539174576469, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.086800653178619, -0.8848543317206131, 0.}, 
      Optica`Optica`RayEnd :> {8.140126437614487, -1.1365465124910128`, 0.}, 
      RotationMatrix :> {{0.20726814239280966`, -0.9782841699368507, 0.}, {
       0.9782841699368507, 0.20726814239280966`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06416011546702369, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2572792124262284, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.47565305903859, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10057339137546768`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.20726814239280966`, -0.9782841699368507, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.110066133937232, -1.3196122735009896`, 0.}, 
      Optica`Optica`RayEnd :> {7.060689219099167, -1.4297462813242712`, 0.}, 
      RotationMatrix :> {{-0.40910072957505167`, -0.9124892290110386, 0.}, {
       0.9124892290110386, -0.40910072957505167`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009944227644351244, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12069622777097924`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.147746592763994`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16563167506477064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.40910072957505167`, -0.9124892290110386, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.060689219099167, -1.4297462813242712`, 0.}, 
      Optica`Optica`RayEnd :> {6.941744632947714, -1.6665184367310864`, 0.}, 
      RotationMatrix :> {{-0.4488990576584635, -0.8935824729891152, 0.}, {
       0.8935824729891152, -0.4488990576584635, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009909143792764185, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2649695608003485, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.53990154274851, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27960128054951533`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4488990576584635, -0.8935824729891152, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.311374477317961, -0.8702033506379357, 0.}, 
      Optica`Optica`RayEnd :> {5.24895411678124, -1.1439807200337655`, 0.}, 
      RotationMatrix :> {{-0.22229232167071553`, -0.9749800632455218, 0.}, {
       0.9749800632455218, -0.22229232167071553`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04538539706399608, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28080304379196963`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.92064164857693, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29602271024202514`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22229232167071553`, -0.9749800632455218, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.24895411678124, -1.1439807200337655`, 0.}, 
      Optica`Optica`RayEnd :> {5.1971633524093805`, -1.411110251959242, 0.}, 
      RotationMatrix :> {{-0.1903345970382811, -0.9817192781901931, 0.}, {
       0.9817192781901931, -0.1903345970382811, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.045248087198569265`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27210378553218545`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.323355251164564`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42516194652017547`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1903345970382811, -0.9817192781901931, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.568609747241561, 0.17993281888803214`, 0.}, 
      Optica`Optica`RayEnd :> {2.527798254498685, 0.1554213130849209, 0.}, 
      RotationMatrix :> {{-0.8572647761548882, -0.5148758137299791, 0.}, {
       0.5148758137299791, -0.8572647761548882, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032700920121332896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04760663668689241, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.885806558380278`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13851756702950793`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8572647761548882, -0.5148758137299791, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.527798254498685, 0.1554213130849209, 0.}, 
      Optica`Optica`RayEnd :> {2.3141454695633144`, -0.0009303562125356022, 
       0.}, RotationMatrix :> {{-0.806993669737877, -0.5905600875465535, 
       0.}, {0.5905600875465535, -0.806993669737877, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03242944352826545, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26475150047306795`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.27763877908042, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.032177362798731124`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.806993669737877, -0.5905600875465535, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.352085693409248, 1.914169228756334, 0.}, 
      Optica`Optica`RayEnd :> {2.3220548648436976`, 1.9026847111612062`, 0.}, 
      RotationMatrix :> {{-0.9340296095394319, -0.35719558858364264`, 0.}, {
       0.35719558858364264`, -0.9340296095394319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010560481170217254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03215190210121743, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.620461411936994`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1358067990469982, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9340296095394319, -0.35719558858364264`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3220548648436976`, 1.9026847111612062`, 0.},
       Optica`Optica`RayEnd :> {2.2076719681319608`, 1.8799915918934478`, 0.},
       RotationMatrix :> {{-0.9808820565873183, -0.19460316303963696`, 0.}, {
       0.19460316303963696`, -0.9808820565873183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010165196285888195`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11661228375376495`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.776721872167037`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4009776269219245, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9808820565873183, -0.19460316303963696`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9377092946462433`, 2.335707755262018, 0.}, 
      Optica`Optica`RayEnd :> {2.8772032825485674`, 2.323538337846488, 0.}, 
      RotationMatrix :> {{-0.9803675469335719, -0.19717878415146556`, 0.}, {
       0.19717878415146556`, -0.9803675469335719, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01677218939570061, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.061717681584757274`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.697585616620287`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29599569316195024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9803675469335719, -0.19717878415146556`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8772032825485674`, 2.323538337846488, 0.}, 
      Optica`Optica`RayEnd :> {2.5359324408170836`, 2.2629931975671616`, 0.}, 
      RotationMatrix :> {{-0.9846247112754738, -0.1746830785900265, 0.}, {
       0.1746830785900265, -0.9846247112754738, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016726350294304044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3465999155042583, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.162029503395992`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03123080430615239, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9846247112754738, -0.1746830785900265, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7009504064931456`, -0.886442425745927, 0.}, 
      Optica`Optica`RayEnd :> {2.6416685364883628`, -0.9403888692305328, 0.}, 
      RotationMatrix :> {{-0.7396056803492987, -0.6730404427633236, 0.}, {
       0.6730404427633236, -0.7396056803492987, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018062244674257, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08015334600565172, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.65891430386322, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24373297826534568`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7396056803492987, -0.6730404427633236, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6416685364883628`, -0.9403888692305328, 0.},
       Optica`Optica`RayEnd :> {2.3882353982456106`, -1.1810577998572418`, 
       0.}, RotationMatrix :> {{-0.7251316508811504, -0.6886102590655887, 
       0.}, {0.6886102590655887, -0.7251316508811504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01801356295806492, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.349499484589854, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.127243613213626`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4155629061672085, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7251316508811504, -0.6886102590655887, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.766147741904659, -1.4105064288629432`, 0.}, 
      Optica`Optica`RayEnd :> {7.850274393352393, -1.582000064127832, 0.}, 
      RotationMatrix :> {{0.44041528122695717`, -0.8977941746646497, 0.}, {
       0.8977941746646497, 0.44041528122695717`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012012579310351976`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1910166495889174, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.107492107270037`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12162518057489652`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.44041528122695717`, -0.8977941746646497, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.850274393352393, -1.582000064127832, 0.}, 
      Optica`Optica`RayEnd :> {7.942643768053254, -1.6854126608445184`, 0.}, 
      RotationMatrix :> {{0.6661630257371991, -0.745806156545157, 0.}, {
       0.745806156545157, 0.6661630257371991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009876541128831037, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13865881343180483`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.31270715114911, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38600780776921695`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6661630257371991, -0.745806156545157, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8156411223846534`, 1.5132813511973178`, 0.},
       Optica`Optica`RayEnd :> {2.6527186743894404`, 1.4762625269830916`, 0.},
       RotationMatrix :> {{-0.9751445021579224, -0.2215698533446656, 0.}, {
       0.2215698533446656, -0.9751445021579224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010573884470912466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16707518489278017`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.501723359729365`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41679501707603656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9751445021579224, -0.2215698533446656, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6527186743894404`, 1.4762625269830916`, 0.},
       Optica`Optica`RayEnd :> {2.3269097514349193`, 1.4116366195782286`, 0.},
       RotationMatrix :> {{-0.9808897038733511, -0.19456461352272814`, 0.}, {
       0.19456461352272814`, -0.9808897038733511, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010543648094998134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3321565326539384, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.993315028057193`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21894454542123407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9808897038733511, -0.19456461352272814`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1875130680893315`, 1.639042991257376, 0.}, 
      Optica`Optica`RayEnd :> {5.138377464275786, 1.5960238694596374`, 0.}, 
      RotationMatrix :> {{-0.7523833964138529, -0.6587254547994587, 0.}, {
       0.6587254547994587, -0.7523833964138529, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01043475345470932, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06530660305336979, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.34075040819233, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20354449264559077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7523833964138529, -0.6587254547994587, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.138377464275786, 1.5960238694596374`, 0.}, 
      Optica`Optica`RayEnd :> {4.883148682769548, 1.3764357895408095`, 0.}, 
      RotationMatrix :> {{-0.758051082683954, -0.6521951824735319, 0.}, {
       0.6521951824735319, -0.758051082683954, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010408644686908277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33669074200458265`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.839052706359112`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3562380043117331, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.758051082683954, -0.6521951824735319, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.977761929985089, 0.8882111978820659, 0.}, 
      Optica`Optica`RayEnd :> {8.06130159699868, 0.7394461874404072, 0.}, 
      RotationMatrix :> {{0.48963488345671036`, -0.8719275663163383, 0.}, {
       0.8719275663163383, 0.48963488345671036`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009680126447098179, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1706162486296323, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.572256123203907`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11064395426443033`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.48963488345671036`, -0.8719275663163383, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.06130159699868, 0.7394461874404072, 0.}, 
      Optica`Optica`RayEnd :> {8.171750587440552, 0.6191664772526606, 0.}, 
      RotationMatrix :> {{0.6763652411882434, -0.7365663992556055, 0.}, {
       0.7365663992556055, 0.6763652411882434, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008708366501372047, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1632978510957119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.81393694282556, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36960504867205585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6763652411882434, -0.7365663992556055, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.14183109987971, -0.39881202640755253`, 0.}, 
      Optica`Optica`RayEnd :> {7.1216425990063, -0.4305655282711646, 0.}, 
      RotationMatrix :> {{-0.536529796765824, -0.8438813762504905, 0.}, {
       0.8438813762504905, -0.536529796765824, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012516145844091615`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.037627921124054525`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.123465388912035`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3971612922295429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.536529796765824, -0.8438813762504905, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.1216425990063, -0.4305655282711646, 0.}, 
      Optica`Optica`RayEnd :> {7.048745360448051, -0.5896979328317056, 0.}, 
      RotationMatrix :> {{-0.4164731812998279, -0.9091480018445837, 0.}, {
       0.9091480018445837, -0.4164731812998279, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012258600049010884`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17503465248526612`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.35801182324229, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02936632547856826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.4164731812998279, -0.9091480018445837, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5939123039010066`, 1.2797169994967676`, 0.},
       Optica`Optica`RayEnd :> {2.412278309774798, 1.2127964730526846`, 0.}, 
      RotationMatrix :> {{-0.9383385264082234, -0.3457178182536197, 0.}, {
       0.3457178182536197, -0.9383385264082234, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009761652713889806, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1935697927926585, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.928543446256597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4180413905402335, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9383385264082234, -0.3457178182536197, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.412278309774798, 1.2127964730526846`, 0.}, 
      Optica`Optica`RayEnd :> {2.1178173572235908`, 1.1177483207118895`, 0.}, 
      RotationMatrix :> {{-0.9516512383284065, -0.30718059930277064`, 0.}, {
       0.30718059930277064`, -0.9516512383284065, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009728819207225788, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30942107853338513`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.38648664248601, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3149995132765585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9516512383284065, -0.30718059930277064`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6744488706177325`, -1.8935461606096162`, 
       0.}, Optica`Optica`RayEnd :> {2.6340094531314135`, -1.927500485180183, 
       0.}, RotationMatrix :> {{-0.7658427556721351, -0.6430278948727721, 
       0.}, {0.6430278948727721, -0.7658427556721351, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011890343279437995`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.052803812775937015`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.33808357600885, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37160672540304907`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7658427556721351, -0.6430278948727721, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6340094531314135`, -1.927500485180183, 0.}, 
      Optica`Optica`RayEnd :> {2.4018199732914707`, -2.10354895449524, 0.}, 
      RotationMatrix :> {{-0.7968486829628827, -0.6041789275209107, 0.}, {
       0.6041789275209107, -0.7968486829628827, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01184455417907567, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2913846565907647, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.76933286776318, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4224188968800835, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7968486829628827, -0.6041789275209107, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6672522571574695`, -2.159269702104077, 0.}, 
      Optica`Optica`RayEnd :> {3.4330706213555873`, -2.184247532440832, 0.}, 
      RotationMatrix :> {{-0.994359892035633, -0.10605849853210386`, 0.}, {
       0.10605849853210386`, -0.994359892035633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01682706197670141, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2355099372747935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.61581589576609, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4017306263596122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.994359892035633, -0.10605849853210386`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4330706213555873`, -2.184247532440832, 0.}, 
      Optica`Optica`RayEnd :> {3.134775657365511, -2.2162878220725832`, 0.}, 
      RotationMatrix :> {{-0.9942808321467121, -0.106797129294947, 0.}, {
       0.106797129294947, -0.9942808321467121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016785584278621882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30001077597567644`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.05983184421009, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04986257885323179, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9942808321467121, -0.106797129294947, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.626555883353152, -2.233817827673968, 0.}, 
      Optica`Optica`RayEnd :> {4.397673717117399, -2.1880767136477473`, 0.}, 
      RotationMatrix :> {{-0.9806097648319695, 0.19597063330047487`, 
       0.}, {-0.19597063330047487`, -0.9806097648319695, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01106601722517766, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23340800229026099`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.71719732397902, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36804044983023837`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9806097648319695, 0.19597063330047487`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.397673717117399, -2.1880767136477473`, 0.}, 
      Optica`Optica`RayEnd :> {4.099114995086564, -2.141213723451201, 0.}, 
      RotationMatrix :> {{-0.9879041977745489, 0.1550654572089627, 
       0.}, {-0.1550654572089627, -0.9879041977745489, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011028382037576908`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.302214245777473, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.164474407729678`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2533371201106975, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9879041977745489, 0.1550654572089627, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.162346604277734, 1.862138328747747, 0.}, 
      Optica`Optica`RayEnd :> {4.162179615633744, 1.862387703249933, 0.}, 
      RotationMatrix :> {{-0.5564036712744452, 0.8309121220636503, 
       0.}, {-0.8309121220636503, -0.5564036712744452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012404271544239908`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00030012139137712714`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.497592928754315`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1503368196119024, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5564036712744452, 0.8309121220636503, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.162179615633744, 1.862387703249933, 0.}, 
      Optica`Optica`RayEnd :> {3.975437887865956, 2.127856256636735, 0.}, 
      RotationMatrix :> {{-0.5753502347226057, 0.817907150845768, 
       0.}, {-0.817907150845768, -0.5753502347226057, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01237034459444045, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32457052504344847`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.97795730581862, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3980023647750793, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5753502347226057, 0.817907150845768, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.362099643024295, -4.006547355628791, 0.}, 
      Optica`Optica`RayEnd :> {5.279787419090234, -4.070198385837125, 0.}, 
      RotationMatrix :> {{-0.7910704536350394, -0.6117250504807309, 0.}, {
       0.6117250504807309, -0.7910704536350394, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01307128947216959, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10405169799457042`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.934937845175025`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11282077235094279`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7910704536350394, -0.6117250504807309, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.279787419090234, -4.070198385837125, 0.}, 
      Optica`Optica`RayEnd :> {5.092301143738348, -4.23590309475546, 0.}, 
      RotationMatrix :> {{-0.7492910818701899, -0.6622407980710644, 0.}, {
       0.6622407980710644, -0.7492910818701899, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013004965192346592`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2502182127724384, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.305260800078234`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08597642117311494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7492910818701899, -0.6622407980710644, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.051406858091678, -4.344427070346459, 0.}, 
      Optica`Optica`RayEnd :> {8.11099580886446, -4.343442291022954, 0.}, 
      RotationMatrix :> {{0.9998634702100566, 0.016523950481114297`, 
       0.}, {-0.016523950481114297`, 0.9998634702100566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026482358694543965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05959708755062664, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.31524586119819, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1824253787894285, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9998634702100566, 0.016523950481114297`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.11099580886446, -4.343442291022954, 0.}, 
      Optica`Optica`RayEnd :> {8.470391685845325, -4.324888481466, 0.}, 
      RotationMatrix :> {{0.9986700877718281, 0.05155633607820054, 
       0.}, {-0.05155633607820054, 0.9986700877718281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02639985048466714, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3598744784503624, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.847860089304724`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35053020556013703`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9986700877718281, 0.05155633607820054, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8268878473143895`, -3.3719473963555866`, 
       0.}, Optica`Optica`RayEnd :> {6.665933962421392, -3.5980869677647735`, 
       0.}, RotationMatrix :> {{-0.5798671474507259, -0.8147110477386182, 
       0.}, {0.8147110477386182, -0.5798671474507259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018568781122279714`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27757027726195604`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.35199130412214, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39901850124865956`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5798671474507259, -0.8147110477386182, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.665933962421392, -3.5980869677647735`, 0.}, 
      Optica`Optica`RayEnd :> {6.56398960641994, -3.7938934235005783`, 0.}, 
      RotationMatrix :> {{-0.46179839147252966`, -0.8869849184926333, 0.}, {
       0.8869849184926333, -0.46179839147252966`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0181734531402836, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2207551128023276, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.678708871069585`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10438697688481874`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.46179839147252966`, -0.8869849184926333, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.862323337613243, 3.6088293415498454`, 0.}, 
      Optica`Optica`RayEnd :> {3.829911836817922, 3.63163678705379, 0.}, 
      RotationMatrix :> {{-0.8178141102765452, 0.5754824767380695, 
       0.}, {-0.5754824767380695, -0.8178141102765452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008128058392218326, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03963186791233141, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.450383922304116`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14144009288249804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.8178141102765452, 0.5754824767380695, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.829911836817922, 3.63163678705379, 0.}, 
      Optica`Optica`RayEnd :> {3.636771330728353, 3.7921973243101887`, 0.}, 
      RotationMatrix :> {{-0.7689841671891221, 0.6392678238519848, 
       0.}, {-0.6392678238519848, -0.7689841671891221, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008073324742445615, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25116317647417646`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.822105423485898`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.026536694173265707`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.7689841671891221, 0.6392678238519848, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.414914889031484, -1.574690063371122, 0.}, 
      Optica`Optica`RayEnd :> {4.37831481021951, -1.6160413907100193`, 0.}, 
      RotationMatrix :> {{-0.6627776291406686, -0.7488162754045039, 0.}, {
       0.7488162754045039, -0.6627776291406686, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16562517478346214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05522226038230757, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.018744431898284`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17498594960177466`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6627776291406686, -0.7488162754045039, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.37831481021951, -1.6160413907100193`, 0.}, 
      Optica`Optica`RayEnd :> {4.136185292466732, -1.8815145244865437`, 0.}, 
      RotationMatrix :> {{-0.673876163244413, -0.7388443114831356, 0.}, {
       0.7388443114831356, -0.673876163244413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16519836703602336`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35930862517384876`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.55052119715558, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4133033186003932, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.673876163244413, -0.7388443114831356, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.107906924151698, 2.811140438077034, 0.}, 
      Optica`Optica`RayEnd :> {3.9126355914282813`, 2.7800145138044243`, 0.}, 
      RotationMatrix :> {{-0.9875331560967172, -0.15741113559610403`, 0.}, {
       0.15741113559610403`, -0.9875331560967172, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035574993875200585`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.197736482585798, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.77179880048048, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40471580825845954`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9875331560967172, -0.15741113559610403`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9126355914282813`, 2.7800145138044243`, 0.},
       Optica`Optica`RayEnd :> {3.652329238880699, 2.7398869964278223`, 0.}, 
      RotationMatrix :> {{-0.9883257831614265, -0.15235532920889672`, 0.}, {
       0.15235532920889672`, -0.9883257831614265, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035486848129557, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2633811208637314, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.1616028593588, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10025965162662258`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9883257831614265, -0.15235532920889672`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8776235649819144`, 1.547137372789917, 0.}, 
      Optica`Optica`RayEnd :> {3.603518065205677, 1.4908146381672884`, 0.}, 
      RotationMatrix :> {{-0.9795351393520778, -0.20127322418668744`, 0.}, {
       0.20127322418668744`, -0.9795351393520778, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031889972851997475`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2798322273129953, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.06148572608404, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.43175809109572505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9795351393520778, -0.20127322418668744`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.603518065205677, 1.4908146381672884`, 0.}, 
      Optica`Optica`RayEnd :> {3.33269357193641, 1.4407580715476331`, 0.}, 
      RotationMatrix :> {{-0.9833444329555789, -0.18175182578249385`, 0.}, {
       0.18175182578249385`, -0.9833444329555789, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0318049566061322, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27541163013987485`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.469094938691054`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18105576122331377`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9833444329555789, -0.18175182578249385`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.128791118712853, 2.7182553933505633`, 0.}, 
      Optica`Optica`RayEnd :> {3.9106446064727507`, 2.739761757931408, 0.}, 
      RotationMatrix :> {{-0.9951754625315937, 0.0981111552017772, 
       0.}, {-0.0981111552017772, -0.9951754625315937, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03962351342375098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21920407049141552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.423449303044055`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3737664215151575, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9951754625315937, 0.0981111552017772, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9106446064727507`, 2.739761757931408, 0.}, 
      Optica`Optica`RayEnd :> {3.6496634334844873`, 2.7681090417856065`, 0.}, 
      RotationMatrix :> {{-0.9941527406630835, 0.10798299973643326`, 
       0.}, {-0.10798299973643326`, -0.9941527406630835, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0395238984121437, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26251617313270514`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.81197323928046, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0067649465909444, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9941527406630835, 0.10798299973643326`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.170792281269932, -2.938696871178345, 0.}, 
      Optica`Optica`RayEnd :> {8.175387372593446, -3.200941815523302, 0.}, 
      RotationMatrix :> {{0.017519445772076203`, -0.9998465227322832, 0.}, {
       0.9998465227322832, 0.017519445772076203`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24545209149716662`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2622851991606865, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.710868632210776`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31457578162492267`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.017519445772076203`, -0.9998465227322832, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.175387372593446, -3.200941815523302, 0.}, 
      Optica`Optica`RayEnd :> {8.202925738185447, -3.42230821353291, 0.}, 
      RotationMatrix :> {{0.12345016510612124`, -0.9923507730310237, 0.}, {
       0.9923507730310237, 0.12345016510612124`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2426787829787857, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2230727319670131, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.041016275521955`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4002092316691655, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.12345016510612124`, -0.9923507730310237, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.081982035900316, -0.837429909266994, 0.}, 
      Optica`Optica`RayEnd :> {4.8549634431669375`, -0.8382992390160692, 0.}, 
      RotationMatrix :> {{-0.9999926681856908, -0.003829304749201269, 0.}, {
       0.003829304749201269, -0.9999926681856908, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06283697121920676, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2270202572037485, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.624596985297114`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02952213562160544, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999926681856908, -0.003829304749201269, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.8549634431669375`, -0.8382992390160692, 0.},
       Optica`Optica`RayEnd :> {4.658065848402106, -0.8129543347630941, 0.}, 
      RotationMatrix :> {{-0.991816970261984, 0.1276679188376542, 
       0.}, {-0.1276679188376542, -0.991816970261984, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0616603080326803, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19852210707064438`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.918409703761668`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3342106836415234, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.991816970261984, 0.1276679188376542, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.656320172600433, -3.4231682308452736`, 0.}, 
      Optica`Optica`RayEnd :> {5.638641215965254, -3.462072466565094, 0.}, 
      RotationMatrix :> {{-0.4137101045306021, -0.9104086716465729, 0.}, {
       0.9104086716465729, -0.4137101045306021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017937475967619666`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.042732716560638505`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.218705228308384`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3191199591115568, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4137101045306021, -0.9104086716465729, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.638641215965254, -3.462072466565094, 0.}, 
      Optica`Optica`RayEnd :> {5.513356881400975, -3.6820117133582566`, 0.}, 
      RotationMatrix :> {{-0.4949613841910594, -0.8689149717663228, 0.}, {
       0.8689149717663228, -0.4949613841910594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01778744057656669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2531194120709786, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.593321958173433`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16833160372493003`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4949613841910594, -0.8689149717663228, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.848439921609096, -4.060339923633495, 0.}, 
      Optica`Optica`RayEnd :> {6.810830744740259, -4.141818437470286, 0.}, 
      RotationMatrix :> {{-0.41909224926965294`, -0.907943658275172, 0.}, {
       0.907943658275172, -0.41909224926965294`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1660621519633566, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08973961445094174, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.789369725955602`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08627653210725227, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.41909224926965294`, -0.907943658275172, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.810830744740259, -4.141818437470286, 0.}, 
      Optica`Optica`RayEnd :> {6.672843912771113, -4.421741734640321, 0.}, 
      RotationMatrix :> {{-0.4421441891003626, -0.8969439871278374, 0.}, {
       0.8969439871278374, -0.4421441891003626, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1655970462999427, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31208559418118687`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.25125640534376, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3380861043382799, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4421441891003626, -0.8969439871278374, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.690471506059175, -1.3392204971550752`, 0.}, 
      Optica`Optica`RayEnd :> {2.6285767423124753`, -1.5008821935487953`, 0.},
       RotationMatrix :> {{-0.35755544219277335`, -0.9338919133167015, 0.}, {
       0.9338919133167015, -0.35755544219277335`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.22981582256798078`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17310536057602346`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.433359653100798`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4311753415398135, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 132, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.35755544219277335`, -0.9338919133167015, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6285767423124753`, -1.5008821935487953`, 
       0.}, Optica`Optica`RayEnd :> {2.543596105985032, -1.6363224572962705`, 
       0.}, RotationMatrix :> {{-0.5314843849415017, -0.8470680896854471, 
       0.}, {0.8470680896854471, -0.5314843849415017, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2166363620687963, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15989300670949583`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.67000130303085, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04036090406417464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 132, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5314843849415017, -0.8470680896854471, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.543596105985032, -1.6363224572962705`, 0.}, 
      Optica`Optica`RayEnd :> {2.3849479729325935`, -1.616409057948625, 0.}, 
      RotationMatrix :> {{-0.9922143333052731, 0.12454202818154092`, 
       0.}, {-0.12454202818154092`, -0.9922143333052731, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012423645790219824`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15989300670949577`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.906642952960905`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38481925220459284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 132, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9922143333052731, 0.12454202818154092`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7253197317359628`, -1.9226930520229284`, 
       0.}, Optica`Optica`RayEnd :> {
       3.5646833574010808`, -2.3816995048095375`, 0.}, 
      RotationMatrix :> {{-0.33032132610553233`, -0.9438685403804292, 0.}, {
       0.9438685403804292, -0.33032132610553233`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023415214555781466`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.4863033708079783, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.114291174587404`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.061381228139551006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.33032132610553233`, -0.9438685403804292, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5646833574010808`, -2.3816995048095375`, 
       0.}, Optica`Optica`RayEnd :> {3.461323438055423, -2.6714090529866406`, 
       0.}, RotationMatrix :> {{-0.3360256310452141, -0.9418528416268992, 
       0.}, {0.9418528416268992, -0.3360256310452141, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023357075642886575`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30759534331995664`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.56953228270094, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3616125397677604, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3360256310452141, -0.9418528416268992, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9291983209491628`, -2.1531670824734057`, 
       0.}, Optica`Optica`RayEnd :> {3.9174504507025527`, -2.180336851323488, 
       0.}, RotationMatrix :> {{-0.3968764571551029, -0.9178720377895891, 
       0.}, {0.9178720377895891, -0.3968764571551029, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008371949641395121, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02960082422328979, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.28491960098653, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34681844067224304`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3968764571551029, -0.9178720377895891, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.9174504507025527`, -2.180336851323488, 0.}, 
      Optica`Optica`RayEnd :> {3.822596609712692, -2.3474960651091377`, 0.}, 
      RotationMatrix :> {{-0.4935256014318866, -0.8697312692615425, 0.}, {
       0.8697312692615425, -0.4935256014318866, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008273919058432035, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19219639409719982`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.569370264250384`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13131735326228341`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4935256014318866, -0.8697312692615425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.81530561668199, -1.3819969648385397`, 0.}, 
      Optica`Optica`RayEnd :> {2.8545555271329692`, -1.5348882764083038`, 0.},
       RotationMatrix :> {{0.24865478409856148`, -0.9685921733861456, 0.}, {
       0.9685921733861456, 0.24865478409856148`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009692877636176246, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1578490057742923, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.206002033284815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07928017248668744, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 130, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.24865478409856148`, -0.9685921733861456, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.396143214128973, 3.5870377413582615`, 0.}, 
      Optica`Optica`RayEnd :> {7.403854419465872, 3.5837227126396174`, 0.}, 
      RotationMatrix :> {{0.9187033218165543, -0.3949483592613441, 0.}, {
       0.3949483592613441, 0.9187033218165543, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02098345234674483, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008393575111551177, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.75764119011702, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32994986980795227`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9187033218165543, -0.3949483592613441, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.403854419465872, 3.5837227126396174`, 0.}, 
      Optica`Optica`RayEnd :> {7.6717827922214505`, 3.458681008403295, 0.}, 
      RotationMatrix :> {{0.9061721701923531, -0.42290897125608523`, 0.}, {
       0.42290897125608523`, 0.9061721701923531, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020921442860254384`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2956704934987196, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.195233520495126`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38997210383718517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9061721701923531, -0.42290897125608523`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.951636345348979, 0.7137730150913497, 0.}, 
      Optica`Optica`RayEnd :> {7.984278723080915, 0.6741966303886024, 0.}, 
      RotationMatrix :> {{0.6362885423956006, -0.771451159060689, 0.}, {
       0.771451159060689, 0.6362885423956006, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010819326533738205`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05130121879774605, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.337340754523524`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3345473635746008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6362885423956006, -0.771451159060689, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.984278723080915, 0.6741966303886024, 0.}, 
      Optica`Optica`RayEnd :> {8.165363385013364, 0.43148520809964575`, 0.}, 
      RotationMatrix :> {{0.597992641885775, -0.801501590921983, 0.}, {
       0.801501590921983, 0.597992641885775, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010778340393249044`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30282088649351385`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.785515666533925`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26091659188330296`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.597992641885775, -0.801501590921983, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.140126437614487, -1.1365465124910128`, 0.}, 
      Optica`Optica`RayEnd :> {8.14040047723197, -1.138381443590131, 0.}, 
      RotationMatrix :> {{0.14770782833335064`, -0.9890310396792633, 0.}, {
       0.9890310396792633, 0.14770782833335064`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06386304300173534, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001855281609476249, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.47813913639529, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30128971150548367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.14770782833335064`, -0.9890310396792633, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.14040047723197, -1.138381443590131, 0.}, 
      Optica`Optica`RayEnd :> {8.194207568944458, -1.3608744551039436`, 0.}, 
      RotationMatrix :> {{0.23506108747525073`, -0.9719805991659255, 0.}, {
       0.9719805991659255, 0.23506108747525073`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06335220939627735, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2289068441332449, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.81692126571249, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41331792317652055`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.23506108747525073`, -0.9719805991659255, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.941744632947714, -1.6665184367310864`, 0.}, 
      Optica`Optica`RayEnd :> {6.700922205001355, -2.0974585618943045`, 0.}, 
      RotationMatrix :> {{-0.487825905527204, -0.8729409406692773, 0.}, {
       0.8729409406692773, -0.487825905527204, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009874183719180427, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.49366469721630796`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.201412237018364`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38990991801871044`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.487825905527204, -0.8729409406692773, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.700922205001355, -2.0974585618943045`, 0.}, 
      Optica`Optica`RayEnd :> {6.649765790317664, -2.252140099420774, 0.}, 
      RotationMatrix :> {{-0.3139945980701363, -0.9494247692064774, 0.}, {
       0.9494247692064774, -0.3139945980701363, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009348102033914648, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16292132093388667`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.442535792000516`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1264047310586979, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.3139945980701363, -0.9494247692064774, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1971633524093805`, -1.411110251959242, 0.}, 
      Optica`Optica`RayEnd :> {5.171495430089541, -1.571344055739821, 0.}, 
      RotationMatrix :> {{-0.15817383998223894`, -0.9874112802400384, 0.}, {
       0.9874112802400384, -0.15817383998223894`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04511119275308724, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16227665916640766`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.54080597444755, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42424101386300805`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.15817383998223894`, -0.9874112802400384, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.171495430089541, -1.571344055739821, 0.}, 
      Optica`Optica`RayEnd :> {5.149893895290433, -1.8437437694677532`, 0.}, 
      RotationMatrix :> {{-0.07905269493737342, -0.9968704386343981, 0.}, {
       0.9968704386343981, -0.07905269493737342, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0448112476161388, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27325488164850126`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.945223199287334`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37723290223886224`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.07905269493737342, -0.9968704386343981, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3141454695633144`, -0.0009303562125356213, 
       0.}, Optica`Optica`RayEnd :> {
       1.9827536820664209`, -0.29313647247103203`, 0.}, 
      RotationMatrix :> {{-0.7500605937701056, -0.6613691145443937, 0.}, {
       0.6613691145443937, -0.7500605937701056, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03216022068036205, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.44182002127479486`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.869677607588645`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2983840483621546, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7500605937701056, -0.6613691145443937, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9827536820664209`, -0.29313647247103203`, 
       0.}, Optica`Optica`RayEnd :> {
       1.8423080769447733`, -0.45235163317290616`, 0.}, 
      RotationMatrix :> {{-0.6615200411272681, -0.7499274866191905, 0.}, {
       0.7499274866191905, -0.6615200411272681, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03162983664470131, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21230740777304338`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.18389257109275, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.004619954255706049, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6615200411272681, -0.7499274866191905, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5359324408170836`, 2.2629931975671616`, 0.},
       Optica`Optica`RayEnd :> {2.373788782868912, 2.2380415331809025`, 0.}, 
      RotationMatrix :> {{-0.988365754822614, -0.15209580761455618`, 0.}, {
       0.15209580761455618`, -0.988365754822614, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016680636473105984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16405228242379988`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.404826881383215`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4158746117803885, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.988365754822614, -0.15209580761455618`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.373788782868912, 2.2380415331809025`, 0.}, 
      Optica`Optica`RayEnd :> {2.0947908614681428`, 2.1924778196150227`, 0.}, 
      RotationMatrix :> {{-0.9869255484540614, -0.16117680294834535`, 0.}, {
       0.16117680294834535`, -0.9869255484540614, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016638817946494158`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.282693990279, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.783636828357075`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1279697698519162, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9869255484540614, -0.16117680294834535`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3882353982456106`, -1.1810577998572418`, 
       0.}, Optica`Optica`RayEnd :> {2.3688702250328464`, -1.200246830713806, 
       0.}, RotationMatrix :> {{-0.7103299223039465, -0.703868880885971, 
       0.}, {0.703868880885971, -0.7103299223039465, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01796501244978937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.027262223657921227`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.16759170422735, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22214871249946544`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7103299223039465, -0.703868880885971, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3688702250328464`, -1.200246830713806, 0.}, 
      Optica`Optica`RayEnd :> {2.1535509058181757`, -1.4225705938373867`, 0.},
       RotationMatrix :> {{-0.695700492713474, -0.7183319736989504, 0.}, {
       0.7183319736989504, -0.695700492713474, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017916861488427804`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30950002403311616`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.582321736431723`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42500275875264265`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.695700492713474, -0.7183319736989504, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.942643768053254, -1.6854126608445184`, 0.}, 
      Optica`Optica`RayEnd :> {8.06431006465274, -1.7631830852736665`, 0.}, 
      RotationMatrix :> {{0.8425731365687525, -0.5385819431922071, 0.}, {
       0.5385819431922071, 0.8425731365687525, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00812032638031625, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14439849945246613`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.506201140415413`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04575444861265937, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8425731365687525, -0.5385819431922071, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.06431006465274, -1.7631830852736665`, 0.}, 
      Optica`Optica`RayEnd :> {8.282380208947151, -1.8815251178425596`, 0.}, 
      RotationMatrix :> {{0.8789191668820915, -0.47697075181533904`, 0.}, {
       0.47697075181533904`, 0.8789191668820915, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008074222850921381, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24811171779084215`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.87340648274586, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01941980176643071, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8789191668820915, -0.47697075181533904`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3269097514349193`, 1.4116366195782286`, 0.},
       Optica`Optica`RayEnd :> {2.0829310118783844`, 1.3702071945206948`, 0.},
       RotationMatrix :> {{-0.9858871828619501, -0.1674110589791687, 0.}, {
       0.1674110589791687, -0.9858871828619501, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010513498181010916`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24747125614138152`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.324926511286645`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.035560380418974906`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9858871828619501, -0.1674110589791687, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0829310118783844`, 1.3702071945206948`, 0.},
       Optica`Optica`RayEnd :> {1.900105784987952, 1.382113841150748, 0.}, 
      RotationMatrix :> {{-0.9978860346450333, 0.06498816707994154, 
       0.}, {-0.06498816707994154, -0.9978860346450333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009425621503675973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1832125318353281, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.59608105840293, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4175488611738104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9978860346450333, 0.06498816707994154, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.883148682769548, 1.3764357895408095`, 0.}, 
      Optica`Optica`RayEnd :> {4.852140342572451, 1.35022068032724, 0.}, 
      RotationMatrix :> {{-0.7636620916545416, -0.6456161473893051, 0.}, {
       0.6456161473893051, -0.7636620916545416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010382601245783043`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.040604791747505295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.89346312730077, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26444763258014237`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7636620916545416, -0.6456161473893051, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.852140342572451, 1.35022068032724, 0.}, 
      Optica`Optica`RayEnd :> {4.651262681609272, 1.1872731524470477`, 0.}, 
      RotationMatrix :> {{-0.7766162477861792, -0.6299739706325288, 0.}, {
       0.6299739706325288, -0.7766162477861792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010354830967041598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25865755646472804`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.276276310868568`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38317501713076396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7766162477861792, -0.6299739706325288, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.048745360448051, -0.5896979328317056, 0.}, 
      Optica`Optica`RayEnd :> {6.9629454351588285`, -0.8743022802455626, 0.}, 
      RotationMatrix :> {{-0.28863962745965066`, -0.9574378128421461, 0.}, {
       0.9574378128421461, -0.28863962745965066`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01200635379560934, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2972562223848368, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.79795103237185, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2237569462050188, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.28863962745965066`, -0.9574378128421461, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.9629454351588285`, -0.8743022802455626, 0.},
       Optica`Optica`RayEnd :> {6.8750291013448415`, -1.1416594337420962`, 
       0.}, RotationMatrix :> {{-0.31237908590274843`, -0.9499575288877717, 
       0.}, {0.9499575288877717, -0.31237908590274843`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01197293597997323, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28144116485877035`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.175082193282602`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4193846252669216, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.31237908590274843`, -0.9499575288877717, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1178173572235908`, 1.1177483207118895`, 0.},
       Optica`Optica`RayEnd :> {2.1143800737692033`, 1.1167916407522147`, 0.},
       RotationMatrix :> {{-0.963381977053935, -0.268132740051733, 0.}, {
       0.268132740051733, -0.963381977053935, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009696096136692976, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.003567934148922588, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.391267674245565`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14316027945465815`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.963381977053935, -0.268132740051733, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1143800737692033`, 1.1167916407522147`, 0.},
       Optica`Optica`RayEnd :> {1.8238439393769457`, 1.0202765181166027`, 0.},
       RotationMatrix :> {{-0.9490064249519753, -0.31525672934906523`, 0.}, {
       0.31525672934906523`, -0.9490064249519753, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009659018158444893, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3061477001137905, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.844366270413975`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05755156170174229, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9490064249519753, -0.31525672934906523`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4018199732914707`, -2.10354895449524, 0.}, 
      Optica`Optica`RayEnd :> {2.391765974104575, -2.1104128801252755`, 0.}, 
      RotationMatrix :> {{-0.825885908095186, -0.5638372697949192, 0.}, {
       0.5638372697949192, -0.825885908095186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01179894141018357, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.012173593335771922`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.785645482833115`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1020456318355062, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.825885908095186, -0.5638372697949192, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.391765974104575, -2.1104128801252755`, 0.}, 
      Optica`Optica`RayEnd :> {2.122311827895533, -2.3037455073972075`, 0.}, 
      RotationMatrix :> {{-0.8124974516427856, -0.5829647425650867, 0.}, {
       0.5829647425650867, -0.8124974516427856, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011766564565803052`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3316369124164435, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.27646811320945, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19612829419679306`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8124974516427856, -0.5829647425650867, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.134775657365511, -2.2162878220725832`, 0.}, 
      Optica`Optica`RayEnd :> {2.86782894591727, -2.2451615561793226`, 0.}, 
      RotationMatrix :> {{-0.9942012235878901, -0.10753570112451996`, 0.}, {
       0.10753570112451996`, -0.9942012235878901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016744208820579295`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26850370439585525`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.41962680810054, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3755364668984076, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9942012235878901, -0.10753570112451996`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.86782894591727, -2.2451615561793226`, 0.}, 
      Optica`Optica`RayEnd :> {2.5579443007284106`, -2.269403900700476, 0.}, 
      RotationMatrix :> {{-0.9969539902020313, -0.07799193176379218, 0.}, {
       0.07799193176379218, -0.9969539902020313, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016695259721568153`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31083144080306246`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.87965734048907, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17316412362353056`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9969539902020313, -0.07799193176379218, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.099114995086564, -2.141213723451201, 0.}, 
      Optica`Optica`RayEnd :> {4.059116012474011, -2.136628299514328, 0.}, 
      RotationMatrix :> {{-0.9934930712372961, 0.11389256957099658`, 
       0.}, {-0.11389256957099658`, -0.9934930712372961, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01099087484610312, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04026095779685643, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.218424091177464`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05589329301408762, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9934930712372961, 0.11389256957099658`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.059116012474011, -2.136628299514328, 0.}, 
      Optica`Optica`RayEnd :> {3.862287847875723, -2.0944986984044083`, 0.}, 
      RotationMatrix :> {{-0.9778511044089916, 0.2093017381822591, 
       0.}, {-0.2093017381822591, -0.9778511044089916, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010888310461735268`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20128643687246117`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.516328017748705`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24559490504689538`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9778511044089916, 0.2093017381822591, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.975437887865956, 2.127856256636735, 0.}, 
      Optica`Optica`RayEnd :> {3.4230846793690546`, 2.8759319963892263`, 0.}, 
      RotationMatrix :> {{-0.5939929548241129, 0.8044702415996, 
       0.}, {-0.8044702415996, -0.5939929548241129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012336510438314416`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9298985855151403, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.22402141040891, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4285906356773369, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5939929548241129, 0.8044702415996, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4230846793690546`, 2.8759319963892263`, 0.},
       Optica`Optica`RayEnd :> {3.339779505009526, 3.0434863985286267`, 0.}, 
      RotationMatrix :> {{-0.4451943962583011, 0.8954339448224008, 
       0.}, {-0.8954339448224008, -0.4451943962583011, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011830980142825758`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18712089608422516`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.500960336613563`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07068294469976966, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4451943962583011, 0.8954339448224008, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.092301143738348, -4.23590309475546, 0.}, 
      Optica`Optica`RayEnd :> {4.988579227331983, -4.340452516713437, 0.}, 
      RotationMatrix :> {{-0.7042917390846323, -0.7099106607574958, 0.}, {
       0.7099106607574958, -0.7042917390846323, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01293897744474587, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14727123811103168`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.502604259147017`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21083446490440322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7042917390846323, -0.7099106607574958, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.988579227331983, -4.340452516713437, 0.}, 
      Optica`Optica`RayEnd :> {4.815103198866747, -4.5442523639535395`, 0.}, 
      RotationMatrix :> {{-0.6481822262186572, -0.7614852602737794, 0.}, {
       0.7614852602737794, -0.6481822262186572, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012858589134751576`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26763465804555414`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.898703553054435`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12308191127509838`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6481822262186572, -0.7614852602737794, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.56398960641994, -3.7938934235005783`, 0.}, 
      Optica`Optica`RayEnd :> {6.543285241504151, -3.852149876543363, 0.}, 
      RotationMatrix :> {{-0.33487984955666356`, -0.9422608377518963, 0.}, {
       0.9422608377518963, -0.33487984955666356`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017786541661897512`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06182624885671428, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.76155604453758, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11715162046821276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.33487984955666356`, -0.9422608377518963, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.543285241504151, -3.852149876543363, 0.}, 
      Optica`Optica`RayEnd :> {6.434314923225942, -4.16383908087726, 0.}, 
      RotationMatrix :> {{-0.3300242010952542, -0.9439724713631422, 0.}, {
       0.9439724713631422, -0.3300242010952542, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017742468331167927`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3301888707451417, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.250235573240392`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39449402543567225`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3300242010952542, -0.9439724713631422, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.136185292466732, -1.8815145244865437`, 0.}, 
      Optica`Optica`RayEnd :> {4.080829143176823, -1.940417865237979, 0.}, 
      RotationMatrix :> {{-0.6848246807054148, -0.7287078678707444, 0.}, {
       0.7287078678707444, -0.6848246807054148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16477265915068884`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08083258511198563, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.65883686120564, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1631793505138157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6848246807054148, -0.7287078678707444, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.080829143176823, -1.940417865237979, 0.}, 
      Optica`Optica`RayEnd :> {3.895683725659957, -2.133657255674023, 0.}, 
      RotationMatrix :> {{-0.6918229055488854, -0.7220672180329872, 0.}, {
       0.7220672180329872, -0.6918229055488854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.164358864692161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2676196697621247, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.054913972453583`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39129728218922616`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6918229055488854, -0.7220672180329872, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.652329238880699, 2.7398869964278223`, 0.}, 
      Optica`Optica`RayEnd :> {3.4438157125500233`, 2.7088351887185578`, 0.}, 
      RotationMatrix :> {{-0.9890925265314038, -0.14729553272154133`, 0.}, {
       0.14729553272154133`, -0.9890925265314038, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035398920786550436`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21081296313288356`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.444092229956865`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31898619180598564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9890925265314038, -0.14729553272154133`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4438157125500233`, 2.7088351887185578`, 0.},
       Optica`Optica`RayEnd :> {3.1602250446055833`, 2.681392119152333, 0.}, 
      RotationMatrix :> {{-0.9953504135274077, -0.09632006172556537, 0.}, {
       0.09632006172556537, -0.9953504135274077, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035258889720509196`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2849154067655703, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.86576703196991, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2606077007497996, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9953504135274077, -0.09632006172556537, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.33269357193641, 1.4407580715476331`, 0.}, 
      Optica`Optica`RayEnd :> {3.1302201679194464`, 1.4074849028546426`, 0.}, 
      RotationMatrix :> {{-0.9867647197165962, -0.16215852713510473`, 0.}, {
       0.16215852713510473`, -0.9867647197165962, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03172016700712219, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2051891397932377, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.744048386013993`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21706847572576465`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9867647197165962, -0.16215852713510473`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1302201679194464`, 1.4074849028546426`, 0.},
       Optica`Optica`RayEnd :> {2.861739231903491, 1.3869725520795433`, 0.}, 
      RotationMatrix :> {{-0.9970941195721402, -0.07617950324501703, 0.}, {
       0.07617950324501703, -0.9970941195721402, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03147833208649081, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26926338321116783`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.142558193166522`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34104770822414, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9970941195721402, -0.07617950324501703, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6496634334844873`, 2.7681090417856065`, 0.},
       Optica`Optica`RayEnd :> {3.451260765305006, 2.791653704045864, 0.}, 
      RotationMatrix :> {{-0.9930320954708353, 0.11784420802398632`, 
       0.}, {-0.11784420802398632`, -0.9930320954708353, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03942453383644382, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19979481940652752`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.079698297285205`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38254217885790043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9930320954708353, 0.11784420802398632`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.451260765305006, 2.791653704045864, 0.}, 
      Optica`Optica`RayEnd :> {3.1468993997360766`, 2.818992318919108, 0.}, 
      RotationMatrix :> {{-0.9959901726476268, 0.08946270725475133, 
       0.}, {-0.08946270725475133, -0.9959901726476268, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03931069464505399, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.305586715539421, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.53196663628355, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17388433961855992`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9959901726476268, 0.08946270725475133, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.202925738185447, -3.42230821353291, 0.}, 
      Optica`Optica`RayEnd :> {8.248112007121396, -3.615283735849963, 0.}, 
      RotationMatrix :> {{0.22798867476342632`, -0.9736637839519429, 0.}, {
       0.9736637839519429, 0.22798867476342632`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2399368094557239, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1981952348415348, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.306597890209613`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3401705036698207, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22798867476342632`, -0.9736637839519429, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.248112007121396, -3.615283735849963, 0.}, 
      Optica`Optica`RayEnd :> {8.319354478030785, -3.9202359941616067`, 0.}, 
      RotationMatrix :> {{0.2274929035332037, -0.9737797383608018, 0.}, {
       0.9737797383608018, 0.2274929035332037, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23934541463425085`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3131634868733054, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.770079850782103`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14260389608535012`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2274929035332037, -0.9737797383608018, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.658065848402106, -0.8129543347630941, 0.}, 
      Optica`Optica`RayEnd :> {4.424263155239173, -0.7507918497619795, 0.}, 
      RotationMatrix :> {{-0.9664249544818883, 0.2569490364929967, 
       0.}, {-0.2569490364929967, -0.9664249544818883, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.060505678630209135`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2419253477247767, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.24258966971287, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38785581526486035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9664249544818883, 0.2569490364929967, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.424263155239173, -0.7507918497619795, 0.}, 
      Optica`Optica`RayEnd :> {4.144075751525485, -0.6886994227943991, 0.}, 
      RotationMatrix :> {{-0.9763133992007695, 0.2163611484094079, 
       0.}, {-0.2163611484094079, -0.9763133992007695, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06029923664829346, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28698510533918226`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.66732762561486, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28047263152388563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9763133992007695, 0.2163611484094079, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.513356881400975, -3.6820117133582566`, 0.}, 
      Optica`Optica`RayEnd :> {5.4472361063926655`, -3.7768066801453966`, 0.},
       RotationMatrix :> {{-0.5720928539698839, -0.8201888602246389, 0.}, {
       0.8201888602246389, -0.5720928539698839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0176386601345717, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11557699864538108`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.748195136358245`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4135417002402155, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5720928539698839, -0.8201888602246389, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.4472361063926655`, -3.7768066801453966`, 
       0.}, Optica`Optica`RayEnd :> {5.301047359768452, -3.944042993187486, 
       0.}, RotationMatrix :> {{-0.6581398398652373, -0.7528957106944886, 
       0.}, {0.7528957106944886, -0.6581398398652373, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017426836973892735`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2221241410551099, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.076938865119807`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22322410715189533`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6581398398652373, -0.7528957106944886, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.672843912771113, -4.421741734640321, 0.}, 
      Optica`Optica`RayEnd :> {6.659903152929509, -4.446385810830566, 0.}, 
      RotationMatrix :> {{-0.4649076808289837, -0.8853591634507518, 0.}, {
       0.8853591634507518, -0.4649076808289837, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1651332433010769, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.027835117325936905`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.288555462560517`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25258178708782797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4649076808289837, -0.8853591634507518, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.659903152929509, -4.446385810830566, 0.}, 
      Optica`Optica`RayEnd :> {6.515057093215638, -4.686380860885859, 0.}, 
      RotationMatrix :> {{-0.5167210881268564, -0.8561537928929573, 0.}, {
       0.8561537928929573, -0.5167210881268564, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1643827321877667, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2803176859666132, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.703425637791103`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2640925970457204, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5167210881268564, -0.8561537928929573, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6285767423124753`, -1.5008821935487953`, 
       0.}, Optica`Optica`RayEnd :> {
       2.6594651458304117`, -1.5781593961122107`, 0.}, 
      RotationMatrix :> {{0.3711578269647809, -0.9285697967750087, 0.}, {
       0.9285697967750087, 0.3711578269647809, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01317946049918434, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08322174900778041, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.544876796771224`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3879718618886211, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3711578269647809, -0.9285697967750087, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6594651458304117`, -1.5781593961122107`, 
       0.}, Optica`Optica`RayEnd :> {
       2.7823370711004873`, -1.8868877195185065`, 0.}, 
      RotationMatrix :> {{0.36978313989817785`, -0.9291180923042258, 0.}, {
       0.9291180923042258, 0.36978313989817785`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013146963147281995`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33228103721524266`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.036652731849784`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0651435684725811, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36978313989817785`, -0.9291180923042258, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.543596105985032, -1.6363224572962705`, 0.}, 
      Optica`Optica`RayEnd :> {2.3965708830209524`, -1.7925522233475382`, 0.},
       RotationMatrix :> {{-0.6853287169555758, -0.7282338564747064, 0.}, {
       0.7282338564747064, -0.6853287169555758, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.20421271627857635`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2145324124417358, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.957474735702778`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23336005019393563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 136, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6853287169555758, -0.7282338564747064, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3965708830209524`, -1.7925522233475382`, 
       0.}, Optica`Optica`RayEnd :> {2.279009699303809, -1.8618269030697097`, 
       0.}, RotationMatrix :> {{-0.8615463032551068, -0.5076790003018232, 
       0.}, {0.5076790003018232, -0.8615463032551068, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16286185078610396`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13645370338538068`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.159426216713143`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22546132842593195`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 136, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8615463032551068, -0.5076790003018232, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.279009699303809, -1.8618269030697097`, 0.}, 
      Optica`Optica`RayEnd :> {2.154464827177917, -1.8060757775677903`, 0.}, 
      RotationMatrix :> {{-0.9127262143567072, 0.40857172886296633`, 
       0.}, {-0.40857172886296633`, -0.9127262143567072, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032977762641009926`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13645370338538082`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.36137769772351, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3117529405569035, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 136, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9127262143567072, 0.40857172886296633`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3849479729325935`, -1.616409057948625, 0.}, 
      Optica`Optica`RayEnd :> {2.382855125444696, -1.6157165107911804`, 0.}, 
      RotationMatrix :> {{-0.9493708260912564, 0.3141576587747061, 
       0.}, {-0.3141576587747061, -0.9493708260912564, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011711175486311043`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0022044573420419017`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.909596925799242`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1623829480131843, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9493708260912564, 0.3141576587747061, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.382855125444696, -1.6157165107911804`, 0.}, 
      Optica`Optica`RayEnd :> {2.1992812968316877`, -1.582953166762202, 0.}, 
      RotationMatrix :> {{-0.984443994283654, 0.17569866851756227`, 
       0.}, {-0.17569866851756227`, -0.984443994283654, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011440152111491957`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18647462900780762`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.185579376730796`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42728723027937565`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.984443994283654, 0.17569866851756227`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.461323438055423, -2.6714090529866406`, 0.}, 
      Optica`Optica`RayEnd :> {3.4057873386829636`, -2.8241461926857054`, 0.},
       RotationMatrix :> {{-0.34171763672899647`, -0.9398026690472573, 0.}, {
       0.9398026690472573, -0.34171763672899647`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023299081086268443`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16252043618252865`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.78730966718553, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4304496302895123, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.34171763672899647`, -0.9398026690472573, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4057873386829636`, -2.8241461926857054`, 
       0.}, Optica`Optica`RayEnd :> {3.351553571969628, -3.045170916975937, 
       0.}, RotationMatrix :> {{-0.23830506324731468`, -0.9711903504620978, 
       0.}, {0.9711903504620978, -0.23830506324731468`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023025736618500225`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2275812606509804, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.12412993294898, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26380898474347886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.23830506324731468`, -0.9711903504620978, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.822596609712692, -2.3474960651091377`, 0.}, 
      Optica`Optica`RayEnd :> {3.623646102364506, -2.623732783245161, 0.}, 
      RotationMatrix :> {{-0.5844209327295468, -0.8114506598601826, 0.}, {
       0.8114506598601826, -0.5844209327295468, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008177036355665052, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34042330828053113`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.025537497346296`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3908889370174853, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 134, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5844209327295468, -0.8114506598601826, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.6717827922214505`, 3.458681008403295, 0.}, 
      Optica`Optica`RayEnd :> {7.772022016348352, 3.40810360023285, 0.}, 
      RotationMatrix :> {{0.8927902809511328, -0.4504725454888417, 0.}, {
       0.4504725454888417, 0.8927902809511328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02085961662179916, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11227633887334788`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.345683814585414`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12975110389017422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8927902809511328, -0.4504725454888417, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.772022016348352, 3.40810360023285, 0.}, 
      Optica`Optica`RayEnd :> {7.877126940960202, 3.311600672087688, 0.}, 
      RotationMatrix :> {{0.7366067054286716, -0.676321344863163, 0.}, {
       0.676321344863163, 0.7366067054286716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017031190648950163`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14268798238903302`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.55686202852118, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3224235725671773, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7366067054286716, -0.676321344863163, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.165363385013364, 0.43148520809964575`, 0.}, 
      Optica`Optica`RayEnd :> {8.203554124833435, 0.37473041028837395`, 0.}, 
      RotationMatrix :> {{0.5582797353501222, -0.8296527810460206, 0.}, {
       0.8296527810460206, 0.5582797353501222, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010737509517850274`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06840789196140058, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.877182241762203`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3022016096355585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5582797353501222, -0.8296527810460206, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.203554124833435, 0.37473041028837395`, 0.}, 
      Optica`Optica`RayEnd :> {8.353958111122084, 0.12673605509693064`, 0.}, 
      RotationMatrix :> {{0.5185648892495708, -0.8550382772938174, 0.}, {
       0.8550382772938174, 0.5185648892495708, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010697809466999778`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2900388927339503, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.30643980300845, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21356975136960685`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5185648892495708, -0.8550382772938174, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.194207568944458, -1.3608744551039436`, 0.}, 
      Optica`Optica`RayEnd :> {8.280785062159566, -1.6167105668714303`, 0.}, 
      RotationMatrix :> {{0.3205523550143233, -0.9472307995915095, 0.}, {
       0.9472307995915095, 0.3205523550143233, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0628454618938329, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27008846405523895`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.17883980754651, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02543726630305887, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3205523550143233, -0.9472307995915095, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.280785062159566, -1.6167105668714303`, 0.}, 
      Optica`Optica`RayEnd :> {8.333292854791026, -1.8375753072924508`, 0.}, 
      RotationMatrix :> {{0.23129098680451382`, -0.9728846177337749, 0.}, {
       0.9728846177337749, 0.23129098680451382`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06230220432101657, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22702048772803082`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.514830129383995`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2020123482247178, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.23129098680451382`, -0.9728846177337749, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.649765790317664, -2.252140099420774, 0.}, 
      Optica`Optica`RayEnd :> {6.642168701414975, -2.310614675154861, 0.}, 
      RotationMatrix :> {{-0.12883841620830871`, -0.9916656001439871, 0.}, {
       0.9916656001439871, -0.12883841620830871`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008850049191077075, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05896602214052459, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.521550261668818`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03424378098979723, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12883841620830871`, -0.9916656001439871, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.642168701414975, -2.310614675154861, 0.}, 
      Optica`Optica`RayEnd :> {6.586852865388811, -2.621865656387353, 0.}, 
      RotationMatrix :> {{-0.17497914647724647`, -0.9845721397125219, 0.}, {
       0.9845721397125219, -0.17497914647724647`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0088175565671167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31612816235423036`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.989419941953077`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13972822580602381`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17497914647724647`, -0.9845721397125219, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.149893895290433, -1.8437437694677532`, 0.}, 
      Optica`Optica`RayEnd :> {5.150028337380061, -2.0794393420918182`, 0.}, 
      RotationMatrix :> {{0.0005704055713013356, -0.9999998373187281, 0.}, {
       0.9999998373187281, 0.0005704055713013356, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04451329681983375, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2356956109673265, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.26105531798355, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4043240801965882, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0005704055713013356, -0.9999998373187281, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.150028337380061, -2.0794393420918182`, 0.}, 
      Optica`Optica`RayEnd :> {5.1633437138595895`, -2.3949405336234557`, 0.},
       RotationMatrix :> {{0.042166350533941195`, -0.9991106039286377, 0.}, {
       0.9991106039286377, 0.042166350533941195`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0443617892119538, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31578204684350686`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.728412747311943`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3781022144627382, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.042166350533941195`, -0.9991106039286377, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0947908614681428`, 2.1924778196150227`, 0.},
       Optica`Optica`RayEnd :> {2.0375417428426617`, 2.1825871052305135`, 0.},
       RotationMatrix :> {{-0.9854019087116255, -0.17024417260947586`, 0.}, {
       0.17024417260947586`, -0.9854019087116255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01659710425935718, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05809722725251487, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.869620724690797`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18880781882410905`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 134, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9854019087116255, -0.17024417260947586`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1535509058181757`, -1.4225705938373867`, 
       0.}, Optica`Optica`RayEnd :> {
       2.1410113125605466`, -1.4360627430792223`, 0.}, 
      RotationMatrix :> {{-0.6807766417952255, -0.7324910675127824, 0.}, {
       0.7324910675127824, -0.6807766417952255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017868839584314972`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01841954098860086, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.60958265709485, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32708244658063856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.6807766417952255, -0.7324910675127824, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1410113125605466`, -1.4360627430792223`, 
       0.}, Optica`Optica`RayEnd :> {
       1.9679775262061567`, -1.6446457138116022`, 0.}, 
      RotationMatrix :> {{-0.6384725989650006, -0.7696445545645584, 0.}, {
       0.7696445545645584, -0.6384725989650006, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017792015423060425`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2710120788815166, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.972738842796083`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.311255134240129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.6384725989650006, -0.7696445545645584, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.651262681609272, 1.1872731524470477`, 0.}, 
      Optica`Optica`RayEnd :> {4.613254550733855, 1.1577011222800127`, 0.}, 
      RotationMatrix :> {{-0.7892500591477856, -0.6140719372640434, 0.}, {
       0.6140719372640434, -0.7892500591477856, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010327134965291359`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048157273395021565`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.340807057217898`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03845596100026522, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7892500591477856, -0.6140719372640434, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.613254550733855, 1.1577011222800127`, 0.}, 
      Optica`Optica`RayEnd :> {4.34950135708816, 0.9394537482734076, 0.}, 
      RotationMatrix :> {{-0.7704389849288813, -0.6375137414219033, 0.}, {
       0.6375137414219033, -0.7704389849288813, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010296816236058009`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3423414427425963, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.84747239247694, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2003698861575139, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7704389849288813, -0.6375137414219033, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.8750291013448415`, -1.1416594337420962`, 
       0.}, Optica`Optica`RayEnd :> {6.862194451580757, -1.177646071358585, 
       0.}, RotationMatrix :> {{-0.33592502033686317`, -0.941888730536509, 
       0.}, {0.941888730536509, -0.33592502033686317`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01193961117762166, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03820688840388859, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.231628388120356`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04933892515845827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.33592502033686317`, -0.941888730536509, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.862194451580757, -1.177646071358585, 0.}, 
      Optica`Optica`RayEnd :> {6.778138158256813, -1.4378788033585193`, 0.}, 
      RotationMatrix :> {{-0.30736791280579484`, -0.95159075561788, 0.}, {
       0.95159075561788, -0.30736791280579484`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011904517772118586`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27347126951749506`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.598079889273798`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2510446223408792, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.30736791280579484`, -0.95159075561788, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.122311827895533, -2.3037455073972075`, 0.}, 
      Optica`Optica`RayEnd :> {2.0846919533166233`, -2.3320911188318774`, 0.},
       RotationMatrix :> {{-0.7986660939076652, -0.6017744348526872, 0.}, {
       0.6017744348526872, -0.7986660939076652, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011734276564990412`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047103382584886264`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.339586645873197`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03274193705592992, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7986660939076652, -0.6017744348526872, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0846919533166233`, -2.3320911188318774`, 
       0.}, Optica`Optica`RayEnd :> {
       1.8478535170951083`, -2.5287092081334865`, 0.}, 
      RotationMatrix :> {{-0.7694138746498892, -0.6387505690770405, 0.}, {
       0.6387505690770405, -0.7694138746498892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011690882294326037`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30781669531146005`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.79515535493416, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13481957093004907`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7694138746498892, -0.6387505690770405, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5579443007284106`, -2.269403900700476, 0.}, 
      Optica`Optica`RayEnd :> {2.4442099759061167`, -2.2749127608980144`, 0.},
       RotationMatrix :> {{-0.9988290265277764, -0.0483794973679425, 0.}, {
       0.0483794973679425, -0.9988290265277764, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016646453717660506`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11386766083247292`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.032240006004585`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36651954902145994`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9988290265277764, -0.0483794973679425, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4442099759061167`, -2.2749127608980144`, 
       0.}, Optica`Optica`RayEnd :> {
       2.1147820855425192`, -2.2821698249394347`, 0.}, 
      RotationMatrix :> {{-0.9997574433691664, -0.0220239512337851, 0.}, {
       0.0220239512337851, -0.9997574433691664, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01659944827306273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.329507814668957, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.51991157171464, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13262814255316738`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9997574433691664, -0.0220239512337851, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.862287847875723, -2.0944986984044083`, 0.}, 
      Optica`Optica`RayEnd :> {3.6469436431969653`, -2.026091854644832, 0.}, 
      RotationMatrix :> {{-0.9530685955856618, 0.30275444193004636`, 
       0.}, {-0.30275444193004636`, -0.9530685955856618, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010786703185249007`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2259482745273216, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.819098705615318`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34438581385447914`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9530685955856618, 0.30275444193004636`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6469436431969653`, -2.026091854644832, 0.}, 
      Optica`Optica`RayEnd :> {3.3899699046641167`, -1.9450005602570204`, 0.},
       RotationMatrix :> {{-0.9536447796235121, 0.3009346013618617, 
       0.}, {-0.3009346013618617, -0.9536447796235121, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010760097970568731`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26946484060270204`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.217906669707318`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15915244888850624`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9536447796235121, 0.3009346013618617, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.339779505009526, 3.0434863985286267`, 0.}, 
      Optica`Optica`RayEnd :> {3.315343322038069, 3.126349591829431, 0.}, 
      RotationMatrix :> {{-0.2828550692321101, 0.9591626607670347, 
       0.}, {-0.9591626607670347, -0.2828550692321101, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011346165663283178`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08639117919221267, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.61672451673113, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07444285114375451, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2828550692321101, 0.9591626607670347, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.315343322038069, 3.126349591829431, 0.}, 
      Optica`Optica`RayEnd :> {3.2238502271956717`, 3.427387713933632, 0.}, 
      RotationMatrix :> {{-0.29079157899537156`, 0.9567864221368205, 
       0.}, {-0.9567864221368205, -0.29079157899537156`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011317811409310014`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31463460929125986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.082383738482193`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33697756283287356`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.29079157899537156`, 0.9567864221368205, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.434314923225942, -4.16383908087726, 0.}, 
      Optica`Optica`RayEnd :> {6.400555111761498, -4.262022410720735, 0.}, 
      RotationMatrix :> {{-0.3251598046785386, -0.9456590830851327, 0.}, {
       0.9456590830851327, -0.3251598046785386, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017698504209891105`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10382529137578883`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.389361463683947`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38161610478602764`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3251598046785386, -0.9456590830851327, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.400555111761498, -4.262022410720735, 0.}, 
      Optica`Optica`RayEnd :> {6.302464808170437, -4.450050301458311, 0.}, 
      RotationMatrix :> {{-0.46252447767493904`, -0.8866065122429025, 0.}, {
       0.8866065122429025, -0.46252447767493904`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017234324784482932`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21207591884466342`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.70323382357405, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04662216399193647, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.46252447767493904`, -0.8866065122429025, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.895683725659957, -2.133657255674023, 0.}, 
      Optica`Optica`RayEnd :> {3.894363137934695, -2.1350092208711593`, 0.}, 
      RotationMatrix :> {{-0.6987567400953506, -0.71535936295775, 0.}, {
       0.71535936295775, -0.6987567400953506, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16394610939786583`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0018899105360783582`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.057446452571927`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18809517395724568`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6987567400953506, -0.71535936295775, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.894363137934695, -2.1350092208711593`, 0.}, 
      Optica`Optica`RayEnd :> {3.7055343143627244`, -2.3234015063995175`, 0.},
       RotationMatrix :> {{-0.7079246044418692, -0.7062880109599925, 0.}, {
       0.7062880109599925, -0.7079246044418692, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16352832101342266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.266735782860442, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.45221541120538, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3938188304188384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7079246044418692, -0.7062880109599925, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1602250446055833`, 2.681392119152333, 0.}, 
      Optica`Optica`RayEnd :> {3.088276325440507, 2.678144610161838, 0.}, 
      RotationMatrix :> {{-0.998982904757788, -0.04509053117552031, 0.}, {
       0.04509053117552031, -0.998982904757788, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03511941258941911, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0720219723705088, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.962276474946393`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09748017951884567, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.998982904757788, -0.04509053117552031, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.088276325440507, 2.678144610161838, 0.}, 
      Optica`Optica`RayEnd :> {2.892263836527015, 2.630179466514019, 0.}, 
      RotationMatrix :> {{-0.971340705165378, -0.23769146911242856`, 0.}, {
       0.23769146911242856`, -0.971340705165378, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033099505557120684`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20179581466229138`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.260934280646584`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3457045177109833, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.971340705165378, -0.23769146911242856`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.861739231903491, 1.3869725520795433`, 0.}, 
      Optica`Optica`RayEnd :> {2.8189310068960913`, 1.3874165313898386`, 0.}, 
      RotationMatrix :> {{-0.9999462218333148, 0.01037079752372673, 
       0.}, {-0.01037079752372673, -0.9999462218333148, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03123834091809515, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04281052727907167, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.19992429972048, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0888867398736892, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9999462218333148, 0.01037079752372673, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8189310068960913`, 1.3874165313898386`, 0.},
       Optica`Optica`RayEnd :> {2.6407767730931617`, 1.3513135172147952`, 0.},
       RotationMatrix :> {{-0.9800779699446736, -0.1986131235067979, 0.}, {
       0.1986131235067979, -0.9800779699446736, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02894387027297956, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18177557221593965`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.46895214660007, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36762507756467794`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9800779699446736, -0.1986131235067979, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1468993997360766`, 2.818992318919108, 0.}, 
      Optica`Optica`RayEnd :> {2.859142571987567, 2.8365806538130016`, 0.}, 
      RotationMatrix :> {{-0.9981372550591646, 0.061008360598814426`, 
       0.}, {-0.061008360598814426`, -0.9981372550591646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.039197184166783514`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2882938456509696, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.918280389455848`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22467546869450405`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9981372550591646, 0.061008360598814426`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.859142571987567, 2.8365806538130016`, 0.}, 
      Optica`Optica`RayEnd :> {2.597929550289893, 2.8344956544945057`, 0.}, 
      RotationMatrix :> {{-0.9999681454524371, -0.007981734173263554, 0.}, {
       0.007981734173263554, -0.9999681454524371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.038985020101843765`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26122134278536235`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.304887976778186`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.267790356669105, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999681454524371, -0.007981734173263554, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.319354478030785, -3.9202359941616067`, 0.}, 
      Optica`Optica`RayEnd :> {8.361110025060112, -4.099381638041829, 0.}, 
      RotationMatrix :> {{0.2269970733289634, -0.9738954403323205, 0.}, {
       0.9738954403323205, 0.2269970733289634, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23875547747921777`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18394751270125392`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.016569517801784`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06264881235381055, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2269970733289634, -0.9738954403323205, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.361110025060112, -4.099381638041829, 0.}, 
      Optica`Optica`RayEnd :> {8.412962572471049, -4.416584131883879, 0.}, 
      RotationMatrix :> {{0.16132701403067795`, -0.9869010054427672, 0.}, {
       0.9869010054427672, 0.16132701403067795`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2375123194526273, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3214126767453624, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.492260279384922`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0985712945849953, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.16132701403067795`, -0.9869010054427672, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.144075751525485, -0.6886994227943991, 0.}, 
      Optica`Optica`RayEnd :> {3.915434832123526, -0.647965335292557, 0.}, 
      RotationMatrix :> {{-0.9844980227824383, 0.1753956759372037, 
       0.}, {-0.1753956759372037, -0.9844980227824383, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06009349903484142, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23224111588945884`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.978530720906736`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22539897547357585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9844980227824383, 0.1753956759372037, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.915434832123526, -0.647965335292557, 0.}, 
      Optica`Optica`RayEnd :> {3.6767553638289288`, -0.6263039518208819, 0.}, 
      RotationMatrix :> {{-0.9959070207752182, 0.0903836598651991, 
       0.}, {-0.0903836598651991, -0.9959070207752182, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.059642794307125366`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23966039330539884`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.333228102998728`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3446610244045872, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9959070207752182, 0.0903836598651991, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.301047359768452, -3.944042993187486, 0.}, 
      Optica`Optica`RayEnd :> {5.1473790497722725`, -4.085249162367698, 0.}, 
      RotationMatrix :> {{-0.7363336038731153, -0.6766186694196585, 0.}, {
       0.6766186694196585, -0.7363336038731153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017217557603448272`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20869387080513993`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.356588651998695`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2558976975409137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7363336038731153, -0.6766186694196585, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1473790497722725`, -4.085249162367698, 0.}, 
      Optica`Optica`RayEnd :> {5.017777290759835, -4.160408289752661, 0.}, 
      RotationMatrix :> {{-0.8650598459819387, -0.5016686783821602, 0.}, {
       0.5016686783821602, -0.8650598459819387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015802974506275023`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14981825779385888`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.578319673533606`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25423952806002786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8650598459819387, -0.5016686783821602, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7823370711004873`, -1.8868877195185065`, 
       0.}, Optica`Optica`RayEnd :> {
       2.9520001666773728`, -2.3150268609912428`, 0.}, 
      RotationMatrix :> {{0.36840764286121225`, -0.92966435270018, 0.}, {
       0.92966435270018, 0.36840764286121225`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013114545925964711`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.46053087894487915`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.653764109635922`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30441110445137776`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36840764286121225`, -0.92966435270018, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9520001666773728`, -2.3150268609912428`, 
       0.}, Optica`Optica`RayEnd :> {3.068991289281188, -2.631997311602204, 
       0.}, RotationMatrix :> {{0.3462591627699445, -0.938138898137081, 0.}, {
       0.938138898137081, 0.3462591627699445, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013078439761677923`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3378715574424948, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.153814014650816`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026280987487486418`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3462591627699445, -0.938138898137081, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3965708830209524`, -1.7925522233475382`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3818224814643028`, -1.8307828693178243`, 0.}, 
      RotationMatrix :> {{-0.35992082704753525`, -0.9329828499267376, 0.}, {
       0.9329828499267376, -0.35992082704753525`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.041350865492472015`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04097679391779631, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.012383639552624`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4042996845207713, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.35992082704753525`, -0.9329828499267376, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3818224814643028`, -1.8307828693178243`, 
       0.}, 
      Optica`Optica`RayEnd :> {2.3331305227023598`, -2.0340983190730886`, 0.},
       RotationMatrix :> {{-0.23290369898026037`, -0.9724998030854873, 0.}, {
       0.9724998030854873, -0.23290369898026037`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04055729127874689, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2090647721574827, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.321799502345698`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22717516063093962`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23290369898026037`, -0.9724998030854873, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.279009699303809, -1.8618269030697097`, 0.}, 
      Optica`Optica`RayEnd :> {2.183786388996578, -1.8860639242246482`, 0.}, 
      RotationMatrix :> {{-0.96910116291655, -0.24666360905855095`, 0.}, {
       0.24666360905855095`, -0.96910116291655, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.12988408814509395`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09825941186640645, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.291093828614127`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3073665552375398, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.96910116291655, -0.24666360905855095`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.183786388996578, -1.8860639242246482`, 0.}, 
      Optica`Optica`RayEnd :> {1.8575330775666872`, -1.973609833425109, 0.}, 
      RotationMatrix :> {{-0.9658320687088942, -0.25916869998805264`, 0.}, {
       0.25916869998805264`, -0.9658320687088942, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.12955305318067176`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3377950701782144, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.791030532477883`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06936197201849507, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9658320687088942, -0.25916869998805264`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.154464827177917, -1.8060757775677903`, 0.}, 
      Optica`Optica`RayEnd :> {1.9635584338880692`, -1.6439212922441218`, 0.},
       RotationMatrix :> {{-0.7621677022213734, 0.6473796364503529, 
       0.}, {-0.6473796364503529, -0.7621677022213734, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026300122521132445`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2504781988707239, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.69701848421028, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3221932989061409, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7621677022213734, 0.6473796364503529, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9635584338880692`, -1.6439212922441218`, 
       0.}, Optica`Optica`RayEnd :> {1.8331971455187728`, -1.49581634012526, 
       0.}, RotationMatrix :> {{-0.6607105264665941, 0.750640793066987, 
       0.}, {-0.750640793066987, -0.6607105264665941, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025668947877907827`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19730469418499183`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.989029431604067`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02466778996199919, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6607105264665941, 0.750640793066987, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1992812968316877`, -1.582953166762202, 0.}, 
      Optica`Optica`RayEnd :> {2.1201065284469833`, -1.5802870100530664`, 0.},
       RotationMatrix :> {{-0.9994335017358673, 0.03365524636637604, 
       0.}, {-0.03365524636637604, -0.9994335017358673, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011175400837179281`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07921964617674888, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.29173370260764, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20624701533807063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9994335017358673, 0.03365524636637604, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1201065284469833`, -1.5802870100530664`, 
       0.}, Optica`Optica`RayEnd :> {1.847484571749867, -1.5541627057341192`, 
       0.}, RotationMatrix :> {{-0.9954400576972172, 0.095389158355445, 
       0.}, {-0.095389158355445, -0.9954400576972172, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01112239553128573, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27387079170571166`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.697062474332093`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20886186452494604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9954400576972172, 0.095389158355445, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.351553571969628, -3.045170916975937, 0.}, 
      Optica`Optica`RayEnd :> {3.337120111113439, -3.153467306216698, 0.}, 
      RotationMatrix :> {{-0.13210924226424997`, -0.9912351628692179, 0.}, {
       0.9912351628692179, -0.13210924226424997`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022755599023903672`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1092539826041754, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.270530269638574`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06037172695640039, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13210924226424997`, -0.9912351628692179, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.337120111113439, -3.153467306216698, 0.}, 
      Optica`Optica`RayEnd :> {3.289440215654356, -3.451588365206402, 0.}, 
      RotationMatrix :> {{-0.1579276081998558, -0.9874506927276279, 0.}, {
       0.9874506927276279, -0.1579276081998558, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022691519711564332`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30190981806515, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.717356800374997`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21216503632256417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1579276081998558, -0.9874506927276279, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.877126940960202, 3.311600672087688, 0.}, 
      Optica`Optica`RayEnd :> {7.954147366881353, 3.186700566472998, 0.}, 
      RotationMatrix :> {{0.5248822554874233, -0.8511748456541901, 0.}, {
       0.8511748456541901, 0.5248822554874233, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013905406804924856`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14673848299487172`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.75349159573431, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3563647437883759, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5248822554874233, -0.8511748456541901, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.954147366881353, 3.186700566472998, 0.}, 
      Optica`Optica`RayEnd :> {8.103699191777398, 2.928621355054173, 0.}, 
      RotationMatrix :> {{0.5013815972835944, -0.865226267461495, 0.}, {
       0.865226267461495, 0.5013815972835944, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013865737655638305`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29827944564837217`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.194945175293903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1270939158697711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5013815972835944, -0.865226267461495, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.333292854791026, -1.8375753072924508`, 0.}, 
      Optica`Optica`RayEnd :> {8.37502059150578, -2.132620862057291, 0.}, 
      RotationMatrix :> {{0.14003456956141336`, -0.990146615066551, 0.}, {
       0.990146615066551, 0.14003456956141336`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06176364285165033, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29798168299046196`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.914125584591215`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19735291791723064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.14003456956141336`, -0.990146615066551, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.37502059150578, -2.132620862057291, 0.}, 
      Optica`Optica`RayEnd :> {8.372609199076223, -2.338139090646819, 0.}, 
      RotationMatrix :> {{-0.011732421384996111`, -0.9999311727756285, 0.}, {
       0.9999311727756285, -0.011732421384996111`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.060065185511272545`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20553237481240444`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.218313499313574`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18651949143956026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.011732421384996111`, -0.9999311727756285, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.586852865388811, -2.621865656387353, 0.}, 
      Optica`Optica`RayEnd :> {6.5283406794940015`, -2.8804016821273737`, 0.},
       RotationMatrix :> {{-0.22073854746207827`, -0.9753330168021235, 0.}, {
       0.9753330168021235, -0.22073854746207827`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008785183238607578, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2650746168602971, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.344619928545875`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10753046428719956`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22073854746207827`, -0.9753330168021235, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.5283406794940015`, -2.8804016821273737`, 
       0.}, Optica`Optica`RayEnd :> {6.455915662084558, -3.1889427043325047`, 
       0.}, RotationMatrix :> {{-0.22852245879850389`, -0.9735386411564184, 
       0.}, {0.9735386411564184, -0.22852245879850389`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008763250208185996, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31692735055552645`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.813672407368053`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3135691014168087, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22852245879850389`, -0.9735386411564184, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1633437138595895`, -2.3949405336234557`, 
       0.}, Optica`Optica`RayEnd :> {5.177189268849019, -2.5598001098368637`, 
       0.}, RotationMatrix :> {{0.08368930497990114, -0.9964918967216841, 
       0.}, {0.9964918967216841, 0.08368930497990114, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04421079728268869, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16543995666775854`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.95010228924674, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3843611479973078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08368930497990114, -0.9964918967216841, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.177189268849019, -2.5598001098368637`, 0.}, 
      Optica`Optica`RayEnd :> {5.2141051080821414`, -2.8945932194192343`, 0.},
       RotationMatrix :> {{0.10960036910836281`, -0.9939757336531456, 0.}, {
       0.9939757336531456, 0.10960036910836281`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04408637587737085, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3368222163250501, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.448599169407814`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3054508624972299, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10960036910836281`, -0.9939757336531456, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.34950135708816, 0.9394537482734076, 0.}, 
      Optica`Optica`RayEnd :> {4.308246115973363, 0.9031733340704978, 0.}, 
      RotationMatrix :> {{-0.7509319156266083, -0.6603796317977644, 0.}, {
       0.6603796317977644, -0.7509319156266083, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010266586517508204`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.054938723812760284`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.92109028238604, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11604499127122281`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7509319156266083, -0.6603796317977644, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.308246115973363, 0.9031733340704978, 0.}, 
      Optica`Optica`RayEnd :> {4.102079489920942, 0.6993790946992785, 0.}, 
      RotationMatrix :> {{-0.7111868021504437, -0.7030030813922683, 0.}, {
       0.7030030813922683, -0.7111868021504437, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010220902427665947`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28989096174032863`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.350128905761725`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13712003892418087`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7111868021504437, -0.7030030813922683, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.778138158256813, -1.4378788033585193`, 0.}, 
      Optica`Optica`RayEnd :> {6.730084543669796, -1.6035765617551552`, 0.}, 
      RotationMatrix :> {{-0.2785312118392544, -0.9604271778908356, 0.}, {
       0.9604271778908356, -0.2785312118392544, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011869527514623546`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17252506198389714`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.853416981009964`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20333841615165604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.2785312118392544, -0.9604271778908356, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.730084543669796, -1.6035765617551552`, 0.}, 
      Optica`Optica`RayEnd :> {6.648066431511518, -1.8677482212282193`, 0.}, 
      RotationMatrix :> {{-0.29651068447973256`, -0.9550295356633527, 0.}, {
       0.9550295356633527, -0.29651068447973256`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011838149682084834`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27661098385776445`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.22407569937937, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4262860742157448, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.29651068447973256`, -0.9550295356633527, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3899699046641167`, -1.9450005602570204`, 
       0.}, Optica`Optica`RayEnd :> {2.876920695888101, -1.784177655015215, 
       0.}, RotationMatrix :> {{-0.9542174887631342, 0.29911366424584757`, 
       0.}, {-0.29911366424584757`, -0.9542174887631342, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010733558377184975`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5376648560917016, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.9383775768702, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3358828831152488, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9542174887631342, 0.29911366424584757`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.876920695888101, -1.784177655015215, 0.}, 
      Optica`Optica`RayEnd :> {2.5598910142943008`, -1.6845745240638166`, 0.},
       RotationMatrix :> {{-0.9540236393986129, 0.29973137217953183`, 
       0.}, {-0.29973137217953183`, -0.9540236393986129, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01070710151021494, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3323079937449416, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.430193407612713`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14690699849298997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9540236393986129, 0.29973137217953183`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2238502271956717`, 3.427387713933632, 0.}, 
      Optica`Optica`RayEnd :> {3.164101554416602, 3.6182791304508584`, 0.}, 
      RotationMatrix :> {{-0.2987081303666714, 0.954344514760182, 
       0.}, {-0.954344514760182, -0.2987081303666714, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011289528013082296`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20002359060574224`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.350415349893886`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37047461732073084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2987081303666714, 0.954344514760182, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.164101554416602, 3.6182791304508584`, 0.}, 
      Optica`Optica`RayEnd :> {3.101985669129406, 3.8742308283456834`, 0.}, 
      RotationMatrix :> {{-0.23584024230793124`, 0.9717918399061272, 
       0.}, {-0.9717918399061272, -0.23584024230793124`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01123257182359135, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26338119686161293`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.740219521249074`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35296883354377284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23584024230793124`, 0.9717918399061272, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7055343143627244`, -2.3234015063995175`, 
       0.}, Optica`Optica`RayEnd :> {
       3.6126373039872774`, -2.4137232822676298`, 0.}, 
      RotationMatrix :> {{-0.7169747132016795, -0.6970991756051422, 0.}, {
       0.6970991756051422, -0.7169747132016795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1631115972906224, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.129568042868083, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.62583658864861, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12537396385956945`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7169747132016795, -0.6970991756051422, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6126373039872774`, -2.4137232822676298`, 
       0.}, Optica`Optica`RayEnd :> {3.3922309432078155`, -2.628930241020917, 
       0.}, RotationMatrix :> {{-0.7154957159105708, -0.6986171201120248, 
       0.}, {0.6986171201120248, -0.7154957159105708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1627092163903207, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3080470726494336, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.081746256169772`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3419814261914499, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7154957159105708, -0.6986171201120248, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.892263836527015, 2.630179466514019, 0.}, 
      Optica`Optica`RayEnd :> {2.656542139953466, 2.52067965515237, 0.}, 
      RotationMatrix :> {{-0.9069243114135148, -0.42129359521255505`, 0.}, {
       0.42129359521255505`, -0.9069243114135148, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03119577428399096, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25991330655383726`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.609218111428724`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4008332693291291, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9069243114135148, -0.42129359521255505`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.656542139953466, 2.52067965515237, 0.}, 
      Optica`Optica`RayEnd :> {2.4021847771895124`, 2.4197950374793806`, 0.}, 
      RotationMatrix :> {{-0.929554399966777, -0.3686849841021509, 0.}, {
       0.3686849841021509, -0.929554399966777, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031059387794138946`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27363364938409707`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.014195912517188`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3829074197571266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.929554399966777, -0.3686849841021509, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6407767730931617`, 1.3513135172147952`, 0.},
       Optica`Optica`RayEnd :> {2.4100475676243165`, 1.2509610945770788`, 0.},
       RotationMatrix :> {{-0.9170186358477059, -0.39884435749802405`, 0.}, {
       0.39884435749802405`, -0.9170186358477059, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02681792956212341, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2516079787795755, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.806106838164702`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3832376986861457, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9170186358477059, -0.39884435749802405`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4100475676243165`, 1.2509610945770788`, 0.},
       Optica`Optica`RayEnd :> {2.109843693225373, 1.128427125877418, 0.}, 
      RotationMatrix :> {{-0.9258457283244296, -0.3779016900510049, 0.}, {
       0.3779016900510049, -0.9258457283244296, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02674474298628302, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32424826859896466`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.28599427569117, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2828143945358699, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9258457283244296, -0.3779016900510049, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.597929550289893, 2.8344956544945057`, 0.}, 
      Optica`Optica`RayEnd :> {2.4952292852444606`, 2.826571044663803, 0.}, 
      RotationMatrix :> {{-0.9970362022321602, -0.07693381206251287, 0.}, {
       0.07693381206251287, -0.9970362022321602, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.038774004425274476`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10300555267251818`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.442915417359362`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1481150903699008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 143, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9970362022321602, -0.07693381206251287, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4952292852444606`, 2.826571044663803, 0.}, 
      Optica`Optica`RayEnd :> {2.358105900150826, 2.859797487829117, 0.}, 
      RotationMatrix :> {{-0.9718753993693595, 0.23549566471730887`, 
       0.}, {-0.23549566471730887`, -0.9718753993693595, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02733474697376804, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14109152797016236`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.651730878755203`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3829640709725676, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 143, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9718753993693595, 0.23549566471730887`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.358105900150826, 2.859797487829117, 0.}, 
      Optica`Optica`RayEnd :> {2.301619792494541, 2.9890883958884147`, 0.}, 
      RotationMatrix :> {{-0.40035081105812487`, 0.916361952552102, 
       0.}, {-0.916361952552102, -0.40035081105812487`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008064403268104786, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14109152797016253`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.860546340151043`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02433259746077865, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 143, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.40035081105812487`, 0.916361952552102, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6767553638289288`, -0.6263039518208819, 0.},
       Optica`Optica`RayEnd :> {3.660707579059717, -0.6262284193186336, 0.}, 
      RotationMatrix :> {{-0.9999889235561261, 0.004706672397659012, 
       0.}, {-0.004706672397659012, -0.9999889235561261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05919546989100458, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.016047962523568098`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.35473237278031, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2078987184334114, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999889235561261, 0.004706672397659012, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.660707579059717, -0.6262284193186336, 0.}, 
      Optica`Optica`RayEnd :> {3.380318304137456, -0.6066002737367311, 0.}, 
      RotationMatrix :> {{-0.9975587449981131, 0.06983230110620889, 
       0.}, {-0.06983230110620889, -0.9975587449981131, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05889722832488268, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28107545177481347`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.770724041407032`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2302683458526706, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9975587449981131, 0.06983230110620889, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.017777290759835, -4.160408289752661, 0.}, 
      Optica`Optica`RayEnd :> {4.871824473011491, -4.206822074429016, 0.}, 
      RotationMatrix :> {{-0.9529743424530014, -0.3030509901423664, 0.}, {
       0.3030509901423664, -0.9529743424530014, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01450461261683035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15315503392531513`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.78354741899353, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25727314448545374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9529743424530014, -0.3030509901423664, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.871824473011491, -4.206822074429016, 0.}, 
      Optica`Optica`RayEnd :> {4.566101814353904, -4.310487669884657, 0.}, 
      RotationMatrix :> {{-0.9470368706970829, -0.3211248441654363, 0.}, {
       0.3211248441654363, -0.9470368706970829, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01446619739916272, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3228202281422833, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.261321356644107`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07329239622279791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9470368706970829, -0.3211248441654363, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.068991289281188, -2.631997311602204, 0.}, 
      Optica`Optica`RayEnd :> {3.084678752134776, -2.677816872230564, 0.}, 
      RotationMatrix :> {{0.32391595584313015`, -0.9460858595023132, 0.}, {
       0.9460858595023132, 0.32391595584313015`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01304243300267034, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0484306579240738, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.218711096269075`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19587083624711668`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.32391595584313015`, -0.9460858595023132, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.084678752134776, -2.677816872230564, 0.}, 
      Optica`Optica`RayEnd :> {3.186830152915206, -2.9007350279240947`, 0.}, 
      RotationMatrix :> {{0.4165892585133147, -0.9090948188672763, 0.}, {
       0.9090948188672763, 0.4165892585133147, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012912891969377635`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2452089166796535, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.581620292954963`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3698050106433552, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4165892585133147, -0.9090948188672763, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3331305227023598`, -2.0340983190730886`, 
       0.}, Optica`Optica`RayEnd :> {2.328960687100035, -2.0748605967363356`, 
       0.}, RotationMatrix :> {{-0.1017653538384013, -0.9948084301804766, 
       0.}, {0.9948084301804766, -0.1017653538384013, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03977894673494984, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04097500224827391, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.376706005358386`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11035195056578107`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1017653538384013, -0.9948084301804766, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.328960687100035, -2.0748605967363356`, 0.}, 
      Optica`Optica`RayEnd :> {2.2886130596423895`, -2.406696796436617, 0.}, 
      RotationMatrix :> {{-0.12070005302031814`, -0.9926890234111041, 0.}, {
       0.9926890234111041, -0.12070005302031814`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039673570314835725`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33428011378630634`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.87144057376212, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22399964319505006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.12070005302031814`, -0.9926890234111041, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.289440215654356, -3.451588365206402, 0.}, 
      Optica`Optica`RayEnd :> {3.265160825292077, -3.581552939267163, 0.}, 
      RotationMatrix :> {{-0.18363843961083287`, -0.9829938573039497, 0.}, {
       0.9829938573039497, -0.18363843961083287`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022627620845288635`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1322130073296835, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.894522230196774`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.305445772460198, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.18363843961083287`, -0.9829938573039497, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.265160825292077, -3.581552939267163, 0.}, 
      Optica`Optica`RayEnd :> {3.21414977933437, -3.9108801651768457`, 0.}, 
      RotationMatrix :> {{-0.1530693478926099, -0.9882154495532492, 0.}, {
       0.9882154495532492, -0.1530693478926099, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022560469168505248`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3332544801425277, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.387738860807715`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41089149980361284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1530693478926099, -0.9882154495532492, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.103699191777398, 2.928621355054173, 0.}, 
      Optica`Optica`RayEnd :> {8.12458174917919, 2.890196586484368, 0.}, 
      RotationMatrix :> {{0.47750504156855533`, -0.8786290088977322, 0.}, {
       0.8786290088977322, 0.47750504156855533`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013826181673943847`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.043732642765813026`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.253546916600094`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39003397800900946`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.47750504156855533`, -0.8786290088977322, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.12458174917919, 2.890196586484368, 0.}, 
      Optica`Optica`RayEnd :> {8.301227485802736, 2.5779427149896432`, 0.}, 
      RotationMatrix :> {{0.4923834329050153, -0.8703783975953627, 0.}, {
       0.8703783975953627, 0.4923834329050153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013790079556213985`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35875645852126364`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.784506475211565`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08457571681466568, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4923834329050153, -0.8703783975953627, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.372609199076223, -2.338139090646819, 0.}, 
      Optica`Optica`RayEnd :> {8.328067160359495, -2.6073615446193075`, 0.}, 
      RotationMatrix :> {{-0.16322805366038834`, -0.986588365276137, 0.}, {
       0.986588365276137, -0.16322805366038834`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05841343456973877, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27288225104614466`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.583975715715408`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13497604690833437`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.16322805366038834`, -0.986588365276137, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.328067160359495, -2.6073615446193075`, 0.}, 
      Optica`Optica`RayEnd :> {8.264249979302264, -2.9744161410151913`, 0.}, 
      RotationMatrix :> {{-0.1712932341752863, -0.9852200911094787, 0.}, {
       0.9852200911094787, -0.1712932341752863, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05826750875932775, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.37256101424254884`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.13536601679438, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28955133564836777`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.1712932341752863, -0.9852200911094787, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.455915662084558, -3.1889427043325047`, 0.}, 
      Optica`Optica`RayEnd :> {6.424566515033717, -3.317857071873617, 0.}, 
      RotationMatrix :> {{-0.23629178833175138`, -0.9716821449254804, 0.}, {
       0.9716821449254804, -0.23629178833175138`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008741371935623231, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13267133518337795`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.991451996513778`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3972348894053909, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.23629178833175138`, -0.9716821449254804, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.424566515033717, -3.317857071873617, 0.}, 
      Optica`Optica`RayEnd :> {6.380694900367936, -3.572269944766505, 0.}, 
      RotationMatrix :> {{-0.16993447502413372`, -0.9854553638791924, 0.}, {
       0.9854553638791924, -0.16993447502413372`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008695149140509732, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2581678300389024, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 27.373540384971353`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3705592255481858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.16993447502413372`, -0.9854553638791924, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.2141051080821414`, -2.8945932194192343`, 
       0.}, Optica`Optica`RayEnd :> {5.240643944512358, -3.0887371814349898`, 
       0.}, RotationMatrix :> {{0.13543715549712124`, -0.9907859389953246, 
       0.}, {0.9907859389953246, 0.13543715549712124`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04396230462828299, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1959494522223649, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.711171435385783`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27898507614818496`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.13543715549712124`, -0.9907859389953246, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.240643944512358, -3.0887371814349898`, 0.}, 
      Optica`Optica`RayEnd :> {5.2846673386373135`, -3.42689019718041, 0.}, 
      RotationMatrix :> {{0.129098352732004, -0.9916317942270113, 0.}, {
       0.9916317942270113, 0.129098352732004, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04385305370694658, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34100662939010995`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.215861246883147`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.163448557301287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.129098352732004, -0.9916317942270113, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.102079489920942, 0.6993790946992785, 0.}, 
      Optica`Optica`RayEnd :> {4.087892909975138, 0.6836188491282627, 0.}, 
      RotationMatrix :> {{-0.6690261907054842, -0.7432388284731278, 0.}, {
       0.7432388284731278, -0.6690261907054842, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010175421622144257`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.021204819994930763`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.378543364554933`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028145826892071166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6690261907054842, -0.7432388284731278, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.087892909975138, 0.6836188491282627, 0.}, 
      Optica`Optica`RayEnd :> {3.8723596812644248`, 0.43704591406790944`, 0.},
       RotationMatrix :> {{-0.6581273596950976, -0.7529066199873382, 0.}, {
       0.7529066199873382, -0.6581273596950976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010149253843155022`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32749470985458945`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.863235535139726`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32745323880141125`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6581273596950976, -0.7529066199873382, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.648066431511518, -1.8677482212282193`, 0.}, 
      Optica`Optica`RayEnd :> {6.633457387841712, -1.9118605919964782`, 0.}, 
      RotationMatrix :> {{-0.3143856679475469, -0.949295344868589, 0.}, {
       0.949295344868589, -0.3143856679475469, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011806854798793563`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04646854217363228, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.292849141796346`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33181785878964004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.3143856679475469, -0.949295344868589, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.633457387841712, -1.9118605919964782`, 0.}, 
      Optica`Optica`RayEnd :> {6.609319392222294, -2.0588667500189346`, 0.}, 
      RotationMatrix :> {{-0.16202751152721648`, -0.986786241041238, 0.}, {
       0.986786241041238, -0.16202751152721648`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011452211919860853`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14897467344836315`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.492475204217154`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19479143262417853`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.16202751152721648`, -0.986786241041238, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.5598910142943008`, -1.6845745240638166`, 
       0.}, Optica`Optica`RayEnd :> {2.3957522094877737`, -1.632889265754243, 
       0.}, RotationMatrix :> {{-0.9538293901638837, 0.3003489544839359, 
       0.}, {-0.3003489544839359, -0.9538293901638837, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010680709856083492`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17208402938635126`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.660786006990424`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2288131024585845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9538293901638837, 0.3003489544839359, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3957522094877737`, -1.632889265754243, 0.}, 
      Optica`Optica`RayEnd :> {2.1864040273262773`, -1.5908839168081363`, 0.},
       RotationMatrix :> {{-0.9804582556205477, 0.19672724515306075`, 
       0.}, {-0.19672724515306075`, -0.9804582556205477, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010558094981586623`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21352075007925375`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.97679671710772, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4118516622828556, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9804582556205477, 0.19672724515306075`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3922309432078155`, -2.628930241020917, 0.}, 
      Optica`Optica`RayEnd :> {3.373086493082613, -2.647702492049789, 0.}, 
      RotationMatrix :> {{-0.7140135049070866, -0.700131926718313, 0.}, {
       0.700131926718313, -0.7140135049070866, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16230782812568448`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.026812448215098674`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.117674936778005`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21142851788629013`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7140135049070866, -0.700131926718313, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.373086493082613, -2.647702492049789, 0.}, 
      Optica`Optica`RayEnd :> {3.135354215431099, -2.873588876929993, 0.}, 
      RotationMatrix :> {{-0.7249374250541053, -0.6888147281787192, 0.}, {
       0.6888147281787192, -0.7249374250541053, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16188751415535485`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3279348940134673, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.603018579917936`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3944766914057619, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7249374250541053, -0.6888147281787192, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4021847771895124`, 2.4197950374793806`, 0.},
       Optica`Optica`RayEnd :> {2.2508515589624474`, 2.369591616676134, 0.}, 
      RotationMatrix :> {{-0.9491357482032488, -0.31486716482138527`, 0.}, {
       0.31486716482138527`, -0.9491357482032488, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030923597579745426`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15944317608260428`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.227849768467877`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1905520832921078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9491357482032488, -0.31486716482138527`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2508515589624474`, 2.369591616676134, 0.}, 
      Optica`Optica`RayEnd :> {2.105089716554118, 2.2924074478347602`, 0.}, 
      RotationMatrix :> {{-0.8837474617035851, -0.4679641267580973, 0.}, {
       0.4679641267580973, -0.8837474617035851, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02982057945656011, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1649360804130023, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.47195516747912, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22386116739633322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8837474617035851, -0.4679641267580973, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.109843693225373, 1.128427125877418, 0.}, 
      Optica`Optica`RayEnd :> {2.1045353568776313`, 1.1263999011482146`, 0.}, 
      RotationMatrix :> {{-0.9341946095562911, -0.35676383151318475`, 0.}, {
       0.35676383151318475`, -0.9341946095562911, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026671756137825423`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.005682259663500699, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.29360850364026, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10369441329357676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9341946095562911, -0.35676383151318475`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1045353568776313`, 1.1263999011482146`, 0.},
       Optica`Optica`RayEnd :> {1.8227355325169223`, 1.0030155268912893`, 0.},
       RotationMatrix :> {{-0.916041566865407, -0.40108334267926066`, 0.}, {
       0.40108334267926066`, -0.916041566865407, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026571964416807037`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.307627769911137, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.748897603108745`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.006446924165629196, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.916041566865407, -0.40108334267926066`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4952292852444606`, 2.826571044663803, 0.}, 
      Optica`Optica`RayEnd :> {2.3308064325818236`, 2.763043043820169, 0.}, 
      RotationMatrix :> {{-0.9327962470514981, -0.3604041640806048, 0.}, {
       0.3604041640806048, -0.9327962470514981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011439257451506436`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17626877593297094`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.679115577109542`, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3971581953433545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9327962470514981, -0.3604041640806048, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3308064325818236`, 2.763043043820169, 0.}, 
      Optica`Optica`RayEnd :> {2.107523011322846, 2.6895580339560903`, 0.}, 
      RotationMatrix :> {{-0.9498796689340522, -0.3126157618318924, 0.}, {
       0.3126157618318924, -0.9498796689340522, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011394453687226162`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23506495460582394`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.02701170992616, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34634323383505045`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9498796689340522, -0.3126157618318924, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.358105900150826, 2.859797487829117, 0.}, 
      Optica`Optica`RayEnd :> {2.158132977113625, 2.9830817346584992`, 0.}, 
      RotationMatrix :> {{-0.8512324607952291, 0.5247888124650698, 
       0.}, {-0.5247888124650698, -0.8512324607952291, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019270343705663242`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.234921636858614, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.966525872145745`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4155482248119766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8512324607952291, 0.5247888124650698, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.158132977113625, 2.9830817346584992`, 0.}, 
      Optica`Optica`RayEnd :> {1.9620053601186829`, 3.0868466436547135`, 0.}, 
      RotationMatrix :> {{-0.8839134167504348, 0.4676505871786879, 
       0.}, {-0.4676505871786879, -0.8839134167504348, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019172075462033394`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22188555267774224`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.294916490108804`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4310458771126887, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8839134167504348, 0.4676505871786879, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.380318304137456, -0.6066002737367311, 0.}, 
      Optica`Optica`RayEnd :> {3.1133430358425915`, -0.5703185624998235, 0.}, 
      RotationMatrix :> {{-0.9908916817859126, 0.13466133434466035`, 
       0.}, {-0.13466133434466035`, -0.9908916817859126, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.058600489374280605`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26942931624341304`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.131759325173206`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13580298269157542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9908916817859126, 0.13466133434466035`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1133430358425915`, -0.5703185624998235, 0.},
       Optica`Optica`RayEnd :> {2.8546878672361986`, -0.5169710757238604, 0.},
       RotationMatrix :> {{-0.9793859712975209, 0.20199781985360638`, 
       0.}, {-0.20199781985360638`, -0.9793859712975209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05828746212156104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26409931956011007`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.522626318122168`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17863413450846669`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9793859712975209, 0.20199781985360638`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.566101814353904, -4.310487669884657, 0.}, 
      Optica`Optica`RayEnd :> {4.446348884020257, -4.35365092609602, 0.}, 
      RotationMatrix :> {{-0.9407566494687157, -0.3390824774009932, 0.}, {
       0.3390824774009932, -0.9407566494687157, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014427883923540014`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1272942693535844, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.43189567757791, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29373616873318303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9407566494687157, -0.3390824774009932, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.446348884020257, -4.35365092609602, 0.}, 
      Optica`Optica`RayEnd :> {4.30456992408814, -4.450885268302151, 0.}, 
      RotationMatrix :> {{-0.8246895553515204, -0.5655856586708248, 0.}, {
       0.5655856586708248, -0.8246895553515204, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012398625647326524`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17191797690669802`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.686334283399823`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.227709535693151, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8246895553515204, -0.5655856586708248, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.186830152915206, -2.9007350279240947`, 0.}, 
      Optica`Optica`RayEnd :> {3.333988727489665, -3.1521740169841297`, 0.}, 
      RotationMatrix :> {{0.5051147160302896, -0.8630522137447069, 0.}, {
       0.8630522137447069, 0.5051147160302896, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012784637573271645`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29133693773759456`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.97201178952334, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0711664972415661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5051147160302896, -0.8630522137447069, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.333988727489665, -3.1521740169841297`, 0.}, 
      Optica`Optica`RayEnd :> {3.4218536151488363`, -3.351156547170038, 0.}, 
      RotationMatrix :> {{0.40394218808204363`, -0.9147845148927097, 0.}, {
       0.9147845148927097, 0.40394218808204363`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012617007760862888`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2175184723248689, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.293939128564144`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3178157890922402, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.40394218808204363`, -0.9147845148927097, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2886130596423895`, -2.406696796436617, 0.}, 
      Optica`Optica`RayEnd :> {2.269709177066505, -2.5407943245044953`, 0.}, 
      RotationMatrix :> {{-0.13959093630651123`, -0.990209255915673, 0.}, {
       0.990209255915673, -0.13959093630651123`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039568473042130674`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1354234241568209, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.05290796213226, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23343057465157566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13959093630651123`, -0.990209255915673, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.269709177066505, -2.5407943245044953`, 0.}, 
      Optica`Optica`RayEnd :> {2.2269974575965636`, -2.866598855823816, 0.}, 
      RotationMatrix :> {{-0.1299839425231335, -0.9915160990554525, 0.}, {
       0.9915160990554525, -0.1299839425231335, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03946908602100868, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3285922756369681, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.53922453007497, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3395161382300277, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.1299839425231335, -0.9915160990554525, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.21414977933437, -3.9108801651768457`, 0.}, 
      Optica`Optica`RayEnd :> {3.1878751517765105`, -4.124011085105019, 0.}, 
      RotationMatrix :> {{-0.12235304411782627`, -0.9924866410159386, 0.}, {
       0.9924866410159386, -0.12235304411782627`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022493516776822393`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2147443714809166, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.675496318592145`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36426300282533325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12235304411782627`, -0.9924866410159386, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1878751517765105`, -4.124011085105019, 0.}, 
      Optica`Optica`RayEnd :> {3.1843017802244207`, -4.353766402763522, 0.}, 
      RotationMatrix :> {{-0.015551063097101706`, -0.9998790749068357, 0.}, {
       0.9998790749068357, -0.015551063097101706`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02223493310608651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22978310420178552`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.01557531281079, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3534353471174926, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.015551063097101706`, -0.9998790749068357, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.264249979302264, -2.9744161410151913`, 0.}, 
      Optica`Optica`RayEnd :> {8.230821166008036, -3.1577858296872368`, 0.}, 
      RotationMatrix :> {{-0.17934695186498578`, -0.983785886693206, 0.}, {
       0.983785886693206, -0.17934695186498578`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05812194749420158, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18639186753166906`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.385131119286815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40852249447837696`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17934695186498578`, -0.983785886693206, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.230821166008036, -3.1577858296872368`, 0.}, 
      Optica`Optica`RayEnd :> {8.200425868156623, -3.420396074804406, 0.}, 
      RotationMatrix :> {{-0.11497543220541802`, -0.9933683355076184, 0.}, {
       0.9933683355076184, -0.11497543220541802`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.057829600887681694`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26436341458676854`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.776388972875232`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3940349969218724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.11497543220541802`, -0.9933683355076184, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.380694900367936, -3.572269944766505, 0.}, 
      Optica`Optica`RayEnd :> {6.3661669333633055`, -3.7128484852223758`, 0.},
       RotationMatrix :> {{-0.10279665359211453`, -0.9947023916781653, 0.}, {
       0.9947023916781653, -0.10279665359211453`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008649170763183722, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14132723680165338`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.56291888228557, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3661220064830449, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 145, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.10279665359211453`, -0.9947023916781653, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.2846673386373135`, -3.42689019718041, 0.}, 
      Optica`Optica`RayEnd :> {5.3101931958713955`, -3.633260269225098, 0.}, 
      RotationMatrix :> {{0.12275427037461739`, -0.99243709579237, 0.}, {
       0.99243709579237, 0.12275427037461739`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.043744074285567106`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20794272293894903`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.49450449562134, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1965277845791934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.12275427037461739`, -0.99243709579237, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3101931958713955`, -3.633260269225098, 0.}, 
      Optica`Optica`RayEnd :> {5.340524913380642, -3.9364533047015757`, 0.}, 
      RotationMatrix :> {{0.09954405628844856, -0.9950331556574589, 0.}, {
       0.9950331556574589, 0.09954405628844856, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.043624030622833515`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3047064650585892, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.94547006390805, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10155539072880723`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09954405628844856, -0.9950331556574589, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8723596812644248`, 0.43704591406790944`, 
       0.}, Optica`Optica`RayEnd :> {3.8163508583297476`, 
       0.37105506085661005`, 0.}, 
      RotationMatrix :> {{-0.6470888406852433, -0.7624146065367756, 0.}, {
       0.7624146065367756, -0.6470888406852433, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010123153358935738`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08655507468706429, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.979219335220392`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10093644845148952`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6470888406852433, -0.7624146065367756, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.8163508583297476`, 0.37105506085661005`, 
       0.}, Optica`Optica`RayEnd :> {3.6277582609737444`, 
       0.13098454742641094`, 0.}, 
      RotationMatrix :> {{-0.6177522146048281, -0.7863728132068332, 0.}, {
       0.7863728132068332, -0.6177522146048281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01009043382390742, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3052884196888622, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.431046196359908`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26532326576512094`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6177522146048281, -0.7863728132068332, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.609319392222294, -2.0588667500189346`, 0.}, 
      Optica`Optica`RayEnd :> {6.607990499786304, -2.292803609693519, 0.}, 
      RotationMatrix :> {{-0.005680468642256964, -0.9999838660078486, 0.}, {
       0.9999838660078486, -0.005680468642256964, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011108221460536992`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23394063407093807`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.83870734264214, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0771565547721506, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.005680468642256964, -0.9999838660078486, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.607990499786304, -2.292803609693519, 0.}, 
      Optica`Optica`RayEnd :> {6.6188993657553175`, -2.610571620417632, 0.}, 
      RotationMatrix :> {{0.03430944302380988, -0.9994112577509794, 0.}, {
       0.9994112577509794, 0.03430944302380988, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011071264259578377`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31795520438623126`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.26476731651969, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04309638006352617, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.03430944302380988, -0.9994112577509794, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1864040273262773`, -1.5908839168081363`, 
       0.}, Optica`Optica`RayEnd :> {2.116943046812807, -1.584546922441695, 
       0.}, RotationMatrix :> {{-0.9958642516112337, 0.09085368656690357, 
       0.}, {-0.09085368656690357, -0.9958642516112337, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010436887729583996`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06974944667517449, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.070260975652456`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19087410217177264`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.9958642516112337, 0.09085368656690357, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.116943046812807, -1.584546922441695, 0.}, 
      Optica`Optica`RayEnd :> {1.8429277720194244`, -1.5431834720036013`, 0.},
       RotationMatrix :> {{-0.9887976731170539, 0.14926205692773845`, 
       0.}, {-0.14926205692773845`, -0.9887976731170539, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010389989784159245`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2771196598082454, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.480398072168658`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1742014400871985, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534885*^-15}, 
      Optica`Optica`RayTilt :> {-0.9887976731170539, 0.14926205692773845`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.135354215431099, -2.873588876929993, 0.}, 
      Optica`Optica`RayEnd :> {3.1291590347370537`, -2.8792926509807226`, 0.},
       RotationMatrix :> {{-0.7356819876975914, -0.6773271092886511, 0.}, {
       0.6773271092886511, -0.7356819876975914, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16146828863427443`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008421003636957336, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.61430272479146, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13591413334877106`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7356819876975914, -0.6773271092886511, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1291590347370537`, -2.8792926509807226`, 
       0.}, Optica`Optica`RayEnd :> {2.8747270856212968`, -3.114781565921408, 
       0.}, RotationMatrix :> {{-0.7338990247585169, -0.6792585821750781, 
       0.}, {0.6792585821750781, -0.7338990247585169, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16106976677838786`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3466852258040206, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.127396858981413`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33029283566787515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7338990247585169, -0.6792585821750781, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.107523011322846, 2.6895580339560903`, 0.}, 
      Optica`Optica`RayEnd :> {1.9715389495919409`, 2.652334402765798, 0.}, 
      RotationMatrix :> {{-0.964516604780188, -0.26402219433846386`, 0.}, {
       0.26402219433846386`, -0.964516604780188, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011349825404379212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1409867503130187, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.215933955345605`, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23687442400320097`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.964516604780188, -0.26402219433846386`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9715389495919409`, 2.652334402765798, 0.}, 
      Optica`Optica`RayEnd :> {1.8126837753289176`, 2.5667455556332626`, 0.}, 
      RotationMatrix :> {{-0.8803520608786449, -0.4743208290879935, 0.}, {
       0.4743208290879935, -0.8803520608786449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010277417254604973`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1804450529762787, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.4829926337505, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2623469712000231, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8803520608786449, -0.4743208290879935, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8546878672361986`, -0.5169710757238604, 0.},
       Optica`Optica`RayEnd :> {2.7081137701951414`, -0.4761334728962817, 0.},
       RotationMatrix :> {{-0.9633098742439864, 0.2683916656381741, 
       0.}, {-0.2683916656381741, -0.9633098742439864, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05797610697195857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15215674723161066`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.726516359412525`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32915924502203975`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9633098742439864, 0.2683916656381741, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.7081137701951414`, -0.4761334728962817, 0.},
       Optica`Optica`RayEnd :> {2.4233374609525127`, -0.41594306614899723`, 
       0.}, RotationMatrix :> {{-0.9783849825150366, 0.20679174545675139`, 
       0.}, {-0.20679174545675139`, -0.9783849825150366, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.057693255181950016`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29106774361006926`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.157296619955428`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3390609504968023, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9783849825150366, 0.20679174545675139`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4218536151488363`, -3.351156547170038, 0.}, 
      Optica`Optica`RayEnd :> {3.4253620668364504`, -3.362413453139368, 0.}, 
      RotationMatrix :> {{0.2975539136047475, -0.9547050164833627, 0.}, {
       0.9547050164833627, 0.2975539136047475, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01245157587967019, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.011790978129343245`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.309739039257465`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3217593679504726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2975539136047475, -0.9547050164833627, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.4253620668364504`, -3.362413453139368, 0.}, 
      Optica`Optica`RayEnd :> {3.5187321549010875`, -3.6092674409253935`, 0.},
       RotationMatrix :> {{0.353778993597178, -0.93532904567824, 0.}, {
       0.93532904567824, 0.353778993597178, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012394992483478704`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26392208060535866`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.700343718553395`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.311312180060994, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.353778993597178, -0.93532904567824, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2269974575965636`, -2.866598855823816, 0.}, 
      Optica`Optica`RayEnd :> {2.2005832540538934`, -3.084454745644393, 0.}, 
      RotationMatrix :> {{-0.12036472996723699`, -0.9927297375317782, 0.}, {
       0.9927297375317782, -0.12036472996723699`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039369948637520094`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21945135879804625`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.833289350864355`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41016041892601884`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.12036472996723699`, -0.9927297375317782, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2005832540538934`, -3.084454745644393, 0.}, 
      Optica`Optica`RayEnd :> {2.19117527744928, -3.3256825326061277`, 0.}, 
      RotationMatrix :> {{-0.03897075858165612, -0.9992403514548286, 0.}, {
       0.9992403514548286, -0.03897075858165612, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03909782909135094, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24141117460931505`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.190577889286143`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3866439949557562, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.03897075858165612, -0.9992403514548286, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.200425868156623, -3.420396074804406, 0.}, 
      Optica`Optica`RayEnd :> {8.189281402749307, -3.642485901268315, 0.}, 
      RotationMatrix :> {{-0.05011693227824933, -0.9987433569736603, 0.}, {
       0.9987433569736603, -0.05011693227824933, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.057538724750442846`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2223692652503579, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.074363788310713`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4005769259794034, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05011693227824933, -0.9987433569736603, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.189281402749307, -3.642485901268315, 0.}, 
      Optica`Optica`RayEnd :> {8.195899279209828, -3.8980626220087173`, 0.}, 
      RotationMatrix :> {{0.02588521730014453, -0.9996649216239025, 0.}, {
       0.9996649216239025, 0.02588521730014453, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05718265653137244, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2556623876780946, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 27.452744122074293`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4155261532803731, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.02588521730014453, -0.9996649216239025, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.340524913380642, -3.9364533047015757`, 0.}, 
      Optica`Optica`RayEnd :> {5.354799821483549, -4.123047464971758, 0.}, 
      RotationMatrix :> {{0.0762795455419229, -0.9970864711407513, 0.}, {
       0.9970864711407513, 0.0762795455419229, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.043504316387141154`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18713939630201026`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.196236854952744`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19835686822707274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0762795455419229, -0.9970864711407513, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.354799821483549, -4.123047464971758, 0.}, 
      Optica`Optica`RayEnd :> {5.3435873933583835`, -4.311607522435026, 0.}, 
      RotationMatrix :> {{-0.05935858144977356, -0.9982367248344799, 0.}, {
       0.9982367248344799, -0.05935858144977356, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04262623936684563, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18889312802485206`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.475798684429524`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1425673901415661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05935858144977356, -0.9982367248344799, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6277582609737444`, 0.1309845474264109, 0.}, 
      Optica`Optica`RayEnd :> {3.5846098472847885`, 0.0715563325483261, 0.}, 
      RotationMatrix :> {{-0.5875293406282709, -0.8092028632555052, 0.}, {
       0.8092028632555052, -0.5875293406282709, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01005782004327544, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07344044068133798, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.5294563868729, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21812045673242605`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5875293406282709, -0.8092028632555052, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5846098472847885`, 0.0715563325483261, 0.}, 
      Optica`Optica`RayEnd :> {3.3955428969268873`, -0.17104557766406175`, 
       0.}, RotationMatrix :> {{-0.61470318507497, -0.7887585145395806, 0.}, {
       0.7887585145395806, -0.61470318507497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01002689046088073, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30757437890100103`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.984666467646385`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38300220241527305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.61470318507497, -0.7887585145395806, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.6188993657553175`, -2.610571620417632, 0.}, 
      Optica`Optica`RayEnd :> {6.621906511845788, -2.650963131536688, 0.}, 
      RotationMatrix :> {{0.07424447601816592, -0.9972400702843758, 0.}, {
       0.9972400702843758, 0.07424447601816592, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011034430015720277`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04050329737305689, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.324712196631815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35411333357890334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.07424447601816592, -0.9972400702843758, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.621906511845788, -2.650963131536688, 0.}, 
      Optica`Optica`RayEnd :> {6.617583509206603, -2.8749985982825743`, 0.}, 
      RotationMatrix :> {{-0.01929247238127947, -0.9998138829349272, 0.}, {
       0.9998138829349272, -0.01929247238127947, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010937699242241987`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22407717133136384`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.62497560621584, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34023206852003335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.01929247238127947, -0.9998138829349272, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.8747270856212968`, -3.114781565921408, 0.}, 
      Optica`Optica`RayEnd :> {2.838082340362363, -3.148877303266252, 0.}, 
      RotationMatrix :> {{-0.7321109909116376, -0.6811853616941423, 0.}, {
       0.6811853616941423, -0.7321109909116376, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16067222851916274`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.050053537938698406`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.19446859981927, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05308530712476637, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7321109909116376, -0.6811853616941423, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.838082340362363, -3.148877303266252, 0.}, 
      Optica`Optica`RayEnd :> {2.6159504524003254`, -3.3632753449875312`, 0.},
       RotationMatrix :> {{-0.7195214290559875, -0.6944702391962013, 0.}, {
       0.6944702391962013, -0.7195214290559875, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1602489253146359, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30872171278272376`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.651376734737703`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2800639917920772, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7195214290559875, -0.6944702391962013, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.4233374609525127`, -0.41594306614899723`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3635825394116026`, -0.40722552239788085`, 0.}, 
      RotationMatrix :> {{-0.9895252132034068, 0.1443601483607946, 
       0.}, {-0.1443601483607946, -0.9895252132034068, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05741178335929856, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.060387467386975056`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.238215826253974`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0580364575598141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9895252132034068, 0.1443601483607946, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3635825394116026`, -0.40722552239788085`, 
       0.}, Optica`Optica`RayEnd :> {2.1264231119612176`, -0.3502980429841255,
        0.}, RotationMatrix :> {{-0.9723787256901998, 0.23340868412529453`, 
       0.}, {-0.23340868412529453`, -0.9723787256901998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.056936823920177744`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24389614991015712`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.599182128121008`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22183916443517607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9723787256901998, 0.23340868412529453`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5187321549010875`, -3.6092674409253935`, 
       0.}, Optica`Optica`RayEnd :> {3.66216580349884, -3.929519671680314, 
       0.}, RotationMatrix :> {{0.40875286771613195`, -0.9126451079876765, 
       0.}, {0.9126451079876765, 0.40875286771613195`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012338666217850892`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.35090554691193826`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.17055715141539, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12646324090103922`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.40875286771613195`, -0.9126451079876765, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.66216580349884, -3.929519671680314, 0.}, 
      Optica`Optica`RayEnd :> {3.70053918451893, -4.096874564738043, 0.}, 
      RotationMatrix :> {{0.2234935662269396, -0.9747054046506379, 0.}, {
       0.9747054046506379, 0.2234935662269396, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01161965895953892, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1716979225304628, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.424670076760474`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3245871373119852, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2234935662269396, -0.9747054046506379, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.19117527744928, -3.3256825326061277`, 0.}, 
      Optica`Optica`RayEnd :> {2.2006771023350336`, -3.5480932227332427`, 0.},
       RotationMatrix :> {{0.04268304514085796, -0.9990886635616995, 0.}, {
       0.9990886635616995, 0.04268304514085796, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03882759039720142, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22261356598145401`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.48888006770129, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2868811053978894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.04268304514085796, -0.9990886635616995, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2006771023350336`, -3.5480932227332427`, 
       0.}, Optica`Optica`RayEnd :> {
       2.2155922311191225`, -3.8656354417860164`, 0.}, 
      RotationMatrix :> {{0.04691880937993223, -0.9988987062392106, 0.}, {
       0.9988987062392106, 0.04691880937993223, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03873154493018055, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31789231187244127`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.959360689272504`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24723282588573392`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.04691880937993223, -0.9988987062392106, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.195899279209828, -3.8980626220087173`, 0.}, 
      Optica`Optica`RayEnd :> {8.216390756546161, -4.098432075737106, 0.}, 
      RotationMatrix :> {{0.10173782342183363`, -0.994811246058963, 0.}, {
       0.994811246058963, 0.10173782342183363`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05682879177748452, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20141454423858904`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.722639611354, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3942748534064837, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10173782342183363`, -0.994811246058963, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.216390756546161, -4.098432075737106, 0.}, 
      Optica`Optica`RayEnd :> {8.2637206997027, -4.46240798472222, 0.}, 
      RotationMatrix :> {{0.1289502609140301, -0.9916510627283179, 0.}, {
       0.9916510627283179, 0.1289502609140301, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05666664760788331, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.36704030547167527`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 28.265859263452082`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30252411739668295`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1289502609140301, -0.9916510627283179, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.3955428969268873`, -0.17104557766406175`, 
       0.}, Optica`Optica`RayEnd :> {3.386058930047751, -0.1823967932116381, 
       0.}, RotationMatrix :> {{-0.6411661933871448, -0.7674020539830716, 
       0.}, {0.7674020539830716, -0.6411661933871448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009996055992443423, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01479174506852015, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.0044874060382, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17900719592525277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6411661933871448, -0.7674020539830716, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.386058930047751, -0.1823967932116381, 0.}, 
      Optica`Optica`RayEnd :> {3.1814876357625916`, -0.4182253843986803, 0.}, 
      RotationMatrix :> {{-0.6552716467816868, -0.7553933206773905, 0.}, {
       0.7553933206773905, -0.6552716467816868, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009969678396836617, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3121931114979483, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.466533211055165`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4290225989925714, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6552716467816868, -0.7553933206773905, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.617583509206603, -2.8749985982825743`, 0.}, 
      Optica`Optica`RayEnd :> {6.610183188278267, -2.940267322267495, 0.}, 
      RotationMatrix :> {{-0.11266050003604926`, -0.9936335399590868, 0.}, {
       0.9936335399590868, -0.11266050003604926`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010841816436671809`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06568691711796264, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.722192243550428`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20963158119651631`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.11266050003604926`, -0.9936335399590868, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.610183188278267, -2.940267322267495, 0.}, 
      Optica`Optica`RayEnd :> {6.612659338632755, -3.1199280820686464`, 0.}, 
      RotationMatrix :> {{0.01378105722069417, -0.9999050367219273, 0.}, {
       0.9999050367219273, 0.01378105722069417, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010658158601366319`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1796778225961824, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.962960525829313`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22206210369223883`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.01378105722069417, -0.9999050367219273, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6159504524003254`, -3.3632753449875312`, 
       0.}, Optica`Optica`RayEnd :> {2.610911570792706, -3.368320156404455, 
       0.}, RotationMatrix :> {{-0.7066908382871107, -0.7075224795588196, 
       0.}, {0.7075224795588196, -0.7066908382871107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15982673733459185`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007130248949926514, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.660931268330604`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012636102533284711`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7066908382871107, -0.7075224795588196, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.610911570792706, -3.368320156404455, 0.}, 
      Optica`Optica`RayEnd :> {2.3994172582498967`, -3.5898937933800235`, 0.},
       RotationMatrix :> {{-0.6904624301354393, -0.7233682551587837, 0.}, {
       0.7233682551587837, -0.6904624301354393, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15939074054648214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30630821216633514`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.11426742233678, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2804256705620147, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6904624301354393, -0.7233682551587837, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1264231119612176`, -0.3502980429841255, 0.},
       Optica`Optica`RayEnd :> {2.1230759113004076`, -0.3491653743978561, 0.},
       RotationMatrix :> {{-0.9472357419411566, 0.32053775002202933`, 
       0.}, {-0.32053775002202933`, -0.9472357419411566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05646579375229029, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00353365114153173, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.60391722065066, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.172413112160577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9472357419411566, 0.32053775002202933`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1230759113004076`, -0.3491653743978561, 0.},
       Optica`Optica`RayEnd :> {1.9247809079917395`, -0.31161928865510713`, 
       0.}, RotationMatrix :> {{-0.9825423462748508, 0.1860390759402695, 
       0.}, {-0.1860390759402695, -0.9825423462748508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05524930315696491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2018182769022334, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.902608270465965`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42735517669316475`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9825423462748508, 0.1860390759402695, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.70053918451893, -4.096874564738043, 0.}, 
      Optica`Optica`RayEnd :> {3.702257626811304, -4.154703283557864, 0.}, 
      RotationMatrix :> {{0.029702958992410794`, -0.9995587697714899, 0.}, {
       0.9995587697714899, 0.029702958992410794`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010942550187528316`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.057854245861943134`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.502194766215478`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4277373432728242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.029702958992410794`, -0.9995587697714899, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.702257626811304, -4.154703283557864, 0.}, 
      Optica`Optica`RayEnd :> {3.7259065841173045`, -4.4409374302681215`, 0.},
       RotationMatrix :> {{0.08234046090002008, -0.9966042587199653, 0.}, {
       0.9966042587199653, 0.08234046090002008, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010898277795699938`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28720943564689916`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.92726473097289, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3926129050315694, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.08234046090002008, -0.9966042587199653, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2155922311191225`, -3.8656354417860164`, 
       0.}, Optica`Optica`RayEnd :> {2.228243500126284, -4.112630251758305, 
       0.}, RotationMatrix :> {{0.05115373012285755, -0.9986907909330681, 
       0.}, {0.9986907909330681, 0.05115373012285755, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03863573704503487, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2473186017280919, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.29076761558815, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17792486185203377`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.05115373012285755, -0.9986907909330681, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.228243500126284, -4.112630251758305, 0.}, 
      Optica`Optica`RayEnd :> {2.2382741906794665`, -4.436492633377812, 0.}, 
      RotationMatrix :> {{0.030957232185027946`, -0.9995207100282824, 0.}, {
       0.9995207100282824, 0.030957232185027946`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03853247656745058, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32401768004421155`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.77031378205358, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14866682894303845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.030957232185027946`, -0.9995207100282824, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1814876357625916`, -0.4182253843986803, 0.},
       Optica`Optica`RayEnd :> {3.157010076547749, -0.4454088774003837, 0.}, 
      RotationMatrix :> {{-0.6691522283175975, -0.7431253564087237, 0.}, {
       0.7431253564087237, -0.6691522283175975, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009943370406437158, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03657995621771289, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.5155503523869, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4060314464392026, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6691522283175975, -0.7431253564087237, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.157010076547749, -0.4454088774003837, 0.}, 
      Optica`Optica`RayEnd :> {2.9759563094528474`, -0.6156758306537146, 0.}, 
      RotationMatrix :> {{-0.7284742212831304, -0.6850732142814631, 0.}, {
       0.6850732142814631, -0.7284742212831304, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00987278893074765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2485383309460066, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.88338708218699, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31614512115921656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7284742212831304, -0.6850732142814631, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.612659338632755, -3.1199280820686464`, 0.}, 
      Optica`Optica`RayEnd :> {6.613883624297096, -3.128586745291935, 0.}, 
      RotationMatrix :> {{0.14000174824234501`, -0.9901512563689883, 0.}, {
       0.9901512563689883, 0.14000174824234501`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010477611886846358`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.008744788402371181, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.975902812664824`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3052607049325559, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.14000174824234501`, -0.9901512563689883, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.613883624297096, -3.128586745291935, 0.}, 
      Optica`Optica`RayEnd :> {6.620701540397806, -3.3381284650382446`, 0.}, 
      RotationMatrix :> {{0.03252006329007291, -0.9994710828651365, 0.}, {
       0.9994710828651365, 0.03252006329007291, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010355146338043755`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20965260860336837`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.256837308193337`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3303573046106641, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.03252006329007291, -0.9994710828651365, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3994172582498967`, -3.5898937933800235`, 
       0.}, Optica`Optica`RayEnd :> {2.357224672434786, -3.6361538172685215`, 
       0.}, RotationMatrix :> {{-0.6738788137001575, -0.7388418940788807, 
       0.}, {0.7388418940788807, -0.6738788137001575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1589559331288271, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06261153334594119, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.19816687702034, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27763954744520747`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6738788137001575, -0.7388418940788807, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.357224672434786, -3.6361538172685215`, 0.}, 
      Optica`Optica`RayEnd :> {2.1468082288758534`, -3.850481151304229, 0.}, 
      RotationMatrix :> {{-0.7005662954026965, -0.7135873217383709, 0.}, {
       0.7135873217383709, -0.7005662954026965, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.158449817778772, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3003519366257575, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.642687743226464`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41064915223056064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7005662954026965, -0.7135873217383709, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.9759563094528474`, -0.6156758306537146, 0.},
       Optica`Optica`RayEnd :> {2.898480630675166, -0.6772683293156354, 0.}, 
      RotationMatrix :> {{-0.7827776460270708, -0.6223014999823773, 0.}, {
       0.6223014999823773, -0.7827776460270708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009802708466737973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09897533376291887, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.0160140294293, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17159938694065677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7827776460270708, -0.6223014999823773, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.898480630675166, -0.6772683293156354, 0.}, 
      Optica`Optica`RayEnd :> {2.672209777524318, -0.858033741578869, 0.}, 
      RotationMatrix :> {{-0.781291855813466, -0.6241658722163116, 0.}, {
       0.6241658722163116, -0.781291855813466, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009778520280707782, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28961117598654496`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.444638569889385`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3030904231795021, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.781291855813466, -0.6241658722163116, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.620701540397806, -3.3381284650382446`, 0.}, 
      Optica`Optica`RayEnd :> {6.617152559466575, -3.3851007019041273`, 0.}, 
      RotationMatrix :> {{-0.07534012826467568, -0.9971578937525698, 0.}, {
       0.9971578937525698, -0.07534012826467568, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010234112204224405`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04710611745659842, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.326554362029103`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25826422386070913`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.07534012826467568, -0.9971578937525698, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.617152559466575, -3.3851007019041273`, 0.}, 
      Optica`Optica`RayEnd :> {6.630213745123582, -3.5013041336861583`, 0.}, 
      RotationMatrix :> {{0.11169596403364497`, -0.9937424272006272, 0.}, {
       0.9937424272006272, 0.11169596403364497`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009714020314729989, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11693516207149965`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.483247479204913`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3468634411272914, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.11169596403364497`, -0.9937424272006272, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1468082288758534`, -3.850481151304229, 0.}, 
      Optica`Optica`RayEnd :> {2.132850973422473, -3.8636901345735404`, 0.}, 
      RotationMatrix :> {{-0.7263080020252727, -0.6873693957356961, 0.}, {
       0.6873693957356961, -0.7263080020252727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15794531389890568`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019216717170210514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.668438144234546`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09268786602930476, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7263080020252727, -0.6873693957356961, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.132850973422473, -3.8636901345735404`, 0.}, 
      Optica`Optica`RayEnd :> {1.892191514199834, -4.095942514368096, 0.}, 
      RotationMatrix :> {{-0.7195635130637594, -0.6944266344743268, 0.}, {
       0.6944266344743268, -0.7195635130637594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1575484884853253, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3344520043796531, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.163427110716434`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.312254300389684, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7195635130637594, -0.6944266344743268, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.672209777524318, -0.858033741578869, 0.}, 
      Optica`Optica`RayEnd :> {2.6138631964053385`, -0.9048745229806487, 0.}, 
      RotationMatrix :> {{-0.7798016251616744, -0.6260266970307338, 0.}, {
       0.6260266970307338, -0.7798016251616744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00975439177903375, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07482233844650261, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.5449005034077, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.126952719383921, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7798016251616744, -0.6260266970307338, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.6138631964053385`, -0.9048745229806487, 0.},
       Optica`Optica`RayEnd :> {2.3384123243514687`, -1.1309549887150265`, 
       0.}, RotationMatrix :> {{-0.7729777313692627, -0.6344331539313078, 
       0.}, {0.6344331539313078, -0.7729777313692627, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00972977672635962, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35635033310200576`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.07229899639867, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2757111782404823, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 74, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7729777313692627, -0.6344331539313078, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.630213745123582, -3.5013041336861583`, 0.}, 
      Optica`Optica`RayEnd :> {6.660778854575984, -3.600368690908474, 0.}, 
      RotationMatrix :> {{0.29482334931060206`, -0.9555517739511962, 0.}, {
       0.9555517739511962, 0.29482334931060206`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009220359205758574, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1036726213302759, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.636682958773722`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4086059073685644, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.29482334931060206`, -0.9555517739511962, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.660778854575984, -3.600368690908474, 0.}, 
      Optica`Optica`RayEnd :> {6.757251316699107, -3.9294027223609964`, 0.}, 
      RotationMatrix :> {{0.28135490724177614`, -0.959603780823612, 0.}, {
       0.959603780823612, 0.28135490724177614`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009196715279504124, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3428853012335131, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.09614926242663, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1883100385791175, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 74, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.28135490724177614`, -0.959603780823612, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3384123243514687`, -1.1309549887150265`, 
       0.}, 
      Optica`Optica`RayEnd :> {2.315348086617261, -1.1503070340854382`, 0.}, 
      RotationMatrix :> {{-0.766063218271388, -0.642765233667536, 0.}, {
       0.642765233667536, -0.766063218271388, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009705223789379826, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.030107486150100924`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.112643027839805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0030064386410880847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 75, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.766063218271388, -0.642765233667536, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.315348086617261, -1.1503070340854382`, 0.}, 
      Optica`Optica`RayEnd :> {2.0918985495275626`, -1.3514712695253897`, 0.},
       RotationMatrix :> {{-0.743195484555467, -0.669074339469362, 0.}, {
       0.669074339469362, -0.743195484555467, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009675060194578883, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.300660514942918, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.557620589955324`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20054877422355855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 76, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.743195484555467, -0.669074339469362, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.757251316699107, -3.9294027223609964`, 0.}, 
      Optica`Optica`RayEnd :> {6.818098322848967, -4.148287247464208, 0.}, 
      RotationMatrix :> {{0.2678308081947124, -0.9634659610913954, 0.}, {
       0.9634659610913954, 0.2678308081947124, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009173131983777866, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2271844921799449, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.432382310852947`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11593954711943455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 75, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.2678308081947124, -0.9634659610913954, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.818098322848967, -4.148287247464208, 0.}, 
      Optica`Optica`RayEnd :> {6.866441308379045, -4.240348940993934, 0.}, 
      RotationMatrix :> {{0.4649137839635013, -0.8853559586294869, 0.}, {
       0.8853559586294869, 0.4649137839635013, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008477358699008812, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10398268925894594`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.571719114459935`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38957594090948744`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 76, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.4649137839635013, -0.8853559586294869, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0918985495275626`, -1.3514712695253897`, 
       0.}, Optica`Optica`RayEnd :> {2.083749471856234, -1.3593388178846615`, 
       0.}, RotationMatrix :> {{-0.7194246923018226, -0.6945704515068478, 
       0.}, {0.6945704515068478, -0.7194246923018226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009644990347482377, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.011327214312390366`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.572799057133928`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.049425584288464094`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 167, 
      Optica`Optica`IntersectionNumber :> 77, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7194246923018226, -0.6945704515068478, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.083749471856234, -1.3593388178846615`, 0.}, 
      Optica`Optica`RayEnd :> {1.8626583431103891`, -1.5802739192837725`, 0.},
       RotationMatrix :> {{-0.7073563331557031, -0.7068571411144662, 0.}, {
       0.7068571411144662, -0.7073563331557031, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009619770402865472, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3125597642697271, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.035387508253123`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2912925483439838, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 167, 
      Optica`Optica`IntersectionNumber :> 78, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7073563331557031, -0.7068571411144662, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7667114977152143`, 0., 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, 0.2310098625111181, 0.}, 
      RotationMatrix :> {{-0.975145483966289, 0.22156553229271028`, 
       0.}, {-0.22156553229271028`, -0.975145483966289, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25210800679539547`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0426254486457347`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.4445115081236715`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.6310098625111181, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 2, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.975145483966289, 0.22156553229271028`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7737198649463215`, -0.07722951543100699, 
       0.}, Optica`Optica`RayEnd :> {0.75, -0.2645718457173044, 0.}, 
      RotationMatrix :> {{-0.9836643929276236, -0.18001211649866722`, 0.}, {
       0.18001211649866722`, -0.9836643929276236, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2508384402129281, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.0407206688650008`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 7.579050002408071, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.13542815428269564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 4, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9836643929276236, -0.18001211649866722`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7672930323709903`, 0.004669646611714488, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, 
       0.011079305361220593`, 0.}, 
      RotationMatrix :> {{-0.999980151177387, 0.006300575469771955, 
       0.}, {-0.006300575469771955, -0.999980151177387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24399111906604629`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0173132248407322`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.983874433669025, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.4110793053612206, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.999980151177387, 0.006300575469771955, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7661119968940817`, -0.006264234149068747, 
       0.}, Optica`Optica`RayEnd :> {0.75, -0.008397797803824991, 0.}, 
      RotationMatrix :> {{-0.999997795568443, -0.002099728138219784, 0.}, {
       0.002099728138219784, -0.999997795568443, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24281264740012035`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0161142368483709`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.005136127759545, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.39160220219617503`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999997795568443, -0.002099728138219784, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3675489352810515`, 0.11310424430511475`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, 0.35379247403818237`,
        0.}, RotationMatrix :> {{-0.9891100652716592, 0.14717771155407428`, 
       0.}, {-0.14717771155407428`, -0.9891100652716592, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24931985845250892`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.635357875806058, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.58874427924843, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.7537924740381824, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9891100652716592, 0.14717771155407428`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.850524420653777, -0.5013247962187429, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, -0.928706845010267, 0.}, 
      RotationMatrix :> {{-0.9321761494491662, -0.36200500880253805`, 0.}, {
       0.36200500880253805`, -0.9321761494491662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24086346391192495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1805970591546344`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.789590919019641`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.528706845010267, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9321761494491662, -0.36200500880253805`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9375366706374482`, 0.3992115048105958, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, 0.5757269206438212, 0.}, 
      RotationMatrix :> {{-0.9891328248659392, 0.14702467402693642`, 
       0.}, {-0.14702467402693642`, -0.9891328248659392, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23369156789924644`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2005836231331206`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.788791002973728`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.9757269206438213, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9891328248659392, 0.14702467402693642`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.842422203976989, -0.4570800530492261, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -0.8587765005445434, 0.}, 
      RotationMatrix :> {{-0.9385588966995021, -0.34511910614484, 0.}, {
       0.34511910614484, -0.9385588966995021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24520328198809632`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1639356973958228`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.983935067694727`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.4587765005445434, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9385588966995021, -0.34511910614484, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1679364592479047`, 0.7873630095557195, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.6218552987430191, 0.}, 
      RotationMatrix :> {{-0.9932565429570509, -0.1159372238455268, 0.}, {
       0.1159372238455268, -0.9932565429570509, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06057624519092128, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.427563170161988, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.725666916272605`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0218552987430192`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9932565429570509, -0.1159372238455268, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1968282486405424`, -1.5843271908251064`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.088120711125074, 0.}, 
      RotationMatrix :> {{-0.9443855698933966, -0.3288402277354823, 0.}, {
       0.3288402277354823, -0.9443855698933966, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07670595478336543, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.5320312960773654`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.470105752895062`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.6881207111250738`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9443855698933966, -0.3288402277354823, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9265945208348418`, -0.5911279665573725, 0.},
       Optica`Optica`RayEnd :> {0.75, -2.921154990973647, 0.}, 
      RotationMatrix :> {{-0.45075946980629783`, -0.8926454505457054, 0.}, {
       0.8926454505457054, -0.45075946980629783`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013440267656036283`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.6102491453822436`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.182395620976248`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.5211549909736477`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45075946980629783`, -0.8926454505457054, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8849683746156314`, 0.8698811764446064, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.9551550171248132, 0.}, 
      RotationMatrix :> {{-0.9971893926572495, 0.07492206064882145, 
       0.}, {-0.07492206064882145, -0.9971893926572495, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19755853436454543`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1381673160313475`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.046373725498299`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.3551550171248132`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9971893926572495, 0.07492206064882145, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.981736479233178, 2.1791356728325355`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 2.966776391674025, 0.}, 
      RotationMatrix :> {{-0.8424795984752177, 0.5387282488908818, 
       0.}, {-0.5387282488908818, -0.8424795984752177, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22777152927111408`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4620371596682773`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.078710769148675`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.366776391674025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8424795984752177, 0.5387282488908818, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0330784063531713`, -2.120040053223454, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, -3.832482196669296, 0.}, 
      RotationMatrix :> {{-0.5996251101343456, -0.8002810301990005, 0.}, {
       0.8002810301990005, -0.5996251101343456, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01238178954365232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.1398009934335445`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.63521417428526, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.432482196669296, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5996251101343456, -0.8002810301990005, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.871705955361084, -2.579383011099843, 0.}, 
      Optica`Optica`RayEnd :> {1.574703078245685, -5.4, 0.}, 
      RotationMatrix :> {{-0.10471820070317472`, -0.9945019348606058, 0.}, {
       0.9945019348606058, -0.10471820070317472`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21212186112314835`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      2.836210659857095, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.729315957594864`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {3.675296921754315, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10471820070317472`, -0.9945019348606058, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8907195989671668`, 1.684804414747426, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, 4.016141094002052, 0.}, 
      RotationMatrix :> {{-0.4395070795338904, 0.8982391257563824, 
       0.}, {-0.8982391257563824, -0.4395070795338904, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015042604907991313`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.595452160126594, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.630217251128226`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.416141094002052, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4395070795338904, 0.8982391257563824, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8604948557158172`, -0.18781759303254186`, 
       0.}, Optica`Optica`RayEnd :> {0.7500000000000002, -4.038364933774184, 
       0.}, RotationMatrix :> {{-0.2771053739138759, -0.9608395348589956, 
       0.}, {0.9608395348589956, -0.2771053739138759, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01321490144109207, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 4.007482208053308, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.044097261235233`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.638364933774184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2771053739138759, -0.9608395348589956, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0670908527082337`, -0.6339946714700225, 0.},
       Optica`Optica`RayEnd :> {0.7500000000000002, -1.147294791143008, 0.}, 
      RotationMatrix :> {{-0.9317420102358133, -0.3631209527990987, 0.}, {
       0.3631209527990987, -0.9317420102358133, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008710703712198769, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.413578907293117, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.498469541383368`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.747294791143008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9317420102358133, -0.3631209527990987, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.82287096155126, 1.0079416589077277`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.4930922703543543`, 0.}, 
      RotationMatrix :> {{-0.9111703512953842, 0.4120298422690347, 
       0.}, {-0.4120298422690347, -0.9111703512953842, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21194901949479275`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1774647408423577`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.545396600791276`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.8930922703543542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9111703512953842, 0.4120298422690347, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.382099314299674, 0.22347529134967298`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.05704594163051452, 0.}, 
      RotationMatrix :> {{0.979613099988907, -0.20089344023666536`, 0.}, {
       0.20089344023666536`, 0.979613099988907, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07180781634103656, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3963683067486694`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.089647249471223`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.34295405836948556`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.979613099988907, -0.20089344023666536`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8528470577585507`, -1.17291256256883, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, -1.6019322081523129`, 0.}, 
      RotationMatrix :> {{-0.931966220804767, -0.36254511895608243`, 0.}, {
       0.36254511895608243`, -0.931966220804767, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21674958435278577`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1833551829874536`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.56020189987696, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.201932208152313, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.931966220804767, -0.36254511895608243`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.410142819605809, 3.6812770041790377`, 0.}, 
      Optica`Optica`RayEnd :> {6.398097770588954, 4.6, 0.}, 
      RotationMatrix :> {{0.7322994206804064, 0.6809827886746782, 
       0.}, {-0.6809827886746782, 0.7322994206804064, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008724005044455016, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3491133859770106`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.28097047630116, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.1480977705889548`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7322994206804064, 0.6809827886746782, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1531498249152365`, 3.3914826324245704`, 0.},
       Optica`Optica`RayEnd :> {4.096020104562012, 4.6, 0.}, 
      RotationMatrix :> {{0.615123761317455, 0.7884305665451249, 
       0.}, {-0.7884305665451249, 0.615123761317455, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01863151469667742, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.5328139456478838`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.53669590932355, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.1539798954379883`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.615123761317455, 0.7884305665451249, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.841612151678042, -2.4839424729838475`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -3.7999334201003583`, 0.}, 
      RotationMatrix :> {{-0.6384407234914246, -0.7696709963274867, 0.}, {
       0.7696709963274867, -0.6384407234914246, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2503182207593463, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7098097153144776`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.308345555528728`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.3999334201003584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6384407234914246, -0.7696709963274867, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.34571974139002, 2.320663474652185, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.798201103792634, 0.}, 
      RotationMatrix :> {{0.9467558246219879, 0.32195249423531436`, 
       0.}, {-0.32195249423531436`, 0.9467558246219879, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010397071340990218`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4832549450336556`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.845029707383027`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.198201103792634, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9467558246219879, 0.32195249423531436`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.371022184652178, -0.3716808198235361, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.4126332128078969, 0.}, 
      RotationMatrix :> {{0.999559316428755, -0.02968455727276835, 0.}, {
       0.02968455727276835, 0.999559316428755, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.5475511541848186`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.379585776134488, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.638569464513736`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.012633212807896886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.999559316428755, -0.02968455727276835, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0921927069666446`, 0.3256054024297014, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.10026814533756578`, 0.}, 
      RotationMatrix :> {{-0.9861980021971971, -0.16557022818809206`, 0.}, {
       0.16557022818809206`, -0.9861980021971971, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06269067518534704, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3609769072501767`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.04120231669908, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.5002681453375658, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9861980021971971, -0.16557022818809206`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.18705552402088, 0.7293805768078586, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.26803405995480933`, 0.}, 
      RotationMatrix :> {{-0.952137402486927, -0.3056703564061254, 0.}, {
       0.3056703564061254, -0.952137402486927, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010374915291683382`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5092942681039265`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.778959066371865`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.6680340599548094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.952137402486927, -0.3056703564061254, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.074965366139089, -0.7819802989291605, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, -1.0556499518973506`, 0.}, 
      RotationMatrix :> {{-0.9793279857390603, -0.20227875901407544`, 0.}, {
       0.20227875901407544`, -0.9793279857390603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009154747018122682, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.352933220977229, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.5110647065028, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.6556499518973503, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9793279857390603, -0.20227875901407544`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.279619357017198, 2.3844659508650694`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 3.4820796197269925`, 0.}, 
      RotationMatrix :> {{0.8013509015041572, 0.5981945608733614, 
       0.}, {-0.5981945608733614, 0.8013509015041572, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      70.51767649597501, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8348773804619884`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.193593049782393`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.8820796197269924`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8013509015041572, 0.5981945608733614, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.353376858084014, 1.4486758481567938`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 1.475934126222417, 0.}, 
      RotationMatrix :> {{0.9998095923828223, 0.019513558857732094`, 
       0.}, {-0.019513558857732094`, 0.9998095923828223, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0875835243348965, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3968891202448335`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.66985961631749, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-1.875934126222417, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9998095923828223, 0.019513558857732094`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.471556087494077, 1.3036155224815655`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.1488836651565428`, 0.}, 
      RotationMatrix :> {{0.462247415586626, -0.8867509948026473, 0.}, {
       0.8867509948026473, 0.462247415586626, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.1653661208978088`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.765713488919095, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.78100183499799, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.7488836651565429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.462247415586626, -0.8867509948026473, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.18182694304322, 0.5465277883779298, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.3682938018806834, 0.}, 
      RotationMatrix :> {{0.8637659614480736, -0.5038932067846161, 0.}, {
       0.5038932067846161, 0.8637659614480736, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08025236492921935, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8155068930104539`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.997602950225513`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.03170619811931663, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8637659614480736, -0.5038932067846161, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.40513098295746, -1.2478631540215561`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.0051899138897755`, 0.}, 
      RotationMatrix :> {{0.9841070903929416, 0.17757599679669042`, 
       0.}, {-0.17757599679669042`, 0.9841070903929416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010862216620351466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3665880778336341`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.623015065322136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.6051899138897753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9841070903929416, 0.17757599679669042`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8631456608056345`, -1.9991716919118454`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.54891212154094, 0.}, 
      RotationMatrix :> {{-0.8966177027608964, -0.442805482233195, 0.}, {
       0.442805482233195, -0.8966177027608964, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16858614175314884`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2414941812748035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.546817502901217`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.14891212154094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8966177027608964, -0.442805482233195, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0003485458539485`, 3.6568472194308046`, 0.},
       Optica`Optica`RayEnd :> {1.8899101609401012`, 4.6, 0.}, 
      RotationMatrix :> {{-0.11630030972161609`, 0.9932140947241214, 
       0.}, {-0.9932140947241214, -0.11630030972161609`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013624201370336193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9495966535102065, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.69253859306236, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.3600898390598988`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.11630030972161609`, 0.9932140947241214, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.347403889598631, 0.3164039243675053, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.3150971450631865`, 0.}, 
      RotationMatrix :> {{0.5744269500724504, 0.8185558496709079, 
       0.}, {-0.8185558496709079, 0.5744269500724504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09730877095902937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.441731033379378, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.889567265264755`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-2.7150971450631864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.5744269500724504, 0.8185558496709079, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.33682100981092, -2.372116296911316, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -3.3637609551454264`, 0.}, 
      RotationMatrix :> {{0.8185730054687448, -0.5744025023603798, 0.}, {
       0.5744025023603798, 0.8185730054687448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.069397672552881, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.726393346406337, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.215547721415845`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.9637609551454265`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8185730054687448, -0.5744025023603798, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.311903601845028, -1.6379705011059962`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 1.2905317992727268`, 0.}, 
      RotationMatrix :> {{0.44078877583012166`, 0.897610859505489, 
       0.}, {-0.897610859505489, 0.44078877583012166`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042739110560332604`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.2625522177751844`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.538205844867377`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-1.6905317992727267`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.44078877583012166`, 0.897610859505489, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.336491908698271, -1.3533739219868754`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -5.137849265650147, 0.}, 
      RotationMatrix :> {{0.34989261716047115`, -0.9367898144496426, 0.}, {
       0.9367898144496426, 0.34989261716047115`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035978520662323245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 4.039834000422627, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.32334829270187, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {4.737849265650146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.34989261716047115`, -0.9367898144496426, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.468165047516123, 1.3220799330813995`, 0.}, 
      Optica`Optica`RayEnd :> {9.547044756836728, 4.6, 0.}, 
      RotationMatrix :> {{0.3126367973598252, 0.9498727456541696, 
       0.}, {-0.9498727456541696, 0.3126367973598252, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11722278060440564`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.4509044310573644`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.776044930720317`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {4.297044756836728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3126367973598252, 0.9498727456541696, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.454284569695465, -0.7830988991393053, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.9427746248001707`, 0.}, 
      RotationMatrix :> {{0.5144694780422894, -0.8575086915961223, 0.}, {
       0.8575086915961223, 0.5144694780422894, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2847796251139698, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.51854674690347, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.914811541821898`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.542774624800171, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5144694780422894, -0.8575086915961223, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.192257270270463, 1.011642970905468, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 1.6024250208275874`, 0.}, 
      RotationMatrix :> {{0.9350146191117992, 0.3546091680247656, 
       0.}, {-0.3546091680247656, 0.9350146191117992, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08034998488806841, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6660089563190854`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.216500101997912`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-2.0024250208275873`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9350146191117992, 0.3546091680247656, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.822712616640818, -1.146059333803818, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -1.338546865179533, 0.}, 
      RotationMatrix :> {{-0.9842792840960521, -0.1766190558783587, 0.}, {
       0.1766190558783587, -0.9842792840960521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013809689753066571`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.089845772407962, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.635109667202105`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9385468651795329, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9842792840960521, -0.1766190558783587, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.11164321715692, -2.5383145838870496`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.2312511425493917`, 0.}, 
      RotationMatrix :> {{0.9828861427390129, 0.1842140885264334, 
       0.}, {-0.1842140885264334, 0.9828861427390129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08938541161846728, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.666883590684739, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.530901943719563`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {1.8312511425493918`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9828861427390129, 0.1842140885264334, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.45538678793015, -0.7653751126454883, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.3727948734462406, 0.}, 
      RotationMatrix :> {{0.7510269268530875, 0.6602715768088212, 
       0.}, {-0.6602715768088212, 0.7510269268530875, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013134417381011775`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7237906735174837`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.80110313134888, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.7727948734462406, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7510269268530875, 0.6602715768088212, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.367052651840087, 0.14943348693084343`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.4050411595395943, 0.}, 
      RotationMatrix :> {{0.9833447978616546, 0.1817498514949073, 
       0.}, {-0.1817498514949073, 0.9833447978616546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020847260454136658`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4063707370672207`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.87972972768948, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.8050411595395943, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9833447978616546, 0.1817498514949073, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.295863451371103, 3.872524143458744, 0.}, 
      Optica`Optica`RayEnd :> {7.453531826332829, 4.6, 0.}, 
      RotationMatrix :> {{0.21181571721944217`, 0.9773096243969014, 
       0.}, {-0.9773096243969014, 0.21181571721944217`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17658619051611493`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7443657960394909, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.202089699293495`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.2035318263328287`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.21181571721944217`, 0.9773096243969014, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.825246023854241, 3.9303156676656474`, 0.}, 
      Optica`Optica`RayEnd :> {6.28487639933107, 4.6, 0.}, 
      RotationMatrix :> {{0.56587856022159, 0.8244886021538074, 
       0.}, {-0.8244886021538074, 0.56587856022159, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00942103932641719, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8122420741595927, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.673082360293456`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.0348763993310697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.56587856022159, 0.8244886021538074, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.43413732121714, -0.8473346537407715, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.949015893495694, 0.}, 
      RotationMatrix :> {{0.7667494230058054, -0.6419465104821925, 0.}, {
       0.6419465104821925, 0.7667494230058054, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009086340261723959, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7161573772360004`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.628107972991387`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {1.5490158934956941`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7667494230058054, -0.6419465104821925, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.942088537623861, 3.6182506337634655`, 0.}, 
      Optica`Optica`RayEnd :> {7.184896479020065, 4.6, 0.}, 
      RotationMatrix :> {{0.24008784749924422`, 0.9707511655842491, 
       0.}, {-0.9707511655842491, 0.24008784749924422`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7198225580499793`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0113295775912512`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.478426209328894`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.9348964790200647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.24008784749924422`, 0.9707511655842491, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.469682112473555, 1.3151141464055818`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.8473077115705722, 0.}, 
      RotationMatrix :> {{0.9392654024444569, -0.34319164292105236`, 0.}, {
       0.34319164292105236`, 0.9392654024444569, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17255297843795475`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3631055548244315`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.56677081649764, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-1.2473077115705722`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9392654024444569, -0.34319164292105236`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.114318319292503, -4.651750633423436, 0.}, 
      Optica`Optica`RayEnd :> {7.424573157315425, -5.4, 0.}, 
      RotationMatrix :> {{0.3830203958736288, -0.923739885652237, 0.}, {
       0.923739885652237, 0.3830203958736288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017394438873931734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8100217152020427, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.106025262609908`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-2.1745731573154248`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.3830203958736288, -0.923739885652237, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8170903467914052`, 1.5473035894966969`, 0.},
       Optica`Optica`RayEnd :> {0.7499999999999998, 0.8961459321822772, 0.}, 
      RotationMatrix :> {{-0.853620897039725, -0.5208947726144848, 0.}, {
       0.5208947726144848, -0.853620897039725, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008453759448249396, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2500752388934857`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.00987785894462, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.2961459321822772`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.853620897039725, -0.5208947726144848, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.779063316539821, -0.9682283827490923, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -0.9106411150436824, 0.}, 
      RotationMatrix :> {{-0.998437859165306, 0.05587344078720141, 
       0.}, {-0.05587344078720141, -0.998437859165306, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01299763426657872, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0306733735038034`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.948103974035543`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.5106411150436824, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.998437859165306, 0.05587344078720141, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.397117182488653, -0.1252058009954891, 0.}, 
      Optica`Optica`RayEnd :> {9.582253220006294, 4.6, 0.}, 
      RotationMatrix :> {{0.2432763892390465, 0.9699570085518285, 
       0.}, {-0.9699570085518285, 0.2432763892390465, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02090861580665654, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 4.871562099489694, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.17934956702325, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {4.332253220006295, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2432763892390465, 0.9699570085518285, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8258596958523285`, 1.0332433360189008`, 0.},
       Optica`Optica`RayEnd :> {0.75, 1.6060528093408535`, 0.}, 
      RotationMatrix :> {{-0.88268738076641, 0.46996062370770425`, 
       0.}, {-0.46996062370770425`, -0.88268738076641, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10706041730862778`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.218845674352105, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.105935181631743`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.0060528093408534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.88268738076641, 0.46996062370770425`, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.996997111901896, 3.6103894700818837`, 0.}, 
      Optica`Optica`RayEnd :> {7.002175056042999, 4.6, 0.}, 
      RotationMatrix :> {{0.005232233396563521, 0.999986311773158, 
       0.}, {-0.999986311773158, 0.005232233396563521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015718216196931555`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9896240761169579, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.888435179989987`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.7521750560429985`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.005232233396563521, 0.999986311773158, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.576370351743306, 3.840641917987641, 0.}, 
      Optica`Optica`RayEnd :> {6.703907454306172, 4.6, 0.}, 
      RotationMatrix :> {{0.1656339403839987, 0.9861873036055926, 
       0.}, {-0.9861873036055926, 0.1656339403839987, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07710030357132663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.769993772213528, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.104241775163672`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.453907454306172, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1656339403839987, 0.9861873036055926, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.5651883069599, 3.6848540105536114`, 0.}, 
      Optica`Optica`RayEnd :> {4.214078151596347, 4.6, 0.}, 
      RotationMatrix :> {{-0.3582065771888677, 0.9336423555401903, 
       0.}, {-0.9336423555401903, -0.3582065771888677, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.41562285305397206`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9801890242189144, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.033110112721673`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.0359218484036534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.3582065771888677, 0.9336423555401903, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.1726285273595956`, 3.9255726373682482`, 0.},
       Optica`Optica`RayEnd :> {5.063450928584296, 4.6, 0.}, 
      RotationMatrix :> {{-0.15980160351837713`, 0.9871491516042318, 
       0.}, {-0.9871491516042318, -0.15980160351837713`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015482629958930077`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.6832071541931921, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.069448958282116`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-0.18654907141570376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.15980160351837713`, 0.9871491516042318, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.557058154927904, 3.6857111952687807`, 0.}, 
      Optica`Optica`RayEnd :> {4.299288985045942, 4.6, 0.}, 
      RotationMatrix :> {{-0.27135566847152126`, 0.962479143248503, 
       0.}, {-0.962479143248503, -0.27135566847152126`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014867180537842278`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9499310308640709, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.238980201547975`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-0.9507110149540575, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.27135566847152126`, 0.962479143248503, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.000414990405947, -4.159206389957394, 0.}, 
      Optica`Optica`RayEnd :> {5.598862526758939, -5.4, 0.}, 
      RotationMatrix :> {{0.43442155136600263`, -0.9007096733735876, 0.}, {
       0.9007096733735876, 0.43442155136600263`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02287202886569785, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3775733143791409`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.028446222305977`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.34886252675893925`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.43442155136600263`, -0.9007096733735876, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.021738605429321, 3.6895005923389186`, 0.}, 
      Optica`Optica`RayEnd :> {4.2565580051618515`, 4.6, 0.}, 
      RotationMatrix :> {{0.24973025720164188`, 0.9683154437671654, 
       0.}, {-0.9683154437671654, 0.24973025720164188`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00842876023869091, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9402921470702206, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.071058417516316`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-0.9934419948381489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.24973025720164188`, 0.9683154437671654, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.11741073100309, 3.1862318942371473`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 4.48138308290737, 0.}, 
      RotationMatrix :> {{-0.726029702546548, 0.6876633413380207, 
       0.}, {-0.6876633413380207, -0.726029702546548, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3528603025861492, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.883408800228006, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.49883832773273, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.88138308290737, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.726029702546548, 0.6876633413380207, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.28456357642351, 1.882574819793523, 0.}, 
      Optica`Optica`RayEnd :> {9.095478664054873, 4.6, 0.}, 
      RotationMatrix :> {{0.28595244117731566`, 0.9582438110338791, 
       0.}, {-0.9582438110338791, 0.28595244117731566`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018253914323597284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.8358390097761865`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.844835979181813`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {3.8454786640548724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.28595244117731566`, 0.9582438110338791, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.893635248830319, 3.7624543145467406`, 0.}, 
      Optica`Optica`RayEnd :> {6.92910395054671, 4.6, 0.}, 
      RotationMatrix :> {{0.042310456043945954`, 0.9991045117050336, 
       0.}, {-0.9991045117050336, 0.042310456043945954`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008202692387136062, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8382963700403432, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.070291250097718`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.6791039505467102`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.042310456043945954`, 0.9991045117050336, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.057522303906609, 3.7785231599775653`, 0.}, 
      Optica`Optica`RayEnd :> {2.151173025599504, 4.6, 0.}, 
      RotationMatrix :> {{-0.7409471642748673, 0.6715633251995166, 
       0.}, {-0.6715633251995166, -0.7409471642748673, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009085943876305364, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.22323064586408, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.741607696273213`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.098826974400496, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.7409471642748673, 0.6715633251995166, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.393442965850957, -2.303851857405552, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -4.986211477490428, 0.}, 
      RotationMatrix :> {{0.45130148886885263`, -0.8923715404161858, 0.}, {
       0.8923715404161858, 0.45130148886885263`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27038197838035677`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.0058775953722936`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.797888374835335`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {4.586211477490427, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.45130148886885263`, -0.8923715404161858, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.202642609176679, 0.8816321711879552, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.4042047935943578, 0.}, 
      RotationMatrix :> {{-0.9500064324375548, -0.31223032896768516`, 0.}, {
       0.31223032896768516`, -0.9500064324375548, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26727178874055074`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5290871299149464`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.57403365939973, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.8042047935943578, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9500064324375548, -0.31223032896768516`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.377435097169095, 3.658150991890274, 0.}, 
      Optica`Optica`RayEnd :> {7.039248119545805, 4.6, 0.}, 
      RotationMatrix :> {{0.5749299186667751, 0.8182026574277393, 
       0.}, {-0.8182026574277393, 0.5749299186667751, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.191341619086145, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1511194684587125`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.203157797533336`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.7892481195458043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5749299186667751, 0.8182026574277393, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.345897813530606, 3.806407466702233, 0.}, 
      Optica`Optica`RayEnd :> {5.975765862474676, 4.6, 0.}, 
      RotationMatrix :> {{-0.42268736976126314`, 0.906275558229562, 
       0.}, {-0.906275558229562, -0.42268736976126314`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.018028563397250823`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8756636169776822, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.058376013270625`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.7257658624746754, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.42268736976126314`, 0.906275558229562, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8591223699710941`, -0.379751604104828, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.11183972014175736`, 0.}, 
      RotationMatrix :> {{-0.9142246602818619, 0.4052076881458607, 
       0.}, {-0.4052076881458607, -0.9142246602818619, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00825072265202851, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2131836059083587`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.83401049062392, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.5118397201417574, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9142246602818619, 0.4052076881458607, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.370476193877607, 3.3020565011722733`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 3.3939851403745727`, 0.}, 
      RotationMatrix :> {{0.9977870591667533, 0.06649048472797858, 
       0.}, {-0.06649048472797858, 0.9977870591667533, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07691633247592052, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.382583381342333, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.50647594737257, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.7939851403745726`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9977870591667533, 0.06649048472797858, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.6634007260393116`, 3.889464890278438, 0.}, 
      Optica`Optica`RayEnd :> {3.997703916991005, 4.6, 0.}, 
      RotationMatrix :> {{-0.9198104942403901, 0.39236291196448214`, 
       0.}, {-0.39236291196448214`, -0.9198104942403901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07364704065544961, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8109130298887195`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.078764752899158`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.252296083008995, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9198104942403901, 0.39236291196448214`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1664863383255795`, 1.7124017880902116`, 0.},
       Optica`Optica`RayEnd :> {0.75, 2.59384875361945, 0.}, 
      RotationMatrix :> {{-0.8490357155232069, 0.5283354557153952, 
       0.}, {-0.5283354557153952, -0.8490357155232069, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07771978843336844, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6683471760109496`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.62910010262892, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.99384875361945, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8490357155232069, 0.5283354557153952, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1688661246212564`, 3.9136726985842807`, 0.},
       Optica`Optica`RayEnd :> {2.8078833745951814`, 4.6, 0.}, 
      RotationMatrix :> {{-0.46550189324159574`, 0.8850468842883354, 
       0.}, {-0.8850468842883354, -0.46550189324159574`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00869048902662272, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7754699932846989, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.696100387395152`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.4421166254048186`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.46550189324159574`, 0.8850468842883354, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.057599674808473, -3.732319033051137, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -4.456095867831128, 0.}, 
      RotationMatrix :> {{-0.874913899547312, -0.4842785029081051, 0.}, {
       0.4842785029081051, -0.874913899547312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011845081965868559`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4945466925202993`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.43873973762424, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-4.056095867831128, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.874913899547312, -0.4842785029081051, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.939751687198152, 2.8785860260273344`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 2.251784413451983, 0.}, 
      RotationMatrix :> {{-0.8847291983448784, -0.46610540180953586`, 0.}, {
       0.46610540180953586`, -0.8847291983448784, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01005472558477097, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3447636739285866`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.048484726104583`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.651784413451983, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8847291983448784, -0.46610540180953586`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.3669117145038703`, 3.764223584864702, 0.}, 
      Optica`Optica`RayEnd :> {2.54043304516074, 4.6, 0.}, 
      RotationMatrix :> {{0.20328193609478504`, 0.979120245147426, 
       0.}, {-0.979120245147426, 0.20328193609478504`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009108008077500871, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8535993605253817, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.018090147021052`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.70956695483926, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.20328193609478504`, 0.979120245147426, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7735416284485892`, -1.0338422441077806`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, -1.3049203825930151`,
        0.}, 
      RotationMatrix :> {{-0.9666723603923588, -0.2560166940913534, 0.}, {
       0.2560166940913534, -0.9666723603923588, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0188568828218138, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0588299307876645`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.051504725746312`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9049203825930149, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9666723603923588, -0.2560166940913534, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.957214733053927, 3.6183783225821378`, 0.}, 
      Optica`Optica`RayEnd :> {7.189188771260336, 4.6, 0.}, 
      RotationMatrix :> {{0.22998260812079407`, 0.9731947389715775, 
       0.}, {-0.9731947389715775, 0.22998260812079407`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008049888409401629, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0086590464465408`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.106460896376255`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.9391887712603362`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.22998260812079407`, 0.9731947389715775, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.988617948777935, -4.710701163914752, 0.}, 
      Optica`Optica`RayEnd :> {6.246975915126126, -5.4, 0.}, 
      RotationMatrix :> {{0.35096968455132455`, -0.9363868220591011, 0.}, {
       0.9363868220591011, 0.35096968455132455`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015479012753830191`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7361261605214493, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.18131934692715, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.9969759151261259, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35096968455132455`, -0.9363868220591011, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.249413289851313, 3.865881414191816, 0.}, 
      Optica`Optica`RayEnd :> {7.096338363960726, 4.6, 0.}, 
      RotationMatrix :> {{-0.20412493642972812`, 0.978944845396082, 
       0.}, {-0.978944845396082, -0.20412493642972812`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034133503291260255`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.7499080150027845, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.67727130724369, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.8463383639607263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.20412493642972812`, 0.978944845396082, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1854391618308204`, 3.917440606065164, 0.}, 
      Optica`Optica`RayEnd :> {2.7269243355216988`, 4.6, 0.}, 
      RotationMatrix :> {{-0.5576227362433976, 0.8300945030684311, 
       0.}, {-0.8300945030684311, -0.5576227362433976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2859832372995041`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8222670929776859, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.31408787671773, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.5230756644783012`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5576227362433976, 0.8300945030684311, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.6447050878359932`, 3.7340071536615724`, 0.},
       Optica`Optica`RayEnd :> {3.1539235737992732`, 4.6, 0.}, 
      RotationMatrix :> {{-0.4930522926730219, 0.8699996762584892, 
       0.}, {-0.8699996762584892, -0.4930522926730219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.030368714105124362`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9953944466539414, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.10397316311101, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.0960764262007268`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.4930522926730219, 0.8699996762584892, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.666413661944249, 3.8758765752816933`, 0.}, 
      Optica`Optica`RayEnd :> {4.004056392175901, 4.6, 0.}, 
      RotationMatrix :> {{0.4225960881950098, 0.9063181264005895, 
       0.}, {-0.9063181264005895, 0.4225960881950098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09322966793809642, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7989726825768528, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.05317865407839, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.2459436078240995`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4225960881950098, 0.9063181264005895, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7945631340613906`, 3.9404978394038013`, 0.},
       Optica`Optica`RayEnd :> {7.3663440076069335`, 4.6, 0.}, 
      RotationMatrix :> {{0.9833774387332423, 0.18157316153674163`, 
       0.}, {-0.18157316153674163`, 0.9833774387332423, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019165915001405957`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.632156619483364, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.062055784363793`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.1163440076069335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9833774387332423, 0.18157316153674163`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.0875717529220807`, 3.857537429702332, 0.}, 
      Optica`Optica`RayEnd :> {1.3952982896641766`, 4.6, 0.}, 
      RotationMatrix :> {{-0.9157409550606517, 0.40176921637253993`, 
       0.}, {-0.40176921637253993`, -0.9157409550606517, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02295444258858553, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8479827225220258`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.939900331725898`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.8547017103358234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9157409550606517, 0.40176921637253993`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.866738553866757, 1.6632737373389903`, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, 1.6226898414554505`, 0.}, 
      RotationMatrix :> {{-0.9993403029601367, -0.036317473474098895`, 0.}, {
       0.036317473474098895`, -0.9993403029601367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1455889529665632, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1174757493106962`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.67625625329184, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.0226898414554504`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9993403029601367, -0.036317473474098895`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9255244467780555`, 0.4850253643387584, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.6350326116805584, 0.}, 
      RotationMatrix :> {{-0.9919561067366975, 0.1265823143562024, 
       0.}, {-0.1265823143562024, -0.9919561067366975, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012103611224886438`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1850569181384991`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.224720928320146`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0350326116805584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9919561067366975, 0.1265823143562024, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.1545226228344525`, 3.848702210669975, 0.}, 
      Optica`Optica`RayEnd :> {3.5800354857925454`, 4.6, 0.}, 
      RotationMatrix :> {{-0.6074269547623992, 0.7943755375312592, 
       0.}, {-0.7943755375312592, -0.6074269547623992, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1755309911382409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9457715574486204, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.606438037945566`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.6699645142074548`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6074269547623992, 0.7943755375312592, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9002821581533915`, 2.948691825759078, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 3.196372152840666, 0.}, 
      RotationMatrix :> {{-0.9775945064147752, 0.21049698579232112`, 
       0.}, {-0.21049698579232112`, -0.9775945064147752, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19937205813226602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1766454809284173`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.651519739848446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.596372152840666, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9775945064147752, 0.21049698579232112`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.145218465973057, 3.002605801682305, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.9934296759182932`, 0.}, 
      RotationMatrix :> {{0.9999836526924761, -0.005717897149549355, 0.}, {
       0.005717897149549355, 0.9999836526924761, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011376249882806836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6048077683130477`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.272213256215295`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.393429675918293, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9999836526924761, -0.005717897149549355, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9254498630377734`, 0.4847035724536128, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.8292542812134315, 0.}, 
      RotationMatrix :> {{-0.9596236296707696, 0.2812872008774978, 
       0.}, {-0.2812872008774978, -0.9596236296707696, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010369009586280703`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.2249071684917245`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.90447743104367, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.2292542812134315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9596236296707696, 0.2812872008774978, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.464967287231055, -2.8252742464879286`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -4.327625127895923, 0.}, 
      RotationMatrix :> {{0.6500047063355107, -0.7599301821494437, 0.}, {
       0.7599301821494437, 0.6500047063355107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011308330064175354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.9769590900556566`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.009363846955484`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {3.927625127895922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6500047063355107, -0.7599301821494437, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.705414945740973, 3.888998368063742, 0.}, 
      Optica`Optica`RayEnd :> {7.5745167285675254`, 4.6, 0.}, 
      RotationMatrix :> {{-0.18106106478520534`, 0.9834718556312874, 
       0.}, {-0.9834718556312874, -0.18106106478520534`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035451583665520314`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7229506648971342, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.896027825961546`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.3245167285675254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18106106478520534`, 0.9834718556312874, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.88750394744357, 3.8598451511704264`, 0.}, 
      Optica`Optica`RayEnd :> {8.360700078604824, 4.6, 0.}, 
      RotationMatrix :> {{0.5386474603928759, 0.8425312536709271, 
       0.}, {-0.8425312536709271, 0.5386474603928759, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008784173128675054, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8784894870127392, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.08040832190089, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {3.110700078604823, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5386474603928759, 0.8425312536709271, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.928757673475447, 3.59616286765204, 0.}, 
      Optica`Optica`RayEnd :> {6.764964971778461, 4.6, 0.}, 
      RotationMatrix :> {{0.6400381925960525, 0.7683430952500172, 
       0.}, {-0.7683430952500172, 0.6400381925960525, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03510472341432141, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3064959372366225`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.98589924179747, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.5149649717784612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6400381925960525, 0.7683430952500172, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8999957360474449`, 1.691340859919253, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 4.09124363753976, 0.}, 
      RotationMatrix :> {{-0.4321331140344915, 0.9018098312587041, 
       0.}, {-0.9018098312587041, -0.4321331140344915, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00860646001683766, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.6612071574678153`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.17909889373412, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.49124363753976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4321331140344915, 0.9018098312587041, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.315560330733823, 3.842826281431774, 0.}, 
      Optica`Optica`RayEnd :> {5.930886695834191, 4.6, 0.}, 
      RotationMatrix :> {{0.905461201115119, 0.4244290438638308, 
       0.}, {-0.4244290438638308, 0.905461201115119, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03164313229320953, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7839818681474326`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.818543304451072`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.6808866958341915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.905461201115119, 0.4244290438638308, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.089830620806531, 3.644610377272796, 0.}, 
      Optica`Optica`RayEnd :> {0.9077638619197765, 4.6, 0.}, 
      RotationMatrix :> {{-0.7777342163645173, 0.6285932617327911, 
       0.}, {-0.6285932617327911, -0.7777342163645173, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020565684496185017`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.5198852435890893`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.519703174342297`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-4.3422361380802235`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7777342163645173, 0.6285932617327911, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8184609758976726`, -0.1543466785264378, 0.},
       Optica`Optica`RayEnd :> {0.75, -0.47408743664388747`, 0.}, 
      RotationMatrix :> {{-0.9580228770546458, -0.2866917631184025, 0.}, {
       0.2866917631184025, -0.9580228770546458, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07950243014446738, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1152770998356096`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.0946524637117, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.07408743664388745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9580228770546458, -0.2866917631184025, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8925223693054563`, -3.0614739192830824`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -3.735555503708284, 0.}, 
      RotationMatrix :> {{-0.861271439479639, -0.5081451638426461, 0.}, {
       0.5081451638426461, -0.861271439479639, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1523541855084696, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3265531828104533`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.739503973505748`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.3355555037082842`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.861271439479639, -0.5081451638426461, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.735202566971461, 3.941086772914109, 0.}, 
      Optica`Optica`RayEnd :> {2.3976433451061703`, 4.6, 0.}, 
      RotationMatrix :> {{-0.45594764575522445`, 0.8900065979138962, 
       0.}, {-0.8900065979138962, -0.45594764575522445`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04044297839734489, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7403464520716251, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.337635616201954`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.8523566548938297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.45594764575522445`, 0.8900065979138962, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.5490640983277992`, 3.6362395798778353`, 0.},
       Optica`Optica`RayEnd :> {2.9906241608010675`, 4.6, 0.}, 
      RotationMatrix :> {{-0.5013545370502013, 0.8652419477690487, 
       0.}, {-0.8652419477690487, -0.5013545370502013, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.046418863892723754`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1138623394382765`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.800262572711343`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.2593758391989325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5013545370502013, 0.8652419477690487, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.35458679363506, 0.12765032623837, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.0717124374373639`, 0.}, 
      RotationMatrix :> {{0.7583712484287423, -0.6518228667027796, 0.}, {
       0.6518228667027796, 0.7583712484287423, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0314479105128328, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8400133302206207`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.269190778478272`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.671712437437364, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7583712484287423, -0.6518228667027796, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.133292155381548, 3.839095338540685, 0.}, 
      Optica`Optica`RayEnd :> {2.101890100273397, 4.6, 0.}, 
      RotationMatrix :> {{-0.041234269459624814`, 0.9991495058409087, 
       0.}, {-0.9991495058409087, -0.041234269459624814`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008569221334538671, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.761552357291033, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.897457624794082`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.148109899726603, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.041234269459624814`, 0.9991495058409087, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.816528145569681, -4.383112257242901, 0.}, 
      Optica`Optica`RayEnd :> {6.344021416112138, -5.4, 0.}, 
      RotationMatrix :> {{-0.42139028400520867`, -0.9068793902973035, 0.}, {
       0.9068793902973035, -0.42139028400520867`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033810148026422675`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1213042810728457`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.323264180674045`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-1.0940214161121378`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.42139028400520867`, -0.9068793902973035, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.750818439690522, -4.419688470805187, 0.}, 
      Optica`Optica`RayEnd :> {6.401005318061502, -5.4, 0.}, 
      RotationMatrix :> {{-0.3360823507281261, -0.9418326037725897, 0.}, {
       0.9418326037725897, -0.3360823507281261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11461909881547977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0408553762824657`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.08542796797454, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-1.1510053180615025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3360823507281261, -0.9418326037725897, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.166895214856064, -3.0588244373516718`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -3.742805141543442, 0.}, 
      RotationMatrix :> {{0.9179848252998901, -0.3966155071591744, 0.}, {
       0.3966155071591744, 0.9179848252998901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017805985599295766`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7245435235018853`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.08419899231693, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {3.342805141543442, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9179848252998901, -0.3966155071591744, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.624661889022492, 3.837040565238847, 0.}, 
      Optica`Optica`RayEnd :> {5.271286518202127, 4.6, 0.}, 
      RotationMatrix :> {{-0.42027381153405563`, 0.9073973348752109, 
       0.}, {-0.9073973348752109, -0.42027381153405563`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1403741893515447`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8408217717171032, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.755344533989263`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.02128651820212696, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.42027381153405563`, 0.9073973348752109, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.882779322650426, 3.811935048904515, 0.}, 
      Optica`Optica`RayEnd :> {7.828399084772261, 4.6, 0.}, 
      RotationMatrix :> {{0.7682019089296646, 0.6402076437506958, 
       0.}, {-0.6402076437506958, 0.7682019089296646, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008186074095058088, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.2309521118469575`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.579345522648342`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.5783990847722613`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7682019089296646, 0.6402076437506958, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.475677707174433, 3.668722634526091, 0.}, 
      Optica`Optica`RayEnd :> {6.636523485148712, 4.6, 0.}, 
      RotationMatrix :> {{0.17019536665964527`, 0.9854103394868493, 
       0.}, {-0.9854103394868493, 0.17019536665964527`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02740152175722202, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9450655510260518, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.42425284827519, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.3865234851487116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17019536665964527`, 0.9854103394868493, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8654612149900247`, 0.8885482619526972, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, 0.6160840059493612, 0.}, 
      RotationMatrix :> {{-0.9714399798064066, -0.23728540965202038`, 0.}, {
       0.23728540965202038`, -0.9714399798064066, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2370612963924621, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1482554127660243`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.404576609301706`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0160840059493612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9714399798064066, -0.23728540965202038`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.905450895359237, 2.9302119632853034`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 2.8526439560842514`, 0.}, 
      RotationMatrix :> {{-0.9977542191683024, -0.0669814760351756, 0.}, {
       0.0669814760351756, -0.9977542191683024, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2867185637790726, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.158051625501905, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.958914969526308`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.2526439560842513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9977542191683024, -0.0669814760351756, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.001820259253169, 0.8322686305099309, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -0.06447361069971824, 0.}, 
      RotationMatrix :> {{-0.8129387529261658, -0.5823491942046884, 0.}, {
       0.5823491942046884, -0.8129387529261658, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07606481930067648, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5398703220227266`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.893556250792194`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.33552638930028167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8129387529261658, -0.5823491942046884, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.553007083039228, 3.824253879775438, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 4.365551956770799, 0.}, 
      RotationMatrix :> {{-0.9577683761967657, 0.2875408450245114, 
       0.}, {-0.2875408450245114, -0.9577683761967657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028024213040754323`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.882508472663138, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.597598099893222`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.7655519567708, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9577683761967657, 0.2875408450245114, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8717760217040529`, -3.596276373248007, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, -4.264103608630234, 0.}, 
      RotationMatrix :> {{-0.8592580674914431, -0.5115423476613354, 0.}, {
       0.5115423476613354, -0.8592580674914431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0361092550172754, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.305517008387267, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.387632114329293`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.8641036086302334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8592580674914431, -0.5115423476613354, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.277153594740588, -1.8841482342927005`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.7016737323025786`, 0.}, 
      RotationMatrix :> {{0.874339297927636, -0.48531514719757984`, 0.}, {
       0.48531514719757984`, 0.874339297927636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00914123005986919, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6845249993341957`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.735810650059516`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.301673732302579, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.874339297927636, -0.48531514719757984`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.78884187988963, 3.9356753447342863`, 0.}, 
      Optica`Optica`RayEnd :> {5.337352751897541, 4.6, 0.}, 
      RotationMatrix :> {{-0.5620957764477629, 0.8270721480618153, 
       0.}, {-0.8270721480618153, -0.5620957764477629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15887861318462476`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8032245515974761, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.772553749826354`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.08735275189754038, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5620957764477629, 0.8270721480618153, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7936828751715794`, 0.0789026636679371, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.2982847768764263, 0.}, 
      RotationMatrix :> {{-0.9786141180114314, 0.20570466214626254`, 
       0.}, {-0.20570466214626254`, -0.9786141180114314, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01687145370879416, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0664907198481555`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.644877670287507`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.6982847768764263, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9786141180114314, 0.20570466214626254`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.7818741487236447`, -1.0752584328605608`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -1.0459322082683495`, 0.}, 
      RotationMatrix :> {{-0.9995963863369215, 0.02840887928391188, 
       0.}, {-0.02840887928391188, -0.9995963863369215, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013463621197105787`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0322907953929354`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.294526223590225`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.6459322082683495, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9995963863369215, 0.02840887928391188, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.07115545095173, 3.6707940629447973`, 0.}, 
      Optica`Optica`RayEnd :> {3.893366391537607, 4.6, 0.}, 
      RotationMatrix :> {{-0.1879254503639339, 0.9821832950653925, 
       0.}, {-0.9821832950653925, -0.1879254503639339, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008801486977194652, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9460616381113839, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.226805917181444`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.3566336084623927`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1879254503639339, 0.9821832950653925, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1227029962502155`, 3.8305644736481965`, 0.},
       Optica`Optica`RayEnd :> {2.085762264531462, 4.6, 0.}, 
      RotationMatrix :> {{-0.047954935991112, 0.9988495002321858, 
       0.}, {-0.9988495002321858, -0.047954935991112, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012187064280882806`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.7703217813824254, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.1318776952543, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.164237735468538, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.047954935991112, 0.9988495002321858, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.27378532912938, 3.089154647252922, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.462813743293564, 0.}, 
      RotationMatrix :> {{0.9205665322819643, -0.39058579037435337`, 0.}, {
       0.39058579037435337`, 0.9205665322819643, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012299228214542272`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.6035936774838813`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.578042704514182`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-2.862813743293564, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9205665322819643, -0.39058579037435337`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.495946585525004, 3.6887914096803205`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 4.586149244763882, 0.}, 
      RotationMatrix :> {{0.8132407751058668, 0.5819273508825722, 
       0.}, {-0.5819273508825722, 0.8132407751058668, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.13071026853977363`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.542044438575702, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.581523267673727`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-4.986149244763882, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8132407751058668, 0.5819273508825722, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8756163776684474`, -1.1869631499097286`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -3.3256616220227384`, 0.}, 
      RotationMatrix :> {{-0.46574176798432343`, -0.884920677549596, 0.}, {
       0.884920677549596, -0.46574176798432343`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01188857371649193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.4168250628239436`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.339966146159842`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.9256616220227385`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46574176798432343`, -0.884920677549596, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.300156147257562, 1.4583259666974322`, 0.}, 
      Optica`Optica`RayEnd :> {9.267337733411882, 4.6, 0.}, 
      RotationMatrix :> {{0.29422831273390193`, 0.9557351620536731, 
       0.}, {-0.9557351620536731, 0.29422831273390193`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00923661201086145, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.2871805475397307`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.961363125582565`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {4.017337733411881, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.29422831273390193`, 0.9557351620536731, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.2909883109441656`, -4.5946589053852165`, 
       0.}, Optica`Optica`RayEnd :> {2.520638746641396, -5.4, 0.}, 
      RotationMatrix :> {{-0.69123356373659, -0.7226314139061585, 0.}, {
       0.7226314139061585, -0.69123356373659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08473011028721002, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1144562485341472`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.350527307460425`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {2.729361253358604, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.69123356373659, -0.7226314139061585, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {7.592086742145651, -4.625886100022921, 0.}, 
      Optica`Optica`RayEnd :> {7.575230077813286, -5.4, 0.}, 
      RotationMatrix :> {{-0.021770270881506345`, -0.9997629995682702, 0.}, {
       0.9997629995682702, -0.021770270881506345`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0527029012314148, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7742974087972513, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.956159359973356`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-2.3252300778132864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.021770270881506345`, -0.9997629995682702, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.074781152017092, -4.648738151644846, 0.}, 
      Optica`Optica`RayEnd :> {9.700038947201104, -5.4, 0.}, 
      RotationMatrix :> {{0.9077163675690939, -0.41958431339501784`, 0.}, {
       0.41958431339501784`, 0.9077163675690939, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10986009869390606`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7904907890297566`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.732946503637507`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-4.450038947201104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9077163675690939, -0.41958431339501784`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8240741026616254`, 1.588190619940066, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.9444793858073828`, 0.}, 
      RotationMatrix :> {{-0.9491424990400867, 0.3148468143652372, 
       0.}, {-0.3148468143652372, -0.9491424990400867, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029589792549295744`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1316257608819407`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.387536898541466`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.3444793858073827`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9491424990400867, 0.3148468143652372, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.417195633114394, -0.1544898434743955, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.2504338269290702, 0.}, 
      RotationMatrix :> {{0.9974189954409365, -0.07180074883726505, 0.}, {
       0.07180074883726505, 0.9974189954409365, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013431425908291657`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3362532425968106`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.59892809021053, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.14956617307092987`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9974189954409365, -0.07180074883726505, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2076719681319608`, 1.8799915918934478`, 0.},
       Optica`Optica`RayEnd :> {0.75, 1.841438773858871, 0.}, 
      RotationMatrix :> {{-0.9996504294114436, -0.02643896702814083, 0.}, {
       0.02643896702814083, -0.9996504294114436, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009784707142137649, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4581817055689978`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.934830796409155`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.241438773858871, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9996504294114436, -0.02643896702814083, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.470391685845325, -4.324888481466, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -4.2137530955699525`, 0.}, 
      RotationMatrix :> {{0.9962496471841168, 0.0865253748071732, 
       0.}, {-0.0865253748071732, 0.9962496471841168, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02631759933666217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2844253624294537`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.568990074960194`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {3.813753095569952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9962496471841168, 0.0865253748071732, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.636771330728353, 3.7921973243101887`, 0.}, 
      Optica`Optica`RayEnd :> {2.8101711478294145`, 4.6, 0.}, 
      RotationMatrix :> {{-0.7151920201403896, 0.6989280179871947, 
       0.}, {-0.6989280179871947, -0.7151920201403896, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008018959664387442, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1557737777005397`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.37084228560462, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.4398288521705855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.7151920201403896, 0.6989280179871947, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8423080769447733`, -0.45235163317290616`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.0574530586425595`, 0.}, 
      RotationMatrix :> {{-0.5626055214573742, -0.8267254848047656, 0.}, {
       0.8267254848047656, -0.5626055214573742, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031108199664232762`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.9415168093538366`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.78552509562689, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.6574530586425593`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5626055214573742, -0.8267254848047656, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.282380208947151, -1.8815251178425596`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.5469065420650225`, 0.}, 
      RotationMatrix :> {{0.9107677917053949, -0.412918914064345, 0.}, {
       0.412918914064345, 0.9107677917053949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00802838107645152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6114094112888635`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.03269509387294, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.1469065420650226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9107677917053949, -0.412918914064345, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.900105784987952, 1.382113841150748, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.7357057001386909`, 0.}, 
      RotationMatrix :> {{-0.9558459920649098, 0.2938680647049751, 
       0.}, {-0.2938680647049751, -0.9558459920649098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008450312084613576, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2032333603276224`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.208413761241946`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.1357057001386903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9558459920649098, 0.2938680647049751, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8238439393769457`, 1.0202765181166027`, 0.},
       Optica`Optica`RayEnd :> {0.75, 0.6037719390541022, 0.}, 
      RotationMatrix :> {{-0.9323273240591677, -0.36161548751770894`, 0.}, {
       0.36161548751770894`, -0.9323273240591677, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009622081966793348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1517885528675078`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.387762931256436`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0037719390541022`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9323273240591677, -0.36161548751770894`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.815103198866747, -4.5442523639535395`, 0.}, 
      Optica`Optica`RayEnd :> {4.192520843571415, -5.4, 0.}, 
      RotationMatrix :> {{-0.5883079304897461, -0.808636988346979, 0.}, {
       0.808636988346979, -0.5883079304897461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012778700267654632`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0582593282008852`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.31677105284362, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.057479156428585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5883079304897461, -0.808636988346979, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.515057093215638, -4.686380860885859, 0.}, 
      Optica`Optica`RayEnd :> {6.024217223762429, -5.4, 0.}, 
      RotationMatrix :> {{-0.5667065517676011, -0.8239197073645432, 0.}, {
       0.8239197073645432, -0.5667065517676011, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16363563205894352`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8661270421565483, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.864035874280876`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.774217223762429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5667065517676011, -0.8239197073645432, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.353958111122084, 0.12673605509693064`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.440694887693634, 0.}, 
      RotationMatrix :> {{0.4776979514650126, -0.8785241414816836, 0.}, {
       0.8785241414816836, 0.4776979514650126, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010658256200097168`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      2.922436415304919, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.22250459951704, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.040694887693634, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.4776979514650126, -0.8785241414816836, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.0375417428426617`, 2.1825871052305135`, 0.},
       Optica`Optica`RayEnd :> {0.75, 2.7947799446624715`, 0.}, 
      RotationMatrix :> {{-0.9031114742877898, 0.4294061771909371, 
       0.}, {-0.4294061771909371, -0.9031114742877898, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0165971042593572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4256731084698488`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.979616925226175`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.1947799446624714`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 132.56507968104114`}, 
      Optica`Optica`RayTilt :> {-0.9031114742877898, 0.4294061771909371, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9679775262061567`, -1.6446457138116022`, 
       0.}, Optica`Optica`RayEnd :> {0.7500000000000002, -3.293554580072368, 
       0.}, RotationMatrix :> {{-0.5941445892873589, -0.8043582578805016, 
       0.}, {0.8043582578805016, -0.5941445892873589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017715521554756614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.049968220138213, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.00669180860064, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.893554580072368, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.5941445892873589, -0.8043582578805016, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8478535170951083`, -2.5287092081334865`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -3.531199278342574, 0.}, 
      RotationMatrix :> {{-0.7384513046439465, -0.6743068075213625, 0.}, {
       0.6743068075213625, -0.7384513046439465, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011647648499061757`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.486697240821385, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.787329657634814`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.131199278342574, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7384513046439465, -0.6743068075213625, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.1147820855425192`, -2.2821698249394347`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.2762371811996505`, 0.}, 
      RotationMatrix :> {{-0.9999905521331975, 0.0043469120468401685`, 
       0.}, {-0.0043469120468401685`, -0.9999905521331975, 0.}, {0., 0., 1.}},
       Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0165525755601482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3647949799437027`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.348736844839202`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.8762371811996505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999905521331975, 0.0043469120468401685`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {6.302464808170437, -4.450050301458311, 0.}, 
      Optica`Optica`RayEnd :> {5.609114506107334, -5.4, 0.}, 
      RotationMatrix :> {{-0.5895488334184869, -0.8077327361292846, 0.}, {
       0.8077327361292846, -0.5895488334184869, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016782319412679363`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1760693309199262`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.27916672700675, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.35911450610733364`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5895488334184869, -0.8077327361292846, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.412962572471049, -4.416584131883879, 0.}, 
      Optica`Optica`RayEnd :> {8.506745675151512, -5.4, 0.}, 
      RotationMatrix :> {{0.09493393522580915, -0.9954835749235349, 0.}, {
       0.9954835749235349, 0.09493393522580915, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23627563433252427`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9878775430239106, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.81601618703696, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-3.256745675151512, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09493393522580915, -0.9954835749235349, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8575330775666872`, -1.973609833425109, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -2.286202570382883, 0.}, 
      RotationMatrix :> {{-0.9624016184658515, -0.2716304930863047, 0.}, {
       0.2716304930863047, -0.9624016184658515, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1292228619235062, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1508013456296833`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.33310433562166, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.886202570382883, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9624016184658515, -0.2716304930863047, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8331971455187728`, -1.49581634012526, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.1688199539809353, 0.}, 
      RotationMatrix :> {{-0.5454072201317828, 0.8381712022183297, 
       0.}, {-0.8381712022183297, -0.5454072201317828, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025052920747016295`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.9860337478793317`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.650314653762372`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.5688199539809353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5454072201317828, 0.8381712022183297, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.847484571749867, -1.5541627057341192`, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, -1.379969662677608, 0.}, 
      RotationMatrix :> {{-0.9876370411800853, 0.156758013795294, 
       0.}, {-0.156758013795294, -0.9876370411800853, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011069641631359073`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1112225706303287`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.186100718976732`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9799696626776078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9876370411800853, 0.156758013795294, 0.}], 
     
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.101985669129406, 3.8742308283456834`, 0.}, 
      Optica`Optica`RayEnd :> {2.975288809690501, 4.6, 0.}, 
      RotationMatrix :> {{-0.1719684341037451, 0.9851024604942906, 
       0.}, {-0.9851024604942906, -0.1719684341037451, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011175902980703164`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7367448572711411, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.727457629992404`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.274711190309499, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1719684341037451, 0.9851024604942906, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.301227485802736, 2.5779427149896432`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.11567783808227661`, 0.}, 
      RotationMatrix :> {{0.5071193092161076, -0.8618758647393353, 0.}, {
       0.8618758647393353, 0.5071193092161076, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013754071706224509`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.856867186612831, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      29.612708505272757`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.5156778380822766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5071193092161076, -0.8618758647393353, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.105089716554118, 2.2924074478347602`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.2544260083243568`, 0.}, 
      RotationMatrix :> {{-0.7938667260631909, -0.6080917868625663, 0.}, {
       0.6080917868625663, -0.7938667260631909, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.028756905040941163`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.7069486250847763`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.75926632509272, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.6544260083243567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7938667260631909, -0.6080917868625663, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8227355325169223`, 1.0030155268912893`, 0.},
       Optica`Optica`RayEnd :> {0.7500000000000002, 0.4707323179671955, 0.}, 
      RotationMatrix :> {{-0.8957873519719338, -0.44448286811429527`, 0.}, {
       0.44448286811429527`, -0.8957873519719338, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026472546064063754`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.197533689391198, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.35359274689295, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.8707323179671955, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8957873519719338, -0.44448286811429527`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9620053601186829`, 3.0868466436547135`, 0.},
       Optica`Optica`RayEnd :> {0.75, 3.629250892615372, 0.}, 
      RotationMatrix :> {{-0.9127645334982357, 0.4084861152937114, 
       0.}, {-0.4084861152937114, -0.9127645334982357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019074308332854527`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3278401117028338`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.0742222397906, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.029250892615372, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9127645334982357, 0.4084861152937114, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {4.30456992408814, -4.450885268302151, 0.}, 
      Optica`Optica`RayEnd :> {3.481404355630144, -5.4, 0.}, 
      RotationMatrix :> {{-0.6552029796613175, -0.7554528810210009, 0.}, {
       0.7554528810210009, -0.6552029796613175, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010654779228694138`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2563519916888963`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      27.369845952262946`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.768595644369856, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6552029796613175, -0.7554528810210009, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.1843017802244207`, -4.353766402763522, 0.}, 
      Optica`Optica`RayEnd :> {3.280360365742378, -5.4, 0.}, 
      RotationMatrix :> {{0.0914291534977151, -0.9958115835290785, 0.}, {
       0.9958115835290785, 0.0914291534977151, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021979322092558224`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.0506340903654763`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.42342499390053, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.969639634257622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.0914291534977151, -0.9958115835290785, 0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8429277720194244`, -1.5431834720036013`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, -1.3117594152727874`,
        0.}, RotationMatrix :> {{-0.9783083969292055, 0.20715376052055529`, 
       0.}, {-0.20715376052055529`, -0.9783083969292055, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010343302573710479`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1171607802304422`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.97739351767745, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9117594152727874, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534885*^-15}, 
      Optica`Optica`RayTilt :> {-0.9783083969292055, 0.20715376052055529`, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8126837753289176`, 2.5667455556332626`, 0.},
       Optica`Optica`RayEnd :> {0.75, 1.632450992619971, 0.}, 
      RotationMatrix :> {{-0.7510173691395673, -0.6602824480861822, 0.}, {
       0.6602824480861822, -0.7510173691395673, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009306337468812365, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.414992274474853, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.3790822815468, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.032450992619971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7510173691395673, -0.6602824480861822, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {5.3435873933583835`, -4.311607522435026, 0.}, 
      Optica`Optica`RayEnd :> {5.1284600887553955`, -5.4, 0.}, 
      RotationMatrix :> {{-0.19390456844249668`, -0.9810203964939402, 0.}, {
       0.9810203964939402, -0.19390456844249668`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04176588516850442, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1094493870410536`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.962460863064535`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {0.12153991124460461`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.19390456844249668`, -0.9810203964939402, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {8.2637206997027, -4.46240798472222, 0.}, 
      Optica`Optica`RayEnd :> {8.41186209041113, -5.4, 0.}, 
      RotationMatrix :> {{0.15606592078241882`, -0.9877466417914741, 0.}, {
       0.9877466417914741, 0.15606592078241882`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.056504966068771215`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9492231870080277, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 29.53781833404284, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-3.1618620904111303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.15606592078241882`, -0.9877466417914741, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.9247809079917395`, -0.31161928865510713`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, -0.2552318476916251, 
       0.}, RotationMatrix :> {{-0.9988500700112948, 0.04794306663564521, 
       0.}, {-0.04794306663564521, -0.9988500700112948, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.054059020452650715`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1761333790350081`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      28.478626998372874`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.1447681523083749, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9988500700112948, 0.04794306663564521, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {3.7259065841173045`, -4.4409374302681215`, 
       0.}, Optica`Optica`RayEnd :> {3.856328888908827, -5.4, 0.}, 
      RotationMatrix :> {{0.13474910278754154`, -0.9908797501704997, 0.}, {
       0.9908797501704997, 0.13474910278754154`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010854184525250454`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9678899680479428, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 28.224237288157134`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.393671111091173, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13474910278754154`, -0.9908797501704997, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {2.2382741906794665`, -4.436492633377812, 0.}, 
      Optica`Optica`RayEnd :> {2.2486306484639114`, -5.4, 0.}, 
      RotationMatrix :> {{0.010748085515444279`, -0.9999422376606322, 0.}, {
       0.9999422376606322, 0.010748085515444279`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03842949207078567, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9635630242765988, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 28.061488234584225`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {3.0013693515360886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.010748085515444279`, -0.9999422376606322, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.892191514199834, -4.095942514368096, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -5.219973146163546, 0.}, 
      RotationMatrix :> {{-0.7127504549162951, -0.7014176993893252, 0.}, {
       0.7014176993893252, -0.7127504549162951, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15715266006497608`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6025125011445578`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      27.31079386225014, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-4.819973146163545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 74, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7127504549162951, -0.7014176993893252, 
       0.}], 
     Optica`Optica`Ray[
     Optica`Optica`RayStart :> {1.8626583431103891`, -1.5802739192837725`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.7311201728047454`, 0.}, 
      RotationMatrix :> {{-0.6950781664382594, -0.7189341712151578, 0.}, {
       0.7189341712151578, -0.6950781664382594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009594616403945098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.600767218472572, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      28.180415581006372`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.3311201728047455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 79, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6950781664382594, -0.7189341712151578, 
       0.}]}, {{}, {
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`SingleRay[{
           Optica`Optica`Ray[]}, 1, Optica`Optica`IntrinsicMedium -> 1.34, 
          Optica`Optica`SourceTransformation -> {{-2., 0, 0}, {{1., 0, 0}, {
             0, 1., 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{-2, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-2., 0, 0}, {{1., 0, 0}, {
          0, 1., 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-2, 0, 0}, {{1, 0, 
         0}, {0, 1, 0}, {0, 0, 1}}}, Optica`Optica`SourceLevel :> {1, 1}, 
       Optica`Optica`NumberOfRays :> 1, Optica`Optica`BirthPoint :> {0, 0, 0},
        Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 79735, Optica`Optica`SourceFraction :> 
       1, Optica`Optica`SourceOffset :> 0, Optica`Optica`GridSpacing :> (#& ),
        Optica`Optica`PowerOutput :> Optica`Optica`PowerOutput, 
       Optica`Optica`SymbolicValues -> {}, Optica`Optica`IntrinsicMedium :> 
       1.34]}}, 
    Optica`Optica`Private`HeldList[
     Optica`Optica`Component[
     Optica`Optica`ComponentID -> 76509, Optica`Optica`ComponentDescription -> 
      Optica`Optica`ComponentDescription[
        Optica`Optica`RemoveSurface[
         Optica`Optica`RodLens[
         1, 1, {Optica`Optica`FresnelReflections -> True, 
           Optica`Optica`ComponentMedium -> 1.48}, 
          Optica`Optica`ComponentLabel -> "", 
          Optica`Optica`SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0,
             0}, {0, 1, 0}, {0, 0, 1}}}, 
          Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
            0.}, {0., 1., 0.}, {0., 0., 1.}}}], {1, 5}, 
         Optica`Optica`ComponentLabel -> ""]], 
      Optica`Optica`TranslationVector -> {0., 0., 0.}, 
      RotationMatrix -> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, 
      Optica`Optica`Labels -> {"L"}, 
      Optica`Optica`LabelPositions -> {{
        0., -0.5 - 1. Optica`Optica`Offy, -0.5 - 1. Optica`Optica`Offz}}, 
      EdgeStyle -> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CrossStyle -> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CatalogInformation -> {{}}, 
      Optica`Optica`Surfaces -> {{
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76512, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> -1., 
         Optica`Optica`ComponentMedium -> 1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, 1.}, {0, 1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {0, 0, 0.5}, 
         Optica`Optica`SurfaceCenter -> {-0.00001, 0.00001, 0.5}, 
         Optica`Optica`SurfaceBoundary -> 1., 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           0}}, {{7., {3, 0, 5}}, {0.25, {3, 0, 4}}}, {1, 0, 6, 0, 
           0}, {{40, 56, 3, 0, 0, 3, 0, 2}, {40, 56, 3, 0, 1, 3, 0, 3}, {13, 
            2, 3, 2}, {27, 4, 5, 2, 4, 0}, {1}}, 
           
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            Optica`Optica`SCx^2 + Optica`Optica`SCy^2 <= 0.25], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {0, 0, 
           Rational[1, 2]}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, 1}, {0, 1, 0}, {-1, 
          0, 0}}, Optica`Optica`SymbolicComponentTransformation -> {{0, 0, 
            Rational[1, 2]}, {{0, 0, 1}, {0, 1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> 1, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {1, {2, 0, 1}}, {
            7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {2, {2, 0, 2}}, {
            0.25, {3, 0, 14}}, {False, {1, 0, 3}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}}, {5, 4,
            15, 0, 5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27,
             8, 9, 7, 8, 0}, {2, 0, 37}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 
            7, 8}, {19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {
            13, 1, 11, 8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13,
             2, 12, 11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 
            269, 3, 0, 10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 
            9}, {38, 0, 0, 2, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 11}, {38, 0, 0, 
            3, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 12}, {13, 11, 12, 11}, {27, 4, 
            9, 11, 14, 2}, {5, 2, 4}, {3, 2}, {5, 3, 4}, {2, 4, 7}, {38, 0, 0,
             1, 0, 11}, {38, 0, 0, 2, 0, 8}, {38, 0, 0, 3, 0, 10}, {34, 11, 8,
             10, 3, 1}, {42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$474}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 0.25], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$474 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$474), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$474, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$474}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76359, 
         Optica`Optica`SurfaceContinuation -> True, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`CylindricalShape, 
         Optica`Optica`SurfaceValue -> Rational[1, 2], 
         Optica`Optica`SurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`ActiveRegion -> 1., Optica`Optica`ComponentMedium -> 
         1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, -
             Optica`Optica`SCx (Rational[1, 4] - Optica`Optica`SCx^2)^
              Rational[-1, 2], 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {-0.5, 0, 0}, 
         Optica`Optica`SurfaceCenter -> {-0.5, 0.00001, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {0.8660254037844386, 1.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{7., {3, 0, 3}}, {0.5, {3, 0, 6}}, {
            False, {1, 0, 4}}, {-0.4330127018922193, {3, 0, 4}}, {-0.5, {3, 0,
              5}}, {0.4330127018922193, {3, 0, 2}}}, {6, 0, 7, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 0.4330127018922193, 
             Optica`Optica`SCx >= -0.4330127018922193, 
             Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {
           Rational[-1, 2], 0, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}, Optica`Optica`SymbolicComponentTransformation -> {{
            Rational[-1, 2], 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> Rational[1, 2], 
         Optica`Optica`SymbolicSurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {
          Rational[1, 2] 3^Rational[1, 2], 1}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           6}}, {{{{-1., 0., 0.}}, {3, 2, 0}}, {1, {2, 0, 3}}, {
            1., {3, 0, 6}}, {1.*^-7, {3, 0, 22}}, {7., {3, 0, 14}}, {
            1.*^-10, {3, 0, 12}}, {2, {2, 0, 0}}, {0.25, {3, 0, 21}}, {
            5, {2, 0, 4}}, {0.5, {3, 0, 9}}, {False, {1, 0, 2}}, {
            0., {3, 0, 13}}, {-0.4330127018922193, {3, 0, 19}}, {
            3, {2, 0, 2}}, {-0.5, {3, 0, 20}}, {{-1., 0., 0.}, {3, 1, 2}}, {
            0.4330127018922193, {3, 0, 18}}}, {8, 5, 33, 4, 
           8}, {{7, 6, 10}, {7, 6, 24}, {7, 6, 26}, {7, 6, 11}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 3}, {7, 6, 25}, {7, 6, 23}, {7, 
            6, 16}, {40, 56, 3, 0, 3, 3, 0, 30}, {40, 56, 3, 0, 4, 3, 0, 
            28}, {13, 30, 28, 30}, {7, 30, 11}, {40, 56, 3, 0, 0, 3, 0, 30}, {
            40, 56, 3, 0, 1, 3, 0, 28}, {10, 0, 31}, {16, 31, 0, 9, 31}, {19, 
            31, 32}, {13, 30, 28, 32, 30}, {7, 30, 10}, {16, 0, 3, 30}, {16, 
            1, 4, 28}, {16, 9, 3, 32}, {19, 32, 31}, {13, 30, 28, 31, 30}, {7,
             30, 24}, {40, 56, 3, 0, 24, 3, 0, 30}, {16, 10, 11, 28}, {19, 28,
             31}, {13, 30, 31, 30}, {7, 30, 26}, {41, 269, 3, 0, 11, 3, 0, 12,
             3, 0, 30}, {27, 8, 14, 30, 13, 0}, {2, 0, 5}, {41, 269, 3, 0, 26,
             3, 0, 12, 3, 0, 30}, {27, 6, 14, 30, 13, 4}, {5, 4, 3}, {3, 2}, {
            5, 2, 3}, {2, 3, 177}, {10, 0, 30}, {40, 60, 3, 0, 30, 3, 0, 
            31}, {41, 263, 3, 0, 26, 3, 0, 31, 3, 0, 30}, {7, 30, 26}, {13, 
            24, 26, 30}, {7, 30, 15}, {40, 60, 3, 0, 11, 3, 0, 30}, {7, 30, 
            17}, {16, 15, 17, 30}, {19, 30, 31}, {16, 1, 11, 30}, {16, 15, 4, 
            28}, {19, 28, 32}, {13, 30, 32, 30}, {16, 30, 17, 30}, {16, 2, 11,
             32}, {16, 15, 5, 28}, {19, 28, 29}, {13, 32, 29, 32}, {16, 32, 
            17, 32}, {34, 31, 30, 32, 3, 4}, {33, 4, 1}, {24, 1, 2, 0}, {32, 
            0, 0}, {2, 0, 3}, {49}, {3, 1}, {37, 4, 3, 3, 31}, {7, 31, 25}, {
            37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 3, 31}, {7, 31, 16}, {
            41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27, 6, 14, 31, 13, 0}, {
            2, 0, 43}, {27, 4, 14, 23, 18, 4}, {2, 4, 14}, {27, 6, 14, 23, 19,
             1}, {2, 1, 9}, {27, 6, 14, 16, 20, 5}, {2, 5, 4}, {27, 4, 14, 16,
             9, 6}, {5, 6, 7}, {3, 2}, {5, 2, 7}, {5, 7, 5}, {3, 2}, {5, 2, 
            5}, {5, 5, 1}, {3, 2}, {5, 2, 1}, {2, 1, 23}, {16, 25, 4, 31}, {
            19, 23, 30}, {13, 1, 31, 30, 32}, {40, 38, 3, 0, 32, 3, 0, 31}, {
            16, 25, 3, 32}, {40, 56, 3, 0, 23, 3, 0, 30}, {19, 30, 29}, {13, 
            21, 29, 30}, {40, 57, 3, 0, 30, 4, 0, 0}, {11, 20, 13, 1}, {11, 0,
             13, 2}, {11, 32, 13, 3}, {14, 1, 2, 3, 0, 1}, {40, 38, 4, 0, 1, 
            3, 0, 32}, {16, 25, 5, 30}, {19, 16, 29}, {13, 2, 30, 29, 28}, {
            40, 38, 3, 0, 28, 3, 0, 30}, {13, 31, 32, 30, 31}, {27, 3, 14, 31,
             22, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {5, 5, 1}, {3, 2}, {5, 2, 
            1}, {2, 1, 4}, {34, 25, 23, 16, 3, 4}, {
            42, "CopyTensor", 3, 1, 4, 3, 1, 6}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 6}, {19, 24, 31}, {7, 31, 7}, {
            13, 7, 26, 31}, {7, 31, 27}, {40, 60, 3, 0, 11, 3, 0, 31}, {7, 31,
             8}, {16, 27, 8, 31}, {16, 1, 11, 32}, {16, 27, 4, 30}, {13, 32, 
            30, 32}, {16, 32, 8, 32}, {16, 2, 11, 30}, {16, 27, 5, 28}, {13, 
            30, 28, 30}, {16, 30, 8, 30}, {34, 31, 32, 30, 3, 4}, {33, 4, 
            1}, {24, 1, 2, 1}, {32, 1, 1}, {2, 1, 3}, {49}, {3, 1}, {37, 4, 3,
             3, 31}, {7, 31, 25}, {37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 
            3, 31}, {7, 31, 16}, {41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27,
             6, 14, 31, 13, 1}, {2, 1, 43}, {27, 4, 14, 23, 18, 0}, {2, 0, 
            14}, {27, 6, 14, 23, 19, 5}, {2, 5, 9}, {27, 6, 14, 16, 20, 4}, {
            2, 4, 4}, {27, 4, 14, 16, 9, 7}, {5, 7, 6}, {3, 2}, {5, 2, 6}, {5,
             6, 4}, {3, 2}, {5, 2, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 
            23}, {16, 25, 4, 31}, {19, 23, 32}, {13, 1, 31, 32, 30}, {40, 38, 
            3, 0, 30, 3, 0, 31}, {16, 25, 3, 30}, {40, 56, 3, 0, 23, 3, 0, 
            32}, {19, 32, 28}, {13, 21, 28, 32}, {40, 57, 3, 0, 32, 4, 0, 
            1}, {11, 20, 13, 0}, {11, 0, 13, 2}, {11, 30, 13, 3}, {14, 0, 2, 
            3, 1, 0}, {40, 38, 4, 0, 0, 3, 0, 30}, {16, 25, 5, 32}, {19, 16, 
            28}, {13, 2, 32, 28, 29}, {40, 38, 3, 0, 29, 3, 0, 32}, {13, 31, 
            30, 32, 31}, {27, 3, 14, 31, 22, 0}, {5, 0, 4}, {3, 2}, {5, 2, 
            4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 4}, {34, 25, 23, 16, 3, 
            4}, {42, "CopyTensor", 3, 1, 4, 3, 1, 7}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 7}, {34, 6, 7, 0, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 3}, {38, 3, 0, 3, 1, 4}, {38, 3, 
            0, 0, 1, 6}, {
            42, "CompareTensor", 2, 0, 4, 3, 0, 14, 3, 1, 4, 3, 1, 6, 1, 0, 
             1}, {2, 1, 5}, {38, 3, 0, 3, 1, 4}, {34, 4, 0, 6}, {
            42, "CopyTensor", 3, 2, 6, 3, 2, 4}, {3, 2}, {
            42, "CopyTensor", 3, 2, 3, 3, 2, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 6}, {3, 2}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 6}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            
            Block[{Compile`$512, Compile`$513, Compile`$526, Compile`$527, 
              Compile`$528}, 
             
             Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
               Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
               Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
               Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
              Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
              Optica`Optica`TempVar4 = 1.; 
              Optica`Optica`TempVar = {{-1., 0., 0.}}; 
              Optica`Optica`RayL = 1.; Optica`Optica`SCx = 1.; 
              Optica`Optica`SCy = 1.; 
              Optica`Optica`TempVar4 = 
               Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
              Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
              Optica`Optica`TempVar1 = 
               Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 
                Optica`Optica`RSx Rational[1, 2]; 
              Optica`Optica`TempVar2 = 
               Optica`Optica`RSx Optica`Optica`RTx + 
                Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
                Optica`Optica`RTx; 
              Optica`Optica`TempVar3 = 
               Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                Optica`Optica`TempVar4; 
              Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
                And[N[
                   Chop[Optica`Optica`TempVar4]] != 0., N[
                   Chop[Optica`Optica`TempVar3]] >= 0.], 
                Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
                Optica`Optica`TempVar = {{
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$512 = 
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3; 
                    Compile`$513 = 
                    Optica`Optica`TempVar4^(-1); {-(Compile`$512 
                    Compile`$513), (Optica`Optica`RSy Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTy) 
                    Compile`$513, (Optica`Optica`RSz Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTz) Compile`$513}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$526 = -Optica`Optica`TempVar2; 
                    Compile`$527 = Compile`$526 + Optica`Optica`TempVar3; 
                    Compile`$528 = Optica`Optica`TempVar4^(-1); {
                    Compile`$527 
                    Compile`$528, (Optica`Optica`RSy Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTy) 
                    Compile`$528, (Optica`Optica`RSz Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTz) Compile`$528}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
                If[Part[Optica`Optica`TempVar, 1] == 
                  Part[Optica`Optica`TempVar, 2], {
                   Part[Optica`Optica`TempVar, 1]}, 
                  Optica`Optica`TempVar], {{-1., 0., 0.}}]]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SymbolicSurfaceIntersectionFunction -> 
         Optica`Optica`SurfaceIntersectionFunction[{
           Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
           
           Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
             Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
             Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
             Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
            Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
            Optica`Optica`TempVar4 = 1.; 
            Optica`Optica`TempVar = {{-1., 0., 0.}}; Optica`Optica`RayL = 1.; 
            Optica`Optica`SCx = 1.; Optica`Optica`SCy = 1.; 
            Optica`Optica`TempVar4 = 
             Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
            Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
            Optica`Optica`TempVar1 = 
             Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 Optica`Optica`RSx 
              Rational[1, 2]; 
            Optica`Optica`TempVar2 = 
             Optica`Optica`RSx Optica`Optica`RTx + 
              Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
              Optica`Optica`RTx; 
            Optica`Optica`TempVar3 = 
             Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
              Optica`Optica`TempVar4; 
            Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
              And[N[
                 Chop[Optica`Optica`TempVar4]] != 0., N[
                 Chop[Optica`Optica`TempVar3]] >= 0.], 
              Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
              Optica`Optica`TempVar = {{
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {-((Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/Optica`Optica`TempVar4), (
                    Optica`Optica`RSy Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTz)/Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {(-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSy 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTz)/
                    Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
              If[Part[Optica`Optica`TempVar, 1] == 
                Part[Optica`Optica`TempVar, 2], {
                 Part[Optica`Optica`TempVar, 1]}, 
                Optica`Optica`TempVar], {{-1., 0., 0.}}]]], 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76359, 
         Optica`Optica`SurfaceContinuation -> True, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`CylindricalShape, 
         Optica`Optica`SurfaceValue -> Rational[1, 2], 
         Optica`Optica`SurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`ActiveRegion -> 1., Optica`Optica`ComponentMedium -> 
         1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, -
             Optica`Optica`SCx (Rational[1, 4] - Optica`Optica`SCx^2)^
              Rational[-1, 2], 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{-0.5, 0.8660254037844386, 
            0}, {-0.8660254037844386, -0.5, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {0.25, -0.4330127018922193, 0}, 
         Optica`Optica`SurfaceCenter -> {
          0.24999133974596216`, -0.4330177018922193, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {0.8660254037844386, 1.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{7., {3, 0, 3}}, {0.5, {3, 0, 6}}, {
            False, {1, 0, 4}}, {-0.4330127018922193, {3, 0, 4}}, {-0.5, {3, 0,
              5}}, {0.4330127018922193, {3, 0, 2}}}, {6, 0, 7, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 0.4330127018922193, 
             Optica`Optica`SCx >= -0.4330127018922193, 
             Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {
           Rational[1, 4], Rational[-1, 4] 3^Rational[1, 2], 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{
            Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {
           Rational[-1, 2] 3^Rational[1, 2], 
            Rational[-1, 2], 0}, {0, 0, 1}}, 
         Optica`Optica`SymbolicComponentTransformation -> {{
            Rational[1, 4], Rational[-1, 4] 3^Rational[1, 2], 0}, {{
             Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {
            Rational[-1, 2] 3^Rational[1, 2], 
             Rational[-1, 2], 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> Rational[1, 2], 
         Optica`Optica`SymbolicSurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {
          Rational[1, 2] 3^Rational[1, 2], 1}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           6}}, {{{{-1., 0., 0.}}, {3, 2, 0}}, {1, {2, 0, 3}}, {
            1., {3, 0, 6}}, {1.*^-7, {3, 0, 22}}, {7., {3, 0, 14}}, {
            1.*^-10, {3, 0, 12}}, {2, {2, 0, 0}}, {0.25, {3, 0, 21}}, {
            5, {2, 0, 4}}, {0.5, {3, 0, 9}}, {False, {1, 0, 2}}, {
            0., {3, 0, 13}}, {-0.4330127018922193, {3, 0, 19}}, {
            3, {2, 0, 2}}, {-0.5, {3, 0, 20}}, {{-1., 0., 0.}, {3, 1, 2}}, {
            0.4330127018922193, {3, 0, 18}}}, {8, 5, 33, 4, 
           8}, {{7, 6, 10}, {7, 6, 24}, {7, 6, 26}, {7, 6, 11}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 3}, {7, 6, 25}, {7, 6, 23}, {7, 
            6, 16}, {40, 56, 3, 0, 3, 3, 0, 30}, {40, 56, 3, 0, 4, 3, 0, 
            28}, {13, 30, 28, 30}, {7, 30, 11}, {40, 56, 3, 0, 0, 3, 0, 30}, {
            40, 56, 3, 0, 1, 3, 0, 28}, {10, 0, 31}, {16, 31, 0, 9, 31}, {19, 
            31, 32}, {13, 30, 28, 32, 30}, {7, 30, 10}, {16, 0, 3, 30}, {16, 
            1, 4, 28}, {16, 9, 3, 32}, {19, 32, 31}, {13, 30, 28, 31, 30}, {7,
             30, 24}, {40, 56, 3, 0, 24, 3, 0, 30}, {16, 10, 11, 28}, {19, 28,
             31}, {13, 30, 31, 30}, {7, 30, 26}, {41, 269, 3, 0, 11, 3, 0, 12,
             3, 0, 30}, {27, 8, 14, 30, 13, 0}, {2, 0, 5}, {41, 269, 3, 0, 26,
             3, 0, 12, 3, 0, 30}, {27, 6, 14, 30, 13, 4}, {5, 4, 3}, {3, 2}, {
            5, 2, 3}, {2, 3, 177}, {10, 0, 30}, {40, 60, 3, 0, 30, 3, 0, 
            31}, {41, 263, 3, 0, 26, 3, 0, 31, 3, 0, 30}, {7, 30, 26}, {13, 
            24, 26, 30}, {7, 30, 15}, {40, 60, 3, 0, 11, 3, 0, 30}, {7, 30, 
            17}, {16, 15, 17, 30}, {19, 30, 31}, {16, 1, 11, 30}, {16, 15, 4, 
            28}, {19, 28, 32}, {13, 30, 32, 30}, {16, 30, 17, 30}, {16, 2, 11,
             32}, {16, 15, 5, 28}, {19, 28, 29}, {13, 32, 29, 32}, {16, 32, 
            17, 32}, {34, 31, 30, 32, 3, 4}, {33, 4, 1}, {24, 1, 2, 0}, {32, 
            0, 0}, {2, 0, 3}, {49}, {3, 1}, {37, 4, 3, 3, 31}, {7, 31, 25}, {
            37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 3, 31}, {7, 31, 16}, {
            41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27, 6, 14, 31, 13, 0}, {
            2, 0, 43}, {27, 4, 14, 23, 18, 4}, {2, 4, 14}, {27, 6, 14, 23, 19,
             1}, {2, 1, 9}, {27, 6, 14, 16, 20, 5}, {2, 5, 4}, {27, 4, 14, 16,
             9, 6}, {5, 6, 7}, {3, 2}, {5, 2, 7}, {5, 7, 5}, {3, 2}, {5, 2, 
            5}, {5, 5, 1}, {3, 2}, {5, 2, 1}, {2, 1, 23}, {16, 25, 4, 31}, {
            19, 23, 30}, {13, 1, 31, 30, 32}, {40, 38, 3, 0, 32, 3, 0, 31}, {
            16, 25, 3, 32}, {40, 56, 3, 0, 23, 3, 0, 30}, {19, 30, 29}, {13, 
            21, 29, 30}, {40, 57, 3, 0, 30, 4, 0, 0}, {11, 20, 13, 1}, {11, 0,
             13, 2}, {11, 32, 13, 3}, {14, 1, 2, 3, 0, 1}, {40, 38, 4, 0, 1, 
            3, 0, 32}, {16, 25, 5, 30}, {19, 16, 29}, {13, 2, 30, 29, 28}, {
            40, 38, 3, 0, 28, 3, 0, 30}, {13, 31, 32, 30, 31}, {27, 3, 14, 31,
             22, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {5, 5, 1}, {3, 2}, {5, 2, 
            1}, {2, 1, 4}, {34, 25, 23, 16, 3, 4}, {
            42, "CopyTensor", 3, 1, 4, 3, 1, 6}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 6}, {19, 24, 31}, {7, 31, 7}, {
            13, 7, 26, 31}, {7, 31, 27}, {40, 60, 3, 0, 11, 3, 0, 31}, {7, 31,
             8}, {16, 27, 8, 31}, {16, 1, 11, 32}, {16, 27, 4, 30}, {13, 32, 
            30, 32}, {16, 32, 8, 32}, {16, 2, 11, 30}, {16, 27, 5, 28}, {13, 
            30, 28, 30}, {16, 30, 8, 30}, {34, 31, 32, 30, 3, 4}, {33, 4, 
            1}, {24, 1, 2, 1}, {32, 1, 1}, {2, 1, 3}, {49}, {3, 1}, {37, 4, 3,
             3, 31}, {7, 31, 25}, {37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 
            3, 31}, {7, 31, 16}, {41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27,
             6, 14, 31, 13, 1}, {2, 1, 43}, {27, 4, 14, 23, 18, 0}, {2, 0, 
            14}, {27, 6, 14, 23, 19, 5}, {2, 5, 9}, {27, 6, 14, 16, 20, 4}, {
            2, 4, 4}, {27, 4, 14, 16, 9, 7}, {5, 7, 6}, {3, 2}, {5, 2, 6}, {5,
             6, 4}, {3, 2}, {5, 2, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 
            23}, {16, 25, 4, 31}, {19, 23, 32}, {13, 1, 31, 32, 30}, {40, 38, 
            3, 0, 30, 3, 0, 31}, {16, 25, 3, 30}, {40, 56, 3, 0, 23, 3, 0, 
            32}, {19, 32, 28}, {13, 21, 28, 32}, {40, 57, 3, 0, 32, 4, 0, 
            1}, {11, 20, 13, 0}, {11, 0, 13, 2}, {11, 30, 13, 3}, {14, 0, 2, 
            3, 1, 0}, {40, 38, 4, 0, 0, 3, 0, 30}, {16, 25, 5, 32}, {19, 16, 
            28}, {13, 2, 32, 28, 29}, {40, 38, 3, 0, 29, 3, 0, 32}, {13, 31, 
            30, 32, 31}, {27, 3, 14, 31, 22, 0}, {5, 0, 4}, {3, 2}, {5, 2, 
            4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 4}, {34, 25, 23, 16, 3, 
            4}, {42, "CopyTensor", 3, 1, 4, 3, 1, 7}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 7}, {34, 6, 7, 0, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 3}, {38, 3, 0, 3, 1, 4}, {38, 3, 
            0, 0, 1, 6}, {
            42, "CompareTensor", 2, 0, 4, 3, 0, 14, 3, 1, 4, 3, 1, 6, 1, 0, 
             1}, {2, 1, 5}, {38, 3, 0, 3, 1, 4}, {34, 4, 0, 6}, {
            42, "CopyTensor", 3, 2, 6, 3, 2, 4}, {3, 2}, {
            42, "CopyTensor", 3, 2, 3, 3, 2, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 6}, {3, 2}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 6}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            
            Block[{Compile`$512, Compile`$513, Compile`$526, Compile`$527, 
              Compile`$528}, 
             
             Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
               Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
               Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
               Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
              Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
              Optica`Optica`TempVar4 = 1.; 
              Optica`Optica`TempVar = {{-1., 0., 0.}}; 
              Optica`Optica`RayL = 1.; Optica`Optica`SCx = 1.; 
              Optica`Optica`SCy = 1.; 
              Optica`Optica`TempVar4 = 
               Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
              Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
              Optica`Optica`TempVar1 = 
               Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 
                Optica`Optica`RSx Rational[1, 2]; 
              Optica`Optica`TempVar2 = 
               Optica`Optica`RSx Optica`Optica`RTx + 
                Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
                Optica`Optica`RTx; 
              Optica`Optica`TempVar3 = 
               Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                Optica`Optica`TempVar4; 
              Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
                And[N[
                   Chop[Optica`Optica`TempVar4]] != 0., N[
                   Chop[Optica`Optica`TempVar3]] >= 0.], 
                Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
                Optica`Optica`TempVar = {{
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$512 = 
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3; 
                    Compile`$513 = 
                    Optica`Optica`TempVar4^(-1); {-(Compile`$512 
                    Compile`$513), (Optica`Optica`RSy Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTy) 
                    Compile`$513, (Optica`Optica`RSz Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTz) Compile`$513}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$526 = -Optica`Optica`TempVar2; 
                    Compile`$527 = Compile`$526 + Optica`Optica`TempVar3; 
                    Compile`$528 = Optica`Optica`TempVar4^(-1); {
                    Compile`$527 
                    Compile`$528, (Optica`Optica`RSy Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTy) 
                    Compile`$528, (Optica`Optica`RSz Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTz) Compile`$528}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
                If[Part[Optica`Optica`TempVar, 1] == 
                  Part[Optica`Optica`TempVar, 2], {
                   Part[Optica`Optica`TempVar, 1]}, 
                  Optica`Optica`TempVar], {{-1., 0., 0.}}]]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SymbolicSurfaceIntersectionFunction -> 
         Optica`Optica`SurfaceIntersectionFunction[{
           Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
           
           Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
             Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
             Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
             Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
            Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
            Optica`Optica`TempVar4 = 1.; 
            Optica`Optica`TempVar = {{-1., 0., 0.}}; Optica`Optica`RayL = 1.; 
            Optica`Optica`SCx = 1.; Optica`Optica`SCy = 1.; 
            Optica`Optica`TempVar4 = 
             Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
            Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
            Optica`Optica`TempVar1 = 
             Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 Optica`Optica`RSx 
              Rational[1, 2]; 
            Optica`Optica`TempVar2 = 
             Optica`Optica`RSx Optica`Optica`RTx + 
              Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
              Optica`Optica`RTx; 
            Optica`Optica`TempVar3 = 
             Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
              Optica`Optica`TempVar4; 
            Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
              And[N[
                 Chop[Optica`Optica`TempVar4]] != 0., N[
                 Chop[Optica`Optica`TempVar3]] >= 0.], 
              Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
              Optica`Optica`TempVar = {{
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {-((Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/Optica`Optica`TempVar4), (
                    Optica`Optica`RSy Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTz)/Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {(-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSy 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTz)/
                    Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
              If[Part[Optica`Optica`TempVar, 1] == 
                Part[Optica`Optica`TempVar, 2], {
                 Part[Optica`Optica`TempVar, 1]}, 
                Optica`Optica`TempVar], {{-1., 0., 0.}}]]], 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76359, 
         Optica`Optica`SurfaceContinuation -> True, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`CylindricalShape, 
         Optica`Optica`SurfaceValue -> Rational[1, 2], 
         Optica`Optica`SurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`ActiveRegion -> 1., Optica`Optica`ComponentMedium -> 
         1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, -
             Optica`Optica`SCx (Rational[1, 4] - Optica`Optica`SCx^2)^
              Rational[-1, 2], 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{-0.5, -0.8660254037844386, 0}, {
           0.8660254037844386, -0.5, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {0.25, 0.4330127018922193, 0}, 
         Optica`Optica`SurfaceCenter -> {0.25000866025403784`, 
          0.4330077018922193, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {0.8660254037844386, 1.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{7., {3, 0, 3}}, {0.5, {3, 0, 6}}, {
            False, {1, 0, 4}}, {-0.4330127018922193, {3, 0, 4}}, {-0.5, {3, 0,
              5}}, {0.4330127018922193, {3, 0, 2}}}, {6, 0, 7, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 0.4330127018922193, 
             Optica`Optica`SCx >= -0.4330127018922193, 
             Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {
           Rational[1, 4], Rational[1, 4] 3^Rational[1, 2], 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{
            Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {
           Rational[1, 2] 3^Rational[1, 2], 
            Rational[-1, 2], 0}, {0, 0, 1}}, 
         Optica`Optica`SymbolicComponentTransformation -> {{
            Rational[1, 4], Rational[1, 4] 3^Rational[1, 2], 0}, {{
             Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {
            Rational[1, 2] 3^Rational[1, 2], 
             Rational[-1, 2], 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> Rational[1, 2], 
         Optica`Optica`SymbolicSurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {
          Rational[1, 2] 3^Rational[1, 2], 1}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           6}}, {{{{-1., 0., 0.}}, {3, 2, 0}}, {1, {2, 0, 3}}, {
            1., {3, 0, 6}}, {1.*^-7, {3, 0, 22}}, {7., {3, 0, 14}}, {
            1.*^-10, {3, 0, 12}}, {2, {2, 0, 0}}, {0.25, {3, 0, 21}}, {
            5, {2, 0, 4}}, {0.5, {3, 0, 9}}, {False, {1, 0, 2}}, {
            0., {3, 0, 13}}, {-0.4330127018922193, {3, 0, 19}}, {
            3, {2, 0, 2}}, {-0.5, {3, 0, 20}}, {{-1., 0., 0.}, {3, 1, 2}}, {
            0.4330127018922193, {3, 0, 18}}}, {8, 5, 33, 4, 
           8}, {{7, 6, 10}, {7, 6, 24}, {7, 6, 26}, {7, 6, 11}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 3}, {7, 6, 25}, {7, 6, 23}, {7, 
            6, 16}, {40, 56, 3, 0, 3, 3, 0, 30}, {40, 56, 3, 0, 4, 3, 0, 
            28}, {13, 30, 28, 30}, {7, 30, 11}, {40, 56, 3, 0, 0, 3, 0, 30}, {
            40, 56, 3, 0, 1, 3, 0, 28}, {10, 0, 31}, {16, 31, 0, 9, 31}, {19, 
            31, 32}, {13, 30, 28, 32, 30}, {7, 30, 10}, {16, 0, 3, 30}, {16, 
            1, 4, 28}, {16, 9, 3, 32}, {19, 32, 31}, {13, 30, 28, 31, 30}, {7,
             30, 24}, {40, 56, 3, 0, 24, 3, 0, 30}, {16, 10, 11, 28}, {19, 28,
             31}, {13, 30, 31, 30}, {7, 30, 26}, {41, 269, 3, 0, 11, 3, 0, 12,
             3, 0, 30}, {27, 8, 14, 30, 13, 0}, {2, 0, 5}, {41, 269, 3, 0, 26,
             3, 0, 12, 3, 0, 30}, {27, 6, 14, 30, 13, 4}, {5, 4, 3}, {3, 2}, {
            5, 2, 3}, {2, 3, 177}, {10, 0, 30}, {40, 60, 3, 0, 30, 3, 0, 
            31}, {41, 263, 3, 0, 26, 3, 0, 31, 3, 0, 30}, {7, 30, 26}, {13, 
            24, 26, 30}, {7, 30, 15}, {40, 60, 3, 0, 11, 3, 0, 30}, {7, 30, 
            17}, {16, 15, 17, 30}, {19, 30, 31}, {16, 1, 11, 30}, {16, 15, 4, 
            28}, {19, 28, 32}, {13, 30, 32, 30}, {16, 30, 17, 30}, {16, 2, 11,
             32}, {16, 15, 5, 28}, {19, 28, 29}, {13, 32, 29, 32}, {16, 32, 
            17, 32}, {34, 31, 30, 32, 3, 4}, {33, 4, 1}, {24, 1, 2, 0}, {32, 
            0, 0}, {2, 0, 3}, {49}, {3, 1}, {37, 4, 3, 3, 31}, {7, 31, 25}, {
            37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 3, 31}, {7, 31, 16}, {
            41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27, 6, 14, 31, 13, 0}, {
            2, 0, 43}, {27, 4, 14, 23, 18, 4}, {2, 4, 14}, {27, 6, 14, 23, 19,
             1}, {2, 1, 9}, {27, 6, 14, 16, 20, 5}, {2, 5, 4}, {27, 4, 14, 16,
             9, 6}, {5, 6, 7}, {3, 2}, {5, 2, 7}, {5, 7, 5}, {3, 2}, {5, 2, 
            5}, {5, 5, 1}, {3, 2}, {5, 2, 1}, {2, 1, 23}, {16, 25, 4, 31}, {
            19, 23, 30}, {13, 1, 31, 30, 32}, {40, 38, 3, 0, 32, 3, 0, 31}, {
            16, 25, 3, 32}, {40, 56, 3, 0, 23, 3, 0, 30}, {19, 30, 29}, {13, 
            21, 29, 30}, {40, 57, 3, 0, 30, 4, 0, 0}, {11, 20, 13, 1}, {11, 0,
             13, 2}, {11, 32, 13, 3}, {14, 1, 2, 3, 0, 1}, {40, 38, 4, 0, 1, 
            3, 0, 32}, {16, 25, 5, 30}, {19, 16, 29}, {13, 2, 30, 29, 28}, {
            40, 38, 3, 0, 28, 3, 0, 30}, {13, 31, 32, 30, 31}, {27, 3, 14, 31,
             22, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {5, 5, 1}, {3, 2}, {5, 2, 
            1}, {2, 1, 4}, {34, 25, 23, 16, 3, 4}, {
            42, "CopyTensor", 3, 1, 4, 3, 1, 6}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 6}, {19, 24, 31}, {7, 31, 7}, {
            13, 7, 26, 31}, {7, 31, 27}, {40, 60, 3, 0, 11, 3, 0, 31}, {7, 31,
             8}, {16, 27, 8, 31}, {16, 1, 11, 32}, {16, 27, 4, 30}, {13, 32, 
            30, 32}, {16, 32, 8, 32}, {16, 2, 11, 30}, {16, 27, 5, 28}, {13, 
            30, 28, 30}, {16, 30, 8, 30}, {34, 31, 32, 30, 3, 4}, {33, 4, 
            1}, {24, 1, 2, 1}, {32, 1, 1}, {2, 1, 3}, {49}, {3, 1}, {37, 4, 3,
             3, 31}, {7, 31, 25}, {37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 
            3, 31}, {7, 31, 16}, {41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27,
             6, 14, 31, 13, 1}, {2, 1, 43}, {27, 4, 14, 23, 18, 0}, {2, 0, 
            14}, {27, 6, 14, 23, 19, 5}, {2, 5, 9}, {27, 6, 14, 16, 20, 4}, {
            2, 4, 4}, {27, 4, 14, 16, 9, 7}, {5, 7, 6}, {3, 2}, {5, 2, 6}, {5,
             6, 4}, {3, 2}, {5, 2, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 
            23}, {16, 25, 4, 31}, {19, 23, 32}, {13, 1, 31, 32, 30}, {40, 38, 
            3, 0, 30, 3, 0, 31}, {16, 25, 3, 30}, {40, 56, 3, 0, 23, 3, 0, 
            32}, {19, 32, 28}, {13, 21, 28, 32}, {40, 57, 3, 0, 32, 4, 0, 
            1}, {11, 20, 13, 0}, {11, 0, 13, 2}, {11, 30, 13, 3}, {14, 0, 2, 
            3, 1, 0}, {40, 38, 4, 0, 0, 3, 0, 30}, {16, 25, 5, 32}, {19, 16, 
            28}, {13, 2, 32, 28, 29}, {40, 38, 3, 0, 29, 3, 0, 32}, {13, 31, 
            30, 32, 31}, {27, 3, 14, 31, 22, 0}, {5, 0, 4}, {3, 2}, {5, 2, 
            4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 4}, {34, 25, 23, 16, 3, 
            4}, {42, "CopyTensor", 3, 1, 4, 3, 1, 7}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 7}, {34, 6, 7, 0, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 3}, {38, 3, 0, 3, 1, 4}, {38, 3, 
            0, 0, 1, 6}, {
            42, "CompareTensor", 2, 0, 4, 3, 0, 14, 3, 1, 4, 3, 1, 6, 1, 0, 
             1}, {2, 1, 5}, {38, 3, 0, 3, 1, 4}, {34, 4, 0, 6}, {
            42, "CopyTensor", 3, 2, 6, 3, 2, 4}, {3, 2}, {
            42, "CopyTensor", 3, 2, 3, 3, 2, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 6}, {3, 2}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 6}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            
            Block[{Compile`$512, Compile`$513, Compile`$526, Compile`$527, 
              Compile`$528}, 
             
             Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
               Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
               Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
               Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
              Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
              Optica`Optica`TempVar4 = 1.; 
              Optica`Optica`TempVar = {{-1., 0., 0.}}; 
              Optica`Optica`RayL = 1.; Optica`Optica`SCx = 1.; 
              Optica`Optica`SCy = 1.; 
              Optica`Optica`TempVar4 = 
               Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
              Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
              Optica`Optica`TempVar1 = 
               Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 
                Optica`Optica`RSx Rational[1, 2]; 
              Optica`Optica`TempVar2 = 
               Optica`Optica`RSx Optica`Optica`RTx + 
                Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
                Optica`Optica`RTx; 
              Optica`Optica`TempVar3 = 
               Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                Optica`Optica`TempVar4; 
              Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
                And[N[
                   Chop[Optica`Optica`TempVar4]] != 0., N[
                   Chop[Optica`Optica`TempVar3]] >= 0.], 
                Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
                Optica`Optica`TempVar = {{
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$512 = 
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3; 
                    Compile`$513 = 
                    Optica`Optica`TempVar4^(-1); {-(Compile`$512 
                    Compile`$513), (Optica`Optica`RSy Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTy) 
                    Compile`$513, (Optica`Optica`RSz Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTz) Compile`$513}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$526 = -Optica`Optica`TempVar2; 
                    Compile`$527 = Compile`$526 + Optica`Optica`TempVar3; 
                    Compile`$528 = Optica`Optica`TempVar4^(-1); {
                    Compile`$527 
                    Compile`$528, (Optica`Optica`RSy Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTy) 
                    Compile`$528, (Optica`Optica`RSz Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTz) Compile`$528}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
                If[Part[Optica`Optica`TempVar, 1] == 
                  Part[Optica`Optica`TempVar, 2], {
                   Part[Optica`Optica`TempVar, 1]}, 
                  Optica`Optica`TempVar], {{-1., 0., 0.}}]]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SymbolicSurfaceIntersectionFunction -> 
         Optica`Optica`SurfaceIntersectionFunction[{
           Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
           
           Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
             Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
             Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
             Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
            Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
            Optica`Optica`TempVar4 = 1.; 
            Optica`Optica`TempVar = {{-1., 0., 0.}}; Optica`Optica`RayL = 1.; 
            Optica`Optica`SCx = 1.; Optica`Optica`SCy = 1.; 
            Optica`Optica`TempVar4 = 
             Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
            Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
            Optica`Optica`TempVar1 = 
             Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 Optica`Optica`RSx 
              Rational[1, 2]; 
            Optica`Optica`TempVar2 = 
             Optica`Optica`RSx Optica`Optica`RTx + 
              Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
              Optica`Optica`RTx; 
            Optica`Optica`TempVar3 = 
             Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
              Optica`Optica`TempVar4; 
            Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
              And[N[
                 Chop[Optica`Optica`TempVar4]] != 0., N[
                 Chop[Optica`Optica`TempVar3]] >= 0.], 
              Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
              Optica`Optica`TempVar = {{
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {-((Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/Optica`Optica`TempVar4), (
                    Optica`Optica`RSy Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTz)/Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {(-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSy 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTz)/
                    Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
              If[Part[Optica`Optica`TempVar, 1] == 
                Part[Optica`Optica`TempVar, 2], {
                 Part[Optica`Optica`TempVar, 1]}, 
                Optica`Optica`TempVar], {{-1., 0., 0.}}]]], 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76513, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> -1., 
         Optica`Optica`ComponentMedium -> 1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, -1.}, {0, -1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {0, 0, -0.5}, 
         Optica`Optica`SurfaceCenter -> {-0.00001, -0.00001, -0.5}, 
         Optica`Optica`SurfaceBoundary -> 1., 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           0}}, {{7., {3, 0, 5}}, {0.25, {3, 0, 4}}}, {1, 0, 6, 0, 
           0}, {{40, 56, 3, 0, 0, 3, 0, 2}, {40, 56, 3, 0, 1, 3, 0, 3}, {13, 
            2, 3, 2}, {27, 4, 5, 2, 4, 0}, {1}}, 
           
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            Optica`Optica`SCx^2 + Optica`Optica`SCy^2 <= 0.25], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {0, 0, 
           Rational[-1, 2]}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, -1}, {0, -1, 0}, {-1,
           0, 0}}, Optica`Optica`SymbolicComponentTransformation -> {{0, 0, 
            Rational[-1, 2]}, {{0, 0, -1}, {0, -1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> 1, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {1, {2, 0, 1}}, {
            7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {2, {2, 0, 2}}, {
            0.25, {3, 0, 14}}, {False, {1, 0, 3}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}}, {5, 4,
            15, 0, 5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27,
             8, 9, 7, 8, 0}, {2, 0, 37}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 
            7, 8}, {19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {
            13, 1, 11, 8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13,
             2, 12, 11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 
            269, 3, 0, 10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 
            9}, {38, 0, 0, 2, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 11}, {38, 0, 0, 
            3, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 12}, {13, 11, 12, 11}, {27, 4, 
            9, 11, 14, 2}, {5, 2, 4}, {3, 2}, {5, 3, 4}, {2, 4, 7}, {38, 0, 0,
             1, 0, 11}, {38, 0, 0, 2, 0, 8}, {38, 0, 0, 3, 0, 10}, {34, 11, 8,
             10, 3, 1}, {42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$474}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 0.25], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$474 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$474), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$474, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$474}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}}, 
      Optica`Optica`Deflections -> {{{
         Optica`Optica`DeflectionID -> 76450, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76450, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76457, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76457, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76464, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76464, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76471, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76471, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76478, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76478, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76488, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Resonate, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`CreatedRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {
           Optica`Optica`CreatedRay, Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Resonate, False, {
            Optica`Optica`CreatedRay, Optica`Optica`OriginalRay}}}}}, 
      Optica`Optica`EntranceCoordinates -> {{-0.5, 0.00001, 0.00001}, {
       0.24999133974596216`, -0.4330177018922193, 0.00001}, {
       0.25000866025403784`, 0.4330077018922193, 0.00001}}, 
      Optica`Optica`ConfinedPaths -> {{{
         Optica`Optica`SurfaceNumber -> 2, 
          Optica`Optica`DeflectionNumber -> {2, 6}}}, {{
         Optica`Optica`SurfaceNumber -> 3, 
          Optica`Optica`DeflectionNumber -> {3, 6}}}, {{
         Optica`Optica`SurfaceNumber -> 4, 
          Optica`Optica`DeflectionNumber -> {4, 6}}}}, 
      Optica`Optica`RenderedSurfaces -> {{
        Optica`Optica`SurfaceNumber -> 2, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Mesh}, {Optica`Optica`SurfaceNumber -> 3, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Mesh}, {Optica`Optica`SurfaceNumber -> 4, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Mesh}}, Optica`Optica`RenderedPolygons -> {{{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {-0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {0.4330127018922193, 0.}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {-0.4330127018922193, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., -0.5}, 
           Optica`Optica`FinishPoint -> {0., 0.5}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., 0.5}, 
           Optica`Optica`FinishPoint -> {0., -0.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {-0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {0.4330127018922193, 0.}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {-0.4330127018922193, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., -0.5}, 
           Optica`Optica`FinishPoint -> {0., 0.5}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., 0.5}, 
           Optica`Optica`FinishPoint -> {0., -0.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {-0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {0.4330127018922193, 0.}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {-0.4330127018922193, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., -0.5}, 
           Optica`Optica`FinishPoint -> {0., 0.5}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., 0.5}, 
           Optica`Optica`FinishPoint -> {0., -0.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> Trace}}},
       Optica`Optica`SymbolicValues -> {}, 
      Options -> {
       Optica`Optica`ComponentLabel -> Optica`Optica`RemoveSurface, 
        CompoundExpression -> True, Optica`Optica`GraphicDesign -> Automatic, 
        PlotPoints -> 10, Optica`Optica`WaveFrontID -> False}], 
     Optica`Optica`Component[
     Optica`Optica`ComponentID -> 79824, Optica`Optica`ComponentDescription -> 
      Optica`Optica`ComponentDescription[
        Optica`Optica`ClearBoundary[{0, -5, -5}, {9, 5, 5}, 
         Optica`Optica`ComponentLabel -> "", 
         Optica`Optica`SymbolicComponentTransformation -> {{0.75, -0.4, 0}, {{
           1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
         Optica`Optica`ComponentTransformation -> {{
           0.75, -0.4, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}]], 
      Optica`Optica`TranslationVector -> {0.75, -0.4, 0}, 
      RotationMatrix -> {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}, 
      Optica`Optica`Labels -> {""}, 
      Optica`Optica`LabelPositions -> {{0.75, -0.4, 0}}, 
      EdgeStyle -> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CrossStyle -> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CatalogInformation -> {{}, {}, {}, {}, {}, {}}, 
      Optica`Optica`Surfaces -> {{
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79830, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{-1., 0, 0}, {0, -1., 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {9.75, -0.4, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           9.75, -0.4, 0}, {{-1., 0, 0}, {0, -1., 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {9.75, -0.40001000000000003`, 
          0.00001}, Optica`Optica`SurfaceBoundary -> {10., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}}, {6, 0, 5, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 4, 2}, {2, 2, 4}, {27, 4, 3, 1, 2, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {9.75, -0.4, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{-1, 0, 0}, {0, -1, 0}, {0, 
          0, 1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           9.75, -0.4, 0}, {{-1, 0, 0}, {0, -1, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {10, 10}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {False, {1, 0, 6}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}}, {8,
            4, 16, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 15, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 14, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 10}, {38, 0, 0, 3, 0, 
            11}, {34, 8, 10, 11, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$484}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$484 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$484), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$484, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$484}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79831, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 1., 0}, {-1., 0, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {5.25, -5.4, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           5.25, -5.4, 0}, {{0, 1., 0}, {-1., 0, 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {5.24999, -5.4, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {9., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 6}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 4}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 5}}, {4.5, {3, 0, 2}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 4.5, Optica`Optica`SCx >= -4.5, 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, -5.4, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 1, 0}, {-1, 0, 0}, {0, 
          0, 1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           5.25, -5.4, 0}, {{0, 1, 0}, {-1, 0, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {9, 10},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 17}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 15}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 16}}, {
            4.5, {3, 0, 14}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$489}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 4.5, Part[#, 2] >= -4.5, Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$489 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$489), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$489, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$489}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79832, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {0.75, -0.4, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           0.75, -0.4, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {0.75, -0.39999, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {10., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}}, {6, 0, 5, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 4, 2}, {2, 2, 4}, {27, 4, 3, 1, 2, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {0.75, -0.4, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           0.75, -0.4, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {10, 10}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {False, {1, 0, 6}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}}, {8,
            4, 16, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 15, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 14, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 10}, {38, 0, 0, 3, 0, 
            11}, {34, 8, 10, 11, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$484}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$484 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$484), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$484, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$484}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79833, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, -1., 0}, {1., 0, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {5.25, 4.6, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           5.25, 4.6, 0}, {{0, -1., 0}, {1., 0, 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {5.25001, 4.6, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {9., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 6}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 4}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 5}}, {4.5, {3, 0, 2}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 4.5, Optica`Optica`SCx >= -4.5, 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, 4.6, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, -1, 0}, {1, 0, 0}, {0, 
          0, 1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           5.25, 4.6, 0}, {{0, -1, 0}, {1, 0, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {9, 10},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 17}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 15}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 16}}, {
            4.5, {3, 0, 14}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$489}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 4.5, Part[#, 2] >= -4.5, Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$489 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$489), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$489, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$489}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79834, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, 1.}, {0, 1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {5.25, -0.4, -5.}, 
         Optica`Optica`ComponentTransformation -> {{
           5.25, -0.4, -5.}, {{0, 0, 1.}, {0, 1., 0}, {-1., 0, 0}}}, 
         Optica`Optica`SurfaceCenter -> {5.24999, -0.39999, -5.}, 
         Optica`Optica`SurfaceBoundary -> {10., 9.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 5}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}, {4.5, {3, 0, 6}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -4.5, Optica`Optica`SCy <= 4.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, -0.4, -5}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, 1}, {0, 1, 0}, {-1, 
          0, 0}}, Optica`Optica`SymbolicComponentTransformation -> {{
           5.25, -0.4, -5}, {{0, 0, 1}, {0, 1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {10, 9},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 16}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}, {
            4.5, {3, 0, 17}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$488}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -4.5, 
                  Part[#, 3] <= 4.5]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$488 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$488), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$488, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$488}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79835, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, -1.}, {0, -1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {5.25, -0.4, 5.}, 
         Optica`Optica`ComponentTransformation -> {{5.25, -0.4, 
           5.}, {{0, 0, -1.}, {0, -1., 0}, {-1., 0, 0}}}, 
         Optica`Optica`SurfaceCenter -> {5.24999, -0.40001000000000003`, 5.}, 
         Optica`Optica`SurfaceBoundary -> {10., 9.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 5}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}, {4.5, {3, 0, 6}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -4.5, Optica`Optica`SCy <= 4.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, -0.4, 5}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, -1}, {0, -1, 0}, {-1,
           0, 0}}, 
         Optica`Optica`SymbolicComponentTransformation -> {{5.25, -0.4, 5}, {{
           0, 0, -1}, {0, -1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {10, 9},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 16}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}, {
            4.5, {3, 0, 17}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$488}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -4.5, 
                  Part[#, 3] <= 4.5]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$488 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$488), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$488, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$488}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}}, 
      Optica`Optica`Deflections -> {{{
         Optica`Optica`DeflectionID -> 79758, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Transmission, Optica`Optica`ComponentLabel -> 
          Optica`Optica`ClearBoundary, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Transmission, 100, {
            AddTo, 100, False, 79758, False, Optica`Optica`OriginalRay}}}}, {{
         Optica`Optica`DeflectionID -> 79816, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Transmission, Optica`Optica`ComponentLabel -> 
          Optica`Optica`ClearBoundary, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Transmission, 100, {
            AddTo, 100, False, 79816, False, Optica`Optica`OriginalRay}}}}, {{
         Optica`Optica`DeflectionID -> 79787, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Transmission, Optica`Optica`ComponentLabel -> 
          Optica`Optica`ClearBoundary, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Transmission, 100, {
            AddTo, 100, False, 79787, False, Optica`Optica`OriginalRay}}}}}, 
      Optica`Optica`EntranceCoordinates -> {{9.75, -0.40001000000000003`, 
       0.00001}, {5.24999, -5.4, 0.00001}, {0.75, -0.39999, 0.00001}, {
       5.25001, 4.6, 0.00001}, {5.24999, -0.39999, -5.}, {
       5.24999, -0.40001000000000003`, 5.}}, 
      Optica`Optica`ConfinedPaths -> {{{
         Optica`Optica`SurfaceNumber -> 1, 
          Optica`Optica`DeflectionNumber -> {1}}}, {{
         Optica`Optica`SurfaceNumber -> 2, 
          Optica`Optica`DeflectionNumber -> {2}}}, {{
         Optica`Optica`SurfaceNumber -> 3, 
          Optica`Optica`DeflectionNumber -> {1}}}, {{
         Optica`Optica`SurfaceNumber -> 4, 
          Optica`Optica`DeflectionNumber -> {2}}}, {{
         Optica`Optica`SurfaceNumber -> 5, 
          Optica`Optica`DeflectionNumber -> {3}}}, {{
         Optica`Optica`SurfaceNumber -> 6, 
          Optica`Optica`DeflectionNumber -> {3}}}}, 
      Optica`Optica`RenderedSurfaces -> {{
        Optica`Optica`SurfaceNumber -> 1, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 2, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 3, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 4, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 5, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 6, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}}, 
      Optica`Optica`RenderedPolygons -> {{{{
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {-4.5, 0.}, 
           Optica`Optica`FinishPoint -> {4.5, 0.}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {4.5, 0.}, 
           Optica`Optica`FinishPoint -> {-4.5, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {-4.5, 0.}, 
           Optica`Optica`FinishPoint -> {4.5, 0.}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {4.5, 0.}, 
           Optica`Optica`FinishPoint -> {-4.5, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {0., -4.5}, 
           Optica`Optica`FinishPoint -> {0., 4.5}}, {
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {0., 4.5}, 
           Optica`Optica`FinishPoint -> {0., -4.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {0., -4.5}, 
           Optica`Optica`FinishPoint -> {0., 4.5}}, {
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {0., 4.5}, 
           Optica`Optica`FinishPoint -> {0., -4.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> Empty}}},
       Optica`Optica`SymbolicValues -> {}, 
      Options -> {
       Optica`Optica`ComponentLabel -> Optica`Optica`ClearBoundary, 
        Optica`Optica`GraphicDesign -> Automatic, Optica`Optica`WaveFrontID -> 
        False}, Optica`Optica`SymbolicTranslationVector -> {0.75, -0.4, 0}, 
      Optica`Optica`SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0, 
       1}}, Optica`Optica`SymbolicComponentTransformation -> {{
        0.75, -0.4, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}]], 
    Optica`Optica`GraphicalOutput[], 
    Options -> {Optica`Optica`TracingEngine -> Optica`Optica`TurboTrace}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.61472787348345*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"RenderSystem called.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727873950953*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"No changes to numeric parameters have been made for \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Hold", "[", 
    RowBox[{
     RowBox[{"Optica`Optica`Private`HeldList", "[", 
      RowBox[{
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{"RaySlot", "\[RuleDelayed]", "1"}], "]"}], ",", 
             RowBox[{"-", "1.9999999999999996`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "99.74789199320458`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             "1.7667114977152143`", ",", 
             RowBox[{"-", "0.607633832936629`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2514724223244908`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.150842225822762`", ",", 
               RowBox[{"-", "0.004073940169013586`"}]}], "}"}], ",", 
             RowBox[{"-", "169.02190060923866`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "99.49641957088005`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.150842225822762`", ",", 
               RowBox[{"-", "0.004073940169013586`"}]}], "}"}], ",", 
             RowBox[{"-", "1.215267665872658`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "99.25118366957307`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.313846576425795`", ",", 
               RowBox[{"-", "0.007531849809321051`"}]}], "}"}], ",", 
             RowBox[{"-", "1.2417262087554972`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24463145094031025`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6587982155668994`", ",", 
               RowBox[{"-", "0.015008885084780993`"}]}], "}"}], ",", 
             "179.26476206466464`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24523590130695874`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.313846576425795`", ",", 
               RowBox[{"-", "0.007531849809321053`"}]}], "}"}], ",", 
             "178.22532697493847`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24461271838368367`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1506905823677744`", ",", 
               RowBox[{"-", "0.0024766576922289896`"}]}], "}"}], ",", 
             "178.93216410177473`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "99.00655221863269`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6587982155668994`", ",", 
               RowBox[{"-", "0.015008885084780998`"}]}], "}"}], ",", 
             RowBox[{"-", "1.2681847516383364`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "98.75435028932107`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.88220483912467`", ",", 
               RowBox[{"-", "0.01995457484591291`"}]}], "}"}], ",", 
             RowBox[{"-", "2.0027464545939337`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2515594888698206`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.203448398313732`", ",", 
               RowBox[{"-", "0.03118806463673083`"}]}], "}"}], ",", 
             RowBox[{"-", "168.02235282588882`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24402849040546773`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3137939589293546`", ",", 
               RowBox[{"-", "0.010581436087871`"}]}], "}"}], ",", 
             "179.2383035217818`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24341980978631647`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1511871633859885`", ",", 
               RowBox[{"-", "0.008419595868123391`"}]}], "}"}], ",", 
             "179.67930458531467`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25220192931161994`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.88220483912467`", ",", 
               RowBox[{"-", "0.019954574845912905`"}]}], "}"}], ",", 
             "163.28229821374552`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2507567532837804`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6470204120697653`", ",", "0.05068334347140578`"}], 
              "}"}], ",", "167.40944608071263`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "98.50279080045121`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.203448398313732`", ",", 
               RowBox[{"-", "0.03118806463673083`"}]}], "}"}], ",", 
             RowBox[{"-", "2.73730815755102`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "98.25016212424417`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.289988407633029`", ",", 
               RowBox[{"-", "0.03532566548370465`"}]}], "}"}], ",", 
             RowBox[{"-", "1.929976871267179`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2519807631121969`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6101936044655933`", ",", 
               RowBox[{"-", "0.046115682956667625`"}]}], "}"}], ",", 
             "162.72299863031571`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25091868493303154`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8890066728387804`", ",", 
               RowBox[{"-", "0.09789651158066667`"}]}], "}"}], ",", 
             RowBox[{"-", "168.7569145288464`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24723671810648565`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8351104353765613`", ",", 
               RowBox[{"-", "0.10861037831299702`"}]}], "}"}], ",", 
             RowBox[{"-", "161.91763282222166`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2526286762070828`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.289988407633029`", ",", 
               RowBox[{"-", "0.03532566548370465`"}]}], "}"}], ",", 
             RowBox[{"-", "165.7756210865662`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2518754848342481`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2036196140900715`", ",", 
               RowBox[{"-", "0.057219436555797455`"}]}], "}"}], ",", 
             RowBox[{"-", "167.57554260639716`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "97.99818136113194`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6101936044655933`", ",", 
               RowBox[{"-", "0.046115682956667625`"}]}], "}"}], ",", 
             RowBox[{"-", "1.1226455849842414`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "97.60177509251764`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.884424114220212`", ",", 
               RowBox[{"-", "0.05148960539899354`"}]}], "}"}], ",", 
             "1.8976295039709503`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.39480279059446854`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.174745282155764`", ",", 
               RowBox[{"-", "0.04187068499412144`"}]}], "}"}], ",", 
             "128.9790045759383`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2513345117106132`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.304262492718633`", ",", "0.049036549917380684`"}], 
              "}"}], ",", "163.5303299165991`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2506962929360381`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8975987417994986`", ",", "0.16926171893825742`"}], 
              "}"}], ",", "162.831967912781`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24360878025636062`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.631370047670223`", ",", 
               RowBox[{"-", "0.17513360904866818`"}]}], "}"}], ",", 
             RowBox[{"-", "155.078351115597`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.242833156181243`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4272549118351114`", ",", 
               RowBox[{"-", "0.2699744584069052`"}]}], "}"}], ",", 
             RowBox[{"-", "157.1835172333889`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25112453903880644`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9006298519039526`", ",", 
               RowBox[{"-", "0.1239716558766005`"}]}], "}"}], ",", 
             RowBox[{"-", "169.3754641262283`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24956482069046557`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.868778330669892`", ",", 
               RowBox[{"-", "0.12994662473065313`"}]}], "}"}], ",", 
             RowBox[{"-", "165.0087239958643`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.39640626861431016`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.884424114220212`", ",", 
               RowBox[{"-", "0.051489605398993554`"}]}], "}"}], ",", 
             RowBox[{"-", "122.1634704790412`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3952797393161795`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8360941866799445`", ",", 
               RowBox[{"-", "0.12834485163359455`"}]}], "}"}], ",", 
             RowBox[{"-", "123.71085787350205`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "97.20697230192317`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.174745282155764`", ",", 
               RowBox[{"-", "0.04187068499412144`"}]}], "}"}], ",", 
             "4.917904592926143`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "96.92895544545073`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.400554302185327`", ",", 
               RowBox[{"-", "0.022440938596222378`"}]}], "}"}], ",", 
             "6.500867277806664`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2772217142037861`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6946057131986`", ",", "0.011066496590403974`"}], 
              "}"}], ",", "156.98322601508963`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3932057987025339`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9920227327644295`", ",", "0.18394201200307905`"}], 
              "}"}], ",", "131.99927966489335`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.37864452946942234`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9208762860103477`", ",", "0.26296014394196404`"}], 
              "}"}], ",", "141.6708223127207`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014022033641014977`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.774007014814893`", ",", "0.3790719956019406`"}], 
              "}"}], ",", 
             RowBox[{"-", "147.84734321007406`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2500596948032183`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.560781759415158`", ",", "0.27331809425780756`"}], 
              "}"}], ",", "162.13360590896346`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24309711641608542`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.289831266060674`", ",", "0.36065725145027167`"}], 
              "}"}], ",", "170.89452742746315`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.242060001609504`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1508630265649438`", ",", 
               RowBox[{"-", "0.38625248209328467`"}]}], "}"}], ",", 
             RowBox[{"-", "159.2886833511811`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24146099159531187`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1468470929130756`", ",", 
               RowBox[{"-", "0.38777088348810573`"}]}], "}"}], ",", 
             RowBox[{"-", "159.03265085589672`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24801478965239496`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.621793917817546`", ",", 
               RowBox[{"-", "0.19608559386754337`"}]}], "}"}], ",", 
             RowBox[{"-", "160.64198386550044`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24733481050217856`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4268272613564683`", ",", 
               RowBox[{"-", "0.26458365317247373`"}]}], "}"}], ",", 
             RowBox[{"-", "161.97422181508202`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.39415641145142666`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6527301356231905`", ",", 
               RowBox[{"-", "0.40317480552400664`"}]}], "}"}], ",", 
             RowBox[{"-", "125.25824526796242`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.39312627612022405`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6440775948960247`", ",", 
               RowBox[{"-", "0.4154141300939811`"}]}], "}"}], ",", 
             RowBox[{"-", "126.24079112951352`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27801685647241575`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.400554302185327`", ",", 
               RowBox[{"-", "0.02244093859622237`"}]}], "}"}], ",", 
             RowBox[{"-", "142.39852877459577`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.276861944470144`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.332719604913328`", ",", 
               RowBox[{"-", "0.07468346298845327`"}]}], "}"}], ",", 
             RowBox[{"-", "139.28742479020295`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "96.65173373124696`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6946057131986`", ",", "0.011066496590403974`"}], 
              "}"}], ",", "8.083829962687416`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "96.40120163838044`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8241048464905125`", ",", "0.02945966646765053`"}], 
              "}"}], ",", "7.1737310651719275`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24988268568952332`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.136587594956282`", ",", "0.06878987295939468`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.55802920113624`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27642884608225426`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.422212158743575`", ",", "0.12678482713072758`"}], 
              "}"}], ",", "158.56618869997016`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2752680041887159`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.399096479845423`", ",", "0.13585950227795887`"}], 
              "}"}], ",", "155.41845935963823`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014561269233111584`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9208762860103477`", ",", "0.26296014394196404`"}], 
              "}"}], ",", "80.86053048334276`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014523045470901708`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9412780345169445`", ",", "0.3897730672871572`"}], 
              "}"}], ",", "79.84127104818344`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3646224958284075`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.774007014814893`", ",", "0.3790719956019406`"}], 
              "}"}], ",", "151.34236496054803`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.36357353990223545`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.618102085979958`", ",", "0.46427768108364853`"}], 
              "}"}], ",", "152.95733839070454`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013502767120235534`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.615497598354153`", ",", "0.27943610944304614`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.1758005622468`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01339630247316773`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4620287086386394`", ",", "0.14210240451730616`"}], 
              "}"}], ",", 
             RowBox[{"-", "133.11596986466407`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2363284017295186`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1456962410064944`", ",", "0.3837580623745752`"}], 
              "}"}], ",", "179.65544894596277`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23500628659526143`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.137773631112005`", ",", "0.3838057059622634`"}], 
              "}"}], ",", "175.60045386734876`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24665669564257717`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.131967869541339`", ",", 
               RowBox[{"-", "0.36053596551370937`"}]}], "}"}], ",", 
             RowBox[{"-", "163.30645976466417`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24592891512772325`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1317647742058625`", ",", 
               RowBox[{"-", "0.3605968720764497`"}]}], "}"}], ",", 
             RowBox[{"-", "161.55869657428724`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.39209883306744114`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4519109865691275`", ",", 
               RowBox[{"-", "0.6775846688198423`"}]}], "}"}], ",", 
             RowBox[{"-", "127.22333699106424`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.38748365083341024`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3743027929427307`", ",", 
               RowBox[{"-", "0.7797432585536458`"}]}], "}"}], ",", 
             RowBox[{"-", "133.4277386313638`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2757118300968718`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.092110418388803`", ",", 
               RowBox[{"-", "0.2817319083055005`"}]}], "}"}], ",", 
             RowBox[{"-", "136.1763208058099`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27461136868058705`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.023924522203216`", ",", 
               RowBox[{"-", "0.3471739477614017`"}]}], "}"}], ",", 
             RowBox[{"-", "133.2022377107233`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2505320928665387`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8241048464905125`", ",", "0.02945966646765053`"}], 
              "}"}], ",", "168.99539243396458`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24977465691115894`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.69466225720908`", ",", "0.05463155987304365`"}], 
              "}"}], ",", "170.8634348756775`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "96.15131895269093`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.136587594956282`", ",", "0.06878987295939468`"}], 
              "}"}], ",", "6.263632167656039`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "95.67368665723663`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.438567307187545`", ",", "0.1019347427665358`"}], 
              "}"}], ",", "2.5729950956717045`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.47525965395389297`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.639921896520204`", ",", "0.11098310414783293`"}], 
              "}"}], ",", 
             RowBox[{"-", "115.15347791773203`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24923496184846966`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.849864850132244`", ",", 
               RowBox[{"-", "0.06152666793996342`"}]}], "}"}], ",", 
             RowBox[{"-", "156.46812809865094`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24746780161251128`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.788657960453038`", ",", 
               RowBox[{"-", "0.08818067542507849`"}]}], "}"}], ",", 
             RowBox[{"-", "151.71443020697316`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2741120371623301`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1360406816166115`", ",", "0.2561933497483976`"}], 
              "}"}], ",", "152.27073001930643`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27238082007958386`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6179271192659637`", ",", "0.5285467804054872`"}], 
              "}"}], ",", "156.6867818016237`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014484922047197642`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9987729664076967`", ",", "0.7106424299902512`"}], 
              "}"}], ",", "78.82201161302413`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014446851157553332`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.032900255712351`", ",", "0.8833460304798999`"}], 
              "}"}], ",", "79.85148546262442`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3625276016410393`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3555961043193907`", ",", "0.5982774551320276`"}], 
              "}"}], ",", "154.57231182086173`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3609400849938371`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3506237843433677`", ",", "0.6006414315659845`"}], 
              "}"}], ",", "151.28524819024466`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013290677263007516`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.290651511409753`", ",", 
               RowBox[{"-", "0.04093297677543392`"}]}], "}"}], ",", 
             RowBox[{"-", "128.0561391670814`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013103198876517008`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.221579882986132`", ",", 
               RowBox[{"-", "0.12916230350309768`"}]}], "}"}], ",", 
             RowBox[{"-", "121.33118128631894`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3829227914008192`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2171263394543335`", ",", 
               RowBox[{"-", "0.945791594974529`"}]}], "}"}], ",", 
             RowBox[{"-", "139.63214027166347`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3752210699497621`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.109609326425071`", ",", 
               RowBox[{"-", "1.037191798066271`"}]}], "}"}], ",", 
             RowBox[{"-", "147.39938220624856`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2735152995869976`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8359760786024566`", ",", 
               RowBox[{"-", "0.547303048019383`"}]}], "}"}], ",", 
             RowBox[{"-", "130.22815461563647`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2722801779361296`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8081445731435055`", ",", 
               RowBox[{"-", "0.5802043795349205`"}]}], "}"}], ",", 
             RowBox[{"-", "126.84067409247707`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24901951091879346`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.40607822076775`", ",", "0.10104414681572732`"}], 
              "}"}], ",", "172.73147731739024`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23874988737056477`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.34698126031897`", ",", "0.10858164471908821`"}], 
              "}"}], ",", "162.70520433808244`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009846101843310104`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.170700334701458`", ",", "0.1634694739701575`"}], 
              "}"}], ",", "93.6631263170981`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.47763229545424635`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.438567307187545`", ",", "0.1019347427665358`"}], 
              "}"}], ",", "116.60883103709111`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4659181433095814`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.369947045855445`", ",", "0.2389135007740329`"}], 
              "}"}], ",", "124.9769160742884`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01142685716529616`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.256652686999513`", ",", "0.4008534369572916`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.33107958450853`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "95.19842700328273`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.639921896520204`", ",", "0.11098310414783293`"}], 
              "}"}], ",", 
             RowBox[{"-", "1.117641976312827`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "89.56221790895778`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.656117764920519`", ",", "0.11066713884056857`"}], 
              "}"}], ",", "10.150828986860738`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.302518150525389`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.780139413390965`", ",", "0.1328722918237478`"}], 
              "}"}], ",", "74.844806786469`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3139348197610793`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.813078531240988`", ",", "0.25448418525360783`"}], 
              "}"}], ",", "139.53878458607724`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018586465573654988`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.717216724786908`", ",", "0.33624574206176727`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.76723761431447`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.47289879856545575`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.554250872733547`", ",", 
               RowBox[{"-", "0.07146146050772645`"}]}], "}"}], ",", 
             RowBox[{"-", "118.84411498971656`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29646093220014913`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.446013302160968`", ",", 
               RowBox[{"-", "0.26798629236588783`"}]}], "}"}], ",", 
             RowBox[{"-", "138.0847197244957`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11060915040751881`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3289129465642615`", ",", 
               RowBox[{"-", "0.373110817031439`"}]}], "}"}], ",", 
             "170.02511806440685`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04126811604846847`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.173926973483606`", ",", 
               RowBox[{"-", "0.3458526601738012`"}]}], "}"}], ",", 
             "118.13495585330932`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015397075159833136`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.099721637990405`", ",", 
               RowBox[{"-", "0.2070822485170844`"}]}], "}"}], ",", 
             "66.24479364221179`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24571317114074157`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.563160363805937`", ",", 
               RowBox[{"-", "0.2095253732610226`"}]}], "}"}], ",", 
             RowBox[{"-", "146.9607323152954`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24290961227306532`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.435873312302021`", ",", 
               RowBox[{"-", "0.29231063265284085`"}]}], "}"}], ",", 
             RowBox[{"-", "153.07612787808435`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27066053689313274`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3901148833251633`", ",", "0.6267205401047594`"}], 
              "}"}], ",", "161.10283358394096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26979268882356827`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3831584032670334`", ",", "0.629101891221183`"}], 
              "}"}], ",", "158.96697054004673`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014408880330072529`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.087894069184557`", ",", "1.190572550681726`"}], 
              "}"}], ",", "80.88095931222436`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013097169104803217`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.096974615643519`", ",", "1.2471439068332988`"}], 
              "}"}], ",", "68.01907193036958`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.35935952011828964`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1189077061664916`", ",", "0.7275798313596082`"}], 
              "}"}], ",", "147.9981845596276`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29663190931406896`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.962953264961906`", ",", "0.8250378530382365`"}], 
              "}"}], ",", "132.43938067102897`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.051778260816468594`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8527497331871134`", ",", "0.9455596562108208`"}], 
              "}"}], ",", "76.93912426559548`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009038098090585665`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.88965565168125`", ",", "1.1046454086706592`"}], 
              "}"}], ",", "21.438867860162002`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012918365061458454`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1079744812692307`", ",", 
               RowBox[{"-", "0.31578149969126973`"}]}], "}"}], ",", 
             RowBox[{"-", "114.60622340555649`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012883102638388119`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0979082551464243`", ",", 
               RowBox[{"-", "0.3377617363851812`"}]}], "}"}], ",", 
             RowBox[{"-", "115.909892656742`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3676742531286771`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9525382644923193`", ",", 
               RowBox[{"-", "1.1376453192431852`"}]}], "}"}], ",", 
             RowBox[{"-", "155.16662414083362`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.36673044716996733`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9202939341265974`", ",", 
               RowBox[{"-", "1.15256709084685`"}]}], "}"}], ",", 
             RowBox[{"-", "154.35024686425535`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27105063376299215`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6479267674466245`", ",", 
               RowBox[{"-", "0.7940552712029678`"}]}], "}"}], ",", 
             RowBox[{"-", "123.45319356931758`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2703818851158309`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.63352257300137`", ",", 
               RowBox[{"-", "0.8158563100177105`"}]}], "}"}], ",", 
             RowBox[{"-", "123.3228623472928`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010269623548228695`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.34698126031897`", ",", "0.10858164471908821`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.27899062024093`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009694321865884491`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.172131662576525`", ",", 
               RowBox[{"-", "0.04731871164326101`"}]}], "}"}], ",", 
             RowBox[{"-", "149.35212883120582`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2289037855272547`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.170700334701458`", ",", "0.1634694739701575`"}], 
              "}"}], ",", "152.67893135877455`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22394480345779205`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9039351419317736`", ",", "0.3012815070009306`"}], 
              "}"}], ",", "160.66945350391038`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009440046273707401`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.158904414755697`", ",", "0.34772064712543155`"}], 
              "}"}], ",", "83.63685333779014`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009410693493085256`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.186709549300818`", ",", "0.5970566748280117`"}], 
              "}"}], ",", "81.63744350236784`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01171415214466485`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.369947045855445`", ",", "0.2389135007740329`"}], 
              "}"}], ",", "56.65299677028256`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011681430313760297`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.4363474180854485`", ",", "0.33981791682190754`"}], 
              "}"}], ",", "58.1006967434753`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.45449128614428513`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.256652686999513`", ",", "0.4008534369572916`"}], 
              "}"}], ",", "133.34500111148574`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.45276369280189577`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.169280136629371`", ",", "0.4934251559499546`"}], 
              "}"}], ",", "136.1466207244527`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01114660822768542`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.072982639363519`", ",", "0.3278776308226116`"}], 
              "}"}], ",", 
             RowBox[{"-", "149.9629945473111`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0105900679858363`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8388393340441525`", ",", "0.1924932213145497`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.63594447027515`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.636209094324948`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.656117764920519`", ",", "0.11066713884056856`"}], 
              "}"}], ",", 
             RowBox[{"-", "43.27467784957392`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.60526256904622`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.050783306785948`", ",", 
               RowBox[{"-", "0.26091767258249676`"}]}], "}"}], ",", 
             RowBox[{"-", "39.27626490589177`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03077660833441297`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.266462557308947`", ",", 
               RowBox[{"-", "0.4372999424005015`"}]}], "}"}], ",", 
             "74.49814414737492`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "84.25969975843235`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.780139413390965`", ",", "0.1328722918237478`"}], 
              "}"}], ",", "21.4192999500343`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "84.04839455874071`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.078954373256245`", ",", "0.2500927233677525`"}], 
              "}"}], ",", "20.887716596406044`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21077529171018483`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.385877384362597`", ",", "0.3672198357910872`"}], 
              "}"}], ",", 
             RowBox[{"-", "148.96718464193205`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.988583330764308`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.813078531240988`", ",", "0.25448418525360783`"}], 
              "}"}], ",", "86.11327774964256`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.9103689088356735`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.826683256183537`", ",", "0.45472933508594915`"}], 
              "}"}], ",", "79.08137506106505`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07698812271861409`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.865410312505054`", ",", "0.6554846140465254`"}], 
              "}"}], ",", 
             RowBox[{"-", "5.827173037930592`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2953483541874244`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.717216724786908`", ",", "0.33624574206176727`"}], 
              "}"}], ",", "150.80725554925078`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29454855432140103`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.623040498948695`", ",", "0.3888634059114886`"}], 
              "}"}], ",", "149.5567004019632`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017486056569061072`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.602324795163315`", ",", "0.28453227557864835`"}], 
              "}"}], ",", 
             RowBox[{"-", "144.49876665114095`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01646435116614683`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.11645815730649`", ",", 
               RowBox[{"-", "0.0620488094172342`"}]}], "}"}], ",", 
             RowBox[{"-", "155.7205016576415`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17643786636530676`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.446013302160968`", ",", 
               RowBox[{"-", "0.26798629236588783`"}]}], "}"}], ",", 
             RowBox[{"-", "105.43516224817738`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17463190914910087`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.408512329344934`", ",", 
               RowBox[{"-", "0.4038070907651124`"}]}], "}"}], ",", 
             RowBox[{"-", "99.62983024723385`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18585178179263037`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3289129465642615`", ",", 
               RowBox[{"-", "0.373110817031439`"}]}], "}"}], ",", 
             RowBox[{"-", "157.32532445927447`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18539225864127637`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.142156563325427`", ",", 
               RowBox[{"-", "0.4511357329145888`"}]}], "}"}], ",", 
             RowBox[{"-", "157.0979639125431`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0693410343590504`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.173926973483606`", ",", 
               RowBox[{"-", "0.3458526601738012`"}]}], "}"}], ",", 
             "150.78451332962814`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06854912906343096`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.873260489996408`", ",", 
               RowBox[{"-", "0.17770917402864797`"}]}], "}"}], ",", 
             "156.90255342611383`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02587104088863533`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.099721637990405`", ",", 
               RowBox[{"-", "0.2070822485170844`"}]}], "}"}], ",", 
             "98.89435111853062`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025765386163769534`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.082806838587439`", ",", 
               RowBox[{"-", "0.0989968810419743`"}]}], "}"}], ",", 
             "101.94743782844047`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009652448407327154`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.163112851191095`", ",", 
               RowBox[{"-", "0.0630502622918786`"}]}], "}"}], ",", 
             "47.00418890743301`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00946646097670723`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5353880389761905`", ",", "0.33622452132097363`"}], 
              "}"}], ",", "54.64338610223961`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24013804168785682`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.2072759558879405`", ",", 
               RowBox[{"-", "0.40840447476237973`"}]}], "}"}], ",", 
             RowBox[{"-", "159.19152344087348`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2395460462025737`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.122525323515495`", ",", 
               RowBox[{"-", "0.44061256833959456`"}]}], "}"}], ",", 
             RowBox[{"-", "159.25251202485632`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26892762342886484`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.118958057251666`", ",", "0.730693687402561`"}], 
              "}"}], ",", "156.83110749615233`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2536702204654676`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.874401641472924`", ",", "0.8353535702065428`"}], 
              "}"}], ",", "167.94883365120558`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014391785879441892`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.700765721031118`", ",", "0.872423121498889`"}], 
              "}"}], ",", 
             RowBox[{"-", "126.88176117854904`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011904869402086862`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1566020874311045`", ",", "1.3948686334667941`"}], 
              "}"}], ",", "55.15718454851467`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01184349004149321`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.288513573205669`", ",", "1.5843620745615243`"}], 
              "}"}], ",", "58.9632777752423`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06272761080422067`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.962953264961906`", ",", "0.8250378530382365`"}], 
              "}"}], ",", "172.38083318786389`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06179549669042663`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.872577200713656`", ",", "0.8371273671687086`"}], 
              "}"}], ",", "179.2566230082061`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2448536484976005`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8527497331871134`", ",", "0.9455596562108208`"}], 
              "}"}], ",", "116.88057678243038`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24418185216005425`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.799054144884693`", ",", "1.0514884273813996`"}], 
              "}"}], ",", "115.5437171841801`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04274016272588291`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.88965565168125`", ",", "1.1046454086706592`"}], 
              "}"}], ",", "61.38032037699672`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.036462914946855426`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8897054905365716`", ",", "1.104736744939623`"}], 
              "}"}], ",", "76.18653664302838`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012847936468866497`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.964069326973405`", ",", 
               RowBox[{"-", "0.6132710566160591`"}]}], "}"}], ",", 
             RowBox[{"-", "117.2135619079281`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012780536450395506`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9168138999373223`", ",", 
               RowBox[{"-", "0.7051666635248719`"}]}], "}"}], ",", 
             RowBox[{"-", "121.0729872252619`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3657890639256037`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6545398615910583`", ",", 
               RowBox[{"-", "1.280178969740208`"}]}], "}"}], ",", 
             RowBox[{"-", "153.53386958767712`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.36018625998912585`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.503822008840952`", ",", 
               RowBox[{"-", "1.3552129096803736`"}]}], "}"}], ",", 
             RowBox[{"-", "146.56996031241633`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26971478643623065`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4528534018009265`", ",", 
               RowBox[{"-", "1.0906598151282794`"}]}], "}"}], ",", 
             RowBox[{"-", "123.19253112527082`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26736266828727917`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3747794230132278`", ",", 
               RowBox[{"-", "1.2100033118374303`"}]}], "}"}], ",", 
             RowBox[{"-", "128.54092226365026`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009151248436518955`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.0215053031803265`", ",", 
               RowBox[{"-", "0.1365688422437436`"}]}], "}"}], ",", 
             RowBox[{"-", "160.4252670421708`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00912865539563651`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8714170205849907`", ",", 
               RowBox[{"-", "0.1899383071354556`"}]}], "}"}], ",", 
             RowBox[{"-", "160.59116279077304`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21909325300248375`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7095927179649006`", ",", "0.3694555953323202`"}], 
              "}"}], ",", "168.6599756490462`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.218184456874832`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5830711532181354`", ",", "0.39482902294536726`"}], 
              "}"}], ",", "165.55386651645475`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009381431981690535`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.232349480833086`", ",", "0.9075335520499725`"}], 
              "}"}], ",", "79.63803366694611`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009354671397241844`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.269784719445412`", ",", "1.1122674644837052`"}], 
              "}"}], ",", "81.20635545623976`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011648799886672645`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.618099162223654`", ",", "0.631822219651038`"}], 
              "}"}], ",", "59.54839671666803`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011610786720315793`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.645647895609862`", ",", "0.6786811532817432`"}], 
              "}"}], ",", "57.33736383394778`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4510426663153465`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.9705929431190015`", ",", "0.6843149737851442`"}], 
              "}"}], ",", "138.94824033741924`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4455559388258916`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.899941011965765`", ",", "0.7458439041177413`"}], 
              "}"}], ",", "145.24697692078274`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010061315303617036`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.698679316809952`", ",", "0.14323389961481361`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.30889439323923`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010013157072089955`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.655763772139483`", ",", "0.1366737163587785`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.73493909721176`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030946525278727734`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.050783306785948`", ",", 
               RowBox[{"-", "0.26091767258249676`"}]}], "}"}], ",", 
             RowBox[{"-", "149.05226101547626`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029968592048010056`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.883599341133357`", ",", 
               RowBox[{"-", "0.36116449926156435`"}]}], "}"}], ",", 
             RowBox[{"-", "158.2123571374608`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.5744859607118045`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.266462557308947`", ",", 
               RowBox[{"-", "0.4372999424005015`"}]}], "}"}], ",", 
             RowBox[{"-", "35.27785196220935`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.553628102947669`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.381514964835767`", ",", 
               RowBox[{"-", "0.5186948359539496`"}]}], "}"}], ",", 
             RowBox[{"-", "32.533331021087314`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02077981465243545`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.639330255385841`", ",", 
               RowBox[{"-", "0.6831522198358223`"}]}], "}"}], ",", 
             "98.69443094718983`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03060762434679379`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.340928797522072`", ",", 
               RowBox[{"-", "0.1688171249226691`"}]}], "}"}], ",", 
             "78.49655709105726`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0303439986044081`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.364726631954419`", ",", 
               RowBox[{"-", "0.05188299846126178`"}]}], "}"}], ",", 
             "73.18366973126003`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2113051996916409`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.078954373256245`", ",", "0.2500927233677525`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.78896551888397`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21067610754528882`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8171415788764795`", ",", "0.2029331101765597`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.58181478702485`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "83.83761926703055`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.385877384362597`", ",", "0.3672198357910872`"}], 
              "}"}], ",", "20.35613324277711`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "79.87033702506476`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.46397806998668`", ",", "0.3961971742504616`"}], 
              "}"}], ",", "30.84540105065904`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.7795463720183426`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5901068238903555`", ",", "0.4715205258808095`"}], 
              "}"}], ",", "98.14750745204253`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17885201578345836`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.569286664841523`", ",", "0.616946076728329`"}], 
              "}"}], ",", "165.44961385342606`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008463461061525249`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.427090072857617`", ",", "0.65385405811834`"}], "}"}],
              ",", 
             RowBox[{"-", "127.24827974519039`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21024671262394828`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.10438412011554`", ",", "0.19786211558100952`"}], 
              "}"}], ",", 
             RowBox[{"-", "149.49876799556029`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20888941283739879`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.081452134150184`", ",", "0.18435347933583313`"}], 
              "}"}], ",", 
             RowBox[{"-", "145.01829444482533`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07821442192863452`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.826683256183537`", ",", "0.45472933508594915`"}], 
              "}"}], ",", "156.95802047148322`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07791643761151348`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.668343071788032`", ",", "0.5220777142812463`"}], 
              "}"}], ",", "159.76783695926608`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.833380786117062`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.865410312505054`", ",", "0.6554846140465254`"}], 
              "}"}], ",", "72.04947237248746`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.725890388587162`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.865531100028655`", ",", "0.6558574549179828`"}], 
              "}"}], ",", "80.11923306814161`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10509989984878894`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.898362925789411`", ",", "0.8443488925545409`"}], 
              "}"}], ",", "158.46511729836496`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07578105026646675`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.068810334202852`", ",", "0.6347265289902424`"}], 
              "}"}], ",", 
             RowBox[{"-", "12.859075726508376`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07559040039126813`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.345098640148805`", ",", "0.5716557199086093`"}], 
              "}"}], ",", 
             RowBox[{"-", "13.437721493465014`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29375092030399896`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.324433384014403`", ",", "0.5643586341087806`"}], 
              "}"}], ",", "148.30614525467564`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2898582568283681`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.25685805736425`", ",", "0.6060839947188786`"}], 
              "}"}], ",", "141.76150744647595`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015502343724646688`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.960778241183477`", ",", 
               RowBox[{"-", "0.13227393548212468`"}]}], "}"}], ",", 
             RowBox[{"-", "166.94223666414194`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0154576254827468`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.862506407101621`", ",", 
               RowBox[{"-", "0.15506615480032948`"}]}], "}"}], ",", 
             RowBox[{"-", "165.31265470439195`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17284443708879696`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.368665699292367`", ",", 
               RowBox[{"-", "0.6386508757579388`"}]}], "}"}], ",", 
             RowBox[{"-", "93.82449824629026`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.159651211132068`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.346770984931949`", ",", 
               RowBox[{"-", "0.966173849270861`"}]}], "}"}], ",", 
             RowBox[{"-", "81.63151815193689`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012186186250522457`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.370658469300976`", ",", 
               RowBox[{"-", "1.1285576357412543`"}]}], "}"}], ",", 
             RowBox[{"-", "19.579294257533935`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18493387167233927`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.862033541413417`", ",", 
               RowBox[{"-", "0.5694760611249675`"}]}], "}"}], ",", 
             RowBox[{"-", "156.87060336581652`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18385079305088364`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.843546772902948`", ",", 
               RowBox[{"-", "0.577372549175145`"}]}], "}"}], ",", 
             RowBox[{"-", "152.6782050284165`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0677662676767037`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6598052417380575`", ",", 
               RowBox[{"-", "0.08667403832027229`"}]}], "}"}], ",", 
             "163.02059352259943`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06746903671021276`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.644180013893946`", ",", 
               RowBox[{"-", "0.08190306712637067`"}]}], "}"}], ",", 
             "159.7282029139003`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025660162922156938`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.023892590390386`", ",", "0.17942858185625332`"}], 
              "}"}], ",", "105.00052453835055`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025504774974547464`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.963593281354314`", ",", "0.40446042622468326`"}], 
              "}"}], ",", "100.7087045107558`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009284057230028295`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.668226346046645`", ",", "0.5234462570138415`"}], 
              "}"}], ",", "62.282583297046116`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00925969124989129`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.7218301323823555`", ",", "0.6254710583343828`"}], 
              "}"}], ",", "63.30017497111`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23895551012227334`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.836599226409276`", ",", 
               RowBox[{"-", "0.5489259410795577`"}]}], "}"}], ",", 
             RowBox[{"-", "159.31350060884515`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23621957715124342`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.669827641570253`", ",", 
               RowBox[{"-", "0.6118987683239112`"}]}], "}"}], ",", 
             RowBox[{"-", "165.43881906205675`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015257402963397159`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.874401641472924`", ",", "0.8353535702065428`"}], 
              "}"}], ",", "113.89715463601347`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015213052704004033`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7800941570748763`", ",", "1.048199041125198`"}], 
              "}"}], ",", "112.22673403336411`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2392784345860258`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.700765721031118`", ",", "0.872423121498889`"}], 
              "}"}], ",", "179.06655980625877`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2365152442046992`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.540332325001979`", ",", "0.8750370702415957`"}], 
              "}"}], ",", "172.9167519078222`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013575278918476414`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.594207019314376`", ",", "0.7304061239629206`"}], 
              "}"}], ",", 
             RowBox[{"-", "115.76403502349586`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013541004802550265`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5653768335927825`", ",", "0.67067236065996`"}], 
              "}"}], ",", 
             RowBox[{"-", "116.39098034934581`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011782427141818165`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.434230233882032`", ",", "1.8265236218852379`"}], 
              "}"}], ",", "62.76937100196972`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011752149891347843`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.442488502570082`", ",", "1.842571367732075`"}], 
              "}"}], ",", "61.9422705343557`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06087723352217307`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.647719817861916`", ",", "0.8400449151302908`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.86758717145162`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06072655287750267`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4122339635400483`", ",", "0.8147439907309327`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.60495077281456`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24351189900647474`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.651432219296955`", ",", "1.3603774696099153`"}], 
              "}"}], ",", "114.20685758592926`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24218263486516475`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6317869098812796`", ",", "1.4040762764764532`"}], 
              "}"}], ",", "118.1875788017513`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031107606560806533`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9294255861950274`", ",", "1.2662841266646672`"}], 
              "}"}], ",", "90.99275290905999`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031008827758712634`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9280989752410815`", ",", "1.3428405400690842`"}], 
              "}"}], ",", "88.89932293449291`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012713490011077166`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7903414601329137`", ",", 
               RowBox[{"-", "0.9150460813852921`"}]}], "}"}], ",", 
             RowBox[{"-", "124.93241254259587`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012654263035535213`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4842168326986034`", ",", 
               RowBox[{"-", "1.3533368486914512`"}]}], "}"}], ",", 
             RowBox[{"-", "121.44462000690558`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3546692743972801`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.335531677235352`", ",", 
               RowBox[{"-", "1.4663065767668944`"}]}], "}"}], ",", 
             RowBox[{"-", "139.60605103715554`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2779633196139141`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1968282486405424`", ",", 
               RowBox[{"-", "1.5843271908251064`"}]}], "}"}], ",", 
             RowBox[{"-", "123.07222913717686`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.060116405239702936`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.122821027838444`", ",", 
               RowBox[{"-", "1.6979744077857233`"}]}], "}"}], ",", 
             RowBox[{"-", "68.8090335282522`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013001651383225262`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.17184458169658`", ",", 
               RowBox[{"-", "1.8244238040708087`"}]}], "}"}], ",", 
             RowBox[{"-", "14.545837919327456`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2650310623981845`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2175576221075644`", ",", 
               RowBox[{"-", "1.407368696474002`"}]}], "}"}], ",", 
             RowBox[{"-", "133.88931340202993`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26402217744730205`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1691153892197756`", ",", 
               RowBox[{"-", "1.4577264201050941`"}]}], "}"}], ",", 
             RowBox[{"-", "136.69613864469306`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009106118133536577`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5497612598705612`", ",", 
               RowBox[{"-", "0.30326694863810244`"}]}], "}"}], ",", 
             RowBox[{"-", "160.75705853937313`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00902536925074922`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.404192993676753`", ",", 
               RowBox[{"-", "0.35408154355463156`"}]}], "}"}], ",", 
             RowBox[{"-", "166.1531207059948`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2172794304223771`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3199501454438773`", ",", "0.46261288869489703`"}], 
              "}"}], ",", "162.4477573838632`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21673588577882225`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1817374130547575`", ",", "0.5063297872396552`"}], 
              "}"}], ",", "162.9398464571576`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009327987147502123`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.316627609022407`", ",", "1.4150762881589727`"}], 
              "}"}], ",", "82.77467724553435`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009294433670189554`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.339192280199492`", ",", "1.5930613960057278`"}], 
              "}"}], ",", "85.37316282951504`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011572897601142393`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.799127858721389`", ",", "0.9180940447729026`"}], 
              "}"}], ",", "55.12633095122784`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011321684154192444`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.0516089093221535`", ",", "1.2803718303013756`"}], 
              "}"}], ",", "47.1298208691403`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4401359548638054`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.71671549254766`", ",", "0.8729662902272273`"}], 
              "}"}], ",", "151.5457135041463`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4390147261340071`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.656340914544981`", ",", "0.9056846679963191`"}], 
              "}"}], ",", "150.81056004270977`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009965229348721485`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.397708205712049`", ",", "0.08057332563951655`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.1609838011843`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009936213526491131`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.189373374273458`", ",", "0.021467253382598736`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.84027431247813`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02902156223520853`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.734567675388738`", ",", 
               RowBox[{"-", "0.42073563195442343`"}]}], "}"}], ",", 
             RowBox[{"-", "167.37245325944534`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028924509565415823`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.628213718193005`", ",", 
               RowBox[{"-", "0.444562251532586`"}]}], "}"}], ",", 
             RowBox[{"-", "165.05974074722164`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020857857764136536`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.381514964835767`", ",", 
               RowBox[{"-", "0.5186948359539496`"}]}], "}"}], ",", 
             RowBox[{"-", "161.01657204824238`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020806130667997542`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.911232301346223`", ",", 
               RowBox[{"-", "0.6804740080385091`"}]}], "}"}], ",", 
             RowBox[{"-", "161.33383337344577`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.532848288295237`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.639330255385841`", ",", 
               RowBox[{"-", "0.6831522198358223`"}]}], "}"}], ",", 
             RowBox[{"-", "29.788810079964883`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.517424936317343`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.6616951298003775`", ",", 
               RowBox[{"-", "0.6959549043217395`"}]}], "}"}], ",", 
             RowBox[{"-", "31.224146676713374`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01538035788627458`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.903791814934578`", ",", 
               RowBox[{"-", "0.8427133549804139`"}]}], "}"}], ",", 
             "175.66265768454178`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02070206355189626`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.593103752960103`", ",", 
               RowBox[{"-", "0.3808641690826178`"}]}], "}"}], ",", 
             "101.43895188831199`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020218071203846697`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.585937710344732`", ",", 
               RowBox[{"-", "0.34544883692820877`"}]}], "}"}], ",", 
             "93.21730160903196`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030082643490126744`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.435475922970339`", ",", "0.18220880631998992`"}], 
              "}"}], ",", "67.8707823714628`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02978984769763544`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5277167916844`", ",", "0.4090387728449872`"}], "}"}],
              ",", "73.5325316406815`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21004888831512233`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.593901268418461`", ",", "0.1698954461074504`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.37466405516616`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09602529295412246`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5368369334040395`", ",", "0.16326730455128366`"}], 
              "}"}], ",", 
             RowBox[{"-", "152.06113200950438`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.052126670300655`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.447483270690153`", ",", "0.11587933936681133`"}], 
              "}"}], ",", 
             RowBox[{"-", "101.18825640636696`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028296604707378912`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.42785836360701`", ",", "0.016659586763362176`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.315380803229495`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015360617383527722`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.492443700937656`", ",", 
               RowBox[{"-", "0.06117633352154406`"}]}], "}"}], ",", 
             "0.557494799907982`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008338405573499956`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.593580874204508`", ",", 
               RowBox[{"-", "0.06019222565020976`"}]}], "}"}], ",", 
             "51.430370403045465`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.9672822419658496`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.46397806998668`", ",", "0.3961971742504616`"}], 
              "}"}], ",", 
             RowBox[{"-", "25.967437542842497`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.9572924151053797`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.612509852193087`", ",", "0.3238578492146921`"}], 
              "}"}], ",", 
             RowBox[{"-", "26.558633762487858`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009964671947203912`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.898387262851132`", ",", "0.1809591662737341`"}], 
              "}"}], ",", "164.71606333937373`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "76.09079065304638`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5901068238903555`", ",", "0.47152052588080956`"}], 
              "}"}], ",", "41.33466885854101`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "75.78805238539758`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.7103606959140265`", ",", "0.5772951254941001`"}], 
              "}"}], ",", "44.2976736494366`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.30153377945895193`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.935844594623621`", ",", "0.7973177727561169`"}], 
              "}"}], ",", "172.22598883106838`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.6006943562348837`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.569286664841523`", ",", "0.616946076728329`"}], 
              "}"}], ",", "108.63677525992458`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.591139600561047`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.4874006132775435`", ",", "0.8597499173682634`"}], 
              "}"}], ",", "107.53199655203302`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009529401298553416`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.385731150277527`", ",", "1.1815774722078438`"}], 
              "}"}], ",", 
             RowBox[{"-", "51.59229888861741`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1703885547219331`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.427090072857617`", ",", "0.65385405811834`"}], "}"}],
              ",", "175.938881661308`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16967267903905908`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.407772164511959`", ",", "0.6552256069035045`"}], 
              "}"}], ",", "172.78954484994117`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008062961392420711`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.338170829330356`", ",", "0.5369120297766741`"}], 
              "}"}], ",", 
             RowBox[{"-", "116.75901193730849`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008042596384623464`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.29429118719413`", ",", "0.4498904721833331`"}], 
              "}"}], ",", 
             RowBox[{"-", "116.12688646104385`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2075408754361802`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.850888149584709`", ",", "0.023020528021387654`"}], 
              "}"}], ",", 
             RowBox[{"-", "140.5378208940903`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20455874324321377`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.152008776889274`", ",", 
               RowBox[{"-", "0.5523167722276326`"}]}], "}"}], ",", 
             RowBox[{"-", "147.3162158120979`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07761958856652082`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.367192815857526`", ",", "0.6330714094465906`"}], 
              "}"}], ",", "162.57765344704893`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07727506301232216`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.339669363981522`", ",", "0.6417085268261644`"}], 
              "}"}], ",", "159.24623564175045`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10749039752990319`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.865531100028655`", ",", "0.6558574549179828`"}], 
              "}"}], ",", "9.843109533572385`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.10385264082103`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.866032082750782`", ",", "0.6559443778978106`"}], 
              "}"}], ",", "0.4635918467535744`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.62079048873837`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.898362925789411`", ",", "0.8443488925545409`"}], 
              "}"}], ",", "88.18899376379582`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.5302938238138175`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.899262128321833`", ",", "0.8727879726536775`"}], 
              "}"}], ",", "80.50127827280868`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08872431744798197`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.934985647022961`", ",", "1.0862925640458698`"}], 
              "}"}], ",", 
             RowBox[{"-", "0.10736642999356864`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10276256486215848`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.720389387508421`", ",", "0.9145797299183803`"}], 
              "}"}], ",", "166.53487799401907`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10250354332498902`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.666533260694018`", ",", "0.9274747733141636`"}], 
              "}"}], ",", "165.92991393404552`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07540023015279645`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.601759200889874`", ",", "0.5103319550200578`"}], 
              "}"}], ",", 
             RowBox[{"-", "14.01636726042354`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07518882025403502`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.839475126009467`", ",", "0.4509905851077668`"}], 
              "}"}], ",", 
             RowBox[{"-", "12.54648369278691`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2860171772896278`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.090506017080307`", ",", "0.737171203163886`"}], 
              "}"}], ",", "135.21686963827628`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28287139440904074`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.991659151421143`", ",", "0.8352725985202283`"}], 
              "}"}], ",", "129.2063833067123`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015413036235610177`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.561073218499606`", ",", 
               RowBox[{"-", "0.23407451704225998`"}]}], "}"}], ",", 
             RowBox[{"-", "163.68307274464172`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01535772897019159`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.44134789660697`", ",", 
               RowBox[{"-", "0.2691230503460128`"}]}], "}"}], ",", 
             RowBox[{"-", "166.2723787748419`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013193225956728961`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.346770984931949`", ",", 
               RowBox[{"-", "0.966173849270861`"}]}], "}"}], ",", 
             RowBox[{"-", "131.49076195198654`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013111306819803749`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.040126630241996`", ",", 
               RowBox[{"-", "1.3128848690005974`"}]}], "}"}], ",", 
             RowBox[{"-", "127.12485544671159`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14746502488154556`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.370658469300976`", ",", 
               RowBox[{"-", "1.1285576357412543`"}]}], "}"}], ",", 
             RowBox[{"-", "69.43853805758356`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1470860527947584`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.461859781943019`", ",", 
               RowBox[{"-", "1.371691218610847`"}]}], "}"}], ",", 
             RowBox[{"-", "68.6105958527151`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011256013943783253`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.525299534917696`", ",", 
               RowBox[{"-", "1.1835598797215485`"}]}], "}"}], ",", 
             RowBox[{"-", "7.386314163180548`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011228016663161554`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.600761982400861`", ",", 
               RowBox[{"-", "1.1933424117791065`"}]}], "}"}], ",", 
             RowBox[{"-", "7.00062483963788`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18277405755786433`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.62020904994084`", ",", 
               RowBox[{"-", "0.6927533534632233`"}]}], "}"}], ",", 
             RowBox[{"-", "148.48580669101665`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18113716219857534`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.421059584571563`", ",", 
               RowBox[{"-", "0.814860172281644`"}]}], "}"}], ",", 
             RowBox[{"-", "153.91015702773728`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06717310943434061`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.3916852340172055`", ",", "0.011356320668955004`"}], 
              "}"}], ",", "156.43581230520104`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06609561949505885`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.165796928560684`", ",", "0.1098764015693789`"}], 
              "}"}], ",", "163.5343212946823`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025350327995798387`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.917328532690551`", ",", "0.6491059597694256`"}], 
              "}"}], ",", "96.41688448316104`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02507899940711894`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.891472330682532`", ",", "0.879007572435998`"}], 
              "}"}], ",", "90.48413197987007`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009235389218195503`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.856008136082876`", ",", "0.892256352907218`"}], 
              "}"}], ",", "64.31776664517353`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009064769491379732`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.877142979456383`", ",", "0.9362061847735541`"}], 
              "}"}], ",", "56.80355173133095`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23351496938053268`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.440801978911579`", ",", 
               RowBox[{"-", "0.6713898163737759`"}]}], "}"}], ",", 
             RowBox[{"-", "171.5641375152683`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23255393365007304`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3397884269225475`", ",", 
               RowBox[{"-", "0.6863708108810382`"}]}], "}"}], ",", 
             RowBox[{"-", "168.484723657966`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015168831362062506`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.652262238794404`", ",", "1.3610242766510867`"}], 
              "}"}], ",", "110.55631343071475`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01506031858180493`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.634322296068684`", ",", "1.4088634427580893`"}], 
              "}"}], ",", "115.33576240762893`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2337839631807564`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3652191267041047`", ",", "0.8967965807865681`"}], 
              "}"}], ",", "166.7669440093856`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21848697272013848`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3584371703534224`", ",", "0.8983914028520312`"}], 
              "}"}], ",", "178.3939225001021`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014296075282482465`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.22879531666272`", ",", "0.9020263899058154`"}], 
              "}"}], ",", 
             RowBox[{"-", "117.99064192160036`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01350681722002278`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.423048150401369`", ",", "0.3838397198217184`"}], 
              "}"}], ",", 
             RowBox[{"-", "117.01792567519519`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01347350134962201`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.070299296037435`", ",", 
               RowBox[{"-", "0.3079337586645584`"}]}], "}"}], ",", 
             RowBox[{"-", "116.90517343317211`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011721950444193009`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.592996513027466`", ",", "2.1249490237982482`"}], 
              "}"}], ",", "61.11517006674166`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01168525852973367`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.611110226660915`", ",", "2.157782503145335`"}], 
              "}"}], ",", "59.08555403376247`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24086062680934622`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.495720909980971`", ",", "1.6579704444939585`"}], 
              "}"}], ",", "122.16830001757351`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23591873599117533`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4243203082646443`", ",", "1.7714919169140946`"}], 
              "}"}], ",", "129.9952148554264`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03091036261790038`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9343541138804152`", ",", "1.6684119244566258`"}], 
              "}"}], ",", "86.80589295992618`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03082021752639167`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.944238569475594`", ",", "1.8455352239882736`"}], 
              "}"}], ",", "85.11827292706349`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012595311974366787`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3495590308742202`", ",", 
               RowBox[{"-", "1.5735559140602946`"}]}], "}"}], ",", 
             RowBox[{"-", "117.95682747121529`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012564226001410135`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.344019420635874`", ",", 
               RowBox[{"-", "1.5839933710191287`"}]}], "}"}], ",", 
             RowBox[{"-", "118.10626850177142`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21784691437421075`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.122821027838444`", ",", 
               RowBox[{"-", "1.6979744077857233`"}]}], "}"}], ",", 
             RowBox[{"-", "106.53840723719836`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21729486882195345`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0942813412035988`", ",", 
               RowBox[{"-", "1.7940861426641752`"}]}], "}"}], ",", 
             RowBox[{"-", "107.21207851171971`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04711475385647763`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.17184458169658`", ",", 
               RowBox[{"-", "1.8244238040708087`"}]}], "}"}], ",", 
             RowBox[{"-", "52.275211628273794`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0386882498429953`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3314998299859577`", ",", 
               RowBox[{"-", "2.030808955936765`"}]}], "}"}], ",", 
             RowBox[{"-", "36.60810887479941`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010189724455510725`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3031174647941777`", ",", 
               RowBox[{"-", "1.8584853486187098`"}]}], "}"}], ",", 
             "1.9879839806507893`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01011723167946918`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3538526555372528`", ",", 
               RowBox[{"-", "1.856724289753587`"}]}], "}"}], ",", 
             RowBox[{"-", "2.775487782526721`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26301713298528495`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9545503044322277`", ",", 
               RowBox[{"-", "1.6599496305216161`"}]}], "}"}], ",", 
             RowBox[{"-", "139.50296388735643`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2616521920850118`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8843245852369903`", ",", 
               RowBox[{"-", "1.7199217785169294`"}]}], "}"}], ",", 
             RowBox[{"-", "143.32915135264645`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008945336412051759`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1711990803001635`", ",", 
               RowBox[{"-", "0.4115125146935025`"}]}], "}"}], ",", 
             RowBox[{"-", "171.54918287261643`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008922328194784484`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1507501855607156`", ",", 
               RowBox[{"-", "0.41455067932681255`"}]}], "}"}], ",", 
             RowBox[{"-", "170.71280279542464`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21619370086259623`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8956096724243867`", ",", "0.5941363996724759`"}], 
              "}"}], ",", "163.43193553045052`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21533601896397675`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.874159596136431`", ",", "0.6005179289230769`"}], 
              "}"}], ",", "160.47897165357705`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009261000887279972`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.3638619846663005`", ",", "1.897890825549716`"}], 
              "}"}], ",", "87.97164841349573`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009097216469408765`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.3728757462880425`", ",", "2.152400317364623`"}], 
              "}"}], ",", "95.3567774012162`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01107592380966364`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.186980434491088`", ",", "1.4262010764902882`"}], 
              "}"}], ",", "39.133310787052736`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010822634391580802`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.350438183835544`", ",", "1.5591974553303574`"}], 
              "}"}], ",", "30.978872389036407`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.43789635368952373`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.3477706183017695`", ",", "1.0780641496062522`"}], 
              "}"}], ",", "150.07540658127277`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4333137727847597`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.284510727295245`", ",", "1.1144763410521983`"}], 
              "}"}], ",", "144.2068681317708`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00990728218981653`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.886363500432843`", ",", 
               RowBox[{"-", "0.05497944326763965`"}]}], "}"}], ",", 
             RowBox[{"-", "167.519564823772`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00970568834935842`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.766450187298416`", ",", 
               RowBox[{"-", "0.08152062867129992`"}]}], "}"}], ",", 
             RowBox[{"-", "159.71753168807584`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028827781455019248`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.335781837376667`", ",", 
               RowBox[{"-", "0.5225924266413898`"}]}], "}"}], ",", 
             RowBox[{"-", "162.74702823499794`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028607857665319522`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1406776893927555`", ",", 
               RowBox[{"-", "0.5831849702109122`"}]}], "}"}], ",", 
             RowBox[{"-", "167.71207700848728`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02075453185408701`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.624663377518157`", ",", 
               RowBox[{"-", "0.777283667465705`"}]}], "}"}], ",", 
             RowBox[{"-", "161.65109469865143`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017174531323319905`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.285262011497718`", ",", 
               RowBox[{"-", "0.8898514129071506`"}]}], "}"}], ",", 
             RowBox[{"-", "177.1572020131803`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015423351977895943`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.6616951298003775`", ",", 
               RowBox[{"-", "0.6959549043217395`"}]}], "}"}], ",", 
             "120.45371236528294`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015384292576962095`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.649809728695999`", ",", 
               RowBox[{"-", "0.6757401709390647`"}]}], "}"}], ",", 
             "121.11956115803216`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.502044578431068`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.903791814934578`", ",", 
               RowBox[{"-", "0.8427133549804139`"}]}], "}"}], ",", 
             RowBox[{"-", "32.659483273462115`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.400012755553523`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.952683447459978`", ",", 
               RowBox[{"-", "0.8740524240884584`"}]}], "}"}], ",", 
             RowBox[{"-", "40.184875332326214`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10013970936750122`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.098021325764257`", ",", 
               RowBox[{"-", "0.9968067045346964`"}]}], "}"}], ",", 
             RowBox[{"-", "121.80705962635722`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015337483644859371`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.621496895843233`", ",", 
               RowBox[{"-", "0.8213024594383405`"}]}], "}"}], ",", 
             "174.22732108779306`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015298968107760425`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.386503912598267`", ",", 
               RowBox[{"-", "0.79754594807913`"}]}], "}"}], ",", 
             "173.67516362163684`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01974539408494728`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.574334237508879`", ",", 
               RowBox[{"-", "0.139023951860052`"}]}], "}"}], ",", 
             "84.99565132975194`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01965111971513255`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.577263296573113`", ",", 
               RowBox[{"-", "0.10557389463469018`"}]}], "}"}], ",", 
             "88.56167492728946`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029499901700446484`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5835171622575075`", ",", "0.5978111898525217`"}], 
              "}"}], ",", "79.19428090990027`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028596646778779558`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.601474680697096`", ",", "0.6918967745999689`"}], 
              "}"}], ",", "70.13444119156834`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11402359536099986`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5368369334040395`", ",", "0.16326730455128366`"}], 
              "}"}], ",", "178.37952443301978`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1135790028857132`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.348854642305988`", ",", "0.16858535696493876`"}], 
              "}"}], ",", "175.48725785287127`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04389862265346749`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.447483270690153`", ",", "0.11587933936681133`"}], 
              "}"}], ",", 
             RowBox[{"-", "130.74759996384304`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04373972409248053`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.325030926814644`", ",", 
               RowBox[{"-", "0.026245639924664915`"}]}], "}"}], ",", 
             RowBox[{"-", "128.12556293159676`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02383006559327609`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.42785836360701`", ",", "0.01665958676336221`"}], 
              "}"}], ",", 
             RowBox[{"-", "79.87472436070594`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02376757003658947`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.4982581522663425`", ",", 
               RowBox[{"-", "0.377555216146243`"}]}], "}"}], ",", 
             RowBox[{"-", "80.88619674316874`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01293598732385119`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.492443700937656`", ",", 
               RowBox[{"-", "0.061176333521544085`"}]}], "}"}], ",", 
             RowBox[{"-", "29.001848757568478`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01288417361574604`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.6973141732691275`", ",", 
               RowBox[{"-", "0.1747465325449184`"}]}], "}"}], ",", 
             RowBox[{"-", "31.988115253259416`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009989826860471058`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.612509852193087`", ",", "0.3238578492146921`"}], 
              "}"}], ",", "141.57547291600534`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00994384498497979`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5127792552332116`", ",", "0.4029728818525733`"}], 
              "}"}], ",", "138.12627536543016`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.9473277431581772`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.898387262851132`", ",", "0.1809591662737341`"}], 
              "}"}], ",", 
             RowBox[{"-", "27.14982998213385`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.93090829127967`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.97435174451669`", ",", "0.14200277352684282`"}], 
              "}"}], ",", 
             RowBox[{"-", "30.265436778514374`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016351152913349525`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1533879505423`", ",", "0.03752729228343482`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.95362229257535`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0099395803753412`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5900884129714665`", ",", "0.26520729191273357`"}], 
              "}"}], ",", "164.12486711972775`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009905449424197901`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.400758126154542`", ",", "0.3190506142465829`"}], 
              "}"}], ",", "166.54399696697314`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3027382676488262`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.7103606959140265`", ",", "0.5772951254941001`"}], 
              "}"}], ",", 
             RowBox[{"-", "80.6676367412996`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3019759219363605`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.739719792815295`", ",", "0.3986426170525476`"}], 
              "}"}], ",", 
             RowBox[{"-", "81.25946416418196`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "75.48651860593858`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.935844594623621`", ",", "0.7973177727561169`"}], 
              "}"}], ",", "47.26067844033207`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "75.18908972622434`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9767342513768655`", ",", "0.8415684967397441`"}], 
              "}"}], ",", "50.18974863351283`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29625696266042756`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.156710522321821`", ",", "1.057504153542214`"}], 
              "}"}], ",", "178.62343125498694`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.30033408350038`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.623695705447773`", ",", "0.8399326160826954`"}], 
              "}"}], ",", "175.18899362196373`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29929508032626695`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.188869344374059`", ",", "0.8765301252217953`"}], 
              "}"}], ",", "172.74052678453037`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00955475567383658`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.4874006132775435`", ",", "0.8597499173682634`"}], 
              "}"}], ",", 
             RowBox[{"-", "94.44848671520808`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009531017240429419`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.471949617710071`", ",", "0.6611436641888342`"}], 
              "}"}], ",", 
             RowBox[{"-", "94.08786761640705`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.581610199262495`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.385731150277527`", ",", "1.1815774722078438`"}], 
              "}"}], ",", "106.42721784414178`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.3948656574795173`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.364102736692175`", ",", "1.2549358388771608`"}], 
              "}"}], ",", "117.24981010180657`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1770077133886069`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.285753978708785`", ",", "1.4070605913421486`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.61038484895062`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00922915183109922`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.114937969488056`", ",", "1.3969433197743022`"}], 
              "}"}], ",", 
             RowBox[{"-", "110.47057979970772`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009504114203310814`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.595407208774853`", ",", "0.9171051574870768`"}], 
              "}"}], ",", 
             RowBox[{"-", "52.69707759650896`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009479162575955621`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.639117835616823`", ",", "0.8597328288639436`"}], 
              "}"}], ",", 
             RowBox[{"-", "51.676815753657145`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16895981105816463`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.17426127708289`", ",", "0.6847681835117939`"}], 
              "}"}], ",", "169.64020803857449`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16853957652470247`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.9129569581717885`", ",", "0.7325369742730579`"}], 
              "}"}], ",", "169.25563452569548`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008022282813701877`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.149860507509465`", ",", "0.15542061427856801`"}], 
              "}"}], ",", 
             RowBox[{"-", "115.49476098477925`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20161946098232789`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.976148157166832`", ",", 
               RowBox[{"-", "0.6651470108793203`"}]}], "}"}], ",", 
             RowBox[{"-", "154.09461073010547`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2010189555938405`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.922093988224713`", ",", 
               RowBox[{"-", "0.6914005885171679`"}]}], "}"}], ",", 
             RowBox[{"-", "155.88952454396505`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0769320666836668`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.090655489293798`", ",", "0.7360701536815027`"}], 
              "}"}], ",", "155.91481783645196`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017436484983645455`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.813642807021752`", ",", "0.8598979484814954`"}], 
              "}"}], ",", "179.3646281616771`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013484543723114452`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.679967194926414`", ",", "0.8613803822979871`"}], 
              "}"}], ",", 
             RowBox[{"-", "130.28026479001534`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010428301322837948`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.593536982293348`", ",", "0.7593941811564283`"}], 
              "}"}], ",", 
             RowBox[{"-", "79.92515774170776`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008064749591302904`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.616922886965641`", ",", "0.6277717425612483`"}], 
              "}"}], ",", 
             RowBox[{"-", "29.570050693400123`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10033799533117782`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.043512798331155`", ",", "0.6573804419320666`"}], 
              "}"}], ",", 
             RowBox[{"-", "8.915925840065315`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09835373539021006`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.210986383001262`", ",", "0.6311070841589409`"}], 
              "}"}], ",", 
             RowBox[{"-", "1.1992298383238487`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09049666492455452`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.899262128321833`", ",", "0.8727879726536775`"}], 
              "}"}], ",", "153.42220748462375`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.034900456856099216`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.841682554284794`", ",", "0.9015937670123577`"}], 
              "}"}], ",", "175.4617768609451`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02144093445513161`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.712539000534084`", ",", "0.9118442775173976`"}], 
              "}"}], ",", 
             RowBox[{"-", "133.8947192363088`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01317213904117977`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.622717590410879`", ",", "0.8184888024532366`"}], 
              "}"}], ",", 
             RowBox[{"-", "83.25121533356258`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008092242774364275`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.637941798653708`", ",", "0.6898367370817262`"}], 
              "}"}], ",", 
             RowBox[{"-", "32.60771143081625`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.441569506365835`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.934985647022961`", ",", "1.0862925640458698`"}], 
              "}"}], ",", "72.81356278182163`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.428545035069252`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.02114616024396`", ",", "1.3648656312182066`"}], 
              "}"}], ",", "74.52970414272157`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0129862782991946`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.10158126102411`", ",", "1.6554902335190946`"}], 
              "}"}], ",", 
             RowBox[{"-", "137.32972322182462`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08698668081496037`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.151457852592751`", ",", "1.0858869168008731`"}], 
              "}"}], ",", 
             RowBox[{"-", "7.795081920980665`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08677016129752341`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.298381427932044`", ",", "1.0657737383879953`"}], 
              "}"}], ",", 
             RowBox[{"-", "8.195713655713424`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10224517467300984`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.343756785437981`", ",", "1.0083714905520778`"}], 
              "}"}], ",", "165.32494987407017`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1017535771684494`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.161225427054131`", ",", "1.0561727505257825`"}], 
              "}"}], ",", "168.9131105635396`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07497800311401193`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.143881683462895`", ",", "0.3832461284525548`"}], 
              "}"}], ",", 
             RowBox[{"-", "11.076600125150037`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07414352473640408`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.32151291507871`", ",", "0.3484715981465151`"}], 
              "}"}], ",", 
             RowBox[{"-", "5.032277059895307`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27976021067395124`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.839439865992445`", ",", "1.0218694340316077`"}], 
              "}"}], ",", "123.19589697514846`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.278727566910716`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.750805233635593`", ",", "1.157338521753208`"}], 
              "}"}], ",", "120.50114930110017`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015302620166228706`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.122856680468086`", ",", 
               RowBox[{"-", "0.3469255217782274`"}]}], "}"}], ",", 
             RowBox[{"-", "168.86168480504196`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015138093205970727`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.05452514831685`", ",", 
               RowBox[{"-", "0.36037909558971937`"}]}], "}"}], ",", 
             RowBox[{"-", "162.91605544976164`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013029896333682863`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.899821121356265`", ",", 
               RowBox[{"-", "1.4982348238119843`"}]}], "}"}], ",", 
             RowBox[{"-", "122.75894894143671`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012997495591885134`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8447250389984315`", ",", 
               RowBox[{"-", "1.5838618799218238`"}]}], "}"}], ",", 
             RowBox[{"-", "123.13889289484467`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14670805463275563`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5760497386044126`", ",", 
               RowBox[{"-", "1.6632283365645302`"}]}], "}"}], ",", 
             RowBox[{"-", "67.78265364784708`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1374711393535217`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.6059430288850525`", ",", 
               RowBox[{"-", "1.7364162622695076`"}]}], "}"}], ",", 
             RowBox[{"-", "56.294481242760945`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008655348002035998`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.698922125620347`", ",", 
               RowBox[{"-", "1.8758034494156233`"}]}], "}"}], ",", 
             "7.73003902138586`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011200089020666285`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.916170905633331`", ",", 
               RowBox[{"-", "1.2320732494795885`"}]}], "}"}], ",", 
             RowBox[{"-", "6.614935516095213`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011169332644271364`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.120371921029847`", ",", 
               RowBox[{"-", "1.2557540571998236`"}]}], "}"}], ",", 
             RowBox[{"-", "5.272445975983037`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17951492661350738`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.211636102543155`", ",", 
               RowBox[{"-", "0.9174096462932262`"}]}], "}"}], ",", 
             RowBox[{"-", "159.33450736445798`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1790670088391891`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1540997221684615`", ",", 
               RowBox[{"-", "0.9391112416421967`"}]}], "}"}], ",", 
             RowBox[{"-", "158.8872116167217`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06503541302797344`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.956690241253088`", ",", "0.17168039885872202`"}], 
              "}"}], ",", "170.6328302841635`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06487305345468208`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9225528304364947`", ",", "0.177311715770142`"}], 
              "}"}], ",", "170.17596174522126`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024810574891437957`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8894263217254865`", ",", "1.1211417280571658`"}], 
              "}"}], ",", "84.551379476579`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02471879451365109`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.911625254895543`", ",", "1.3538738076488344`"}], 
              "}"}], ",", "81.84859222927432`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008897301888474594`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.996981320663829`", ",", "1.1193631448066796`"}], 
              "}"}], ",", "49.28933681748847`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008867776320461054`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.067545715787124`", ",", "1.2013709460128568`"}], 
              "}"}], ",", "47.00827039061789`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23159685308222092`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.060092723143652`", ",", 
               RowBox[{"-", "0.7433532091214999`"}]}], "}"}], ",", 
             RowBox[{"-", "165.40530980066367`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2309243587133448`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9321073113160727`", ",", 
               RowBox[{"-", "0.7766782465086752`"}]}], "}"}], ",", 
             RowBox[{"-", "167.07014185023118`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014952582065927799`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5179669445967625`", ",", "1.6546179606098674`"}], 
              "}"}], ",", "120.1152113845432`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014456281109720108`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4031273095709067`", ",", "1.8526055614273562`"}], 
              "}"}], ",", "110.79811322981409`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015296990460617858`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3584371703534224`", ",", "0.8983914028520312`"}], 
              "}"}], ",", "126.40546541252102`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015209278402895503`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2418943733926846`", ",", "1.0564346421307682`"}], 
              "}"}], ",", "122.27637739601138`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20419089743765598`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.22879531666272`", ",", "0.9020263899058154`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.97909900918143`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20084734110354682`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1107622699206594`", ",", "0.8811695801798028`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.137921559203`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013360652149753193`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.167926937343688`", ",", "0.7875044978575387`"}], 
              "}"}], ",", 
             RowBox[{"-", "106.3636634308839`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01332445518595478`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1018694891400234`", ",", "0.5625338826359672`"}], 
              "}"}], ",", 
             RowBox[{"-", "107.61731042452053`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011648681467882966`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.764975851525028`", ",", "2.414726189496874`"}], 
              "}"}], ",", "57.05593800078328`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01150095117809422`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.040372770179408`", ",", "2.839708033129257`"}], 
              "}"}], ",", "63.474247874165194`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23107824109305267`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.312530256982746`", ",", "1.9047407108645917`"}], 
              "}"}], ",", "137.8221296932794`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22941892763031516`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.160245365407655`", ",", "2.042717078838258`"}], 
              "}"}], ",", "142.61251127885697`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03073033532851586`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9696703051931497`", ",", "2.143299400268076`"}], 
              "}"}], ",", "83.43065289420122`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030653458184703334`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.989624174191954`", ",", "2.316567486165755`"}], 
              "}"}], ",", "82.93805421791085`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012533216750468534`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.203960725449316`", ",", 
               RowBox[{"-", "1.846230942491997`"}]}], "}"}], ",", 
             RowBox[{"-", "118.25570953233003`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012457273060717559`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.183252305621113`", ",", 
               RowBox[{"-", "1.8847619765155457`"}]}], "}"}], ",", 
             RowBox[{"-", "122.54938119246671`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2167442222075358`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9941947604424164`", ",", 
               RowBox[{"-", "2.117172517617665`"}]}], "}"}], ",", 
             RowBox[{"-", "107.88574978624267`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21442058623731008`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9225117896096935`", ",", 
               RowBox[{"-", "2.339296137369611`"}]}], "}"}], ",", 
             RowBox[{"-", "101.94834046576706`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00842650401348229`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3314998299859577`", ",", 
               RowBox[{"-", "2.030808955936765`"}]}], "}"}], ",", 
             RowBox[{"-", "76.29191789676202`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008382122169376241`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.343528762848731`", ",", 
               RowBox[{"-", "2.080123389095915`"}]}], "}"}], ",", 
             RowBox[{"-", "80.16356807228352`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031768831489039896`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4515426952274284`", ",", 
               RowBox[{"-", "2.1199870179428464`"}]}], "}"}], ",", 
             RowBox[{"-", "20.941006121325106`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03169040267991834`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.556943566838984`", ",", 
               RowBox[{"-", "2.160322154999426`"}]}], "}"}], ",", 
             RowBox[{"-", "20.777375108963387`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010045254638921875`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6087330171752736`", ",", 
               RowBox[{"-", "1.8690807179268634`"}]}], "}"}], ",", 
             RowBox[{"-", "7.538959545704307`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009699307143704223`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.626161706169526`", ",", 
               RowBox[{"-", "1.8713873058769472`"}]}], "}"}], ",", 
             "1.8968548487244494`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2602943346155405`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6583334482814975`", ",", 
               RowBox[{"-", "1.8881915848497568`"}]}], "}"}], ",", 
             RowBox[{"-", "147.15533881793655`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2595849112566412`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.628396231651677`", ",", 
               RowBox[{"-", "1.9075178484490787`"}]}], "}"}], ",", 
             RowBox[{"-", "148.4489642062329`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008899379156740599`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.844387562893518`", ",", 
               RowBox[{"-", "0.4646491925784466`"}]}], "}"}], ",", 
             RowBox[{"-", "169.87642271823418`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008877209848899389`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.711766618665485`", ",", 
               RowBox[{"-", "0.4883288901651158`"}]}], "}"}], ",", 
             RowBox[{"-", "169.459797578088`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21448173965403708`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5947838776974526`", ",", "0.699565467163501`"}], 
              "}"}], ",", "157.5260077767038`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21390216141656454`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.411995464801956`", ",", "0.7751817178667965`"}], 
              "}"}], ",", "158.76200417268007`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008936328642938847`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.352532376797479`", ",", "2.369357454152633`"}], 
              "}"}], ",", "102.7419063889365`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010575137314652998`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.52218963097219`", ",", "1.6623099573089042`"}], 
              "}"}], ",", "22.82443399102018`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010540848720848851`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.625069808407641`", ",", "1.7056084372372071`"}], 
              "}"}], ",", "20.640641650560084`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.42877914854273486`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.096591811836374`", ",", "1.2499734969440517`"}], 
              "}"}], ",", "138.338329682269`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4182358096509167`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9862592797803313`", ",", "1.3481438736691491`"}], 
              "}"}], ",", "129.96227813976702`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010284086557917411`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8677830330422824`", ",", "1.489527299309895`"}], 
              "}"}], ",", "53.31314400394015`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009508196549776105`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.560933992060265`", ",", 
               RowBox[{"-", "0.15747189595957234`"}]}], "}"}], ",", 
             RowBox[{"-", "151.9154985523798`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009483135678169314`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4144325205014994`", ",", 
               RowBox[{"-", "0.2356454770595336`"}]}], "}"}], ",", 
             RowBox[{"-", "152.9676180646845`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028389611648616347`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.908455139197296`", ",", 
               RowBox[{"-", "0.6337664010897093`"}]}], "}"}], ",", 
             RowBox[{"-", "172.67712578197646`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02829547433083988`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.902628181296575`", ",", 
               RowBox[{"-", "0.6345152162075803`"}]}], "}"}], ",", 
             RowBox[{"-", "170.39926886569683`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01421205393836006`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.147244857449752`", ",", 
               RowBox[{"-", "0.8967049223682861`"}]}], "}"}], ",", 
             "167.3366906722908`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013895593409651902`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.137138975144561`", ",", 
               RowBox[{"-", "0.8944342626544151`"}]}], "}"}], ",", 
             "175.41024640567576`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015345332093358513`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.477344047574457`", ",", 
               RowBox[{"-", "0.3900611068834905`"}]}], "}"}], ",", 
             "121.78540995078029`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01208765519280617`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.37136217824953`", ",", 
               RowBox[{"-", "0.2190326212415336`"}]}], "}"}], ",", 
             "138.2327845289799`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.102031822877546`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.952683447459978`", ",", 
               RowBox[{"-", "0.8740524240884584`"}]}], "}"}], ",", 
             "33.911916902840716`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10171591638734098`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.052469467204013`", ",", 
               RowBox[{"-", "0.8069688713511451`"}]}], "}"}], ",", 
             "31.9320184987648`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.299873046186019`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.098021325764257`", ",", 
               RowBox[{"-", "0.9968067045346964`"}]}], "}"}], ",", 
             RowBox[{"-", "47.71026739119036`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.279616600698042`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.224219046840725`", ",", 
               RowBox[{"-", "1.1355461267955338`"}]}], "}"}], ",", 
             RowBox[{"-", "50.53157107104334`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02017902408934035`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.404873413023072`", ",", 
               RowBox[{"-", "1.354943595196123`"}]}], "}"}], ",", 
             "179.41250770359824`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0982826838666087`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.997752704567444`", ",", 
               RowBox[{"-", "1.1584789527443164`"}]}], "}"}], ",", 
             RowBox[{"-", "129.33245168522143`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0977787930460281`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.91710714484928`", ",", 
               RowBox[{"-", "1.2568947932735157`"}]}], "}"}], ",", 
             RowBox[{"-", "133.12121229683976`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015260549290999206`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.084428116973464`", ",", 
               RowBox[{"-", "0.7640639246493693`"}]}], "}"}], ",", 
             "173.12300615548128`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015222883000252874`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.9151743398878`", ",", 
               RowBox[{"-", "0.7436509199874607`"}]}], "}"}], ",", 
             "172.97020708192977`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01955729545822849`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.584222943013781`", ",", "0.1716058667428289`"}], 
              "}"}], ",", "92.12769852482685`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01934716147380595`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.574033746401171`", ",", "0.44585974810855794`"}], 
              "}"}], ",", "98.07146277665998`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0277210485409145`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.672516915681058`", ",", "0.8885179867466502`"}], 
              "}"}], ",", "61.07460147323644`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.027185381555830897`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.804524202477089`", ",", "1.1273984324969137`"}], 
              "}"}], ",", "68.72229551796222`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1131361439329352`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.062238178947538`", ",", "0.1912066990993062`"}], 
              "}"}], ",", "172.59499127272275`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11280753395326751`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.854268663032112`", ",", "0.21823571056275384`"}], 
              "}"}], ",", "170.9286572823858`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04358140069196921`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1212892282563045`", ",", 
               RowBox[{"-", "0.28584844369612605`"}]}], "}"}], ",", 
             RowBox[{"-", "125.50352589935048`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04346055979354915`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.058741770078805`", ",", 
               RowBox[{"-", "0.37352533270738797`"}]}], "}"}], ",", 
             RowBox[{"-", "124.10058136952266`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023705238377672685`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.548883626199007`", ",", 
               RowBox[{"-", "0.6931337635867161`"}]}], "}"}], ",", 
             RowBox[{"-", "81.89766912563228`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023557862314608866`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.577185086091668`", ",", 
               RowBox[{"-", "0.8919322091923785`"}]}], "}"}], ",", 
             RowBox[{"-", "86.2673013538829`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012832567441884733`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.903281161164852`", ",", 
               RowBox[{"-", "0.3033895933541004`"}]}], "}"}], ",", 
             RowBox[{"-", "34.97438174895035`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012462827083531003`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.971531298262972`", ",", 
               RowBox[{"-", "0.3511333900671929`"}]}], "}"}], ",", 
             RowBox[{"-", "43.84244036585447`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009898074758088963`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.34098319847574`", ",", "0.5569745163120173`"}], 
              "}"}], ",", "134.6770778148549`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009821291566382246`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.300445387111725`", ",", "0.5979718692414645`"}], 
              "}"}], ",", "129.66399042567593`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016419451878506252`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.97435174451669`", ",", "0.14200277352684282`"}], 
              "}"}], ",", "92.30714193916606`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01637449812895876`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.96810564813093`", ",", "0.29703507084169406`"}], 
              "}"}], ",", "90.98396273037005`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.914557138366321`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1533879505423`", ",", "0.03752729228343482`"}], 
              "}"}], ",", 
             RowBox[{"-", "33.381043574894804`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.7807874059594893`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.39375033838211`", ",", 
               RowBox[{"-", "0.12084842573426254`"}]}], "}"}], ",", 
             RowBox[{"-", "23.970290148934822`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.129198502335155`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5496058187056825`", ",", 
               RowBox[{"-", "0.19014294206542603`"}]}], "}"}], ",", 
             "47.633481229287845`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016283138047119023`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.964087541651995`", ",", 
               RowBox[{"-", "0.04693834832296653`"}]}], "}"}], ",", 
             RowBox[{"-", "159.0692290889559`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016214232730260462`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8111748949094295`", ",", 
               RowBox[{"-", "0.1054241267005212`"}]}], "}"}], ",", 
             RowBox[{"-", "155.89579154075085`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00987143567335703`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.103008723708266`", ",", "0.39029214819013164`"}], 
              "}"}], ",", "168.96312681421838`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009772716261754294`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.033355543856384`", ",", "0.40387788023287086`"}], 
              "}"}], ",", "163.22407459397994`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.30121549593820734`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.788286169112373`", ",", "0.08275477138089243`"}], 
              "}"}], ",", 
             RowBox[{"-", "81.85129158706617`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2981272510973552`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8157708955746745`", ",", 
               RowBox[{"-", "0.10919306060865114`"}]}], "}"}], ",", 
             RowBox[{"-", "87.66134389042425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29742887971425863`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9767342513768655`", ",", "0.8415684967397441`"}], 
              "}"}], ",", 
             RowBox[{"-", "75.3148637947805`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2962795400380463`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.037289686503661`", ",", "0.6105007043935301`"}], 
              "}"}], ",", 
             RowBox[{"-", "78.17532072301118`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "74.89283276356394`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.156710522321821`", ",", "1.057504153542214`"}], 
              "}"}], ",", "53.118818826693584`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "74.54594837632067`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.192065638887377`", ",", "1.1046249733468794`"}], 
              "}"}], ",", "56.58809724210488`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3452777077564049`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.353649000460349`", ",", "1.3495682650002878`"}], 
              "}"}], ",", "177.28976402830634`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29508966314603813`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.875687281178761`", ",", "1.0642572209501147`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.44749855183218`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2943378479465851`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.635547121943515`", ",", "1.057748727360387`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.71106158631576`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29825967157468253`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.881209576075601`", ",", "0.9157210836573269`"}], 
              "}"}], ",", "170.2920599470966`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29752346497243076`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.673185502654298`", ",", "0.9513089607076581`"}], 
              "}"}], ",", "170.13653498805604`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009507337784272946`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.453084848827884`", ",", "0.3971828149358141`"}], 
              "}"}], ",", 
             RowBox[{"-", "93.72724851760502`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009473108443659173`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.439182291361847`", ",", "0.18377233116537578`"}], 
              "}"}], ",", 
             RowBox[{"-", "91.12537676247729`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1867445417829799`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.364102736692175`", ",", "1.2549358388771608`"}], 
              "}"}], ",", "61.93259731022847`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18628405188088945`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.422826032225031`", ",", "1.365065552474647`"}], 
              "}"}], ",", "61.84311480447392`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.2178579440909103`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.285753978708785`", ",", "1.4070605913421486`"}], 
              "}"}], ",", "128.07240235947125`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.1221576234966264`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.174197682692963`", ",", "1.5494748272910812`"}], 
              "}"}], ",", "137.04019877930722`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09285415661781521`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.036656461720002`", ",", "1.6775537955970146`"}], 
              "}"}], ",", 
             RowBox[{"-", "149.3179170100164`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1677785615575076`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.114937969488056`", ",", "1.3969433197743022`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.78779259128592`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008747945436807911`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.055094413422918`", ",", "1.2366335665228163`"}], 
              "}"}], ",", 
             RowBox[{"-", "99.64798754204313`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008724604657246544`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.036231460668536`", ",", "1.1256743437386747`"}], 
              "}"}], ",", 
             RowBox[{"-", "98.50223236998023`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009454276455358273`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.853458526119032`", ",", "0.5885561136172155`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.65655391080425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009429612362099857`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.87794882615238`", ",", "0.5586810616236928`"}], 
              "}"}], ",", 
             RowBox[{"-", "49.68956524251557`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16812038719283007`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.615981264787904`", ",", "0.7888893143257181`"}], 
              "}"}], ",", "168.87106101281742`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16687660816130284`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.369808577478939`", ",", "0.8373156111747763`"}], 
              "}"}], ",", "173.7476175387645`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.200420238756517`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.655926041426688`", ",", 
               RowBox[{"-", "0.8105216709669426`"}]}], "}"}], ",", 
             RowBox[{"-", "157.6844383578246`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19935506263517028`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.593039866070804`", ",", 
               RowBox[{"-", "0.836333126310018`"}]}], "}"}], ",", 
             RowBox[{"-", "153.7851467154957`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05949558170002157`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.813642807021752`", ",", "0.8598979484814954`"}], 
              "}"}], ",", "152.45933143859418`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05934870297569491`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.672920885593271`", ",", "0.9332801431723884`"}], 
              "}"}], ",", "152.62293929037097`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09640871569417986`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.382123401893994`", ",", "0.6275245760517915`"}], 
              "}"}], ",", "6.517466163417426`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0948712557500937`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.382254773277838`", ",", "0.6275395844991265`"}], 
              "}"}], ",", 
             RowBox[{"-", "0.5640206175443543`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05559620806845538`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.841682554284794`", ",", "0.9015937670123577`"}], 
              "}"}], ",", "146.8578423345198`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.055201250034786715`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.674320094655733`", ",", "1.010871541214962`"}], 
              "}"}], ",", "151.6171356378731`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013459522400967618`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.712539000534084`", ",", "0.9118442775173976`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.498653762735`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013295512126931313`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.64849501488751`", ",", "0.8916496320041639`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.80231218943698`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00826879541395185`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.622717590410879`", ",", "0.8184888024532366`"}], 
              "}"}], ",", 
             RowBox[{"-", "111.85514985998898`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008248378369815169`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.563056991588514`", ",", "0.6697420551766223`"}], 
              "}"}], ",", 
             RowBox[{"-", "112.02727014945185`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01302447129658328`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.02114616024396`", ",", "1.3648656312182066`"}], 
              "}"}], ",", 
             RowBox[{"-", "71.89472713183234`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01201864247176827`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.051328059475833`", ",", "1.2725527638858225`"}], 
              "}"}], ",", 
             RowBox[{"-", "59.658165183703034`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.415558756770056`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.10158126102411`", ",", "1.6554902335190946`"}], 
              "}"}], ",", "76.2458455036211`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.219363342218478`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.111402240816899`", ",", "1.6956126639955889`"}], 
              "}"}], ",", "65.96996389556105`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18747791291442026`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.184072372672007`", ",", "1.8586024464312514`"}], 
              "}"}], ",", 
             RowBox[{"-", "2.1152675779987717`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008330159073777816`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.36240697690967`", ",", "1.8520156282570719`"}], 
              "}"}], ",", 
             RowBox[{"-", "70.20049905155858`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012948197299062807`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8798616310272624`", ",", "1.4511061084650112`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.61358186092468`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012907460466375639`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.833820172339405`", ",", "1.4060403563564783`"}], 
              "}"}], ",", 
             RowBox[{"-", "133.5611683243165`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08655418072123228`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.637302678486836`", ",", "1.0169603213082352`"}], 
              "}"}], ",", 
             RowBox[{"-", "8.596345390446183`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08632282556897239`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.858767059798419`", ",", "0.9834814317062208`"}], 
              "}"}], ",", 
             RowBox[{"-", "7.4373994198669555`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10126434327769537`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.879946877019573`", ",", "1.1112905707736813`"}], 
              "}"}], ",", "172.50127125300932`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09949505690056722`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.630680122811341`", ",", "1.1441015350696153`"}], 
              "}"}], ",", "179.85060228406243`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07331833380489744`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5841933507179515`", ",", "0.3253409192139103`"}], 
              "}"}], ",", "1.0120460053594813`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07275867915652669`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.626714297149007`", ",", "0.32609206755954295`"}], 
              "}"}], ",", 
             RowBox[{"-", "3.954636338716895`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27769873481583474`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.628638705595014`", ",", "1.3647266179686772`"}], 
              "}"}], ",", "117.80640162705188`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2768719222552171`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.628289473465782`", ",", "1.3653888162929944`"}], 
              "}"}], ",", "119.5995839218644`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014975335166352324`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8418719011631226`", ",", 
               RowBox[{"-", "0.4257345527276301`"}]}], "}"}], ",", 
             RowBox[{"-", "156.97042609448138`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014936601135951322`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6865263052883464`", ",", 
               RowBox[{"-", "0.4917694976009767`"}]}], "}"}], ",", 
             RowBox[{"-", "157.86058497814227`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01296517541926786`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6801569042007625`", ",", 
               RowBox[{"-", "1.8359346973849022`"}]}], "}"}], ",", 
             RowBox[{"-", "123.51883684825455`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012926979602887445`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.628435784582611`", ",", 
               RowBox[{"-", "1.9140209948334994`"}]}], "}"}], ",", 
             RowBox[{"-", "125.25874934305428`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009236915279233931`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.6059430288850525`", ",", 
               RowBox[{"-", "1.7364162622695076`"}]}], "}"}], ",", 
             RowBox[{"-", "108.83082910182166`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009212778928076043`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.580392820833384`", ",", 
               RowBox[{"-", "1.8113373396360717`"}]}], "}"}], ",", 
             RowBox[{"-", "109.81178758688053`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1288157913514856`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.698922125620347`", ",", 
               RowBox[{"-", "1.8758034494156233`"}]}], "}"}], ",", 
             RowBox[{"-", "44.80630883767494`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11020071862710995`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.1387084261467875`", ",", 
               RowBox[{"-", "2.3126263188259486`"}]}], "}"}], ",", 
             RowBox[{"-", "30.069264496571073`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015925022623388713`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.275115027170251`", ",", 
               RowBox[{"-", "2.39160072839328`"}]}], "}"}], ",", 
             "26.67132499101252`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008110396898927022`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.864952223193942`", ",", 
               RowBox[{"-", "1.8532666557235384`"}]}], "}"}], ",", 
             "19.218211426471964`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008078540266813651`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.087955228348104`", ",", 
               RowBox[{"-", "1.7755293071353104`"}]}], "}"}], ",", 
             "16.300089767938356`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011138660727445219`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.446986340259031`", ",", 
               RowBox[{"-", "1.2858947444894115`"}]}], "}"}], ",", 
             RowBox[{"-", "3.92995643587086`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011110705312078101`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.634975538592947`", ",", 
               RowBox[{"-", "1.2988093106254066`"}]}], "}"}], ",", 
             RowBox[{"-", "3.386361281286148`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17862020868966294`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.854644651235509`", ",", 
               RowBox[{"-", "1.0547381333962738`"}]}], "}"}], ",", 
             RowBox[{"-", "158.43991586898292`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17803973008588353`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3777554314599088`", ",", 
               RowBox[{"-", "1.2431677270440258`"}]}], "}"}], ",", 
             RowBox[{"-", "160.63342486310583`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06471109920873179`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6037690263909803`", ",", "0.23251298497403247`"}], 
              "}"}], ",", "169.7190932062798`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06453786688081013`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4006273323013927`", ",", "0.2693601613068275`"}], 
              "}"}], ",", "170.88905180878817`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024627353653903755`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.955364090593181`", ",", "1.6592345551760308`"}], 
              "}"}], ",", "79.14580498196977`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024563707780477777`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.990563917608184`", ",", "1.8428149348015401`"}], 
              "}"}], ",", "78.26349505702298`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00883834873261919`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.267562956917228`", ",", "1.4159252596804341`"}], 
              "}"}], ",", "44.727203963747314`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008784764056170971`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.3414793017053155`", ",", "1.4891410751493424`"}], 
              "}"}], ",", "40.43189171315737`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23025381708549322`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.660008727854707`", ",", 
               RowBox[{"-", "0.8391463939340966`"}]}], "}"}], ",", 
             RowBox[{"-", "168.73497389979912`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22443726071711514`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.54432612307239`", ",", 
               RowBox[{"-", "0.8621886350649688`"}]}], "}"}], ",", 
             RowBox[{"-", "160.27597129655464`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013976453203989363`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3465003261523547`", ",", "2.0016919364102153`"}], 
              "}"}], ",", "101.48101507508498`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013922465758562676`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.322593379298374`", ",", "2.1193979559844265`"}], 
              "}"}], ",", "104.34008581987273`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015122069281034293`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0948678087528037`", ",", "1.28922010582574`"}], 
              "}"}], ",", "118.14728937950176`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015082284760137343`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.057027867898407`", ",", "1.3599474591186946`"}], 
              "}"}], ",", "117.10986224234333`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013288356287742805`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.030548797235382`", ",", "0.3379380311434561`"}], 
              "}"}], ",", 
             RowBox[{"-", "108.87095741815713`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013251577968552922`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9734752681722851`", ",", "0.1709637584621732`"}], 
              "}"}], ",", 
             RowBox[{"-", "107.4792387480908`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011355094425544969`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.14196656423911`", ",", "3.043244514731989`"}], "}"}],
              ",", "69.89255774754704`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011326642907984163`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.170744503251183`", ",", "3.121852289530835`"}], 
              "}"}], ",", "70.41066222185908`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030576773362099727`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0356327260310234`", ",", "2.687957121083041`"}], 
              "}"}], ",", "82.445455541619`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030492686970856185`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0616699245015138`", ",", "2.8842848435931794`"}], 
              "}"}], ",", "83.79702819751033`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00833797408153295`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.392586079497609`", ",", 
               RowBox[{"-", "2.3630622067704063`"}]}], "}"}], ",", 
             RowBox[{"-", "84.03521824780522`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008252250294128315`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.394983681095318`", ",", 
               RowBox[{"-", "2.386009537355096`"}]}], "}"}], ",", 
             RowBox[{"-", "78.2172429447636`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03161216749070068`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8588435170927085`", ",", 
               RowBox[{"-", "2.274866792392901`"}]}], "}"}], ",", 
             RowBox[{"-", "20.613744096597223`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030314999018646115`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9627488659543375`", ",", 
               RowBox[{"-", "2.3139506941956443`"}]}], "}"}], ",", 
             RowBox[{"-", "30.62333579868526`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009365273698826688`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8201946499746575`", ",", 
               RowBox[{"-", "1.8649612329970076`"}]}], "}"}], ",", 
             "11.332669243153088`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009338396665339768`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.108523759879753`", ",", 
               RowBox[{"-", "1.8071764067739187`"}]}], "}"}], ",", 
             "12.934439677470689`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2588774214069859`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3601829633056144`", ",", 
               RowBox[{"-", "2.072207955493204`"}]}], "}"}], ",", 
             RowBox[{"-", "149.7425895945289`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.257487750986994`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3453218671299387`", ",", 
               RowBox[{"-", "2.0808772665983004`"}]}], "}"}], ",", 
             RowBox[{"-", "145.8128075802196`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00885509576718143`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.37955614645619`", ",", 
               RowBox[{"-", "0.5501416006647808`"}]}], "}"}], ",", 
             RowBox[{"-", "169.04317243793918`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008782603006572872`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3117054913161614`", ",", 
               RowBox[{"-", "0.563277382484079`"}]}], "}"}], ",", 
             RowBox[{"-", "163.87559192237472`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2133241493307555`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.187360460058735`", ",", "0.8624833169471092`"}], 
              "}"}], ",", "159.99800056865692`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21263547278197578`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.117252386810888`", ",", "0.8880033394673086`"}], 
              "}"}], ",", "157.83279515707858`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010506671303630892`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.865402790228393`", ",", "1.7961382788338658`"}], 
              "}"}], ",", "18.456849310100335`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010478898418429052`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3413858183556036`", ",", "1.955001466937924`"}], 
              "}"}], ",", "19.53182824456148`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010543338891818188`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9862592797803313`", ",", "1.3481438736691491`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.76463926690803`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010517277329279352`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9406505601097632`", ",", "1.3331172926123287`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.9820424688601`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4079517230929995`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8677830330422824`", ",", "1.489527299309895`"}], 
              "}"}], ",", "121.58622659726507`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4065136136684532`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7888325516111925`", ",", "1.6179286271643638`"}], 
              "}"}], ",", "119.06463955031148`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010031209033109072`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9779876884070617`", ",", "1.6374489948889326`"}], 
              "}"}], ",", "44.937092461438276`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009860713068529951`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.122485381220374`", ",", "1.7816297349162387`"}], 
              "}"}], ",", "37.668934257513996`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00945814085981273`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.136273110507371`", ",", 
               RowBox[{"-", "0.3775728539432791`"}]}], "}"}], ",", 
             RowBox[{"-", "154.01973757698917`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009434397517409005`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.134336033072358`", ",", 
               RowBox[{"-", "0.3785168038398527`"}]}], "}"}], ",", 
             RowBox[{"-", "153.47257921722118`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02820164916367357`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.621919019136533`", ",", 
               RowBox[{"-", "0.6819973016660933`"}]}], "}"}], ",", 
             RowBox[{"-", "168.12141194941753`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028130144925547763`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.417776698132674`", ",", 
               RowBox[{"-", "0.7249371646637658`"}]}], "}"}], ",", 
             RowBox[{"-", "167.44119973592953`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013586179523650327`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.950544740297555`", ",", 
               RowBox[{"-", "0.8794548318219492`"}]}], "}"}], ",", 
             RowBox[{"-", "176.5161978609394`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013540244654536173`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.650177889460393`", ",", 
               RowBox[{"-", "0.8977408237269249`"}]}], "}"}], ",", 
             RowBox[{"-", "174.15901685406703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009521553992527193`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.258025463924768`", ",", 
               RowBox[{"-", "0.11781453791912785`"}]}], "}"}], ",", 
             "154.68015910717952`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009497200546697086`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.169782539508914`", ",", 
               RowBox[{"-", "0.07606490709734837`"}]}], "}"}], ",", 
             "153.90118970293483`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1014009879930647`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.353433065589417`", ",", 
               RowBox[{"-", "0.6194021000598979`"}]}], "}"}], ",", 
             "29.952120094688528`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10106380707993437`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.385488297624597`", ",", 
               RowBox[{"-", "0.6009307024520898`"}]}], "}"}], ",", 
             "32.24154623513792`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020256445487972553`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.224219046840725`", ",", 
               RowBox[{"-", "1.1355461267955338`"}]}], "}"}], ",", 
             "76.70304647446208`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020187025190116295`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.269024531048093`", ",", 
               RowBox[{"-", "0.9459605645839262`"}]}], "}"}], ",", 
             "79.11435472900831`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.259437576608702`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.404873413023072`", ",", 
               RowBox[{"-", "1.354943595196123`"}]}], "}"}], ",", 
             RowBox[{"-", "53.35287475089647`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.2453551903496605`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.416265530500333`", ",", 
               RowBox[{"-", "1.3702567653724946`"}]}], "}"}], ",", 
             RowBox[{"-", "54.52427641114215`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014044680021468097`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5948414737607`", ",", 
               RowBox[{"-", "1.6208355140056565`"}]}], "}"}], ",", 
             "147.57525305149824`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020101898600125026`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.120685522106613`", ",", 
               RowBox[{"-", "1.3520295228243422`"}]}], "}"}], ",", 
             "176.59120402374498`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020045701722223426`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9146782862872165`", ",", 
               RowBox[{"-", "1.3397586999505606`"}]}], "}"}], ",", 
             "175.13872589277725`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09727748565061539`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.750245482442702`", ",", 
               RowBox[{"-", "1.435074784336653`"}]}], "}"}], ",", 
             RowBox[{"-", "136.9099729084581`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.096802406225178`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.676997172033755`", ",", 
               RowBox[{"-", "1.5035954304728814`"}]}], "}"}], ",", 
             RowBox[{"-", "140.5473624858018`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015185309677946384`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.614645344029233`", ",", 
               RowBox[{"-", "0.7065919626854019`"}]}], "}"}], ",", 
             "172.81740800837588`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014311953167502712`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.536595683944297`", ",", 
               RowBox[{"-", "0.696756088761932`"}]}], "}"}], ",", 
             "161.65158439293083`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019139285280676866`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5469469278676025`", ",", "0.6368635855234813`"}], 
              "}"}], ",", "104.01522702849313`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01909127551823867`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.49118398859179`", ",", "0.8602635747106462`"}], 
              "}"}], ",", "103.47963383461301`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02666006551827676`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.881204474904297`", ",", "1.3242995202150794`"}], 
              "}"}], ",", "76.36998956268805`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02658880912907812`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8980403815701745`", ",", "1.3937316749718944`"}], 
              "}"}], ",", "75.21152245114669`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1124798784388572`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.5969460739394234`", ",", "0.25932011660617466`"}], 
              "}"}], ",", "169.26232329204885`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1121465306727456`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.46026753674279`", ",", "0.28523889220537657`"}], 
              "}"}], ",", "171.03236488019266`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04334005395830969`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.892604669438865`", ",", 
               RowBox[{"-", "0.6189034417401148`"}]}], "}"}], ",", 
             RowBox[{"-", "122.6976368396943`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043206165761176765`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.892404349855441`", ",", 
               RowBox[{"-", "0.6192154998693977`"}]}], "}"}], ",", 
             RowBox[{"-", "124.66725627349666`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023411402492234893`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.594092515281308`", ",", 
               RowBox[{"-", "1.1510887972667576`"}]}], "}"}], ",", 
             RowBox[{"-", "90.63693358213358`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02334105314434112`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.591763735583777`", ",", 
               RowBox[{"-", "1.3605670779720842`"}]}], "}"}], ",", 
             RowBox[{"-", "92.47543965486314`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012103739927135081`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.089186185011931`", ",", 
               RowBox[{"-", "0.46412778297490015`"}]}], "}"}], ",", 
             RowBox[{"-", "52.710498982758516`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012060594818937327`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.205953928125927`", ",", 
               RowBox[{"-", "0.6174656362047188`"}]}], "}"}], ",", 
             RowBox[{"-", "55.274633312923854`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009745104011571878`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.16874912920781`", ",", "0.7568037859242456`"}], 
              "}"}], ",", "124.6509030364968`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009720889215466981`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.128686699457673`", ",", "0.8147673432488302`"}], 
              "}"}], ",", "124.28708101248907`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016329667455358837`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.962721548274071`", ",", "0.6105183577215063`"}], 
              "}"}], ",", "89.66078352157378`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01628091859219892`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.964111540215825`", ",", "0.845293925448589`"}], 
              "}"}], ",", "87.85442859951237`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.13376973240683207`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.39375033838211`", ",", 
               RowBox[{"-", "0.12084842573426252`"}]}], "}"}], ",", 
             RowBox[{"-", "86.16330810119763`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1333275609806711`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.408684917542238`", ",", 
               RowBox[{"-", "0.34354261569780986`"}]}], "}"}], ",", 
             RowBox[{"-", "83.89850635921084`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.6515889036243343`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5496058187056825`", ",", 
               RowBox[{"-", "0.19014294206542603`"}]}], "}"}], ",", 
             RowBox[{"-", "14.559536722974844`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.642568569406351`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.600626168023581`", ",", 
               RowBox[{"-", "0.20339427849454242`"}]}], "}"}], ",", 
             RowBox[{"-", "14.367874260730193`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008998051745461854`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.882934929861941`", ",", 
               RowBox[{"-", "0.2757101473357457`"}]}], "}"}], ",", 
             "161.96461467083756`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12478348207262034`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.664545060342192`", ",", 
               RowBox[{"-", "0.06412059693375713`"}]}], "}"}], ",", 
             "57.04423465524786`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12432259782539284`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.733352346359235`", ",", "0.0420126293025313`"}], 
              "}"}], ",", "59.74127413866241`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01614561899986869`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.543886199459315`", ",", 
               RowBox[{"-", "0.22501170017298794`"}]}], "}"}], ",", 
             RowBox[{"-", "152.72235399254555`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016053205872168536`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.379552487833043`", ",", 
               RowBox[{"-", "0.3097494748182285`"}]}], "}"}], ",", 
             RowBox[{"-", "156.84609419815763`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00967498409481887`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.819217854866354`", ",", "0.46843169438588755`"}], 
              "}"}], ",", "157.4850223737415`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009634840293621137`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.667336484476603`", ",", "0.5313895380341801`"}], 
              "}"}], ",", "160.59215196051005`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2950706688247494`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8256738210161805`", ",", 
               RowBox[{"-", "0.3516744978920914`"}]}], "}"}], ",", 
             RowBox[{"-", "93.47139619378231`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2895606635512515`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.825576837079949`", ",", 
               RowBox[{"-", "0.35327326938085934`"}]}], "}"}], ",", 
             RowBox[{"-", "85.9254164851212`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2951346416981715`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.0967852982839235`", ",", "0.326322821662418`"}], 
              "}"}], ",", 
             RowBox[{"-", "81.03577765124211`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29212706276233985`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1057991123948865`", ",", "0.2691809260645134`"}], 
              "}"}], ",", 
             RowBox[{"-", "75.24304676421988`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3468843872432643`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.192065638887377`", ",", "1.1046249733468794`"}], 
              "}"}], ",", 
             RowBox[{"-", "60.6442911286852`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.34500226009211427`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.277988308189711`", ",", "0.951860803297774`"}], 
              "}"}], ",", 
             RowBox[{"-", "64.60664134827591`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "74.20067066856427`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.353649000460349`", ",", "1.3495682650002878`"}], 
              "}"}], ",", "60.057375657516175`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "73.99593692078204`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3775247299827535`", ",", "1.391018043860573`"}], 
              "}"}], ",", "58.68481766788946`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20416884847466557`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.543884862887944`", ",", "1.6644691373106297`"}], 
              "}"}], ",", 
             RowBox[{"-", "95.55771005859022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.34367846999673873`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.060538310049242`", ",", "1.3634434958074577`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.24095755628215`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.34210884544200904`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.863122473350959`", ",", "1.3608280192880524`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.8168671957885`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2935879481856063`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.295198604732274`", ",", "1.0441447323620774`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.97462462079935`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.292540606754237`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.189895363322487`", ",", "1.0385792570356913`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.40752902907587`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2967890755791845`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.34378759472657`", ",", "1.0085816823173743`"}], 
              "}"}], ",", "169.98101002900844`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29578886132670673`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.166006433166219`", ",", "1.0399900566600764`"}], 
              "}"}], ",", "172.32517003396833`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00943900233920104`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.433388240338392`", ",", 
               RowBox[{"-", "0.11117953659543567`"}]}], "}"}], ",", 
             RowBox[{"-", "88.52350500734958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009385218372845817`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.441161199556236`", ",", 
               RowBox[{"-", "0.41274450725640877`"}]}], "}"}], ",", 
             RowBox[{"-", "84.41325719690103`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18582469749230796`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.57323765724591`", ",", "1.646089620359747`"}], "}"}],
              ",", "61.75363229871936`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18464906523227212`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8197075233683275`", ",", "2.104862101175398`"}], 
              "}"}], ",", "66.17472957299023`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09570032059428298`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.174197682692963`", ",", "1.5494748272910812`"}], 
              "}"}], ",", "72.36611098846686`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09543951924306254`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.186069607961884`", ",", "1.5868232171547578`"}], 
              "}"}], ",", "71.07315873438571`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.0293034668788104`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.036656461720002`", ",", "1.6775537955970146`"}], 
              "}"}], ",", "146.00799519914304`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.0213846701845166`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.625588209786038`", ",", "1.954739381579031`"}], 
              "}"}], ",", "145.02367496402`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0900926386418106`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.875024991266699`", ",", "1.5816524017169022`"}], 
              "}"}], ",", 
             RowBox[{"-", "140.35012059018047`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08730617473994005`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.386838787639893`", ",", "1.17707328175869`"}], "}"}],
              ",", 
             RowBox[{"-", "149.44190112564692`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1597814174755787`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.995683381404745`", ",", "1.3667402332319012`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.27384016322904`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15938277195077405`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.915766996348002`", ",", "1.329938586737978`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.71957428322997`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00870132615424994`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.987631729229609`", ",", "0.8005725958373693`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.35647719791575`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008679869408958098`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.972639396864549`", ",", "0.6844474588014469`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.26570875890071`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009405012611945766`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.082999887296782`", ",", "0.31698239836342923`"}], 
              "}"}], ",", 
             RowBox[{"-", "48.72257657422726`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009380802278179341`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.114516242080115`", ",", "0.28107956277846663`"}], 
              "}"}], ",", 
             RowBox[{"-", "47.878133048238155`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16564203078761788`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.132603163998297`", ",", "0.8633038107538517`"}], 
              "}"}], ",", "178.62417406471167`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16314354674625212`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0986847040374785`", ",", "0.8641184408836207`"}], 
              "}"}], ",", "171.70493080742685`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19829554761959076`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.359421295530483`", ",", 
               RowBox[{"-", "0.9513629506393492`"}]}], "}"}], ",", 
             RowBox[{"-", "149.8858550731669`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19571861166878693`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.158007169770423`", ",", 
               RowBox[{"-", "1.0681850780699813`"}]}], "}"}], ",", 
             RowBox[{"-", "156.3743121555345`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.059202186855767495`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.356816966072465`", ",", "1.0969723235612296`"}], 
              "}"}], ",", "152.78654714214778`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.058782329376076733`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.309155676079274`", ",", "1.1214810476127461`"}], 
              "}"}], ",", "148.03220095151582`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09335831416062572`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.560609031189221`", ",", "0.6257838054686258`"}], 
              "}"}], ",", 
             RowBox[{"-", "7.645507398506084`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09186435675773418`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.650244092232106`", ",", "0.6137514666967877`"}], 
              "}"}], ",", 
             RowBox[{"-", "0.5539459740844064`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05480909780125768`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.441039746564652`", ",", "1.1369156045927298`"}], 
              "}"}], ",", "156.37642894122624`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.054672499688885344`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.380342865732236`", ",", "1.1634631615150444`"}], 
              "}"}], ",", "155.9509014104194`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013133500391118599`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.415740315443308`", ",", "0.8455727215350262`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.105970616139`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0130814633506536`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3671627411517635`", ",", "0.8414132536242973`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.157432765967`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008228011738788303`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.43041916475558`", ",", "0.3419012486380427`"}], 
              "}"}], ",", 
             RowBox[{"-", "112.19939043891472`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008201918012840724`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.2825728163768`", ",", 
               RowBox[{"-", "0.02039618674577165`"}]}], "}"}], ",", 
             RowBox[{"-", "110.11159736536656`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011090489861349362`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.132844253351959`", ",", "1.133288049183445`"}], 
              "}"}], ",", 
             RowBox[{"-", "47.42160323557383`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010209838977461047`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.826067983688849`", ",", "0.37884217744721077`"}], 
              "}"}], ",", 
             RowBox[{"-", "59.76252654200126`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19619541455157707`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.111402240816899`", ",", "1.6956126639955889`"}], 
              "}"}], ",", "123.77931376106082`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1953461399360908`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.028279707946844`", ",", "1.8198766499719492`"}], 
              "}"}], ",", "120.53038515358611`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "4.03188542930406`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.184072372672007`", ",", "1.8586024464312514`"}], 
              "}"}], ",", "55.69408228750106`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.997855174516123`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.320906309499774`", ",", "2.0591489993432495`"}], 
              "}"}], ",", "60.94902774196264`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033743029800710284`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.440837379378749`", ",", "2.2750571618804605`"}], 
              "}"}], ",", "160.70584453509753`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17914775384064238`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.36240697690967`", ",", "1.8520156282570719`"}], 
              "}"}], ",", 
             RowBox[{"-", "12.391149186058719`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17853621610004966`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.6517446872126405`", ",", "1.7884474615593178`"}], 
              "}"}], ",", 
             RowBox[{"-", "14.78678744626888`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012866851797439688`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.599442986112421`", ",", "1.1595858165884754`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.50875478770797`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012829652935721525`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.578820183056489`", ",", "1.1362831538007814`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.867181857826`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0860920888178808`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.162702661414744`", ",", "0.9438053337150264`"}], 
              "}"}], ",", 
             RowBox[{"-", "6.2784534492874124`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08394844419421651`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.19531982452479`", ",", "0.9402167803239352`"}], 
              "}"}], ",", 
             RowBox[{"-", "14.693023096784009`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09775668342113808`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.395280740220098`", ",", "1.1447153361225655`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.8000666848845`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09441775778949685`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.341300350337997`", ",", "1.1378960908493214`"}], 
              "}"}], ",", "177.7907752843749`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07220329647274092`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.891581672955386`", ",", "0.3077814576649613`"}], 
              "}"}], ",", 
             RowBox[{"-", "8.921318682792975`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07200528489167993`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.077006186780842`", ",", "0.27867406472608236`"}], 
              "}"}], ",", 
             RowBox[{"-", "10.255264261604577`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27604757142353303`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.503571201537513`", ",", "1.5849363906658709`"}], 
              "}"}], ",", "121.39276621667733`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27456430801567877`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.440374935192335`", ",", "1.6884978939291888`"}], 
              "}"}], ",", "125.32547286957923`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014897967291963146`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3847302367062975`", ",", 
               RowBox[{"-", "0.6145580846091381`"}]}], "}"}], ",", 
             RowBox[{"-", "158.75074386180273`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014813936086023877`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2969396556608648`", ",", 
               RowBox[{"-", "0.6486966623067383`"}]}], "}"}], ",", 
             RowBox[{"-", "154.6710480778327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012888896312588756`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.444584970458577`", ",", 
               RowBox[{"-", "2.17407961338191`"}]}], "}"}], ",", 
             RowBox[{"-", "126.99866183785443`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012667005466950527`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.401395049186998`", ",", 
               RowBox[{"-", "2.231397359948631`"}]}], "}"}], ",", 
             RowBox[{"-", "134.30448198138762`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009188705645965512`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.466710937071036`", ",", 
               RowBox[{"-", "2.126897206581193`"}]}], "}"}], ",", 
             RowBox[{"-", "110.79274607193865`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009059551948214036`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3881037401442144`", ",", 
               RowBox[{"-", "2.333911060676379`"}]}], "}"}], ",", 
             RowBox[{"-", "104.07811920384727`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0186150727243756`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.1387084261467875`", ",", 
               RowBox[{"-", "2.3126263188259486`"}]}], "}"}], ",", 
             RowBox[{"-", "72.07280964305113`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01855211657722031`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.225760321846037`", ",", 
               RowBox[{"-", "2.5817075108829264`"}]}], "}"}], ",", 
             RowBox[{"-", "74.43118110298312`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09427569600372121`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.275115027170251`", ",", 
               RowBox[{"-", "2.39160072839328`"}]}], "}"}], ",", 
             RowBox[{"-", "15.332220155467173`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09404150968592384`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.376396982301569`", ",", 
               RowBox[{"-", "2.4193695636149584`"}]}], "}"}], ",", 
             RowBox[{"-", "14.975295945507634`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0136237096309247`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.415962670666085`", ",", 
               RowBox[{"-", "2.3208500429481655`"}]}], "}"}], ",", 
             "41.40836933211641`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013542091135676294`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.324472913554798`", ",", 
               RowBox[{"-", "1.5196546351294475`"}]}], "}"}], ",", 
             "37.148430003614614`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008046808763596223`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.29649179032783`", ",", 
               RowBox[{"-", "1.714548594238228`"}]}], "}"}], ",", 
             "13.38196810940487`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011082820058220305`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.920460688392599`", ",", 
               RowBox[{"-", "1.3157020578048386`"}]}], "}"}], ",", 
             RowBox[{"-", "2.8427661267000963`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01105083673751191`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.111345118114919`", ",", 
               RowBox[{"-", "1.3251806879671508`"}]}], "}"}], ",", 
             RowBox[{"-", "1.2108801552004895`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17746113791708212`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.08320727731976`", ",", 
               RowBox[{"-", "1.3467014046111412`"}]}], "}"}], ",", 
             RowBox[{"-", "162.82693385722854`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1743001972414755`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.061437346951778`", ",", 
               RowBox[{"-", "1.3534291110795635`"}]}], "}"}], ",", 
             RowBox[{"-", "155.42074939647335`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06436509829774531`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0823029265595387`", ",", "0.3204098587077727`"}], 
              "}"}], ",", "172.05901041129593`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06381637470298848`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.875842145644434`", ",", "0.349209221182765`"}], 
              "}"}], ",", "177.34257443950457`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024500226390709316`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.042768365054769`", ",", "2.0940943312606244`"}], 
              "}"}], ",", "77.38118513207493`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019871883268168213`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.073874337603238`", ",", "2.2330401138623297`"}], 
              "}"}], ",", "61.46822844173404`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008731504250084504`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.540441563317021`", ",", "1.658662282854143`"}], 
              "}"}], ",", "36.13657946256744`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008670982290149471`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.625737115933364`", ",", "1.7209443206159765`"}], 
              "}"}], ",", "31.448630735019787`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21876763927652582`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3362231553334047`", ",", 
               RowBox[{"-", "0.9367987626976133`"}]}], "}"}], ",", 
             RowBox[{"-", "151.81696869331026`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2177562740382631`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1561864118925493`", ",", 
               RowBox[{"-", "1.033264979160073`"}]}], "}"}], ",", 
             RowBox[{"-", "155.28019284672456`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013868686852757673`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.258971730969517`", ",", "2.3682680267369927`"}], 
              "}"}], ",", "107.19915656466061`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013809783044862618`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1707816353633187`", ",", "2.6531790411572076`"}], 
              "}"}], ",", "104.0134376852345`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011298262679029265`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.261063463459581`", ",", "3.37564683895124`"}], "}"}],
              ",", "70.92876669617111`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009928046162535169`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.317602229717479`", ",", "3.5391865573943955`"}], 
              "}"}], ",", "56.924628064479265`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030408831817915934`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0949401737714983`", ",", "3.1903948146437107`"}], 
              "}"}], ",", "85.14860085340219`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023802575426291463`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.100638485469136`", ",", "3.2575318555276516`"}], 
              "}"}], ",", "68.59384364830186`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008167407844043167`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4434141231202973`", ",", 
               RowBox[{"-", "2.618182018279854`"}]}], "}"}], ",", 
             RowBox[{"-", "72.39926764172202`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008129882585708893`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.507203505473403`", ",", 
               RowBox[{"-", "2.8192627123809926`"}]}], "}"}], ",", 
             RowBox[{"-", "75.84261907698817`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029071058343938503`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.131828495403569`", ",", 
               RowBox[{"-", "2.4140370798315542`"}]}], "}"}], ",", 
             RowBox[{"-", "40.6329275007733`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02840872678841154`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5736524678233232`", ",", 
               RowBox[{"-", "2.793166685997226`"}]}], "}"}], ",", 
             RowBox[{"-", "32.489843867872686`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009311596765202315`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4145530314090804`", ",", 
               RowBox[{"-", "1.7368927213868033`"}]}], "}"}], ",", 
             "14.53621011178783`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008892737407424346`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6175598185970927`", ",", 
               RowBox[{"-", "1.6842546957809021`"}]}], "}"}], ",", 
             "4.21884675598593`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2561055404059701`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.108755056526315`", ",", 
               RowBox[{"-", "2.2415706126908783`"}]}], "}"}], ",", 
             RowBox[{"-", "141.8830255659103`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25319534593083126`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0154221800005097`", ",", 
               RowBox[{"-", "2.3147975971414723`"}]}], "}"}], ",", 
             RowBox[{"-", "135.77933588385838`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010451198946883183`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.6650107297416685`", ",", "2.069805418458244`"}], 
              "}"}], ",", "20.60680717902263`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010424100011493862`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.063843397574225`", ",", "2.219770844068518`"}], 
              "}"}], ",", "19.693925905551648`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010491280187039336`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6579620877190564`", ",", "1.2411682766713321`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.1994456708172`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01046206966147482`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1701167073340666`", ",", "1.0845330539530924`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.77130934518595`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4050805738602362`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.64293783700036`", ",", "1.8804307999132586`"}], 
              "}"}], ",", "116.54305250335776`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4039430340575549`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.627751011380789`", ",", "1.9108336284133907`"}], 
              "}"}], ",", "118.02202676845064`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009693114947455218`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.297582025844731`", ",", "1.9168082156473396`"}], 
              "}"}], ",", "30.400776053589823`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009657370105847711`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.376064366816332`", ",", "1.9628549605429493`"}], 
              "}"}], ",", "27.70954729974`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009410713779352138`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8550571286116426`", ",", 
               RowBox[{"-", "0.5179270523033074`"}]}], "}"}], ",", 
             RowBox[{"-", "152.9254208574525`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009309332837770938`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.704601447193009`", ",", 
               RowBox[{"-", "0.5948348992005054`"}]}], "}"}], ",", 
             RowBox[{"-", "158.8767189675213`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0280588219837724`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.118371926014607`", ",", 
               RowBox[{"-", "0.7916360463911913`"}]}], "}"}], ",", 
             RowBox[{"-", "166.76098752244155`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.027285911110495113`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8896606650171655`", ",", 
               RowBox[{"-", "0.8454441103070542`"}]}], "}"}], ",", 
             RowBox[{"-", "175.48836913651695`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013494465091201462`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.364103526572395`", ",", 
               RowBox[{"-", "0.9270059505467887`"}]}], "}"}], ",", 
             RowBox[{"-", "171.8018358471945`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013459071982889852`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.161058715726155`", ",", 
               RowBox[{"-", "0.9562585138170068`"}]}], "}"}], ",", 
             RowBox[{"-", "170.78961842883695`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009472909390102981`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8600330983876`", ",", "0.07567180311158181`"}], 
              "}"}], ",", "153.12222029869108`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00943571583997411`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.767312050664425`", ",", "0.12266667029449653`"}], 
              "}"}], ",", "150.20550125958533`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10072774736858355`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.626023718036561`", ",", 
               RowBox[{"-", "0.4492137686747103`"}]}], "}"}], ",", 
             "34.530972375587304`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09965710111863778`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.72673538027961`", ",", 
               RowBox[{"-", "0.3799163735965593`"}]}], "}"}], ",", 
             "40.44391151188273`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02011784280062146`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.334496159081358`", ",", 
               RowBox[{"-", "0.6055118865612469`"}]}], "}"}], ",", 
             "81.52566298355424`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019825809161793266`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.342652343122805`", ",", 
               RowBox[{"-", "0.5507698702134257`"}]}], "}"}], ",", 
             "74.71772836827125`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014082386259038229`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.416265530500333`", ",", 
               RowBox[{"-", "1.3702567653724946`"}]}], "}"}], ",", 
             "102.20479246597178`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013809884103596163`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.410231089580755`", ",", 
               RowBox[{"-", "1.3423576688021113`"}]}], "}"}], ",", 
             "109.8566598373605`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.231310510328191`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5948414737607`", ",", 
               RowBox[{"-", "1.6208355140056565`"}]}], "}"}], ",", 
             RowBox[{"-", "55.69567807138846`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.209477790497711`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.666658242611352`", ",", 
               RowBox[{"-", "1.7260979029653378`"}]}], "}"}], ",", 
             RowBox[{"-", "52.56884804118948`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02174160161941837`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.823226157153527`", ",", 
               RowBox[{"-", "1.930649643545257`"}]}], "}"}], ",", 
             "72.95668857684666`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014007074744085104`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.33511329940802`", ",", 
               RowBox[{"-", "1.4558495987725213`"}]}], "}"}], ",", 
             "146.40385139125195`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013918848862568497`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.307758015701156`", ",", 
               RowBox[{"-", "1.4376774421161653`"}]}], "}"}], ",", 
             "141.99576309346932`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019989661948342154`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.636570319863082`", ",", 
               RowBox[{"-", "1.3161057789349486`"}]}], "}"}], ",", 
             "173.686247761809`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019934029997220225`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.443841666585319`", ",", 
               RowBox[{"-", "1.2947815133730185`"}]}], "}"}], ",", 
             "172.26078320920752`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09632964697135038`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.489914395050555`", ",", 
               RowBox[{"-", "1.6575550106708106`"}]}], "}"}], ",", 
             RowBox[{"-", "144.1847520631457`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09597518380971577`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.32590391948947`", ",", 
               RowBox[{"-", "1.7759094604061625`"}]}], "}"}], ",", 
             RowBox[{"-", "146.86800062988058`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01348882622830329`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3712579755478105`", ",", 
               RowBox[{"-", "0.6419208330212081`"}]}], "}"}], ",", 
             "150.4857607774859`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013437340610427924`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1564270156805865`", ",", 
               RowBox[{"-", "0.520304833930549`"}]}], "}"}], ",", 
             "153.30222928298647`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019043386185443257`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.41150589720002`", ",", "1.1926671838836118`"}], 
              "}"}], ",", "102.94404064072947`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015376806516702356`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.354979373850421`", ",", "1.4386060953362028`"}], 
              "}"}], ",", "86.94491153535182`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026517743192262206`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.966496046375656`", ",", "1.6530371043377268`"}], 
              "}"}], ",", "74.05305533960501`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026059017545362138`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.051610080316026`", ",", "1.9509057415606017`"}], 
              "}"}], ",", "81.37305675608414`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11181417082318149`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.151550991487545`", ",", "0.3339560449741226`"}], 
              "}"}], ",", "172.80240646833667`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11136090835582428`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5911278109148954`", ",", "0.40473004330086804`"}], 
              "}"}], ",", "169.77476240322196`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04307269117795738`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.727886367284384`", ",", 
               RowBox[{"-", "0.8570999932866199`"}]}], "}"}], ",", 
             RowBox[{"-", "126.63687570729903`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04274634605243103`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.664926309399225`", ",", 
               RowBox[{"-", "0.9417618929029387`"}]}], "}"}], ",", 
             RowBox[{"-", "131.58213426000492`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023270915190478556`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.578707936680302`", ",", 
               RowBox[{"-", "1.6625646141888275`"}]}], "}"}], ",", 
             RowBox[{"-", "94.31394572759326`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02319900721475991`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.567958176702326`", ",", 
               RowBox[{"-", "1.8050679294545213`"}]}], "}"}], ",", 
             RowBox[{"-", "96.28474086495915`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01201760350620879`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.366015524438264`", ",", 
               RowBox[{"-", "0.8484054132965815`"}]}], "}"}], ",", 
             RowBox[{"-", "57.83876764308892`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011981220273258689`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.390699751889108`", ",", 
               RowBox[{"-", "0.8876621830023901`"}]}], "}"}], ",", 
             RowBox[{"-", "55.964080144758455`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009696734588689125`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.940507675890693`", ",", "1.090761132862692`"}], 
              "}"}], ",", "123.92325898847831`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009665706492078707`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.906650267057244`", ",", "1.1411021167992952`"}], 
              "}"}], ",", "126.05023824826934`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01623231525874228`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.975305451484222`", ",", "1.144078691628268`"}], 
              "}"}], ",", "86.04807367745038`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016183740011021297`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.991925785457024`", ",", "1.3846612093021353`"}], 
              "}"}], ",", "87.86631700644675`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1328868511375348`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.438952443142733`", ",", 
               RowBox[{"-", "0.6266931228462786`"}]}], "}"}], ",", 
             RowBox[{"-", "81.63370461722407`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1324858712460342`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.470287291566744`", ",", 
               RowBox[{"-", "0.8397595192879214`"}]}], "}"}], ",", 
             RowBox[{"-", "79.7750057913425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009020334217983232`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.600626168023581`", ",", 
               RowBox[{"-", "0.20339427849454245`"}]}], "}"}], ",", 
             "169.4912992699466`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008270635030373886`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.538987903316532`", ",", 
               RowBox[{"-", "0.1919606194188685`"}]}], "}"}], ",", 
             "156.9780873057337`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.633570517660891`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.882934929861941`", ",", 
               RowBox[{"-", "0.2757101473357457`"}]}], "}"}], ",", 
             RowBox[{"-", "14.176211798487442`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.590303230054508`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.129580112651137`", ",", 
               RowBox[{"-", "0.3380120252934028`"}]}], "}"}], ",", 
             RowBox[{"-", "7.93863076458169`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0427520758696878`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.371022184652178`", ",", 
               RowBox[{"-", "0.3716808198235361`"}]}], "}"}], ",", 
             "82.97489039043516`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008975824316198333`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.605830110964485`", ",", 
               RowBox[{"-", "0.1854840910062472`"}]}], "}"}], ",", 
             "162.15627713308413`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008896853607336734`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.583808442483033`", ",", 
               RowBox[{"-", "0.17839516500404123`"}]}], "}"}], ",", 
             "156.78264751015834`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12386341584104354`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.8898389876045965`", ",", "0.310250823629456`"}], 
              "}"}], ",", "62.43831362207722`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12354873668994602`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.923392072908012`", ",", "0.37453662136558347`"}], 
              "}"}], ",", "61.73434159606469`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015961321692052968`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.125657458194816`", ",", 
               RowBox[{"-", "0.41832732762270464`"}]}], "}"}], ",", 
             RowBox[{"-", "160.96983440377`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01592172875302877`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.080637716367729`", ",", 
               RowBox[{"-", "0.43385538527627593`"}]}], "}"}], ",", 
             RowBox[{"-", "160.6466930788365`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009594863058565406`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.370259476906691`", ",", "0.6360526074102332`"}], 
              "}"}], ",", "163.6992815472785`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009552742827458662`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.342481872083101`", ",", "0.6441757256033335`"}], 
              "}"}], ",", "160.4040789067542`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2841535494198482`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.840886796903556`", ",", 
               RowBox[{"-", "0.5681950703666385`"}]}], "}"}], ",", 
             RowBox[{"-", "78.37943677646012`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27922743402544303`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.866761886098688`", ",", 
               RowBox[{"-", "0.694019397587685`"}]}], "}"}], ",", 
             RowBox[{"-", "85.70577638103478`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2891501326551351`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.149448457539012`", ",", "0.10347078033821677`"}], 
              "}"}], ",", 
             RowBox[{"-", "69.45031587719765`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2882825865942385`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.238157393487466`", ",", 
               RowBox[{"-", "0.13316628934978925`"}]}], "}"}], ",", 
             RowBox[{"-", "71.28136617987171`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.34313034499645995`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.390408105692144`", ",", "0.7150344162751484`"}], 
              "}"}], ",", 
             RowBox[{"-", "68.56899156786663`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.34225796082991805`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.419974370971576`", ",", "0.6397102217070847`"}], 
              "}"}], ",", 
             RowBox[{"-", "69.28163178729251`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20473374778223055`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3775247299827535`", ",", "1.391018043860573`"}], 
              "}"}], ",", 
             RowBox[{"-", "148.44521259525752`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20422639908246404`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.341954503215509`", ",", "1.3691737677150844`"}], 
              "}"}], ",", 
             RowBox[{"-", "148.14815294784609`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "73.79176807230742`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.543884862887944`", ",", "1.6644691373106297`"}], 
              "}"}], ",", "57.31225967826247`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "72.40537642210035`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.590368247538926`", ",", "1.7369085399029403`"}], 
              "}"}], ",", "49.748154432180556`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3603442758456952`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.738157029364659`", ",", "1.911472297130765`"}], 
              "}"}], ",", 
             RowBox[{"-", "31.62938407433456`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02555799914688803`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.932904742021405`", ",", "1.7915249845889867`"}], 
              "}"}], ",", 
             RowBox[{"-", "113.00692258084968`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20360550783162337`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.512885661753796`", ",", "1.345893802643445`"}], 
              "}"}], ",", 
             RowBox[{"-", "96.93026804821667`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20302652711350602`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.496842644551443`", ",", "1.2139061125156703`"}], 
              "}"}], ",", 
             RowBox[{"-", "95.37935071670816`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3405463895680606`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.57982954868064`", ",", "1.3401081333321252`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.39277683529502`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3396831595089225`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.359754642466834`", ",", "1.3107156326557965`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.71555091097684`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2914970015936533`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.883323261180942`", ",", "1.0085602719018325`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.84043343735198`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2907377575713962`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.67637167252377`", ",", "0.978887154996747`"}], "}"}],
              ",", 
             RowBox[{"-", "172.79362645868295`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2947920179144425`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.858833762293857`", ",", "1.081384031628743`"}], 
              "}"}], ",", "174.6693300389285`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2933092808604072`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6671547952838885`", ",", "1.099269044092898`"}], 
              "}"}], ",", "178.39877808417347`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009331740870556703`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.468322005052908`", ",", 
               RowBox[{"-", "0.690413361520776`"}]}], "}"}], ",", 
             RowBox[{"-", "80.3030093864523`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009308691707241247`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.4922024195277235`", ",", 
               RowBox[{"-", "0.830163736610522`"}]}], "}"}], ",", 
             RowBox[{"-", "80.48990514360716`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1834808706876179`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.902671251455068`", ",", "2.2927415826140214`"}], 
              "}"}], ",", "70.59582684726125`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18302503380982799`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.918722068695445`", ",", "2.3383097548097824`"}], 
              "}"}], ",", "70.2359262181389`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0951794286245165`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.287150018382918`", ",", "1.8816042394023436`"}], 
              "}"}], ",", "69.78020648030486`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0944078045663355`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.356777134173283`", ",", "2.0706436486224016`"}], 
              "}"}], ",", "74.91982218307797`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.013486573740879`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.434632846005179`", ",", "2.0883302110018165`"}], 
              "}"}], ",", "144.03935472889586`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.006058013087019`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.377379804505068`", ",", "2.129866926644981`"}], 
              "}"}], ",", "143.9855297802709`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08460589303001663`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.216418216343868`", ",", "1.0764549847096392`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.53368166111326`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08439661581420521`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.161659475834462`", ",", "1.054922119649615`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.77545157257856`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15898512102382034`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.589348707423781`", ",", "1.1826893079768626`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.16530840323253`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12103378312832232`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.518103669062487`", ",", "1.1512149591504777`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.1642411214983`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028891974108604036`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.461139648466303`", ",", "1.1443863509174352`"}], 
              "}"}], ",", 
             RowBox[{"-", "153.40955666061444`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008658465574212347`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.934336026432902`", ",", "0.3840163419848044`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.17494031987762`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008553618377615537`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.904292357145209`", ",", "0.1453567907485327`"}], 
              "}"}], ",", 
             RowBox[{"-", "90.8892706574212`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009356654266526165`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.269243314924368`", ",", "0.10997104284251004`"}], 
              "}"}], ",", 
             RowBox[{"-", "47.03368952224905`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009316071866090764`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3793113611938725`", ",", 
               RowBox[{"-", "0.008201718506410174`"}]}], "}"}], ",", 
             RowBox[{"-", "43.778225425488465`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16068274892785345`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.874911054466808`", ",", "0.8967438186105634`"}], 
              "}"}], ",", "164.7856875501421`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16028158611906965`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.67989996195875`", ",", "0.9497794729162449`"}], 
              "}"}], ",", "164.32785678993352`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19317516410929736`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9514534114328006`", ",", 
               RowBox[{"-", "1.1585364994661662`"}]}], "}"}], ",", 
             RowBox[{"-", "162.86276923790209`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1922473465867297`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.88193336815691`", ",", 
               RowBox[{"-", "1.17997311673636`"}]}], "}"}], ",", 
             RowBox[{"-", "159.27792326821194`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.058365449494218354`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.0960916602283275`", ",", "1.2544517791728071`"}], 
              "}"}], ",", "143.277854760884`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.050483767032209075`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.959387763546078`", ",", "1.3564299397503847`"}], 
              "}"}], ",", "128.82748594619622`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09039430626384935`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.885969195992962`", ",", "0.6114723626851394`"}], 
              "}"}], ",", "6.537615450337324`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08664499971912516`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.2096543937444535`", ",", "0.6485669109904696`"}], 
              "}"}], ",", "16.582958055645328`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05453624201350348`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0774646795014835`", ",", "1.2986243324192273`"}], 
              "}"}], ",", "155.52537387961166`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.052956282245871136`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.01246476383433`", ",", "1.3282117434903686`"}], 
              "}"}], ",", "146.64011992087444`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013029632489310678`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.096699440575585`", ",", "0.8041596610668059`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.2088949157949`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012996707814092888`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.895066441242999`", ",", "0.7657285500947084`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.57083462606306`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00817590703866301`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.165712099764965`", ",", 
               RowBox[{"-", "0.3395329293425942`"}]}], "}"}], ",", 
             RowBox[{"-", "108.02380429181804`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008122867838280187`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.134211892678214`", ",", 
               RowBox[{"-", "0.4363437224036853`"}]}], "}"}], ",", 
             RowBox[{"-", "112.51855169838343`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0093991170136647`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9089651371026575`", ",", "0.23662464116783447`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.10344984842796`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009356549167343929`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.947263191339536`", ",", "0.11802716847812038`"}], 
              "}"}], ",", 
             RowBox[{"-", "68.70651842993273`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19450054159088923`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.871677664455433`", ",", "2.085412051030004`"}], 
              "}"}], ",", "117.28145654611117`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19212239195866207`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.821416870401075`", ",", "2.182867931844339`"}], 
              "}"}], ",", "123.59486529394175`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03403025478793858`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.320906309499774`", ",", "2.0591489993432495`"}], 
              "}"}], ",", 
             RowBox[{"-", "33.55284359671073`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03392739336227029`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.3633446608630795`", ",", "2.0310033450348413`"}], 
              "}"}], ",", 
             RowBox[{"-", "31.68585586749268`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.9641121447154126`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.440837379378749`", ",", "2.2750571618804605`"}], 
              "}"}], ",", "66.20397319642422`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.949966292510657`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.472040952293647`", ",", "2.3458184217531763`"}], 
              "}"}], ",", "68.77223420362462`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014095373023719666`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.583810886957185`", ",", "2.633564846050262`"}], 
              "}"}], ",", 
             RowBox[{"-", "157.26009069750867`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03345822907371311`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.2077278035136985`", ",", "2.356664280519256`"}], 
              "}"}], ",", "165.96078998955915`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03330863362328728`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.164941740114911`", ",", "2.3673631501433543`"}], 
              "}"}], ",", "162.60558641409048`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1779267659011658`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.897227864791424`", ",", "1.7236485654343994`"}], 
              "}"}], ",", 
             RowBox[{"-", "17.182425706479197`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17703044897375564`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.0821012120622076`", ",", "1.6664828386215795`"}], 
              "}"}], ",", 
             RowBox[{"-", "13.448168865552617`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012792561618205705`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.372007422895698`", ",", "0.8886497691912926`"}], 
              "}"}], ",", 
             RowBox[{"-", "128.22560892794382`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012759855650103761`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.350843936590856`", ",", "0.8617804958970844`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.00009387426755`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08185817511685006`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3821519417883765`", ",", "0.8912266074744308`"}], 
              "}"}], ",", 
             RowBox[{"-", "23.107592744280463`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08163762128954866`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.622852413903404`", ",", "0.7885214531920586`"}], 
              "}"}], ",", 
             RowBox[{"-", "21.891829929084864`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09119287473769258`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.156171182713343`", ",", "1.1450378863667876`"}], 
              "}"}], ",", "168.38161725363437`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08995559488743221`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.153496893426274`", ",", "1.1455877333499838`"}], 
              "}"}], ",", "174.99420717553255`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2730890145034687`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.278409306365115`", ",", "1.9170346464985808`"}], 
              "}"}], ",", "129.2581795224812`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2640567711830703`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.201877408545196`", ",", "2.010677723111943`"}], 
              "}"}], ",", "138.56392078050183`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008733507688182688`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.055325171769849`", ",", "2.140045002997775`"}], 
              "}"}], ",", 
             RowBox[{"-", "149.36459029356257`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014730378853710223`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.056035109608411`", ",", 
               RowBox[{"-", "0.7627206856098533`"}]}], "}"}], ",", 
             RowBox[{"-", "150.59135229386254`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014371721753125401`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9121687742877462`", ",", 
               RowBox[{"-", "0.8438138098897752`"}]}], "}"}], ",", 
             RowBox[{"-", "158.93718043375475`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012448934618477603`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.250973596039403`", ",", 
               RowBox[{"-", "2.385515828997722`"}]}], "}"}], ",", 
             RowBox[{"-", "141.6103021249209`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012388138816846063`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.141155509164145`", ",", 
               RowBox[{"-", "2.4725244263466686`"}]}], "}"}], ",", 
             RowBox[{"-", "145.2476014214346`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008932213596201732`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.334963802773455`", ",", 
               RowBox[{"-", "2.54581248256604`"}]}], "}"}], ",", 
             RowBox[{"-", "97.36349233575606`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008900564346459292`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.330985085163504`", ",", 
               RowBox[{"-", "2.576600492582407`"}]}], "}"}], ",", 
             RowBox[{"-", "99.90470929697905`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0184893733476573`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.290875589312144`", ",", 
               RowBox[{"-", "2.815415160633884`"}]}], "}"}], ",", 
             RowBox[{"-", "76.78955256291572`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018103943472246403`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.329760945790908`", ",", 
               RowBox[{"-", "2.9810678518678104`"}]}], "}"}], ",", 
             RowBox[{"-", "68.91496864211445`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09380790510057467`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.709709089406296`", ",", 
               RowBox[{"-", "2.50852625996953`"}]}], "}"}], ",", 
             RowBox[{"-", "14.618371735546045`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.092370580340839`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.863121642356406`", ",", 
               RowBox[{"-", "2.5485397701708075`"}]}], "}"}], ",", 
             RowBox[{"-", "7.65351903979394`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013460961609948455`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.529897953148777`", ",", 
               RowBox[{"-", "1.3640197673514542`"}]}], "}"}], ",", 
             "32.8884906751128`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013424507334127814`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.627798623920488`", ",", 
               RowBox[{"-", "1.3007128758044786`"}]}], "}"}], ",", 
             "31.63753452983537`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011018945715766977`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.41383491331418`", ",", 
               RowBox[{"-", "1.3315744125057838`"}]}], "}"}], ",", 
             "0.4210058162993401`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010972780041362174`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.641643426389006`", ",", 
               RowBox[{"-", "1.3299004596253732`"}]}], "}"}], ",", 
             "3.560899376028884`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1711955592926065`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.866810299806632`", ",", 
               RowBox[{"-", "1.442451087010559`"}]}], "}"}], ",", 
             RowBox[{"-", "148.01456493571828`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17032709141775013`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.419159283002482`", ",", 
               RowBox[{"-", "1.7220162844483655`"}]}], "}"}], ",", 
             RowBox[{"-", "151.77055552142684`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06327232907177721`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.605303873416047`", ",", "0.3617660148907954`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.37386153228672`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0629808306555191`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.300476159870274`", ",", "0.3477845166552455`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.92174987800684`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01611788145653439`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1481400246627125`", ",", "2.369639803748075`"}], 
              "}"}], ",", "45.55527175139333`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014107026393222017`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.367259958218387`", ",", "2.59304855884162`"}], "}"}],
              ",", "31.434606317864716`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008610879834978966`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.811440419389403`", ",", "1.8345145594733225`"}], 
              "}"}], ",", "26.76068200747205`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00802715695922945`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.985714678248692`", ",", "1.922396766792331`"}], 
              "}"}], ",", "38.51616765525809`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013751129416283115`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.114866436608288`", ",", "2.87721879600748`"}], "}"}],
              ",", "100.82771880580843`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008092529737647243`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5716690254112136`", ",", 
               RowBox[{"-", "3.0748271865089367`"}]}], "}"}], ",", 
             RowBox[{"-", "79.28597051225451`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02776148526105819`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7370821451708434`", ",", 
               RowBox[{"-", "2.897242151157988`"}]}], "}"}], ",", 
             RowBox[{"-", "24.346760234972212`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02769265687691364`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9134400662329862`", ",", 
               RowBox[{"-", "2.9770441415149165`"}]}], "}"}], ",", 
             RowBox[{"-", "24.65664235205616`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008492719411232584`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.767724301347901`", ",", 
               RowBox[{"-", "1.6731776431117509`"}]}], "}"}], ",", 
             RowBox[{"-", "6.098516599816007`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00847171375373309`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.05889476923608`", ",", 
               RowBox[{"-", "1.7042871649611344`"}]}], "}"}], ",", 
             RowBox[{"-", "6.3378105672945635`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010432940465813664`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.847931087938611`", ",", "0.9721552211046295`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.3431730195547`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01040388742614954`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.413079136039623`", ",", "0.8082127062037942`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.7723371645825`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4028086886731848`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5075177202934777`", ",", "2.1367499951643203`"}], 
              "}"}], ",", "119.5010010335433`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3936760800675188`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.45669261763965`", ",", "2.226579398023197`"}], "}"}],
              ",", "127.6292662182781`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008925551155592217`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.332308243559459`", ",", "2.3879252482139632`"}], 
              "}"}], ",", 
             RowBox[{"-", "154.35676891624718`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009621757078802242`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.637363154484737`", ",", "2.100095438023548`"}], 
              "}"}], ",", "25.018318545890313`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009555005386657857`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.669297845975176`", ",", "2.114999261324612`"}], 
              "}"}], ",", "29.70883535266231`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009209044065769745`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4748039084685063`", ",", 
               RowBox[{"-", "0.6836136830671304`"}]}], "}"}], ",", 
             RowBox[{"-", "164.82801707759012`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009181855406227324`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3839809742100564`", ",", 
               RowBox[{"-", "0.7082420446104155`"}]}], "}"}], ",", 
             RowBox[{"-", "166.57888534747923`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026534290910731333`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7044712285073365`", ",", 
               RowBox[{"-", "0.8600566613744223`"}]}], "}"}], ",", 
             "175.7842492494077`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026363873661098672`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6789730870763115`", ",", 
               RowBox[{"-", "0.8581771474698388`"}]}], "}"}], ",", 
             RowBox[{"-", "179.7504135633546`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013423771703164444`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8477455568113452`", ",", 
               RowBox[{"-", "1.0070624334439158`"}]}], "}"}], ",", 
             RowBox[{"-", "169.77740101047976`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013341396477410651`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6896996591254667`", ",", 
               RowBox[{"-", "1.035563739061351`"}]}], "}"}], ",", 
             RowBox[{"-", "174.10852634213`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009398668323140206`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5831585270802275`", ",", "0.2281089080558495`"}], 
              "}"}], ",", "147.28878222047956`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009372900830459567`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.169421741661696`", ",", "0.4938376082481516`"}], 
              "}"}], ",", "148.6208400652999`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09859783488484906`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.888559142148566`", ",", 
               RowBox[{"-", "0.24197956494456557`"}]}], "}"}], ",", 
             "46.356850648178096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09823175194889973`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.960429604410104`", ",", 
               RowBox[{"-", "0.1666218653883848`"}]}], "}"}], ",", 
             "49.073158839067936`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019538014727289936`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.397588857222164`", ",", 
               RowBox[{"-", "0.3497113918811222`"}]}], "}"}], ",", 
             "67.90979375298828`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019489859011447036`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4653602179059835`", ",", 
               RowBox[{"-", "0.18272877991268882`"}]}], "}"}], ",", 
             "67.9286864545682`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01354265501930516`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.341191770303148`", ",", 
               RowBox[{"-", "1.1511869589989376`"}]}], "}"}], ",", 
             "117.50852720874924`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013492489451439745`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.236059442686831`", ",", 
               RowBox[{"-", "0.9493030010524817`"}]}], "}"}], ",", 
             "114.80075560744797`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021832719830477885`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.666658242611352`", ",", 
               RowBox[{"-", "1.7260979029653378`"}]}], "}"}], ",", 
             RowBox[{"-", "174.96755462902658`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021773850230226044`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3802853501272025`", ",", 
               RowBox[{"-", "1.7513157008069478`"}]}], "}"}], ",", 
             RowBox[{"-", "173.74649030519294`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.1877361888782945`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.823226157153527`", ",", 
               RowBox[{"-", "1.930649643545257`"}]}], "}"}], ",", 
             RowBox[{"-", "49.442018010990736`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.144021869820614`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.863139321655691`", ",", 
               RowBox[{"-", "1.9772863051707465`"}]}], "}"}], ",", 
             RowBox[{"-", "44.19175667322398`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04334596152732044`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.022041265246742`", ",", 
               RowBox[{"-", "2.1317672179825253`"}]}], "}"}], ",", 
             "55.61138267740907`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021650863687520526`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.898725692883722`", ",", 
               RowBox[{"-", "1.6843677998318296`"}]}], "}"}], ",", 
             "76.08351860704516`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021577543430302697`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.90382085132422`", ",", 
               RowBox[{"-", "1.663804587281601`"}]}], "}"}], ",", 
             "73.71981264722203`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013831178686387337`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.106842406878487`", ",", 
               RowBox[{"-", "1.2806810371144008`"}]}], "}"}], ",", 
             "137.5876747956866`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013751558650465753`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.978182730931252`", ",", 
               RowBox[{"-", "1.1631478453094757`"}]}], "}"}], ",", 
             "133.44678540841971`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019878552871827406`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.119803288382871`", ",", 
               RowBox[{"-", "1.2507439383342212`"}]}], "}"}], ",", 
             "170.83531865660606`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019829222934472254`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.918159887220145`", ",", 
               RowBox[{"-", "1.2182123801542875`"}]}], "}"}], ",", 
             "171.16856072295886`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09562202496234898`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.141316224293418`", ",", 
               RowBox[{"-", "1.8963876196907001`"}]}], "}"}], ",", 
             RowBox[{"-", "149.55124919661532`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09538462304405353`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.137011277797102`", ",", 
               RowBox[{"-", "1.8989182429969074`"}]}], "}"}], ",", 
             RowBox[{"-", "149.20691565097445`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013386051508454167`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.909899322736532`", ",", 
               RowBox[{"-", "0.39632633971432635`"}]}], "}"}], ",", 
             "156.11869778848666`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013337406193758792`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.826113860211855`", ",", 
               RowBox[{"-", "0.35923044026463574`"}]}], "}"}], ",", 
             "153.48184052393793`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012416183568909675`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.362812811651092`", ",", "1.5853767994063988`"}], 
              "}"}], ",", "70.94578242997433`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012172288816274489`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.367294364003814`", ",", "1.5983522727364021`"}], 
              "}"}], ",", "78.64241529489833`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02560822731052177`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.076721279197129`", ",", "2.116419354507405`"}], 
              "}"}], ",", "88.69305817256333`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025250848033238505`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.078080013573787`", ",", "2.1759753661073877`"}], 
              "}"}], ",", "81.99908196305839`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11090948328405656`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3223761266728817`", ",", "0.45320832530609795`"}], 
              "}"}], ",", "166.7471183381069`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11062956885746135`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1763382067299815`", ",", "0.4876034430521933`"}], 
              "}"}], ",", "166.12504273234796`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04242247351772829`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.5046753581612275`", ",", 
               RowBox[{"-", "1.1223702829451243`"}]}], "}"}], ",", 
             RowBox[{"-", "136.52739281271073`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04214961154879319`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.415850647724226`", ",", 
               RowBox[{"-", "1.2065811131300719`"}]}], "}"}], ",", 
             RowBox[{"-", "140.99706139902042`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023127321437305916`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.532598262384877`", ",", 
               RowBox[{"-", "2.126137966057005`"}]}], "}"}], ",", 
             RowBox[{"-", "98.25553600232483`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02306989640155276`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5055179968266055`", ",", 
               RowBox[{"-", "2.312780313975175`"}]}], "}"}], ",", 
             RowBox[{"-", "98.60256193373222`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011944947190359654`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.558502686551672`", ",", 
               RowBox[{"-", "1.1361041517412096`"}]}], "}"}], ",", 
             RowBox[{"-", "54.089392646427996`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01188117040879269`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.641624614133751`", ",", 
               RowBox[{"-", "1.2508878463061588`"}]}], "}"}], ",", 
             RowBox[{"-", "50.17604286045781`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009634777680724621`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.7072547024128575`", ",", "1.4150411308714208`"}], 
              "}"}], ",", "128.17721750806052`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009602697319747713`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.655358674577875`", ",", "1.4810432047924222`"}], 
              "}"}], ",", "130.47210534108746`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016135310124861718`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.001660413572281`", ",", "1.6459442831685513`"}], 
              "}"}], ",", "89.68456033544354`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016090017719086726`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.003201024612557`", ",", "1.9257747184821181`"}], 
              "}"}], ",", "91.16114531570773`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1320861012927029`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.523807089318023`", ",", 
               RowBox[{"-", "1.1364673427704632`"}]}], "}"}], ",", 
             RowBox[{"-", "77.91630696546075`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1305648895256623`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.578043295185931`", ",", 
               RowBox[{"-", "1.389808408822895`"}]}], "}"}], ",", 
             RowBox[{"-", "84.05837841619474`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04326728760638411`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.129580112651137`", ",", 
               RowBox[{"-", "0.3380120252934028`"}]}], "}"}], ",", 
             RowBox[{"-", "92.61457088569271`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03955961226727557`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.112982644365966`", ",", 
               RowBox[{"-", "0.7014769110622621`"}]}], "}"}], ",", 
             RowBox[{"-", "79.98500138122373`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04224299909425905`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.400837322111133`", ",", 
               RowBox[{"-", "0.12973264472074342`"}]}], "}"}], ",", 
             "89.21247142434098`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04190150848794057`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.41846620837065`", ",", "1.152756908452858`"}], "}"}],
              ",", "94.34391231043831`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00881857769514655`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.380663139819714`", ",", 
               RowBox[{"-", "0.09125414151794078`"}]}], "}"}], ",", 
             "151.40901788723272`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008789188700428658`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.153035130388449`", ",", "0.03280620533953821`"}], 
              "}"}], ",", "153.7075807309928`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12323485699175779`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.080195487154919`", ",", "0.6661707831798577`"}], 
              "}"}], ",", "61.03036957005266`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12279693417128397`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.087933797518698`", ",", "0.6801485323010795`"}], 
              "}"}], ",", "58.47806474206751`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015882234026474134`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.825637039936708`", ",", 
               RowBox[{"-", "0.5234217821511212`"}]}], "}"}], ",", 
             RowBox[{"-", "160.3235517539019`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015798993829612164`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.652425320378326`", ",", 
               RowBox[{"-", "0.5853602408820765`"}]}], "}"}], ",", 
             RowBox[{"-", "164.18011432960517`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009510807498820831`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.091004786913011`", ",", "0.7337025154327036`"}], 
              "}"}], ",", "157.10887626622977`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008799909207814084`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.850167520404469`", ",", "0.8353921946611623`"}], 
              "}"}], ",", "169.2238133974156`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2743867182782657`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.881191250877583`", ",", 
               RowBox[{"-", "0.8861829153964238`"}]}], "}"}], ",", 
             RowBox[{"-", "93.03211598560948`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.273103411309412`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.880779105955508`", ",", 
               RowBox[{"-", "0.8939636586819787`"}]}], "}"}], ",", 
             RowBox[{"-", "89.5317173032171`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28741764345854515`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.331543225782122`", ",", 
               RowBox[{"-", "0.40876767013290327`"}]}], "}"}], ",", 
             RowBox[{"-", "73.11241648254577`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28387955112004487`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.335812371414638`", ",", 
               RowBox[{"-", "0.42283003841443123`"}]}], "}"}], ",", 
             RowBox[{"-", "66.77961154555182`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3413877946372311`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.548191576253571`", ",", "0.30072193789939994`"}], 
              "}"}], ",", 
             RowBox[{"-", "69.9942720067184`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3160805289196947`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.581851068272584`", ",", "0.2082720020311536`"}], 
              "}"}], ",", 
             RowBox[{"-", "57.91003989472051`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023431224136205592`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.675336249011812`", ",", "0.05918582749291684`"}], 
              "}"}], ",", "4.42994113969281`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20372030763855262`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.055504511607546`", ",", "1.1912081890792554`"}], 
              "}"}], ",", 
             RowBox[{"-", "147.8510933004322`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19112322792901326`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.983547199606125`", ",", "1.1459838153379867`"}], 
              "}"}], ",", 
             RowBox[{"-", "136.42764059125062`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011818137153208003`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.863324853607964`", ",", "1.031608164437147`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.20874463888306`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.38639165020708`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.590368247538926`", ",", "1.7369085399029403`"}], 
              "}"}], ",", "123.56158769261376`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3806870656860148`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.503845818473073`", ",", "1.867324869727871`"}], 
              "}"}], ",", "120.48285386545193`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "71.04503214625467`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.738157029364659`", ",", "1.911472297130765`"}], 
              "}"}], ",", "42.184049186098626`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "70.78086318727493`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.066377499692184`", ",", "2.2089179863153836`"}], 
              "}"}], ",", "39.46237545796201`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26318669129995625`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.279619357017198`", ",", "2.3844659508650694`"}], 
              "}"}], ",", 
             RowBox[{"-", "92.11663331440805`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3347862766988072`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.932904742021405`", ",", "1.7915249845889867`"}], 
              "}"}], ",", 
             RowBox[{"-", "39.19348932041634`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2472027523639106`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.353376858084014`", ",", "1.4486758481567938`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.83063242442032`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08183663146610168`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.471556087494077`", ",", "1.3036155224815655`"}], 
              "}"}], ",", 
             RowBox[{"-", "114.41652348547844`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02507781826033543`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.843510263820795`", ",", "1.5809955172019488`"}], 
              "}"}], ",", 
             RowBox[{"-", "120.57102782693131`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02483729915265739`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.742433758337944`", ",", "1.4098870680789055`"}], 
              "}"}], ",", 
             RowBox[{"-", "114.95122892952203`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20244919280798096`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.464985043809726`", ",", "0.8755865366445774`"}], 
              "}"}], ",", 
             RowBox[{"-", "93.82843338519893`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20193058988788956`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.449521888375906`", ",", "0.6445117044053194`"}], 
              "}"}], ",", 
             RowBox[{"-", "93.03334959314469`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.338822117598471`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.051399004163451`", ",", "1.2658168799102762`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.03832498665756`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3379617789708981`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.9381947141431874`", ",", "1.2479646951500007`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.73614988969695`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28998049110459306`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.348678083172981`", ",", "0.9374527928655113`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.7468194800147`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28837576716301516`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.146843271438939`", ",", "0.915336947551428`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.7689787322483`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2918340016377845`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.363292513720586`", ",", "1.1077631715094527`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.87177387058156`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2909368741618161`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.180835378956244`", ",", "1.1009827641266325`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.92492303516144`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009285699474774697`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.544058705200856`", ",", 
               RowBox[{"-", "1.1397096353662313`"}]}], "}"}], ",", 
             RowBox[{"-", "80.67680090076398`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009248513187835832`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.585515200998242`", ",", 
               RowBox[{"-", "1.3922282078274029`"}]}], "}"}], ",", 
             RowBox[{"-", "83.66245397692349`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1825703294057307`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.023459793219201`", ",", "2.629803328498619`"}], 
              "}"}], ",", "69.87602558901452`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18050619647547012`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.10368184781019`", ",", "2.848736495535804`"}], "}"}],
              ",", "75.96526405634826`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.093642436100311`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.42157587195393`", ",", "2.311129214326098`"}], "}"}],
              ",", "80.05943788585101`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09341025455145736`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.428421427838424`", ",", "2.3501891946211466`"}], 
              "}"}], ",", "79.74774011460116`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "2.99864776461476`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.105130303168906`", ",", "2.32777283886906`"}], "}"}],
              ",", "143.93170483163917`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.1357602968139426`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.973860009185009`", ",", "2.4233855638274715`"}], 
              "}"}], ",", "121.82554963819592`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.7055825790302638`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.911576044151911`", ",", "2.523739366932794`"}], 
              "}"}], ",", "71.2001755020867`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4383378933279654`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.949638783966609`", ",", "2.6355490531667902`"}], 
              "}"}], ",", "20.574801365977343`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2723141336500434`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0602158577717615`", ",", "2.677056749400575`"}], 
              "}"}], ",", 
             RowBox[{"-", "30.050572770132085`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1691731162518658`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.162450707646214`", ",", "2.6179110515934285`"}], 
              "}"}], ",", 
             RowBox[{"-", "80.6759469062416`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10509753158513789`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.18158680607505`", ",", "2.5013606855070525`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.30132104235128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06529105445361282`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1036313876707275`", ",", "2.412630020912711`"}], 
              "}"}], ",", "178.07330482153893`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040561578634327314`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.985587288433265`", ",", "2.416601007334562`"}], 
              "}"}], ",", "127.44793068542896`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025198576973167956`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.913771130957169`", ",", "2.5103699660752623`"}], 
              "}"}], ",", "76.82255654931893`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01565442724004946`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.9406965792129025`", ",", "2.6253708283945265`"}], 
              "}"}], ",", "26.197182413208786`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009725195691602856`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.046675111958901`", ",", "2.677512258130888`"}], 
              "}"}], ",", 
             RowBox[{"-", "24.42819172290156`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08418785625681557`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.851961525503718`", ",", "0.934645522777102`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.0172214840484`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08396323415536613`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.424351740191631`", ",", "0.7706489542266817`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.16287053732864`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037951337895498025`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.518103669062487`", ",", "1.1512149591504777`"}], 
              "}"}], ",", "150.08214169935206`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03781867161783675`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.398525796497053`", ",", "1.2200248889577248`"}], 
              "}"}], ",", "147.5930349233807`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09214180901971822`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.461139648466303`", ",", "1.1443863509174352`"}], 
              "}"}], ",", "169.83682616023586`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09184567454461695`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3780326268083885`", ",", "1.1592845253399489`"}], 
              "}"}], ",", "171.98278147920334`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02199517103167116`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.409836078855042`", ",", "1.1187061391187512`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.4084893788803`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008450040797966445`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.900457870164396`", ",", 
               RowBox[{"-", "0.10167967351866608`"}]}], "}"}], ",", 
             RowBox[{"-", "84.6036009949648`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008428470707011719`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.924279037284031`", ",", 
               RowBox[{"-", "0.35385045836149054`"}]}], "}"}], ",", 
             RowBox[{"-", "83.84590262632943`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009275665482763417`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5649167357676115`", ",", 
               RowBox[{"-", "0.1860555186724132`"}]}], "}"}], ",", 
             RowBox[{"-", "40.52276132872811`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009233652315384836`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.598560623249983`", ",", 
               RowBox[{"-", "0.21481323580048364`"}]}], "}"}], ",", 
             RowBox[{"-", "37.12548893906633`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15988142485899107`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.338030659768891`", ",", "1.0456952774415846`"}], 
              "}"}], ",", "163.87002602972336`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1591171623905866`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.184804334084109`", ",", "1.0900086345508422`"}], 
              "}"}], ",", "167.43981755317935`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1913239853583196`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6682505014656734`", ",", 
               RowBox[{"-", "1.260811247870144`"}]}], "}"}], ",", 
             RowBox[{"-", "155.6930772985218`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18133119751960128`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.515237747523003`", ",", 
               RowBox[{"-", "1.3299214132440937`"}]}], "}"}], ",", 
             RowBox[{"-", "144.8645144526981`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009470867868241547`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3631369823812154`", ",", 
               RowBox[{"-", "1.436960415300968`"}]}], "}"}], ",", 
             RowBox[{"-", "78.74487519357464`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043666428612270575`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8700807173829546`", ",", "1.4673964527622854`"}], 
              "}"}], ",", "114.37711713150861`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043547136433508146`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8010335980801604`", ",", "1.619771714514598`"}], 
              "}"}], ",", "113.06803457819824`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08305120407046669`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.379052243606461`", ",", "0.6990117450102403`"}], 
              "}"}], ",", "26.628300660953254`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08205377451641607`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.634981857793197`", ",", "0.8273299019140062`"}], 
              "}"}], ",", "20.366248909529595`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05142209521165748`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.842566133514247`", ",", "1.440068636143774`"}], 
              "}"}], ",", "137.75486596213727`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05096531262506663`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.720940674311308`", ",", "1.5505265746309072`"}], 
              "}"}], ",", "132.35382993358746`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012963866336481724`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.588794290327433`", ",", "0.7038109943929166`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.9327743363301`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012877801990218384`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.405729173165847`", ",", "0.664674750076516`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.49507536613723`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008070172716757851`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0400177056328745`", ",", 
               RowBox[{"-", "0.6635405089458228`"}]}], "}"}], ",", 
             RowBox[{"-", "117.01329910494891`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008046922784696818`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.818081978692056`", ",", 
               RowBox[{"-", "1.098864073309862`"}]}], "}"}], ",", 
             RowBox[{"-", "118.63606731800834`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009314174107381465`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.021149725198444`", ",", 
               RowBox[{"-", "0.07154571447836386`"}]}], "}"}], ",", 
             RowBox[{"-", "65.30958701143763`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009224364734456833`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.098059280499725`", ",", 
               RowBox[{"-", "0.2388328067404872`"}]}], "}"}], ",", 
             RowBox[{"-", "59.67457118834301`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18977331985818377`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.728774910946679`", ",", "2.3223324043258624`"}], 
              "}"}], ",", "129.90827404177236`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18924189136883612`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.6539520195670985`", ",", "2.4117933223224775`"}], 
              "}"}], ",", "131.37078225884963`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03382484285031562`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.6258440355301405`", ",", "1.8689699323790148`"}], 
              "}"}], ",", 
             RowBox[{"-", "29.81886813827425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.033673916425846`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.697475812834526`", ",", "1.8279146946195524`"}], 
              "}"}], ",", 
             RowBox[{"-", "33.16742263704937`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014145852204755924`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.472040952293647`", ",", "2.3458184217531763`"}], 
              "}"}], ",", 
             RowBox[{"-", "62.62717988804172`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014001271585279368`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.577898380087658`", ",", "2.1413614120070266`"}], 
              "}"}], ",", 
             RowBox[{"-", "68.42834369695274`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.935870919486937`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.583810886957185`", ",", "2.633564846050262`"}], 
              "}"}], ",", "71.34049521082532`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.9164072744211462`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.585555138189024`", ",", "2.638730032428786`"}], 
              "}"}], ",", "67.66392474646807`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019367393565932853`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.692367912281009`", ",", "2.8987001271996897`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.24828794684315`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014045073976597542`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.299114145669607`", ",", "2.5142405463846695`"}], 
              "}"}], ",", 
             RowBox[{"-", "154.6918296903081`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013987573944107053`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.215984381681101`", ",", "2.4749307830443343`"}], 
              "}"}], ",", 
             RowBox[{"-", "157.75333187041656`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033159707030700245`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8856226064772645`", ",", "2.454866553037327`"}], 
              "}"}], ",", "159.25038283862193`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03303044008086781`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.683048452564097`", ",", "2.531613486608514`"}], 
              "}"}], ",", "162.14191352847385`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17613864729749557`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.354603703684484`", ",", "1.6013214427552687`"}], 
              "}"}], ",", 
             RowBox[{"-", "9.71391202462584`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17552946217379214`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.356213552333505`", ",", "1.6010458639601983`"}], 
              "}"}], ",", 
             RowBox[{"-", "12.161315443351151`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01272723329937115`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.161374580802137`", ",", "0.6278061110068232`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.77457882059267`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012688689233488683`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.155851148044681`", ",", "0.62117069692608`"}], "}"}],
              ",", 
             RowBox[{"-", "131.65081302863672`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08141766170943962`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.929742957745927`", ",", "0.6652030754613594`"}], 
              "}"}], ",", 
             RowBox[{"-", "20.67606711388866`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08083291346468757`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.943743831431117`", ",", "0.6599192684195407`"}], 
              "}"}], ",", 
             RowBox[{"-", "25.466987802737354`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08873510210998069`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.934429269750753`", ",", "1.1647759852781359`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.39320290256939`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08613915523312513`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8711843852292245`", ",", "1.1630018869658185`"}], 
              "}"}], ",", "172.6908459561108`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0090322433203985`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.201877408545196`", ",", "2.010677723111943`"}], 
              "}"}], ",", "75.79817311258682`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009009215361748977`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.220711907001162`", ",", "2.085100957738307`"}], 
              "}"}], ",", "76.54237579514508`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25532326349488754`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.055325171769849`", ",", "2.140045002997775`"}], 
              "}"}], ",", "147.8696620385224`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24035783209437522`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8070783438029028`", ",", "2.2959531760368335`"}], 
              "}"}], ",", "159.10253289804862`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014088252666628965`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.675134321503202`", ",", "2.346331015390589`"}], 
              "}"}], ",", 
             RowBox[{"-", "136.09241230099096`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008444652544654986`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8871266030435763`", ",", "2.040432289515257`"}], 
              "}"}], ",", 
             RowBox[{"-", "140.05884903554187`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008347331480467958`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7699581791501924`", ",", "1.9423212098599785`"}], 
              "}"}], ",", 
             RowBox[{"-", "133.91485121250864`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014021797280334971`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7442304120272185`", ",", 
               RowBox[{"-", "0.9084906570121896`"}]}], "}"}], ",", 
             RowBox[{"-", "167.28300857364695`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013977533816082882`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6368300877082387`", ",", 
               RowBox[{"-", "0.932727835487602`"}]}], "}"}], ",", 
             RowBox[{"-", "165.21558500387724`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012327639918492539`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9103644313012382`", ",", 
               RowBox[{"-", "2.63264420570771`"}]}], "}"}], ",", 
             RowBox[{"-", "148.8849007179482`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012297234943880136`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8531464172669496`", ",", 
               RowBox[{"-", "2.667180887666956`"}]}], "}"}], ",", 
             RowBox[{"-", "148.99196921286688`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008869027238572677`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.275954050371112`", ",", 
               RowBox[{"-", "2.8917611585853704`"}]}], "}"}], ",", 
             RowBox[{"-", "102.4459262582022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008842181070358002`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.232309234713183`", ",", 
               RowBox[{"-", "3.089513230492525`"}]}], "}"}], ",", 
             RowBox[{"-", "100.57209033059138`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01772654827632767`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.402864922916759`", ",", 
               RowBox[{"-", "3.1706687047615048`"}]}], "}"}], ",", 
             RowBox[{"-", "61.04038472131329`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017660669639167025`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.477872133810045`", ",", 
               RowBox[{"-", "3.3062105155783237`"}]}], "}"}], ",", 
             RowBox[{"-", "63.76013863255009`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09095527827165098`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.065516021771263`", ",", 
               RowBox[{"-", "2.5757373891090496`"}]}], "}"}], ",", 
             RowBox[{"-", "0.6886663440416735`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09070150533705124`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.330498288687872`", ",", 
               RowBox[{"-", "2.5789224955651515`"}]}], "}"}], ",", 
             "0.752022688321635`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013388151781880133`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.907913549349928`", ",", 
               RowBox[{"-", "1.128131966537967`"}]}], "}"}], ",", 
             "30.38657838455852`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013353982074667318`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.925750905818889`", ",", 
               RowBox[{"-", "1.1176724675766507`"}]}], "}"}], ",", 
             "31.142454919089445`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010926807785597252`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.9396332096186235`", ",", 
               RowBox[{"-", "1.3113566863266601`"}]}], "}"}], ",", 
             "6.70079293575831`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010894464334518713`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.12417255435784`", ",", 
               RowBox[{"-", "1.2896757064740478`"}]}], "}"}], ",", 
             "8.464696566250852`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16946302924391063`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.195908819104282`", ",", 
               RowBox[{"-", "1.8418698879684676`"}]}], "}"}], ",", 
             RowBox[{"-", "155.5265461071354`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1690240168438554`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1672204988726462`", ",", 
               RowBox[{"-", "1.8549278598035843`"}]}], "}"}], ",", 
             RowBox[{"-", "154.62176334727195`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012347044132055179`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.507286540201194`", ",", "2.678637279603003`"}], 
              "}"}], ",", "17.313940884336233`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012309762312982598`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.573136455120478`", ",", "2.6991648220460918`"}], 
              "}"}], ",", "19.175901196420124`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01369256098645535`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0728522647269667`", ",", "3.096887373596184`"}], 
              "}"}], ",", "97.63263498921711`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013658338411207886`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0379501329067837`", ",", "3.357334989361348`"}], 
              "}"}], ",", "97.15563279458993`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02762399913733004`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.16312011496545`", ",", 
               RowBox[{"-", "3.0916553002213503`"}]}], "}"}], ",", 
             RowBox[{"-", "24.966524469138946`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02694271009682234`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.204481116344392`", ",", 
               RowBox[{"-", "3.110912839801599`"}]}], "}"}], ",", 
             RowBox[{"-", "33.35176862107053`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008450760051046375`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.4193349084766895`", ",", 
               RowBox[{"-", "1.7443209047785018`"}]}], "}"}], ",", 
             RowBox[{"-", "6.577104534771598`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008414614059508836`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.617159875700941`", ",", 
               RowBox[{"-", "1.7671299287408804`"}]}], "}"}], ",", 
             RowBox[{"-", "3.3678973369053526`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009132608605665917`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.45669261763965`", ",", "2.226579398023197`"}], "}"}],
              ",", "57.74356653753813`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008953168700008701`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5395831023513624`", ",", "2.3579201842494855`"}], 
              "}"}], ",", "65.44095423499321`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3847505289119267`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.332308243559459`", ",", "2.3879252482139632`"}], 
              "}"}], ",", "135.75753140301288`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3816464895602496`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2156463427626463`", ",", "2.5015423567450736`"}], 
              "}"}], ",", "140.88318990992553`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00872318817885908`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1486487051213468`", ",", "2.299759893171285`"}], 
              "}"}], ",", 
             RowBox[{"-", "146.22850373151238`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008651437781788993`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.610436075581841`", ",", "1.9398455583721346`"}], 
              "}"}], ",", 
             RowBox[{"-", "151.4095886367574`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009488716789597621`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.888010749790684`", ",", "2.239795602771776`"}], 
              "}"}], ",", "34.39935215943431`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00937395846192137`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.352094276162099`", ",", "2.5575525177369407`"}], 
              "}"}], ",", "28.117240417713116`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026194550921173086`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4125453660218863`", ",", 
               RowBox[{"-", "0.8593377419620716`"}]}], "}"}], ",", 
             RowBox[{"-", "175.28507637611685`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02606860083849863`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.353904435352324`", ",", 
               RowBox[{"-", "0.8641742816307323`"}]}], "}"}], ",", 
             RowBox[{"-", "178.8733872922872`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013259526748768102`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.422089061304332`", ",", 
               RowBox[{"-", "1.0631783556271799`"}]}], "}"}], ",", 
             RowBox[{"-", "178.43965167378056`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013195382163280214`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.093326910640336`", ",", 
               RowBox[{"-", "1.0721338202571287`"}]}], "}"}], ",", 
             "177.95282238261203`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009347203982220907`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.9164044126609205`", ",", "0.6481537547206977`"}], 
              "}"}], ",", "149.95289791011996`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009323085692243398`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.891964282972589`", ",", "0.6622910721049998`"}], 
              "}"}], ",", "150.8201787439885`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09786702823869965`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.150256002333505`", ",", "0.05231239248044925`"}], 
              "}"}], ",", "51.78946702995778`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09758750040512609`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.164078058226643`", ",", "0.069870449653405`"}], 
              "}"}], ",", "53.36497799969245`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019441821985911233`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.574921277472411`", ",", "0.0874755916513075`"}], 
              "}"}], ",", "67.94757915618669`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019292251155254413`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.596749065410667`", ",", "0.14135927252437472`"}], 
              "}"}], ",", "62.95835964094559`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013442509710075531`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.093124318394603`", ",", 
               RowBox[{"-", "0.6399737634313856`"}]}], "}"}], ",", 
             "112.09298400614668`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013401727792807969`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.067044428207292`", ",", 
               RowBox[{"-", "0.5757241701134088`"}]}], "}"}], ",", 
             "113.97763196730179`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02171513936557199`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.095556880334739`", ",", 
               RowBox[{"-", "1.782516190304264`"}]}], "}"}], ",", 
             RowBox[{"-", "172.52542598135872`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021587779468350228`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.836140707000324`", ",", 
               RowBox[{"-", "1.8165518686022184`"}]}], "}"}], ",", 
             RowBox[{"-", "176.72213011355245`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04371431905767775`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.863139321655691`", ",", 
               RowBox[{"-", "1.9772863051707465`"}]}], "}"}], ",", 
             RowBox[{"-", "138.74463468609022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04173424052011483`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.7142040229293976`", ",", 
               RowBox[{"-", "2.10792373154992`"}]}], "}"}], ",", 
             RowBox[{"-", "128.4038174122411`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.100675908293293`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.022041265246742`", ",", 
               RowBox[{"-", "2.1317672179825253`"}]}], "}"}], ",", 
             RowBox[{"-", "38.94149533545729`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.085012741178588`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.079759756486173`", ",", 
               RowBox[{"-", "2.178409227415667`"}]}], "}"}], ",", 
             RowBox[{"-", "36.99964756880024`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015615068625707015`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.33682100981092`", ",", 
               RowBox[{"-", "2.372116296911316`"}]}], "}"}], ",", 
             "107.24548211588342`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04298070795175712`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.147211336256754`", ",", 
               RowBox[{"-", "1.948883010289454`"}]}], "}"}], ",", 
             "60.86164401517582`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04285973902290488`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.177544675768603`", ",", 
               RowBox[{"-", "1.8944705060288458`"}]}], "}"}], ",", 
             "62.353712522748154`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021504471470806186`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.981703858840445`", ",", 
               RowBox[{"-", "1.3971231822573906`"}]}], "}"}], ",", 
             "71.35610668739905`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02142982434960078`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.05729602739823`", ",", 
               RowBox[{"-", "1.1730735280725026`"}]}], "}"}], ",", 
             "73.817855630127`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013672396952207486`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.81221724320332`", ",", 
               RowBox[{"-", "0.9879310810174107`"}]}], "}"}], ",", 
             "129.30589602115307`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013603579244059243`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.775781437771898`", ",", 
               RowBox[{"-", "0.9434245706739666`"}]}], "}"}], ",", 
             "125.57424954565988`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019780015412603533`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.603984831371815`", ",", 
               RowBox[{"-", "1.169398971513567`"}]}], "}"}], ",", 
             "171.5018027893138`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019538039861123544`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.574104318307114`", ",", 
               RowBox[{"-", "1.1649342600888264`"}]}], "}"}], ",", 
             "165.1868986279668`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09514781052627358`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.930221352069838`", ",", 
               RowBox[{"-", "2.022155952212378`"}]}], "}"}], ",", 
             RowBox[{"-", "148.86258210533362`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0945532599995545`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.770604205594284`", ",", 
               RowBox[{"-", "2.118585400139093`"}]}], "}"}], ",", 
             RowBox[{"-", "144.47795791835188`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013288937657603401`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.561283549930273`", ",", 
               RowBox[{"-", "0.227086100596803`"}]}], "}"}], ",", 
             "150.84498325938904`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012947902499315668`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.41769083502157`", ",", 
               RowBox[{"-", "0.14698272811855936`"}]}], "}"}], ",", 
             "159.3526325880933`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01193318496013604`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.407879210301261`", ",", "1.8004025358513511`"}], 
              "}"}], ",", "86.33904815982224`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011864851132445337`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.412338370545742`", ",", "1.87009568796768`"}], "}"}],
              ",", "82.21392367109125`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0248984562135517`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1079055127338115`", ",", "2.388170150014077`"}], 
              "}"}], ",", "75.30510575355352`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022851189005179948`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1101305241034725`", ",", "2.3966544690921925`"}], 
              "}"}], ",", "87.77762997488098`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11035036088160324`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8863540324988484`", ",", "0.559232777351813`"}], 
              "}"}], ",", "165.5029671265896`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10928234430771655`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8356563595576576`", ",", "0.5723412860644501`"}], 
              "}"}], ",", "159.8572689008221`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0418785046320254`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.2133081495809765`", ",", 
               RowBox[{"-", "1.3706139949046245`"}]}], "}"}], ",", 
             RowBox[{"-", "145.46672998533`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.041749658315437824`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.108618644472275`", ",", 
               RowBox[{"-", "1.4426546388240173`"}]}], "}"}], ",", 
             RowBox[{"-", "147.41746300855849`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023012613951906694`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.458210494903547`", ",", 
               RowBox[{"-", "2.6254920219548468`"}]}], "}"}], ",", 
             RowBox[{"-", "98.9495878651417`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019248099947778104`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.407019887660409`", ",", 
               RowBox[{"-", "2.9505475865878963`"}]}], "}"}], ",", 
             RowBox[{"-", "83.67699185820453`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011817734145923898`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.796596113038852`", ",", 
               RowBox[{"-", "1.4367323507430918`"}]}], "}"}], ",", 
             RowBox[{"-", "46.26269307448791`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011780119441163816`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.821543249800346`", ",", 
               RowBox[{"-", "1.4628040299671872`"}]}], "}"}], ",", 
             RowBox[{"-", "44.15888786060312`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00957072377488993`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.507576983832616`", ",", "1.6542440114158796`"}], 
              "}"}], ",", "132.76699317411442`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009424671261420842`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.430740033522393`", ",", "2.8184667495682527`"}], 
              "}"}], ",", "139.72011058195227`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01604485245075161`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9982269963100165`", ",", "2.1711805332934513`"}], 
              "}"}], ",", "92.63773029597193`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016005257171484762`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.991086841474694`", ",", "2.3261666890661976`"}], 
              "}"}], ",", "92.78106209168295`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1290611972797337`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.601329198023765`", ",", 
               RowBox[{"-", "1.6135517013908613`"}]}], "}"}], ",", 
             RowBox[{"-", "90.20044986692868`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12705050018888117`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.600403197491476`", ",", 
               RowBox[{"-", "1.8782348697021982`"}]}], "}"}], ",", 
             RowBox[{"-", "97.21383171369399`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03616965632267346`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.144168730365307`", ",", 
               RowBox[{"-", "0.8780716570571427`"}]}], "}"}], ",", 
             RowBox[{"-", "67.35543187675484`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.036073961902658234`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.229428519827426`", ",", 
               RowBox[{"-", "1.0824469116506141`"}]}], "}"}], ",", 
             RowBox[{"-", "68.43734231681997`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04156277847714569`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.397711101966816`", ",", "1.425990015523278`"}], 
              "}"}], ",", "99.47535319653558`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.041104093087562646`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.355766015401802`", ",", "1.677308046114456`"}], 
              "}"}], ",", "105.49553117827398`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00875989764815006`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9578493651101825`", ",", "0.12924088828540214`"}], 
              "}"}], ",", "156.00614357475288`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008737986765164067`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.888620916030578`", ",", "0.16005448555398563`"}], 
              "}"}], ",", "155.51619109575307`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12236056753711465`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.246315232740649`", ",", "0.938381580360709`"}], 
              "}"}], ",", "55.92575991408235`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11976412636108417`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.368445590996329`", ",", "1.1189421761208362`"}], 
              "}"}], ",", "63.853775853499954`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015716189902003127`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.388581737806026`", ",", 
               RowBox[{"-", "0.6601193636767255`"}]}], "}"}], ",", 
             RowBox[{"-", "168.0366769053084`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015660870595436388`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.32799048777566`", ",", 
               RowBox[{"-", "0.672957898133279`"}]}], "}"}], ",", 
             RowBox[{"-", "165.5208866036744`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008142147980113375`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.690582381629045`", ",", "0.865765952717761`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.66124947139863`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2718261063685962`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.882842248520935`", ",", 
               RowBox[{"-", "1.1463896616883769`"}]}], "}"}], ",", 
             RowBox[{"-", "86.03131862082505`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26809663024753516`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.886544713685529`", ",", 
               RowBox[{"-", "1.1997565696185986`"}]}], "}"}], ",", 
             RowBox[{"-", "92.67612871254703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28038501246615904`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4207183716486735`", ",", 
               RowBox[{"-", "0.620736054269777`"}]}], "}"}], ",", 
             RowBox[{"-", "60.44680660855803`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2793503516646433`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.534987210262611`", ",", 
               RowBox[{"-", "0.8222687521754535`"}]}], "}"}], ",", 
             RowBox[{"-", "63.14052429095053`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025307265717536664`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.581851068272584`", ",", "0.2082720020311536`"}], 
              "}"}], ",", 
             RowBox[{"-", "108.16578881713595`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02524255363827332`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.545049759835014`", ",", "0.09611452520613893`"}], 
              "}"}], ",", 
             RowBox[{"-", "107.38957079742102`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2926493047834892`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.675336249011812`", ",", "0.0591858274929169`"}], 
              "}"}], ",", 
             RowBox[{"-", "45.82580778272275`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28868765007548547`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.30451965388601`", ",", 
               RowBox[{"-", "0.5884010241932411`"}]}], "}"}], ",", 
             RowBox[{"-", "52.431903515616675`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021694254553177014`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.850782598441062`", ",", "0.07277791814304138`"}], 
              "}"}], ",", "16.51417325169054`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021376871550046972`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.87963114875032`", ",", "0.08133101104005919`"}], 
              "}"}], ",", "9.683626119136653`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012597079709539365`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.983547199606125`", ",", "1.1459838153379867`"}], 
              "}"}], ",", "170.77691616556342`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012544637138556657`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.852980997598422`", ",", "1.167184912738187`"}], 
              "}"}], ",", "167.65851585159015`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1793050907758053`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.863324853607964`", ",", "1.031608164437147`"}], 
              "}"}], ",", 
             RowBox[{"-", "125.00418788206912`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.178553439888321`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.783168053508213`", ",", "0.9171501968809312`"}], 
              "}"}], ",", 
             RowBox[{"-", "121.86239823036823`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011087360641710873`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.914027006419358`", ",", "0.8736066021139146`"}], 
              "}"}], ",", 
             RowBox[{"-", "60.78529192970161`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010922902169554315`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.066867649932133`", ",", "0.6002952428894279`"}], 
              "}"}], ",", 
             RowBox[{"-", "67.65585228367964`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.375005953813934`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.346007987984193`", ",", "2.1354637918059716`"}], 
              "}"}], ",", "117.40412003829024`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3701762291127424`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.327120090947857`", ",", "2.1718958268236905`"}], 
              "}"}], ",", "119.91181105550658`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2641689589797744`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.066377499692184`", ",", "2.2089179863153836`"}], 
              "}"}], ",", "168.31971050219542`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26351488861141836`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.898965312849362`", ",", "2.243527325900353`"}], 
              "}"}], ",", "168.04727040250376`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2622080760166959`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.269418053371558`", ",", "2.1084494459656544`"}], 
              "}"}], ",", 
             RowBox[{"-", "94.83830704254505`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2615603495313354`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.251000233336963`", ",", "1.8908622107119537`"}], 
              "}"}], ",", 
             RowBox[{"-", "95.03044121316142`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07646682752923194`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.394212442133696`", ",", "1.133243022143843`"}], 
              "}"}], ",", 
             RowBox[{"-", "126.05366658948233`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07619447622862997`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.251696866129556`", ",", "0.9374730351937544`"}], 
              "}"}], ",", 
             RowBox[{"-", "123.49264939678761`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024599086842187857`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.6564143033686465`", ",", "1.2250070433451765`"}], 
              "}"}], ",", 
             RowBox[{"-", "109.3314300321128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024521132686194165`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.6385450164797195`", ",", "1.1740699618890027`"}], 
              "}"}], ",", 
             RowBox[{"-", "111.41596415692479`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20141331544426683`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.430375912009466`", ",", "0.283208622726918`"}], 
              "}"}], ",", 
             RowBox[{"-", "92.23826580109001`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19979764395859306`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.421668960201598`", ",", "0.06043892671619491`"}], 
              "}"}], ",", 
             RowBox[{"-", "87.12900126195116`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.33710362491899387`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.585010064392459`", ",", "1.196668184852395`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.43397479273634`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.335538024806492`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.38361273321551`", ",", "1.1699175830622408`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.91190952326457`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2867799236082485`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.869019545342315`", ",", "0.9045133912008863`"}], 
              "}"}], ",", "178.2088620155177`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28549430929952446`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6601133026574955`", ",", "0.9110461907966975`"}], 
              "}"}], ",", "174.84506314820194`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2900425045471786`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8802831926153463`", ",", "1.0795703200884155`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.97807219974132`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2892851428382827`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6903964674858494`", ",", "1.0595389433095326`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.00307008426276`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009211475820204557`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.613447268885137`", ",", 
               RowBox[{"-", "1.6437226269738707`"}]}], "}"}], ",", 
             RowBox[{"-", "86.64810705308265`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009144178844074995`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.61359122751234`", ",", 
               RowBox[{"-", "1.6461805843378567`"}]}], "}"}], ",", 
             RowBox[{"-", "81.80782076349875`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17846540055055785`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1516229963101905`", ",", "3.04052253545903`"}], 
              "}"}], ",", "82.05450252368206`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17799828216807748`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1594300176847945`", ",", "3.096458406591349`"}], 
              "}"}], ",", "81.05936317641887`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09317864868467558`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.488034289750155`", ",", "2.6797783985379304`"}], 
              "}"}], ",", "79.43604234335129`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09289994309639356`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.512358282793377`", ",", "2.8102062193222936`"}], 
              "}"}], ",", "81.25196060208084`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.8628874678008174`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.973860009185009`", ",", "2.4233855638274715`"}], "}"}
              ], ",", "150.34476858086228`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.8581358924226263`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.42036330315144`", ",", "2.7385215816048163`"}], 
              "}"}], ",", "151.0938359839008`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4301777177836793`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.911576044151911`", ",", "2.523739366932794`"}], 
              "}"}], ",", "99.71939444475326`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4261380628670148`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.88366247065081`", ",", "2.686708323647802`"}], "}"}],
              ",", "105.27901881397781`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2672446857022981`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.949638783966609`", ",", "2.6355490531667902`"}], 
              "}"}], ",", "49.094020308644374`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2514363227260545`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.30327979785749`", ",", "3.0437173209918855`"}], 
              "}"}], ",", "37.82865181428635`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014873248628385755`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.4372327959670805`", ",", "3.147729248239088`"}], 
              "}"}], ",", 
             RowBox[{"-", "26.874976847738786`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16602375967792204`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0602158577717615`", ",", "2.677056749400575`"}], 
              "}"}], ",", 
             RowBox[{"-", "1.531353827464691`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16546651203471324`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1235570583401175`", ",", "2.675363415373785`"}], 
              "}"}], ",", "0.7962969625204293`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1031410173981778`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.162450707646214`", ",", "2.6179110515934285`"}], 
              "}"}], ",", 
             RowBox[{"-", "52.15672796357385`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10273052734101643`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.522941060404558`", ",", "2.1538937358320926`"}], 
              "}"}], ",", 
             RowBox[{"-", "55.12082232259104`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06407558466672793`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.18158680607505`", ",", "2.5013606855070525`"}], 
              "}"}], ",", 
             RowBox[{"-", "102.78210209968287`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06354535848363348`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.152322539864831`", ",", "2.372367037486031`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.58374634426224`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039806477131525075`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1036313876707275`", ",", "2.412630020912711`"}], 
              "}"}], ",", 
             RowBox[{"-", "153.4074762357919`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03970141247948349`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.883622081333916`", ",", "2.302493471582756`"}], 
              "}"}], ",", 
             RowBox[{"-", "154.4706455055919`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024729475819285418`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.985587288433265`", ",", "2.416601007334562`"}], 
              "}"}], ",", "155.96714962809875`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024651918776346305`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.384889466004231`", ",", "2.6844616944699413`"}], 
              "}"}], ",", "153.92887831328815`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015363001661159345`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.913771130957169`", ",", "2.5103699660752623`"}], 
              "}"}], ",", "105.34177549198894`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015290852539424834`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.870247198990103`", ",", "2.669012116609145`"}], 
              "}"}], ",", "108.85530914077306`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009544149733118451`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.9406965792129025`", ",", "2.6253708283945265`"}], 
              "}"}], ",", "54.7164013558794`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009511743778559264`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.457306936761345`", ",", "3.355448852941872`"}], 
              "}"}], ",", "57.09064122574636`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08373921136943206`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1188388464948025`", ",", "0.6604338486612473`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.30851959060885`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0834447391571244`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1166751170879525`", ",", "0.6597018252416424`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.79640518256713`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03768646910093345`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.143855725421484`", ",", "1.3816868608239041`"}], 
              "}"}], ",", "145.1039281474095`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037592344494505804`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.132335989322367`", ",", "1.3897219659560067`"}], 
              "}"}], ",", "145.56853769111024`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09155049181583227`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.072201536619233`", ",", "1.2023600096651306`"}], 
              "}"}], ",", "174.12873679817065`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09122629485963236`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.851498967343398`", ",", "1.2250555314779823`"}], 
              "}"}], ",", "176.66769588968904`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021995171031671156`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.327993242796761`", ",", "1.1048759326021627`"}], 
              "}"}], ",", 
             RowBox[{"-", "120.49075152845165`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02178238613968048`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.210763959576821`", ",", "0.9057866227232705`"}], 
              "}"}], ",", 
             RowBox[{"-", "126.13519704042865`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008406955677190412`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.953065952582621`", ",", 
               RowBox[{"-", "0.6208304854292546`"}]}], "}"}], ",", 
             RowBox[{"-", "83.08820425769409`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008384926219419794`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.979795162103256`", ",", 
               RowBox[{"-", "0.8413281452657155`"}]}], "}"}], ",", 
             RowBox[{"-", "82.08358902731925`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009191829442302282`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.8015864440438545`", ",", 
               RowBox[{"-", "0.3685024860381718`"}]}], "}"}], ",", 
             RowBox[{"-", "33.728216549404344`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009163249487429402`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.865477093546045`", ",", 
               RowBox[{"-", "0.4111577264223858`"}]}], "}"}], ",", 
             RowBox[{"-", "35.727463261516824`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15835655323663772`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9180161944865612`", ",", "1.1494482120242693`"}], 
              "}"}], ",", "171.00960907663514`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15573397530720887`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8621851503738815`", ",", "1.158281382640382`"}], 
              "}"}], ",", "163.81759780847025`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009992787838718266`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.515237747523003`", ",", 
               RowBox[{"-", "1.3299214132440937`"}]}], "}"}], ",", 
             "159.84440913400212`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00996739686590369`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3736817974158426`", ",", 
               RowBox[{"-", "1.2779634997862737`"}]}], "}"}], ",", 
             "160.5502039418248`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17186032965135978`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3631369823812154`", ",", 
               RowBox[{"-", "1.436960415300968`"}]}], "}"}], ",", 
             RowBox[{"-", "134.03595160687442`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16989633312019414`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2347894055906963`", ",", 
               RowBox[{"-", "1.5697014360895865`"}]}], "}"}], ",", 
             RowBox[{"-", "127.9160539509001`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008976207603462818`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3994379955641585`", ",", 
               RowBox[{"-", "1.6193726603941647`"}]}], "}"}], ",", 
             RowBox[{"-", "67.91631234775099`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008952112530770833`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4950612409166117`", ",", 
               RowBox[{"-", "1.855056788319011`"}]}], "}"}], ",", 
             RowBox[{"-", "69.10583971778145`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043428170148673055`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6764578941698423`", ",", "1.912287471595425`"}], 
              "}"}], ",", "111.75895202488815`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04309512000844569`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.659701915750172`", ",", "1.9542676047755663`"}], 
              "}"}], ",", "116.7390861781061`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08106832390627644`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.8600772293281915`", ",", "0.9108912178091552`"}], 
              "}"}], ",", "14.10419715810605`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08070835521041393`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.917087917971804`", ",", "0.9252157528523273`"}], 
              "}"}], ",", "17.436845128462938`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.050512587639212486`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.563509470794093`", ",", "1.7232149979237499`"}], 
              "}"}], ",", "126.95279390503762`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0497964265762504`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.491949144930795`", ",", "1.8183417237540334`"}], 
              "}"}], ",", "120.2131365314655`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012792309006811277`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1420754931227135`", ",", "0.6299410302479087`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.05737639594443`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012743424265618152`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.13941268460613`", ",", "0.6298041521065122`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.23667802454779`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008023739835011482`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6730830867006965`", ",", 
               RowBox[{"-", "1.3644129827131524`"}]}], "}"}], ",", 
             RowBox[{"-", "120.25883553106776`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009135421323814214`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.212311557604752`", ",", 
               RowBox[{"-", "0.4341530931148644`"}]}], "}"}], ",", 
             RowBox[{"-", "54.03955536524852`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008517132002126502`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.338588345914811`", ",", 
               RowBox[{"-", "0.6082107515768171`"}]}], "}"}], ",", 
             RowBox[{"-", "65.78920177425572`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18871195105622218`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.435909779053422`", ",", "2.6593680888455133`"}], 
              "}"}], ",", "132.8332904759274`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18750941602837956`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3888323111581675`", ",", "2.7101479142359346`"}], 
              "}"}], ",", "137.27558227033012`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03352366343497384`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8978100437530285`", ",", "1.696982269817469`"}], 
              "}"}], ",", 
             RowBox[{"-", "36.515977135824386`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03304788095536744`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.956747605735684`", ",", "1.6533453290572493`"}], 
              "}"}], ",", 
             RowBox[{"-", "43.25860494910863`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013858168682042577`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.665193389335898`", ",", "1.9205603235213684`"}], 
              "}"}], ",", 
             RowBox[{"-", "74.22950750586358`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013819595685257417`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.69219454215379`", ",", "1.82495236190656`"}], "}"}], 
             ",", 
             RowBox[{"-", "72.80322588941829`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0194636450657914`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.585555138189024`", ",", "2.638730032428786`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.100433024578`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019289780411100174`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.578523583257114`", ",", "2.6384968249285388`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.68343971696808`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.8970398808552136`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.692367912281009`", ",", "2.8987001271996897`"}], 
              "}"}], ",", "63.98735428211081`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.818583817398182`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.829041889572819`", ",", "3.1787664066759094`"}], 
              "}"}], ",", "71.75745618959026`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07687656874273986`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.883506851961149`", ",", "3.3440089025840014`"}], 
              "}"}], ",", "151.86382449847446`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019271618048410034`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.872093610858287`", ",", "2.6826165966951008`"}], 
              "}"}], ",", 
             RowBox[{"-", "53.9248584112006`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01922031977264812`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.91602272532324`", ",", "2.622319810077522`"}], "}"}],
              ",", 
             RowBox[{"-", "55.053110082371035`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013930309314701081`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.939781396097772`", ",", "2.361951907883309`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.81483405052538`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013856605921443037`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.772658749981498`", ",", "2.303802156351581`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.9292989172056`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03290167705419436`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.391351704172249`", ",", "2.625593379193287`"}], 
              "}"}], ",", "165.03344421832603`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03278073812803582`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.355124772949332`", ",", "2.6352776953953128`"}], 
              "}"}], ",", "162.35413714092834`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17492238395008286`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.653693099468152`", ",", "1.5369387176341482`"}], 
              "}"}], ",", 
             RowBox[{"-", "14.60871886207676`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17448462683892865`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.849169220663623`", ",", "1.4859892362381888`"}], 
              "}"}], ",", 
             RowBox[{"-", "14.110125377065682`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012650261897218986`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.963243164986898`", ",", "0.40461823168334243`"}], 
              "}"}], ",", 
             RowBox[{"-", "133.52704723668097`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012585585767993008`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.864035069368825`", ",", "0.3001735008972025`"}], 
              "}"}], ",", 
             RowBox[{"-", "137.30716004917082`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08361915282499986`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.693844003873882`", ",", "1.1857485126662142`"}], 
              "}"}], ",", "163.774894814791`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08339803321601268`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4228500119969545`", ",", "1.264608325084982`"}], 
              "}"}], ",", "164.8528503739111`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00898624611352839`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.2970211362664825`", ",", "2.4039905965296344`"}], 
              "}"}], ",", "77.28657847770381`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008914558721356186`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.354927469531008`", ",", "2.660660901539697`"}], 
              "}"}], ",", "82.37998973698235`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014965431400512286`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8070783438029028`", ",", "2.2959531760368335`"}], 
              "}"}], ",", "105.53034895661435`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014794145320095998`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7064987451471687`", ",", "2.657886923554598`"}], 
              "}"}], ",", "99.4060548237696`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22626957942774628`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.675134321503202`", ",", "2.346331015390589`"}], 
              "}"}], ",", "170.33540375757482`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22395049021830984`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5557058479751067`", ",", "2.3666693537413117`"}], 
              "}"}], ",", "164.5262914361907`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013262488590337719`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.573380697926003`", ",", "2.248385357970332`"}], 
              "}"}], ",", 
             RowBox[{"-", "124.85954144146476`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013029652756978094`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4922244091376218`", ",", "2.1318753049699684`"}], 
              "}"}], ",", 
             RowBox[{"-", "117.49607314433285`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008251132000559797`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.608033170338925`", ",", "1.7741434996327017`"}], 
              "}"}], ",", 
             RowBox[{"-", "127.77085338947532`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008222372346247762`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.494865762782598`", ",", "1.6280956073710566`"}], 
              "}"}], ",", 
             RowBox[{"-", "125.29305650505091`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013933410081013042`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.30918847720457`", ",", 
               RowBox[{"-", "1.0191991468394757`"}]}], "}"}], ",", 
             RowBox[{"-", "163.1481614341077`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013871411983682134`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1501325925922243`", ",", 
               RowBox[{"-", "1.0673780166924594`"}]}], "}"}], ",", 
             RowBox[{"-", "166.48763524735386`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012266904960303113`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.589108696355187`", ",", 
               RowBox[{"-", "2.8258811301481175`"}]}], "}"}], ",", 
             RowBox[{"-", "149.09903770779235`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012225610598768887`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5793722792052693`", ",", 
               RowBox[{"-", "2.831708477702094`"}]}], "}"}], ",", 
             RowBox[{"-", "146.75944130659153`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008815416164352637`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.172461097552453`", ",", 
               RowBox[{"-", "3.4101727141824996`"}]}], "}"}], ",", 
             RowBox[{"-", "98.69825440298057`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00808866082489783`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1639613154432675`", ",", 
               RowBox[{"-", "3.465730359428305`"}]}], "}"}], ",", 
             RowBox[{"-", "111.1807480380335`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017595035832233152`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.601170038740591`", ",", 
               RowBox[{"-", "3.55634550583027`"}]}], "}"}], ",", 
             RowBox[{"-", "66.47989254378719`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01754692263322301`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.628715581397982`", ",", 
               RowBox[{"-", "3.6196351682442374`"}]}], "}"}], ",", 
             RowBox[{"-", "65.16466740742031`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09044844045044562`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.638935893568386`", ",", 
               RowBox[{"-", "2.5748739356299155`"}]}], "}"}], ",", 
             "2.192711720684943`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08991535508416518`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.862015843501545`", ",", 
               RowBox[{"-", "2.566332486898788`"}]}], "}"}], ",", 
             "6.404013612354198`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013319899576571198`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.17711503024882`", ",", 
               RowBox[{"-", "0.9657857867526604`"}]}], "}"}], ",", 
             "31.898331453619885`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013226833351632132`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.229584526554289`", ",", 
               RowBox[{"-", "0.9331285216554779`"}]}], "}"}], ",", 
             "36.609459762419064`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012272593066119079`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.859102310574856`", ",", "2.798613824550409`"}], 
              "}"}], ",", "21.037861508504008`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011960144256608192`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.084440878437667`", ",", "2.8852840868237886`"}], 
              "}"}], ",", "12.554843298649132`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026278223647221502`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.346900401770584`", ",", 
               RowBox[{"-", "3.2046491384338243`"}]}], "}"}], ",", 
             RowBox[{"-", "41.7370127730019`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026154910625220514`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.4508501385809875`", ",", 
               RowBox[{"-", "3.297385501936052`"}]}], "}"}], ",", 
             RowBox[{"-", "45.248034784034864`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008378622673319966`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8834535086676665`", ",", 
               RowBox[{"-", "1.782800960434623`"}]}], "}"}], ",", 
             RowBox[{"-", "0.1586901390393347`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008350282437598965`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.105640936272439`", ",", 
               RowBox[{"-", "1.7834163468424353`"}]}], "}"}], ",", 
             "2.2002140965389096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008777254477004986`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6246736316529993`", ",", "2.5441255502263878`"}], 
              "}"}], ",", "73.13834193244851`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008720520321501175`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6704688145865982`", ",", "2.6952186852900835`"}], 
              "}"}], ",", "68.65422652052884`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3785674925660814`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.990766656968944`", ",", "2.68440669863797`"}], "}"}],
              ",", "146.0088484168383`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.37661141892337874`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8845911525099703`", ",", "2.7559991259945607`"}], 
              "}"}], ",", "149.82164511240043`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00858027754961896`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.427325078483299`", ",", "1.8400499517806694`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.59067354200232`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008558993392664983`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4097248437291436`", ",", "1.8324302484370008`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.26717141524983`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009260588043070206`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5648705308709445`", ",", "2.67124674879148`"}], 
              "}"}], ",", "21.835128675991815`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009229627545588556`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.588892206482666`", ",", "2.680871821839608`"}], 
              "}"}], ",", "24.146736979060005`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025943256355949695`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0780660610831423`", ",", 
               RowBox[{"-", "0.8695988186114041`"}]}], "}"}], ",", 
             "177.5383017915425`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025117912326129387`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0428885243697246`", ",", 
               RowBox[{"-", "0.8680864942479819`"}]}], "}"}], ",", 
             RowBox[{"-", "173.28023176409397`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013131547885084987`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.844101538872602`", ",", 
               RowBox[{"-", "1.0632252089375354`"}]}], "}"}], ",", 
             "174.3452964390048`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013099150648358019`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.666467982513889`", ",", 
               RowBox[{"-", "1.0456368429455045`"}]}], "}"}], ",", 
             "174.47266316178008`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009299029633914253`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.620435270414352`", ",", "0.8139180346299864`"}], 
              "}"}], ",", "151.6874595778558`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009229151067912247`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.568674019498865`", ",", "0.8418032120599352`"}], 
              "}"}], ",", "146.7658691680177`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01914383101064954`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.71725703465744`", ",", "0.3774451573715266`"}], 
              "}"}], ",", "57.969140125704406`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018786695888718015`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.859452932420811`", ",", "0.6047336633735261`"}], 
              "}"}], ",", "65.51223497119587`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013361069599816009`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.939023855942025`", ",", 
               RowBox[{"-", "0.28788288655888045`"}]}], "}"}], ",", 
             "115.8622799284567`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013318726843723708`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.761532495199798`", ",", "0.0782594081300623`"}], 
              "}"}], ",", "113.77756688122014`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021461166540473097`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.603624631246455`", ",", 
               RowBox[{"-", "1.8298685568134114`"}]}], "}"}], ",", 
             "179.08116575425387`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021046991752128888`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.570468399754491`", ",", 
               RowBox[{"-", "1.8293367952577892`"}]}], "}"}], ",", 
             RowBox[{"-", "173.27494552563357`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03984385138180222`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.608643324015406`", ",", 
               RowBox[{"-", "2.241089960054466`"}]}], "}"}], ",", 
             RowBox[{"-", "118.06300013839203`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03973858991586621`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5302611664733945`", ",", 
               RowBox[{"-", "2.388115128296302`"}]}], "}"}], ",", 
             RowBox[{"-", "116.99248774388022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015663167114706073`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.079759756486173`", ",", 
               RowBox[{"-", "2.178409227415667`"}]}], "}"}], ",", 
             RowBox[{"-", "179.30292948682686`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015603551854063535`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.8944045676906915`", ",", 
               RowBox[{"-", "2.180664402454299`"}]}], "}"}], ",", 
             RowBox[{"-", "176.49665854971514`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015567117837656668`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.241396205327685`", ",", 
               RowBox[{"-", "2.0647126153737987`"}]}], "}"}], ",", 
             "109.18732988254084`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015500840483340902`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.182546427716614`", ",", 
               RowBox[{"-", "1.895598670219838`"}]}], "}"}], ",", 
             "105.993539802665`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021355436346258933`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.13369358484671`", ",", 
               RowBox[{"-", "0.909805201904108`"}]}], "}"}], ",", 
             "76.27960457285509`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02123954235960414`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.142056766957792`", ",", 
               RowBox[{"-", "0.8755510463406937`"}]}], "}"}], ",", 
             "72.31663673168963`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013535107918258687`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.631251815124599`", ",", 
               RowBox[{"-", "0.7413559237850313`"}]}], "}"}], ",", 
             "121.8426030701666`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013499134451970375`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.605605728708971`", ",", 
               RowBox[{"-", "0.7000616123378564`"}]}], "}"}], ",", 
             "120.7258291858763`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019299024477585434`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.35587456765623`", ",", 
               RowBox[{"-", "1.1072220852942924`"}]}], "}"}], ",", 
             "158.8719944666197`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019250282026786802`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.178150371177928`", ",", 
               RowBox[{"-", "1.038544202537983`"}]}], "}"}], ",", 
             "159.50358148237805`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0939624246432305`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.56054423222673`", ",", 
               RowBox[{"-", "2.2685416838301906`"}]}], "}"}], ",", 
             RowBox[{"-", "140.09333373137017`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09343608168659631`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.507209445819916`", ",", 
               RowBox[{"-", "2.3131470319159875`"}]}], "}"}], ",", 
             RowBox[{"-", "136.03444154204675`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012615619355837918`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.212331653106352`", ",", 
               RowBox[{"-", "0.0695994659840488`"}]}], "}"}], ",", 
             "167.86028191679753`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012577171129079178`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.165340332262248`", ",", 
               RowBox[{"-", "0.05949132258521739`"}]}], "}"}], ",", 
             "165.9539556971546`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011796908609508758`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.448658799778517`", ",", "2.1357213457488884`"}], 
              "}"}], ",", "78.0887991823601`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011759641439691458`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.493406679852289`", ",", "2.34785971181047`"}], "}"}],
              ",", "80.15945708104249`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020972257656129187`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1162682073205294`", ",", "2.5548130859784597`"}], 
              "}"}], ",", "100.25015419620841`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02092037523015651`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.065798112577622`", ",", "2.833912076653831`"}], 
              "}"}], ",", "100.49604905092319`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10822466444132209`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6055738337734273`", ",", "0.6567341618634729`"}], 
              "}"}], ",", "154.21157067505465`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1079533728649814`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4061119345070474`", ",", "0.7531081223307664`"}], 
              "}"}], ",", "154.736729051692`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04162120841637863`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8962224611401854`", ",", 
               RowBox[{"-", "1.5783964706025564`"}]}], "}"}], ",", 
             RowBox[{"-", "149.3681960317866`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0413847438651463`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.750287447374651`", ",", 
               RowBox[{"-", "1.6648115713326714`"}]}], "}"}], ",", 
             RowBox[{"-", "145.2667701542009`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01609940323919443`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.421649245250298`", ",", 
               RowBox[{"-", "3.0825725534329287`"}]}], "}"}], ",", 
             RowBox[{"-", "68.40439585126742`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01600462836506241`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.532067868258321`", ",", 
               RowBox[{"-", "3.3615206858124775`"}]}], "}"}], ",", 
             RowBox[{"-", "72.61218124421205`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01174262446037085`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.016042773262057`", ",", 
               RowBox[{"-", "1.6516751997741703`"}]}], "}"}], ",", 
             RowBox[{"-", "42.055082646718844`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011708367027352314`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.108282798810705`", ",", 
               RowBox[{"-", "1.7348892010832604`"}]}], "}"}], ",", 
             RowBox[{"-", "40.36563747215957`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00928084755918825`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.262747380025582`", ",", "2.9608335378144637`"}], 
              "}"}], ",", "146.6732279897899`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009257721782905237`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.930376204807889`", ",", "3.179382975753243`"}], 
              "}"}], ",", "147.09506037963934`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015965759604935754`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.976035586645406`", ",", "2.6360109109681593`"}], 
              "}"}], ",", "92.92439388739398`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015890154412593283`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.965115949693173`", ",", "2.849766562718292`"}], 
              "}"}], ",", "89.38442127670436`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12507112856901748`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.575596281441464`", ",", 
               RowBox[{"-", "2.0742213214166454`"}]}], "}"}], ",", 
             RowBox[{"-", "104.22721356045932`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1247474454342944`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.497597923677322`", ",", 
               RowBox[{"-", "2.381853343242259`"}]}], "}"}], ",", 
             RowBox[{"-", "103.33176350534004`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040650469734116866`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.300925599643978`", ",", "1.8751161064027455`"}], 
              "}"}], ",", "111.51570916001243`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040521575965739895`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.213321694087746`", ",", "2.097332886682772`"}], 
              "}"}], ",", "109.42867579011366`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008716130687246871`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.597317163585998`", ",", "0.2927098512295937`"}], 
              "}"}], ",", "155.0262386167547`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008365667326248064`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.363415043055312`", ",", "0.4016498220837778`"}], 
              "}"}], ",", "164.96843174938104`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015605746006908698`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.063027041023098`", ",", 
               RowBox[{"-", "0.7413790643896072`"}]}], "}"}], ",", 
             RowBox[{"-", "163.0050963020401`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015445256537428079`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.900853631799341`", ",", 
               RowBox[{"-", "0.7909446785446752`"}]}], "}"}], ",", 
             RowBox[{"-", "168.82386758263664`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.264418322839897`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.87725476830333`", ",", 
               RowBox[{"-", "1.3985091703707337`"}]}], "}"}], ",", 
             RowBox[{"-", "99.32093880426889`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2626869904616622`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.876882042036348`", ",", 
               RowBox[{"-", "1.4007800698946995`"}]}], "}"}], ",", 
             RowBox[{"-", "94.79902957824035`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2783195089094803`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.665234411496248`", ",", 
               RowBox[{"-", "1.0794506771927341`"}]}], "}"}], ",", 
             RowBox[{"-", "65.83424197334318`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2775450987620716`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.68024549226014`", ",", 
               RowBox[{"-", "1.1129053057541303`"}]}], "}"}], ",", 
             RowBox[{"-", "64.41005134882556`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025178007031378655`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4586303530034055`", ",", 
               RowBox[{"-", "0.17982614486075948`"}]}], "}"}], ",", 
             RowBox[{"-", "106.61335277770561`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024994843945423804`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.409973767999245`", ",", 
               RowBox[{"-", "0.34290258960178854`"}]}], "}"}], ",", 
             RowBox[{"-", "101.78537167066156`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021064131802596874`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.093840169841501`", ",", "0.11788342776077729`"}], 
              "}"}], ",", "2.8530789865829815`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02095541557519201`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.099263833995069`", ",", "0.11815372593931085`"}], 
              "}"}], ",", "6.662389654044234`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012492412889860909`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.569808117033248`", ",", "1.2291413933762683`"}], 
              "}"}], ",", "164.5401155376169`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012452970345813984`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.364174656875045`", ",", "1.2860135822578602`"}], 
              "}"}], ",", "166.60832507804955`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1778049399379028`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.61876224892598`", ",", "0.6526344388411479`"}], 
              "}"}], ",", 
             RowBox[{"-", "118.72060857866711`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17701340302364668`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.586204528821855`", ",", "0.5932172930600468`"}], 
              "}"}], ",", 
             RowBox[{"-", "122.06163412899105`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010760883104749801`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.150151747661281`", ",", "0.39767247546671286`"}], 
              "}"}], ",", 
             RowBox[{"-", "74.52641263765771`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010734358805697898`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1720769430198406`", ",", "0.31847101385484194`"}], 
              "}"}], ",", 
             RowBox[{"-", "74.48866434100958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3653634688767773`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.184201931052216`", ",", "2.420319605206351`"}], 
              "}"}], ",", "122.41950207272322`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3145257902223082`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.133875783682815`", ",", "2.4995612934954696`"}], 
              "}"}], ",", "132.10878784451558`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04894479838493547`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.013927724321256`", ",", "2.6322695172548927`"}], 
              "}"}], ",", 
             RowBox[{"-", "157.48371150834726`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26286243769164735`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.585569373781221`", ",", "2.3098714954677755`"}], 
              "}"}], ",", "167.77483030281076`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25418655224553155`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.496013510024986`", ",", "2.3292753428951984`"}], 
              "}"}], ",", "158.4757791277915`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008389534193592906`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.311736426290701`", ",", "2.4019540191871216`"}], 
              "}"}], ",", "86.37417481688229`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2609142231095817`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.226143229094154`", ",", "1.6084734436314265`"}], 
              "}"}], ",", 
             RowBox[{"-", "95.2225753837778`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25967082701411404`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.210443865659897`", ",", "1.4367162884544131`"}], 
              "}"}], ",", 
             RowBox[{"-", "91.66250657688619`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07592309495952186`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.084613540559982`", ",", "0.6849672883762922`"}], 
              "}"}], ",", 
             RowBox[{"-", "120.93163220409305`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0757219415205776`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.074604986041667`", ",", "0.6682651451625644`"}], 
              "}"}], ",", 
             RowBox[{"-", "119.83883837592617`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024443425565811028`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.517440732883323`", ",", "0.8653015214522295`"}], 
              "}"}], ",", 
             RowBox[{"-", "113.50049828173712`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024305773443645085`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.419272103491942`", ",", "0.6395345000659645`"}], 
              "}"}], ",", 
             RowBox[{"-", "109.42560489874994`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19819493285909787`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.432955462470727`", ",", 
               RowBox[{"-", "0.16461433324118624`"}]}], "}"}], ",", 
             RowBox[{"-", "82.01973672281233`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19770644826205294`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.455973551255673`", ",", 
               RowBox[{"-", "0.3288069164334586`"}]}], "}"}], ",", 
             RowBox[{"-", "82.02393737999826`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3339796957629762`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.095547716240053`", ",", "1.1493290099655205`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.38984425379292`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.32382384725927527`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.079872856413603`", ",", "1.1491620785190124`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.3518350894107`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00984702356572182`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.884183329433145`", ",", "1.1158944386613112`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.04462264003966`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2842144583096899`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.349677723758777`", ",", "0.9390518793580136`"}], 
              "}"}], ",", "171.48126428088597`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2833336055578053`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.172850117231622`", ",", "0.9655380592388819`"}], 
              "}"}], ",", "169.49677804146384`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28852975875938647`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3824431749592`", ",", "1.0217437832545335`"}], "}"}],
              ",", 
             RowBox[{"-", "172.02806796878383`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2878040356395935`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1976610322841617`", ",", "0.995866649072636`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.60358933762132`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009077373524557748`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.645263755494122`", ",", 
               RowBox[{"-", "1.866185420573217`"}]}], "}"}], ",", 
             RowBox[{"-", "76.967534473915`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009043961861891115`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.699133125138902`", ",", 
               RowBox[{"-", "2.0989175663572746`"}]}], "}"}], ",", 
             RowBox[{"-", "74.28320774432814`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1775323864292164`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.211612833848461`", ",", "3.428151601916212`"}], 
              "}"}], ",", "80.06422382915423`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17705865641862906`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.235215586903052`", ",", "3.562892476138304`"}], 
              "}"}], ",", "78.91772233046699`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09262207114120274`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.560121556279733`", ",", "3.120599832514311`"}], 
              "}"}], ",", "83.06787886081018`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08926632481016271`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.598423449002021`", ",", "3.4356287083046526`"}], 
              "}"}], ",", "92.6680666858998`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.8533964366538942`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.138474141033417`", ",", "2.894172329501781`"}], 
              "}"}], ",", "151.84290338693978`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.8485406563067763`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.080013278153141`", ",", "2.925462430168098`"}], 
              "}"}], ",", "152.84609257627184`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4221363429971257`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.821355136964984`", ",", "2.914793700563985`"}], 
              "}"}], ",", "110.8386431832023`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.420515972296579`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.75847914606916`", ",", "3.0799802186572953`"}], 
              "}"}], ",", "108.00199375236859`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015808362976243297`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.30327979785749`", ",", "3.0437173209918855`"}], 
              "}"}], ",", "91.2669119819533`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015685949146524682`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.300767807755573`", ",", "3.1573029335704743`"}], 
              "}"}], ",", "96.27489107120314`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23656307409766864`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.4372327959670805`", ",", "3.147729248239088`"}], 
              "}"}], ",", "26.563283319928495`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.235847264520867`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.668793819653014`", ",", "3.263500829221451`"}], 
              "}"}], ",", "24.69116887325459`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013993449232803616`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.5885091764360935`", ",", "3.0710654143640497`"}], 
              "}"}], ",", 
             RowBox[{"-", "38.14034534209651`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013015058505972097`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.751131827436362`", ",", "2.943367950001699`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.00884528879269`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1649111347559417`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3812716959614155`", ",", "2.6789453650180284`"}], 
              "}"}], ",", "3.123947752505863`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16398664728395093`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.58057510902941`", ",", "2.6898228005408806`"}], 
              "}"}], ",", "7.185175570976962`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10232167098973927`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.644278954911342`", ",", "1.9798251660506894`"}], 
              "}"}], ",", 
             RowBox[{"-", "58.08491668160822`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.101642624684561`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.730922672863257`", ",", "1.8407078588253922`"}], 
              "}"}], ",", 
             RowBox[{"-", "62.646162014212244`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06301951992816199`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.118213821951841`", ",", "2.1161797360726418`"}], 
              "}"}], ",", 
             RowBox[{"-", "92.38539058884155`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06268682856734187`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.116121369485934`", ",", "2.0659492119851817`"}], 
              "}"}], ",", 
             RowBox[{"-", "96.26415558560664`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03959662513359669`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.60282190644634`", ",", "2.1683820226624086`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.53381477539193`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037343383810377724`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.528702525048912`", ",", "2.1346566890071426`"}], 
              "}"}], ",", 
             RowBox[{"-", "144.40550687143758`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024574604969250673`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.108774052035784`", ",", "2.8195567145089377`"}], 
              "}"}], ",", "151.89060699847738`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024488139417201616`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.033330609019542`", ",", "2.859855657210858`"}], 
              "}"}], ",", "149.37635128414962`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015219042250939311`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.781731117882949`", ",", "2.928205971915999`"}], 
              "}"}], ",", "112.3688427895573`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015088822067630016`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.714349277427727`", ",", "3.0919392338751`"}], "}"}], 
             ",", "107.07482646988583`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009479447854324441`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.634090986696744`", ",", "3.6286175405357364`"}], 
              "}"}], ",", "59.46488109561347`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009450198465022392`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.647119825236141`", ",", "3.6507051496787444`"}], 
              "}"}], ",", "57.500779366055596`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08315130246786985`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.832018778269499`", ",", "0.5492703607319532`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.2842907745251`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08263711157970306`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6155978878735318`", ",", "0.4541974514948907`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.63810193097012`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03749845497090089`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8547025614206625`", ",", "1.5800455557922033`"}], 
              "}"}], ",", "146.033147234811`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037399703149124115`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.828195341595365`", ",", "1.5979025979241401`"}], 
              "}"}], ",", "147.07852249227477`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09090324594386706`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.613741195307599`", ",", "1.2388990593583549`"}], 
              "}"}], ",", "179.2066549812073`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09066534806994662`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.409518578935311`", ",", "1.2417270050109548`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.79940082155636`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02157165976363377`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.090100669028041`", ",", "0.7405292894550553`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.7796425524056`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02145096558646744`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                 "0.`", ",", "0.9999999999999999`", ",", 
                  "167.35910683550452`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.047734840827478`", ",", "0.6931117933551798`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.83498068412567`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008362954487302588`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.021253812479882`", ",", 
               RowBox[{"-", "1.1394772355398624`"}]}], "}"}], ",", 
             RowBox[{"-", "81.07897379694441`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008296795959606034`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.054017287501334`", ",", 
               RowBox[{"-", "1.3481992558309215`"}]}], "}"}], ",", 
             RowBox[{"-", "86.14834536993936`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009134758395587078`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.090697161067123`", ",", 
               RowBox[{"-", "0.5731585137979203`"}]}], "}"}], ",", 
             RowBox[{"-", "37.7267099736295`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009110517163747832`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.163270847579373`", ",", 
               RowBox[{"-", "0.6293038944579838`"}]}], "}"}], ",", 
             RowBox[{"-", "38.831914732003305`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1531548304713613`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6713872384178625`", ",", "1.2136497580075274`"}], 
              "}"}], ",", "156.62558654030545`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15200720131031964`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4149910609401246`", ",", "1.324466377966882`"}], 
              "}"}], ",", "161.53897947659965`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00994207040976963`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.062560437831467`", ",", 
               RowBox[{"-", "1.1680963505251802`"}]}], "}"}], ",", 
             "161.25599874964854`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00932575546924344`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9761983032071324`", ",", 
               RowBox[{"-", "1.13879043959612`"}]}], "}"}], ",", 
             "149.8235559091691`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16795478087493373`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0912834629691233`", ",", 
               RowBox[{"-", "1.7539364159912485`"}]}], "}"}], ",", 
             RowBox[{"-", "121.79615629492594`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16675850431367437`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0188197633552356`", ",", 
               RowBox[{"-", "1.8708259074624283`"}]}], "}"}], ",", 
             RowBox[{"-", "117.02930405838666`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008928082137123013`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.589344272267322`", ",", 
               RowBox[{"-", "2.1020351712178833`"}]}], "}"}], ",", 
             RowBox[{"-", "70.29536708781251`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008878183979121459`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7667858207547886`", ",", 
               RowBox[{"-", "2.597483960778643`"}]}], "}"}], ",", 
             RowBox[{"-", "74.34739622491725`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.042764624025935026`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5671895390265544`", ",", "2.1378958136711663`"}], 
              "}"}], ",", "121.71922033132392`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.042428635352687254`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4381985078642834`", ",", "2.3465934659157877`"}], 
              "}"}], ",", "116.66958854196835`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04909041915403561`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.380048048528092`", ",", "2.0105057011738268`"}], 
              "}"}], ",", "113.47347915789351`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04895945632813861`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.3348175139279395`", ",", "2.1146606225039792`"}], 
              "}"}], ",", "114.61825029828553`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012694726333383463`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.84117167131676`", ",", "0.5997028117287332`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.41597965315103`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012657291554271059`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.605395170373543`", ",", "0.5641122271604382`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.67120727802637`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18631454395185035`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.224191606502897`", ",", "2.8622039459876105`"}], 
              "}"}], ",", "141.71787406473283`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18578832793871375`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.137604686626926`", ",", "2.930542326395737`"}], 
              "}"}], ",", "143.23011788787363`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032578850988604406`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.093661954241497`", ",", "1.5245104065784694`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.00123276239287`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03245583209334701`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1663719160576385`", ",", "1.4378542619639703`"}], 
              "}"}], ",", 
             RowBox[{"-", "52.778938645696854`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013781130053024898`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.7707649418967755`", ",", "1.571081812287572`"}], 
              "}"}], ",", 
             RowBox[{"-", "71.37694427297221`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013513575193398476`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.829062553610241`", ",", "1.3980842767110477`"}], 
              "}"}], ",", 
             RowBox[{"-", "79.03865199936881`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019117468852863858`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.327120076572609`", ",", "2.606217434266993`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.26644640935822`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019059989290064604`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.191739739163332`", ",", "2.5756248385797793`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.4251327182077`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07845606345703046`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.829041889572819`", ",", "3.1787664066759094`"}], 
              "}"}], ",", 
             RowBox[{"-", "0.5788102118144657`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07814151938321014`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.0636939052972245`", ",", "3.176395837595149`"}], 
              "}"}], ",", "2.4107247662341544`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.741707248655444`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.883506851961149`", ",", "3.3440089025840014`"}], 
              "}"}], ",", "79.52755809706962`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.7307488563514473`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.887209292294565`", ",", "3.364039245201363`"}], 
              "}"}], ",", "77.81791642396212`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010926298301470265`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.942088537623861`", ",", "3.6182506337634655`"}], 
              "}"}], ",", 
             RowBox[{"-", "70.43622179475737`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07532887276321726`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.730079919853941`", ",", "3.4260557860474723`"}], 
              "}"}], ",", "159.6339264059539`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07514292080116731`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.614471715614493`", ",", "3.468972186371477`"}], 
              "}"}], ",", "159.79349961118885`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.019169158045519`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.090703027845902`", ",", "2.372357661055526`"}], 
              "}"}], ",", 
             RowBox[{"-", "56.181361753542106`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013783292482927213`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.589205417729699`", ",", "2.225663533370224`"}], 
              "}"}], ",", 
             RowBox[{"-", "153.04376378388602`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01242147399553092`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.358245643211889`", ",", "2.1082057756821846`"}], 
              "}"}], ",", 
             RowBox[{"-", "166.22477712637897`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03266024374529178`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1144186586145235`", ",", "2.7118462900651146`"}], 
              "}"}], ",", "159.6748300635305`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03254310426332896`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.908658190760104`", ",", "2.788062173697886`"}], 
              "}"}], ",", "162.26230644099616`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1740479652495941`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.113793252067586`", ",", "1.4194705564399406`"}], 
              "}"}], ",", 
             RowBox[{"-", "13.611531892051671`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1732988597622128`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.169498280706339`", ",", "1.4059822232091812`"}], 
              "}"}], ",", 
             RowBox[{"-", "16.84148892279766`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012521240303991646`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.694976960098423`", ",", "0.14421027926079488`"}], 
              "}"}], ",", 
             RowBox[{"-", "141.0872728616609`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01249019145047567`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.66760203244225`", ",", "0.12211145550534279`"}], 
              "}"}], ",", 
             RowBox[{"-", "141.4015572207307`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08317749832810706`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1565195605696372`", ",", "1.3367049720306945`"}], 
              "}"}], ",", "165.9308059330319`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08249257582622119`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0764932009547103`", ",", "1.3567604682757834`"}], 
              "}"}], ",", "160.7465129925466`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008843443212274158`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.388221823160652`", ",", "2.9095274470816745`"}], 
              "}"}], ",", "87.47340099626096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008649489005714219`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.388688848237903`", ",", "2.920111326351133`"}], 
              "}"}], ",", "79.44573838084902`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014624819685761025`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.675537600714022`", ",", "2.844785459439058`"}], 
              "}"}], ",", "93.28176069092505`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011409047810579394`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6666652177736796`", ",", "2.9995176613208825`"}], 
              "}"}], ",", "109.89286470521824`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.221655169890112`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3314682700404803`", ",", "2.4287451418733497`"}], 
              "}"}], ",", "158.7171791148065`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22105176618492475`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2138668225961746`", ",", "2.4745554143657085`"}], 
              "}"}], ",", "160.00303000624257`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012800904582199806`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4118601926906513`", ",", "1.9774712451865195`"}], 
              "}"}], ",", 
             RowBox[{"-", "110.13260484720092`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012760774007616042`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3814054766801434`", ",", "1.8943963373611692`"}], 
              "}"}], ",", 
             RowBox[{"-", "112.16910139086357`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008193712934874038`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.345010882115403`", ",", "1.4163935745926908`"}], 
              "}"}], ",", 
             RowBox[{"-", "122.81525962062665`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008172425749640224`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3381077552641885`", ",", "1.405688281109693`"}], 
              "}"}], ",", 
             RowBox[{"-", "121.88467502705065`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012184455247384334`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3311028726883682`", ",", 
               RowBox[{"-", "2.9944225439346672`"}]}], "}"}], ",", 
             RowBox[{"-", "144.41984490539085`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012080212992138361`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9000758278077194`", ",", 
               RowBox[{"-", "3.30278184605173`"}]}], "}"}], ",", 
             RowBox[{"-", "149.7135103897125`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01749894099858938`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.770942851840212`", ",", 
               RowBox[{"-", "3.9269453409866735`"}]}], "}"}], ",", 
             RowBox[{"-", "63.84944227105288`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01744661169277578`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.968359650415052`", ",", 
               RowBox[{"-", "4.329024738210822`"}]}], "}"}], ",", 
             RowBox[{"-", "65.66427169638028`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011655650103300682`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.2854634585950215`", ",", "2.930051637924093`"}], 
              "}"}], ",", "4.071825088794249`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011625347850951798`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.330169129435359`", ",", "2.933234084288223`"}], 
              "}"}], ",", "5.008590864257576`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026032176261107487`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.653245556053751`", ",", 
               RowBox[{"-", "3.501540898488227`"}]}], "}"}], ",", 
             RowBox[{"-", "48.75905679506792`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02451448565971566`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.773889911495325`", ",", 
               RowBox[{"-", "3.6391532943810976`"}]}], "}"}], ",", 
             RowBox[{"-", "59.972955689147874`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00832203806118468`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.421968446816875`", ",", 
               RowBox[{"-", "1.7712630858995746`"}]}], "}"}], ",", 
             "4.559118332117152`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008301303467120947`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.607815702618099`", ",", 
               RowBox[{"-", "1.7564436272019612`"}]}], "}"}], ",", 
             "4.979039262037431`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008664152882538302`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7481042170747867`", ",", "2.8938741145769025`"}], 
              "}"}], ",", "64.17011110860926`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008566952064386606`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8509603849960232`", ",", "3.1063593674367422`"}], 
              "}"}], ",", "70.23721468259609`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3746654523928048`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.656496102702559`", ",", "2.8886382820148584`"}], 
              "}"}], ",", "153.6344418079624`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3737409020829626`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6041384557393847`", ",", "2.9145896264108724`"}], 
              "}"}], ",", "153.77503772689917`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00853776203299345`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1617716970949905`", ",", "1.7234169393512568`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.94366928849846`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008495656917114966`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0981549132147475`", ",", "1.6950179459541808`"}], 
              "}"}], ",", 
             RowBox[{"-", "152.2756895282689`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009198770556912162`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.858952183105744`", ",", "2.80193995526425`"}], "}"}],
              ",", "26.458345282128356`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009084833907498703`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.340608338011412`", ",", "3.0416477975838894`"}], 
              "}"}], ",", "20.10785183101982`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02431882532272911`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8724930742377612`", ",", 
               RowBox[{"-", "0.8881629628885982`"}]}], "}"}], ",", 
             RowBox[{"-", "164.09876531973046`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022553581274540324`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8708371103867525`", ",", 
               RowBox[{"-", "0.888634715180869`"}]}], "}"}], ",", 
             RowBox[{"-", "176.10515322729353`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013066833339828143`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3099577862941993`", ",", 
               RowBox[{"-", "1.0111371331343069`"}]}], "}"}], ",", 
             "174.6000298845525`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013032187873623657`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1558050837059786`", ",", 
               RowBox[{"-", "0.9965654936102184`"}]}], "}"}], ",", 
             "175.69852476567385`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009159797611967821`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.335307961329535`", ",", "0.9947123023651957`"}], 
              "}"}], ",", "141.84427875817943`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008516651925285315`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.167880082384757`", ",", "1.1262556643233088`"}], 
              "}"}], ",", "153.72828314249105`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018436223252223514`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.9507690227662335`", ",", "0.8052219787546446`"}], 
              "}"}], ",", "73.05532981668725`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01839062436127478`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.976217467467496`", ",", "0.8887484947175992`"}], 
              "}"}], ",", "72.81659809803868`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013276518276663214`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.639163844367371`", ",", "0.35600074813492016`"}], 
              "}"}], ",", "111.6928538339839`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013169861514621333`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5917685741927246`", ",", "0.47514305546185914`"}], 
              "}"}], ",", "116.80633978204133`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02064081004072096`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.364338814151551`", ",", 
               RowBox[{"-", "1.8536428419150592`"}]}], "}"}], ",", 
             RowBox[{"-", "165.63105680552104`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02036317876011437`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.301717809521697`", ",", 
               RowBox[{"-", "1.869685007195425`"}]}], "}"}], ",", 
             RowBox[{"-", "172.21864653571396`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03963360653490009`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.388525244576338`", ",", 
               RowBox[{"-", "2.6663777250317304`"}]}], "}"}], ",", 
             RowBox[{"-", "115.9219753493684`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039526969423696795`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.385285491719142`", ",", 
               RowBox[{"-", "2.67304322521958`"}]}], "}"}], ",", 
             RowBox[{"-", "117.12793973260845`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015544163493847673`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.618630463181174`", ",", 
               RowBox[{"-", "2.1975476124328246`"}]}], "}"}], ",", 
             RowBox[{"-", "173.6903876126035`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015505816997499491`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.383847382218892`", ",", 
               RowBox[{"-", "2.223507775755651`"}]}], "}"}], ",", 
             RowBox[{"-", "173.56806680410423`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015434845306351783`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.10977393330874`", ",", 
               RowBox[{"-", "1.6417027819848846`"}]}], "}"}], ",", 
             "102.79974972278914`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015348831316798414`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.10964461137912`", ",", 
               RowBox[{"-", "1.6411335578766304`"}]}], "}"}], ",", 
             "106.84302650066583`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02112427731894346`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.232240954122844`", ",", 
               RowBox[{"-", "0.5926830924116476`"}]}], "}"}], ",", 
             "68.35366889052445`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02101616993305529`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.307891776053028`", ",", 
               RowBox[{"-", "0.40206142026351155`"}]}], "}"}], ",", 
             "72.13683617343219`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013463256595579277`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.436956136237303`", ",", 
               RowBox[{"-", "0.4163147868373776`"}]}], "}"}], ",", 
             "119.60905530158598`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013327980320105749`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.378723026894536`", ",", 
               RowBox[{"-", "0.3138436879739406`"}]}], "}"}], ",", 
             "125.36156348366431`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01920166268202976`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.902025869288929`", ",", 
               RowBox[{"-", "0.9353251541593269`"}]}], "}"}], ",", 
             "160.13516849813638`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0191355626097128`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.425748637850462`", ",", 
               RowBox[{"-", "0.7632457802846241`"}]}], "}"}], ",", 
             "162.56415410757737`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09291268710968995`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.317042174504154`", ",", 
               RowBox[{"-", "2.496568643107816`"}]}], "}"}], ",", 
             RowBox[{"-", "131.97554935272328`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09250139933565829`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.267414443626319`", ",", 
               RowBox[{"-", "2.551733145538712`"}]}], "}"}], ",", 
             RowBox[{"-", "128.65301474744336`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012538840079773187`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.865264422165415`", ",", "0.01558219543576532`"}], 
              "}"}], ",", "164.0476294775115`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01201232796385104`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5553008412191462`", ",", "0.10418403203907302`"}], 
              "}"}], ",", "174.13396154784553`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011722491999187169`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.547614972963494`", ",", "2.660373650005636`"}], 
              "}"}], ",", "82.2301149797245`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010454560928429111`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.554837225932531`", ",", "2.7133042740968643`"}], 
              "}"}], ",", "68.68995299772382`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020868621154033862`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.015837296923768`", ",", "3.1035802932107157`"}], 
              "}"}], ",", "100.74194390563649`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020816945212477858`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.969200230953496`", ",", "3.3494134145434793`"}], 
              "}"}], ",", "100.46595710605715`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10768276134729257`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1844334948319033`", ",", "0.8577212354772984`"}], 
              "}"}], ",", "155.26188742832935`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10737113842549359`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1176780270552102`", ",", "0.888479135663443`"}], 
              "}"}], ",", "153.61507343154858`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04114962275121717`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.566128926377194`", ",", 
               RowBox[{"-", "1.7924870565715108`"}]}], "}"}], ",", 
             RowBox[{"-", "141.16534427661526`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03958053518457367`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4861205041345973`", ",", 
               RowBox[{"-", "1.8568951960375732`"}]}], "}"}], ",", 
             RowBox[{"-", "131.3980387215106`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015910411416999663`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.613537725456426`", ",", 
               RowBox[{"-", "3.6216851368345666`"}]}], "}"}], ",", 
             RowBox[{"-", "76.8199666371566`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01580250332956923`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.625609448203834`", ",", 
               RowBox[{"-", "3.6732339857997185`"}]}], "}"}], ",", 
             RowBox[{"-", "72.19531634797086`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011674209535511395`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.322692665885227`", ",", 
               RowBox[{"-", "1.9171446844618552`"}]}], "}"}], ",", 
             RowBox[{"-", "38.6761922976005`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011632371798397366`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.338693997548402`", ",", 
               RowBox[{"-", "1.9299532556065953`"}]}], "}"}], ",", 
             RowBox[{"-", "36.0917061542994`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009234653630834382`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6460075670016345`", ",", "3.363384076381549`"}], 
              "}"}], ",", "147.5168927694888`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009210907228012639`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.641308145352485`", ",", "3.366375990633749`"}], 
              "}"}], ",", "146.68300441369152`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015814907245503013`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.967666509375516`", ",", "3.0871540433788582`"}], 
              "}"}], ",", "85.84444866601483`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015766487599311256`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9869882325984545`", ",", "3.3530902027251317`"}], 
              "}"}], ",", "87.77233120355793`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12442459998907568`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.425253906713074`", ",", 
               RowBox[{"-", "2.687134026360825`"}]}], "}"}], ",", 
             RowBox[{"-", "102.43631345021912`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12334643097475351`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.419796584842048`", ",", 
               RowBox[{"-", "2.7118805555779257`"}]}], "}"}], ",", 
             RowBox[{"-", "107.76645659227735`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04039309089137395`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.118134773638745`", ",", "2.367199620738484`"}], 
              "}"}], ",", "107.34164242021471`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040222472700680044`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.117789784286584`", ",", "2.3683044252525343`"}], 
              "}"}], ",", "110.50893237897267`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008029295604281504`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.182146425329703`", ",", "0.4503276617857824`"}], 
              "}"}], ",", "174.91062488200723`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00800139876845557`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.0872471334290434`", ",", "0.4587794600283177`"}], 
              "}"}], ",", "172.44533634568973`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015286417541420677`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.68166825234663`", ",", 
               RowBox[{"-", "0.834249674863952`"}]}], "}"}], ",", 
             RowBox[{"-", "174.64263886323312`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015117817506643988`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.601379121612772`", ",", 
               RowBox[{"-", "0.8417789523378222`"}]}], "}"}], ",", 
             RowBox[{"-", "168.6241602326469`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2609669943318832`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.857503797053943`", ",", 
               RowBox[{"-", "1.631596318035911`"}]}], "}"}], ",", 
             RowBox[{"-", "90.27712035221171`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26008655888193055`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.855348031303997`", ",", 
               RowBox[{"-", "2.0773063315811187`"}]}], "}"}], ",", 
             RowBox[{"-", "92.62562768241764`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27677284337226055`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.821491369572861`", ",", 
               RowBox[{"-", "1.4078409622156671`"}]}], "}"}], ",", 
             RowBox[{"-", "62.98586072430847`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27518630244426884`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.85970811237031`", ",", 
               RowBox[{"-", "1.482799807515262`"}]}], "}"}], ",", 
             RowBox[{"-", "58.85763930038267`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024813013320613118`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.360966391982671`", ",", 
               RowBox[{"-", "0.5777872347677663`"}]}], "}"}], ",", 
             RowBox[{"-", "96.95739056361747`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024694866876892138`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.355657786762561`", ",", 
               RowBox[{"-", "0.6212897865834256`"}]}], "}"}], ",", 
             RowBox[{"-", "100.51475375406419`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012413652334497018`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.075636979375578`", ",", "1.354708650666049`"}], 
              "}"}], ",", "168.67653461848235`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01047614904650106`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.024587853821008`", ",", "1.3649310161556567`"}], 
              "}"}], ",", "153.60854429084867`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17622538980612734`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.462835957629652`", ",", "0.3962580859494457`"}], 
              "}"}], ",", 
             RowBox[{"-", "125.40265967931498`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17433134228123778`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.401800641306805`", ",", "0.31038149519909297`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.34731050636665`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010707899885893532`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.234378837136803`", ",", "0.09399011306815414`"}], 
              "}"}], ",", 
             RowBox[{"-", "74.45091604437111`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01064693246405689`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.300742584987046`", ",", 
               RowBox[{"-", "0.14451621421034622`"}]}], "}"}], ",", 
             RowBox[{"-", "78.5588596081471`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0508376786544684`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.133875783682815`", ",", "2.4995612934954696`"}], 
              "}"}], ",", "71.3905729691707`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05071237055720806`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.180237032875569`", ",", "2.637246016100087`"}], 
              "}"}], ",", "71.427023302306`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2655809918373722`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.013927724321256`", ",", "2.6322695172548927`"}], 
              "}"}], ",", "141.79807361630793`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.258255220130773`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.881221144900748`", ",", "2.7367065227106515`"}], 
              "}"}], ",", "145.95551196524468`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.047122397252328675`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.848681154583996`", ",", "2.563767102786102`"}], 
              "}"}], ",", 
             RowBox[{"-", "147.79442573655493`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04227214269382524`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.592467754632565`", ",", "2.4023860998368267`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.136963347192`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008675885446115741`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.496013510024986`", ",", "2.3292753428951984`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.72166773631858`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008125914795933447`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.340774332740918`", ",", "2.1929983763609657`"}], 
              "}"}], ",", 
             RowBox[{"-", "150.23428083855993`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24579701805193852`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.311736426290701`", ",", "2.4019540191871216`"}], 
              "}"}], ",", "149.17672795277224`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24414790491148575`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.132449862213479`", ",", "2.5089289844678593`"}], 
              "}"}], ",", "153.76984430794428`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008112634084741051`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.324263802301104`", ",", "2.5996489822677544`"}], 
              "}"}], ",", "77.07512364186316`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25843335636736947`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.201544877431438`", ",", "1.1301121692279588`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.10243776999438`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25779341729664584`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.20785455614225`", ",", "0.9396647794255726`"}], 
              "}"}], ",", 
             RowBox[{"-", "87.82676214747465`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07552132102494946`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.911408050797058`", ",", "0.38375460538032846`"}], 
              "}"}], ",", 
             RowBox[{"-", "118.74604454775931`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.075290895035326`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.878705842196716`", ",", "0.3241365905784629`"}], 
              "}"}], ",", 
             RowBox[{"-", "120.65774906155809`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024168896503610877`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3181519197722915`", ",", "0.352797237396545`"}], 
              "}"}], ",", 
             RowBox[{"-", "105.35071151576268`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024031922073260648`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.29714803826906`", ",", "0.27628610566998607`"}], 
              "}"}], ",", 
             RowBox[{"-", "109.44474058759633`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19721916761708747`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4981801653118625`", ",", 
               RowBox[{"-", "0.6300356770624768`"}]}], "}"}], ",", 
             RowBox[{"-", "82.02813803718419`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1967324479978787`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5252117425817255`", ",", 
               RowBox[{"-", "0.8230631277620201`"}]}], "}"}], ",", 
             RowBox[{"-", "82.17431635125322`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010155848503700847`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.079872856413603`", ",", "1.1491620785190124`"}], 
              "}"}], ",", "125.3789616256004`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00999760033494628`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.946357056947727`", ",", "1.3371832328657298`"}], 
              "}"}], ",", "118.36509974558575`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3139768236935531`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.884183329433145`", ",", "1.1158944386613112`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.31382592502862`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.31318590669708823`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6865304189315635`", ",", "1.0490457747668551`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.91037740502566`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009547589555766872`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.859839177235601`", ",", "0.9188957354033456`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.00661347565753`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00943484333847693`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8632038120715215`", ",", "0.8222252776510854`"}], 
              "}"}], ",", 
             RowBox[{"-", "94.22034170073402`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2824554827921963`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8771242751091632`", ",", "1.0203648055844956`"}], 
              "}"}], ",", "167.51229180204152`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2813076860894983`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.689696749116665`", ",", "1.0618743042281937`"}], 
              "}"}], ",", "170.54833521272116`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.287080137891467`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.851433958250631`", ",", "0.9509216586411364`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.1791107064613`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2857843220414894`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5742653848532453`", ",", "0.9177688138836663`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.56518751062592`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009010673179643778`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.773314947406275`", ",", 
               RowBox[{"-", "2.362531201942003`"}]}], "}"}], ",", 
             RowBox[{"-", "71.59888101474128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00898832765291629`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.925505318214823`", ",", 
               RowBox[{"-", "2.8200025049527064`"}]}], "}"}], ",", 
             RowBox[{"-", "71.2825089684225`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08603215893289086`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.590262861182729`", ",", "3.6107477297384736`"}], 
              "}"}], ",", "102.26825451098945`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08144387988438724`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.58082047593546`", ",", "3.654169993663881`"}], "}"}],
              ",", "91.36709559311188`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.8436975977941865`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8485975650478776`", ",", "3.044158711728051`"}], 
              "}"}], ",", "153.84928176560356`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.5501949375025736`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7427671292921243`", ",", "3.096120721976002`"}], 
              "}"}], ",", "138.69549935917382`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2467792650334446`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.622847132670974`", ",", "3.201489704433622`"}], 
              "}"}], ",", "82.60824634315858`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039285385455173426`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.643384671488563`", ",", "3.3597983825061997`"}], 
              "}"}], ",", "26.52099332714331`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4189018213903022`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.667391997490735`", ",", "3.360284447263403`"}], 
              "}"}], ",", "105.16534432153486`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.4172591163243085`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.649074573465307`", ",", "3.427865298501506`"}], 
              "}"}], ",", "108.07772044583567`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015564483242010537`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.277758717143984`", ",", "3.366557381576849`"}], 
              "}"}], ",", "101.28287016045299`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015523502650433552`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.233858861547429`", ",", "3.5865970474625457`"}], 
              "}"}], ",", "100.23912546621924`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2351336208922049`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.898000674453068`", ",", "3.368881404682121`"}], 
              "}"}], ",", "22.81905442658029`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.234174851383517`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.899134242939919`", ",", "3.3693583566555887`"}], 
              "}"}], ",", "25.866816677443797`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012105074674283072`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8574455005292645`", ",", "2.816628517706533`"}], 
              "}"}], ",", 
             RowBox[{"-", "61.877345235488804`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01207483296882638`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.958198181637355`", ",", "2.6281149491080376`"}], 
              "}"}], ",", 
             RowBox[{"-", "61.407861221097846`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16306734246434534`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8427720735431`", ",", "2.7228770601336127`"}], "}"}],
              ",", "11.246403389447611`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16265773361049068`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.047190372337455`", ",", "2.7635250484531877`"}], 
              "}"}], ",", "10.690146803127895`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10096808479410525`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.820946895856471`", ",", "1.666690518766145`"}], 
              "}"}], ",", 
             RowBox[{"-", "67.20740734681608`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09942613898925415`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.867096760510475`", ",", "1.5568645856293863`"}], 
              "}"}], ",", 
             RowBox[{"-", "60.2521408990183`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06235589354395006`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.092211361633606`", ",", "1.8481257845740613`"}], 
              "}"}], ",", 
             RowBox[{"-", "100.14292058237176`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05621955499857236`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.088297965282513`", ",", "1.8262510277303763`"}], 
              "}"}], ",", 
             RowBox[{"-", "86.97759877340057`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035218362921186554`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.387311192534063`", ",", "2.0334509906640714`"}], 
              "}"}], ",", 
             RowBox[{"-", "133.27719896748337`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.034906898048323344`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.277659440999164`", ",", "1.9169985646153616`"}], 
              "}"}], ",", 
             RowBox[{"-", "127.88878569524309`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02440197809350946`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8238202808915664`", ",", "2.9838764681221184`"}], 
              "}"}], ",", "146.86209556982155`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023717147410956534`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.648140038558968`", ",", "3.098566661548034`"}], 
              "}"}], ",", "155.64771662742973`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014959716100042153`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.641487887169879`", ",", "3.3291496725314924`"}], 
              "}"}], ",", "101.78081015021438`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014913376547723609`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.624830179117953`", ",", "3.40901924966295`"}], "}"}],
              ",", "103.76288155218614`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08212610034430937`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3805055831974253`", ",", "0.37158406636224844`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.99191308741524`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08184612156414703`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3641239810316463`", ",", "0.3671921510397863`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.60149143015437`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037301211389323546`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.573649858233891`", ",", "1.7627108399105784`"}], 
              "}"}], ",", "148.12389774973852`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09042807278543785`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.098053619989534`", ",", "1.2406365255603116`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.80545662432036`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09010655765813673`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9358161488169614`", ",", "1.2372535926012982`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.25109455619653`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021330946697367084`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                 "0.`", ",", "0.9999999999999999`", ",", 
                  "167.35910683550452`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.875021438164752`", ",", "0.5253603907749506`"}], 
              "}"}], ",", 
             RowBox[{"-", "139.89031881584566`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021005434590515924`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.73748714802897`", ",", "0.40950604122527534`"}], 
              "}"}], ",", 
             RowBox[{"-", "146.8433877303675`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008231160805651819`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.070713347817326`", ",", 
               RowBox[{"-", "1.596189391324968`"}]}], "}"}], ",", 
             RowBox[{"-", "91.21771694293415`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008209098769605051`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.065334003334559`", ",", 
               RowBox[{"-", "1.8492591456462795`"}]}], "}"}], ",", 
             RowBox[{"-", "92.39653497720954`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15086817163443453`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2065309528116637`", ",", "1.3940584934118068`"}], 
              "}"}], ",", "166.45237241289396`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1504130030912096`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1330446222023243`", ",", "1.4117656203703455`"}], 
              "}"}], ",", "164.5944072842307`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008747646263565279`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.843136121561057`", ",", 
               RowBox[{"-", "1.0614196196331982`"}]}], "}"}], ",", 
             "138.39111306868983`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008516627514714629`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.374937088589322`", ",", 
               RowBox[{"-", "0.6456031838817202`"}]}], "}"}], ",", 
             "146.98743662182605`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16557074836494867`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.910787109517695`", ",", 
               RowBox[{"-", "2.0825841162416596`"}]}], "}"}], ",", 
             RowBox[{"-", "112.26245182184724`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16220192185862228`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8685673441515807`", ",", 
               RowBox[{"-", "2.1857190069215964`"}]}], "}"}], ",", 
             RowBox[{"-", "120.06429390496052`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008828564696933742`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.836149343049395`", ",", 
               RowBox[{"-", "2.845038464983356`"}]}], "}"}], ",", 
             RowBox[{"-", "78.3994253620219`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00854113758069572`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9074945903586378`", ",", 
               RowBox[{"-", "3.192587711922769`"}]}], "}"}], ",", 
             RowBox[{"-", "87.65461849933202`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.042095286440483146`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3278659338480487`", ",", "2.5662557517157665`"}], 
              "}"}], ",", "111.61995675261286`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0419764609277312`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.311936366792392`", ",", "2.6064483382348436`"}], 
              "}"}], ",", "110.11090334571954`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04882884288328304`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.199617787190727`", ",", "2.409714096482288`"}], 
              "}"}], ",", "115.7630214386782`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04847285641668143`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.180860665318691`", ",", "2.4485790599121247`"}], 
              "}"}], ",", "120.59725946101781`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01261996716451644`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3170462945642005`", ",", "0.5115606526621097`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.9264349029009`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01255782721996194`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1737449217559712`", ",", "0.4809086478989754`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.5895253900572`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18526359813962467`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.886521337520707`", ",", "3.1181709029604834`"}], 
              "}"}], ",", "144.7423617110144`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18475735323859188`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.885546272031111`", ",", "3.1188602060507615`"}], 
              "}"}], ",", "143.43168369151715`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03233327772179539`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.352014452126943`", ",", "1.193465846067691`"}], 
              "}"}], ",", 
             RowBox[{"-", "55.556644529000955`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03223665902254091`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.38442038266304`", ",", "1.146214917856264`"}], "}"}],
              ",", 
             RowBox[{"-", "53.745465952900496`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01325121479914858`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.869205868538643`", ",", "1.1908184192383027`"}], 
              "}"}], ",", 
             RowBox[{"-", "86.70035972576531`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012955010863459836`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.876421105352835`", ",", "1.0656697795973613`"}], 
              "}"}], ",", 
             RowBox[{"-", "78.61513400628635`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019002682548268236`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.882439085046726`", ",", "2.4952029161458746`"}], 
              "}"}], ",", 
             RowBox[{"-", "163.58381902705713`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018857482624384282`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.665748465648419`", ",", "2.431360896350264`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.55344279014494`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07782823637156928`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.36873589652042`", ",", "3.1892380843199777`"}], 
              "}"}], ",", "5.400259744282775`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07761646722590164`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.586433657280547`", ",", "3.2098175772256794`"}], 
              "}"}], ",", "6.68298361454642`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01095839230399624`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.887209292294565`", ",", "3.364039245201363`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.6375870304259`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010926500070207843`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.878341464867088`", ",", "3.355366615909915`"}], 
              "}"}], ",", 
             RowBox[{"-", "137.31434324941807`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01089429829311552`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.0291737225527635`", ",", "3.3731969004548623`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.14586346786507`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010715530046262984`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.05028264096431`", ",", "3.3076631218756067`"}], 
              "}"}], ",", 
             RowBox[{"-", "64.98084543721473`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07495742786805175`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.3305081301654775`", ",", "3.5734870220448216`"}], 
              "}"}], ",", "159.95307281642837`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07455453200892936`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.316650533579623`", ",", "3.5785436319596386`"}], 
              "}"}], ",", "156.01935726915286`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019117156574398258`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.258892531326898`", ",", "2.1212958894635108`"}], 
              "}"}], ",", 
             RowBox[{"-", "57.44385450554936`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015863803786497575`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.319072018686604`", ",", "2.0270369739297505`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.8902545685189`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011194206058731483`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.195563023826857`", ",", "2.0683216790920302`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.4057904688717`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011050292583148413`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.114170409498007`", ",", "2.067477533124626`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.94833868944104`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032426384914735054`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.631857465184819`", ",", "2.876601243636376`"}], 
              "}"}], ",", "164.84978281846182`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03227175994160671`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.630982662709606`", ",", "2.876838106199413`"}], 
              "}"}], ",", "161.28774808691148`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012459219588637941`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.428739814516301`", ",", 
               RowBox[{"-", "0.06855911911277818`"}]}], "}"}], ",", 
             RowBox[{"-", "141.71584157980283`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012426480776489567`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.382351075793916`", ",", 
               RowBox[{"-", "0.10517391641614338`"}]}], "}"}], ",", 
             RowBox[{"-", "140.68833266117082`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08181329329720088`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8263520093400993`", ",", "1.444130763380094`"}], 
              "}"}], ",", "155.5622200520613`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08136198035884218`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6487928585431653`", ",", "1.524816379995089`"}], 
              "}"}], ",", "159.57478232788543`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008459788598646096`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.425356686909021`", ",", "3.1169129380419007`"}], 
              "}"}], ",", "71.41807576543697`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008438262258830306`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.516830552912185`", ",", "3.3890059587277985`"}], 
              "}"}], ",", "72.14029031681018`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008900374482621383`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6155601683525647`", ",", "3.140748752813215`"}], 
              "}"}], ",", "126.50396871951145`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008818277576626286`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.488082437448585`", ",", "3.3130000643458306`"}], 
              "}"}], ",", "120.99543084306072`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22045000510342017`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.868843846892141`", ",", "2.60011284487213`"}], "}"}],
              ",", "161.2888808976789`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21911161364479734`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8116934041868635`", ",", "2.6194695648763573`"}], 
              "}"}], ",", "156.98944933426262`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012720769241564482`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.26131283152225`", ",", "1.5996640494127237`"}], 
              "}"}], ",", 
             RowBox[{"-", "114.2055979345264`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01268743223333858`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0638595987935724`", ",", "1.1604254624250783`"}], 
              "}"}], ",", 
             RowBox[{"-", "113.20005916153707`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00815119386830329`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.191782608675725`", ",", "1.1704668874483517`"}], 
              "}"}], ",", 
             RowBox[{"-", "120.95409043347543`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008127404314064142`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.153448928015458`", ",", "1.10655298156924`"}], "}"}],
              ",", 
             RowBox[{"-", "122.64564481143964`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011976862565665873`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.69371070634779`", ",", 
               RowBox[{"-", "3.4233066182279197`"}]}], "}"}], ",", 
             RowBox[{"-", "155.00717587403403`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011947336524091232`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.670413320797123`", ",", 
               RowBox[{"-", "3.4341668154465013`"}]}], "}"}], ",", 
             RowBox[{"-", "154.94475522401802`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011595124378120948`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.65303976200892`", ",", "2.961530386470526`"}], "}"}],
              ",", "5.9453566397216795`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011563207725312523`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.899423196141074`", ",", "2.98718877936853`"}], "}"}],
              ",", "4.587841780808842`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023085277278882387`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.854366695460026`", ",", 
               RowBox[{"-", "3.7783913530293813`"}]}], "}"}], ",", 
             RowBox[{"-", "71.18685458322774`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022978405695244324`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.903634815891672`", ",", 
               RowBox[{"-", "3.9230067389810745`"}]}], "}"}], ",", 
             RowBox[{"-", "67.71918128849634`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008280620533886911`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.921928558588366`", ",", 
               RowBox[{"-", "1.7290781022400192`"}]}], "}"}], ",", 
             "5.398960191956841`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00818566325929982`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.121394253571286`", ",", 
               RowBox[{"-", "1.7102266949563503`"}]}], "}"}], ",", 
             RowBox[{"-", "0.7308156028906033`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008470841716264398`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.933775921915895`", ",", "3.33685800507418`"}], "}"}],
              ",", "76.30431825658285`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008449774780802957`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9501014524724933`", ",", "3.4038499652223475`"}], 
              "}"}], ",", "75.92138374007257`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.37281863325722814`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.319455317078221`", ",", "3.0548251894317278`"}], 
              "}"}], ",", "153.91563364583595`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3627022135869865`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2762663904675184`", ",", "3.0759686155040873`"}], 
              "}"}], ",", "145.2351040608176`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009841911000837502`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.11741073100309`", ",", "3.1862318942371473`"}], 
              "}"}], ",", "70.17604514487674`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008972308485813917`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.558434112117004`", ",", "3.121394561388964`"}], 
              "}"}], ",", "13.757358379911222`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00869483209502335`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.726026292771315`", ",", "3.1624269201018165`"}], 
              "}"}], ",", "22.848829995650885`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02091647197415751`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7207957282082207`", ",", 
               RowBox[{"-", "0.8988499529645195`"}]}], "}"}], ",", 
             "171.88845886514332`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019911736844423877`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.580453695055914`", ",", 
               RowBox[{"-", "0.8788474812033391`"}]}], "}"}], ",", 
             RowBox[{"-", "177.57113826326636`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01834513825149751`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.073286747564538`", ",", "1.2026505553483355`"}], 
              "}"}], ",", "72.57786637938709`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018299469443057163`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.201736972220186`", ",", "1.6119815177360024`"}], 
              "}"}], ",", "72.98103870054057`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0130640615784921`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.499397579882815`", ",", "0.6579562769550734`"}], 
              "}"}], ",", "121.91982573009861`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020089281786825147`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.135532990828835`", ",", 
               RowBox[{"-", "1.892394399522408`"}]}], "}"}], ",", 
             RowBox[{"-", "178.80623626590676`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019981090247845213`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.132323290557163`", ",", 
               RowBox[{"-", "1.8924612836515469`"}]}], "}"}], ",", 
             RowBox[{"-", "174.86655270601807`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03942061922742455`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.249945292601955`", ",", 
               RowBox[{"-", "2.9372034400351885`"}]}], "}"}], ",", 
             RowBox[{"-", "118.33390411584821`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039057655766644425`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.163782036569682`", ",", 
               RowBox[{"-", "3.096999373830829`"}]}], "}"}], ",", 
             RowBox[{"-", "112.83048391429293`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015467565099601897`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.071484832429513`", ",", 
               RowBox[{"-", "2.258721142881024`"}]}], "}"}], ",", 
             RowBox[{"-", "173.44574599559903`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015402976513957261`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.931722774464518`", ",", 
               RowBox[{"-", "2.2747790926863147`"}]}], "}"}], ",", 
             RowBox[{"-", "176.57441466241713`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015263296658670286`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.037465293458888`", ",", 
               RowBox[{"-", "1.4027113492410619`"}]}], "}"}], ",", 
             "110.88630327854261`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014321783793023742`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.931161121804959`", ",", 
               RowBox[{"-", "1.1241284316455704`"}]}], "}"}], ",", 
             "99.47156723245195`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013194063275259375`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.236712677796566`", ",", 
               RowBox[{"-", "0.11373154791280835`"}]}], "}"}], ",", 
             "131.11407166574259`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01314859414084821`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.183012615094738`", ",", 
               RowBox[{"-", "0.052204520762133305`"}]}], "}"}], ",", 
             "133.54737245370248`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019069690081209758`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.152490345497259`", ",", 
               RowBox[{"-", "0.6774240377395112`"}]}], "}"}], ",", 
             "164.99313971701804`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018586723648170465`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.017570463917072`", ",", 
               RowBox[{"-", "0.6412550494577799`"}]}], "}"}], ",", 
             "156.5262313280434`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09209193217018218`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.077151719566918`", ",", 
               RowBox[{"-", "2.7896193673170946`"}]}], "}"}], ",", 
             RowBox[{"-", "125.33048014216337`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09182984584338193`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.04843387188945`", ",", 
               RowBox[{"-", "2.830133321013055`"}]}], "}"}], ",", 
             RowBox[{"-", "123.77506396890465`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011507924352898182`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3735957448722327`", ",", "0.12285257957385659`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.77970638182043`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010978168210542209`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3126918097624993`", ",", "0.11835838566538617`"}], 
              "}"}], ",", "173.82474660947872`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009323772130858846`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.613477516367497`", ",", "2.8636309481357225`"}], 
              "}"}], ",", "55.14979101572329`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008686223664738335`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.836228146190559`", ",", "3.1835285607538286`"}], 
              "}"}], ",", "66.93687245421152`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020765397233517745`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.920138022643766`", ",", "3.6150100035364083`"}], 
              "}"}], ",", "100.1899703064778`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012562704846381669`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.893635248830319`", ",", "3.7624543145467406`"}], 
              "}"}], ",", "119.73434791254286`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.038071278926875105`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.383789456511689`", ",", 
               RowBox[{"-", "1.9729749954037983`"}]}], "}"}], ",", 
             RowBox[{"-", "121.63073316640606`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03796757085197436`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.330907938269609`", ",", 
               RowBox[{"-", "2.058829454821125`"}]}], "}"}], ",", 
             RowBox[{"-", "120.34053813103519`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01569532709972737`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.7020451715431815`", ",", 
               RowBox[{"-", "3.9112365439015684`"}]}], "}"}], ",", 
             RowBox[{"-", "67.57066605878501`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0156346115766811`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.771706365735673`", ",", 
               RowBox[{"-", "4.080001974130683`"}]}], "}"}], ",", 
             RowBox[{"-", "70.43491731169665`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011590683998308326`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.555889127695717`", ",", 
               RowBox[{"-", "2.088286515364006`"}]}], "}"}], ",", 
             RowBox[{"-", "33.50722001099845`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011560738412840877`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.648601230646284`", ",", 
               RowBox[{"-", "2.149668120186087`"}]}], "}"}], ",", 
             RowBox[{"-", "34.38673466128312`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00918722188775691`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3690487587760924`", ",", "3.5453326097585736`"}], 
              "}"}], ",", "145.84911605789512`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009136442549007983`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2605448101087156`", ",", "3.61893592385977`"}], 
              "}"}], ",", "141.8306390546295`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12227760455364485`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.34954007318907`", ",", 
               RowBox[{"-", "2.9311449148270943`"}]}], "}"}], ",", 
             RowBox[{"-", "113.09659973433551`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12197617804681277`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.277103947723624`", ",", 
               RowBox[{"-", "3.1009969653937595`"}]}], "}"}], ",", 
             RowBox[{"-", "113.04308606251146`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04005257519182435`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.023701590059098`", ",", "2.6198351822922343`"}], 
              "}"}], ",", "113.6762223377305`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03812215150147079`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.889445456338815`", ",", "2.926024376894937`"}], 
              "}"}], ",", "103.12433828480121`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014951077029324087`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.382315238116761`", ",", 
               RowBox[{"-", "0.8858538580442203`"}]}], "}"}], ",", 
             RowBox[{"-", "162.6056816020606`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01442919213850764`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.378244028380549`", ",", 
               RowBox[{"-", "0.8871292544932251`"}]}], "}"}], ",", 
             RowBox[{"-", "172.08504444742292`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2592090937945081`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.842558002495407`", ",", 
               RowBox[{"-", "2.3562116887071047`"}]}], "}"}], ",", 
             RowBox[{"-", "94.97413501262356`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2333391156040766`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.838998481869474`", ",", 
               RowBox[{"-", "2.3971098311794203`"}]}], "}"}], ",", 
             RowBox[{"-", "81.75344189579589`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023288063482978356`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.860468037503002`", ",", 
               RowBox[{"-", "2.5452454429729006`"}]}], "}"}], ",", 
             RowBox[{"-", "22.152648996405883`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2736088560216683`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.987758823987346`", ",", 
               RowBox[{"-", "1.6947174978191548`"}]}], "}"}], ",", 
             RowBox[{"-", "54.72941787645714`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2719906318120623`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.249651997048355`", ",", 
               RowBox[{"-", "2.065005472982989`"}]}], "}"}], ",", 
             RowBox[{"-", "58.951100522971096`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024577282984038457`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.296808618032822`", ",", 
               RowBox[{"-", "0.9383558163661906`"}]}], "}"}], ",", 
             RowBox[{"-", "104.07211694451097`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024502237353548752`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.2484503078147435`", ",", 
               RowBox[{"-", "1.131275623238627`"}]}], "}"}], ",", 
             RowBox[{"-", "102.15683112746794`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008841048217494886`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.892238369604698`", ",", "1.4306052722726568`"}], 
              "}"}], ",", "138.54055396321507`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008715109357626271`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.701552488729594`", ",", "1.5990694274151984`"}], 
              "}"}], ",", "131.78727179072587`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17245765173232358`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.243269221268635`", ",", "0.13022919532730276`"}], 
              "}"}], ",", 
             RowBox[{"-", "137.29196133341844`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17188949785270988`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.188201289061612`", ",", "0.0793996632269098`"}], 
              "}"}], ",", 
             RowBox[{"-", "139.5428878218816`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01058631217158876`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.35088627346321`", ",", 
               RowBox[{"-", "0.39228288094063185`"}]}], "}"}], ",", 
             RowBox[{"-", "82.66680317192309`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01047791027299739`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.351114219330654`", ",", 
               RowBox[{"-", "0.3940541335758071`"}]}], "}"}], ",", 
             RowBox[{"-", "76.86031183280261`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05058737132769413`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.267663358684314`", ",", "2.8974339656723194`"}], 
              "}"}], ",", "71.46347363545128`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04165783591531445`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.359469019374845`", ",", "3.1712319685556047`"}], 
              "}"}], ",", "87.07201362095188`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2509718533997882`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.656119914545259`", ",", "2.8887936551931834`"}], 
              "}"}], ",", "150.11295031418166`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.247866025183471`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.636500606390305`", ",", "2.9000693577730754`"}], 
              "}"}], ",", "150.4574800741623`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037921119300415765`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.435364607407312`", ",", "2.3487108780900354`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.47950095782878`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037585883610391155`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.3900416727379525`", ",", "2.3443304094935713`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.0922107978152`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24250985607999634`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.90909050153152`", ",", "2.6189814743779674`"}], 
              "}"}], ",", "158.36296066311635`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2418475581176971`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.851180149953768`", ",", "2.6419531208205154`"}], 
              "}"}], ",", "157.05598674471776`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25715506285888134`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.220310908486281`", ",", "0.6114199351966487`"}], 
              "}"}], ",", 
             RowBox[{"-", "87.5510865249483`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25651258153130724`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.230386758025595`", ",", "0.3758248157132166`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.02163570337042`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07506117210724828`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.713475040829654`", ",", "0.0453881684976358`"}], 
              "}"}], ",", 
             RowBox[{"-", "122.56945357535706`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07415323361893261`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.6645860830738215`", ",", 
               RowBox[{"-", "0.031147231682318602`"}]}], "}"}], ",", 
             RowBox[{"-", "128.85199000655862`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023895723929679133`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.232629346704844`", ",", "0.0935309731620283`"}], 
              "}"}], ",", 
             RowBox[{"-", "113.53876965942996`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02383202775510653`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.053641669446334`", ",", 
               RowBox[{"-", "0.31735196978193336`"}]}], "}"}], ",", 
             RowBox[{"-", "114.67744659673802`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1962469295600287`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5681643822077485`", ",", 
               RowBox[{"-", "1.1355830966992775`"}]}], "}"}], ",", 
             RowBox[{"-", "82.32049466532227`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1911250966889257`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.606344688347924`", ",", 
               RowBox[{"-", "1.4187334913977334`"}]}], "}"}], ",", 
             RowBox[{"-", "90.88020349994467`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009841817985064952`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.837885967467196`", ",", "1.5380887190130017`"}], 
              "}"}], ",", "111.35123786557104`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009811690677919238`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.818216791195257`", ",", "1.5884045492762944`"}], 
              "}"}], ",", "113.27836459837478`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.31239698204415983`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.349692745732636`", ",", "0.9390177742939605`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.5069288850233`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2801784840613447`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.257659461780888`", ",", "0.9100120270629408`"}], 
              "}"}], ",", 
             RowBox[{"-", "149.1565276967669`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028895701438889386`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.117167632438771`", ",", "0.8261175470069844`"}], 
              "}"}], ",", 
             RowBox[{"-", "89.83324921222524`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009323428526295995`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.846694276822012`", ",", "0.5984956863594586`"}], 
              "}"}], ",", 
             RowBox[{"-", "100.43406992581052`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00929171402085879`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.807577656537465`", ",", "0.386077457015285`"}], 
              "}"}], ",", 
             RowBox[{"-", "102.81564141420775`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28016455361656745`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.412383262155191`", ",", "1.1080402052512859`"}], 
              "}"}], ",", "173.58437862340068`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2673399707217089`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.109795497765404`", ",", "1.1420644005632679`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.03918391239137`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012237535303347718`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9148613770099985`", ",", "1.1285672376053026`"}], 
              "}"}], ",", 
             RowBox[{"-", "108.32690231020912`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2844943552158621`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3595970983370855`", ",", "0.9048842717050697`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.95126431479076`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27574864497424645`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3474023378701885`", ",", "0.9048738988616299`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.87878616125818`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008476856233695713`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.202642609176679`", ",", "0.8816321711879552`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.73423319676586`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008966037540757144`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.028902406669837`", ",", 
               RowBox[{"-", "3.1251692495618935`"}]}], "}"}], ",", 
             RowBox[{"-", "70.9661369221049`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00880072066566727`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.058316122578409`", ",", 
               RowBox[{"-", "3.2104291544489056`"}]}], "}"}], ",", 
             RowBox[{"-", "63.45777260664327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29350266029161254`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7427671292921243`", ",", "3.096120721976002`"}], 
              "}"}], ",", "179.62896996875946`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2923722035278479`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6491189382290914`", ",", "3.096727167638321`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.52222857579645`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.3034156724691288`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.622847132670974`", ",", "3.201489704433622`"}], 
              "}"}], ",", "123.54171695274425`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2991297679476463`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.548730151265034`", ",", "3.313291298098303`"}], 
              "}"}], ",", "121.2987066380636`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2074938795782712`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.643384671488563`", ",", "3.3597983825061997`"}], 
              "}"}], ",", "67.45446393672898`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17507661322311674`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.651399080236819`", ",", "3.37910346651708`"}], "}"}],
              ",", "82.52672760686615`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02735263909927003`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6715545154570086`", ",", "3.532753025731774`"}], 
              "}"}], ",", "138.73773604088652`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03303145034375969`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7862216760573277`", ",", "3.4310796435752473`"}], 
              "}"}], ",", "11.36721092071368`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032903138430371154`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.881455294618198`", ",", "3.4502254001223314`"}], 
              "}"}], ",", "14.246231216580236`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2332199913071227`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.111585282110616`", ",", "3.472367027206931`"}], 
              "}"}], ",", "28.91457892830718`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21124556975227035`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.264634592188302`", ",", "3.5569056035555873`"}], 
              "}"}], ",", "41.90992721173995`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019903950666125318`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.377435097169095`", ",", "3.658150991890274`"}], 
              "}"}], ",", "102.00902072714804`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01204466681521663`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.1176548356263805`", ",", "2.335555256105638`"}], 
              "}"}], ",", 
             RowBox[{"-", "60.9383772067069`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011983669133454427`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.144325840184996`", ",", "2.2875612976895767`"}], 
              "}"}], ",", 
             RowBox[{"-", "57.18769029722968`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16224915365310683`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.374197998047203`", ",", "2.8252555391612586`"}], 
              "}"}], ",", "10.133890216808835`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1604729420220983`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.406564721915494`", ",", "2.8310406851140684`"}], 
              "}"}], ",", "16.131065015829854`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09790774118840805`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.9726659601126935`", ",", "1.3721407739913314`"}], 
              "}"}], ",", 
             RowBox[{"-", "53.29687445122056`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09633888958622767`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.051377142344828`", ",", "1.2665536430853388`"}], 
              "}"}], ",", 
             RowBox[{"-", "46.20141323327297`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.050687083202645936`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.095108047103927`", ",", "1.6972718055676446`"}], 
              "}"}], ",", 
             RowBox[{"-", "73.81227696442964`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.049494744637069245`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.117654458232004`", ",", "1.619604436013454`"}], 
              "}"}], ",", 
             RowBox[{"-", "82.05273130349639`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.034598187714824896`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.122848840957539`", ",", "1.7180552732101344`"}], 
              "}"}], ",", 
             RowBox[{"-", "122.50037242300289`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.034505898670755424`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.06868495637522`", ",", "1.6330362242929266`"}], 
              "}"}], ",", 
             RowBox[{"-", "121.35652674575891`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02305153619749623`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4661872280868278`", ",", "3.180921472328808`"}], 
              "}"}], ",", "164.4333376850379`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022989948179846304`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.397482177038022`", ",", "3.200061181694977`"}], 
              "}"}], ",", "163.27766487564935`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08156709726881975`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.072694552474338`", ",", "0.27587203506025676`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.21106977289335`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08126037382539143`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9111937313212852`", ",", "0.21776340620799062`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.9737304231867`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03730121138932358`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.47360863487234`", ",", "1.8249231390726355`"}], 
              "}"}], ",", "165.4786947626636`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.036816131696574134`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.428650990937275`", ",", "1.8365678135129835`"}], 
              "}"}], ",", "158.98825389637892`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08978618567116699`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.667818548636428`", ",", "1.2196932435683943`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.69673248807257`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08868550331442777`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.392784632189184`", ",", "1.1893133403696`"}], "}"}], 
             ",", 
             RowBox[{"-", "167.37583562271107`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02068488982680287`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.605132568154086`", ",", "0.3230387054496063`"}], 
              "}"}], ",", 
             RowBox[{"-", "153.7964566448894`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020585614942961496`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.461195578242246`", ",", "0.2522018687756769`"}], 
              "}"}], ",", 
             RowBox[{"-", "150.2139769517848`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008187095866582905`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.055440525207455`", ",", 
               RowBox[{"-", "2.0856520759379458`"}]}], "}"}], ",", 
             RowBox[{"-", "93.57535301148462`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00816679943348881`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.035374206978884`", ",", 
               RowBox[{"-", "2.406801521780479`"}]}], "}"}], ",", 
             RowBox[{"-", "93.88311036071906`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14995920778927538`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8155000203866543`", ",", "1.49926532461838`"}], 
              "}"}], ",", "162.73644215556686`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14900047646286538`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6393669072293284`", ",", "1.554001809947269`"}], 
              "}"}], ",", "167.18837728074797`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0082917097970114`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.205090409605016`", ",", 
               RowBox[{"-", "0.5352505042925035`"}]}], "}"}], ",", 
             "155.5837601749622`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00827119083604342`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1486604500619717`", ",", 
               RowBox[{"-", "0.509633451286922`"}]}], "}"}], ",", 
             "155.83980878664227`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15890164002061336`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7646409666322525`", ",", 
               RowBox[{"-", "2.3652591978116506`"}]}], "}"}], ",", 
             RowBox[{"-", "127.86613598807375`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1574414362572255`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.687346924834199`", ",", 
               RowBox[{"-", "2.4646689242798066`"}]}], "}"}], ",", 
             RowBox[{"-", "133.3639434397474`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008263068083729345`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9147952493490976`", ",", 
               RowBox[{"-", "3.3708372984770985`"}]}], "}"}], ",", 
             RowBox[{"-", "96.90981163664205`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.041857970832639396`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2063272730200887`", ",", "2.8948686695957933`"}], 
              "}"}], ",", "108.60184993882595`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04155156283495627`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1824858594920125`", ",", "2.9657044306250255`"}], 
              "}"}], ",", "113.44782628189209`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04811946526786577`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.044827874469686`", ",", "2.678623059659469`"}], 
              "}"}], ",", "125.43149748335767`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.047731239538056386`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9333640797218736`", ",", "2.8352853936772213`"}], 
              "}"}], ",", "120.30573646441692`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012495993248684466`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.918979408019427`", ",", "0.4432405576931465`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.2526158772133`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012329205797224829`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5876291796852042`", ",", "0.4157227093399586`"}], 
              "}"}], ",", "178.18201879863275`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18425249168486746`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.630191771136144`", ",", "3.308284194420784`"}], 
              "}"}], ",", "142.12100567201878`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18029339692309035`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.528763188868726`", ",", "3.3871844873446237`"}], 
              "}"}], ",", "134.15519974689136`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03214032904047513`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.583154901338565`", ",", "0.8752202076403494`"}], 
              "}"}], ",", 
             RowBox[{"-", "51.93428737679964`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031997405606215196`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.630096466793213`", ",", "0.8152795720390332`"}], 
              "}"}], ",", 
             RowBox[{"-", "48.59682748804748`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01266542796386836`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.915310280175682`", ",", "0.8725376930146247`"}], 
              "}"}], ",", 
             RowBox[{"-", "70.52990828680754`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012624684158436088`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.006439621925628`", ",", "0.6147688300325258`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.67993120093384`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018713392176377876`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.405927012198225`", ",", "2.3787519570622178`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.52306655323287`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018499332020293288`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.334621434201527`", ",", "2.3706567906970477`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.4004152287048`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07740527430003738`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.8855943003165185`", ",", "3.2448708046005024`"}], 
              "}"}], ",", "7.965707484809215`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07716041610470682`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.080559990141701`", ",", "3.272152460207569`"}], 
              "}"}], ",", "5.889072142481674`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010894700652459226`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.686899135231831`", ",", "3.1787974319452377`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.99109946841025`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010866584956333542`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.59454673071253`", ",", "3.0984915207788184`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.12230510174277`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010539695268388717`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.146594245946951`", ",", "3.101302362746748`"}], 
              "}"}], ",", 
             RowBox[{"-", "57.81582740656453`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010363912059326562`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.277212258579763`", ",", "2.893757354530947`"}], 
              "}"}], ",", 
             RowBox[{"-", "65.02847750525787`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07415380171335308`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.083933215616448`", ",", "3.682061863205232`"}], 
              "}"}], ",", "152.08564172187715`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07389998680337813`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.955770445167616`", ",", "3.749961683916154`"}], 
              "}"}], ",", "154.49201745823729`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013164105739109632`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.341081509098933`", ",", "1.9555372819863597`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.33665463148859`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013037210331737627`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.344366407822268`", ",", "1.8424170849010477`"}], 
              "}"}], ",", 
             RowBox[{"-", "82.70244492501301`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0109082292690101`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.933471172038791`", ",", "2.0451250526433418`"}], 
              "}"}], ",", 
             RowBox[{"-", "166.49088691001043`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010880347429740273`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.698023718464621`", ",", "1.9885595114614365`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.2628545986558`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03211787229650239`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.372429286979578`", ",", "2.9644152224685603`"}], 
              "}"}], ",", "157.72571335536134`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03202407014881213`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9123037629453368`", ",", "3.1528852667350202`"}], 
              "}"}], ",", "156.03054610031572`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012393827991384323`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.110370663361457`", ",", 
               RowBox[{"-", "0.32787980772381814`"}]}], "}"}], ",", 
             RowBox[{"-", "139.66082374253807`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012358861385522885`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.064677983430684`", ",", 
               RowBox[{"-", "0.3666837619941653`"}]}], "}"}], ",", 
             RowBox[{"-", "138.15479596955356`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.080913157032625`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.379458000813778`", ",", "1.6251160758509406`"}], 
              "}"}], ",", "163.5873446037096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07930040003714685`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.326056895709007`", ",", "1.6408456934842706`"}], 
              "}"}], ",", "155.84714374307492`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008416790693823655`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.608146945359943`", ",", "3.6724081726290074`"}], 
              "}"}], ",", "72.8625048681824`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008736937931124794`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.360907336975386`", ",", "3.524693212670782`"}], 
              "}"}], ",", "115.48689296661014`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008713682529030067`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.304799005122269`", ",", "3.6423960631976082`"}], 
              "}"}], ",", "116.61480075975769`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2177813478003957`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.577113124496869`", ",", "2.7190939695865692`"}], 
              "}"}], ",", "152.69001777084645`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.20907787479473`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3044227199070897`", ",", "2.8599001531862447`"}], 
              "}"}], ",", "162.61203669613775`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008355645043696427`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1626895965014343`", ",", "2.9042839244054353`"}], 
              "}"}], ",", 
             RowBox[{"-", "127.93271589045659`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012654182590593201`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9275913020691573`", ",", "0.8424886120484518`"}], 
              "}"}], ",", 
             RowBox[{"-", "112.19452038854735`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012567539497110194`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.906504493089363`", ",", "0.790802834633577`"}], 
              "}"}], ",", 
             RowBox[{"-", "116.84683317856948`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008103684190499815`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9713169457996758`", ",", "0.8222603747779084`"}], 
              "}"}], ",", 
             RowBox[{"-", "124.3371991894034`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008036156829238536`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9206628938257806`", ",", "0.7481077742418967`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.55551702543892`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011917883271790598`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3865127223489795`", ",", 
               RowBox[{"-", "3.5668852488817966`"}]}], "}"}], ",", 
             RowBox[{"-", "154.88233457401367`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011881426859347045`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3275229689816683`", ",", 
               RowBox[{"-", "3.594540250413836`"}]}], "}"}], ",", 
             RowBox[{"-", "152.9585609402958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011531378926044368`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.166293012942752`", ",", "3.0086036193514536`"}], 
              "}"}], ",", "3.2303269218954673`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01148464108005055`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.375858465854501`", ",", "3.0204314211510552`"}], 
              "}"}], ",", "0.20320098900830982`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008091794898757283`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.294542797162495`", ",", 
               RowBox[{"-", "1.712435348389325`"}]}], "}"}], ",", 
             RowBox[{"-", "6.860591397738048`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008071171132543742`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.574341747354627`", ",", 
               RowBox[{"-", "1.7460994912691292`"}]}], "}"}], ",", 
             RowBox[{"-", "6.119885940723795`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010116419670241383`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2762663904675184`", ",", "3.0759686155040873`"}], 
              "}"}], ",", 
             RowBox[{"-", "148.38636660825986`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010085525454068142`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.155549579335169`", ",", "3.0016635362683948`"}], 
              "}"}], ",", 
             RowBox[{"-", "150.30229068446988`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009574851113911351`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1829895557969965`", ",", "3.368145414678848`"}], 
              "}"}], ",", "61.495515559858354`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009338512798426355`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3023266289224917`", ",", "3.587895943765453`"}], 
              "}"}], ",", "69.88328594058919`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008425936901320234`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.874329786784559`", ",", "3.224916746452884`"}], 
              "}"}], ",", "31.940301611390545`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008163537134455279`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.066713849244671`", ",", "3.3448531121491145`"}], 
              "}"}], ",", "22.826724964043013`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01895526476221411`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.38258625282617`", ",", 
               RowBox[{"-", "0.8872404335930295`"}]}], "}"}], ",", 
             RowBox[{"-", "167.03073539167602`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018906009797879823`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1419537588121385`", ",", 
               RowBox[{"-", "0.9426588754758249`"}]}], "}"}], ",", 
             RowBox[{"-", "166.09844899759347`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01987348137823251`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.930327422316176`", ",", 
               RowBox[{"-", "1.9106077982607501`"}]}], "}"}], ",", 
             RowBox[{"-", "170.92686914612918`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019823295162250266`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.66751611441676`", ",", 
               RowBox[{"-", "1.9525769503209212`"}]}], "}"}], ",", 
             RowBox[{"-", "171.55661238182992`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03869803427452041`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.069476274145186`", ",", 
               RowBox[{"-", "3.3210102154751135`"}]}], "}"}], ",", 
             RowBox[{"-", "107.32706371273771`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03860062655474068`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.05875444315332`", ",", 
               RowBox[{"-", "3.3553768685733916`"}]}], "}"}], ",", 
             RowBox[{"-", "106.74101092241992`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015338657633684406`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.6658613148600745`", ",", 
               RowBox[{"-", "2.290693316004209`"}]}], "}"}], ",", 
             RowBox[{"-", "179.70308332923526`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014280252355921732`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.603155983884158`", ",", 
               RowBox[{"-", "2.2910182688181258`"}]}], "}"}], ",", 
             RowBox[{"-", "167.88283120211557`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013438347927123846`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.905259287943307`", ",", 
               RowBox[{"-", "0.9688719174246986`"}]}], "}"}], ",", 
             "88.05683118636152`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013402351513102574`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.915357255053708`", ",", 
               RowBox[{"-", "0.671240002641347`"}]}], "}"}], ",", 
             "86.8825011336664`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013103281701318744`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.960741327726372`", ",", "0.18163303324655294`"}], 
              "}"}], ",", "135.98067324166195`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013047235194754725`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.66440582370264`", ",", "0.4679941414438552`"}], 
              "}"}], ",", "139.1899118729836`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01811598901200094`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.844581130049851`", ",", 
               RowBox[{"-", "0.5661312995344663`"}]}], "}"}], ",", 
             "148.0593229390688`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017769936436893032`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.675606847818308`", ",", 
               RowBox[{"-", "0.4607875571318453`"}]}], "}"}], ",", 
             "155.6727123103927`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09156850539345801`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8796782695141685`", ",", 
               RowBox[{"-", "3.08245491405061`"}]}], "}"}], ",", 
             RowBox[{"-", "122.21964779564568`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09134272639066464`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8505075852022514`", ",", 
               RowBox[{"-", "3.1287419660385773`"}]}], "}"}], ",", 
             RowBox[{"-", "122.13774477075529`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010472798878679407`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1309275385333617`", ",", "0.13802487590127688`"}], 
              "}"}], ",", "163.42919960077793`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010446684103274234`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9088502337360813`", ",", "0.20410577926362702`"}], 
              "}"}], ",", "163.86482537864327`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0080922700056281`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.891693862377186`", ",", "3.3137983546813343`"}], 
              "}"}], ",", "78.72395389269977`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008071051389010852`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.900480009785586`", ",", "3.357864598318122`"}], 
              "}"}], ",", "77.71395303779198`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037864145283075586`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.182742657092213`", ",", 
               RowBox[{"-", "2.311972613455932`"}]}], "}"}], ",", 
             RowBox[{"-", "119.05034309566432`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03768178656136339`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.129136823338847`", ",", 
               RowBox[{"-", "2.408480019606195`"}]}], "}"}], ",", 
             RowBox[{"-", "122.64382367246702`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015574130924479852`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.875281126091442`", ",", 
               RowBox[{"-", "4.37143559027782`"}]}], "}"}], ",", 
             RowBox[{"-", "73.29916856460855`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015526499000413602`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.883357522681043`", ",", 
               RowBox[{"-", "4.39835420285686`"}]}], "}"}], ",", 
             RowBox[{"-", "71.37626587180178`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011530870194514922`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.897226245942283`", ",", 
               RowBox[{"-", "2.319820684585405`"}]}], "}"}], ",", 
             RowBox[{"-", "35.266249311568195`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011484988558032566`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.91112926995619`", ",", 
               RowBox[{"-", "2.329652284028459`"}]}], "}"}], ",", 
             RowBox[{"-", "38.229587325408524`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12167549458642282`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.150433843677726`", ",", 
               RowBox[{"-", "3.3987902081105528`"}]}], "}"}], ",", 
             RowBox[{"-", "112.98957239066699`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12124974700989788`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.147521702715067`", ",", 
               RowBox[{"-", "3.405654255286705`"}]}], "}"}], ",", 
             RowBox[{"-", "115.48239228470185`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03628476891038316`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.850770231733905`", ",", "3.0919020319561095`"}], 
              "}"}], ",", "92.57245423187184`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03596607957172944`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.84782261656146`", ",", "3.157509579376103`"}], "}"}],
              ",", "97.94116129624298`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013925524252307543`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.200021876269678`", ",", 
               RowBox[{"-", "0.9119070393901738`"}]}], "}"}], ",", 
             "178.43559270721485`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013841783394522045`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.136410550081083`", ",", 
               RowBox[{"-", "0.9101697603019961`"}]}], "}"}], ",", 
             RowBox[{"-", "177.29330222306427`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02586997819043141`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.838998481869474`", ",", 
               RowBox[{"-", "2.3971098311794203`"}]}], "}"}], ",", 
             RowBox[{"-", "128.13354167835823`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024862725998632637`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.66306013011406`", ",", 
               RowBox[{"-", "2.6212220089192915`"}]}], "}"}], ",", 
             RowBox[{"-", "118.29763821511378`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21005105212109818`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.860468037503002`", ",", 
               RowBox[{"-", "2.5452454429729006`"}]}], "}"}], ",", 
             RowBox[{"-", "68.5327487789683`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20947303678310183`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.964529303640744`", ",", 
               RowBox[{"-", "2.809863803943051`"}]}], "}"}], ",", 
             RowBox[{"-", "69.88840967141066`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020963832933877245`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.999102128718822`", ",", 
               RowBox[{"-", "2.6016873604925377`"}]}], "}"}], ",", 
             RowBox[{"-", "8.931955879578291`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0195717957129455`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.261874385091049`", ",", 
               RowBox[{"-", "2.6429865621305675`"}]}], "}"}], ",", 
             RowBox[{"-", "20.612251546112397`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02442742087152347`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.185536517567847`", ",", 
               RowBox[{"-", "1.4233285737793353`"}]}], "}"}], ",", 
             RowBox[{"-", "100.24154531042474`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024005506395813808`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.136704245799847`", ",", 
               RowBox[{"-", "1.693602331480489`"}]}], "}"}], ",", 
             RowBox[{"-", "92.92608232129359`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008590964470150397`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.589911053871509`", ",", "1.723989415994277`"}], 
              "}"}], ",", "125.03398961823677`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008569745768531502`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.333991827929522`", ",", "2.0890188684700233`"}], 
              "}"}], ",", "124.84866217798358`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1713232157301778`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.940248911892806`", ",", 
               RowBox[{"-", "0.1320508901896091`"}]}], "}"}], ",", 
             RowBox[{"-", "141.79381431034494`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17088743869980935`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.863056968970465`", ",", 
               RowBox[{"-", "0.19280845491380338`"}]}], "}"}], ",", 
             RowBox[{"-", "141.07588361490355`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010370618390002365`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.401924794015256`", ",", 
               RowBox[{"-", "0.6117164683421243`"}]}], "}"}], ",", 
             RowBox[{"-", "71.05382049368214`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010344701171262202`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.478801711368002`", ",", 
               RowBox[{"-", "0.8356664099524582`"}]}], "}"}], ",", 
             RowBox[{"-", "70.5785666700482`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00892953541237966`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.359469019374845`", ",", "3.1712319685556047`"}], 
              "}"}], ",", "47.24927257301712`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008879945190229206`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.505099127366551`", ",", "3.3287697191965226`"}], 
              "}"}], ",", "51.282120459066114`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03430451607983149`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.367555068531391`", ",", "3.3293246155986482`"}], 
              "}"}], ",", "102.6805536064522`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03421890285377395`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.31726555061554`", ",", "3.552830485456761`"}], "}"}],
              ",", "102.2294160341504`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2447679079071583`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.351578364845772`", ",", "3.0615498507624155`"}], 
              "}"}], ",", "150.802009834144`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.236378070327634`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.332726271625041`", ",", "3.072085061703826`"}], 
              "}"}], ",", "146.19552392913295`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00833328938755617`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.111084384355568`", ",", "3.220486449041145`"}], 
              "}"}], ",", "39.6152363247523`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03725361151875023`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.149841575224362`", ",", "2.298041295074627`"}], 
              "}"}], ",", 
             RowBox[{"-", "163.70492063780182`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0371432684417718`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.823748620050392`", ",", "2.202715441043321`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.47211360299883`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2411870689008152`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.556008619207015`", ",", "2.7669057467627027`"}], 
              "}"}], ",", "155.74901282631888`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2002580428142613`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.455720919383612`", ",", "2.812084139995091`"}], 
              "}"}], ",", "140.31512247918386`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033983441549087716`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.337832227099149`", ",", "2.9099046679207174`"}], 
              "}"}], ",", "84.63868139429606`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2558717053918702`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.241317660936481`", ",", "0.0593787069427702`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.49218488179176`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2552285554710081`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.24463024279155`", ",", 
               RowBox[{"-", "0.06646771856770184`"}]}], "}"}], ",", 
             RowBox[{"-", "87.92626176978506`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07325627753703859`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.534634195919815`", ",", 
               RowBox[{"-", "0.19247479425545638`"}]}], "}"}], ",", 
             RowBox[{"-", "135.1345264377602`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06969638555442212`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.38369793090081`", ",", 
               RowBox[{"-", "0.3427039428852845`"}]}], "}"}], ",", 
             RowBox[{"-", "145.71453033249566`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023768501368344793`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.918235140502793`", ",", 
               RowBox[{"-", "0.6120523874165424`"}]}], "}"}], ",", 
             RowBox[{"-", "115.81612353404607`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02368978988878191`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8745919970061`", ",", 
               RowBox[{"-", "0.7022677679808029`"}]}], "}"}], ",", 
             RowBox[{"-", "118.08859080618777`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18613693812303794`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.603390235694879`", ",", 
               RowBox[{"-", "1.6110348748944543`"}]}], "}"}], ",", 
             RowBox[{"-", "99.439912334567`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18547431890347077`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.564839912479123`", ",", 
               RowBox[{"-", "1.8428960138801187`"}]}], "}"}], ",", 
             RowBox[{"-", "101.99895661686973`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009781655595059446`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.701971665894905`", ",", "1.8586035155755987`"}], 
              "}"}], ",", "115.20549133117872`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009724803632390321`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.681822241294973`", ",", "1.9014125722190873`"}], 
              "}"}], ",", "119.37511804165635`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032218497982814835`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.257659461780888`", ",", "0.9100120270629408`"}], 
              "}"}], ",", "164.87059500694778`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03210303400659668`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1537787624621005`", ",", "0.9380983931909275`"}], 
              "}"}], ",", "162.28610436070255`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2512827826224551`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.117167632438771`", ",", "0.8261175470069844`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.80612650851063`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2491558155402798`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.998399544867169`", ",", "0.7106453352719848`"}], 
              "}"}], ",", 
             RowBox[{"-", "130.5430080330151`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0259155955094754`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.117643865374875`", ",", "0.662483775743396`"}], 
              "}"}], ",", 
             RowBox[{"-", "76.48284802396901`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025230996322651453`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.118875553318521`", ",", "0.6573601836489971`"}], 
              "}"}], ",", 
             RowBox[{"-", "85.08002229939916`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009260107395248438`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.751781410101081`", ",", "0.14079931650843222`"}], 
              "}"}], ",", 
             RowBox[{"-", "105.1972129026048`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009226806826398662`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.6926775436207055`", ",", 
               RowBox[{"-", "0.07678088209334447`"}]}], "}"}], ",", 
             RowBox[{"-", "102.59971734911835`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012824582894858435`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.109795497765404`", ",", "1.1420644005632679`"}], 
              "}"}], ",", "126.62497194963441`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.012728163364922`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.967594342453163`", ",", "1.3333641745595262`"}], 
              "}"}], ",", "121.70195249085492`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.255102435418361`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9148613770099985`", ",", "1.1285672376053026`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.6627464481836`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2526513120101845`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.906428365600408`", ",", "1.1264118496109896`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.2877375107902`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011677359921056776`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.853419889646802`", ",", "0.9430775385026428`"}], 
              "}"}], ",", 
             RowBox[{"-", "97.95046484600131`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011639207662630451`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.841861157799778`", ",", "0.8603137646950654`"}], 
              "}"}], ",", 
             RowBox[{"-", "100.16657528783458`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00874571024161575`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3474023378701885`", ",", "0.90487389886163`"}], 
              "}"}], ",", "125.0491390277821`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008697978940488392`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2410664177084985`", ",", "1.0564604651676346`"}], 
              "}"}], ",", "121.06899721173266`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008216267132293393`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1829116023236583`", ",", "0.7363522884607112`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.66175504323338`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008195810767901284`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.190827813661015`", ",", "0.39748830483989306`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.25602048549912`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008638451922939694`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.152935114196686`", ",", 
               RowBox[{"-", "3.3998557454180136`"}]}], "}"}], ",", 
             RowBox[{"-", "55.949408291181555`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008493593975680641`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.343013019922998`", ",", 
               RowBox[{"-", "3.681121789661831`"}]}], "}"}], ",", 
             RowBox[{"-", "63.177981382391444`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2912461008387395`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.350901074353575`", ",", "3.083822610252523`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.67342712035247`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.29051786504563903`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.199044104206012`", ",", "3.069664227035078`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.18922763534425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.294857956380511`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3885589709624035`", ",", "3.5767400067352`"}], "}"}],
              ",", "119.05569632338279`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2904129674601188`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3350883661874784`", ",", "3.6729827736237035`"}], 
              "}"}], ",", "121.4736246735672`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03241726635515453`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.651399080236819`", ",", "3.37910346651708`"}], "}"}],
              ",", "41.38798284298281`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03215893897230612`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.847707350386743`", ",", "3.5520993251997077`"}], 
              "}"}], ",", "36.29767904850843`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14772397412384664`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6715545154570086`", ",", "3.532753025731774`"}], 
              "}"}], ",", "97.59899127700305`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11735526001872232`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6447050878359932`", ",", "3.7340071536615724`"}], 
              "}"}], ",", "81.30019652806459`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024125592080625955`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.666413661944249`", ",", "3.8758765752816933`"}], 
              "}"}], ",", "26.76020018622506`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023079270704020948`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5550668598930115`", ",", "3.63495407620088`"}], 
              "}"}], ",", "153.80999971102344`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023016772023067712`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3616401828882223`", ",", "3.7300898723231537`"}], 
              "}"}], ",", "155.06058614511164`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0327753249494446`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.139812661650813`", ",", "3.5158217226159985`"}], 
              "}"}], ",", "17.12525151244704`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032548757325003466`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.409143393975804`", ",", "3.598808626479347`"}], 
              "}"}], ",", "12.44515005391116`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02197442155485222`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.264634592188302`", ",", "3.5569056035555873`"}], 
              "}"}], ",", 
             RowBox[{"-", "5.193818020235503`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02191839661334862`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.323640786141722`", ",", "3.551542038427968`"}], 
              "}"}], ",", 
             RowBox[{"-", "5.93812656407877`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011922980361622036`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.29350856581124`", ",", "2.0561842066253853`"}], 
              "}"}], ",", 
             RowBox[{"-", "53.43700338775256`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011570571696116201`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.360070698942792`", ",", "1.9664371853324578`"}], 
              "}"}], ",", 
             RowBox[{"-", "44.48869998165202`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15871617534773266`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.635004169707646`", ",", "2.8971105400953423`"}], 
              "}"}], ",", "22.12823981485094`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15778811140663979`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.903575285557843`", ",", "3.006320190988968`"}], 
              "}"}], ",", "17.940562856934797`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0947951769089147`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.1972652318558445`", ",", "1.114415438426117`"}], 
              "}"}], ",", 
             RowBox[{"-", "39.105952015325336`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09426843411389882`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.294695493609805`", ",", "1.0352192052585532`"}], 
              "}"}], ",", 
             RowBox[{"-", "35.07139850437076`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.048330454070413295`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.14685598326838`", ",", "1.4104281174482072`"}], 
              "}"}], ",", 
             RowBox[{"-", "90.29318564256303`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.048117425433559805`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.146718110808978`", ",", "1.3834846388450577`"}], 
              "}"}], ",", 
             RowBox[{"-", "86.98463734846231`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03441385580338529`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9166370419365357`", ",", "1.3835162247723365`"}], 
              "}"}], ",", 
             RowBox[{"-", "120.21268106851431`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.034301104467841105`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9159720498642523`", ",", "1.3823742354471145`"}], 
              "}"}], ",", 
             RowBox[{"-", "122.44053915627715`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022928524710185104`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1006670786341908`", ",", "3.289236112860523`"}], 
              "}"}], ",", "162.12199206626082`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022871896228055025`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.692734014232927`", ",", "3.4208220106492813`"}], 
              "}"}], ",", "162.3054871700115`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08095480377927528`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.602454551891017`", ",", "0.12321755953209025`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.73639107348035`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08052361116729567`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5955754033611145`", ",", "0.1214687389375463`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.8304227583107`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03633736017183194`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.237518902676637`", ",", "1.909981509090571`"}], 
              "}"}], ",", "152.49781303009425`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03623889957405221`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.19964115086494`", ",", "1.929701256250354`"}], "}"}],
              ",", "151.24315719586932`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08759831414309759`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2213753721831653`", ",", "1.1509229207014182`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.0549387573496`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08718679004135797`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1376643673154043`", ",", "1.1221886645158219`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.56953367281426`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020486816518151044`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.226784094955743`", ",", "0.11802907473082361`"}], 
              "}"}], ",", 
             RowBox[{"-", "146.63149725868016`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020431511625259153`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.177832688135187`", ",", "0.08579016512972962`"}], 
              "}"}], ",", 
             RowBox[{"-", "145.40236432820674`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008146553316795431`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.017758252410186`", ",", 
               RowBox[{"-", "2.666329052544557`"}]}], "}"}], ",", 
             RowBox[{"-", "94.19086770995585`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00812636191240054`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.006534413084269`", ",", 
               RowBox[{"-", "2.8195029085434435`"}]}], "}"}], ",", 
             RowBox[{"-", "93.88908526421808`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1480478745750526`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3678358241441186`", ",", "1.6157500856389455`"}], 
              "}"}], ",", "171.640312405929`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.146813265913905`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1502410153074516`", ",", "1.6477252730810639`"}], 
              "}"}], ",", "176.860804026782`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15599465082627487`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5207053132081034`", ",", 
               RowBox[{"-", "2.6411097727657418`"}]}], "}"}], ",", 
             RowBox[{"-", "138.86175089142105`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1545458112842911`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.42761242653415`", ",", 
               RowBox[{"-", "2.722429377510061`"}]}], "}"}], ",", 
             RowBox[{"-", "144.3899428436172`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.041247397799824295`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0835451215110132`", ",", "3.193820375821446`"}], 
              "}"}], ",", "118.2938026249583`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04102605515943896`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.980971346924826`", ",", "3.384369921390081`"}], 
              "}"}], ",", "114.36506729150055`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04734614599636355`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.830651011562688`", ",", "3.011017350880267`"}], 
              "}"}], ",", "115.17997544547623`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.047194885599491566`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.792604485067973`", ",", "3.091943737459184`"}], 
              "}"}], ",", "113.05989985448504`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01216464450365523`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.363445515092777`", ",", "0.42283839082818514`"}], 
              "}"}], ",", "171.61665347447885`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012134089490406542`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1629977363500927`", ",", "0.45237841394074313`"}], 
              "}"}], ",", "172.17225592368717`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17641937255134932`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.395953481947561`", ",", "3.52396953458935`"}], "}"}],
              ",", "126.18939382176393`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17597462123819133`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.330377895951577`", ",", "3.613602019872441`"}], 
              "}"}], ",", "126.79654024808698`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03185511773197192`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.825791340319894`", ",", "0.5933320850040109`"}], 
              "}"}], ",", 
             RowBox[{"-", "45.25936759929522`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03173083555516049`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.8593814876447174`", ",", "0.5594364396521986`"}], 
              "}"}], ",", 
             RowBox[{"-", "42.364970532193446`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012584071423006818`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.096466395184083`", ",", "0.3260823219419739`"}], 
              "}"}], ",", 
             RowBox[{"-", "74.82995411505976`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012510582246910786`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.110169719282886`", ",", "0.2755412943464901`"}], 
              "}"}], ",", 
             RowBox[{"-", "70.64609016910634`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01828772047160128`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.098600632748835`", ",", "2.3179016869850884`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.2777639041767`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018225971422683965`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.888769269933546`", ",", "2.2467869132101863`"}], 
              "}"}], ",", 
             RowBox[{"-", "163.629608445628`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01083854181771943`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.352822588729898`", ",", "2.881774653529568`"}], 
              "}"}], ",", 
             RowBox[{"-", "137.25351073507534`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010811178194709677`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.348498540963568`", ",", "2.8777780362125003`"}], 
              "}"}], ",", 
             RowBox[{"-", "137.88001091060835`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010191060598839815`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.35450132886719`", ",", "2.727795098489933`"}], "}"}],
              ",", 
             RowBox[{"-", "72.24112760395106`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010165094290472217`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.381310718910736`", ",", "2.6440872337303665`"}], 
              "}"}], ",", 
             RowBox[{"-", "71.50382163092304`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012911538132742338`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.372508919400013`", ",", "1.6226560092947893`"}], 
              "}"}], ",", 
             RowBox[{"-", "77.06823521853735`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01283864572793367`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.372752225477329`", ",", "1.6215963790450416`"}], 
              "}"}], ",", 
             RowBox[{"-", "81.15063884332731`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010852536857487473`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.385537894137745`", ",", "1.917924882028194`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.0348222873016`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010605829287655058`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.339896425545627`", ",", "1.9082524771412326`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.89847829197697`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03193054195584809`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.613683131266335`", ",", "3.285649020901551`"}], 
              "}"}], ",", "154.33537884526947`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03152819925925279`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.553902918326969`", ",", "3.314373845341771`"}], 
              "}"}], ",", "147.93560579851973`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012323993430661468`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8437336950449588`", ",", 
               RowBox[{"-", "0.5645446446200453`"}]}], "}"}], ",", 
             RowBox[{"-", "136.64876819656857`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01226749733389535`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.823958396045145`", ",", 
               RowBox[{"-", "0.5832133566231358`"}]}], "}"}], ",", 
             RowBox[{"-", "133.21262609739745`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008703473005665709`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3044227199070897`", ",", "2.8599001531862447`"}], 
              "}"}], ",", "103.07880820802352`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008677599357854674`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2541150612332057`", ",", "3.0764472252778026`"}], 
              "}"}], ",", "101.2932884127373`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20072222975103354`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1626895965014343`", ",", "2.9042839244054353`"}], 
              "}"}], ",", "172.53405562142905`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20004600485478619`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1397724922646493`", ",", "2.907287161873985`"}], 
              "}"}], ",", "170.19128857903485`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008021717772985479`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0713890407219795`", ",", "2.787141251001066`"}], 
              "}"}], ",", 
             RowBox[{"-", "118.01069696516521`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012481489648239759`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7875435276326748`", ",", "0.5557776983030938`"}], 
              "}"}], ",", 
             RowBox[{"-", "121.49914596859168`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012391837481959015`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7013439460896578`", ",", "0.41510805924679106`"}], 
              "}"}], ",", 
             RowBox[{"-", "116.70793170287729`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011438092667277355`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.63197961151276`", ",", "3.0213397653388454`"}], 
              "}"}], ",", 
             RowBox[{"-", "2.823924943878605`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011407129365692659`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.843513348210977`", ",", "3.0109054965819593`"}], 
              "}"}], ",", 
             RowBox[{"-", "1.575769051719089`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008050599930654703`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.852640212802115`", ",", 
               RowBox[{"-", "1.7759387147053527`"}]}], "}"}], ",", 
             RowBox[{"-", "5.37918048370954`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00803028887204484`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.094971761813688`", ",", 
               RowBox[{"-", "1.7987569508849908`"}]}], "}"}], ",", 
             RowBox[{"-", "4.761748442208664`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019773235680795632`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.333169237688875`", ",", 
               RowBox[{"-", "2.0022077378949565`"}]}], "}"}], ",", 
             RowBox[{"-", "172.18635561753007`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019709822162423958`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.102642866096751`", ",", 
               RowBox[{"-", "2.0338418521312005`"}]}], "}"}], ",", 
             RowBox[{"-", "174.32306991113265`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03850346402219204`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.965978042793`", ",", 
               RowBox[{"-", "3.6638144368616565`"}]}], "}"}], ",", 
             RowBox[{"-", "106.15495813210212`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03802347580759137`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.904023761744716`", ",", 
               RowBox[{"-", "3.8776898950459926`"}]}], "}"}], ",", 
             RowBox[{"-", "99.78598301284478`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013294879657590014`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.426423131981197`", ",", 
               RowBox[{"-", "2.3289619051770183`"}]}], "}"}], ",", 
             RowBox[{"-", "156.06257907499597`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012590715941711086`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.399416597563361`", ",", 
               RowBox[{"-", "2.340950662209046`"}]}], "}"}], ",", 
             RowBox[{"-", "166.9397016642384`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013366451520295392`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.930958569340212`", ",", 
               RowBox[{"-", "0.3847901262935921`"}]}], "}"}], ",", 
             "85.70817108097096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013327488754502318`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.947664964619279`", ",", 
               RowBox[{"-", "0.16217757645068404`"}]}], "}"}], ",", 
             "84.02301268645304`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012991428415227772`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.427593108847438`", ",", "0.6724781669937853`"}], 
              "}"}], ",", "142.39915050430537`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012953072608805799`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.383963743079979`", ",", "0.7060783323082914`"}], 
              "}"}], ",", "144.15003007806868`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01743049417627911`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4805411901108987`", ",", 
               RowBox[{"-", "0.372600169719215`"}]}], "}"}], ",", 
             "163.2861016817165`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017385696064913338`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4060816265724547`", ",", 
               RowBox[{"-", "0.350241541182473`"}]}], "}"}], ",", 
             "162.45742704226296`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09111750408755619`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.676768144014921`", ",", 
               RowBox[{"-", "3.4053014779424857`"}]}], "}"}], ",", 
             RowBox[{"-", "122.05584174586937`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09006462351004987`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.657676669171288`", ",", 
               RowBox[{"-", "3.4357880667505545`"}]}], "}"}], ",", 
             RowBox[{"-", "128.20742827826183`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01042063444718457`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.568817617378096`", ",", "0.30247733245865827`"}], 
              "}"}], ",", "164.3004511565061`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010394789967959126`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1565119128098553`", ",", "0.41836773618834916`"}], 
              "}"}], ",", "163.98170362690266`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0375003061033261`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9681142684318607`", ",", 
               RowBox[{"-", "2.6598401862157806`"}]}], "}"}], ",", 
             RowBox[{"-", "126.23730424926984`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03716721373871164`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.919631614244007`", ",", 
               RowBox[{"-", "2.7259929176539672`"}]}], "}"}], ",", 
             RowBox[{"-", "131.63814365996114`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011439289485791308`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.12604817160651`", ",", 
               RowBox[{"-", "2.498956565176562`"}]}], "}"}], ",", 
             RowBox[{"-", "41.192925339249214`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011373621288093732`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.246993911727618`", ",", 
               RowBox[{"-", "2.6048101806406474`"}]}], "}"}], ",", 
             RowBox[{"-", "45.32548431364763`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12082548914171178`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.018810165197388`", ",", 
               RowBox[{"-", "3.6757171600667142`"}]}], "}"}], ",", 
             RowBox[{"-", "117.97521217873685`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11827831057451985`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9154365070604165`", ",", 
               RowBox[{"-", "3.8703378116629303`"}]}], "}"}], ",", 
             RowBox[{"-", "110.06685526104644`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035650189283410655`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.815550438724145`", ",", "3.3888616835434866`"}], 
              "}"}], ",", "103.30986836061413`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03555074778499699`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.770634920213825`", ",", "3.578721628612756`"}], 
              "}"}], ",", "101.87071914089658`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013758546110687195`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.872301017939595`", ",", 
               RowBox[{"-", "0.9226557924440155`"}]}], "}"}], ",", 
             RowBox[{"-", "173.02219715334343`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013724514919912245`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.710162616831017`", ",", 
               RowBox[{"-", "0.9425001262725878`"}]}], "}"}], ",", 
             RowBox[{"-", "173.26266865885623`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023894691349671197`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.575543885995159`", ",", 
               RowBox[{"-", "2.7837733642724407`"}]}], "}"}], ",", 
             RowBox[{"-", "108.46173475186939`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023835213525979424`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.541654341085413`", ",", 
               RowBox[{"-", "2.88528378636298`"}]}], "}"}], ",", 
             RowBox[{"-", "108.86280443165042`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2088966120190522`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.072749319436245`", ",", 
               RowBox[{"-", "3.105403635144691`"}]}], "}"}], ",", 
             RowBox[{"-", "71.24407056385301`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2079332617048073`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.08799960753779`", ",", 
               RowBox[{"-", "3.150314265218908`"}]}], "}"}], ",", 
             RowBox[{"-", "67.78877361342904`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018272192334172897`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.410905318833086`", ",", 
               RowBox[{"-", "2.699039979861575`"}]}], "}"}], ",", 
             RowBox[{"-", "32.29254721264639`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018087030809893354`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.588084346100509`", ",", 
               RowBox[{"-", "2.811015656833259`"}]}], "}"}], ",", 
             RowBox[{"-", "26.515818101145033`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023590879297095364`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1268187889837655`", ",", 
               RowBox[{"-", "1.8870016953381006`"}]}], "}"}], ",", 
             RowBox[{"-", "85.61061933216244`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023253661275712302`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.128881658595486`", ",", 
               RowBox[{"-", "1.9138761945120275`"}]}], "}"}], ",", 
             RowBox[{"-", "92.37396966124959`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008548579474683583`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.14175033611594`", ",", "2.3651174583367935`"}], 
              "}"}], ",", "124.66333473772447`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008526442329211152`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1076434555438315`", ",", "2.4144414593341925`"}], 
              "}"}], ",", "123.76224489302848`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17045277011011184`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.653980257328887`", ",", 
               RowBox[{"-", "0.3616574428833441`"}]}], "}"}], ",", 
             RowBox[{"-", "140.35795291946314`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16999037541435172`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.594967418142435`", ",", 
               RowBox[{"-", "0.41055009918854746`"}]}], "}"}], ",", 
             RowBox[{"-", "139.09551933436853`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010318848722259188`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.583398214968567`", ",", 
               RowBox[{"-", "1.132330017951795`"}]}], "}"}], ",", 
             RowBox[{"-", "70.10331284641198`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009908168301184886`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.618430132596749`", ",", 
               RowBox[{"-", "1.2291221078227457`"}]}], "}"}], ",", 
             RowBox[{"-", "60.19499439196128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0088306303676398`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.666072835015382`", ",", "3.5295693043040495`"}], 
              "}"}], ",", "55.3149683451151`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00880737111655251`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.709587383961219`", ",", "3.592447385020252`"}], 
              "}"}], ",", "56.361677673115295`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008389837579523699`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.332726271625041`", ",", "3.072085061703826`"}], 
              "}"}], ",", 
             RowBox[{"-", "111.83067437149744`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008369155533173411`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.27728416674348`", ",", "2.933684843818274`"}], "}"}],
              ",", 
             RowBox[{"-", "111.88605266849663`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2280447809400767`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.111084384355568`", ",", "3.220486449041145`"}], 
              "}"}], ",", "141.58903802412163`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.1907037301657544`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.954758455371051`", ",", "3.344437558261244`"}], 
              "}"}], ",", "132.55120245704782`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0362056246933072`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.848099970795353`", ",", "3.4606262406768167`"}], 
              "}"}], ",", "59.24316808297181`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008277122335031238`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.316562790117922`", ",", "3.3905650271201493`"}], 
              "}"}], ",", "35.00875041974084`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008256340871542143`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.356524519002311`", ",", "3.4185556272910147`"}], 
              "}"}], ",", "35.557995106435115`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03703325219470707`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.604405943891403`", ",", "2.1458756573122315`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.23930656819564`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03658015217719984`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.592964444774758`", ",", "2.143284465560271`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.92402367249736`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040929026086553834`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.455720919383612`", ",", "2.812084139995091`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.44232678306327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04082176782059912`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.377552899821237`", ",", "2.8113232883593313`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.43705402303573`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1662746012651736`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.337832227099149`", ",", "2.9099046679207174`"}], 
              "}"}], ",", "124.88123213204912`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.163970710004797`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.225713861223167`", ",", "3.070734819407332`"}], 
              "}"}], ",", "118.20797025898116`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028216510626910527`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.352145538186897`", ",", "3.0624226294134362`"}], 
              "}"}], ",", "69.20479104716135`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.027877254482644786`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.360730456802546`", ",", "3.0850282812256205`"}], 
              "}"}], ",", "75.47006284842753`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2545870221486679`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.256952250972121`", ",", 
               RowBox[{"-", "0.4067665791358533`"}]}], "}"}], ",", 
             RowBox[{"-", "87.36033865777772`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2539585588019182`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.26526151421365`", ",", 
               RowBox[{"-", "0.5869975905894367`"}]}], "}"}], ",", 
             RowBox[{"-", "87.20025136364882`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06630948667702445`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.245025077907684`", ",", 
               RowBox[{"-", "0.43724862593718694`"}]}], "}"}], ",", 
             RowBox[{"-", "156.29453422723105`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06592681237779134`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.117777238390528`", ",", 
               RowBox[{"-", "0.4931210008312532`"}]}], "}"}], ",", 
             RowBox[{"-", "160.44294440644333`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0236113390691958`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.746337843806928`", ",", 
               RowBox[{"-", "0.9425816125023615`"}]}], "}"}], ",", 
             RowBox[{"-", "120.36105807832993`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02325496386566611`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.480883233853334`", ",", 
               RowBox[{"-", "1.3957434313766623`"}]}], "}"}], ",", 
             RowBox[{"-", "113.43993501739988`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18481405850765223`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.508878933533153`", ",", 
               RowBox[{"-", "2.1061952972400784`"}]}], "}"}], ",", 
             RowBox[{"-", "104.55800089917248`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18397945415253414`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.435440312755351`", ",", 
               RowBox[{"-", "2.388980126571918`"}]}], "}"}], ",", 
             RowBox[{"-", "101.17038946310448`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00966828209902613`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.550720203660656`", ",", "2.1343176423314136`"}], 
              "}"}], ",", "123.54474475213415`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009492820494557604`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.428443316827227`", ",", "2.3187447737060687`"}], 
              "}"}], ",", "116.08330838352009`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03198798382775079`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.876393431753907`", ",", "1.0266974747121043`"}], 
              "}"}], ",", "159.701613714457`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031504984949511365`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6701262197708275`", ",", "1.1029914289804044`"}], 
              "}"}], ",", "166.62389079739543`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24704685203527538`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.834142400424299`", ",", "0.5186169949293943`"}], 
              "}"}], ",", 
             RowBox[{"-", "125.2798895575198`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24479880758501874`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.73333375410169`", ",", "0.37613382223822867`"}], 
              "}"}], ",", 
             RowBox[{"-", "119.81006742234952`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024564481846496396`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.13623424416586`", ",", "0.45570602404111304`"}], 
              "}"}], ",", 
             RowBox[{"-", "93.67719657482913`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024463118315835128`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.117262062815048`", ",", "0.16049933262649818`"}], 
              "}"}], ",", 
             RowBox[{"-", "96.7656148750636`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009193626010791307`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.627965300614364`", ",", 
               RowBox[{"-", "0.36629352393380893`"}]}], "}"}], ",", 
             RowBox[{"-", "100.00222179563161`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009145360169150624`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.616643151682505`", ",", 
               RowBox[{"-", "0.43049006424632213`"}]}], "}"}], ",", 
             RowBox[{"-", "103.86395308253414`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012632468749458765`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.825680949044306`", ",", "1.5631240269047626`"}], 
              "}"}], ",", "116.77893303207534`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012594372275134429`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7959855139893546`", ",", "1.6219647450608035`"}], 
              "}"}], ",", "114.92294939216094`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25022373994894936`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.648326616778112`", ",", "1.086860197629454`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.91272857339683`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24449284781285735`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5204903062092607`", ",", "1.0799653130267683`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.75369321146778`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01160118005522395`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.78724020649285`", ",", "0.5557238620463394`"}], 
              "}"}], ",", 
             RowBox[{"-", "102.38268572966818`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011572121172541583`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.756798215815996`", ",", "0.4170659713737852`"}], 
              "}"}], ",", 
             RowBox[{"-", "101.8696189840642`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00865050814160092`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0974595866669437`", ",", "1.2948117347041475`"}], 
              "}"}], ",", "117.08885539568314`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008628455971146688`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0631151281931768`", ",", "1.361958894730527`"}], 
              "}"}], ",", "116.3459323353367`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00817540533452656`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.198137492260498`", ",", "0.1574141637177774`"}], 
              "}"}], ",", 
             RowBox[{"-", "87.85028592776577`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008150231902771919`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2090268470570162`", ",", 
               RowBox[{"-", "0.13268082458635444`"}]}], "}"}], ",", 
             RowBox[{"-", "85.89578668219421`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00835116514709602`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.415501185784918`", ",", 
               RowBox[{"-", "3.8244870407543035`"}]}], "}"}], ",", 
             RowBox[{"-", "70.40655447360135`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008329517840496571`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.422972368351319`", ",", 
               RowBox[{"-", "3.8454761566998754`"}]}], "}"}], ",", 
             RowBox[{"-", "69.49639078664958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28979145014342367`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8860657647081065`", ",", "3.0378135942946987`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.70502815033527`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2890726448865627`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.616602416028211`", ",", "3.0080884991397507`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.38323562158064`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03190267015405101`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.03176716932845`", ",", "3.687293224962993`"}], "}"}],
              ",", "31.20737525403434`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03177263621721155`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.083036431691981`", ",", "3.7183520146823694`"}], 
              "}"}], ",", "28.16095217862719`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032323755905886736`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.642666223636448`", ",", "3.6503448995112304`"}], 
              "}"}], ",", "7.765048595375285`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03222052453646206`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.648119115760208`", ",", "3.6510884643268637`"}], 
              "}"}], ",", "9.88361165664551`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021862514510374933`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.622413844330305`", ",", "3.520465895530815`"}], 
              "}"}], ",", 
             RowBox[{"-", "6.682435107921549`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021808621140697426`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.816371544651145`", ",", "3.497741381394294`"}], 
              "}"}], ",", 
             RowBox[{"-", "6.628674364880957`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011228579207082773`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.498313174423297`", ",", "1.8306402663680825`"}], 
              "}"}], ",", 
             RowBox[{"-", "35.540396575551384`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011191586991407477`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.628465941339579`", ",", "1.7376646769887718`"}], 
              "}"}], ",", 
             RowBox[{"-", "33.28945061611368`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15686547415048863`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.119367256792085`", ",", "3.0761878458813996`"}], 
              "}"}], ",", "13.75288589901865`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1506862901766112`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.180006138502992`", ",", "3.0910293230434465`"}], 
              "}"}], ",", "23.627214763191365`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09374461823965194`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.529350429469603`", ",", "0.870475889649174`"}], 
              "}"}], ",", 
             RowBox[{"-", "31.03684499341601`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09351088110400799`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.612412203942919`", ",", "0.8204946137409735`"}], 
              "}"}], ",", 
             RowBox[{"-", "30.603041022655816`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.047905335774023894`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.162084544223142`", ",", "1.0917722028025019`"}], 
              "}"}], ",", 
             RowBox[{"-", "83.67608905436151`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04776944736918801`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.183607526553527`", ",", "0.8975625777593969`"}], 
              "}"}], ",", 
             RowBox[{"-", "82.13914646917975`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03418872254349396`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7662921383577954`", ",", "1.1468848888748389`"}], 
              "}"}], ",", 
             RowBox[{"-", "124.66839724404063`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03390025856023029`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6942946472059317`", ",", "1.0427846718180966`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.92236599553755`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02281540760599134`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3617301027851787`", ",", "3.5264239061816407`"}], 
              "}"}], ",", "162.48898227376617`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021661359017307216`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2362153506393723`", ",", "3.5660250924968926`"}], 
              "}"}], ",", "151.77128512305904`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0800947152327206`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.319178571095467`", ",", "0.030756680964077566`"}], 
              "}"}], ",", 
             RowBox[{"-", "157.92445444314106`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07979802317557987`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1509732346100674`", ",", 
               RowBox[{"-", "0.037460808890576236`"}]}], "}"}], ",", 
             RowBox[{"-", "160.63222723682787`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.036140705767510724`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.915873650154078`", ",", "2.085425531623274`"}], 
              "}"}], ",", "149.98850136164526`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03605109866124203`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.811957347798449`", ",", "2.145449446476206`"}], 
              "}"}], ",", "150.29964710695322`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08677719921981861`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8556411871541107`", ",", "1.0443451746924912`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.08412858827893`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08656063162434105`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.585297879846851`", ",", "0.987296686739908`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.6330626467129`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020376356029900882`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9173878228281183`", ",", 
               RowBox[{"-", "0.09386285124665286`"}]}], "}"}], ",", 
             RowBox[{"-", "144.17323139773364`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020326123603821886`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                 "0.`", ",", "0.9999999999999999`", ",", 
                  "167.35910683550452`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8483375195141334`", ",", 
               RowBox[{"-", "0.14371255809062766`"}]}], "}"}], ",", 
             RowBox[{"-", "144.1121805289304`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008106220552827743`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.982587617186125`", ",", 
               RowBox[{"-", "3.1717560561794467`"}]}], "}"}], ",", 
             RowBox[{"-", "93.58730281847909`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008079289286411688`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.969952656087857`", ",", 
               RowBox[{"-", "3.3732957056206274`"}]}], "}"}], ",", 
             RowBox[{"-", "91.30150342715216`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15311042820384177`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2264786672156953`", ",", 
               RowBox[{"-", "2.866480413713278`"}]}], "}"}], ",", 
             RowBox[{"-", "149.9181347958133`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15273183879548274`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.181353800596747`", ",", 
               RowBox[{"-", "2.892619305560026`"}]}], "}"}], ",", 
             RowBox[{"-", "149.6888879818087`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04080590029251491`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.873754933729199`", ",", "3.6211107541915326`"}], 
              "}"}], ",", "110.4363319580428`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04062403406869375`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.860348670364729`", ",", "3.65708926283423`"}], "}"}],
              ",", "113.78112798646536`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.047044108445915965`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.667143186592133`", ",", "3.386655018692026`"}], 
              "}"}], ",", "110.93982426349315`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04673044047412252`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6629156674126215`", ",", "3.3977027496627663`"}], 
              "}"}], ",", "115.51474012452597`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03160703826305748`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.081675417603904`", ",", "0.3567032731689679`"}], 
              "}"}], ",", 
             RowBox[{"-", "39.470573465091164`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03152737399264827`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.112777383536885`", ",", "0.3310916078713156`"}], 
              "}"}], ",", 
             RowBox[{"-", "40.074876540524095`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012437522237085495`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.173986439691582`", ",", "0.09385754040219779`"}], 
              "}"}], ",", 
             RowBox[{"-", "66.46222622315292`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012374114899797433`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.274268209074545`", ",", 
               RowBox[{"-", "0.1363595633154113`"}]}], "}"}], ",", 
             RowBox[{"-", "70.23351306476336`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01816443087132368`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.60623413005632`", ",", "2.1637909267630078`"}], 
              "}"}], ",", 
             RowBox[{"-", "165.98145298707942`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01811263836004397`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.18329341596266`", ",", "2.0581945319702597`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.4154554548623`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010783883655519206`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.101941934037496`", ",", "2.654840751506858`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.50651108614136`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010734899908417542`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.0951283677385755`", ",", "2.6488139974837615`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.10002447413643`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010139194142948596`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4872954362059225`", ",", "2.3272620760423`"}], "}"}],
              ",", 
             RowBox[{"-", "70.76651565789405`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010096473093018712`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.527369175267768`", ",", "2.2124021505044738`"}], 
              "}"}], ",", 
             RowBox[{"-", "73.92546042942524`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012766164838981913`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.412708949979767`", ",", "1.3649542899157536`"}], 
              "}"}], ",", 
             RowBox[{"-", "85.23304246811736`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012709240607369532`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4275612104463455`", ",", "1.1868517104206138`"}], 
              "}"}], ",", 
             RowBox[{"-", "88.57939831136295`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01036473004938714`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1432445512089`", ",", "1.8362821881632283`"}], "}"}],
              ",", 
             RowBox[{"-", "151.76213429665236`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010239825751505265`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.920732809479422`", ",", "1.7167830393253625`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.03397030828376`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031130926305780807`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.357456586428072`", ",", "3.437434345337315`"}], 
              "}"}], ",", "141.53583275177`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029610080232268826`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1387202755849977`", ",", "3.6112018223763473`"}], 
              "}"}], ",", "152.133986059271`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012211260228580977`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6415973214998734`", ",", 
               RowBox[{"-", "0.7773224395460558`"}]}], "}"}], ",", 
             RowBox[{"-", "129.77648399822627`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012177567440452109`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.617055429827024`", ",", 
               RowBox[{"-", "0.8068031282257101`"}]}], "}"}], ",", 
             RowBox[{"-", "128.40400003590605`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008651802627114628`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1945212760539454`", ",", "3.3748669079486944`"}], 
              "}"}], ",", "99.50776861745106`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008610412978161293`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.160334222458122`", ",", "3.5789906596311543`"}], 
              "}"}], ",", "95.93549411747375`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012302829270137653`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5751762563305114`", ",", "0.164338020188098`"}], 
              "}"}], ",", 
             RowBox[{"-", "111.9167174371629`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012271991089420805`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.565815094168653`", ",", "0.14107101664663185`"}], 
              "}"}], ",", 
             RowBox[{"-", "112.44093137476234`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008010029056709446`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3847323755227645`", ",", 
               RowBox[{"-", "1.8228940275480667`"}]}], "}"}], ",", 
             RowBox[{"-", "4.144316400706608`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019646612013615936`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.810627423020948`", ",", 
               RowBox[{"-", "2.0628701227823787`"}]}], "}"}], ",", 
             RowBox[{"-", "176.45978420473506`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019581525776108916`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.655261269437338`", ",", 
               RowBox[{"-", "2.072482187679916`"}]}], "}"}], ",", 
             RowBox[{"-", "178.73382547506014`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03754947117633854`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.866622737248663`", ",", 
               RowBox[{"-", "4.094535006342286`"}]}], "}"}], ",", 
             RowBox[{"-", "93.41700789358755`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0356307897580996`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.859571591560801`", ",", 
               RowBox[{"-", "4.212627155441221`"}]}], "}"}], ",", 
             RowBox[{"-", "104.16970048970886`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011923848279014368`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.2235295923556375`", ",", 
               RowBox[{"-", "2.3817523947534873`"}]}], "}"}], ",", 
             RowBox[{"-", "177.8168242534808`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011700911716802006`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8106301849454995`", ",", 
               RowBox[{"-", "2.3974929692183786`"}]}], "}"}], ",", 
             "174.63351397925524`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013288639563887815`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.979510040500845`", ",", "0.14198319736464082`"}], 
              "}"}], ",", "82.3378542919349`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0132556663911243`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.006806903401426`", ",", "0.34488466422178027`"}], 
              "}"}], ",", "82.66852309362757`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01291483004381035`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.14771009037063`", ",", "0.8767832613979392`"}], 
              "}"}], ",", "145.90090965183157`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01288191299428509`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.128144313032029`", ",", "0.8900298355245744`"}], 
              "}"}], ",", "145.15997102680564`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017341013089169174`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1066298187111636`", ",", 
               RowBox[{"-", "0.2555800674312975`"}]}], "}"}], ",", 
             "161.62875240280945`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017229021097724437`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.913926441095321`", ",", 
               RowBox[{"-", "0.19158357221137529`"}]}], "}"}], ",", 
             "166.11034649423033`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08902390917350449`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.510555217834851`", ",", 
               RowBox[{"-", "3.622696215050899`"}]}], "}"}], ",", 
             RowBox[{"-", "134.3590148106544`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08800349095817998`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.346861212778436`", ",", 
               RowBox[{"-", "3.790094402998322`"}]}], "}"}], ",", 
             RowBox[{"-", "140.4875144148465`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.036837080030569444`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7454803212975145`", ",", 
               RowBox[{"-", "2.9218814178830406`"}]}], "}"}], ",", 
             RowBox[{"-", "137.03898307065242`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03657096042967973`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4385228322540007`", ",", 
               RowBox[{"-", "3.207733694584439`"}]}], "}"}], ",", 
             RowBox[{"-", "141.84683004622968`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11578483026834266`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.847230167096772`", ",", 
               RowBox[{"-", "4.057055011384567`"}]}], "}"}], ",", 
             RowBox[{"-", "102.15849834335614`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11520049002439489`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.825875960104849`", ",", 
               RowBox[{"-", "4.156169652824735`"}]}], "}"}], ",", 
             RowBox[{"-", "105.89843345812447`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01369056790387031`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3837451970089263`", ",", 
               RowBox[{"-", "0.9810609906121149`"}]}], "}"}], ",", 
             RowBox[{"-", "173.50314016437207`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013653239158579933`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1151139283275167`", ",", 
               RowBox[{"-", "1.0116527439306593`"}]}], "}"}], ",", 
             RowBox[{"-", "174.7995134954129`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02377588375239048`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.43912162825665`", ",", 
               RowBox[{"-", "3.185392938272045`"}]}], "}"}], ",", 
             RowBox[{"-", "109.26387411143327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017845064802731653`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.4054814356495156`", ",", 
               RowBox[{"-", "3.2816487654920232`"}]}], "}"}], ",", 
             RowBox[{"-", "126.47352347905017`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.206974353989315`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.194421264377078`", ",", 
               RowBox[{"-", "3.4109465853670002`"}]}], "}"}], ",", 
             RowBox[{"-", "64.33347666300507`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2058791164333152`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.321252999872217`", ",", 
               RowBox[{"-", "3.674877994366107`"}]}], "}"}], ",", 
             RowBox[{"-", "68.2194703802668`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01790374562258787`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.757347622260808`", ",", 
               RowBox[{"-", "2.895465567414296`"}]}], "}"}], ",", 
             RowBox[{"-", "20.73908898964362`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01785479870312892`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.85372094736996`", ",", 
               RowBox[{"-", "2.9319571685943555`"}]}], "}"}], ",", 
             RowBox[{"-", "22.052928125127448`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022921263591566918`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.120352531365677`", ",", 
               RowBox[{"-", "2.119608947377167`"}]}], "}"}], ",", 
             RowBox[{"-", "99.13731999033674`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022593734368124205`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.118421919627566`", ",", 
               RowBox[{"-", "2.1316120902231095`"}]}], "}"}], ",", 
             RowBox[{"-", "92.37500380428324`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008504362509427871`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.9558269679507205`", ",", "2.6415458060438706`"}], 
              "}"}], ",", "122.8611550483321`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008452235239997557`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.9018847525001386`", ",", "2.7250518604226603`"}], 
              "}"}], ",", "127.18888256570317`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16952923507693698`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3552372974225495`", ",", 
               RowBox[{"-", "0.6182436607527533`"}]}], "}"}], ",", 
             RowBox[{"-", "137.83308574927395`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1691085201095186`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.313269548490573`", ",", 
               RowBox[{"-", "0.656253555064122`"}]}], "}"}], ",", 
             RowBox[{"-", "137.49885752929114`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009513832572507326`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.71366100941622`", ",", 
               RowBox[{"-", "1.3953709118801847`"}]}], "}"}], ",", 
             RowBox[{"-", "50.28667593751066`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009373462859084827`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.846069552065707`", ",", 
               RowBox[{"-", "1.5547823287806197`"}]}], "}"}], ",", 
             RowBox[{"-", "43.431554857019655`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008348524470770927`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.152706677785381`", ",", "2.623570492538123`"}], 
              "}"}], ",", 
             RowBox[{"-", "111.94143096548925`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008324924162037084`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.151437642763765`", ",", "2.6204202530124365`"}], 
              "}"}], ",", 
             RowBox[{"-", "113.45883245486905`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037341050774322045`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.954758455371051`", ",", "3.344437558261244`"}], 
              "}"}], ",", 
             RowBox[{"-", "163.17859873594995`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037246420574836535`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.920544336604041`", ",", "3.3340937605348855`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.5043733645863`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.1544981054724472`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.848099970795353`", ",", "3.4606262406768167`"}], 
              "}"}], ",", "123.51336688997418`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.1474144156040729`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.763727798657249`", ",", "3.5880340962695576`"}], 
              "}"}], ",", "119.18262122523532`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008235611584305526`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.601745336365228`", ",", "3.5938447090001717`"}], 
              "}"}], ",", "36.10723979312939`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008210805481025828`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.624242981949835`", ",", "3.610254629137234`"}], 
              "}"}], ",", "37.95727225338355`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03613259581610135`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.434749207937504`", ",", "2.0885718099516564`"}], 
              "}"}], ",", 
             RowBox[{"-", "154.608740776799`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03599695695836152`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.164801340599267`", ",", "1.9604416019457573`"}], 
              "}"}], ",", 
             RowBox[{"-", "157.3651569699128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040714790634765664`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.048061583993393`", ",", "2.8023330118719088`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.43178126300674`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04061414788246977`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8591954719604376`", ",", "2.793861627005079`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.64987289402575`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16169874132850273`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.116955393542976`", ",", "3.2735007709854105`"}], 
              "}"}], ",", "111.53470838591308`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1611439538202129`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.07412909135062`", ",", "3.3820288297901584`"}], 
              "}"}], ",", "113.95055237538871`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.027542077323656298`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.420110121692732`", ",", "3.3141384967822844`"}], 
              "}"}], ",", "81.73533464969383`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.027471709648714253`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.428544256025292`", ",", "3.3722030476344838`"}], 
              "}"}], ",", "80.96807818616112`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25333164685466586`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.282525643195672`", ",", 
               RowBox[{"-", "0.9400201055250266`"}]}], "}"}], ",", 
             RowBox[{"-", "87.04016406951992`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2526215490268054`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.289914658878898`", ",", 
               RowBox[{"-", "1.0829276038966589`"}]}], "}"}], ",", 
             RowBox[{"-", "88.50836739250732`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06554634650493328`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.860004043903626`", ",", 
               RowBox[{"-", "0.5846922603434024`"}]}], "}"}], ",", 
             RowBox[{"-", "164.5913545856556`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06491907621816267`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.690008009051376`", ",", 
               RowBox[{"-", "0.6315445677566753`"}]}], "}"}], ",", 
             RowBox[{"-", "170.20489182222428`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022903967572892772`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.404594217038392`", ",", 
               RowBox[{"-", "1.5717003663107687`"}]}], "}"}], ",", 
             RowBox[{"-", "106.51881195646983`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022826583892989208`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.259408443254719`", ",", 
               RowBox[{"-", "2.061249027219967`"}]}], "}"}], ",", 
             RowBox[{"-", "104.16447702183984`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18314861879873123`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.381736509769126`", ",", 
               RowBox[{"-", "2.6609417351921207`"}]}], "}"}], ",", 
             RowBox[{"-", "97.78277802703647`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18243289297965154`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.380574323379593`", ",", 
               RowBox[{"-", "2.669444910492241`"}]}], "}"}], ",", 
             RowBox[{"-", "100.68296578514985`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009320543196703987`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.337253499543261`", ",", "2.5050236894144997`"}], 
              "}"}], ",", "108.62187201490599`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009296105364908028`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.292422481352895`", ",", "2.6380683363991775`"}], 
              "}"}], ",", "107.6123529424297`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03102927905721432`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4621819624918184`", ",", "1.1524391197069026`"}], 
              "}"}], ",", "173.54616788033394`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03073100693773136`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3656486830671053`", ",", "1.1633589103542972`"}], 
              "}"}], ",", "167.9199266026694`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24257121959396685`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6118972978118684`", ",", "0.16418018278816915`"}], 
              "}"}], ",", 
             RowBox[{"-", "114.34024528717924`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24169118025090436`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5755001570220437`", ",", "0.08372018670784769`"}], 
              "}"}], ",", 
             RowBox[{"-", "116.97085416105904`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024362173054340373`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.08319075266063`", ",", 
               RowBox[{"-", "0.12669712854553145`"}]}], "}"}], ",", 
             RowBox[{"-", "99.85403317529796`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02429397479168017`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.043580714792697`", ",", 
               RowBox[{"-", "0.35473242622201256`"}]}], "}"}], ",", 
             RowBox[{"-", "101.31446555789232`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009097347719530306`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.552047754432303`", ",", 
               RowBox[{"-", "0.6922139549788413`"}]}], "}"}], ",", 
             RowBox[{"-", "107.72568436943659`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00907068872064511`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.51316159899305`", ",", 
               RowBox[{"-", "0.8138720656466969`"}]}], "}"}], ",", 
             RowBox[{"-", "106.01304354804157`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012556390690574295`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6709939753795493`", ",", "1.8909537908995016`"}], 
              "}"}], ",", "113.06696575224656`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01247986905247673`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4586418271341675`", ",", "2.389602901024031`"}], 
              "}"}], ",", "108.75630302872577`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23889321070749203`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3688715306818175`", ",", "1.0498166231520185`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.59465784953875`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23797549081717562`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1586051450993393`", ",", "0.9757481031880711`"}], 
              "}"}], ",", 
             RowBox[{"-", "163.43413980529309`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011543135077166946`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6840645451323115`", ",", "0.07101065378714078`"}], 
              "}"}], ",", 
             RowBox[{"-", "101.35655223845953`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010851675001839178`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.636307215419951`", ",", 
               RowBox[{"-", "0.16676976387992273`"}]}], "}"}], ",", 
             RowBox[{"-", "90.0464531666702`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008125135984197411`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2306487365576024`", ",", 
               RowBox[{"-", "0.434011017903535`"}]}], "}"}], ",", 
             RowBox[{"-", "83.94128743662209`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008102817684153265`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2415014762410768`", ",", 
               RowBox[{"-", "0.5362599279497503`"}]}], "}"}], ",", 
             RowBox[{"-", "85.28549102088918`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008307926646532274`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.5064694967424925`", ",", 
               RowBox[{"-", "4.068756492661345`"}]}], "}"}], ",", 
             RowBox[{"-", "68.58622709969703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00814390780893489`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.578285539175333`", ",", 
               RowBox[{"-", "4.251879845857825`"}]}], "}"}], ",", 
             RowBox[{"-", "60.87456459730977`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2883556225704925`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.301734612303231`", ",", "2.9715636864263844`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.06144309282487`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.28753592812209033`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.15678870259673`", ",", "2.953924326936628`"}], "}"}],
              ",", 
             RowBox[{"-", "174.61040585382725`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03211762285383692`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.926853849632756`", ",", "3.6996533119034503`"}], 
              "}"}], ",", "12.002174717915564`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03203841564892293`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.06111150636273`", ",", "3.728195983954255`"}], "}"}],
              ",", "11.902969724332527`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02175486062377545`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.08493018736672`", ",", "3.4665318756219445`"}], 
              "}"}], ",", 
             RowBox[{"-", "6.574913621847145`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021678417844706352`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.373505533449265`", ",", "3.4332706036957727`"}], 
              "}"}], ",", 
             RowBox[{"-", "4.06577885453093`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011154716645471472`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8423809303975185`", ",", "1.5972051673966625`"}], 
              "}"}], ",", 
             RowBox[{"-", "31.038504656676153`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011126973395551534`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.845562438732375`", ",", "1.5952906131564648`"}], 
              "}"}], ",", 
             RowBox[{"-", "31.422612880117853`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14475051422345883`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.358079660061334`", ",", "3.168928479704756`"}], 
              "}"}], ",", "33.501543627363965`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.14166595628413695`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.592570358476737`", ",", "3.3241435725362685`"}], 
              "}"}], ",", "25.5607943242936`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09327772675433729`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.913412393865279`", ",", "0.6424620335464204`"}], 
              "}"}], ",", 
             RowBox[{"-", "30.169237051894775`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09235911634911008`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.966790918559761`", ",", "0.6114333462384633`"}], 
              "}"}], ",", 
             RowBox[{"-", "35.86450208913387`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04763394442576827`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.223831140464143`", ",", "0.6062246397799318`"}], 
              "}"}], ",", 
             RowBox[{"-", "80.60220388399776`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04745898715223935`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.25788395479941`", ",", "0.40047914863717937`"}], 
              "}"}], ",", 
             RowBox[{"-", "83.27867753885248`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033614228463448755`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5400266537753016`", ",", "0.8584285114380503`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.17633474703447`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03339658625640332`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.418791294547206`", ",", "0.7379370981728014`"}], 
              "}"}], ",", 
             RowBox[{"-", "139.66540582714876`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035961713726436834`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.58339473401461`", ",", "2.2758211254393754`"}], 
              "}"}], ",", "150.61079285226117`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02528997250968048`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4639266872794554`", ",", "2.343108263921816`"}], 
              "}"}], ",", "168.6732329006984`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0863446045109698`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.345772548463666`", ",", "0.9347785088876049`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.18199670514844`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08104188262691892`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1109418660443935`", ",", "0.8813486848297772`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.78302703149296`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020276015012280636`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5719528092812887`", ",", 
               RowBox[{"-", "0.3436921906763729`"}]}], "}"}], ",", 
             RowBox[{"-", "144.0511296601331`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019897858517167778`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.540315837718936`", ",", 
               RowBox[{"-", "0.3666346889023103`"}]}], "}"}], ",", 
             RowBox[{"-", "151.59344059413488`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008052447493641963`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.96350433554662`", ",", 
               RowBox[{"-", "3.6571197780856823`"}]}], "}"}], ",", 
             RowBox[{"-", "89.01570403582491`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00803258833253827`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.966474220943696`", ",", 
               RowBox[{"-", "3.8299795327438115`"}]}], "}"}], ",", 
             RowBox[{"-", "88.91431905883087`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012311030817442746`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.361821664728799`", ",", 
               RowBox[{"-", "0.379995678727669`"}]}], "}"}], ",", 
             RowBox[{"-", "74.0047999063739`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012253810099394923`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.361840882167571`", ",", 
               RowBox[{"-", "0.3800627190973369`"}]}], "}"}], ",", 
             RowBox[{"-", "70.52434698635753`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018060993525520194`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8735678907445887`", ",", "1.9718076657689771`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.8494579226454`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016796250386695615`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7775506922884885`", ",", "1.9421761779742046`"}], 
              "}"}], ",", 
             RowBox[{"-", "150.97527476813147`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010686138660700773`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.888508547977647`", ",", "2.4429143369798125`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.69353786213142`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010658263821516021`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.767552045297535`", ",", "2.3071249030370566`"}], 
              "}"}], ",", 
             RowBox[{"-", "130.72744958687673`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010053932046359442`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.613073684194516`", ",", "1.9149759269957787`"}], 
              "}"}], ",", 
             RowBox[{"-", "77.08440520095631`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009994875061707703`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.628545758690353`", ",", "1.8475056952641078`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.88313083703785`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012652570200471572`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4349281815717845`", ",", "0.8897875450281161`"}], 
              "}"}], ",", 
             RowBox[{"-", "91.92575415460854`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01261710592430744`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.4265704102400125`", ",", "0.6412175565394289`"}], 
              "}"}], ",", 
             RowBox[{"-", "93.39373505485621`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010116426662495704`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7061559660456895`", ",", "1.6302363202035928`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.30580631991515`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010076230151400516`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5630614227640534`", ",", "1.590029904485815`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.3474024817301`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028163532390573003`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9882413674549433`", ",", "3.6907620563599965`"}], 
              "}"}], ",", "162.7321393667719`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02809378635381146`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8913015105007416`", ",", "3.7208958175518165`"}], 
              "}"}], ",", "163.01067611444506`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01214396761602647`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.417849472132508`", ",", 
               RowBox[{"-", "1.058102453305081`"}]}], "}"}], ",", 
             RowBox[{"-", "127.03151607358555`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012107295987815172`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3495126332599936`", ",", 
               RowBox[{"-", "1.148684791261067`"}]}], "}"}], ",", 
             RowBox[{"-", "128.89387053172317`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012241230207459314`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4346059552727373`", ",", 
               RowBox[{"-", "0.17662184558167104`"}]}], "}"}], ",", 
             RowBox[{"-", "112.96514531236245`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0121397315140795`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.416036833516986`", ",", 
               RowBox[{"-", "0.22044205134953043`"}]}], "}"}], ",", 
             RowBox[{"-", "118.16921480874805`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01951665515940765`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.34509924734631`", ",", 
               RowBox[{"-", "2.079337547647544`"}]}], "}"}], ",", 
             "178.9921332546149`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01882252703547951`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.312866981451187`", ",", 
               RowBox[{"-", "2.0787705044848455`"}]}], "}"}], ",", 
             RowBox[{"-", "171.4678408334471`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011482143331641896`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.604807374485697`", ",", 
               RowBox[{"-", "2.3781584461875953`"}]}], "}"}], ",", 
             "167.08385221199129`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011371672798873451`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.603160721611645`", ",", 
               RowBox[{"-", "2.3777808238799247`"}]}], "}"}], ",", 
             "172.71260510540782`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01322277503487157`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.049286457408408`", ",", "0.6750501916120701`"}], 
              "}"}], ",", "82.99919189531913`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01162506070492232`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.058839754670561`", ",", "0.7528464829549052`"}], 
              "}"}], ",", "69.01017495097477`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012849079843049296`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.857304483961946`", ",", "1.0785491778117529`"}], 
              "}"}], ",", "144.4190324017792`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012710497532463748`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.747626960664649`", ",", "1.1570154792815404`"}], 
              "}"}], ",", "138.46443462602127`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017117752374642584`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6677729820998963`", ",", 
               RowBox[{"-", "0.13071392041402335`"}]}], "}"}], ",", 
             "170.59194058565123`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017046098949106227`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6187428803404096`", ",", 
               RowBox[{"-", "0.12258995378609706`"}]}], "}"}], ",", 
             "167.45506543681174`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08699476907638912`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.199850853875885`", ",", 
               RowBox[{"-", "3.9113342055346747`"}]}], "}"}], ",", 
             RowBox[{"-", "146.6160140190385`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08676491918242181`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.167172969626897`", ",", 
               RowBox[{"-", "3.932868198177771`"}]}], "}"}], ",", 
             RowBox[{"-", "147.68730406167515`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03630676333844383`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2504504448487164`", ",", 
               RowBox[{"-", "3.355483321000886`"}]}], "}"}], ",", 
             RowBox[{"-", "146.65467702180703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03620787450596532`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.135404990293597`", ",", 
               RowBox[{"-", "3.4311843999347778`"}]}], "}"}], ",", 
             RowBox[{"-", "147.94402878154762`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013616012193963287`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.833124009085632`", ",", 
               RowBox[{"-", "1.0373182512021093`"}]}], "}"}], ",", 
             RowBox[{"-", "176.09588682645344`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013580844600214552`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6662098907927887`", ",", 
               RowBox[{"-", "1.0487093524605482`"}]}], "}"}], ",", 
             RowBox[{"-", "176.97254842818958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013393669868598643`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.323627665433101`", ",", 
               RowBox[{"-", "3.3923747599303007`"}]}], "}"}], ",", 
             RowBox[{"-", "143.68317284666688`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013335137780755424`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.171777647535761`", ",", 
               RowBox[{"-", "3.5039883632184616`"}]}], "}"}], ",", 
             RowBox[{"-", "146.9635437009482`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20478967450020755`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.396788952294392`", ",", 
               RowBox[{"-", "3.863917628126922`"}]}], "}"}], ",", 
             RowBox[{"-", "72.10546409752862`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20403468454437404`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.3970953867840885`", ",", 
               RowBox[{"-", "3.8648666770073263`"}]}], "}"}], ",", 
             RowBox[{"-", "69.41522810646259`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02227088531389559`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.109466376042483`", ",", 
               RowBox[{"-", "2.3475363475123796`"}]}], "}"}], ",", 
             RowBox[{"-", "85.61268761822976`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021259099729042108`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.112100941858732`", ",", 
               RowBox[{"-", "2.3818749918280813`"}]}], "}"}], ",", 
             RowBox[{"-", "95.96356786725185`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008400427483313232`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.745581720203257`", ",", "2.93105649072293`"}], "}"}],
              ",", "131.51661008307406`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008308138995562058`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.685296765772567`", ",", "2.999156445129354`"}], 
              "}"}], ",", "137.52387098832637`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16868884921620195`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0950691582980365`", ",", 
               RowBox[{"-", "0.8562053790945715`"}]}], "}"}], ",", 
             RowBox[{"-", "137.16462930930942`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16807545660187906`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.0876498459533925`", ",", 
               RowBox[{"-", "0.8630842502231568`"}]}], "}"}], ",", 
             RowBox[{"-", "134.52550444890957`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009235164199183203`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.994065167912832`", ",", 
               RowBox[{"-", "1.694889300567602`"}]}], "}"}], ",", 
             RowBox[{"-", "36.57643377652856`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009188077088564358`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.063713541240318`", ",", 
               RowBox[{"-", "1.7465703138020194`"}]}], "}"}], ",", 
             RowBox[{"-", "32.80477791676501`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008301390568634113`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.022441816341458`", ",", "2.3231662784791007`"}], 
              "}"}], ",", 
             RowBox[{"-", "114.97623394424957`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008195005765858115`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.941956888865805`", ",", "2.150378709482794`"}], 
              "}"}], ",", 
             RowBox[{"-", "108.52791239264472`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.037152030188491524`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.6701500886058795`", ",", "3.255165769425571`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.8301479932221`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03705124552272197`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1265156431039856`", ",", "3.076744775513107`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.56766584184643`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03586182727798118`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.946889611226584`", ",", "1.869578185063331`"}], 
              "}"}], ",", 
             RowBox[{"-", "160.12157316302657`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03571534524504367`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.81685376611325`", ",", "1.822561236102724`"}], "}"}],
              ",", 
             RowBox[{"-", "157.0678804870531`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040513753908650474`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.542744171328283`", ",", "2.780874315517512`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.86796452504478`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04039359241338009`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3812344063793915`", ",", "2.7748615939355155`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.09399057676393`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.160591069784868`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.974551438823336`", ",", "3.606204375382554`"}], 
              "}"}], ",", "116.36639636486434`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15973254664361652`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.93698715466518`", ",", "3.681988704384638`"}], "}"}],
              ",", "120.28362763927251`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25191344162900536`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.297399842444705`", ",", 
               RowBox[{"-", "1.3703794401746636`"}]}], "}"}], ",", 
             RowBox[{"-", "89.97657071549422`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.250674451114743`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.297504651474537`", ",", 
               RowBox[{"-", "1.6266875117243267`"}]}], "}"}], ",", 
             RowBox[{"-", "93.6360836794783`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06429780882909183`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.443488422529625`", ",", 
               RowBox[{"-", "0.6741042190569693`"}]}], "}"}], ",", 
             RowBox[{"-", "175.81842905879313`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06402806781700361`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.362490433178861`", ",", 
               RowBox[{"-", "0.6800261468809501`"}]}], "}"}], ",", 
             RowBox[{"-", "172.6741016094434`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02274946166271862`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.183785132830618`", ",", 
               RowBox[{"-", "2.3608905041613863`"}]}], "}"}], ",", 
             RowBox[{"-", "101.81014208720985`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0205864070092409`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.149600281557578`", ",", 
               RowBox[{"-", "2.5243795802136213`"}]}], "}"}], ",", 
             RowBox[{"-", "114.84087775212274`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18171996414288846`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.329947657622755`", ",", 
               RowBox[{"-", "2.9378162837687634`"}]}], "}"}], ",", 
             RowBox[{"-", "103.5831535432631`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1812231873625461`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.28916863721412`", ",", 
               RowBox[{"-", "3.106593666353948`"}]}], "}"}], ",", 
             RowBox[{"-", "104.8966509732426`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009271731607448755`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1955955310933275`", ",", "2.9430773810869217`"}], 
              "}"}], ",", "106.60283386995378`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009096705829027354`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.135076293354458`", ",", "3.146048459213462`"}], 
              "}"}], ",", "99.02461952672782`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030435601989512576`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1615855378483713`", ",", "1.207032031787801`"}], 
              "}"}], ",", "162.29368532500487`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030262615454523963`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.924273756208271`", ",", "1.2827967015776476`"}], 
              "}"}], ",", "166.39635003812646`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24081433365777574`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4410452598506835`", ",", 
               RowBox[{"-", "0.18049458499323162`"}]}], "}"}], ",", 
             RowBox[{"-", "119.60146303493894`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23919154037313073`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4127101159956346`", ",", 
               RowBox[{"-", "0.23037049313153385`"}]}], "}"}], ",", 
             RowBox[{"-", "124.20738311193588`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.024225967439864368`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9852894961017116`", ",", 
               RowBox[{"-", "0.6460686592447719`"}]}], "}"}], ",", 
             RowBox[{"-", "102.77489794048668`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02407531150051946`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.935730260460921`", ",", 
               RowBox[{"-", "0.8646476621391642`"}]}], "}"}], ",", 
             RowBox[{"-", "98.4044333340578`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009044107843674506`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.43125834980598`", ",", 
               RowBox[{"-", "1.0992574212415742`"}]}], "}"}], ",", 
             RowBox[{"-", "104.30040272664654`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008780237424073651`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.411462985290634`", ",", 
               RowBox[{"-", "1.1769154495360734`"}]}], "}"}], ",", 
             RowBox[{"-", "113.20783884946086`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01240381375548319`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3767600525366226`", ",", "2.6307316791079334`"}], 
              "}"}], ",", "104.44564030520498`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012368030325712107`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.262077448055811`", ",", "3.075918410771986`"}], 
              "}"}], ",", "102.81557021425061`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010201634959507322`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6361714884051755`", ",", 
               RowBox[{"-", "0.33417672375082363`"}]}], "}"}], ",", 
             RowBox[{"-", "78.73635409488094`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010103089830228935`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.648156598461509`", ",", 
               RowBox[{"-", "0.3943550324390119`"}]}], "}"}], ",", 
             RowBox[{"-", "84.3765444337419`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008080560688500561`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2680396580060287`", ",", 
               RowBox[{"-", "0.8580522163487847`"}]}], "}"}], ",", 
             RowBox[{"-", "86.62969460515679`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008055170324611846`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.284457958746897`", ",", 
               RowBox[{"-", "1.1368441939427059`"}]}], "}"}], ",", 
             RowBox[{"-", "88.67644098108464`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03195940378166947`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.403187952588996`", ",", "3.800301315581602`"}], 
              "}"}], ",", "11.803764730745819`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031742246390203614`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.630284451455838`", ",", "3.8477598192669125`"}], 
              "}"}], ",", "7.173727396519533`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02160224367220629`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.657254405218824`", ",", "3.413101570340565`"}], 
              "}"}], ",", 
             RowBox[{"-", "1.556644087214717`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016496266149675438`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.709790060700965`", ",", "3.4116739007042938`"}], 
              "}"}], ",", 
             RowBox[{"-", "18.508550410030043`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011099299146749298`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.078171501620103`", ",", "1.4531793955188055`"}], 
              "}"}], ",", 
             RowBox[{"-", "31.806721103561447`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01105173183287477`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.126234424523609`", ",", "1.4233713146992655`"}], 
              "}"}], ",", 
             RowBox[{"-", "35.02243483108043`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1386471286652363`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.76948545282574`", ",", "3.4087582852440135`"}], 
              "}"}], ",", "17.620045021223245`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1383026528670347`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.826222303376928`", ",", "3.426778123712218`"}], 
              "}"}], ",", "17.981462266738085`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09144955253095094`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.159514962471937`", ",", "0.4721062938499978`"}], 
              "}"}], ",", 
             RowBox[{"-", "41.55976712637297`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07698969842798983`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.812765773017162`", ",", 
               RowBox[{"-", "0.10705713229944788`"}]}], "}"}], ",", 
             RowBox[{"-", "56.68410833936893`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012173485554484881`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.888113141749456`", ",", 
               RowBox[{"-", "0.22169323589710352`"}]}], "}"}], ",", 
             RowBox[{"-", "112.81583459778055`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04728467248867965`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.2919813439335`", ",", "0.11115117115553974`"}], 
              "}"}], ",", 
             RowBox[{"-", "85.95515119370748`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04715996806817774`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.30137660267463`", ",", 
               RowBox[{"-", "0.021712658906653276`"}]}], "}"}], ",", 
             RowBox[{"-", "87.01209658936926`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033180353218404846`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2337022530914274`", ",", "0.5807779500679296`"}], 
              "}"}], ",", 
             RowBox[{"-", "144.15447690726316`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033026689297777176`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1850486011279524`", ",", "0.5456290314456834`"}], 
              "}"}], ",", 
             RowBox[{"-", "147.62335958098154`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01067174121675637`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4639266872794554`", ",", "2.343108263921816`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.6346877148011`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010642239483722064`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.42524535983107`", ",", "2.32639715513739`"}], "}"}], 
             ",", 
             RowBox[{"-", "158.01915955236734`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0177851009661479`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.419021162144573`", ",", "2.3521030916458017`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.26432705086427`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017624845741933917`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4036866376173576`", ",", "2.350292019126975`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.70609134522348`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019526754805094863`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.381604823976741`", ",", 
               RowBox[{"-", "0.45247289711526967`"}]}], "}"}], ",", 
             RowBox[{"-", "159.13575152813664`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0188306493500104`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1315529398097395`", ",", 
               RowBox[{"-", "0.5477796894646114`"}]}], "}"}], ",", 
             RowBox[{"-", "149.5881729983392`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008012778148628164`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.972389363345108`", ",", 
               RowBox[{"-", "4.14210818712324`"}]}], "}"}], ",", 
             RowBox[{"-", "88.81293408183322`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01219685533881422`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.449908629578593`", ",", 
               RowBox[{"-", "0.6290946221239575`"}]}], "}"}], ",", 
             RowBox[{"-", "67.0438940663414`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012160121274981043`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.531812469884396`", ",", 
               RowBox[{"-", "0.8224597114203069`"}]}], "}"}], ",", 
             RowBox[{"-", "68.89346227437515`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015620072431449951`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6290617411838237`", ",", "1.8597836212114276`"}], 
              "}"}], ",", 
             RowBox[{"-", "139.10109161361768`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01288808963587158`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4058226965187366`", ",", "1.6664153391472372`"}], 
              "}"}], ",", 
             RowBox[{"-", "154.66874718928074`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010630461693970548`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.615425364229257`", ",", "2.1304326170238865`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.76136131162164`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01060424037599711`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.614686661186413`", ",", "2.1295447813128416`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.6479071713565`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009936164978887019`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.713787371339179`", ",", "1.570713499858081`"}], 
              "}"}], ",", 
             RowBox[{"-", "68.6818564731195`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00990682077110572`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.774328954197708`", ",", "1.4155775426289767`"}], 
              "}"}], ",", 
             RowBox[{"-", "70.43424622580066`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012581741052048121`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.405720745714707`", ",", "0.28962841116119903`"}], 
              "}"}], ",", 
             RowBox[{"-", "94.86171595510363`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010036193356730718`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3243323955771182`", ",", "1.5094446611867771`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.388998643545`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009958635797187197`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1473289708149186`", ",", "1.439324730597311`"}], 
              "}"}], ",", 
             RowBox[{"-", "163.39109675615265`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01207073509839684`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1502362259938024`", ",", 
               RowBox[{"-", "1.3957048186924736`"}]}], "}"}], ",", 
             RowBox[{"-", "130.75622498986158`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012039266566667994`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.140939782144625`", ",", 
               RowBox[{"-", "1.4064915027523015`"}]}], "}"}], ",", 
             RowBox[{"-", "131.7173527867946`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012039074401536185`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3009531280733664`", ",", 
               RowBox[{"-", "0.43534944114653396`"}]}], "}"}], ",", 
             RowBox[{"-", "123.37328430513378`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011993146577347942`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.234991679446133`", ",", 
               RowBox[{"-", "0.5354867968672238`"}]}], "}"}], ",", 
             RowBox[{"-", "120.558706637335`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018153086228537434`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.126212024936174`", ",", 
               RowBox[{"-", "2.1067733899757095`"}]}], "}"}], ",", 
             RowBox[{"-", "161.92781492150914`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017554742480894805`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.074089590001083`", ",", 
               RowBox[{"-", "2.1237816255091575`"}]}], "}"}], ",", 
             RowBox[{"-", "171.22254815208146`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011262265111103337`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3692815675533225`", ",", 
               RowBox[{"-", "2.347872509711066`"}]}], "}"}], ",", 
             "178.34135799882444`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01119160099071891`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3459786044157145`", ",", 
               RowBox[{"-", "2.3471977292237662`"}]}], "}"}], ",", 
             "173.94463182860906`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010220398973492943`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.11598951992452`", ",", "0.901805773284278`"}], "}"}],
              ",", "55.021158006630465`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009743557485578981`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.117465107955368`", ",", "0.9039147885466935`"}], 
              "}"}], ",", "65.46225261112687`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012573409885857397`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.604221962285013`", ",", "1.2840482842581151`"}], 
              "}"}], ",", "132.50983685026335`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01252307649637794`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.563582880352831`", ",", "1.3283827761195492`"}], 
              "}"}], ",", "129.5255008920877`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016974745458589298`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3194844998904247`", ",", 
               RowBox[{"-", "0.05599969509460018`"}]}], "}"}], ",", 
             "164.31819028797227`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0169230207771294`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.151209848715848`", ",", 
               RowBox[{"-", "0.008757463641831466`"}]}], "}"}], ",", 
             "166.22371894222718`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08653567657754005`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9464350153265713`", ",", 
               RowBox[{"-", "4.072481409782038`"}]}], "}"}], ",", 
             RowBox[{"-", "148.75859410431212`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0859778359737021`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.835722394194781`", ",", 
               RowBox[{"-", "4.13964075830178`"}]}], "}"}], ",", 
             RowBox[{"-", "144.2823865496042`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013545767837733614`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.312220468657105`", ",", 
               RowBox[{"-", "1.0674312255994285`"}]}], "}"}], ",", 
             RowBox[{"-", "177.84921002992576`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013504632056860493`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1483285684874125`", ",", 
               RowBox[{"-", "1.0735863512073813`"}]}], "}"}], ",", 
             RowBox[{"-", "179.73856896873326`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01327686148578607`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.947765141123858`", ",", 
               RowBox[{"-", "3.6496665162900763`"}]}], "}"}], ",", 
             RowBox[{"-", "150.24391455522954`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013244126484075079`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.887302745128805`", ",", 
               RowBox[{"-", "3.684232142683669`"}]}], "}"}], ",", 
             RowBox[{"-", "150.16682420031646`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2032824779800118`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.474559788528993`", ",", 
               RowBox[{"-", "4.071123810438171`"}]}], "}"}], ",", 
             RowBox[{"-", "66.72499211539612`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15014819618983194`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.579937962894859`", ",", 
               RowBox[{"-", "4.3161032824231205`"}]}], "}"}], ",", 
             RowBox[{"-", "49.289173122385115`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03924596278987575`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.666259953006467`", ",", 
               RowBox[{"-", "4.416423503191367`"}]}], "}"}], ",", 
             "4.026114600010307`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01025816915813612`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.798279980013547`", ",", 
               RowBox[{"-", "4.407131294580484`"}]}], "}"}], ",", 
             "57.34140232240581`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02029328043853616`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.094646516432469`", ",", 
               RowBox[{"-", "2.548964716506338`"}]}], "}"}], ",", 
             RowBox[{"-", "106.31444811627381`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02024264715887027`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.017709930673849`", ",", 
               RowBox[{"-", "2.8118212473725794`"}]}], "}"}], ",", 
             RowBox[{"-", "105.86773792171074`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008216864404423688`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.516406202241529`", ",", "3.153786736063154`"}], 
              "}"}], ",", "143.5311318935787`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00819351101102162`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.4247886751073`", ",", "3.2215031330595845`"}], "}"}],
              ",", "145.07906227575617`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16746429442840072`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.897134594666521`", ",", 
               RowBox[{"-", "1.0567814332362302`"}]}], "}"}], ",", 
             RowBox[{"-", "131.88637958850958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1670094770389857`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.838260177596472`", ",", 
               RowBox[{"-", "1.1224294320918338`"}]}], "}"}], ",", 
             RowBox[{"-", "133.15664609206152`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008089984316145455`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.863954869871214`", ",", "1.9176321217127803`"}], 
              "}"}], ",", 
             RowBox[{"-", "102.07959084103997`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03695073426189968`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.828233618459975`", ",", "2.9715138482660324`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.30518369046987`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.036355405316505024`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.657936910198665`", ",", "2.9071816910221346`"}], 
              "}"}], ",", 
             RowBox[{"-", "166.4165894882148`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03556946153593966`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.56275376786472`", ",", "1.7150572909505666`"}], 
              "}"}], ",", 
             RowBox[{"-", "154.01418781107986`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03383326130557584`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.411361324814766`", ",", "1.641264663471477`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.6094163263504`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04027378731028649`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.116889302356681`", ",", "2.756812497992865`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.32001662848245`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.040151370201531866`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.90488330168855`", ",", "2.735726286789342`"}], "}"}],
              ",", 
             RowBox[{"-", "176.21379992706252`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2494415543503198`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.281273842308778`", ",", 
               RowBox[{"-", "1.8821019026795236`"}]}], "}"}], ",", 
             RowBox[{"-", "97.29559664346239`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24882635126203284`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.257770156028219`", ",", 
               RowBox[{"-", "2.0656888230253854`"}]}], "}"}], ",", 
             RowBox[{"-", "97.19117866979059`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06375945841756175`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.093639983498253`", ",", 
               RowBox[{"-", "0.7145902088797783`"}]}], "}"}], ",", 
             RowBox[{"-", "169.5297741600937`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06356053230102765`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.914514873020996`", ",", 
               RowBox[{"-", "0.7476928139270784`"}]}], "}"}], ",", 
             RowBox[{"-", "171.5445853909737`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01862901899980518`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.094872903973718`", ",", 
               RowBox[{"-", "2.6425988951424286`"}]}], "}"}], ",", 
             RowBox[{"-", "127.87161341703548`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018325650740303748`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.951171420434094`", ",", 
               RowBox[{"-", "2.8273803728010924`"}]}], "}"}], ",", 
             RowBox[{"-", "120.72891428954327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.18072776864525777`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.207895388041592`", ",", 
               RowBox[{"-", "3.412112857650837`"}]}], "}"}], ",", 
             RowBox[{"-", "106.21014840322182`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17462954874357203`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.186656610075415`", ",", 
               RowBox[{"-", "3.4851689095687415`"}]}], "}"}], ",", 
             RowBox[{"-", "115.58013876828221`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008924984074536874`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.097702904223805`", ",", "3.381360299048231`"}], 
              "}"}], ",", "91.44640518350201`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008863020427805972`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.09629675294918`", ",", "3.437049686041319`"}], "}"}],
              ",", "96.13907286419816`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030090612121421702`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6408519376863855`", ",", "1.35138276775199`"}], 
              "}"}], ",", "170.49901475124798`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02991307961919179`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5958833832665844`", ",", "1.3589087179036896`"}], 
              "}"}], ",", "166.2846162849951`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23757968272510135`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2698138327236355`", ",", 
               RowBox[{"-", "0.4405777175670541`"}]}], "}"}], ",", 
             RowBox[{"-", "128.81330318893296`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2344716387877651`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.937998642286805`", ",", 
               RowBox[{"-", "0.8530764190411502`"}]}], "}"}], ",", 
             RowBox[{"-", "122.30571876437818`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023925592457177423`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8973613008508083`", ",", 
               RowBox[{"-", "1.124342701262884`"}]}], "}"}], ",", 
             RowBox[{"-", "94.03396872762885`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023766055741274536`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.892751312928141`", ",", 
               RowBox[{"-", "1.1897116440320903`"}]}], "}"}], ",", 
             RowBox[{"-", "98.60910649204439`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008524065674097695`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.3351822088776855`", ",", 
               RowBox[{"-", "1.3548246086900826`"}]}], "}"}], ",", 
             RowBox[{"-", "122.11527497227516`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008468562486519738`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.21139443529494`", ",", 
               RowBox[{"-", "1.5520424102655443`"}]}], "}"}], ",", 
             RowBox[{"-", "117.60966534690901`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012332350126598257`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1941208268320462`", ",", "3.3746548047126277`"}], 
              "}"}], ",", "101.18550012329626`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012259491984874664`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1530100585787526`", ",", "3.5825554779714337`"}], 
              "}"}], ",", "96.96708487893588`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01000549662116167`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6728400483340056`", ",", 
               RowBox[{"-", "0.6450395782798753`"}]}], "}"}], ",", 
             RowBox[{"-", "90.01673477260266`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009872945037530766`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6728293627882644`", ",", 
               RowBox[{"-", "0.6816242794814096`"}]}], "}"}], ",", 
             RowBox[{"-", "83.47290169780094`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00802985974114967`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.291385780639463`", ",", 
               RowBox[{"-", "1.436690548982074`"}]}], "}"}], ",", 
             RowBox[{"-", "90.72318735701245`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008009581870598843`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2897548956541605`", ",", 
               RowBox[{"-", "1.5658933942645108`"}]}], "}"}], ",", 
             RowBox[{"-", "91.35304729242709`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03152656453729881`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.907182003757885`", ",", "3.882611126529649`"}], 
              "}"}], ",", "2.543690062293249`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025818944992908193`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.679674476361992`", ",", "3.916929071821072`"}], 
              "}"}], ",", 
             RowBox[{"-", "13.17785814177143`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012597154305367621`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.841941765830849`", ",", "3.367434628351651`"}], 
              "}"}], ",", 
             RowBox[{"-", "35.460456732844975`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012447299934343995`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.081998778109991`", ",", "3.196453475142506`"}], 
              "}"}], ",", 
             RowBox[{"-", "29.225705314989238`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011004368374155358`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.370656595532074`", ",", "1.2520823986515497`"}], 
              "}"}], ",", 
             RowBox[{"-", "38.238148558599754`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01096704909811298`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.442301448445294`", ",", "1.1956261762702811`"}], 
              "}"}], ",", 
             RowBox[{"-", "40.607587372419204`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.13795903293636302`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.135770010216715`", ",", "3.527245556395318`"}], 
              "}"}], ",", "18.342879512252928`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1342857484716806`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.25819076382651`", ",", "3.567834013922942`"}], "}"}],
              ",", "26.96454811711376`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014459854102961163`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.812765773017162`", ",", 
               RowBox[{"-", "0.10705713229944788`"}]}], "}"}], ",", 
             RowBox[{"-", "15.676723293953211`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013999677330604303`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.898297320087702`", ",", 
               RowBox[{"-", "0.13106147713959804`"}]}], "}"}], ",", 
             RowBox[{"-", "6.494154022295504`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06481621287350493`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.888113141749456`", ",", 
               RowBox[{"-", "0.22169323589710355`"}]}], "}"}], ",", 
             RowBox[{"-", "71.80844955236462`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06463714399228207`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.9413563276372345`", ",", 
               RowBox[{"-", "0.3837138304238663`"}]}], "}"}], ",", 
             RowBox[{"-", "73.18897607761542`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010248633872102194`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.834918368184336`", ",", 
               RowBox[{"-", "0.34814076765746804`"}]}], "}"}], ",", 
             RowBox[{"-", "127.94017581077621`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010095283466440808`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.220197575325882`", ",", 
               RowBox[{"-", "1.1366431247685609`"}]}], "}"}], ",", 
             RowBox[{"-", "121.04426618038063`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04703559253210442`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.319840476503305`", ",", 
               RowBox[{"-", "0.3754533054975368`"}]}], "}"}], ",", 
             RowBox[{"-", "88.0690419850314`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.046203128067370994`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.329960608744796`", ",", 
               RowBox[{"-", "0.6756262338699552`"}]}], "}"}], ",", 
             RowBox[{"-", "95.4563749148177`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03287373702118617`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9646265652922676`", ",", "0.4058709806656777`"}], 
              "}"}], ",", 
             RowBox[{"-", "151.09224225469993`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032787214709693056`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.871601740402528`", ",", "0.35450208351356993`"}], 
              "}"}], ",", 
             RowBox[{"-", "150.05154384481708`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01061281930741165`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1344910450342534`", ",", "2.2090378699962967`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.40363138993385`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010586617895193861`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.605605904911915`", ",", "2.0102812707078206`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.23778215747774`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017466034520592713`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1808192602493235`", ",", "2.3452581568970534`"}], 
              "}"}], ",", "175.85214436041736`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01711559636621599`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1380886835098276`", ",", "2.34835699848299`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.38791267649066`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01815935922186763`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                 "0.`", ",", "0.9999999999999999`", ",", 
                  "167.35910683550452`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.013239309426549`", ",", 
               RowBox[{"-", "0.6172267168862021`"}]}], "}"}], ",", 
             RowBox[{"-", "140.04059446854177`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018110736853952092`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9142006442519786`", ",", 
               RowBox[{"-", "0.7002105201445175`"}]}], "}"}], ",", 
             RowBox[{"-", "138.8692154410246`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012123497845521093`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.640428094261788`", ",", 
               RowBox[{"-", "1.1038480785083356`"}]}], "}"}], ",", 
             RowBox[{"-", "70.74303048240873`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012067911144361454`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.653211682028765`", ",", 
               RowBox[{"-", "1.1404403509867747`"}]}], "}"}], ",", 
             RowBox[{"-", "67.30632488531677`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010633936250374093`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.264465092946304`", ",", "1.5995015474563508`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.23640276494328`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01060386785010563`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1433883712892046`", ",", "1.578667178518207`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.71757399346654`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010578083736072108`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.4640233858549445`", ",", "1.9477339013071668`"}], 
              "}"}], ",", 
             RowBox[{"-", "129.5344530310914`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010506174175654186`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.332146241952127`", ",", "1.7879499890282105`"}], 
              "}"}], ",", 
             RowBox[{"-", "134.16585600410514`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009877563224781047`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.862360376716455`", ",", "1.1678882075169161`"}], 
              "}"}], ",", 
             RowBox[{"-", "72.18663597848182`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009778346537379792`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.880779110920352`", ",", "1.1105665064762662`"}], 
              "}"}], ",", 
             RowBox[{"-", "66.4350248140164`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012581741052048123`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.380816080976115`", ",", 
               RowBox[{"-", "0.003170653943217805`"}]}], "}"}], ",", 
             RowBox[{"-", "120.50455369498104`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012548900588498939`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.29815300656839`", ",", 
               RowBox[{"-", "0.1434792057361047`"}]}], "}"}], ",", 
             RowBox[{"-", "121.47613587551825`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00988167758590537`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8900303313193105`", ",", "1.3625771376378866`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.39319486876022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009821481803894826`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8701993775974306`", ",", "1.3585039727833168`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.08378732793838`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01200788007372809`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9274205586807724`", ",", 
               RowBox[{"-", "1.6459941452217333`"}]}], "}"}], ",", 
             RowBox[{"-", "132.67848058372843`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011948967157664725`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.880748875491625`", ",", 
               RowBox[{"-", "1.6966098945074817`"}]}], "}"}], ",", 
             RowBox[{"-", "136.33025312430456`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011947393963060755`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0824279862392947`", ",", 
               RowBox[{"-", "0.7938827603812862`"}]}], "}"}], ",", 
             RowBox[{"-", "117.74412896953626`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011917947551899127`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0544620146035415`", ",", 
               RowBox[{"-", "0.8470505500838811`"}]}], "}"}], ",", 
             RowBox[{"-", "117.75118376801811`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016976120737314512`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9177412468353956`", ",", 
               RowBox[{"-", "2.1479226278260843`"}]}], "}"}], ",", 
             "179.48271861734622`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01690142703356013`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9031775651540577`", ",", 
               RowBox[{"-", "2.147791139500906`"}]}], "}"}], ",", 
             RowBox[{"-", "177.21456338797933`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011121380246321502`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.071169419359076`", ",", 
               RowBox[{"-", "2.318045595221131`"}]}], "}"}], ",", 
             "169.54790565839377`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011093664199602598`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.914250378235094`", ",", 
               RowBox[{"-", "2.2890980576784323`"}]}], "}"}], ",", 
             "169.1232373987507`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009288963446633084`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.193310352004639`", ",", "1.0700518446392056`"}], 
              "}"}], ",", "75.9033472156233`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009262750743684305`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.207500799389074`", ",", "1.1265603554403336`"}], 
              "}"}], ",", "74.39603890645711`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012472944599581818`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.413118909568857`", ",", "1.5107447399974474`"}], 
              "}"}], ",", "126.54116493391194`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012438560679173198`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.349313759099647`", ",", "1.5968430133600238`"}], 
              "}"}], ",", "125.17430781294563`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08542359141431197`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6249144125819277`", ",", 
               RowBox[{"-", "4.291219948717063`"}]}], "}"}], ",", 
             RowBox[{"-", "139.80617899489658`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08507614425715486`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5146907617059844`", ",", 
               RowBox[{"-", "4.384345781536437`"}]}], "}"}], ",", 
             RowBox[{"-", "136.76700730667335`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013211472192729126`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.616473148431152`", ",", 
               RowBox[{"-", "3.839546036759751`"}]}], "}"}], ",", 
             RowBox[{"-", "150.08973384540337`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013141193910169713`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.580849709699812`", ",", 
               RowBox[{"-", "3.8600389169282856`"}]}], "}"}], ",", 
             RowBox[{"-", "146.18769685554935`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.053134281790179844`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.579937962894859`", ",", 
               RowBox[{"-", "4.3161032824231205`"}]}], "}"}], ",", 
             RowBox[{"-", "85.16864185176969`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.052918151944205384`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.583838827532015`", ",", 
               RowBox[{"-", "4.362254507597883`"}]}], "}"}], ",", 
             RowBox[{"-", "88.20804252094239`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11090223339995614`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.666259953006467`", ",", 
               RowBox[{"-", "4.416423503191367`"}]}], "}"}], ",", 
             RowBox[{"-", "31.853354129374374`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11037993616003676`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.813075213571055`", ",", 
               RowBox[{"-", "4.507642203723091`"}]}], "}"}], ",", 
             RowBox[{"-", "28.33085018556708`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028987793631739634`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.798279980013547`", ",", 
               RowBox[{"-", "4.407131294580484`"}]}], "}"}], ",", 
             "21.46193359302112`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02770677081002304`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.862689890837578`", ",", 
               RowBox[{"-", "4.381808975953809`"}]}], "}"}], ",", 
             "11.204364652735427`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020192140213091986`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.929734262581606`", ",", 
               RowBox[{"-", "3.1213235621942435`"}]}], "}"}], ",", 
             RowBox[{"-", "105.42102772714523`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019363456096660202`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9071799002491305`", ",", 
               RowBox[{"-", "3.203089436157028`"}]}], "}"}], ",", 
             RowBox[{"-", "115.43111338436502`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008170223990989801`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.134348357352752`", ",", "3.424274933828437`"}], 
              "}"}], ",", "146.62699265793316`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008149113919701217`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.103650192613267`", ",", "3.4444959002671793`"}], 
              "}"}], ",", "145.74678265861985`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1665558948911391`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.628548247530289`", ",", 
               RowBox[{"-", "1.346088855764899`"}]}], "}"}], ",", 
             RowBox[{"-", "134.42691259561371`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16608988290248408`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.614717322515146`", ",", 
               RowBox[{"-", "1.3601992666660045`"}]}], "}"}], ",", 
             RowBox[{"-", "132.969484399494`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03576966796814638`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.451625246734025`", ",", "2.8573328742422452`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.52799528595966`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03567219812241412`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.42224035122515`", ",", "2.8539994316229933`"}], 
              "}"}], ",", 
             RowBox[{"-", "172.23566710062843`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032181807683953075`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.234404632860996`", ",", "1.5925539569764573`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.20464484162096`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032035557953147414`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.134558778891135`", ",", "1.5841778176651693`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.79661062428022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0400293251945714`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.604009722506619`", ",", "2.7158150708953386`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.1075832256428`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03982590242782695`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.405039731031097`", ",", "2.7092409194679954`"}], 
              "}"}], ",", "178.13100201502812`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24821266546239837`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.215440038407017`", ",", 
               RowBox[{"-", "2.401181598702991`"}]}], "}"}], ",", 
             RowBox[{"-", "97.08676069611181`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24682851916630746`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.187344793038829`", ",", 
               RowBox[{"-", "2.6271694339600202`"}]}], "}"}], ",", 
             RowBox[{"-", "93.04145951890658`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06336222682338886`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.630380699138552`", ",", 
               RowBox[{"-", "0.7899309361355071`"}]}], "}"}], ",", 
             RowBox[{"-", "173.5593966218541`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06309905247534335`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.345367726580626`", ",", 
               RowBox[{"-", "0.8221047988375817`"}]}], "}"}], ",", 
             RowBox[{"-", "176.66999654252328`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0180272227463565`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.8301339973671515`", ",", 
               RowBox[{"-", "3.0309964858953027`"}]}], "}"}], ",", 
             RowBox[{"-", "113.58621516205113`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01798229336808007`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.78627592501987`", ",", 
               RowBox[{"-", "3.131449517541143`"}]}], "}"}], ",", 
             RowBox[{"-", "114.01216350834807`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16873709847124718`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.104736350691827`", ",", 
               RowBox[{"-", "3.6563018927554336`"}]}], "}"}], ",", 
             RowBox[{"-", "124.9501291333425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1673942821251315`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.968545787671244`", ",", 
               RowBox[{"-", "3.8511629426954896`"}]}], "}"}], ",", 
             RowBox[{"-", "119.86370989240123`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029736594546280398`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3206781979850604`", ",", "1.4260747983155784`"}], 
              "}"}], ",", "162.07021781874224`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029663102732973772`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1758216835623503`", ",", "1.4729453427395387`"}], 
              "}"}], ",", "161.85932572557977`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23140425462825842`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8297096805049433`", ",", 
               RowBox[{"-", "1.02433477027403`"}]}], "}"}], ",", 
             RowBox[{"-", "115.7981343398234`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23060867096257184`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.800016384379107`", ",", 
               RowBox[{"-", "1.0857634080385206`"}]}], "}"}], ",", 
             RowBox[{"-", "113.37413869402823`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023607582821963784`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.860881282240003`", ",", 
               RowBox[{"-", "1.4002161107014388`"}]}], "}"}], ",", 
             RowBox[{"-", "103.18424425645993`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023511201945448527`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.792643879086505`", ",", 
               RowBox[{"-", "1.6915080459494076`"}]}], "}"}], ",", 
             RowBox[{"-", "106.2362620442511`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008413420699703935`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.07555611396809`", ",", 
               RowBox[{"-", "1.8117704305492082`"}]}], "}"}], ",", 
             RowBox[{"-", "113.10405572154288`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008392659555218038`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.035231998209413`", ",", 
               RowBox[{"-", "1.9062904564970764`"}]}], "}"}], ",", 
             RowBox[{"-", "113.24355555374115`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00974214948091065`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6958045992808475`", ",", 
               RowBox[{"-", "0.8824309136322641`"}]}], "}"}], ",", 
             RowBox[{"-", "76.92906862299908`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00971748232989414`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7450952301165734`", ",", 
               RowBox[{"-", "1.0947326431897753`"}]}], "}"}], ",", 
             RowBox[{"-", "76.26557255388754`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021144641997327355`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.834619754427745`", ",", "3.8806501516394767`"}], 
              "}"}], ",", 
             RowBox[{"-", "28.899406345836134`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021063892986337974`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.134549649453645`", ",", "3.7150840089529598`"}], 
              "}"}], ",", 
             RowBox[{"-", "26.081079873094563`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010929856383479403`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.690322061937462`", ",", "0.9829898218117369`"}], 
              "}"}], ",", 
             RowBox[{"-", "42.97702618623881`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010874451028889988`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.7545209504678905`", ",", "0.9231714981215575`"}], 
              "}"}], ",", 
             RowBox[{"-", "46.73070364521987`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013554145426743982`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.085192016271241`", ",", 
               RowBox[{"-", "0.15233612156201284`"}]}], "}"}], ",", 
             "2.688415249362286`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013492646147050695`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.118623229274593`", ",", 
               RowBox[{"-", "0.15076632007160554`"}]}], "}"}], ",", 
             RowBox[{"-", "0.7145037985848365`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06445856982777903`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.023749465279174`", ",", 
               RowBox[{"-", "0.6564234254441896`"}]}], "}"}], ",", 
             RowBox[{"-", "74.569502602867`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06416011546702369`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.086800653178619`", ",", 
               RowBox[{"-", "0.8848543317206131`"}]}], "}"}], ",", 
             RowBox[{"-", "78.03769373191008`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009944227644351244`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.110066133937232`", ",", 
               RowBox[{"-", "1.3196122735009896`"}]}], "}"}], ",", 
             RowBox[{"-", "114.14835654998495`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009909143792764185`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.060689219099167`", ",", 
               RowBox[{"-", "1.4297462813242712`"}]}], "}"}], ",", 
             RowBox[{"-", "116.67307054806113`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04538539706399608`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.311374477317961`", ",", 
               RowBox[{"-", "0.8702033506379357`"}]}], "}"}], ",", 
             RowBox[{"-", "102.84370784460411`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.045248087198569265`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.24895411678124`", ",", 
               RowBox[{"-", "1.1439807200337655`"}]}], "}"}], ",", 
             RowBox[{"-", "100.97231153788428`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032700920121332896`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.568609747241561`", ",", "0.17993281888803214`"}], 
              "}"}], ",", 
             RowBox[{"-", "149.0108454349342`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03242944352826545`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.527798254498685`", ",", "0.1554213130849209`"}], 
              "}"}], ",", 
             RowBox[{"-", "143.8032362085446`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010560481170217254`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.352085693409248`", ",", "1.914169228756334`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.07193292502163`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010165196285888195`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3220548648436976`", ",", "1.9026847111612062`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.77845758014595`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01677218939570061`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9377092946462433`", ",", "2.335707755262018`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.6279697133987`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016726350294304044`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8772032825485674`", ",", "2.323538337846488`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.93978422644588`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.018062244674257`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7009504064931456`", ",", 
               RowBox[{"-", "0.886442425745927`"}]}], "}"}], ",", 
             RowBox[{"-", "137.69783641350745`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01801356295806492`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6416685364883628`", ",", 
               RowBox[{"-", "0.9403888692305328`"}]}], "}"}], ",", 
             RowBox[{"-", "136.47980073474366`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012012579310351976`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.766147741904659`", ",", 
               RowBox[{"-", "1.4105064288629432`"}]}], "}"}], ",", 
             RowBox[{"-", "63.86961928822468`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009876541128831037`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.850274393352393`", ",", 
               RowBox[{"-", "1.582000064127832`"}]}], "}"}], ",", 
             RowBox[{"-", "48.22838847202045`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010573884470912466`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8156411223846534`", ",", "1.5132813511973178`"}], 
              "}"}], ",", 
             RowBox[{"-", "167.19874522198978`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010543648094998134`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6527186743894404`", ",", "1.4762625269830916`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.7807093452752`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01043475345470932`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1875130680893315`", ",", "1.639042991257376`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.7972589771189`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010408644686908277`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.138377464275786`", ",", "1.5960238694596374`"}], 
              "}"}], ",", 
             RowBox[{"-", "139.29268558090277`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009680126447098179`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.977761929985089`", ",", "0.8882111978820659`"}], 
              "}"}], ",", 
             RowBox[{"-", "60.68341364955079`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008708366501372047`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.06130159699868`", ",", "0.7394461874404072`"}], 
              "}"}], ",", 
             RowBox[{"-", "47.43974103561976`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012516145844091615`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.14183109987971`", ",", 
               RowBox[{"-", "0.39881202640755253`"}]}], "}"}], ",", 
             RowBox[{"-", "122.44771805605546`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012258600049010884`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.1216425990063`", ",", 
               RowBox[{"-", "0.4305655282711646`"}]}], "}"}], ",", 
             RowBox[{"-", "114.61212403900429`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009761652713889806`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5939123039010066`", ",", "1.2797169994967676`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.77437978711637`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009728819207225788`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.412278309774798`", ",", "1.2127964730526846`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.11059780907308`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011890343279437995`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6744488706177325`", ",", 
               RowBox[{"-", "1.8935461606096162`"}]}], "}"}], ",", 
             RowBox[{"-", "139.982025664881`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01184455417907567`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6340094531314135`", ",", 
               RowBox[{"-", "1.927500485180183`"}]}], "}"}], ",", 
             RowBox[{"-", "142.83021875742236`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01682706197670141`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6672522571574695`", ",", 
               RowBox[{"-", "2.159269702104077`"}]}], "}"}], ",", 
             RowBox[{"-", "173.9118453933052`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016785584278621882`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4330706213555873`", ",", 
               RowBox[{"-", "2.184247532440832`"}]}], "}"}], ",", 
             RowBox[{"-", "173.86928323225854`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01106601722517766`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.626555883353152`", ",", 
               RowBox[{"-", "2.233817827673968`"}]}], "}"}], ",", 
             "168.69856913910678`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011028382037576908`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.397673717117399`", ",", 
               RowBox[{"-", "2.1880767136477473`"}]}], "}"}], ",", 
             "171.0794074251379`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012404271544239908`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.162346604277734`", ",", "1.862138328747747`"}], 
              "}"}], ",", "123.80745069197906`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01237034459444045`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.162179615633744`", ",", "1.862387703249933`"}], 
              "}"}], ",", "125.12416303689798`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01307128947216959`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.362099643024295`", ",", 
               RowBox[{"-", "4.006547355628791`"}]}], "}"}], ",", 
             RowBox[{"-", "142.28565986569532`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013004965192346592`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.279787419090234`", ",", 
               RowBox[{"-", "4.070198385837125`"}]}], "}"}], ",", 
             RowBox[{"-", "138.5290064789951`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026482358694543965`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.051406858091678`", ",", 
               RowBox[{"-", "4.344427070346459`"}]}], "}"}], ",", 
             "0.9467957124498002`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02639985048466714`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.11099580886446`", ",", 
               RowBox[{"-", "4.343442291022954`"}]}], "}"}], ",", 
             "2.9552706641600928`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018568781122279714`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8268878473143895`", ",", 
               RowBox[{"-", "3.3719473963555866`"}]}], "}"}], ",", 
             RowBox[{"-", "125.44119904158475`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0181734531402836`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.665933962421392`", ",", 
               RowBox[{"-", "3.5980869677647735`"}]}], "}"}], ",", 
             RowBox[{"-", "117.50321543376491`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008128058392218326`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.862323337613243`", ",", "3.6088293415498454`"}], 
              "}"}], ",", "144.86657265930654`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008073324742445615`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.829911836817922`", ",", "3.63163678705379`"}], "}"}],
              ",", "140.26275538881242`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16562517478346214`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.414914889031484`", ",", 
               RowBox[{"-", "1.574690063371122`"}]}], "}"}], ",", 
             RowBox[{"-", "131.51205620337402`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16519836703602336`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.37831481021951`", ",", 
               RowBox[{"-", "1.6160413907100193`"}]}], "}"}], ",", 
             RowBox[{"-", "132.36693852184186`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035574993875200585`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.107906924151698`", ",", "2.811140438077034`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.9433389152969`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.035486848129557`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9126355914282813`", ",", "2.7800145138044243`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.23655391163092`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031889972851997475`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8776235649819144`", ",", "1.547137372789917`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.38857640693905`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0318049566061322`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.603518065205677`", ",", "1.4908146381672884`"}], 
              "}"}], ",", 
             RowBox[{"-", "169.52818464420787`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03962351342375098`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.128791118712853`", ",", "2.7182553933505633`"}], 
              "}"}], ",", "174.36958725569906`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0395238984121437`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9106446064727507`", ",", "2.739761757931408`"}], 
              "}"}], ",", "173.8009426407295`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24545209149716662`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.170792281269932`", ",", 
               RowBox[{"-", "2.938696871178345`"}]}], "}"}], ",", 
             RowBox[{"-", "88.99615834170126`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2426787829787857`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.175387372593446`", ",", 
               RowBox[{"-", "3.200941815523302`"}]}], "}"}], ",", 
             RowBox[{"-", "82.90873642721452`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06283697121920676`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.081982035900316`", ",", 
               RowBox[{"-", "0.837429909266994`"}]}], "}"}], ",", 
             RowBox[{"-", "179.78059646319244`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0616603080326803`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.8549634431669375`", ",", 
               RowBox[{"-", "0.8382992390160692`"}]}], "}"}], ",", 
             "172.66514903429248`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017937475967619666`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.656320172600433`", ",", 
               RowBox[{"-", "3.4231682308452736`"}]}], "}"}], ",", 
             RowBox[{"-", "114.43811185464584`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01778744057656669`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.638641215965254`", ",", 
               RowBox[{"-", "3.462072466565094`"}]}], "}"}], ",", 
             RowBox[{"-", "119.66720399978257`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1660621519633566`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.848439921609096`", ",", 
               RowBox[{"-", "4.060339923633495`"}]}], "}"}], ",", 
             RowBox[{"-", "114.7772906514599`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1655970462999427`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.810830744740259`", ",", 
               RowBox[{"-", "4.141818437470286`"}]}], "}"}], ",", 
             RowBox[{"-", "116.24076906343583`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22981582256798078`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.690471506059175`", ",", 
               RowBox[{"-", "1.3392204971550752`"}]}], "}"}], ",", 
             RowBox[{"-", "110.95014304823353`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2166363620687963`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6285767423124753`", ",", 
               RowBox[{"-", "1.5008821935487953`"}]}], "}"}], ",", 
             RowBox[{"-", "122.10580370393512`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012423645790219824`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.543596105985032`", ",", 
               RowBox[{"-", "1.6363224572962705`"}]}], "}"}], ",", 
             "172.8456907357269`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023415214555781466`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7253197317359628`", ",", 
               RowBox[{"-", "1.9226930520229284`"}]}], "}"}], ",", 
             RowBox[{"-", "109.28827983204253`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023357075642886575`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5646833574010808`", ",", 
               RowBox[{"-", "2.3816995048095375`"}]}], "}"}], ",", 
             RowBox[{"-", "109.63491810460665`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008371949641395121`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9291983209491628`", ",", 
               RowBox[{"-", "2.1531670824734057`"}]}], "}"}], ",", 
             RowBox[{"-", "113.38305538593421`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008273919058432035`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.9174504507025527`", ",", 
               RowBox[{"-", "2.180336851323488`"}]}], "}"}], ",", 
             RowBox[{"-", "119.5725737388855`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009692877636176246`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.81530561668199`", ",", 
               RowBox[{"-", "1.3819969648385397`"}]}], "}"}], ",", 
             RowBox[{"-", "75.60207648477711`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02098345234674483`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.396143214128973`", ",", "3.5870377413582615`"}], 
              "}"}], ",", 
             RowBox[{"-", "23.262753400353123`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020921442860254384`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.403854419465872`", ",", "3.5837227126396174`"}], 
              "}"}], ",", 
             RowBox[{"-", "25.018379710171846`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010819326533738205`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.951636345348979`", ",", "0.7137730150913497`"}], 
              "}"}], ",", 
             RowBox[{"-", "50.484381104200914`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010778340393249044`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.984278723080915`", ",", "0.6741966303886024`"}], 
              "}"}], ",", 
             RowBox[{"-", "53.27373391635643`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06386304300173534`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.140126437614487`", ",", 
               RowBox[{"-", "1.1365465124910128`"}]}], "}"}], ",", 
             RowBox[{"-", "81.50588486095327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06335220939627735`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.14040047723197`", ",", 
               RowBox[{"-", "1.138381443590131`"}]}], "}"}], ",", 
             RowBox[{"-", "76.40477630241244`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009874183719180427`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.941744632947714`", ",", 
               RowBox[{"-", "1.6665184367310864`"}]}], "}"}], ",", 
             RowBox[{"-", "119.19778454613703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009348102033914648`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.700922205001355`", ",", 
               RowBox[{"-", "2.0974585618943045`"}]}], "}"}], ",", 
             RowBox[{"-", "108.30012927132721`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04511119275308724`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1971633524093805`", ",", 
               RowBox[{"-", "1.411110251959242`"}]}], "}"}], ",", 
             RowBox[{"-", "99.10091523116425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0448112476161388`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.171495430089541`", ",", 
               RowBox[{"-", "1.571344055739821`"}]}], "}"}], ",", 
             RowBox[{"-", "94.5341166987728`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03216022068036205`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3141454695633144`", ",", 
               RowBox[{"-", "0.0009303562125356213`"}]}], "}"}], ",", 
             RowBox[{"-", "138.59562698215495`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03162983664470131`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9827536820664209`", ",", 
               RowBox[{"-", "0.29313647247103203`"}]}], "}"}], ",", 
             RowBox[{"-", "131.41590305104853`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016680636473105984`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5359324408170836`", ",", "2.2629931975671616`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.2515987394931`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016638817946494158`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.373788782868912`", ",", "2.2380415331809025`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.72479133641778`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01796501244978937`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3882353982456106`", ",", 
               RowBox[{"-", "1.1810577998572418`"}]}], "}"}], ",", 
             RowBox[{"-", "135.26176505598045`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017916861488427804`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                 "0.`", ",", "0.9999999999999999`", ",", 
                  "167.35910683550452`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3688702250328464`", ",", 
               RowBox[{"-", "1.200246830713806`"}]}], "}"}], ",", 
             RowBox[{"-", "134.08306373894055`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00812032638031625`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.942643768053254`", ",", 
               RowBox[{"-", "1.6854126608445184`"}]}], "}"}], ",", 
             RowBox[{"-", "32.58715765581652`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008074222850921381`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.06431006465274`", ",", 
               RowBox[{"-", "1.7631830852736665`"}]}], "}"}], ",", 
             RowBox[{"-", "28.48774322353844`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010513498181010916`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3269097514349193`", ",", "1.4116366195782286`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.3626734685608`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009425621503675973`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0829310118783844`", ",", "1.3702071945206948`"}], 
              "}"}], ",", "176.27382627041365`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010382601245783043`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.883148682769548`", ",", "1.3764357895408095`"}], 
              "}"}], ",", 
             RowBox[{"-", "139.7881121846881`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010354830967041598`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.852140342572451`", ",", "1.35022068032724`"}], "}"}],
              ",", 
             RowBox[{"-", "140.95179783723307`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01200635379560934`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.048745360448051`", ",", 
               RowBox[{"-", "0.5896979328317056`"}]}], "}"}], ",", 
             RowBox[{"-", "106.77653002195306`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01197293597997323`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.9629454351588285`", ",", 
               RowBox[{"-", "0.8743022802455626`"}]}], "}"}], ",", 
             RowBox[{"-", "108.20266389354039`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009696096136692976`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1178173572235908`", ",", "1.1177483207118895`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.44681583102982`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009659018158444893`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1143800737692033`", ",", "1.1167916407522147`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.62368699860946`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01179894141018357`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4018199732914707`", ",", 
               RowBox[{"-", "2.10354895449524`"}]}], "}"}], ",", 
             RowBox[{"-", "145.67841184996374`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011766564565803052`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.391765974104575`", ",", 
               RowBox[{"-", "2.1104128801252755`"}]}], "}"}], ",", 
             RowBox[{"-", "144.34066184178837`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016744208820579295`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.134775657365511`", ",", 
               RowBox[{"-", "2.2162878220725832`"}]}], "}"}], ",", 
             RowBox[{"-", "173.8267210712033`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016695259721568153`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.86782894591727`", ",", 
               RowBox[{"-", "2.2451615561793226`"}]}], "}"}], ",", 
             RowBox[{"-", "175.52684879678011`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01099087484610312`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.099114995086564`", ",", 
               RowBox[{"-", "2.141213723451201`"}]}], "}"}], ",", 
             "173.4602457111689`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010888310461735268`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.059116012474011`", ",", 
               RowBox[{"-", "2.136628299514328`"}]}], "}"}], ",", 
             "167.91856453310317`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012336510438314416`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.975437887865956`", ",", "2.127856256636735`"}], 
              "}"}], ",", "126.44087538181665`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011830980142825758`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4230846793690546`", ",", "2.8759319963892263`"}], 
              "}"}], ",", "116.43577685165907`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01293897744474587`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.092301143738348`", ",", 
               RowBox[{"-", "4.23590309475546`"}]}], "}"}], ",", 
             RowBox[{"-", "134.77235309229502`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012858589134751576`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.988579227331983`", ",", 
               RowBox[{"-", "4.340452516713437`"}]}], "}"}], ",", 
             RowBox[{"-", "130.4046893146536`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017786541661897512`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.56398960641994`", ",", 
               RowBox[{"-", "3.7938934235005783`"}]}], "}"}], ",", 
             RowBox[{"-", "109.56523182594526`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017742468331167927`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.543285241504151`", ",", 
               RowBox[{"-", "3.852149876543363`"}]}], "}"}], ",", 
             RowBox[{"-", "109.27024440551004`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16477265915068884`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.136185292466732`", ",", 
               RowBox[{"-", "1.8815145244865437`"}]}], "}"}], ",", 
             RowBox[{"-", "133.22182084030968`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.164358864692161`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.080829143176823`", ",", 
               RowBox[{"-", "1.940417865237979`"}]}], "}"}], ",", 
             RowBox[{"-", "133.7745814184609`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035398920786550436`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.652329238880699`", ",", "2.7398869964278223`"}], 
              "}"}], ",", 
             RowBox[{"-", "171.52976890796617`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035258889720509196`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4438157125500233`", ",", "2.7088351887185578`"}], 
              "}"}], ",", 
             RowBox[{"-", "174.47269776577926`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03172016700712219`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.33269357193641`", ",", "1.4407580715476331`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.66779288147734`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03147833208649081`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1302201679194464`", ",", "1.4074849028546426`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.6310032308577`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03942453383644382`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6496634334844873`", ",", "2.7681090417856065`"}], 
              "}"}], ",", "173.232298025758`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03931069464505399`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.451260765305006`", ",", "2.791653704045864`"}], 
              "}"}], ",", "174.86730220412667`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2399368094557239`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.202925738185447`", ",", 
               RowBox[{"-", "3.42230821353291`"}]}], "}"}], ",", 
             RowBox[{"-", "76.82131451272777`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23934541463425085`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.248112007121396`", ",", 
               RowBox[{"-", "3.615283735849963`"}]}], "}"}], ",", 
             RowBox[{"-", "76.85048670504725`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.060505678630209135`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.658065848402106`", ",", 
               RowBox[{"-", "0.8129543347630941`"}]}], "}"}], ",", 
             "165.11089453177738`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06029923664829346`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.424263155239173`", ",", 
               RowBox[{"-", "0.7507918497619795`"}]}], "}"}], ",", 
             "167.5046048570846`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0176386601345717`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.513356881400975`", ",", 
               RowBox[{"-", "3.6820117133582566`"}]}], "}"}], ",", 
             RowBox[{"-", "124.8962961449194`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017426836973892735`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.4472361063926655`", ",", 
               RowBox[{"-", "3.7768066801453966`"}]}], "}"}], ",", 
             RowBox[{"-", "131.15816023743142`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1651332433010769`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.672843912771113`", ",", 
               RowBox[{"-", "4.421741734640321`"}]}], "}"}], ",", 
             RowBox[{"-", "117.70424747541178`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1643827321877667`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.659903152929509`", ",", 
               RowBox[{"-", "4.446385810830566`"}]}], "}"}], ",", 
             RowBox[{"-", "121.1125644498652`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01317946049918434`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6285767423124753`", ",", 
               RowBox[{"-", "1.5008821935487953`"}]}], "}"}], ",", 
             RowBox[{"-", "68.21295879929868`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013146963147281995`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6594651458304117`", ",", 
               RowBox[{"-", "1.5781593961122107`"}]}], "}"}], ",", 
             RowBox[{"-", "68.297756415899`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.20421271627857635`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.543596105985032`", ",", 
               RowBox[{"-", "1.6363224572962705`"}]}], "}"}], ",", 
             RowBox[{"-", "133.26146435963668`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16286185078610396`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3965708830209524`", ",", 
               RowBox[{"-", "1.7925522233475382`"}]}], "}"}], ",", 
             RowBox[{"-", "149.49064758495007`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.032977762641009926`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.279009699303809`", ",", 
               RowBox[{"-", "1.8618269030697097`"}]}], "}"}], ",", 
             "155.88485542772798`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011711175486311043`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3849479729325935`", ",", 
               RowBox[{"-", "1.616409057948625`"}]}], "}"}], ",", 
             "161.69003008002534`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011440152111491957`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.382855125444696`", ",", 
               RowBox[{"-", "1.6157165107911804`"}]}], "}"}], ",", 
             "169.880681147676`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023299081086268443`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.461323438055423`", ",", 
               RowBox[{"-", "2.6714090529866406`"}]}], "}"}], ",", 
             RowBox[{"-", "109.98155637717394`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.023025736618500225`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4057873386829636`", ",", 
               RowBox[{"-", "2.8241461926857054`"}]}], "}"}], ",", 
             RowBox[{"-", "103.78652539232493`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008177036355665052`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.822596609712692`", ",", 
               RowBox[{"-", "2.3474960651091377`"}]}], "}"}], ",", 
             RowBox[{"-", "125.76209209183672`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02085961662179916`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.6717827922214505`", ",", "3.458681008403295`"}], 
              "}"}], ",", 
             RowBox[{"-", "26.77400601999036`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017031190648950163`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.772022016348352`", ",", "3.40810360023285`"}], "}"}],
              ",", 
             RowBox[{"-", "42.556844465222596`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010737509517850274`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.165363385013364`", ",", "0.43148520809964575`"}], 
              "}"}], ",", 
             RowBox[{"-", "56.063086728512204`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010697809466999778`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.203554124833435`", ",", "0.37473041028837395`"}], 
              "}"}], ",", 
             RowBox[{"-", "58.76396375108864`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0628454618938329`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.194207568944458`", ",", 
               RowBox[{"-", "1.3608744551039436`"}]}], "}"}], ",", 
             RowBox[{"-", "71.30366774387154`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06230220432101657`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.280785062159566`", ",", 
               RowBox[{"-", "1.6167105668714303`"}]}], "}"}], ",", 
             RowBox[{"-", "76.62691055040588`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008850049191077075`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.649765790317664`", ",", 
               RowBox[{"-", "2.252140099420774`"}]}], "}"}], ",", 
             RowBox[{"-", "97.4024739965174`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0088175565671167`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.642168701414975`", ",", 
               RowBox[{"-", "2.310614675154861`"}]}], "}"}], ",", 
             RowBox[{"-", "100.07744456431794`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04451329681983375`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.149893895290433`", ",", 
               RowBox[{"-", "1.8437437694677532`"}]}], "}"}], ",", 
             RowBox[{"-", "89.96731816638145`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0443617892119538`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.150028337380061`", ",", 
               RowBox[{"-", "2.0794393420918182`"}]}], "}"}], ",", 
             RowBox[{"-", "87.58332957538543`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01659710425935718`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0947908614681428`", ",", "2.1924778196150227`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.1979839333425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017868839584314972`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1535509058181757`", ",", 
               RowBox[{"-", "1.4225705938373867`"}]}], "}"}], ",", 
             RowBox[{"-", "132.90436242190128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017792015423060425`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "167.35910683550452`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1410113125605466`", ",", 
               RowBox[{"-", "1.4360627430792223`"}]}], "}"}], ",", 
             RowBox[{"-", "129.67801911372118`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010327134965291359`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.651262681609272`", ",", "1.1872731524470477`"}], 
              "}"}], ",", 
             RowBox[{"-", "142.11548348977806`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010296816236058009`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.613254550733855`", ",", "1.1577011222800127`"}], 
              "}"}], ",", 
             RowBox[{"-", "140.39332569565605`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01193961117762166`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.8750291013448415`", ",", 
               RowBox[{"-", "1.1416594337420962`"}]}], "}"}], ",", 
             RowBox[{"-", "109.62879776512695`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011904517772118586`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.862194451580757`", ",", 
               RowBox[{"-", "1.177646071358585`"}]}], "}"}], ",", 
             RowBox[{"-", "107.90068007694306`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011734276564990412`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.122311827895533`", ",", 
               RowBox[{"-", "2.3037455073972075`"}]}], "}"}], ",", 
             RowBox[{"-", "143.00291183361327`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011690882294326037`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0846919533166233`", ",", 
               RowBox[{"-", "2.3320911188318774`"}]}], "}"}], ",", 
             RowBox[{"-", "140.30128444776133`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016646453717660506`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5579443007284106`", ",", 
               RowBox[{"-", "2.269403900700476`"}]}], "}"}], ",", 
             RowBox[{"-", "177.22697652235652`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01659944827306273`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4442099759061167`", ",", 
               RowBox[{"-", "2.2749127608980144`"}]}], "}"}], ",", 
             RowBox[{"-", "178.73801851045937`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010786703185249007`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.862287847875723`", ",", 
               RowBox[{"-", "2.0944986984044083`"}]}], "}"}], ",", 
             "162.37688335503742`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010760097970568731`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6469436431969653`", ",", 
               RowBox[{"-", "2.026091854644832`"}]}], "}"}], ",", 
             "162.48625391239327`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011346165663283178`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.339779505009526`", ",", "3.0434863985286267`"}], 
              "}"}], ",", "106.43067832150163`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011317811409310014`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.315343322038069`", ",", "3.126349591829431`"}], 
              "}"}], ",", "106.9053526400342`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017698504209891105`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.434314923225942`", ",", 
               RowBox[{"-", "4.16383908087726`"}]}], "}"}], ",", 
             RowBox[{"-", "108.97525698507609`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017234324784482932`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.400555111761498`", ",", 
               RowBox[{"-", "4.262022410720735`"}]}], "}"}], ",", 
             RowBox[{"-", "117.55012778563545`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16394610939786583`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.895683725659957`", ",", 
               RowBox[{"-", "2.133657255674023`"}]}], "}"}], ",", 
             RowBox[{"-", "134.32734199661408`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16352832101342266`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.894363137934695`", ",", 
               RowBox[{"-", "2.1350092208711593`"}]}], "}"}], ",", 
             RowBox[{"-", "135.06630534645882`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03511941258941911`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1602250446055833`", ",", "2.681392119152333`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.4156266235926`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033099505557120684`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.088276325440507`", ",", "2.678144610161838`"}], 
              "}"}], ",", 
             RowBox[{"-", "166.2496710463285`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03123834091809515`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.861739231903491`", ",", "1.3869725520795433`"}], 
              "}"}], ",", "179.40578641976188`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02894387027297956`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8189310068960913`", ",", "1.3874165313898386`"}], 
              "}"}], ",", 
             RowBox[{"-", "168.5441300187184`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039197184166783514`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1468993997360766`", ",", "2.818992318919108`"}], 
              "}"}], ",", "176.50230638249553`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.038985020101843765`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.859142571987567`", ",", "2.8365806538130016`"}], 
              "}"}], ",", 
             RowBox[{"-", "179.54267546271095`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23875547747921777`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.319354478030785`", ",", 
               RowBox[{"-", "3.9202359941616067`"}]}], "}"}], ",", 
             RowBox[{"-", "76.87965889736674`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2375123194526273`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.361110025060112`", ",", 
               RowBox[{"-", "4.099381638041829`"}]}], "}"}], ",", 
             RowBox[{"-", "80.71607075150101`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06009349903484142`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.144075751525485`", ",", 
               RowBox[{"-", "0.6886994227943991`"}]}], "}"}], ",", 
             "169.89831518239194`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.059642794307125366`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.915434832123526`", ",", 
               RowBox[{"-", "0.647965335292557`"}]}], "}"}], ",", 
             "174.8143208613902`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017217557603448272`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.301047359768452`", ",", 
               RowBox[{"-", "3.944042993187486`"}]}], "}"}], ",", 
             RowBox[{"-", "137.42002432994332`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015802974506275023`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1473790497722725`", ",", 
               RowBox[{"-", "4.085249162367698`"}]}], "}"}], ",", 
             RowBox[{"-", "149.8895395832615`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013114545925964711`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7823370711004873`", ",", 
               RowBox[{"-", "1.8868877195185065`"}]}], "}"}], ",", 
             RowBox[{"-", "68.38255403250794`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013078439761677923`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9520001666773728`", ",", 
               RowBox[{"-", "2.3150268609912428`"}]}], "}"}], ",", 
             RowBox[{"-", "69.74132129700955`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.041350865492472015`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3965708830209524`", ",", 
               RowBox[{"-", "1.7925522233475382`"}]}], "}"}], ",", 
             RowBox[{"-", "111.09533382294144`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04055729127874689`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3818224814643028`", ",", 
               RowBox[{"-", "1.8307828693178243`"}]}], "}"}], ",", 
             RowBox[{"-", "103.46808515232895`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12988408814509395`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.279009699303809`", ",", 
               RowBox[{"-", "1.8618269030697097`"}]}], "}"}], ",", 
             RowBox[{"-", "165.71983081026315`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.12955305318067176`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.183786388996578`", ",", 
               RowBox[{"-", "1.8860639242246482`"}]}], "}"}], ",", 
             RowBox[{"-", "164.9792585302121`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026300122521132445`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.154464827177917`", ",", 
               RowBox[{"-", "1.8060757775677903`"}]}], "}"}], ",", 
             "139.6556722024149`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025668947877907827`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9635584338880692`", ",", 
               RowBox[{"-", "1.6439212922441218`"}]}], "}"}], ",", 
             "131.35408411266502`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011175400837179281`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1992812968316877`", ",", 
               RowBox[{"-", "1.582953166762202`"}]}], "}"}], ",", 
             "178.0713322153267`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01112239553128573`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1201065284469833`", ",", 
               RowBox[{"-", "1.5802870100530664`"}]}], "}"}], ",", 
             "174.52628133584943`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022755599023903672`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.351553571969628`", ",", 
               RowBox[{"-", "3.045170916975937`"}]}], "}"}], ",", 
             RowBox[{"-", "97.5914944074759`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022691519711564332`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.337120111113439`", ",", 
               RowBox[{"-", "3.153467306216698`"}]}], "}"}], ",", 
             RowBox[{"-", "99.08662760799609`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013905406804924856`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.877126940960202`", ",", "3.311600672087688`"}], 
              "}"}], ",", 
             RowBox[{"-", "58.33968291045474`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013865737655638305`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.954147366881353`", ",", "3.186700566472998`"}], 
              "}"}], ",", 
             RowBox[{"-", "59.9085520865083`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06176364285165033`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.333292854791026`", ",", 
               RowBox[{"-", "1.8375753072924508`"}]}], "}"}], ",", 
             RowBox[{"-", "81.95015335694022`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.060065185511272545`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.37502059150578`", ",", 
               RowBox[{"-", "2.132620862057291`"}]}], "}"}], ",", 
             RowBox[{"-", "90.67223365155886`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008785183238607578`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.586852865388811`", ",", 
               RowBox[{"-", "2.621865656387353`"}]}], "}"}], ",", 
             RowBox[{"-", "102.75241513211876`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008763250208185996`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.5283406794940015`", ",", 
               RowBox[{"-", "2.8804016821273737`"}]}], "}"}], ",", 
             RowBox[{"-", "103.21009831957046`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04421079728268869`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1633437138595895`", ",", 
               RowBox[{"-", "2.3949405336234557`"}]}], "}"}], ",", 
             RowBox[{"-", "85.19934098438942`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04408637587737085`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.177189268849019`", ",", 
               RowBox[{"-", "2.5598001098368637`"}]}], "}"}], ",", 
             RowBox[{"-", "83.7077208799835`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010266586517508204`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.34950135708816`", ",", "0.9394537482734076`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.67116790153403`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010220902427665947`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.308246115973363`", ",", "0.9031733340704978`"}], 
              "}"}], ",", 
             RowBox[{"-", "135.33155903012968`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011869527514623546`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.778138158256813`", ",", 
               RowBox[{"-", "1.4378788033585193`"}]}], "}"}], ",", 
             RowBox[{"-", "106.17256238876003`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011838149682084834`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.730084543669796`", ",", 
               RowBox[{"-", "1.6035765617551552`"}]}], "}"}], ",", 
             RowBox[{"-", "107.24814675477587`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010733558377184975`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3899699046641167`", ",", 
               RowBox[{"-", "1.9450005602570204`"}]}], "}"}], ",", 
             "162.59562446974914`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01070710151021494`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.876920695888101`", ",", 
               RowBox[{"-", "1.784177655015215`"}]}], "}"}], ",", 
             "162.55853056603502`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011289528013082296`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2238502271956717`", ",", "3.427387713933632`"}], 
              "}"}], ",", "107.38002695856831`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01123257182359135`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.164101554416602`", ",", "3.6182791304508584`"}], 
              "}"}], ",", "103.64115734723856`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1631115972906224`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7055343143627244`", ",", 
               RowBox[{"-", "2.3234015063995175`"}]}], "}"}], ",", 
             RowBox[{"-", "135.80526869630256`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1627092163903207`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6126373039872774`", ",", 
               RowBox[{"-", "2.4137232822676298`"}]}], "}"}], ",", 
             RowBox[{"-", "135.68383961901284`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03119577428399096`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.892263836527015`", ",", "2.630179466514019`"}], 
              "}"}], ",", 
             RowBox[{"-", "155.08371546906463`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031059387794138946`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.656542139953466`", ",", "2.52067965515237`"}], "}"}],
              ",", 
             RowBox[{"-", "158.3654603124171`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02681792956212341`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6407767730931617`", ",", "1.3513135172147952`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.49404645719878`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02674474298628302`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4100475676243165`", ",", "1.2509610945770788`"}], 
              "}"}], ",", 
             RowBox[{"-", "157.7962310661119`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.038774004425274476`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.597929550289893`", ",", "2.8344956544945057`"}], 
              "}"}], ",", 
             RowBox[{"-", "175.5876573079176`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02733474697376804`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4952292852444606`", ",", "2.826571044663803`"}], 
              "}"}], ",", "166.37915769543096`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008064403268104786`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.358105900150826`", ",", "2.859797487829117`"}], 
              "}"}], ",", "113.60011120122442`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05919546989100458`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6767553638289288`", ",", 
               RowBox[{"-", "0.6263039518208819`"}]}], "}"}], ",", 
             "179.73032654038838`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05889722832488268`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.660707579059717`", ",", 
               RowBox[{"-", "0.6262284193186336`"}]}], "}"}], ",", 
             "175.99564479156146`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01450461261683035`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.017777290759835`", ",", 
               RowBox[{"-", "4.160408289752661`"}]}], "}"}], ",", 
             RowBox[{"-", "162.3590548365797`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01446619739916272`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.871824473011491`", ",", 
               RowBox[{"-", "4.206822074429016`"}]}], "}"}], ",", 
             RowBox[{"-", "161.2690356676432`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01304243300267034`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.068991289281188`", ",", 
               RowBox[{"-", "2.631997311602204`"}]}], "}"}], ",", 
             RowBox[{"-", "71.10008856151065`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012912891969377635`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.084678752134776`", ",", 
               RowBox[{"-", "2.677816872230564`"}]}], "}"}], ",", 
             RowBox[{"-", "65.38056039857949`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03977894673494984`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3331305227023598`", ",", 
               RowBox[{"-", "2.0340983190730886`"}]}], "}"}], ",", 
             RowBox[{"-", "95.84083648171661`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039673570314835725`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.328960687100035`", ",", 
               RowBox[{"-", "2.0748605967363356`"}]}], "}"}], ",", 
             RowBox[{"-", "96.93250633761616`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022627620845288635`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.289440215654356`", ",", 
               RowBox[{"-", "3.451588365206402`"}]}], "}"}], ",", 
             RowBox[{"-", "100.58176080851631`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022560469168505248`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.265160825292077`", ",", 
               RowBox[{"-", "3.581552939267163`"}]}], "}"}], ",", 
             RowBox[{"-", "98.80484189090893`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013826181673943847`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.103699191777398`", ",", "2.928621355054173`"}], 
              "}"}], ",", 
             RowBox[{"-", "61.47742126256186`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013790079556213985`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.12458174917919`", ",", "2.890196586484368`"}], "}"}],
              ",", 
             RowBox[{"-", "60.50264155119739`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05841343456973877`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.372609199076223`", ",", 
               RowBox[{"-", "2.338139090646819`"}]}], "}"}], ",", 
             RowBox[{"-", "99.39431394617743`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05826750875932775`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.328067160359495`", ",", 
               RowBox[{"-", "2.6073615446193075`"}]}], "}"}], ",", 
             RowBox[{"-", "99.86301893224791`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008741371935623231`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.455915662084558`", ",", 
               RowBox[{"-", "3.1889427043325047`"}]}], "}"}], ",", 
             RowBox[{"-", "103.66778150702376`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008695149140509732`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.424566515033717`", ",", 
               RowBox[{"-", "3.317857071873617`"}]}], "}"}], ",", 
             RowBox[{"-", "99.78400931937425`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04396230462828299`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.2141051080821414`", ",", 
               RowBox[{"-", "2.8945932194192343`"}]}], "}"}], ",", 
             RowBox[{"-", "82.21610077557686`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04385305370694658`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.240643944512358`", ",", 
               RowBox[{"-", "3.0887371814349898`"}]}], "}"}], ",", 
             RowBox[{"-", "82.58250731217989`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010175421622144257`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.102079489920942`", ",", "0.6993790946992785`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.99195015872561`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010149253843155022`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.087892909975138`", ",", "0.6836188491282627`"}], 
              "}"}], ",", 
             RowBox[{"-", "131.15721049647004`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011806854798793563`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.648066431511518`", ",", 
               RowBox[{"-", "1.8677482212282193`"}]}], "}"}], ",", 
             RowBox[{"-", "108.32373112079138`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011452211919860853`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.633457387841712`", ",", 
               RowBox[{"-", "1.9118605919964782`"}]}], "}"}], ",", 
             RowBox[{"-", "99.32459987501026`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010680709856083492`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.5598910142943008`", ",", 
               RowBox[{"-", "1.6845745240638166`"}]}], "}"}], ",", 
             "162.52143666230126`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010558094981586623`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3957522094877737`", ",", 
               RowBox[{"-", "1.632889265754243`"}]}], "}"}], ",", 
             "168.65435785904953`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16230782812568448`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3922309432078155`", ",", 
               RowBox[{"-", "2.628930241020917`"}]}], "}"}], ",", 
             RowBox[{"-", "135.5624105417201`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16188751415535485`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.373086493082613`", ",", 
               RowBox[{"-", "2.647702492049789`"}]}], "}"}], ",", 
             RowBox[{"-", "136.4636425842942`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030923597579745426`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4021847771895124`", ",", "2.4197950374793806`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.64720515577002`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02982057945656011`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2508515589624474`", ",", "2.369591616676134`"}], 
              "}"}], ",", 
             RowBox[{"-", "152.0977754492438`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026671756137825423`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.109843693225373`", ",", "1.128427125877418`"}], 
              "}"}], ",", 
             RowBox[{"-", "159.09841567502446`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026571964416807037`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1045353568776313`", ",", "1.1263999011482146`"}], 
              "}"}], ",", 
             RowBox[{"-", "156.35407905482958`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011439257451506436`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4952292852444606`", ",", "2.826571044663803`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.8749808070138`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011394453687226162`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3308064325818236`", ",", "2.763043043820169`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.7830606392799`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019270343705663242`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.358105900150826`", ",", "2.859797487829117`"}], 
              "}"}], ",", "148.34597269877995`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019172075462033394`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.158132977113625`", ",", "2.9830817346584992`"}], 
              "}"}], ",", "152.1181011742073`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.058600489374280605`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.380318304137456`", ",", 
               RowBox[{"-", "0.6066002737367311`"}]}], "}"}], ",", 
             "172.26096304273455`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05828746212156104`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1133430358425915`", ",", 
               RowBox[{"-", "0.5703185624998235`"}]}], "}"}], ",", 
             "168.34618953240005`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014427883923540014`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.566101814353904`", ",", 
               RowBox[{"-", "4.310487669884657`"}]}], "}"}], ",", 
             RowBox[{"-", "160.17901649870606`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012398625647326524`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.446348884020257`", ",", 
               RowBox[{"-", "4.35365092609602`"}]}], "}"}], ",", 
             RowBox[{"-", "145.55702961899175`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012784637573271645`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.186830152915206`", ",", 
               RowBox[{"-", "2.9007350279240947`"}]}], "}"}], ",", 
             RowBox[{"-", "59.66103223564833`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012617007760862888`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.333988727489665`", ",", 
               RowBox[{"-", "3.1521740169841297`"}]}], "}"}], ",", 
             RowBox[{"-", "66.17514382514165`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039568473042130674`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2886130596423895`", ",", 
               RowBox[{"-", "2.406696796436617`"}]}], "}"}], ",", 
             RowBox[{"-", "98.02417619351606`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03946908602100868`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.269709177066505`", ",", 
               RowBox[{"-", "2.5407943245044953`"}]}], "}"}], ",", 
             RowBox[{"-", "97.46866441758438`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.022493516776822393`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.21414977933437`", ",", 
               RowBox[{"-", "3.9108801651768457`"}]}], "}"}], ",", 
             RowBox[{"-", "97.02792297330095`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02223493310608651`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1878751517765105`", ",", 
               RowBox[{"-", "4.124011085105019`"}]}], "}"}], ",", 
             RowBox[{"-", "90.89104619931001`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05812194749420158`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.264249979302264`", ",", 
               RowBox[{"-", "2.9744161410151913`"}]}], "}"}], ",", 
             RowBox[{"-", "100.3317239183184`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.057829600887681694`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.230821166008036`", ",", 
               RowBox[{"-", "3.1577858296872368`"}]}], "}"}], ",", 
             RowBox[{"-", "96.60220801850853`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008649170763183722`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.380694900367936`", ",", 
               RowBox[{"-", "3.572269944766505`"}]}], "}"}], ",", 
             RowBox[{"-", "95.90023713172455`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043744074285567106`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.2846673386373135`", ",", 
               RowBox[{"-", "3.42689019718041`"}]}], "}"}], ",", 
             RowBox[{"-", "82.94891384878488`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043624030622833515`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3101931958713955`", ",", 
               RowBox[{"-", "3.633260269225098`"}]}], "}"}], ",", 
             RowBox[{"-", "84.28708417557984`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010123153358935738`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8723596812644248`", ",", "0.43704591406790944`"}], 
              "}"}], ",", 
             RowBox[{"-", "130.3224708342145`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01009043382390742`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.8163508583297476`", ",", "0.37105506085661005`"}], 
              "}"}], ",", 
             RowBox[{"-", "128.15217443686078`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011108221460536992`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.609319392222294`", ",", 
               RowBox[{"-", "2.0588667500189346`"}]}], "}"}], ",", 
             RowBox[{"-", "90.32546862922905`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011071264259578377`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.607990499786304`", ",", 
               RowBox[{"-", "2.292803609693519`"}]}], "}"}], ",", 
             RowBox[{"-", "88.03382784593904`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010436887729583996`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1864040273262773`", ",", 
               RowBox[{"-", "1.5908839168081363`"}]}], "}"}], ",", 
             "174.78727905579777`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010389989784159245`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.116943046812807`", ",", 
               RowBox[{"-", "1.584546922441695`"}]}], "}"}], ",", 
             "171.41583588962368`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16146828863427443`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.135354215431099`", ",", 
               RowBox[{"-", "2.873588876929993`"}]}], "}"}], ",", 
             RowBox[{"-", "137.3648746268687`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16106976677838786`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1291590347370537`", ",", 
               RowBox[{"-", "2.8792926509807226`"}]}], "}"}], ",", 
             RowBox[{"-", "137.21426682780537`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011349825404379212`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.107523011322846`", ",", "2.6895580339560903`"}], 
              "}"}], ",", 
             RowBox[{"-", "164.69114047154616`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010277417254604973`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9715389495919409`", ",", "2.652334402765798`"}], 
              "}"}], ",", 
             RowBox[{"-", "151.68486151311876`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05797610697195857`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8546878672361986`", ",", 
               RowBox[{"-", "0.5169710757238604`"}]}], "}"}], ",", 
             "164.43141602206532`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.057693255181950016`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.7081137701951414`", ",", 
               RowBox[{"-", "0.4761334728962817`"}]}], "}"}], ",", 
             "168.06559373047196`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01245157587967019`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4218536151488363`", ",", 
               RowBox[{"-", "3.351156547170038`"}]}], "}"}], ",", 
             RowBox[{"-", "72.68925541463484`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012394992483478704`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.4253620668364504`", ",", 
               RowBox[{"-", "3.362413453139368`"}]}], "}"}], ",", 
             RowBox[{"-", "69.28136973321689`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.039369948637520094`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2269974575965636`", ",", 
               RowBox[{"-", "2.866598855823816`"}]}], "}"}], ",", 
             RowBox[{"-", "96.91315264165009`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03909782909135094`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2005832540538934`", ",", 
               RowBox[{"-", "3.084454745644393`"}]}], "}"}], ",", 
             RowBox[{"-", "92.23342555929034`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.057538724750442846`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.200425868156623`", ",", 
               RowBox[{"-", "3.420396074804406`"}]}], "}"}], ",", 
             RowBox[{"-", "92.87269211869868`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05718265653137244`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.189281402749307`", ",", 
               RowBox[{"-", "3.642485901268315`"}]}], "}"}], ",", 
             RowBox[{"-", "88.5167206216064`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.043504316387141154`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.340524913380642`", ",", 
               RowBox[{"-", "3.9364533047015757`"}]}], "}"}], ",", 
             RowBox[{"-", "85.62525450237504`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04262623936684563`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.354799821483549`", ",", 
               RowBox[{"-", "4.123047464971758`"}]}], "}"}], ",", 
             RowBox[{"-", "93.40299656995415`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01005782004327544`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6277582609737444`", ",", "0.1309845474264109`"}], 
              "}"}], ",", 
             RowBox[{"-", "125.98187803950674`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01002689046088073`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5846098472847885`", ",", "0.0715563325483261`"}], 
              "}"}], ",", 
             RowBox[{"-", "127.93035635427199`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011034430015720277`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.6188993657553175`", ",", 
               RowBox[{"-", "2.610571620417632`"}]}], "}"}], ",", 
             RowBox[{"-", "85.74218706264918`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010937699242241987`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.621906511845788`", ",", 
               RowBox[{"-", "2.650963131536688`"}]}], "}"}], ",", 
             RowBox[{"-", "91.10544582544853`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16067222851916274`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.8747270856212968`", ",", 
               RowBox[{"-", "3.114781565921408`"}]}], "}"}], ",", 
             RowBox[{"-", "137.06365902874688`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1602489253146359`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.838082340362363`", ",", 
               RowBox[{"-", "3.148877303266252`"}]}], "}"}], ",", 
             RowBox[{"-", "136.01498285876502`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05741178335929856`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.4233374609525127`", ",", 
               RowBox[{"-", "0.41594306614899723`"}]}], "}"}], ",", 
             "171.6997714388788`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.056936823920177744`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3635825394116026`", ",", 
               RowBox[{"-", "0.40722552239788085`"}]}], "}"}], ",", 
             "166.50216130116522`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012338666217850892`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5187321549010875`", ",", 
               RowBox[{"-", "3.6092674409253935`"}]}], "}"}], ",", 
             RowBox[{"-", "65.87348405179902`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01161965895953892`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.66216580349884`", ",", 
               RowBox[{"-", "3.929519671680314`"}]}], "}"}], ",", 
             RowBox[{"-", "77.085689757564`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03882759039720142`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.19117527744928`", ",", 
               RowBox[{"-", "3.3256825326061277`"}]}], "}"}], ",", 
             RowBox[{"-", "87.55369847693062`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03873154493018055`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2006771023350336`", ",", 
               RowBox[{"-", "3.5480932227332427`"}]}], "}"}], ",", 
             RowBox[{"-", "87.31076295692564`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05682879177748452`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.195899279209828`", ",", 
               RowBox[{"-", "3.8980626220087173`"}]}], "}"}], ",", 
             RowBox[{"-", "84.16074912451386`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05666664760788331`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.216390756546161`", ",", 
               RowBox[{"-", "4.098432075737106`"}]}], "}"}], ",", 
             RowBox[{"-", "82.59106386890582`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009996055992443423`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.3955428969268873`", ",", 
               RowBox[{"-", "0.17104557766406175`"}]}], "}"}], ",", 
             RowBox[{"-", "129.87883466903742`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009969678396836617`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.386058930047751`", ",", 
               RowBox[{"-", "0.1823967932116381`"}]}], "}"}], ",", 
             RowBox[{"-", "130.94025086195933`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010841816436671809`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.617583509206603`", ",", 
               RowBox[{"-", "2.8749985982825743`"}]}], "}"}], ",", 
             RowBox[{"-", "96.46870458824797`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010658158601366319`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.610183188278267`", ",", 
               RowBox[{"-", "2.940267322267495`"}]}], "}"}], ",", 
             RowBox[{"-", "89.21037858885515`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15982673733459185`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6159504524003254`", ",", 
               RowBox[{"-", "3.3632753449875312`"}]}], "}"}], ",", 
             RowBox[{"-", "134.96630668878316`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15939074054648214`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.610911570792706`", ",", 
               RowBox[{"-", "3.368320156404455`"}]}], "}"}], ",", 
             RowBox[{"-", "133.6667253740382`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05646579375229029`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1264231119612176`", ",", 
               RowBox[{"-", "0.3502980429841255`"}]}], "}"}], ",", 
             "161.30455116345155`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.05524930315696491`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1230759113004076`", ",", 
               RowBox[{"-", "0.3491653743978561`"}]}], "}"}], ",", 
             "169.27828118798516`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010942550187528316`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.70053918451893`", ",", 
               RowBox[{"-", "4.096874564738043`"}]}], "}"}], ",", 
             RowBox[{"-", "88.29789546332887`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010898277795699938`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.702257626811304`", ",", 
               RowBox[{"-", "4.154703283557864`"}]}], "}"}], ",", 
             RowBox[{"-", "85.27689174478681`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03863573704503487`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2155922311191225`", ",", 
               RowBox[{"-", "3.8656354417860164`"}]}], "}"}], ",", 
             RowBox[{"-", "87.0678274369207`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03853247656745058`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.228243500126284`", ",", 
               RowBox[{"-", "4.112630251758305`"}]}], "}"}], ",", 
             RowBox[{"-", "88.22599782084951`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009943370406437158`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1814876357625916`", ",", 
               RowBox[{"-", "0.4182253843986803`"}]}], "}"}], ",", 
             RowBox[{"-", "132.00166705488087`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00987278893074765`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.157010076547749`", ",", 
               RowBox[{"-", "0.4454088774003837`"}]}], "}"}], ",", 
             RowBox[{"-", "136.75863469103018`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010477611886846358`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.612659338632755`", ",", 
               RowBox[{"-", "3.1199280820686464`"}]}], "}"}], ",", 
             RowBox[{"-", "81.95205258946237`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010355146338043755`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.613883624297096`", ",", 
               RowBox[{"-", "3.128586745291935`"}]}], "}"}], ",", 
             RowBox[{"-", "88.1364090506651`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1589559331288271`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3994172582498967`", ",", 
               RowBox[{"-", "3.5898937933800235`"}]}], "}"}], ",", 
             RowBox[{"-", "132.36714405929274`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.158449817778772`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.357224672434786`", ",", 
               RowBox[{"-", "3.6361538172685215`"}]}], "}"}], ",", 
             RowBox[{"-", "134.47245563534466`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009802708466737973`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.9759563094528474`", ",", 
               RowBox[{"-", "0.6156758306537146`"}]}], "}"}], ",", 
             RowBox[{"-", "141.51560232717964`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009778520280707782`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.898480630675166`", ",", 
               RowBox[{"-", "0.6772683293156354`"}]}], "}"}], ",", 
             RowBox[{"-", "141.37900915184113`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010234112204224405`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.620701540397806`", ",", 
               RowBox[{"-", "3.3381284650382446`"}]}], "}"}], ",", 
             RowBox[{"-", "94.32076551186775`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009714020314729989`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.617152559466575`", ",", 
               RowBox[{"-", "3.3851007019041273`"}]}], "}"}], ",", 
             RowBox[{"-", "83.58691029157379`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15794531389890568`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1468082288758534`", ",", 
               RowBox[{"-", "3.850481151304229`"}]}], "}"}], ",", 
             RowBox[{"-", "136.5777672113959`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1575484884853253`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.132850973422473`", ",", 
               RowBox[{"-", "3.8636901345735404`"}]}], "}"}], ",", 
             RowBox[{"-", "136.01845501868604`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00975439177903375`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.672209777524318`", ",", 
               RowBox[{"-", "0.858033741578869`"}]}], "}"}], ",", 
             RowBox[{"-", "141.24241597650266`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00972977672635962`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.6138631964053385`", ",", 
               RowBox[{"-", "0.9048745229806487`"}]}], "}"}], ",", 
             RowBox[{"-", "140.62204477765187`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009220359205758574`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.630213745123582`", ",", 
               RowBox[{"-", "3.5013041336861583`"}]}], "}"}], ",", 
             RowBox[{"-", "72.85305507127984`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009196715279504124`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.660778854575984`", ",", 
               RowBox[{"-", "3.600368690908474`"}]}], "}"}], ",", 
             RowBox[{"-", "73.65891354466358`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009705223789379826`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3384123243514687`", ",", 
               RowBox[{"-", "1.1309549887150265`"}]}], "}"}], ",", 
             RowBox[{"-", "140.00167357880048`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009675060194578883`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.315348086617261`", ",", 
               RowBox[{"-", "1.1503070340854382`"}]}], "}"}], ",", 
             RowBox[{"-", "138.0043379773409`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009173131983777866`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.757251316699107`", ",", 
               RowBox[{"-", "3.9294027223609964`"}]}], "}"}], ",", 
             RowBox[{"-", "74.46477201804777`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008477358699008812`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "116.97237085078373`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.818098322848967`", ",", 
               RowBox[{"-", "4.148287247464208`"}]}], "}"}], ",", 
             RowBox[{"-", "62.295357561168856`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009644990347482377`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0918985495275626`", ",", 
               RowBox[{"-", "1.3514712695253897`"}]}], "}"}], ",", 
             RowBox[{"-", "136.0070023758813`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009619770402865472`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.083749471856234`", ",", 
               RowBox[{"-", "1.3593388178846615`"}]}], "}"}], ",", 
             RowBox[{"-", "135.02022438370295`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.25210800679539547`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             "1.7667114977152143`", ",", "167.19899911042882`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2508384402129281`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.7737198649463215`", ",", 
               RowBox[{"-", "0.07722951543100699`"}]}], "}"}], ",", 
             RowBox[{"-", "169.62953444217587`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24399111906604629`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.7672930323709903`", ",", "0.004669646611714488`"}], 
              "}"}], ",", "179.63900122860838`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24281264740012035`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.7661119968940817`", ",", 
               RowBox[{"-", "0.006264234149068747`"}]}], "}"}], ",", 
             RowBox[{"-", "179.87969435115326`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24931985845250892`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3675489352810515`", ",", "0.11310424430511475`"}], 
              "}"}], ",", "171.53659394767965`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24086346391192495`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.850524420653777`", ",", 
               RowBox[{"-", "0.5013247962187429`"}]}], "}"}], ",", 
             RowBox[{"-", "158.7766183606123`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23369156789924644`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9375366706374482`", ",", "0.3992115048105958`"}], 
              "}"}], ",", "171.54545878873466`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.24520328198809632`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.842422203976989`", ",", 
               RowBox[{"-", "0.4570800530492261`"}]}], "}"}], ",", 
             RowBox[{"-", "159.81093338390926`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06057624519092128`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1679364592479047`", ",", "0.7873630095557195`"}], 
              "}"}], ",", 
             RowBox[{"-", "173.3423143741775`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07670595478336543`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1968282486405424`", ",", 
               RowBox[{"-", "1.5843271908251064`"}]}], "}"}], ",", 
             RowBox[{"-", "160.80160284612302`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013440267656036283`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9265945208348418`", ",", 
               RowBox[{"-", "0.5911279665573725`"}]}], "}"}], ",", 
             RowBox[{"-", "116.79242119114255`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19755853436454543`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8849683746156314`", ",", "0.8698811764446064`"}], 
              "}"}], ",", "175.70325589077552`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.22777152927111408`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.981736479233178`", ",", "2.1791356728325355`"}], 
              "}"}], ",", "147.40289286443442`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01238178954365232`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0330784063531713`", ",", 
               RowBox[{"-", "2.120040053223454`"}]}], "}"}], ",", 
             RowBox[{"-", "126.8430528526034`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21212186112314835`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.871705955361084`", ",", 
               RowBox[{"-", "2.579383011099843`"}]}], "}"}], ",", 
             RowBox[{"-", "96.01093114529128`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015042604907991313`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8907195989671668`", ",", "1.684804414747426`"}], 
              "}"}], ",", "116.07243510518562`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01321490144109207`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8604948557158172`", ",", 
               RowBox[{"-", "0.18781759303254186`"}]}], "}"}], ",", 
             RowBox[{"-", "106.08752007802445`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008710703712198769`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0670908527082337`", ",", 
               RowBox[{"-", "0.6339946714700225`"}]}], "}"}], ",", 
             RowBox[{"-", "158.70801140681021`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21194901949479275`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.82287096155126`", ",", "1.0079416589077277`"}], 
              "}"}], ",", "155.66758974549973`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07180781634103656`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.382099314299674`", ",", "0.22347529134967298`"}], 
              "}"}], ",", 
             RowBox[{"-", "11.58920984041727`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.21674958435278577`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8528470577585507`", ",", 
               RowBox[{"-", "1.17291256256883`"}]}], "}"}], ",", 
             RowBox[{"-", "158.74341700013886`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008724005044455016`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.410142819605809`", ",", "3.6812770041790377`"}], 
              "}"}], ",", "42.920489432787356`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01863151469667742`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1531498249152365`", ",", "3.3914826324245704`"}], 
              "}"}], ",", "52.03908644320149`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2503182207593463`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.841612151678042`", ",", 
               RowBox[{"-", "2.4839424729838475`"}]}], "}"}], ",", 
             RowBox[{"-", "129.67564620180644`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010397071340990218`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.34571974139002`", ",", "2.320663474652185`"}], "}"}],
              ",", "18.781044632081063`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.5475511541848186`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.371022184652178`", ",", 
               RowBox[{"-", "0.3716808198235361`"}]}], "}"}], ",", 
             RowBox[{"-", "1.7010497306758807`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.06269067518534704`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0921927069666446`", ",", "0.3256054024297014`"}], 
              "}"}], ",", 
             RowBox[{"-", "170.46963822372692`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010374915291683382`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.18705552402088`", ",", "0.7293805768078586`"}], 
              "}"}], ",", 
             RowBox[{"-", "162.20150130961`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009154747018122682`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.074965366139089`", ",", 
               RowBox[{"-", "0.7819802989291605`"}]}], "}"}], ",", 
             RowBox[{"-", "168.32975361736854`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "70.51767649597501`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.279619357017198`", ",", "2.3844659508650694`"}], 
              "}"}], ",", "36.74070172982526`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0875835243348965`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.353376858084014`", ",", "1.4486758481567938`"}], 
              "}"}], ",", "1.1181155326338097`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.1653661208978088`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.471556087494077`", ",", "1.3036155224815655`"}], 
              "}"}], ",", 
             RowBox[{"-", "62.46777552842411`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08025236492921935`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.18182694304322`", ",", "0.5465277883779298`"}], 
              "}"}], ",", 
             RowBox[{"-", "30.25790849158597`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010862216620351466`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.40513098295746`", ",", 
               RowBox[{"-", "1.2478631540215561`"}]}], "}"}], ",", 
             "10.228600196743807`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16858614175314884`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8631456608056345`", ",", 
               RowBox[{"-", "1.9991716919118454`"}]}], "}"}], ",", 
             RowBox[{"-", "153.7169805874081`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013624201370336193`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0003485458539485`", ",", "3.6568472194308046`"}], 
              "}"}], ",", "96.67863059996351`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09730877095902937`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.347403889598631`", ",", "0.3164039243675053`"}], 
              "}"}], ",", "54.94048896942712`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "5.069397672552881`"}], 
               ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.33682100981092`", ",", 
               RowBox[{"-", "2.372116296911316`"}]}], "}"}], ",", 
             RowBox[{"-", "35.05779980214282`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.042739110560332604`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.311903601845028`", ",", 
               RowBox[{"-", "1.6379705011059962`"}]}], "}"}], ",", 
             "63.845781030320474`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035978520662323245`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.336491908698271`", ",", 
               RowBox[{"-", "1.3533739219868754`"}]}], "}"}], ",", 
             RowBox[{"-", "69.51925275688477`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11722278060440564`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.468165047516123`", ",", "1.3220799330813995`"}], 
              "}"}], ",", "71.78179179291755`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2847796251139698`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.454284569695465`", ",", 
               RowBox[{"-", "0.7830988991393053`"}]}], "}"}], ",", 
             RowBox[{"-", "59.03799924851048`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08034998488806841`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.192257270270463`", ",", "1.011642970905468`"}], 
              "}"}], ",", "20.76949309882005`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013809689753066571`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.822712616640818`", ",", 
               RowBox[{"-", "1.146059333803818`"}]}], "}"}], ",", 
             RowBox[{"-", "169.82710906060004`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08938541161846728`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.11164321715692`", ",", 
               RowBox[{"-", "2.5383145838870496`"}]}], "}"}], ",", 
             "10.615315504023455`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013134417381011775`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.45538678793015`", ",", 
               RowBox[{"-", "0.7653751126454883`"}]}], "}"}], ",", 
             "41.3205880712183`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020847260454136658`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.367052651840087`", ",", "0.14943348693084343`"}], 
              "}"}], ",", "10.471700321505581`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17658619051611493`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.295863451371103`", ",", "3.872524143458744`"}], 
              "}"}], ",", "77.77122083177879`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00942103932641719`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.825246023854241`", ",", "3.9303156676656474`"}], 
              "}"}], ",", "55.5366776364981`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009086340261723959`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.43413732121714`", ",", 
               RowBox[{"-", "0.8473346537407715`"}]}], "}"}], ",", 
             RowBox[{"-", "39.937119490377775`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "3.7198225580499793`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.942088537623861`", ",", "3.6182506337634655`"}], 
              "}"}], ",", "76.1082747508538`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.17255297843795475`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.469682112473555`", ",", "1.3151141464055818`"}], 
              "}"}], ",", 
             RowBox[{"-", "20.07144595354387`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017394438873931734`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.114318319292503`", ",", 
               RowBox[{"-", "4.651750633423436`"}]}], "}"}], ",", 
             RowBox[{"-", "67.4791011217079`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008453759448249396`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8170903467914052`", ",", "1.5473035894966969`"}], 
              "}"}], ",", 
             RowBox[{"-", "148.60770976803934`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01299763426657872`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.779063316539821`", ",", 
               RowBox[{"-", "0.9682283827490923`"}]}], "}"}], ",", 
             "176.7970196467942`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02090861580665654`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.397117182488653`", ",", 
               RowBox[{"-", "0.1252058009954891`"}]}], "}"}], ",", 
             "75.92000345633994`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10706041730862778`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8258596958523285`", ",", "1.0332433360189008`"}], 
              "}"}], ",", "151.96825943476807`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015718216196931555`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.996997111901896`", ",", "3.6103894700818837`"}], 
              "}"}], ",", "89.70021374110082`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07710030357132663`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.576370351743306`", ",", "3.840641917987641`"}], 
              "}"}], ",", "80.4659366752344`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.41562285305397206`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.5651883069599`", ",", "3.6848540105536114`"}], "}"}],
              ",", "110.99009657013657`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015482629958930077`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.1726285273595956`", ",", "3.9255726373682482`"}], 
              "}"}], ",", "99.19538077198547`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.014867180537842278`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.557058154927904`", ",", "3.6857111952687807`"}], 
              "}"}], ",", "105.74495295415792`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02287202886569785`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.000414990405947`", ",", 
               RowBox[{"-", "4.159206389957394`"}]}], "}"}], ",", 
             RowBox[{"-", "64.25150799376473`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00842876023869091`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.021738605429321`", ",", "3.6895005923389186`"}], 
              "}"}], ",", "75.53844922356132`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.3528603025861492`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.11741073100309`", ",", "3.1862318942371473`"}], 
              "}"}], ",", "136.55457447579917`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018253914323597284`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.28456357642351`", ",", "1.882574819793523`"}], "}"}],
              ",", "73.38421102169585`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008202692387136062`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.893635248830319`", ",", "3.7624543145467406`"}], 
              "}"}], ",", "87.5750655627184`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009085943876305364`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.057522303906609`", ",", "3.7785231599775653`"}], 
              "}"}], ",", "137.81216205136357`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.27038197838035677`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.393442965850957`", ",", 
               RowBox[{"-", "2.303851857405552`"}]}], "}"}], ",", 
             RowBox[{"-", "63.172783169485044`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.26727178874055074`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.202642609176679`", ",", "0.8816321711879552`"}], 
              "}"}], ",", 
             RowBox[{"-", "161.80630800772565`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.191341619086145`"}], 
               ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.377435097169095`", ",", "3.658150991890274`"}], 
              "}"}], ",", "54.905275495172546`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.018028563397250823`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.345897813530606`", ",", "3.806407466702233`"}], 
              "}"}], ",", "115.00436901058066`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00825072265202851`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8591223699710941`", ",", 
               RowBox[{"-", "0.379751604104828`"}]}], "}"}], ",", 
             "156.09585739832232`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07691633247592052`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.370476193877607`", ",", "3.3020565011722733`"}], 
              "}"}], ",", "3.8124368001543103`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07364704065544961`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.6634007260393116`", ",", "3.889464890278438`"}], 
              "}"}], ",", "156.8983931945971`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07771978843336844`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1664863383255795`", ",", "1.7124017880902116`"}], 
              "}"}], ",", "148.1069428824405`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00869048902662272`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1688661246212564`", ",", "3.9136726985842807`"}], 
              "}"}], ",", "117.74270855290527`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011845081965868559`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.057599674808473`", ",", 
               RowBox[{"-", "3.732319033051137`"}]}], "}"}], ",", 
             RowBox[{"-", "151.0347873065779`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01005472558477097`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.939751687198152`", ",", "2.8785860260273344`"}], 
              "}"}], ",", 
             RowBox[{"-", "152.21821476068007`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009108008077500871`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.3669117145038703`", ",", "3.764223584864702`"}], 
              "}"}], ",", "78.27105632132013`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0188568828218138`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.7735416284485892`", ",", 
               RowBox[{"-", "1.0338422441077806`"}]}], "}"}], ",", 
             RowBox[{"-", "165.16616260351088`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008049888409401629`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.957214733053927`", ",", "3.6183783225821378`"}], 
              "}"}], ",", "76.70395218288492`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.015479012753830191`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.988617948777935`", ",", 
               RowBox[{"-", "4.710701163914752`"}]}], "}"}], ",", 
             RowBox[{"-", "69.45336317899522`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.034133503291260255`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.249413289851313`", ",", "3.865881414191816`"}], 
              "}"}], ",", "101.77827846184863`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.2859832372995041`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1854391618308204`", ",", "3.917440606065164`"}], 
              "}"}], ",", "123.89155302375207`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.030368714105124362`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.6447050878359932`", ",", "3.7340071536615724`"}], 
              "}"}], ",", "119.54139812096562`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.09322966793809642`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.666413661944249`", ",", "3.8758765752816933`"}], 
              "}"}], ",", "65.00140177912648`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019165915001405957`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7945631340613906`", ",", "3.9404978394038013`"}], 
              "}"}], ",", "10.461405437286924`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02295444258858553`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.0875717529220807`", ",", "3.857537429702332`"}], 
              "}"}], ",", "156.31117257920042`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1455889529665632`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.866738553866757`", ",", "1.6632737373389903`"}], 
              "}"}], ",", 
             RowBox[{"-", "177.91870435236493`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012103611224886438`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9255244467780555`", ",", "0.4850253643387584`"}], 
              "}"}], ",", "172.7278583728955`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1755309911382409`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.1545226228344525`", ",", "3.848702210669975`"}], 
              "}"}], ",", "127.40368667441064`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.19937205813226602`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9002821581533915`", ",", "2.948691825759078`"}], 
              "}"}], ",", "167.84852153664048`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011376249882806836`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.145218465973057`", ",", "3.002605801682305`"}], 
              "}"}], ",", 
             RowBox[{"-", "0.32761315955869674`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010369009586280703`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9254498630377734`", ",", "0.4847035724536128`"}], 
              "}"}], ",", "163.66295609730378`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011308330064175354`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.464967287231055`", ",", 
               RowBox[{"-", "2.8252742464879286`"}]}], "}"}], ",", 
             RowBox[{"-", "49.45804328804603`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.035451583665520314`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.705414945740973`", ",", "3.888998368063742`"}], 
              "}"}], ",", "100.43156992117854`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008784173128675054`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.88750394744357`", ",", "3.8598451511704264`"}], 
              "}"}], ",", "57.408387001115486`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03510472341432141`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.928757673475447`", ",", "3.59616286765204`"}], "}"}],
              ",", "50.20533251589817`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00860646001683766`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8999957360474449`", ",", "1.691340859919253`"}], 
              "}"}], ",", "115.60300927498879`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03164313229320953`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.315560330733823`", ",", "3.842826281431774`"}], 
              "}"}], ",", "25.114529103220054`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.020565684496185017`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.089830620806531`", ",", "3.644610377272796`"}], 
              "}"}], ",", "141.05358797235212`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07950243014446738`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8184609758976726`", ",", 
               RowBox[{"-", "0.1543466785264378`"}]}], "}"}], ",", 
             RowBox[{"-", "163.3400000305147`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1523541855084696`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8925223693054563`", ",", 
               RowBox[{"-", "3.0614739192830824`"}]}], "}"}], ",", 
             RowBox[{"-", "149.45964116780254`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04044297839734489`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.735202566971461`", ",", "3.941086772914109`"}], 
              "}"}], ",", "117.12592401488814`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.046418863892723754`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.5490640983277992`", ",", "3.6362395798778353`"}], 
              "}"}], ",", "120.08965598555879`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0314479105128328`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.35458679363506`", ",", "0.12765032623837`"}], "}"}], 
             ",", 
             RowBox[{"-", "40.67917961595703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008569221334538671`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.133292155381548`", ",", "3.839095338540685`"}], 
              "}"}], ",", "92.36321961749675`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.033810148026422675`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.816528145569681`", ",", 
               RowBox[{"-", "4.383112257242901`"}]}], "}"}], ",", 
             RowBox[{"-", "114.92239308583001`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.11461909881547977`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.750818439690522`", ",", 
               RowBox[{"-", "4.419688470805187`"}]}], "}"}], ",", 
             RowBox[{"-", "109.63836857289277`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017805985599295766`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.166895214856064`", ",", 
               RowBox[{"-", "3.0588244373516718`"}]}], "}"}], ",", 
             RowBox[{"-", "23.366767260611834`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "1.1403741893515447`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.624661889022492`", ",", "3.837040565238847`"}], 
              "}"}], ",", "114.8518755604965`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008186074095058088`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.882779322650426`", ",", "3.811935048904515`"}], 
              "}"}], ",", "39.80730471363811`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02740152175722202`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.475677707174433`", ",", "3.668722634526091`"}], 
              "}"}], ",", "80.200821722627`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2370612963924621`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8654612149900247`", ",", "0.8885482619526972`"}], 
              "}"}], ",", 
             RowBox[{"-", "166.2736217610478`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.2867185637790726`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.905450895359237`", ",", "2.9302119632853034`"}], 
              "}"}], ",", 
             RowBox[{"-", "176.15936861482984`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.07606481930067648`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.001820259253169`", ",", "0.8322686305099309`"}], 
              "}"}], ",", 
             RowBox[{"-", "144.38405735783746`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028024213040754323`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.553007083039228`", ",", "3.824253879775438`"}], 
              "}"}], ",", "163.2892128621183`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0361092550172754`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8717760217040529`", ",", 
               RowBox[{"-", "3.596276373248007`"}]}], "}"}], ",", 
             RowBox[{"-", "149.23338054128817`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00914123005986919`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.277153594740588`", ",", 
               RowBox[{"-", "1.8841482342927005`"}]}], "}"}], ",", 
             RowBox[{"-", "29.03312205700166`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15887861318462476`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.78884187988963`", ",", "3.9356753447342863`"}], 
              "}"}], ",", "124.20085891368073`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01687145370879416`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.7936828751715794`", ",", "0.0789026636679371`"}], 
              "}"}], ",", "168.1292475964825`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013463621197105787`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.7818741487236447`", ",", 
               RowBox[{"-", "1.0752584328605608`"}]}], "}"}], ",", 
             "178.3720720924594`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008801486977194652`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.07115545095173`", ",", "3.6707940629447973`"}], 
              "}"}], ",", "100.83174054489427`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012187064280882806`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1227029962502155`", ",", "3.8305644736481965`"}], 
              "}"}], ",", "92.74866963457558`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012299228214542272`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.27378532912938`", ",", "3.089154647252922`"}], "}"}],
              ",", 
             RowBox[{"-", "22.99095389713344`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.13071026853977363`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.495946585525004`", ",", "3.6887914096803205`"}], 
              "}"}], ",", "35.58621672197445`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.01188857371649193`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8756163776684474`", ",", 
               RowBox[{"-", "1.1869631499097286`"}]}], "}"}], ",", 
             RowBox[{"-", "117.75823856665497`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00923661201086145`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.300156147257562`", ",", "1.4583259666974322`"}], 
              "}"}], ",", "72.88873059729019`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.08473011028721002`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.2909883109441656`", ",", 
               RowBox[{"-", "4.5946589053852165`"}]}], "}"}], ",", 
             RowBox[{"-", "133.7278356184503`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0527029012314148`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"7.592086742145651`", ",", 
               RowBox[{"-", "4.625886100022921`"}]}], "}"}], ",", 
             RowBox[{"-", "91.24744319011555`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.10986009869390606`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.074781152017092`", ",", 
               RowBox[{"-", "4.648738151644846`"}]}], "}"}], ",", 
             RowBox[{"-", "24.808346241759477`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.029589792549295744`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8240741026616254`", ",", "1.588190619940066`"}], 
              "}"}], ",", "161.64843363241732`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013431425908291657`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "0.9999999999999999`", ",", "180.`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.417195633114394`", ",", 
               RowBox[{"-", "0.1544898434743955`"}]}], "}"}], ",", 
             RowBox[{"-", "4.117422846532065`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009784707142137649`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", 
                  RowBox[{"-", "138.3679760955136`"}]}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2076719681319608`", ",", "1.8799915918934478`"}], 
              "}"}], ",", 
             RowBox[{"-", "178.4849822352703`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.02631759933666217`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.470391685845325`", ",", 
               RowBox[{"-", "4.324888481466`"}]}], "}"}], ",", 
             "4.963745615870568`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008018959664387442`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.636771330728353`", ",", "3.7921973243101887`"}], 
              "}"}], ",", "135.65893811831836`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.031108199664232762`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8423080769447733`", ",", 
               RowBox[{"-", "0.45235163317290616`"}]}], "}"}], ",", 
             RowBox[{"-", "124.23617911994208`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.00802838107645152`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.282380208947151`", ",", 
               RowBox[{"-", "1.8815251178425596`"}]}], "}"}], ",", 
             RowBox[{"-", "24.388328791260378`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.008450312084613576`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.900105784987952`", ",", "1.382113841150748`"}], 
              "}"}], ",", "162.91032600938826`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009622081966793348`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8238439393769457`", ",", "1.0202765181166027`"}], 
              "}"}], ",", 
             RowBox[{"-", "158.8005581661891`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.012778700267654632`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.815103198866747`", ",", 
               RowBox[{"-", "4.5442523639535395`"}]}], "}"}], ",", 
             RowBox[{"-", "126.03702553701217`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.16363563205894352`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.515057093215638`", ",", 
               RowBox[{"-", "4.686380860885859`"}]}], "}"}], ",", 
             RowBox[{"-", "124.52088142431859`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010658256200097168`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.353958111122084`", ",", "0.12673605509693064`"}], 
              "}"}], ",", 
             RowBox[{"-", "61.464840773665365`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0165971042593572`"}],
                ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "132.56507968104114`"}], 
                 "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.0375417428426617`", ",", "2.1825871052305135`"}], 
              "}"}], ",", "154.5701194401237`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.017715521554756614`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                 "0.`", ",", "0.9999999999999999`", ",", 
                  "167.35910683550452`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9679775262061567`", ",", 
               RowBox[{"-", "1.6446457138116022`"}]}], "}"}], ",", 
             RowBox[{"-", "126.45167580554087`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011647648499061757`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8478535170951083`", ",", 
               RowBox[{"-", "2.5287092081334865`"}]}], "}"}], ",", 
             RowBox[{"-", "137.5996570619094`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.0165525755601482`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.1147820855425192`", ",", 
               RowBox[{"-", "2.2821698249394347`"}]}], "}"}], ",", 
             "179.75093950143753`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.016782319412679363`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"6.302464808170437`", ",", 
               RowBox[{"-", "4.450050301458311`"}]}], "}"}], ",", 
             RowBox[{"-", "126.12499858619478`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.23627563433252427`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.412962572471049`", ",", 
               RowBox[{"-", "4.416584131883879`"}]}], "}"}], ",", 
             RowBox[{"-", "84.55248260563498`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{"Intensity", "\[RuleDelayed]", "0.1292228619235062`"}],
                ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8575330775666872`", ",", 
               RowBox[{"-", "1.973609833425109`"}]}], "}"}], ",", 
             RowBox[{"-", "164.238686250161`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.025052920747016295`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8331971455187728`", ",", 
               RowBox[{"-", "1.49581634012526`"}]}], "}"}], ",", 
             "123.0524960229152`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011069641631359073`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.847484571749867`", ",", 
               RowBox[{"-", "1.5541627057341192`"}]}], "}"}], ",", 
             "170.98123045637232`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.011175902980703164`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.101985669129406`", ",", "3.8742308283456834`"}], 
              "}"}], ",", "99.90228773590891`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.013754071706224509`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.301227485802736`", ",", "2.5779427149896432`"}], 
              "}"}], ",", 
             RowBox[{"-", "59.527861839832894`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.028756905040941163`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.105089716554118`", ",", "2.2924074478347602`"}], 
              "}"}], ",", 
             RowBox[{"-", "142.5483457427178`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.026472546064063754`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8227355325169223`", ",", "1.0030155268912893`"}], 
              "}"}], ",", 
             RowBox[{"-", "153.60974243463457`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.019074308332854527`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9620053601186829`", ",", "3.0868466436547135`"}], 
              "}"}], ",", "155.89022964963465`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010654779228694138`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"4.30456992408814`", ",", 
               RowBox[{"-", "4.450885268302151`"}]}], "}"}], ",", 
             RowBox[{"-", "130.93504273927766`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.021979322092558224`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.1843017802244207`", ",", 
               RowBox[{"-", "4.353766402763522`"}]}], "}"}], ",", 
             RowBox[{"-", "84.75416942531919`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010343302573710479`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8429277720194244`", ",", 
               RowBox[{"-", "1.5431834720036013`"}]}], "}"}], ",", 
             "168.04439272344925`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009306337468812365`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8126837753289176`", ",", "2.5667455556332626`"}], 
              "}"}], ",", 
             RowBox[{"-", "138.6785825546915`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.04176588516850442`"}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"5.3435873933583835`", ",", 
               RowBox[{"-", "4.311607522435026`"}]}], "}"}], ",", 
             RowBox[{"-", "101.18073863753324`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.056504966068771215`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"8.2637206997027`", ",", 
               RowBox[{"-", "4.46240798472222`"}]}], "}"}], ",", 
             RowBox[{"-", "81.02137861329751`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.054059020452650715`"}], ",", 
               
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.9247809079917395`", ",", 
               RowBox[{"-", "0.31161928865510713`"}]}], "}"}], ",", 
             "177.25201121251865`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.010854184525250454`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"3.7259065841173045`", ",", 
               RowBox[{"-", "4.4409374302681215`"}]}], "}"}], ",", 
             RowBox[{"-", "82.25588802624462`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.03842949207078567`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2.2382741906794665`", ",", 
               RowBox[{"-", "4.436492633377812`"}]}], "}"}], ",", 
             RowBox[{"-", "89.38416820477865`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.15715266006497608`"}], ",", 
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.892191514199834`", ",", 
               RowBox[{"-", "4.095942514368096`"}]}], "}"}], ",", 
             RowBox[{"-", "135.45914282597485`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"Optica`Optica`Private`HeldRay", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Ray", "[", 
              RowBox[{
               RowBox[{
               "Intensity", "\[RuleDelayed]", "0.009594616403945098`"}], ",", 
               
               RowBox[{"Polarization", "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{"0.`", ",", "1.`", ",", "180.`"}], "}"}]}], ",", 
               RowBox[{"RaySlot", "\[RuleDelayed]", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1.8626583431103891`", ",", 
               RowBox[{"-", "1.5802739192837725`"}]}], "}"}], ",", 
             RowBox[{"-", "134.03344639152346`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm]}], "]"}], ",", 
     RowBox[{"Optica`Optica`Private`HeldList", "[", 
      RowBox[{
       RowBox[{"Optica`Optica`Private`HeldList", "[", "]"}], ",", 
       RowBox[{"Optica`Optica`Private`HeldList", "[", 
        TagBox[
         RowBox[{"Optica`Optica`Private`HeldSource", "[", 
          StyleBox[
           TagBox[
            RowBox[{"Move", "[", 
             RowBox[{
              RowBox[{"SingleRay", "[", 
               RowBox[{"IntrinsicMedium", "\[Rule]", "1.34`"}], "]"}], ",", 
              RowBox[{"-", "2.`"}]}], "]"}],
            HoldForm],
           FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
         DisplayForm], "]"}]}], "]"}], ",", 
     RowBox[{"Optica`Optica`Private`HeldList", "[", 
      RowBox[{
       TagBox[
        RowBox[{"HeldComponent", "[", 
         StyleBox[
          TagBox[
           RowBox[{"RemoveSurface", "[", 
            RowBox[{
             RowBox[{"RodLens", "[", 
              RowBox[{"1", ",", "1", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"FresnelReflections", "\[Rule]", "True"}], ",", 
                 RowBox[{"ComponentMedium", "\[Rule]", "1.48`"}]}], "}"}]}], 
              "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", "5"}], "}"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm], ",", 
       TagBox[
        RowBox[{"HeldComponent", "[", 
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"ClearBoundary", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "5"}], ",", 
                 RowBox[{"-", "5"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"9", ",", "5", ",", "5"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.75`", ",", 
               RowBox[{"-", "0.4`"}]}], "}"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]], "]"}],
        DisplayForm]}], "]"}], ",", "\<\"-held optics graphics-\"\>"}], 
    "]"}]}],
  SequenceForm["No changes to numeric parameters have been made for ", 
   Hold[
    Optica`Optica`Private`HeldList[
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {-1.9999999999999996`, 0., 0.}, 
      Optica`Optica`RayEnd :> {1.7667114977152143`, 0., 0.}, 
      RotationMatrix :> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 100., 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      3.766711497715214, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 5.047393406938387, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05573880608888074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 4, 
      Optica`Optica`IntersectionNumber :> 1, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {1., 0., 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7667114977152143`, 0., 0.}, 
      Optica`Optica`RayEnd :> {2.150842225822762, -0.004073940169013586, 0.}, 
      RotationMatrix :> {{0.9999437652765565, -0.010605012236808924`, 0.}, {
       0.010605012236808924`, 0.9999437652765565, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.74789199320458, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.38415233080763067`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      5.61593885653368, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.408646719457491, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 4, 
      Optica`Optica`IntersectionNumber :> 2, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999437652765565, -0.010605012236808924`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.150842225822762, -0.004073940169013586, 0.},
       Optica`Optica`RayEnd :> {1.7737198649463215`, -0.07722951543100699, 
       0.}, RotationMatrix :> {{-0.9817000461342819, -0.19043376649100038`, 
       0.}, {0.19043376649100038`, -0.9817000461342819, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2514724223244908, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3841523308076281, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 6.18448430612897, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14427332443753854`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 4, 
      Optica`Optica`IntersectionNumber :> 3, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9817000461342819, -0.19043376649100038`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.150842225822762, -0.004073940169013586, 0.},
       Optica`Optica`RayEnd :> {2.313846576425795, -0.007531849809321051, 0.},
       RotationMatrix :> {{0.9997750674309145, -0.021208831733746873`, 0.}, {
       0.021208831733746873`, 0.9997750674309145, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.49641957088005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16304102383939145`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      5.834413828478465, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.013044597128339214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 8, 
      Optica`Optica`IntersectionNumber :> 3, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9997750674309145, -0.021208831733746873`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.313846576425795, -0.007531849809321051, 0.},
       Optica`Optica`RayEnd :> {2.6587982155668994`, -0.015008885084780993`, 
       0.}, RotationMatrix :> {{0.9997651668322586, -0.021670514273228633`, 
       0.}, {0.021670514273228633`, 0.9997651668322586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.25118366957307, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3450326642546253, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      6.345062171575311, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42863540965260527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 8, 
      Optica`Optica`IntersectionNumber :> 4, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9997651668322586, -0.021670514273228633`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6587982155668994`, -0.015008885084780993`, 
       0.}, Optica`Optica`RayEnd :> {2.3137939589293546`, -0.010581436087871, 
       0.}, RotationMatrix :> {{-0.9999176668761433, 0.012831970580161198`, 
       0.}, {-0.012831970580161198`, -0.9999176668761433, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24463145094031025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34503266425462553`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      6.855710514672157, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.00420613976960598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 8, 
      Optica`Optica`IntersectionNumber :> 5, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999176668761433, 0.012831970580161198`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.313846576425795, -0.007531849809321053, 0.},
       Optica`Optica`RayEnd :> {2.1506905823677744`, -0.002476657692228986, 
       0.}, RotationMatrix :> {{-0.9995203474979495, 0.030968935041074536`, 
       0.}, {-0.030968935041074536`, -0.9995203474979495, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24523590130695874`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16323428979354024`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.053147776801809, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40623824978740386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 4, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9995203474979495, 0.030968935041074536`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1506905823677744`, -0.0024766576922289896`, 
       0.}, 
      Optica`Optica`RayEnd :> {1.7672930323709903`, 0.004669646611714488, 0.},
       RotationMatrix :> {{-0.9998263314404735, 0.018636173380943626`, 
       0.}, {-0.018636173380943626`, -0.9998263314404735, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24461271838368367`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.38346414566259146`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      6.620674712382444, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06783244622635987, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 5, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9998263314404735, 0.018636173380943626`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6587982155668994`, -0.015008885084780998`, 
       0.}, Optica`Optica`RayEnd :> {2.88220483912467, -0.019954574845912905`,
        0.}, RotationMatrix :> {{0.9997550530348914, -0.022132192191499464`, 
       0.}, {0.022132192191499464`, 0.9997550530348914, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      99.00655221863269, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22346135973965783`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.644500393626452, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07815640850299857, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 12, 
      Optica`Optica`IntersectionNumber :> 5, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9997550530348914, -0.022132192191499464`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.88220483912467, -0.01995457484591291, 0.}, 
      Optica`Optica`RayEnd :> {3.203448398313732, -0.03118806463673083, 0.}, 
      RotationMatrix :> {{0.9993891529748828, -0.03494740213729931, 0.}, {
       0.03494740213729931, 0.9993891529748828, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      98.75435028932107, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32143990980171855`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.120231460132995, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40963882827172354`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 12, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9993891529748828, -0.03494740213729931, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.203448398313732, -0.03118806463673083, 0.}, 
      Optica`Optica`RayEnd :> {2.8890066728387804`, -0.09789651158066667, 0.},
       RotationMatrix :> {{-0.9782286389668182, -0.20753006988175557`, 0.}, {
       0.20753006988175557`, -0.9782286389668182, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2515594888698206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32143990980171844`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.595962526639538, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1625187257260004, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 12, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9782286389668182, -0.20753006988175557`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3137939589293546`, -0.010581436087871, 0.}, 
      Optica`Optica`RayEnd :> {2.1511871633859885`, -0.008419595868123391, 
       0.}, RotationMatrix :> {{-0.9999116346018719, 0.01329371986362917, 
       0.}, {-0.01329371986362917, -0.9999116346018719, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24402849040546773`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.162621165627411, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.0736228766128875`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41504764644609426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999116346018719, 0.01329371986362917, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1511871633859885`, -0.008419595868123391, 
       0.}, Optica`Optica`RayEnd :> {
       1.7661119968940817`, -0.006264234149068746, 0.}, 
      RotationMatrix :> {{-0.9999843357680084, 0.00559716165704483, 
       0.}, {-0.00559716165704483, -0.9999843357680084, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24341980978631647`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3850811984931353, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.6435430503827275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03951543849063535, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 11, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999843357680084, 0.00559716165704483, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.88220483912467, -0.019954574845912905`, 0.},
       Optica`Optica`RayEnd :> {2.6470204120697653`, 0.05068334347140578, 0.},
       RotationMatrix :> {{-0.9577336678208785, 0.2876564296558782, 
       0.}, {-0.2876564296558782, -0.9577336678208785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25220192931161994`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2455634953191293, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.973555477354085, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3125031565382293, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9577336678208785, 0.2876564296558782, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6470204120697653`, 0.05068334347140578, 0.},
       Optica`Optica`RayEnd :> {2.3675489352810515`, 0.11310424430511475`, 
       0.}, RotationMatrix :> {{-0.9759527129068826, 0.21798234371089836`, 
       0.}, {-0.21798234371089836`, -0.9759527129068826, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2507567532837804, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28635760021231554`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.397364725668313, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36267791665571997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9759527129068826, 0.21798234371089836`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.203448398313732, -0.03118806463673083, 0.}, 
      Optica`Optica`RayEnd :> {3.289988407633029, -0.03532566548370465, 0.}, 
      RotationMatrix :> {{0.9988589898270124, -0.04775686800618502, 0.}, {
       0.04775686800618502, 0.9988589898270124, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      98.50279080045121, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08663886514580404, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.236327539428372, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05003789986576571, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 16, 
      Optica`Optica`IntersectionNumber :> 7, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9988589898270124, -0.04775686800618502, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.289988407633029, -0.03532566548370465, 0.}, 
      Optica`Optica`RayEnd :> {3.6101936044655933`, -0.046115682956667625`, 
       0.}, RotationMatrix :> {{0.9994327325242668, -0.033678081285566805`, 
       0.}, {0.033678081285566805`, 0.9994327325242668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      98.25016212424417, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32038694192436795`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.710500213476437, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3852372121838523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 16, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9994327325242668, -0.033678081285566805`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6101936044655933`, -0.046115682956667625`, 
       0.}, Optica`Optica`RayEnd :> {3.304262492718633, 0.049036549917380684`,
        0.}, 
      RotationMatrix :> {{-0.9548800893988368, 0.29699160740611696`, 
       0.}, {-0.29699160740611696`, -0.9548800893988368, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2519807631121969, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.320386941924368, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.184672887524501, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21091766295593617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 16, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9548800893988368, 0.29699160740611696`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8890066728387804`, -0.09789651158066667, 
       0.}, Optica`Optica`RayEnd :> {
       2.8351104353765613`, -0.10861037831299702`, 0.}, 
      RotationMatrix :> {{-0.9808088170137308, -0.19497195815841276`, 0.}, {
       0.19497195815841276`, -0.9808088170137308, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25091868493303154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05495080848306122, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.66959661000684, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04307688827840045, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9808088170137308, -0.19497195815841276`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8351104353765613`, -0.10861037831299702`, 
       0.}, Optica`Optica`RayEnd :> {2.631370047670223, -0.17513360904866818`,
        0.}, RotationMatrix :> {{-0.9506112975353982, -0.31038389294237956`, 
       0.}, {0.31038389294237956`, -0.9506112975353982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24723671810648565`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21432565364472916`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.986798577401039, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24070583031372797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 15, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9506112975353982, -0.31038389294237956`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.289988407633029, -0.03532566548370465, 0.}, 
      Optica`Optica`RayEnd :> {3.203619614090072, -0.057219436555797455`, 0.},
       RotationMatrix :> {{-0.9693408857366421, -0.24571985519957873`, 0.}, {
       0.24571985519957873`, -0.9693408857366421, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2526286762070828, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08910053709054258, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.355722259129699, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41337462017475474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9693408857366421, -0.24571985519957873`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2036196140900715`, -0.057219436555797455`, 
       0.}, Optica`Optica`RayEnd :> {2.9006298519039526`, -0.1239716558766005,
        0.}, RotationMatrix :> {{-0.9765805269957853, -0.21515221191666578`, 
       0.}, {0.21515221191666578`, -0.9765805269957853, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2518754848342481, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31025578926726516`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      7.814900827245252, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24303557091065608`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9765805269957853, -0.21515221191666578`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6101936044655933`, -0.046115682956667625`, 
       0.}, Optica`Optica`RayEnd :> {3.884424114220212, -0.05148960539899354, 
       0.}, RotationMatrix :> {{0.9998080464314015, -0.019592608071010764`, 
       0.}, {0.019592608071010764`, 0.9998080464314015, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      97.99818136113194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27428315938586945`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.078039647053503, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23748150751418137`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 20, 
      Optica`Optica`IntersectionNumber :> 9, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9998080464314015, -0.019592608071010764`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.884424114220212, -0.05148960539899354, 0.}, 
      Optica`Optica`RayEnd :> {4.174745282155764, -0.04187068499412144, 0.}, 
      RotationMatrix :> {{0.9994515868142558, 0.03311382814574367, 
       0.}, {-0.03311382814574367, 0.9994515868142558, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      97.60177509251764, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2904804712561898, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.507950744512664, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28991308320566767`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 20, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9994515868142558, 0.03311382814574367, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.174745282155764, -0.04187068499412144, 0.}, 
      Optica`Optica`RayEnd :> {3.9920227327644295`, 0.18394201200307905`, 0.},
       RotationMatrix :> {{-0.6290355719995433, 0.7773765169846638, 
       0.}, {-0.7773765169846638, -0.6290355719995433, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.39480279059446854`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2904804712561897, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.937861841971825, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33792178208558277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 20, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6290355719995433, 0.7773765169846638, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.304262492718633, 0.049036549917380684`, 0.},
       Optica`Optica`RayEnd :> {2.8975987417994986`, 0.16926171893825742`, 
       0.}, RotationMatrix :> {{-0.9589699460058219, 0.28350774708566767`, 
       0.}, {-0.28350774708566767`, -0.9589699460058219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2513345117106132, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.42406308207354987`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.752917417503058, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.295180108361651, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9589699460058219, 0.28350774708566767`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8975987417994986`, 0.16926171893825742`, 
       0.}, Optica`Optica`RayEnd :> {2.560781759415158, 0.27331809425780756`, 
       0.}, RotationMatrix :> {{-0.955443202349738, 0.29517501094042053`, 
       0.}, {-0.29517501094042053`, -0.955443202349738, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2506962929360381, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3525243379784386, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.274653437711146, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09127768688089939, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.955443202349738, 0.29517501094042053`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.631370047670223, -0.17513360904866818`, 0.},
       Optica`Optica`RayEnd :> {2.4272549118351114`, -0.2699744584069052, 0.},
       RotationMatrix :> {{-0.9068848635602611, -0.4213785047261982, 0.}, {
       0.4213785047261982, -0.9068848635602611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24360878025636062`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22507282240194557`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.288396159419646, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41665265513164207`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9068848635602611, -0.4213785047261982, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4272549118351114`, -0.2699744584069052, 0.},
       Optica`Optica`RayEnd :> {2.1508630265649438`, -0.38625248209328467`, 
       0.}, RotationMatrix :> {{-0.9217516335228982, -0.38778077066542205`, 
       0.}, {0.38778077066542205`, -0.9217516335228982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.242833156181243, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2998550533768069, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.73218163841732, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33503683690138536`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 19, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9217516335228982, -0.38778077066542205`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9006298519039526`, -0.1239716558766005, 0.},
       Optica`Optica`RayEnd :> {2.868778330669892, -0.1299466247306531, 0.}, 
      RotationMatrix :> {{-0.9828564852107069, -0.18437225788945374`, 0.}, {
       0.18437225788945374`, -0.9828564852107069, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25112453903880644`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.032407092707163646`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.858326331472851, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08398174809308423, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9828564852107069, -0.18437225788945374`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.868778330669892, -0.12994662473065313`, 0.},
       Optica`Optica`RayEnd :> {2.621793917817546, -0.19608559386754335`, 0.},
       RotationMatrix :> {{-0.9659652235143442, -0.2586719678683463, 0.}, {
       0.2586719678683463, -0.9659652235143442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24956482069046557`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25568665086489895`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.2367425747529, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17386074561011847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9659652235143442, -0.2586719678683463, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.884424114220212, -0.051489605398993554`, 
       0.}, Optica`Optica`RayEnd :> {
       3.8360941866799445`, -0.12834485163359455`, 0.}, 
      RotationMatrix :> {{-0.532336668538546, -0.8465327349425312, 0.}, {
       0.8465327349425312, -0.532336668538546, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39640626861431016`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09078827440715387, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 8.199695934759088, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1557887690226129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 10, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.532336668538546, -0.8465327349425312, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8360941866799445`, -0.12834485163359455`, 
       0.}, Optica`Optica`RayEnd :> {
       3.6527301356231905`, -0.40317480552400664`, 0.}, 
      RotationMatrix :> {{-0.5550020774845027, -0.8318489610427399, 0.}, {
       0.8318489610427399, -0.5550020774845027, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3952797393161795, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3303844408796364, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 8.68866490726095, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37888153375539146`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5550020774845027, -0.8318489610427399, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.174745282155764, -0.04187068499412144, 0.}, 
      Optica`Optica`RayEnd :> {4.400554302185327, -0.022440938596222378`, 0.},
       RotationMatrix :> {{0.9963185552591743, 0.08572827098613041, 
       0.}, {-0.08572827098613041, 0.9963185552591743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      97.20697230192317, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22664339516473522`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.81165289403341, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18129781125149372`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 11, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9963185552591743, 0.08572827098613041, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.400554302185327, -0.022440938596222378`, 
       0.}, Optica`Optica`RayEnd :> {4.6946057131986, 0.011066496590403974`, 
       0.}, RotationMatrix :> {{0.9935701420223269, 0.11321825330631577`, 
       0.}, {-0.11321825330631577`, 0.9935701420223269, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.92895544545073, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29595435548692706`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.249665340154062, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3926154927590467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9935701420223269, 0.11321825330631577`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6946057131986, 0.011066496590403974`, 0.}, 
      Optica`Optica`RayEnd :> {4.422212158743575, 0.12678482713072758`, 0.}, 
      RotationMatrix :> {{-0.9203904230666321, 0.3910005999064781, 
       0.}, {-0.3910005999064781, -0.9203904230666321, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2772217142037861, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2959543554869271, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.687677786274714, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3062852140674474, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9203904230666321, 0.3910005999064781, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9920227327644295`, 0.18394201200307905`, 
       0.}, Optica`Optica`RayEnd :> {3.9208762860103477`, 
       0.26296014394196404`, 0.}, 
      RotationMatrix :> {{-0.669121263326238, 0.7431532378754055, 
       0.}, {-0.7431532378754055, -0.669121263326238, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3932057987025339, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10632818093451259`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.080341604424072, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3446207370521083, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.669121263326238, 0.7431532378754055, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9208762860103477`, 0.26296014394196404`, 
       0.}, Optica`Optica`RayEnd :> {3.774007014814893, 0.3790719956019406, 
       0.}, RotationMatrix :> {{-0.7844606483542546, 0.6201785961992098, 
       0.}, {-0.6201785961992098, -0.7844606483542546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.37864452946942234`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18722324886987857`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.357432012751493, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22630871180950718`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7844606483542546, 0.6201785961992098, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.774007014814893, 0.3790719956019406, 0.}, 
      Optica`Optica`RayEnd :> {3.615497598354153, 0.27943610944304614`, 0.}, 
      RotationMatrix :> {{-0.8466331901488637, -0.5321768891434107, 0.}, {
       0.5321768891434107, -0.8466331901488637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014022033641014977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18722324886987846`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.634522421078913, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19219943114675692`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 24, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8466331901488637, -0.5321768891434107, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.560781759415158, 0.27331809425780756`, 0.}, 
      Optica`Optica`RayEnd :> {2.289831266060674, 0.36065725145027167`, 0.}, 
      RotationMatrix :> {{-0.9517745152170292, 0.3067984227198519, 
       0.}, {-0.3067984227198519, -0.9517745152170292, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2500596948032183, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28467929012860815`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.65612368648348, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14144486928827724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9517745152170292, 0.3067984227198519, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.289831266060674, 0.36065725145027167`, 0.}, 
      Optica`Optica`RayEnd :> {2.1456962410064944`, 0.3837580623745752, 0.}, 
      RotationMatrix :> {{-0.9873986958724716, 0.15825237877941062`, 
       0.}, {-0.15825237877941062`, -0.9873986958724716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24309711641608542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14597449404854732`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.87216593767533, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42504658342537627`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9873986958724716, 0.15825237877941062`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1508630265649438`, -0.38625248209328467`, 
       0.}, Optica`Optica`RayEnd :> {
       2.1468470929130756`, -0.38777088348810573`, 0.}, 
      RotationMatrix :> {{-0.9353741967840518, -0.35365959903640376`, 0.}, {
       0.35365959903640376`, -0.9353741967840518, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.242060001609504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.004293397942423073, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.737934791660166, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29799885069007614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9353741967840518, -0.35365959903640376`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1468470929130756`, -0.38777088348810573`, 
       0.}, Optica`Optica`RayEnd :> {1.850524420653777, -0.5013247962187429, 
       0.}, RotationMatrix :> {{-0.9337844962275794, -0.35783587663201916`, 
       0.}, {0.35783587663201916`, -0.9337844962275794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24146099159531187`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31733518114342246`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.20759085975243, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1588053123770257, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 23, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9337844962275794, -0.35783587663201916`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.621793917817546, -0.19608559386754337`, 0.},
       Optica`Optica`RayEnd :> {2.4268272613564683`, -0.26458365317247373`, 
       0.}, RotationMatrix :> {{-0.9434657979925637, -0.33146989006281524`, 
       0.}, {0.33146989006281524`, -0.9434657979925637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24801478965239496`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20664941630731395`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.513652792604702, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40700052959136984`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9434657979925637, -0.33146989006281524`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4268272613564683`, -0.26458365317247373`, 
       0.}, Optica`Optica`RayEnd :> {2.131967869541339, -0.36053596551370937`,
        0.}, 
      RotationMatrix :> {{-0.9509173889076586, -0.3094448569180631, 0.}, {
       0.3094448569180631, -0.9509173889076586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24733481050217856`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3100788725231343, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      8.97256952393894, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25407187421879324`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9509173889076586, -0.3094448569180631, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6527301356231905`, -0.40317480552400664`, 
       0.}, Optica`Optica`RayEnd :> {3.6440775948960247`, -0.4154141300939811,
        0.}, RotationMatrix :> {{-0.5772627045571342, -0.8165584914305786, 
       0.}, {0.8165584914305786, -0.5772627045571342, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39415641145142666`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.014988913468441984`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 8.708750051308662, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13402888307773247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5772627045571342, -0.8165584914305786, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6440775948960247`, -0.4154141300939811, 0.},
       Optica`Optica`RayEnd :> {3.4519109865691275`, -0.6775846688198423, 0.},
       RotationMatrix :> {{-0.5911800248285837, -0.8065396321593097, 0.}, {
       0.8065396321593097, -0.5911800248285837, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39312627612022405`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.325055990148884, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 9.18983291672901, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.419015874056054, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5911800248285837, -0.8065396321593097, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.400554302185327, -0.02244093859622237, 0.}, 
      Optica`Optica`RayEnd :> {4.332719604913328, -0.07468346298845327, 0.}, 
      RotationMatrix :> {{-0.7922739759528378, -0.6101655078975557, 0.}, {
       0.6101655078975557, -0.7922739759528378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27801685647241575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08562025174487939, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.926384031371548, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06816741876586356, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 12, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7922739759528378, -0.6101655078975557, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.332719604913328, -0.07468346298845327, 0.}, 
      Optica`Optica`RayEnd :> {4.092110418388803, -0.2817319083055005, 0.}, 
      RotationMatrix :> {{-0.7579911961537824, -0.6522647825487422, 0.}, {
       0.6522647825487422, -0.7579911961537824, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.276861944470144, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31743005426109294`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.396180511677965, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11748060513014594`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7579911961537824, -0.6522647825487422, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6946057131986, 0.011066496590403974`, 0.}, 
      Optica`Optica`RayEnd :> {4.8241048464905125`, 0.02945966646765053, 0.}, 
      RotationMatrix :> {{0.9900633834899635, 0.14062182146596425`, 
       0.}, {-0.14062182146596425`, 0.9900633834899635, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.65173373124696, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1307988311166798, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.424935773850413, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012742916591336223`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 28, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9900633834899635, 0.14062182146596425`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8241048464905125`, 0.02945966646765053, 0.},
       Optica`Optica`RayEnd :> {5.136587594956282, 0.06878987295939466, 0.}, 
      RotationMatrix :> {{0.9921720597457364, 0.12487835625080448`, 
       0.}, {-0.12487835625080448`, 0.9921720597457364, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.40120163838044, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3149481437179856, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.891059026553032, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34853343095568107`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 28, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9921720597457364, 0.12487835625080448`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.136587594956282, 0.06878987295939468, 0.}, 
      Optica`Optica`RayEnd :> {4.849864850132244, -0.06152666793996342, 0.}, 
      RotationMatrix :> {{-0.9103808056756774, -0.413771420783631, 0.}, {
       0.413771420783631, -0.9103808056756774, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24988268568952332`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3149481437179855, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.357182279255651`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2728761681498907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 28, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9103808056756774, -0.413771420783631, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.422212158743575, 0.12678482713072758`, 0.}, 
      Optica`Optica`RayEnd :> {4.399096479845423, 0.13585950227795887`, 0.}, 
      RotationMatrix :> {{-0.9308403332153881, 0.36542615404410395`, 
       0.}, {-0.36542615404410395`, -0.9308403332153881, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27642884608225426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.024833129886308154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.720954180322366, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06984729830253202, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9308403332153881, 0.36542615404410395`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.399096479845423, 0.13585950227795887`, 0.}, 
      Optica`Optica`RayEnd :> {4.1360406816166115`, 0.2561933497483976, 0.}, 
      RotationMatrix :> {{-0.9093701777881628, 0.41598783605957174`, 
       0.}, {-0.41598783605957174`, -0.9093701777881628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2752680041887159, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28927251481749156`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.149077502252254`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.024483670967811073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9093701777881628, 0.41598783605957174`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9208762860103477`, 0.26296014394196404`, 
       0.}, Optica`Optica`RayEnd :> {3.9412780345169445`, 0.3897730672871572, 
       0.}, RotationMatrix :> {{0.15883823240493306`, 0.9873046216474813, 
       0.}, {-0.9873046216474813, 0.15883823240493306`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014561269233111584`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12844356297409484`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.25245597880936, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38193737398048777`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 13, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15883823240493306`, 0.9873046216474813, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9412780345169445`, 0.3897730672871572, 0.}, 
      Optica`Optica`RayEnd :> {3.9987729664076967`, 0.7106424299902512, 0.}, 
      RotationMatrix :> {{0.17637576291505594`, 0.9843229095455067, 
       0.}, {-0.9843229095455067, 0.17637576291505594`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014523045470901708`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3259797771559027, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 9.734906049000097, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24613225581910286`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17637576291505594`, 0.9843229095455067, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.774007014814893, 0.3790719956019406, 0.}, 
      Optica`Optica`RayEnd :> {3.618102085979958, 0.46427768108364853`, 0.}, 
      RotationMatrix :> {{-0.8775010050140475, 0.4795747972937451, 
       0.}, {-0.4795747972937451, -0.8775010050140475, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3646224958284075, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17766923108246344`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.595508782401994, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3715665650713764, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8775010050140475, 0.4795747972937451, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.618102085979958, 0.46427768108364853`, 0.}, 
      Optica`Optica`RayEnd :> {3.3555961043193907`, 0.5982774551320276, 0.}, 
      RotationMatrix :> {{-0.8906682424648924, 0.45465380441001435`, 
       0.}, {-0.45465380441001435`, -0.8906682424648924, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.36357353990223545`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2947292483833167, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.031708070009303`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3351117811344288, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8906682424648924, 0.45465380441001435`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.615497598354153, 0.27943610944304614`, 0.}, 
      Optica`Optica`RayEnd :> {3.4620287086386394`, 0.14210240451730616`, 0.},
       RotationMatrix :> {{-0.7451944166345312, -0.666847269932719, 0.}, {
       0.666847269932719, -0.7451944166345312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013502767120235534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2059447659425766, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.910488407441965, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21936585876489084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7451944166345312, -0.666847269932719, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4620287086386394`, 0.14210240451730616`, 
       0.}, Optica`Optica`RayEnd :> {3.290651511409753, -0.04093297677543393, 
       0.}, RotationMatrix :> {{-0.6834772628729329, -0.729971801603133, 
       0.}, {0.729971801603133, -0.6834772628729329, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01339630247316773, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2507430847202119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.28158817282788, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06738285776063474, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6834772628729329, -0.729971801603133, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1456962410064944`, 0.3837580623745752, 0.}, 
      Optica`Optica`RayEnd :> {2.137773631112005, 0.3838057059622634, 0.}, 
      RotationMatrix :> {{-0.9999819186606784, 0.006013514089774824, 
       0.}, {-0.006013514089774824, -0.9999819186606784, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2363284017295186, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007922753148477363, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.88278242689429, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18840259110947652`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999819186606784, 0.006013514089774824, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.137773631112005, 0.3838057059622634, 0.}, 
      Optica`Optica`RayEnd :> {1.9375366706374482`, 0.3992115048105958, 0.}, 
      RotationMatrix :> {{-0.9970533599238541, 0.07671112999137163, 
       0.}, {-0.07671112999137163, -0.9970533599238541, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23500628659526143`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20082873046017238`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.180008947975345`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24290061066354512`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 27, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9970533599238541, 0.07671112999137163, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.131967869541339, -0.36053596551370937`, 0.},
       Optica`Optica`RayEnd :> {2.1317647742058625`, -0.3605968720764497, 0.},
       RotationMatrix :> {{-0.9578548869787742, -0.2872525291287782, 0.}, {
       0.2872525291287782, -0.9578548869787742, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24665669564257717`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0002120314237963691, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      8.972853646046827, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21409910787816447`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9578548869787742, -0.2872525291287782, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1317647742058625`, -0.3605968720764497, 0.},
       Optica`Optica`RayEnd :> {1.842422203976989, -0.4570800530492261, 0.}, 
      RotationMatrix :> {{-0.9486482197923176, -0.3163329813422345, 0.}, {
       0.3163329813422345, -0.9486482197923176, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24592891512772325`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3050051264442551, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.424261233184325, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.019506742582937334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9486482197923176, -0.3163329813422345, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4519109865691275`, -0.6775846688198423, 0.},
       Optica`Optica`RayEnd :> {3.3743027929427307`, -0.7797432585536458, 0.},
       RotationMatrix :> {{-0.604923497177565, -0.796283594306993, 0.}, {
       0.796283594306993, -0.604923497177565, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.39209883306744114`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12829422892068026`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.361747183482722, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.423259716504044, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.604923497177565, -0.796283594306993, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3743027929427307`, -0.7797432585536458, 0.},
       Optica`Optica`RayEnd :> {3.2171263394543335`, -0.945791594974529, 0.}, 
      RotationMatrix :> {{-0.687439187190562, -0.726241945851917, 0.}, {
       0.726241945851917, -0.687439187190562, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.38748365083341024`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.228640520379335, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 9.700135153644137, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24256034056857045`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.687439187190562, -0.726241945851917, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.092110418388803, -0.2817319083055005, 0.}, 
      Optica`Optica`RayEnd :> {4.023924522203216, -0.3471739477614017, 0.}, 
      RotationMatrix :> {{-0.721474117604436, -0.6924414037497325, 0.}, {
       0.6924414037497325, -0.721474117604436, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2757118300968718, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09450913694865332, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.52282275518916, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.111759557276061, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.721474117604436, -0.6924414037497325, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.023924522203216, -0.3471739477614017, 0.}, 
      Optica`Optica`RayEnd :> {3.8359760786024566`, -0.547303048019383, 0.}, 
      RotationMatrix :> {{-0.6845755755823887, -0.7289418915908461, 0.}, {
       0.7289418915908461, -0.6845755755823887, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27461136868058705`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27454739886223106`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      9.929152905505262, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17657179835465311`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6845755755823887, -0.7289418915908461, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8241048464905125`, 0.02945966646765053, 0.},
       Optica`Optica`RayEnd :> {4.69466225720908, 0.05463155987304365, 0.}, 
      RotationMatrix :> {{-0.9816118359488982, 0.19088793446688382`, 
       0.}, {-0.19088793446688382`, -0.9816118359488982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2505320928665387, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1318673884533026, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.601638074377838, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3934178451262893, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9816118359488982, 0.19088793446688382`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.69466225720908, 0.05463155987304365, 0.}, 
      Optica`Optica`RayEnd :> {4.40607822076775, 0.1010441468157273, 0.}, 
      RotationMatrix :> {{-0.9873126720810275, 0.15878818453594562`, 
       0.}, {-0.15878818453594562`, -0.9873126720810275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24977465691115894`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29229244655906383`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.034230895285253`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22217963939932622`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9873126720810275, 0.15878818453594562`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.136587594956282, 0.06878987295939468, 0.}, 
      Optica`Optica`RayEnd :> {5.438567307187545, 0.1019347427665358, 0.}, 
      RotationMatrix :> {{0.9940304078034512, 0.1091033838251799, 
       0.}, {-0.1091033838251799, 0.9940304078034512, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      96.15131895269093, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30379323395001484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.298141960046053`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23906828014549203`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 32, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9940304078034512, 0.1091033838251799, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.438567307187545, 0.1019347427665358, 0.}, 
      Optica`Optica`RayEnd :> {5.639921896520204, 0.11098310414783293`, 0.}, 
      RotationMatrix :> {{0.9989918395183365, 0.044892143809023996`, 
       0.}, {-0.044892143809023996`, 0.9989918395183365, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      95.67368665723663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20155779193325782`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.596447492107274`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2214592476354068, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 32, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9989918395183365, 0.044892143809023996`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.639921896520204, 0.11098310414783293`, 0.}, 
      Optica`Optica`RayEnd :> {5.554250872733547, -0.07146146050772646, 0.}, 
      RotationMatrix :> {{-0.42504446474103386`, -0.9051724714069733, 0.}, {
       0.9051724714069733, -0.42504446474103386`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.47525965395389297`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2015577919332577, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.894753024168494`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2035015634172836, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 32, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.42504446474103386`, -0.9051724714069733, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.849864850132244, -0.06152666793996342, 0.}, 
      Optica`Optica`RayEnd :> {4.788657960453038, -0.08818067542507846, 0.}, 
      RotationMatrix :> {{-0.9168381205189038, -0.399259139862025, 0.}, {
       0.399259139862025, -0.9168381205189038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24923496184846966`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06675866579867423, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.446638891425875`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.050590084903721244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9168381205189038, -0.399259139862025, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.788657960453038, -0.08818067542507849, 0.}, 
      Optica`Optica`RayEnd :> {4.563160363805937, -0.2095253732610226, 0.}, 
      RotationMatrix :> {{-0.88059672689059, -0.473866441721272, 0.}, {
       0.473866441721272, -0.88059672689059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24746780161251128`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2560736257143928, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.825627857483177`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08025064745371002, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.88059672689059, -0.473866441721272, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1360406816166115`, 0.2561933497483976, 0.}, 
      Optica`Optica`RayEnd :> {3.6179271192659637`, 0.5285467804054872, 0.}, 
      RotationMatrix :> {{-0.8851560421700713, 0.4652942950540173, 
       0.}, {-0.4652942950540173, -0.8851560421700713, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2741120371623301, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5853358477680699, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.933427538261467`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36973938896155384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8851560421700713, 0.4652942950540173, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6179271192659637`, 0.5285467804054872, 0.}, 
      Optica`Optica`RayEnd :> {3.3901148833251633`, 0.6267205401047594, 0.}, 
      RotationMatrix :> {{-0.9183551041269086, 0.3957573786097422, 
       0.}, {-0.3957573786097422, -0.9183551041269086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27238082007958386`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24806551944564428`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.30056450704102, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42831104982300866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9183551041269086, 0.3957573786097422, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9987729664076967`, 0.7106424299902512, 0.}, 
      Optica`Optica`RayEnd :> {4.032900255712351, 0.8833460304798999, 0.}, 
      RotationMatrix :> {{0.19385747833021866`, 0.9810297029628862, 
       0.}, {-0.9810297029628862, 0.19385747833021866`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014484922047197642`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.176043192135827, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.970803926462105, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2530598713774328, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 15, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19385747833021866`, 0.9810297029628862, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.032900255712351, 0.8833460304798999, 0.}, 
      Optica`Optica`RayEnd :> {4.087894069184557, 1.190572550681726, 0.}, 
      RotationMatrix :> {{0.1762002797858955, 0.9843543373213591, 
       0.}, {-0.9843543373213591, 0.1762002797858955, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014446851157553332`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3121096830211119, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.432726257333352`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08775795741922073, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1762002797858955, 0.9843543373213591, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3555961043193907`, 0.5982774551320276, 0.}, 
      Optica`Optica`RayEnd :> {3.3506237843433677`, 0.6006414315659845, 0.}, 
      RotationMatrix :> {{-0.9031279045372516, 0.4293716199822167, 
       0.}, {-0.4293716199822167, -0.9031279045372516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3625276016410393, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00550566531168221, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.039085661526958`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02532004483700924, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9031279045372516, 0.4293716199822167, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3506237843433677`, 0.6006414315659845, 0.}, 
      Optica`Optica`RayEnd :> {3.1189077061664916`, 0.7275798313596082, 0.}, 
      RotationMatrix :> {{-0.8770224926183509, 0.4804493182860131, 
       0.}, {-0.4804493182860131, -0.8770224926183509, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3609400849938371, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26420768010759665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.4301130280862, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.002899050341736653, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8770224926183509, 0.4804493182860131, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.290651511409753, -0.04093297677543392, 0.}, 
      Optica`Optica`RayEnd :> {3.221579882986132, -0.12916230350309768`, 0.}, 
      RotationMatrix :> {{-0.6164332830949181, -0.7874071421398339, 0.}, {
       0.7874071421398339, -0.6164332830949181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013290677263007516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11205045268943635`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.431735779431724`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.354227948066582, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6164332830949181, -0.7874071421398339, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.221579882986132, -0.12916230350309768`, 0.},
       Optica`Optica`RayEnd :> {3.1079744812692307`, -0.31578149969126973`, 
       0.}, RotationMatrix :> {{-0.5199840451850417, -0.8541759729429296, 
       0.}, {0.8541759729429296, -0.5199840451850417, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013103198876517008`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21847862981348537`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.755084151555682`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10590305690193888`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 31, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5199840451850417, -0.8541759729429296, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2171263394543335`, -0.945791594974529, 0.}, 
      Optica`Optica`RayEnd :> {3.109609326425071, -1.037191798066271, 0.}, 
      RotationMatrix :> {{-0.761901752869223, -0.6476926114869652, 0.}, {
       0.6476926114869652, -0.761901752869223, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3829227914008192, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1411166369211877, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 9.889231447118528, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3388389581834084, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.761901752869223, -0.6476926114869652, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.109609326425071, -1.037191798066271, 0.}, 
      Optica`Optica`RayEnd :> {2.9525382644923193`, -1.1376453192431852`, 0.},
       RotationMatrix :> {{-0.8424465876432952, -0.5387798687480512, 0.}, {
       0.5387798687480512, -0.8424465876432952, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3752210699497621, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1864463150977328, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.165171993463172`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3041121382895055, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8424465876432952, -0.5387798687480512, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8359760786024566`, -0.547303048019383, 0.}, 
      Optica`Optica`RayEnd :> {3.8081445731435055`, -0.5802043795349205, 0.}, 
      RotationMatrix :> {{-0.6458329320787934, -0.7634787645000404, 0.}, {
       0.7634787645000404, -0.6458329320787934, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2735152995869976, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04309397071061014, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.98689882625748, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1892807338968753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6458329320787934, -0.7634787645000404, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8081445731435055`, -0.5802043795349205, 0.},
       Optica`Optica`RayEnd :> {3.6479267674466245`, -0.7940552712029678, 0.},
       RotationMatrix :> {{-0.5995918841929333, -0.8003059242626956, 0.}, {
       0.8003059242626956, -0.5995918841929333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2722801779361296, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2672114315098484, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.382371744892056`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20395846594105088`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5995918841929333, -0.8003059242626956, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.40607822076775, 0.10104414681572732`, 0.}, 
      Optica`Optica`RayEnd :> {4.34698126031897, 0.10858164471908821`, 0.}, 
      RotationMatrix :> {{-0.9919641000130234, 0.1265196596792469, 
       0.}, {-0.1265196596792469, -0.9919641000130234, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24901951091879346`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05957570485464469, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.114062339790477`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11055091198386752`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9919641000130234, 0.1265196596792469, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.34698126031897, 0.10858164471908821`, 0.}, 
      Optica`Optica`RayEnd :> {4.170700334701458, 0.1634694739701575, 0.}, 
      RotationMatrix :> {{-0.9547878069669318, 0.2972881492210493, 
       0.}, {-0.2972881492210493, -0.9547878069669318, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23874988737056477`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18462837955325728`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.387312341529299`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3090955933492257, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9547878069669318, 0.2972881492210493, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.170700334701458, 0.1634694739701575, 0.}, 
      Optica`Optica`RayEnd :> {4.158904414755697, 0.3477206471254315, 0.}, 
      RotationMatrix :> {{-0.06389006919902085, 0.9979569424868711, 
       0.}, {-0.9979569424868711, -0.06389006919902085, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009846101843310104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1846283795532571, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.660562343268118`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2564554058148944, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.06389006919902085, 0.9979569424868711, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.438567307187545, 0.1019347427665358, 0.}, 
      Optica`Optica`RayEnd :> {5.369947045855445, 0.2389135007740329, 0.}, 
      RotationMatrix :> {{-0.4478968991145136, 0.8940852128089376, 
       0.}, {-0.8940852128089376, -0.4478968991145136, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.47763229545424635`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.153205484270512, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.50343730896854, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4175723766432237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.4478968991145136, 0.8940852128089376, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.369947045855445, 0.2389135007740329, 0.}, 
      Optica`Optica`RayEnd :> {5.256652686999513, 0.4008534369572916, 0.}, 
      RotationMatrix :> {{-0.5732463612250787, 0.8193830663018407, 
       0.}, {-0.8193830663018407, -0.5732463612250787, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4659181433095814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19763642042805413`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.79593921120206, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11521949459319769`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5732463612250787, 0.8193830663018407, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.256652686999513, 0.4008534369572916, 0.}, 
      Optica`Optica`RayEnd :> {5.072982639363519, 0.3278776308226116, 0.}, 
      RotationMatrix :> {{-0.9293330006594371, -0.36924270322557007`, 0.}, {
       0.36924270322557007`, -0.9293330006594371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01142685716529616, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19763642042805418`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.088441113435579`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24988721411724535`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 36, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9293330006594371, -0.36924270322557007`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.639921896520204, 0.11098310414783293`, 0.}, 
      Optica`Optica`RayEnd :> {5.656117764920519, 0.11066713884056856`, 0.}, 
      RotationMatrix :> {{0.9998097536305198, -0.019505295313812135`, 0.}, {
       0.019505295313812135`, 0.9998097536305198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      95.19842700328273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.016198950191778097`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.618154085364257`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39505696612238694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9998097536305198, -0.019505295313812135`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.656117764920519, 0.11066713884056857`, 0.}, 
      Optica`Optica`RayEnd :> {5.780139413390965, 0.1328722918237478, 0.}, 
      RotationMatrix :> {{0.9843472189495585, 0.1762400424031657, 
       0.}, {-0.1762400424031657, 0.9843472189495585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      89.56221790895778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474787`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.804624912124083`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10820121574341954`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9843472189495585, 0.1762400424031657, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.780139413390965, 0.1328722918237478, 0.}, 
      Optica`Optica`RayEnd :> {5.813078531240988, 0.25448418525360783`, 0.}, 
      RotationMatrix :> {{0.26143443060304344`, 0.9652212381082702, 
       0.}, {-0.9652212381082702, 0.26143443060304344`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.302518150525389, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474785`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.99109573888391, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33977318087657354`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26143443060304344`, 0.9652212381082702, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.813078531240988, 0.25448418525360783`, 0.}, 
      Optica`Optica`RayEnd :> {5.717216724786908, 0.33624574206176727`, 0.}, 
      RotationMatrix :> {{-0.7608454148957724, 0.6489331665372633, 
       0.}, {-0.6489331665372633, -0.7608454148957724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3139348197610793, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474793`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.177566565643737`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1863786948954282, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7608454148957724, 0.6489331665372633, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.717216724786908, 0.33624574206176727`, 0.}, 
      Optica`Optica`RayEnd :> {5.602324795163315, 0.28453227557864835`, 0.}, 
      RotationMatrix :> {{-0.9118855683625422, -0.4104445275699544, 0.}, {
       0.4104445275699544, -0.9118855683625422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018586465573654988`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12599380186474796`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.364037392403564`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27538787328100506`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9118855683625422, -0.4104445275699544, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.554250872733547, -0.07146146050772645, 0.}, 
      Optica`Optica`RayEnd :> {5.446013302160968, -0.26798629236588783`, 0.}, 
      RotationMatrix :> {{-0.4824282451602636, -0.8759354932137345, 0.}, {
       0.8759354932137345, -0.4824282451602636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.47289879856545575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2243599367541645, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.195395339419075`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.306869572752462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4824282451602636, -0.8759354932137345, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.446013302160968, -0.26798629236588783`, 0.},
       Optica`Optica`RayEnd :> {5.3289129465642615`, -0.373110817031439, 0.}, 
      RotationMatrix :> {{-0.7441334147530378, -0.6680310329977068, 0.}, {
       0.6680310329977068, -0.7441334147530378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29646093220014913`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15736473228469317`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.42829514320042, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12121326779677413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7441334147530378, -0.6680310329977068, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3289129465642615`, -0.373110817031439, 0.}, 
      Optica`Optica`RayEnd :> {5.173926973483606, -0.3458526601738012, 0.}, 
      RotationMatrix :> {{-0.9848837845081162, 0.173216428242157, 
       0.}, {-0.173216428242157, -0.9848837845081162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11060915040751881`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1573647322846933, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.661194946981766`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4049186434789684, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9848837845081162, 0.173216428242157, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.173926973483606, -0.3458526601738012, 0.}, 
      Optica`Optica`RayEnd :> {5.099721637990405, -0.2070822485170844, 0.}, 
      RotationMatrix :> {{-0.47154997448192115`, 0.8818393399968609, 
       0.}, {-0.8818393399968609, -0.47154997448192115`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04126811604846847, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15736473228469344`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.894094750763113`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.019105609878257376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.47154997448192115`, 0.8818393399968609, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.099721637990405, -0.2070822485170844, 0.}, 
      Optica`Optica`RayEnd :> {5.163112851191095, -0.06305026229187857, 0.}, 
      RotationMatrix :> {{0.40282986079757116`, 0.9152748785200047, 
       0.}, {-0.9152748785200047, 0.40282986079757116`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015397075159833136`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15736473228469341`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.12699455454446, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3813357873739703, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 38, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.40282986079757116`, 0.9152748785200047, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.563160363805937, -0.2095253732610226, 0.}, 
      Optica`Optica`RayEnd :> {4.435873312302021, -0.29231063265284085`, 0.}, 
      RotationMatrix :> {{-0.8382971024368879, -0.5452136902590744, 0.}, {
       0.5452136902590744, -0.8382971024368879, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24571317114074157`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15184002322553636`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.029093488605396`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.340267179967318, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8382971024368879, -0.5452136902590744, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.435873312302021, -0.29231063265284085`, 0.},
       Optica`Optica`RayEnd :> {4.2072759558879405`, -0.40840447476237973`, 
       0.}, RotationMatrix :> {{-0.8916089465832205, -0.45280623490932603`, 
       0.}, {0.45280623490932603`, -0.8916089465832205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24290961227306532`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2563874636858447, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.408546934860446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37757037488619244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8916089465832205, -0.45280623490932603`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3901148833251633`, 0.6267205401047594, 0.}, 
      Optica`Optica`RayEnd :> {3.3831584032670334`, 0.629101891221183, 0.}, 
      RotationMatrix :> {{-0.9461013771261277, 0.32387062880113826`, 
       0.}, {-0.32387062880113826`, -0.9461013771261277, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27066053689313274`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007352785046419563, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.310417239003222`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1665292357658861, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9461013771261277, 0.32387062880113826`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3831584032670334`, 0.629101891221183, 0.}, 
      Optica`Optica`RayEnd :> {3.118958057251666, 0.730693687402561, 0.}, 
      RotationMatrix :> {{-0.9333736819997513, 0.3589060737159891, 
       0.}, {-0.3589060737159891, -0.9333736819997513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26979268882356827`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.283059562435185, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.729345391407296`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.013267977284063037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9333736819997513, 0.3589060737159891, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.087894069184557, 1.190572550681726, 0.}, 
      Optica`Optica`RayEnd :> {4.096974615643519, 1.2471439068332988`, 0.}, 
      RotationMatrix :> {{0.1584861985309714, 0.987361192712779, 
       0.}, {-0.987361192712779, 0.1584861985309714, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014408880330072529`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.057295502972061034`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 10.509502231315913`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07149724037825003, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1584861985309714, 0.987361192712779, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.096974615643519, 1.2471439068332988`, 0.}, 
      Optica`Optica`RayEnd :> {4.1566020874311045`, 1.3948686334667941`, 0.}, 
      RotationMatrix :> {{0.3742979428517587, 0.9273084977379111, 
       0.}, {-0.9273084977379111, 0.3742979428517587, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013097169104803217`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15930483436079493`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.74527338616989, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39498665502861907`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3742979428517587, 0.9273084977379111, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1189077061664916`, 0.7275798313596082, 0.}, 
      Optica`Optica`RayEnd :> {2.962953264961906, 0.8250378530382365, 0.}, 
      RotationMatrix :> {{-0.8480313050205771, 0.5299461347204043, 
       0.}, {-0.5299461347204043, -0.8480313050205771, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.35935952011828964`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18390175018456614`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.676541373333519`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38195710108162617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8480313050205771, 0.5299461347204043, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.962953264961906, 0.8250378530382365, 0.}, 
      Optica`Optica`RayEnd :> {2.8527497331871134`, 0.9455596562108208, 0.}, 
      RotationMatrix :> {{-0.6748097851451538, 0.7379917031189114, 
       0.}, {-0.7379917031189114, -0.6748097851451538, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29663190931406896`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16331051238548253`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.918240931664034`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12678825010796402`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6748097851451538, 0.7379917031189114, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8527497331871134`, 0.9455596562108208, 0.}, 
      Optica`Optica`RayEnd :> {2.88965565168125, 1.1046454086706592`, 0.}, 
      RotationMatrix :> {{0.22598617783417996`, 0.9741305084165561, 
       0.}, {-0.9741305084165561, 0.22598617783417996`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.051778260816468594`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16331051238548247`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.159940489994549`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3267829882867522, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22598617783417996`, 0.9741305084165561, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.88965565168125, 1.1046454086706592`, 0.}, 
      Optica`Optica`RayEnd :> {3.0416663960619714`, 1.164336756858046, 0.}, 
      RotationMatrix :> {{0.9308080794083295, 0.36550830265286244`, 
       0.}, {-0.36550830265286244`, 0.9308080794083295, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009038098090585665, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16331051238548244`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.401640048325064`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20088390683858276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 37, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9308080794083295, 0.36550830265286244`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1079744812692307`, -0.31578149969126973`, 
       0.}, Optica`Optica`RayEnd :> {3.0979082551464243`, -0.3377617363851812,
        0.}, 
      RotationMatrix :> {{-0.416379550046603, -0.9091908877144492, 0.}, {
       0.9091908877144492, -0.416379550046603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012918365061458454`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02417560161559255, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.787479457720575`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07101695824818587, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.416379550046603, -0.9091908877144492, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0979082551464243`, -0.3377617363851812, 0.},
       Optica`Optica`RayEnd :> {2.964069326973405, -0.6132710566160591, 0.}, 
      RotationMatrix :> {{-0.436957098991212, -0.8994823475984306, 0.}, {
       0.8994823475984306, -0.436957098991212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012883102638388119`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30629763993309367`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.240799964821553`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3451523158640592, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 35, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.436957098991212, -0.8994823475984306, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9525382644923193`, -1.1376453192431852`, 
       0.}, Optica`Optica`RayEnd :> {2.9202939341265974`, -1.15256709084685, 
       0.}, RotationMatrix :> {{-0.9075329858758598, -0.4199808085463499, 
       0.}, {0.4199808085463499, -0.9075329858758598, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3676742531286771, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03552965111742231, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 10.212781725960518`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22381684908110722`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9075329858758598, -0.4199808085463499, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9202939341265974`, -1.15256709084685, 0.}, 
      Optica`Optica`RayEnd :> {2.6545398615910583`, -1.280178969740208, 0.}, 
      RotationMatrix :> {{-0.9014569821761123, -0.4328686975122316, 0.}, {
       0.4328686975122316, -0.9014569821761123, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.36673044716996733`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29480505203255547`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 10.6490932029687, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1536074871725836, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9014569821761123, -0.4328686975122316, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6479267674466245`, -0.7940552712029678, 0.},
       Optica`Optica`RayEnd :> {3.63352257300137, -0.8158563100177105, 0.}, 
      RotationMatrix :> {{-0.5512555779337724, -0.8343364356162939, 0.}, {
       0.8343364356162939, -0.5512555779337724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27105063376299215`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.026129793551013997`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.417385668250414`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01810937399030649, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5512555779337724, -0.8343364356162939, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.63352257300137, -0.8158563100177105, 0.}, 
      Optica`Optica`RayEnd :> {3.4528534018009265`, -1.0906598151282794`, 0.},
       RotationMatrix :> {{-0.5493562808388661, -0.8355882219747287, 0.}, {
       0.8355882219747287, -0.5493562808388661, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2703818851158309, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3288743161806797, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.904119656197821`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4117163466854287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5493562808388661, -0.8355882219747287, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.34698126031897, 0.10858164471908821`, 0.}, 
      Optica`Optica`RayEnd :> {4.172131662576525, -0.04731871164326101, 0.}, 
      RotationMatrix :> {{-0.746394203533001, -0.6655040893430612, 0.}, {
       0.6655040893430612, -0.746394203533001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010269623548228695`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23425905093422206`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.427969468042335`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2745418560488449, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.746394203533001, -0.6655040893430612, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.172131662576525, -0.04731871164326101, 0.}, 
      Optica`Optica`RayEnd :> {4.0215053031803265`, -0.13656884224374358`, 
       0.}, RotationMatrix :> {{-0.8603164176767244, -0.5097603961430193, 
       0.}, {0.5097603961430193, -0.8603164176767244, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009694321865884491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1750825118541425, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      10.687091585586465`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2650220322688981, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8603164176767244, -0.5097603961430193, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.170700334701458, 0.1634694739701575, 0.}, 
      Optica`Optica`RayEnd :> {3.9039351419317736`, 0.3012815070009306, 0.}, 
      RotationMatrix :> {{-0.888448519270324, 0.4589762832722063, 
       0.}, {-0.4589762832722063, -0.888448519270324, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2289037855272547, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3002595952197393, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.78966019912375, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24035121676729038`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.888448519270324, 0.4589762832722063, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9039351419317736`, 0.3012815070009306, 0.}, 
      Optica`Optica`RayEnd :> {3.7095927179649006`, 0.3694555953323202, 0.}, 
      RotationMatrix :> {{-0.9436246080317363, 0.3310175208609837, 
       0.}, {-0.3310175208609837, -0.9436246080317363, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22394480345779205`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2059531113460924, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.094470803915966`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3834156906957767, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9436246080317363, 0.3310175208609837, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.158904414755697, 0.34772064712543155`, 0.}, 
      Optica`Optica`RayEnd :> {4.186709549300818, 0.5970566748280117, 0.}, 
      RotationMatrix :> {{0.1108297056567604, 0.9938394117482137, 
       0.}, {-0.9938394117482137, 0.1108297056567604, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009440046273707401, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.250881605976951, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.996743695277233`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41804244091325343`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1108297056567604, 0.9938394117482137, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.186709549300818, 0.5970566748280117, 0.}, 
      Optica`Optica`RayEnd :> {4.232349480833086, 0.9075335520499724, 0.}, 
      RotationMatrix :> {{0.14543649567760558`, 0.9893675887783152, 
       0.}, {-0.9893675887783152, 0.14543649567760558`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009410693493085256, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31381347109353125`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.46118763249566, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3214196086825758, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14543649567760558`, 0.9893675887783152, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.369947045855445, 0.2389135007740329, 0.}, 
      Optica`Optica`RayEnd :> {5.4363474180854485`, 0.33981791682190754`, 0.},
       RotationMatrix :> {{0.5497082970382567, 0.8353566832002361, 
       0.}, {-0.8353566832002361, 0.5497082970382567, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01171415214466485, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12079201385127093`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.665298607529243`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3735805626744669, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 17, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5497082970382567, 0.8353566832002361, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.4363474180854485`, 0.33981791682190754`, 
       0.}, Optica`Optica`RayEnd :> {5.618099162223654, 0.631822219651038, 
       0.}, RotationMatrix :> {{0.5284280107905021, 0.8489781136236629, 
       0.}, {-0.8489781136236629, 0.5284280107905021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011681430313760297`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34394797479852446`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.174341610231059`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1332284997693361, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5284280107905021, 0.8489781136236629, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.256652686999513, 0.4008534369572916, 0.}, 
      Optica`Optica`RayEnd :> {5.169280136629371, 0.4934251559499546, 0.}, 
      RotationMatrix :> {{-0.68638974683991, 0.7272338794590391, 
       0.}, {-0.7272338794590391, -0.68638974683991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.45449128614428513`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12729291306054602`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.966511714703191`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32782586539922676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.68638974683991, 0.7272338794590391, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.169280136629371, 0.4934251559499546, 0.}, 
      Optica`Optica`RayEnd :> {4.9705929431190015`, 0.6843149737851442, 0.}, 
      RotationMatrix :> {{-0.7211150838502431, 0.6928152970623966, 
       0.}, {-0.6928152970623966, -0.7211150838502431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.45276369280189577`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27552771805787307`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.374292737428844`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.390346966988952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7211150838502431, 0.6928152970623966, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.072982639363519, 0.3278776308226116, 0.}, 
      Optica`Optica`RayEnd :> {4.8388393340441525`, 0.1924932213145497, 0.}, 
      RotationMatrix :> {{-0.8657022896828663, -0.5005592328964099, 0.}, {
       0.5005592328964099, -0.8657022896828663, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01114660822768542, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27046631169837904`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.450865971111407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19287556528403926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8657022896828663, -0.5005592328964099, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8388393340441525`, 0.1924932213145497, 0.}, 
      Optica`Optica`RayEnd :> {4.698679316809952, 0.14323389961481361`, 0.}, 
      RotationMatrix :> {{-0.9434308533947554, -0.33156933643333675`, 0.}, {
       0.33156933643333675`, -0.9434308533947554, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0105900679858363, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1485641652802231, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.670740935726137`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3470922515716134, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9434308533947554, -0.33156933643333675`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.656117764920519, 0.11066713884056856`, 0.}, 
      Optica`Optica`RayEnd :> {6.050783306785948, -0.26091767258249676`, 0.}, 
      RotationMatrix :> {{0.7280757873521932, -0.6854966432240815, 0.}, {
       0.6854966432240815, 0.7280757873521932, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.636209094324948, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5420665660380165, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.3445232838552, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05368274216917744, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 18, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7280757873521932, -0.6854966432240815, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.050783306785948, -0.26091767258249676`, 0.},
       Optica`Optica`RayEnd :> {6.266462557308947, -0.4372999424005015, 0.}, 
      RotationMatrix :> {{0.7741025248562585, -0.6330602506959078, 0.}, {
       0.6330602506959078, 0.7741025248562585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.60526256904622, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2786184563382585, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.756878599235822`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10727442243556647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7741025248562585, -0.6330602506959078, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.266462557308947, -0.4372999424005015, 0.}, 
      Optica`Optica`RayEnd :> {6.340928797522072, -0.1688171249226691, 0.}, 
      RotationMatrix :> {{0.2672695886403147, 0.9636217966547025, 
       0.}, {-0.9636217966547025, 0.2672695886403147, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03077660833441297, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2786184563382585, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.169233914616445`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15960082820150506`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2672695886403147, 0.9636217966547025, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.780139413390965, 0.1328722918237478, 0.}, 
      Optica`Optica`RayEnd :> {6.078954373256245, 0.25009272336775246`, 0.}, 
      RotationMatrix :> {{0.9309328551471545, 0.3651903876166055, 
       0.}, {-0.3651903876166055, 0.9309328551471545, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      84.25969975843235, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.320984438580208, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.234744059821562`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13626747688806312`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9309328551471545, 0.3651903876166055, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.078954373256245, 0.2500927233677525, 0.}, 
      Optica`Optica`RayEnd :> {6.385877384362597, 0.3672198357910872, 0.}, 
      RotationMatrix :> {{0.9342809324260642, 0.3565377109158069, 
       0.}, {-0.3565377109158069, 0.9342809324260642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      84.04839455874071, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3285125495490519, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.72094263315416, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2798838489145635, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9342809324260642, 0.3565377109158069, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.385877384362597, 0.3672198357910872, 0.}, 
      Optica`Optica`RayEnd :> {6.10438412011554, 0.19786211558100952`, 0.}, 
      RotationMatrix :> {{-0.8568721792621364, -0.5155289210185561, 0.}, {
       0.5155289210185561, -0.8568721792621364, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21077529171018483`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32851254954905174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.207141206486757`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2946360043839924, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8568721792621364, -0.5155289210185561, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.813078531240988, 0.25448418525360783`, 0.}, 
      Optica`Optica`RayEnd :> {5.826683256183537, 0.45472933508594915`, 0.}, 
      RotationMatrix :> {{0.06778408503872654, 0.9977000139397925, 
       0.}, {-0.9977000139397925, 0.06778408503872654, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.988583330764308, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20070677261153702`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.26004281418337, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2615144857211294, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.06778408503872654, 0.9977000139397925, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.826683256183537, 0.45472933508594915`, 0.}, 
      Optica`Optica`RayEnd :> {5.865410312505054, 0.6554846140465254, 0.}, 
      RotationMatrix :> {{0.18941463488272425`, 0.981897192221387, 
       0.}, {-0.981897192221387, 0.18941463488272425`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.9103689088356735`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20445651596823403`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.562638457816357`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4012676849529541, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.18941463488272425`, 0.981897192221387, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.865410312505054, 0.6554846140465254, 0.}, 
      Optica`Optica`RayEnd :> {6.068810334202852, 0.6347265289902424, 0.}, 
      RotationMatrix :> {{0.9948326700891261, -0.10152811691023872`, 0.}, {
       0.10152811691023872`, 0.9948326700891261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07698812271861409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20445651596823386`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.865234101449342`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1568425033036861, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9948326700891261, -0.10152811691023872`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.717216724786908, 0.33624574206176727`, 0.}, 
      Optica`Optica`RayEnd :> {5.623040498948695, 0.3888634059114886, 0.}, 
      RotationMatrix :> {{-0.8729838495118031, 0.4877491142908955, 
       0.}, {-0.4877491142908955, -0.8729838495118031, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2953483541874244, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1078785431034938, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.322123813402419`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1527130991181252, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8729838495118031, 0.4877491142908955, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.623040498948695, 0.3888634059114886, 0.}, 
      Optica`Optica`RayEnd :> {5.324433384014403, 0.5643586341087806, 0.}, 
      RotationMatrix :> {{-0.8621310028322385, 0.5066854388626915, 
       0.}, {-0.5066854388626915, -0.8621310028322385, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29454855432140103`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3463593281685959, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.83473561909194, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16006185115881488`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8621310028322385, 0.5066854388626915, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.602324795163315, 0.28453227557864835`, 0.}, 
      Optica`Optica`RayEnd :> {5.11645815730649, -0.0620488094172342, 0.}, 
      RotationMatrix :> {{-0.8141030179567975, -0.5807204802257572, 0.}, {
       0.5807204802257572, -0.8141030179567975, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017486056569061072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5968122303197364, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.16376578103201, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22465539936752438`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8141030179567975, -0.5807204802257572, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.11645815730649, -0.0620488094172342, 0.}, 
      Optica`Optica`RayEnd :> {4.960778241183477, -0.13227393548212463`, 0.}, 
      RotationMatrix :> {{-0.9115504669414317, -0.4111882126458123, 0.}, {
       0.4111882126458123, -0.9115504669414317, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01646435116614683, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17078584430478472`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.416528830603092`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3087958313064085, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9115504669414317, -0.4111882126458123, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.446013302160968, -0.26798629236588783`, 0.},
       Optica`Optica`RayEnd :> {5.408512329344934, -0.4038070907651124, 0.}, 
      RotationMatrix :> {{-0.266147729902546, -0.96393225170015, 0.}, {
       0.96393225170015, -0.266147729902546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17643786636530676`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.140902846812801, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.384205154148228`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4189919327987829, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.266147729902546, -0.96393225170015, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.408512329344934, -0.4038070907651124, 0.}, 
      Optica`Optica`RayEnd :> {5.368665699292367, -0.6386508757579388, 0.}, 
      RotationMatrix :> {{-0.16728206915382476`, -0.9859090776230914, 0.}, {
       0.9859090776230914, -0.16728206915382476`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17463190914910087`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23820024617179367`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.736741518482482`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3055436864776241, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.16728206915382476`, -0.9859090776230914, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3289129465642615`, -0.373110817031439, 0.}, 
      Optica`Optica`RayEnd :> {5.142156563325427, -0.4511357329145888, 0.}, 
      RotationMatrix :> {{-0.9227085679539582, -0.3854982472390188, 0.}, {
       0.3854982472390188, -0.9227085679539582, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18585178179263037`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20240018324849182`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.6995113887534, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2862376263562592, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9227085679539582, -0.3854982472390188, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.142156563325427, -0.4511357329145888, 0.}, 
      Optica`Optica`RayEnd :> {4.862033541413417, -0.5694760611249675, 0.}, 
      RotationMatrix :> {{-0.9211715769080618, -0.38915668553516414`, 0.}, {
       0.38915668553516414`, -0.9211715769080618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18539225864127637`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30409429571443264`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.14957094641076, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17695851153888617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9211715769080618, -0.38915668553516414`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.173926973483606, -0.3458526601738012, 0.}, 
      Optica`Optica`RayEnd :> {4.873260489996408, -0.17770917402864797`, 0.}, 
      RotationMatrix :> {{-0.8727901801440048, 0.48809558638057327`, 
       0.}, {-0.48809558638057327`, -0.8727901801440048, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0693410343590504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.344488847752149, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.122810002969645`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3149851727870629, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8727901801440048, 0.48809558638057327`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.873260489996408, -0.17770917402864797`, 0.},
       Optica`Optica`RayEnd :> {4.6598052417380575`, -0.08667403832027229, 
       0.}, RotationMatrix :> {{-0.9198389811837516, 0.39229612373159883`, 
       0.}, {-0.39229612373159883`, -0.9198389811837516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06854912906343096, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2320571889480614, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.466254642612776`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3985446421528405, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9198389811837516, 0.39229612373159883`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.099721637990405, -0.2070822485170844, 0.}, 
      Optica`Optica`RayEnd :> {5.082806838587439, -0.09899688104197428, 0.}, 
      RotationMatrix :> {{-0.15461298102288035`, 0.9879751141092664, 
       0.}, {-0.9879751141092664, -0.15461298102288035`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02587104088863533, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10940090082386048`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.040691957867086`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0751790541254807, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.15461298102288035`, 0.9879751141092664, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.082806838587439, -0.0989968810419743, 0.}, 
      Optica`Optica`RayEnd :> {5.023892590390386, 0.17942858185625338`, 0.}, 
      RotationMatrix :> {{-0.20701426751819224`, 0.9783379237481832, 
       0.}, {-0.9783379237481832, -0.20701426751819224`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025765386163769534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2845902792273769, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.461885571123604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13149199614344578`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20701426751819224`, 0.9783379237481832, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.163112851191095, -0.0630502622918786, 0.}, 
      Optica`Optica`RayEnd :> {5.5353880389761905`, 0.33622452132097363`, 0.},
       RotationMatrix :> {{0.6819448888048971, 0.7314035607193039, 
       0.}, {-0.7314035607193039, 0.6819448888048971, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009652448407327154, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5459021599787984, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.85850344891605, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13623023485727218`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.6819448888048971, 0.7314035607193039, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5353880389761905`, 0.33622452132097363`, 
       0.}, Optica`Optica`RayEnd :> {5.668226346046645, 0.5234462570138415, 
       0.}, RotationMatrix :> {{0.5786637668296475, 0.815566211265844, 
       0.}, {-0.815566211265844, 0.5786637668296475, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00946646097670723, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22956043679431032`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.19825289537163, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4090873832053674, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5786637668296475, 0.815566211265844, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.2072759558879405`, -0.40840447476237973`, 
       0.}, Optica`Optica`RayEnd :> {4.122525323515495, -0.44061256833959456`,
        0.}, RotationMatrix :> {{-0.9347731302688989, -0.3552452602460506, 
       0.}, {0.3552452602460506, -0.9347731302688989, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24013804168785682`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09066438649992627, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.530037212770347`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3202977342459794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9347731302688989, -0.3552452602460506, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.122525323515495, -0.44061256833959456`, 0.},
       Optica`Optica`RayEnd :> {3.836599226409276, -0.5489259410795577, 0.}, 
      RotationMatrix :> {{-0.93515074200629, -0.3542500384263707, 0.}, {
       0.3542500384263707, -0.93515074200629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2395460462025737, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30575401832306526`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.982553159888484`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18187936175766015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.93515074200629, -0.3542500384263707, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.118958057251666, 0.730693687402561, 0.}, 
      Optica`Optica`RayEnd :> {2.874401641472924, 0.8353535702065428, 0.}, 
      RotationMatrix :> {{-0.919349085961141, 0.3934428270313421, 
       0.}, {-0.3934428270313421, -0.919349085961141, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26892762342886484`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2660103974792871, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.08579932402954, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12633756237227736`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.919349085961141, 0.3934428270313421, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.874401641472924, 0.8353535702065428, 0.}, 
      Optica`Optica`RayEnd :> {2.700765721031118, 0.872423121498889, 0.}, 
      RotationMatrix :> {{-0.9779615411699503, 0.20878511439395192`, 
       0.}, {-0.20878511439395192`, -0.9779615411699503, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2536702204654676, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17754882286483611`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.348571581869498`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38599837952821525`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9779615411699503, 0.20878511439395192`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.700765721031118, 0.872423121498889, 0.}, 
      Optica`Optica`RayEnd :> {2.594207019314376, 0.7304061239629206, 0.}, 
      RotationMatrix :> {{-0.6001656333022449, -0.7998757482277578, 0.}, {
       0.7998757482277578, -0.6001656333022449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014391785879441892`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17754882286483611`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.611343839709455`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.037463767002821335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 42, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6001656333022449, -0.7998757482277578, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1566020874311045`, 1.3948686334667941`, 0.},
       Optica`Optica`RayEnd :> {4.288513573205669, 1.5843620745615243`, 0.}, 
      RotationMatrix :> {{0.5713270289417913, 0.8207225024334021, 
       0.}, {-0.8207225024334021, 0.5713270289417913, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011904869402086862`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23088612842086265`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.054660798253845`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24351973363473522`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5713270289417913, 0.8207225024334021, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.288513573205669, 1.5843620745615243`, 0.}, 
      Optica`Optica`RayEnd :> {4.434230233882032, 1.8265236218852379`, 0.}, 
      RotationMatrix :> {{0.515587347952126, 0.8568370245453295, 
       0.}, {-0.8568370245453295, 0.515587347952126, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01184349004149321, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28262264629870976`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.472942314775937`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2717869671677527, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.515587347952126, 0.8568370245453295, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.962953264961906, 0.8250378530382365, 0.}, 
      Optica`Optica`RayEnd :> {2.872577200713656, 0.8371273671687086, 0.}, 
      RotationMatrix :> {{-0.9911712418568374, 0.13258796821723612`, 
       0.}, {-0.13258796821723612`, -0.9911712418568374, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06272761080422067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09118107995036416, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.798724020467008`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1188548633701251, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9911712418568374, 0.13258796821723612`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.872577200713656, 0.8371273671687086, 0.}, 
      Optica`Optica`RayEnd :> {2.647719817861916, 0.8400449151302908, 0.}, 
      RotationMatrix :> {{-0.9999158339632128, 0.012974012087726763`, 
       0.}, {-0.012974012087726763`, -0.9999158339632128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06179549669042663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22487630979950307`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.131540958970271`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37002308138249973`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9999158339632128, 0.012974012087726763`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8527497331871134`, 0.9455596562108208, 0.}, 
      Optica`Optica`RayEnd :> {2.799054144884693, 1.0514884273813996`, 0.}, 
      RotationMatrix :> {{-0.45213236476252294`, 0.8919508533177425, 
       0.}, {-0.8919508533177425, -0.45213236476252294`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2448536484976005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11876077115298585`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.077380365009034`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14629085791748353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45213236476252294`, 0.8919508533177425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.799054144884693, 1.0514884273813996`, 0.}, 
      Optica`Optica`RayEnd :> {2.651432219296955, 1.3603774696099153`, 0.}, 
      RotationMatrix :> {{-0.43119965194147714`, 0.9022565378901662, 
       0.}, {-0.9022565378901662, -0.43119965194147714`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24418185216005425`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3423516807656731, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.58406085254223, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3934674176173692, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.43119965194147714`, 0.9022565378901662, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.88965565168125, 1.1046454086706592`, 0.}, 
      Optica`Optica`RayEnd :> {2.8897054905365716`, 1.104736744939623, 0.}, 
      RotationMatrix :> {{0.47899339421294007`, 0.8778185053303256, 
       0.}, {-0.8778185053303256, 0.47899339421294007`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04274016272588291, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.00010404914957834294`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.160079915854984`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1534480098790993, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.47899339421294007`, 0.8778185053303256, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8897054905365716`, 1.104736744939623, 0.}, 
      Optica`Optica`RayEnd :> {2.9294255861950274`, 1.2662841266646672`, 0.}, 
      RotationMatrix :> {{0.23876164803439073`, 0.9710782025294882, 
       0.}, {-0.9710782025294882, 0.23876164803439073`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.036462914946855426`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16635877656839743`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.406290905176213`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3566203076408562, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.23876164803439073`, 0.9710782025294882, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.964069326973405, -0.6132710566160591, 0.}, 
      Optica`Optica`RayEnd :> {2.9168138999373223`, -0.7051666635248719, 0.}, 
      RotationMatrix :> {{-0.45730843905955176`, -0.8893081533219607, 0.}, {
       0.8893081533219607, -0.45730843905955176`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012847936468866497`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10333381805344069`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.379267281013163`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2745597872243769, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45730843905955176`, -0.8893081533219607, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9168138999373223`, -0.7051666635248719, 0.},
       Optica`Optica`RayEnd :> {2.7903414601329137`, -0.9150460813852921, 0.},
       RotationMatrix :> {{-0.5161295742032981, -0.8565105151909823, 0.}, {
       0.8565105151909823, -0.5161295742032981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012780536450395506`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2450400948243138, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.741926621353148`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24117763257177255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 41, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5161295742032981, -0.8565105151909823, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6545398615910583`, -1.280178969740208, 0.}, 
      Optica`Optica`RayEnd :> {2.503822008840952, -1.3552129096803736`, 0.}, 
      RotationMatrix :> {{-0.8951979687337348, -0.4456687074217739, 0.}, {
       0.4456687074217739, -0.8951979687337348, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3657890639256037, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16836259465970213`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 10.874699079812702`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17703669313984083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8951979687337348, -0.4456687074217739, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.503822008840952, -1.3552129096803736`, 0.}, 
      Optica`Optica`RayEnd :> {2.335531677235352, -1.4663065767668944`, 0.}, 
      RotationMatrix :> {{-0.8345591361865511, -0.5509183680070552, 0.}, {
       0.5509183680070552, -0.8345591361865511, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.36018625998912585`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20165177554054278`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.173143707612706`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11991566619494523`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8345591361865511, -0.5509183680070552, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4528534018009265`, -1.0906598151282794`, 
       0.}, Optica`Optica`RayEnd :> {
       3.3747794230132278`, -1.2100033118374303`, 0.}, 
      RotationMatrix :> {{-0.5474541412105977, -0.8368356847502183, 0.}, {
       0.8368356847502183, -0.5474541412105977, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26971478643623065`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1426128197972019, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.09522083472607, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3780422879275489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5474541412105977, -0.8368356847502183, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3747794230132278`, -1.2100033118374303`, 
       0.}, Optica`Optica`RayEnd :> {3.2175576221075644`, -1.407368696474002, 
       0.}, RotationMatrix :> {{-0.6230734386558696, -0.7821633397453182, 
       0.}, {0.7821633397453182, -0.6230734386558696, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26736266828727917`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2523326965194204, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.468673225574813`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23443997703986008`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6230734386558696, -0.7821633397453182, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.0215053031803265`, -0.1365688422437436, 0.},
       Optica`Optica`RayEnd :> {3.8714170205849907`, -0.1899383071354556, 0.},
       RotationMatrix :> {{-0.9422052929995457, -0.3350360963293958, 0.}, {
       0.3350360963293958, -0.9422052929995457, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009151248436518955, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15929467145904477`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.900546445341586`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3357216018531316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9422052929995457, -0.3350360963293958, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8714170205849907`, -0.1899383071354556, 0.},
       Optica`Optica`RayEnd :> {3.5497612598705612`, -0.30326694863810244`, 
       0.}, RotationMatrix :> {{-0.943171414727655, -0.3323066090835899, 
       0.}, {0.3323066090835899, -0.943171414727655, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00912865539563651, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3410363754581229, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.405280281019609`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17915321385408342`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.943171414727655, -0.3323066090835899, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7095927179649006`, 0.3694555953323202, 0.}, 
      Optica`Optica`RayEnd :> {3.5830711532181354`, 0.39482902294536726`, 0.},
       RotationMatrix :> {{-0.9804775398039611, 0.19663111132262778`, 
       0.}, {-0.19663111132262778`, -0.9804775398039611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21909325300248375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12904075780467364`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.267385419374229`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1583783172010458, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9804775398039611, 0.19663111132262778`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5830711532181354`, 0.39482902294536726`, 
       0.}, Optica`Optica`RayEnd :> {3.3199501454438773`, 
       0.46261288869489703`, 0.}, 
      RotationMatrix :> {{-0.9683826067583299, 0.24946969140146397`, 
       0.}, {-0.24946969140146397`, -0.9683826067583299, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.218184456874832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27171182747184813`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.669518924032564`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10941940776492415`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9683826067583299, 0.24946969140146397`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.232349480833086, 0.9075335520499725, 0.}, 
      Optica`Optica`RayEnd :> {4.269784719445412, 1.1122674644837052`, 0.}, 
      RotationMatrix :> {{0.17986619827761616`, 0.9836910850044117, 
       0.}, {-0.9836910850044117, 0.17986619827761616`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009381431981690535, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20812825850995134`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.740079498898995`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20467872675588336`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17986619827761616`, 0.9836910850044117, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.269784719445412, 1.1122674644837052`, 0.}, 
      Optica`Optica`RayEnd :> {4.316627609022407, 1.4150762881589727`, 0.}, 
      RotationMatrix :> {{0.15287621745698116`, 0.9882453451122576, 
       0.}, {-0.9882453451122576, 0.15287621745698116`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009354671397241844, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3064105742292875, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.19356714875834, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.057270820678346254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15287621745698116`, 0.9882453451122576, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.618099162223654, 0.631822219651038, 0.}, 
      Optica`Optica`RayEnd :> {5.645647895609862, 0.6786811532817432, 0.}, 
      RotationMatrix :> {{0.5068103792978771, 0.8620575615560379, 
       0.}, {-0.8620575615560379, 0.5068103792978771, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011648799886672645`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.054357082079441975`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.247180100217511`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3023109729977167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5068103792978771, 0.8620575615560379, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.645647895609862, 0.6786811532817432, 0.}, 
      Optica`Optica`RayEnd :> {5.799127858721389, 0.9180940447729026, 0.}, 
      RotationMatrix :> {{0.5396914380146275, 0.8418629055456142, 
       0.}, {-0.8418629055456142, 0.5396914380146275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011610786720315793`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28438465445391625`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.668069388809307`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1501288793974286, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5396914380146275, 0.8418629055456142, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.9705929431190015`, 0.6843149737851442, 0.}, 
      Optica`Optica`RayEnd :> {4.899941011965765, 0.7458439041177413, 0.}, 
      RotationMatrix :> {{-0.7541166040180155, 0.6567405481195263, 
       0.}, {-0.6567405481195263, -0.7541166040180155, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4510426663153465, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09368833782043083, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.49983511010822, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3828069356111753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7541166040180155, 0.6567405481195263, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.899941011965765, 0.7458439041177413, 0.}, 
      Optica`Optica`RayEnd :> {4.71671549254766, 0.8729662902272273, 0.}, 
      RotationMatrix :> {{-0.8216168622383428, 0.5700401141021745, 
       0.}, {-0.5700401141021745, -0.8216168622383428, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4455559388258916, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22300603582908657`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.829884043135268`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3244292278095978, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8216168622383428, 0.5700401141021745, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.698679316809952, 0.14323389961481361`, 0.}, 
      Optica`Optica`RayEnd :> {4.655763772139483, 0.1366737163587785, 0.}, 
      RotationMatrix :> {{-0.9885173560903553, -0.15110736814640574`, 0.}, {
       0.15110736814640574`, -0.9885173560903553, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010061315303617036`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04341405277920694, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.728915766450275`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14931504021982187`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9885173560903553, -0.15110736814640574`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.655763772139483, 0.1366737163587785, 0.}, 
      Optica`Optica`RayEnd :> {4.397708205712049, 0.08057332563951655, 0.}, 
      RotationMatrix :> {{-0.9771752991818241, -0.21243454208040694`, 0.}, {
       0.21243454208040694`, -0.9771752991818241, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010013157072089955`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2640831861422415, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.119758881940792`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1552928998926695, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9771752991818241, -0.21243454208040694`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.050783306785948, -0.26091767258249676`, 0.},
       Optica`Optica`RayEnd :> {5.883599341133357, -0.36116449926156435`, 0.},
       RotationMatrix :> {{-0.8576367240922441, -0.5142560155100997, 0.}, {
       0.5142560155100997, -0.8576367240922441, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.030946525278727734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1949356422785467, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.605737044508452`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23593369186020247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 19, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8576367240922441, -0.5142560155100997, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.883599341133357, -0.36116449926156435`, 0.},
       Optica`Optica`RayEnd :> {5.734567675388738, -0.42073563195442343`, 0.},
       RotationMatrix :> {{-0.928565899202874, -0.3711675778372323, 0.}, {
       0.3711675778372323, -0.928565899202874, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.029968592048010056`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16049659574248362`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.843272006207327`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35095406772873755`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.928565899202874, -0.3711675778372323, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.266462557308947, -0.4372999424005015, 0.}, 
      Optica`Optica`RayEnd :> {6.381514964835767, -0.5186948359539496, 0.}, 
      RotationMatrix :> {{0.8163609035358363, -0.5775420981869226, 0.}, {
       0.5775420981869226, 0.8163609035358363, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.5744859607118045`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14093326496712716`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.945729174291772`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07085848419638827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8163609035358363, -0.5775420981869226, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.381514964835767, -0.5186948359539496, 0.}, 
      Optica`Optica`RayEnd :> {6.639330255385841, -0.6831522198358223, 0.}, 
      RotationMatrix :> {{0.8430787365638333, -0.537790148621124, 0.}, {
       0.537790148621124, 0.8430787365638333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.553628102947669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3058021503434675, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.398316356800104`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026869919721666847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8430787365638333, -0.537790148621124, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.639330255385841, -0.6831522198358223, 0.}, 
      Optica`Optica`RayEnd :> {6.593103752960103, -0.3808641690826178, 0.}, 
      RotationMatrix :> {{-0.1511647395998275, 0.9885085844350145, 
       0.}, {-0.9885085844350145, -0.1511647395998275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02077981465243545, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30580215034346747`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.850903539308435`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1235697928932768, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1511647395998275, 0.9885085844350145, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.340928797522072, -0.1688171249226691, 0.}, 
      Optica`Optica`RayEnd :> {6.364726631954419, -0.05188299846126178, 0.}, 
      RotationMatrix :> {{0.19942681782767357`, 0.9799127228131737, 
       0.}, {-0.9799127228131737, 0.19942681782767357`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03060762434679379, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11933116464261023`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.329137675237543`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2706875525341686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19942681782767357`, 0.9799127228131737, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.364726631954419, -0.05188299846126178, 0.}, 
      Optica`Optica`RayEnd :> {6.435475922970339, 0.18220880631998992`, 0.}, 
      RotationMatrix :> {{0.2893046374913776, 0.9572370796861049, 
       0.}, {-0.9572370796861049, 0.2893046374913776, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0303439986044081, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24454945357738808`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.691070866532078`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4023953250998421, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2893046374913776, 0.9572370796861049, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.078954373256245, 0.2500927233677525, 0.}, 
      Optica`Optica`RayEnd :> {5.8171415788764795`, 0.20293311017655968`, 0.},
       RotationMatrix :> {{-0.9841614853167712, -0.1772742813244109, 0.}, {
       0.1772742813244109, -0.9841614853167712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2113051996916409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2660262551277307, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.591219241692722`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3930429168148243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 20, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9841614853167712, -0.1772742813244109, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8171415788764795`, 0.2029331101765597, 0.}, 
      Optica`Optica`RayEnd :> {5.593901268418461, 0.16989544610745042`, 0.}, 
      RotationMatrix :> {{-0.9892259175738551, -0.14639700816671014`, 0.}, {
       0.14639700816671014`, -0.9892259175738551, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21067610754528882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22567171612884007`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.925213381563404`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21142897696779941`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9892259175738551, -0.14639700816671014`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.385877384362597, 0.3672198357910872, 0.}, 
      Optica`Optica`RayEnd :> {6.46397806998668, 0.3961971742504616, 0.}, 
      RotationMatrix :> {{0.9375485882639469, 0.34785434400662535`, 
       0.}, {-0.34785434400662535`, 0.9375485882639469, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      83.83761926703055, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08330308061014889, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.832568761171759`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27089556419442856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9375485882639469, 0.34785434400662535`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.46397806998668, 0.3961971742504616, 0.}, 
      Optica`Optica`RayEnd :> {6.5901068238903555`, 0.47152052588080945`, 0.},
       RotationMatrix :> {{0.8585538856563496, 0.5127233419929145, 
       0.}, {-0.5127233419929145, 0.8585538856563496, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      79.87033702506476, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14690837233501414`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.04999315222758, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2831776174003318, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8585538856563496, 0.5127233419929145, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5901068238903555`, 0.4715205258808095, 0.}, 
      Optica`Optica`RayEnd :> {6.569286664841523, 0.616946076728329, 0.}, 
      RotationMatrix :> {{-0.14172207286697952`, 0.9899064875341942, 
       0.}, {-0.9899064875341942, -0.14172207286697952`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7795463720183426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1469083723350142, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.267417543283402`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1561793914964976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.14172207286697952`, 0.9899064875341942, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.569286664841523, 0.616946076728329, 0.}, 
      Optica`Optica`RayEnd :> {6.427090072857617, 0.65385405811834, 0.}, 
      RotationMatrix :> {{-0.967927080831294, 0.25123130018651946`, 
       0.}, {-0.25123130018651946`, -0.967927080831294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17885201578345836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1469083723350143, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.484841934339224`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37793054589963226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.967927080831294, 0.25123130018651946`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.427090072857617, 0.65385405811834, 0.}, 
      Optica`Optica`RayEnd :> {6.338170829330356, 0.5369120297766741, 0.}, 
      RotationMatrix :> {{-0.605270088518074, -0.7960201755893643, 0.}, {
       0.7960201755893643, -0.605270088518074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008463461061525249, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14690837233501436`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.702266325395046`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.031371104521828785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 48, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.605270088518074, -0.7960201755893643, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.10438412011554, 0.19786211558100952`, 0.}, 
      Optica`Optica`RayEnd :> {6.081452134150184, 0.18435347933583313`, 0.}, 
      RotationMatrix :> {{-0.8616182468814945, -0.5075568900535776, 0.}, {
       0.5075568900535776, -0.8616182468814945, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21024671262394828`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02661501894644841, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.242805331874997`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09522270847788408, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8616182468814945, -0.5075568900535776, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.081452134150184, 0.18435347933583313`, 0.}, 
      Optica`Optica`RayEnd :> {5.850888149584709, 0.023020528021387685`, 0.}, 
      RotationMatrix :> {{-0.8193351445083715, -0.5733148532642821, 0.}, {
       0.5733148532642821, -0.8193351445083715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20888941283739879`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2814037529219139, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.65928288619943, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.008860295732218635, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8193351445083715, -0.5733148532642821, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.826683256183537, 0.45472933508594915`, 0.}, 
      Optica`Optica`RayEnd :> {5.668343071788032, 0.5220777142812463, 0.}, 
      RotationMatrix :> {{-0.9202183251342401, 0.39140545996081016`, 
       0.}, {-0.39140545996081016`, -0.9202183251342401, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07821442192863452, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17206806262242863`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.490614018097425`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41130715317541283`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9202183251342401, 0.39140545996081016`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.668343071788032, 0.5220777142812463, 0.}, 
      Optica`Optica`RayEnd :> {5.367192815857526, 0.6330714094465906, 0.}, 
      RotationMatrix :> {{-0.9382990414282795, 0.3458249685242107, 
       0.}, {-0.3458249685242107, -0.9382990414282795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07791643761151348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.320953387602416, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.965625031749001`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3542744208367552, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9382990414282795, 0.3458249685242107, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.865410312505054, 0.6554846140465254, 0.}, 
      Optica`Optica`RayEnd :> {5.865531100028655, 0.6558574549179828, 0.}, 
      RotationMatrix :> {{0.3081956840279179, 0.9513229842417154, 
       0.}, {-0.9513229842417154, 0.3081956840279179, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.833380786117062, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0003919182839407598, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.563163628316838`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09494436732138734, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3081956840279179, 0.9513229842417154, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.865531100028655, 0.6558574549179828, 0.}, 
      Optica`Optica`RayEnd :> {5.898362925789411, 0.8443488925545409, 0.}, 
      RotationMatrix :> {{0.17159840874151186`, 0.9851669838750079, 
       0.}, {-0.9851669838750079, 0.17159840874151186`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.725890388587162, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19132943015929646`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.846331184952597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2553301710782405, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.17159840874151186`, 0.9851669838750079, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.898362925789411, 0.8443488925545409, 0.}, 
      Optica`Optica`RayEnd :> {5.720389387508421, 0.9145797299183803, 0.}, 
      RotationMatrix :> {{-0.9301942630196168, 0.36706761372448937`, 
       0.}, {-0.36706761372448937`, -0.9301942630196168, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10509989984878894`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19132943015929665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.129498741588355`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3694515455888065, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9301942630196168, 0.36706761372448937`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.068810334202852, 0.6347265289902424, 0.}, 
      Optica`Optica`RayEnd :> {6.345098640148805, 0.5716557199086093, 0.}, 
      RotationMatrix :> {{0.9749204048979498, -0.22255382295888898`, 0.}, {
       0.22255382295888898`, 0.9749204048979498, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07578105026646675, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.283395756779625, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.24498441553404, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16242314970763216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9749204048979498, -0.22255382295888898`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.345098640148805, 0.5716557199086093, 0.}, 
      Optica`Optica`RayEnd :> {6.601759200889874, 0.5103319550200578, 0.}, 
      RotationMatrix :> {{0.9726230928618069, -0.23238829409402662`, 0.}, {
       0.23238829409402662`, 0.9726230928618069, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07559040039126813, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2638849135134979, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.635534087534017`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.394439204991071, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9726230928618069, -0.23238829409402662`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.324433384014403, 0.5643586341087806, 0.}, 
      Optica`Optica`RayEnd :> {5.25685805736425, 0.6060839947188786, 0.}, 
      RotationMatrix :> {{-0.8508674639540593, 0.5253803943662032, 
       0.}, {-0.5253803943662032, -0.8508674639540593, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29375092030399896`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07941933322508876, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.94115752561356, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2033536368899778, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8508674639540593, 0.5253803943662032, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.25685805736425, 0.6060839947188786, 0.}, 
      Optica`Optica`RayEnd :> {5.090506017080307, 0.737171203163886, 0.}, 
      RotationMatrix :> {{-0.785441255621421, 0.618936211549983, 
       0.}, {-0.618936211549983, -0.785441255621421, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2898582568283681, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21179437557342073`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.254613201462224`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0654462795249977, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.785441255621421, 0.618936211549983, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.960778241183477, -0.13227393548212468`, 0.},
       Optica`Optica`RayEnd :> {4.862506407101621, -0.15506615480032948`, 0.},
       RotationMatrix :> {{-0.9741427829105711, -0.2259332611707447, 0.}, {
       0.2259332611707447, -0.9741427829105711, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015502343724646688`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10088031837410609`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.551708457224393`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25107397040858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9741427829105711, -0.2259332611707447, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.862506407101621, -0.15506615480032948`, 0.},
       Optica`Optica`RayEnd :> {4.561073218499606, -0.23407451704225998`, 0.},
       RotationMatrix :> {{-0.9673237757503729, -0.253544301588583, 0.}, {
       0.253544301588583, -0.9673237757503729, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0154576254827468, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31161561015926315`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.012899560260102`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.00421579940482858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9673237757503729, -0.253544301588583, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.368665699292367, -0.6386508757579388, 0.}, 
      Optica`Optica`RayEnd :> {5.346770984931949, -0.966173849270861, 0.}, 
      RotationMatrix :> {{-0.06670052935029462, -0.9977730400168118, 0.}, {
       0.9977730400168118, -0.06670052935029462, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17284443708879696`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3282539819951476, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.17660185435598, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19261186261765134`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.06670052935029462, -0.9977730400168118, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.346770984931949, -0.966173849270861, 0.}, 
      Optica`Optica`RayEnd :> {5.3706584693009765`, -1.1285576357412543`, 0.},
       RotationMatrix :> {{0.14553881220331744`, -0.9893525428998741, 0.}, {
       0.9893525428998741, 0.14553881220331744`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.159651211132068, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1641313681717874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.419516279250224`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31732879913581796`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14553881220331744`, -0.9893525428998741, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.370658469300976, -1.1285576357412543`, 0.}, 
      Optica`Optica`RayEnd :> {5.525299534917696, -1.1835598797215485`, 0.}, 
      RotationMatrix :> {{0.9421786178914109, -0.3351111039464828, 0.}, {
       0.3351111039464828, 0.9421786178914109, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012186186250522457`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16413136817178714`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.66243070414447, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15909237984661712`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 46, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9421786178914109, -0.3351111039464828, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.862033541413417, -0.5694760611249675, 0.}, 
      Optica`Optica`RayEnd :> {4.843546772902948, -0.577372549175145, 0.}, 
      RotationMatrix :> {{-0.9196200806226859, -0.3928089959707195, 0.}, {
       0.3928089959707195, -0.9196200806226859, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18493387167233927`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02010261509073525, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.176508450632346`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014185212150559987`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9196200806226859, -0.3928089959707195, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.843546772902948, -0.577372549175145, 0.}, 
      Optica`Optica`RayEnd :> {4.62020904994084, -0.6927533534632233, 0.}, 
      RotationMatrix :> {{-0.8884427008225914, -0.45898754596945146`, 0.}, {
       0.45898754596945146`, -0.8884427008225914, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18385079305088364`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2513811219961893, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.548552511186706`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.060779918600043836`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8884427008225914, -0.45898754596945146`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6598052417380575`, -0.08667403832027229, 
       0.}, Optica`Optica`RayEnd :> {4.644180013893946, -0.08190306712637067, 
       0.}, RotationMatrix :> {{-0.9564097798239777, 0.2920279662242139, 
       0.}, {-0.2920279662242139, -0.9564097798239777, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0677662676767037, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01633737773675604, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.488146728780029`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09804229918705785, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9564097798239777, 0.2920279662242139, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.644180013893946, -0.08190306712637067, 0.}, 
      Optica`Optica`RayEnd :> {4.3916852340172055`, 0.011356320668955006`, 
       0.}, RotationMatrix :> {{-0.9380595944041554, 0.34647394901537903`, 
       0.}, {-0.34647394901537903`, -0.9380595944041554, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06746903671021276, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26916709917254455`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.886514035555395`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07086802159870237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9380595944041554, 0.34647394901537903`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.023892590390386, 0.17942858185625332`, 0.}, 
      Optica`Optica`RayEnd :> {4.963593281354314, 0.40446042622468326`, 0.}, 
      RotationMatrix :> {{-0.2588278880665669, 0.9659234567806086, 
       0.}, {-0.9659234567806086, -0.2588278880665669, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025660162922156938`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23297067980774966`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.774066282065988`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4054793105792124, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2588278880665669, 0.9659234567806086, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.963593281354314, 0.40446042622468326`, 0.}, 
      Optica`Optica`RayEnd :> {4.917328532690551, 0.6491059597694256, 0.}, 
      RotationMatrix :> {{-0.18581589410963678`, 0.982584578291475, 
       0.}, {-0.982584578291475, -0.18581589410963678`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025504774974547464`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24898165404766856`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.142559130056537`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34978735997273125`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.18581589410963678`, 0.982584578291475, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.668226346046645, 0.5234462570138415, 0.}, 
      Optica`Optica`RayEnd :> {5.7218301323823555`, 0.6254710583343828, 0.}, 
      RotationMatrix :> {{0.46511116514601436`, 0.8852522827174845, 
       0.}, {-0.8852522827174845, 0.46511116514601436`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009284057230028295, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11524940778164712`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.352687101799036`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36607540433313523`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.46511116514601436`, 0.8852522827174845, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.7218301323823555`, 0.6254710583343828, 0.}, 
      Optica`Optica`RayEnd :> {5.856008136082876, 0.892256352907218, 0.}, 
      RotationMatrix :> {{0.4493162704166326, 0.8933727604638994, 
       0.}, {-0.8933727604638994, 0.4493162704166326, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00925969124989129, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2986270752583752, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.794655173181432`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.055150279632332676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.4493162704166326, 0.8933727604638994, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.836599226409276, -0.5489259410795577, 0.}, 
      Optica`Optica`RayEnd :> {3.669827641570253, -0.6118987683239112, 0.}, 
      RotationMatrix :> {{-0.9355272941645352, -0.353254415221074, 0.}, {
       0.353254415221074, -0.9355272941645352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23895551012227334`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17826479877100415`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.22142799024163, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25362838280680616`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9355272941645352, -0.353254415221074, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.669827641570253, -0.6118987683239112, 0.}, 
      Optica`Optica`RayEnd :> {3.440801978911579, -0.6713898163737759, 0.}, 
      RotationMatrix :> {{-0.9678797305071055, -0.2514136576908511, 0.}, {
       0.2514136576908511, -0.9678797305071055, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23621957715124342`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23662615864336756`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.571634705033814`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42696209079840625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9678797305071055, -0.2514136576908511, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.874401641472924, 0.8353535702065428, 0.}, 
      Optica`Optica`RayEnd :> {2.7800941570748763`, 1.048199041125198, 0.}, 
      RotationMatrix :> {{-0.4050961835420712, 0.9142740738310632, 
       0.}, {-0.9142740738310632, -0.4050961835420712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015257402963397159`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23280269780239252`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.397754939084747`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1977948329616978, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4050961835420712, 0.9142740738310632, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7800941570748763`, 1.048199041125198, 0.}, 
      Optica`Optica`RayEnd :> {2.6522622387944037`, 1.3610242766510867`, 0.}, 
      RotationMatrix :> {{-0.3782727540213073, 0.9256941846879754, 
       0.}, {-0.9256941846879754, -0.3782727540213073, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015213052704004033`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33793583312974235`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.897899972116765`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39531153669233515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3782727540213073, 0.9256941846879754, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.700765721031118, 0.872423121498889, 0.}, 
      Optica`Optica`RayEnd :> {2.540332325001979, 0.8750370702415957, 0.}, 
      RotationMatrix :> {{-0.9998672947425328, 0.016290884084328106`, 
       0.}, {-0.016290884084328106`, -0.9998672947425328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2392784345860258, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1604546892099825, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.563580865410875`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07593147614194116, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9998672947425328, 0.016290884084328106`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.540332325001979, 0.8750370702415957, 0.}, 
      Optica`Optica`RayEnd :> {2.3652191267041047`, 0.8967965807865681, 0.}, 
      RotationMatrix :> {{-0.9923680335697468, 0.12331133747110881`, 
       0.}, {-0.12331133747110881`, -0.9923680335697468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2365152442046992, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17645993459498768`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.824741568611458`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3015942563136603, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9923680335697468, 0.12331133747110881`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.594207019314376, 0.7304061239629206, 0.}, 
      Optica`Optica`RayEnd :> {2.5653768335927825`, 0.67067236065996, 0.}, 
      RotationMatrix :> {{-0.43466587704036574`, -0.9005917917329302, 0.}, {
       0.9005917917329302, -0.43466587704036574`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013575278918476414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06632723488187711, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.70022233445117, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.020645105970546085`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.43466587704036574`, -0.9005917917329302, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5653768335927825`, 0.67067236065996, 0.}, 
      Optica`Optica`RayEnd :> {2.423048150401369, 0.3838397198217184, 0.}, 
      RotationMatrix :> {{-0.44449416840075556`, -0.8957817447669498, 0.}, {
       0.8957817447669498, -0.44449416840075556`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013541004802550265`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3202037131409339, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.174123829899752`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38534301113681946`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.44449416840075556`, -0.8957817447669498, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.434230233882032, 1.8265236218852379`, 0.}, 
      Optica`Optica`RayEnd :> {4.442488502570082, 1.842571367732075, 0.}, 
      RotationMatrix :> {{0.45757332313709626`, 0.8891718922420314, 
       0.}, {-0.8891718922420314, 0.45757332313709626`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011782427141818165`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01804796798780154, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.49712659187959, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4049366527296472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.45757332313709626`, 0.8891718922420314, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.442488502570082, 1.842571367732075, 0.}, 
      Optica`Optica`RayEnd :> {4.592996513027466, 2.1249490237982482`, 0.}, 
      RotationMatrix :> {{0.47036095517733756`, 0.8824741196458188, 
       0.}, {-0.8824741196458188, 0.47036095517733756`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011752149891347843`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31998406500522175`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.970703008087318`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08511323023941678, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.47036095517733756`, 0.8824741196458188, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.647719817861916, 0.8400449151302908, 0.}, 
      Optica`Optica`RayEnd :> {2.4122339635400483`, 0.8147439907309327, 0.}, 
      RotationMatrix :> {{-0.9942776703189736, -0.10682656179562355`, 0.}, {
       0.10682656179562355`, -0.9942776703189736, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06087723352217307, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2368411373920542, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.448908083075624`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3890833067284579, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9942776703189736, -0.10682656179562355`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4122339635400483`, 0.8147439907309327, 0.}, 
      Optica`Optica`RayEnd :> {2.1679364592479047`, 0.7873630095557195, 0.}, 
      RotationMatrix :> {{-0.9937775471786597, -0.11138306300136665`, 0.}, {
       0.11138306300136665`, -0.9937775471786597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06072655287750267, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2458271521485925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.812732268255541`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0338606432267373, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9937775471786597, -0.11138306300136665`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.651432219296955, 1.3603774696099153`, 0.}, 
      Optica`Optica`RayEnd :> {2.6317869098812796`, 1.4040762764764532`, 0.}, 
      RotationMatrix :> {{-0.4100322002389416, 0.9120710469953602, 
       0.}, {-0.9120710469953602, -0.4100322002389416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24351189900647474`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047911625975295476`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.648262431349126`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25893636894280153`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4100322002389416, 0.9120710469953602, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6317869098812796`, 1.4040762764764532`, 0.},
       Optica`Optica`RayEnd :> {2.495720909980971, 1.6579704444939585`, 0.}, 
      RotationMatrix :> {{-0.472359695279891, 0.8814058760157483, 
       0.}, {-0.8814058760157483, -0.472359695279891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24218263486516475`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2880559058276222, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.074585171974007`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21277507255616118`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.472359695279891, 0.8814058760157483, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9294255861950274`, 1.2662841266646672`, 0.},
       Optica`Optica`RayEnd :> {2.9280989752410815`, 1.3428405400690842`, 0.},
       RotationMatrix :> {{-0.01732593996428833, 0.9998498946363669, 
       0.}, {-0.9998498946363669, -0.01732593996428833, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031107606560806533`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07656790665788844, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.508891900097783`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38446972738177027`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.01732593996428833, 0.9998498946363669, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9280989752410815`, 1.3428405400690842`, 0.},
       Optica`Optica`RayEnd :> {2.9343541138804152`, 1.6684119244566258`, 0.},
       RotationMatrix :> {{0.019209257242965398`, 0.9998154851952302, 
       0.}, {-0.9998154851952302, 0.019209257242965398`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031008827758712634`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32563146821432604`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.990826473054986`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37190736496495813`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.019209257242965398`, 0.9998154851952302, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7903414601329137`, -0.9150460813852921, 0.},
       Optica`Optica`RayEnd :> {2.4842168326986034`, -1.3533368486914512`, 
       0.}, RotationMatrix :> {{-0.5726097463694746, -0.8198280785400593, 
       0.}, {0.8198280785400593, -0.5726097463694746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012713490011077166`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5346130228750671, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.458308072005737`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23728312717586658`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5726097463694746, -0.8198280785400593, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4842168326986034`, -1.3533368486914512`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3495590308742202`, -1.5735559140602946`, 0.}, 
      RotationMatrix :> {{-0.5216741901514949, -0.8531447938830675, 0.}, {
       0.8531447938830675, -0.5216741901514949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012654263035535213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25812624884753926`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.840334920300096`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24072118058475644`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 45, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5216741901514949, -0.8531447938830675, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.335531677235352, -1.4663065767668944`, 0.}, 
      Optica`Optica`RayEnd :> {2.1968282486405424`, -1.5843271908251064`, 0.},
       RotationMatrix :> {{-0.761606751570431, -0.6480394709910309, 0.}, {
       0.6480394709910309, -0.761606751570431, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3546692743972801, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18211948398409436`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.417183816151391`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4321206009747099, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.761606751570431, -0.6480394709910309, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1968282486405424`, -1.5843271908251064`, 
       0.}, Optica`Optica`RayEnd :> {2.122821027838444, -1.6979744077857233`, 
       0.}, RotationMatrix :> {{-0.5456958604916653, -0.8379833100022103, 
       0.}, {0.8379833100022103, -0.5456958604916653, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2779633196139141, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13561990507939486`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.617901275668896`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05174895245824496, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5456958604916653, -0.8379833100022103, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.122821027838444, -1.6979744077857233`, 0.}, 
      Optica`Optica`RayEnd :> {2.17184458169658, -1.8244238040708087`, 0.}, 
      RotationMatrix :> {{0.3614775709320574, -0.9323808050968547, 0.}, {
       0.9323808050968547, 0.3614775709320574, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.060116405239702936`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13561990507939506`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 11.8186187351864, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37345005300224243`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3614775709320574, -0.9323808050968547, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.17184458169658, -1.8244238040708087`, 0.}, 
      Optica`Optica`RayEnd :> {2.3031174647941777`, -1.8584853486187098`, 0.},
       RotationMatrix :> {{0.9679470209092621, -0.25115446385219625`, 0.}, {
       0.25115446385219625`, 0.9679470209092621, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013001651383225262`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13561990507939523`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.019336194703904`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1496389734707451, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 53, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9679470209092621, -0.25115446385219625`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2175576221075644`, -1.407368696474002, 0.}, 
      Optica`Optica`RayEnd :> {3.1691153892197756`, -1.4577264201050941`, 0.},
       RotationMatrix :> {{-0.6932674216734224, -0.7206804299037715, 0.}, {
       0.7206804299037715, -0.6932674216734224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2650310623981845, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06987524780965147, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.562306057639747`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3316902588202187, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6932674216734224, -0.7206804299037715, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1691153892197756`, -1.4577264201050941`, 
       0.}, Optica`Optica`RayEnd :> {
       2.9545503044322277`, -1.6599496305216164`, 0.}, 
      RotationMatrix :> {{-0.7277265363988344, -0.6858673984240361, 0.}, {
       0.6858673984240361, -0.7277265363988344, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26402217744730205`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29484301321390105`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.99867371719632, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39311226480388517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7277265363988344, -0.6858673984240361, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5497612598705612`, -0.30326694863810244`, 
       0.}, Optica`Optica`RayEnd :> {3.404192993676753, -0.35408154355463156`,
        0.}, RotationMatrix :> {{-0.9441296293859127, -0.3295743359480816, 
       0.}, {0.3295743359480816, -0.9441296293859127, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009106118133536577, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15418249958799585`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.611884830467524`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.272591951734736, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9441296293859127, -0.3295743359480816, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.404192993676753, -0.35408154355463156`, 0.},
       Optica`Optica`RayEnd :> {3.1711990803001635`, -0.4115125146935025, 0.},
       RotationMatrix :> {{-0.970938787264056, -0.23932795780310312`, 0.}, {
       0.23932795780310312`, -0.970938787264056, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00902536925074922, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23996766473108738`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.967036974269533`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40784945243095694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.970938787264056, -0.23932795780310312`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3199501454438773`, 0.46261288869489703`, 
       0.}, Optica`Optica`RayEnd :> {3.1817374130547575`, 0.5063297872396552, 
       0.}, RotationMatrix :> {{-0.95344236908067, 0.3015752788970593, 
       0.}, {-0.3015752788970593, -0.95344236908067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2172794304223771, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14496181087734497`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.863767750608206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.369448648681519, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.95344236908067, 0.3015752788970593, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1817374130547575`, 0.5063297872396552, 0.}, 
      Optica`Optica`RayEnd :> {2.8956096724243867`, 0.5941363996724759, 0.}, 
      RotationMatrix :> {{-0.9559972745404482, 0.29337554613708816`, 
       0.}, {-0.29337554613708816`, -0.9559972745404482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21673588577882225`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.299297653089977, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.306728277181373`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18534253756761937`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9559972745404482, 0.29337554613708816`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.316627609022407, 1.4150762881589727`, 0.}, 
      Optica`Optica`RayEnd :> {4.339192280199492, 1.5930613960057278`, 0.}, 
      RotationMatrix :> {{0.12577170172073085`, 0.9920592114618314, 
       0.}, {-0.9920592114618314, 0.12577170172073085`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009327987147502123, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1794097628351116, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.43397623095739, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09860033243838158, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12577170172073085`, 0.9920592114618314, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.339192280199492, 1.5930613960057278`, 0.}, 
      Optica`Optica`RayEnd :> {4.3638619846663005`, 1.897890825549716, 0.}, 
      RotationMatrix :> {{0.08066580373739199, 0.9967412041785971, 
       0.}, {-0.9967412041785971, 0.08066580373739199, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009294433670189554, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3058260542115287, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.886598791190451`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.018493083516881555`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.08066580373739199, 0.9967412041785971, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.799127858721389, 0.9180940447729026, 0.}, 
      Optica`Optica`RayEnd :> {6.0516089093221535`, 1.2803718303013756`, 0.}, 
      RotationMatrix :> {{0.5717689025735088, 0.8204147256417853, 
       0.}, {-0.8204147256417853, 0.5717689025735088, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011572897601142393`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.44157884324306135`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.259785038755009`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.030409063087059936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5717689025735088, 0.8204147256417853, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.0516089093221535`, 1.2803718303013756`, 0.},
       Optica`Optica`RayEnd :> {6.186980434491088, 1.4262010764902882`, 0.}, 
      RotationMatrix :> {{0.6803395084496997, 0.7328970959435038, 
       0.}, {-0.7328970959435038, 0.6803395084496997, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011321684154192444`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1989764279270034, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.554270152086975`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3060839057686657, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.6803395084496997, 0.7328970959435038, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.71671549254766, 0.8729662902272273, 0.}, 
      Optica`Optica`RayEnd :> {4.656340914544981, 0.9056846679963191, 0.}, 
      RotationMatrix :> {{-0.8791975345792012, 0.47645744320962646`, 
       0.}, {-0.47645744320962646`, -0.8791975345792012, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4401359548638054, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06867009474904294, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.921901970098984`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20189078715298964`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8791975345792012, 0.47645744320962646`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.656340914544981, 0.9056846679963191, 0.}, 
      Optica`Optica`RayEnd :> {4.3477706183017695`, 1.0780641496062522`, 0.}, 
      RotationMatrix :> {{-0.8730119786442122, 0.4876987647551691, 
       0.}, {-0.4876987647551691, -0.8730119786442122, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4390147261340071, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35345482512441817`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.445015111283123`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18886930194987742`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8730119786442122, 0.4876987647551691, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.397708205712049, 0.08057332563951655, 0.}, 
      Optica`Optica`RayEnd :> {4.189373374273458, 0.021467253382598736`, 0.}, 
      RotationMatrix :> {{-0.9620323581845438, -0.2729354169137553, 0.}, {
       0.2729354169137553, -0.9620323581845438, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009965229348721485, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21655698965442333`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.409945248077719`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4265590464736081, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9620323581845438, -0.2729354169137553, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.189373374273458, 0.021467253382598736`, 0.},
       Optica`Optica`RayEnd :> {3.886363500432843, -0.05497944326763965, 0.}, 
      RotationMatrix :> {{-0.9696175416914782, -0.24462588343054456`, 0.}, {
       0.24462588343054456`, -0.9696175416914782, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009936213526491131, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31250452968499354`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.87245195201151, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24823706987915836`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9696175416914782, -0.24462588343054456`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.734567675388738, -0.42073563195442343`, 0.},
       Optica`Optica`RayEnd :> {5.628213718193005, -0.444562251532586, 0.}, 
      RotationMatrix :> {{-0.9758117699551414, -0.21861241871635323`, 0.}, {
       0.21861241871635323`, -0.9758117699551414, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02902156223520853, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10899023814871793`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.989318925326609`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2040878039891582, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9758117699551414, -0.21861241871635323`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.628213718193005, -0.444562251532586, 0.}, 
      Optica`Optica`RayEnd :> {5.335781837376667, -0.5225924266413898, 0.}, 
      RotationMatrix :> {{-0.9661951647411955, -0.257811760070665, 0.}, {
       0.257811760070665, -0.9661951647411955, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028924509565415823`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3026633660443425, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.437260707072236`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.052517653342319365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9661951647411955, -0.257811760070665, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.381514964835767, -0.5186948359539496, 0.}, 
      Optica`Optica`RayEnd :> {5.911232301346223, -0.6804740080385091, 0.}, 
      RotationMatrix :> {{-0.9456127023409506, -0.32529466207032165`, 0.}, {
       0.32529466207032165`, -0.9456127023409506, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020857857764136536`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4973311613997109, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.612152930567385`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34962697728596326`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 21, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9456127023409506, -0.32529466207032165`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.911232301346223, -0.6804740080385091, 0.}, 
      Optica`Optica`RayEnd :> {5.624663377518157, -0.777283667465705, 0.}, 
      RotationMatrix :> {{-0.9473994357690588, -0.3200536034861488, 0.}, {
       0.3200536034861488, -0.9473994357690588, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020806130667997542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30247951709559684`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.059822615868868`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1848694261107446, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9473994357690588, -0.3200536034861488, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.639330255385841, -0.6831522198358223, 0.}, 
      Optica`Optica`RayEnd :> {6.6616951298003775`, -0.6959549043217395, 0.}, 
      RotationMatrix :> {{0.8678624963045017, -0.4968044761353491, 0.}, {
       0.4968044761353491, 0.8678624963045017, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.532848288295237, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.025770066698089115`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.432848246175544`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35149600395726116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8678624963045017, -0.4968044761353491, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.6616951298003775`, -0.6959549043217395, 0.},
       Optica`Optica`RayEnd :> {6.903791814934578, -0.8427133549804139, 0.}, 
      RotationMatrix :> {{0.8551458674149354, -0.5183874472276095, 0.}, {
       0.5183874472276095, 0.8551458674149354, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.517424936317343, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28310571840339493`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.851844709412568`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33598475751220963`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8551458674149354, -0.5183874472276095, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.903791814934578, -0.8427133549804139, 0.}, 
      Optica`Optica`RayEnd :> {6.621496895843233, -0.8213024594383405, 0.}, 
      RotationMatrix :> {{-0.9971360546278507, 0.07562862263193548, 
       0.}, {-0.07562862263193548, -0.9971360546278507, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01538035788627458, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28310571840339493`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.270841172649591`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07913124989772191, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9971360546278507, 0.07562862263193548, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.593103752960103, -0.3808641690826178, 0.}, 
      Optica`Optica`RayEnd :> {6.585937710344732, -0.34544883692820877`, 0.}, 
      RotationMatrix :> {{-0.19832372093299083`, 0.9801365729913832, 
       0.}, {-0.9801365729913832, -0.19832372093299083`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02070206355189626, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036133058525018795`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.89932183773196, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33432688459842586`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.19832372093299083`, 0.9801365729913832, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.585937710344732, -0.34544883692820877`, 0.},
       Optica`Optica`RayEnd :> {6.574334237508879, -0.139023951860052, 0.}, 
      RotationMatrix :> {{-0.05612300164450737, 0.998423862238083, 
       0.}, {-0.998423862238083, -0.05612300164450737, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020218071203846697`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20675075273685006`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.2053129517825, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2905549405960226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.05612300164450737, 0.998423862238083, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.435475922970339, 0.18220880631998992`, 0.}, 
      Optica`Optica`RayEnd :> {6.5277167916844, 0.4090387728449872, 0.}, 
      RotationMatrix :> {{0.3766966917488446, 0.9263366571746342, 
       0.}, {-0.9263366571746342, 0.3766966917488446, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030082643490126744`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24486774302642647`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.019193642187489`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03846639944391395, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3766966917488446, 0.9263366571746342, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5277167916844, 0.4090387728449872, 0.}, 
      Optica`Optica`RayEnd :> {6.5835171622575075`, 0.5978111898525217, 0.}, 
      RotationMatrix :> {{0.2834708962175038, 0.9589808397448016, 
       0.}, {-0.9589808397448016, 0.2834708962175038, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02978984769763544, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19684691203816906`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.310527072003978`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2387530844385779, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2834708962175038, 0.9589808397448016, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.593901268418461, 0.1698954461074504, 0.}, 
      Optica`Optica`RayEnd :> {5.5368369334040395`, 0.16326730455128366`, 0.},
       RotationMatrix :> {{-0.9933218437727763, -0.11537640436350709`, 0.}, {
       0.11537640436350709`, -0.9933218437727763, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21004888831512233`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057447981610555296`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.002193676921548`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2686676900707515, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9933218437727763, -0.11537640436350709`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5368369334040395`, 0.16326730455128366`, 
       0.}, Optica`Optica`RayEnd :> {5.447483270690153, 0.11587933936681133`, 
       0.}, RotationMatrix :> {{-0.8834479951515504, -0.4685292305317842, 
       0.}, {0.4685292305317842, -0.8834479951515504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09602529295412246, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837817`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.151883779273147`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2982854150422827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8834479951515504, -0.4685292305317842, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.447483270690153, 0.11587933936681133`, 0.}, 
      Optica`Optica`RayEnd :> {5.42785836360701, 0.016659586763362173`, 0.}, 
      RotationMatrix :> {{-0.1940332862812153, -0.9809949458661403, 0.}, {
       0.9809949458661403, -0.1940332862812153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.052126670300655, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837829`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.301573881624748`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1230612644470728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.1940332862812153, -0.9809949458661403, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.42785836360701, 0.016659586763362176`, 0.}, 
      Optica`Optica`RayEnd :> {5.492443700937656, -0.06117633352154406, 0.}, 
      RotationMatrix :> {{0.6385612525325074, -0.7695710017692422, 0.}, {
       0.7695710017692422, 0.6385612525325074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028296604707378912`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837836`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.451263983976348`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40896916986254844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6385612525325074, -0.7695710017692422, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.492443700937656, -0.06117633352154406, 0.}, 
      Optica`Optica`RayEnd :> {5.593580874204508, -0.06019222565020976, 0.}, 
      RotationMatrix :> {{0.9999526627576067, 0.00972996628830991, 
       0.}, {-0.00972996628830991, 0.9999526627576067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015360617383527722`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837835`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.600954086327949`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03493105573826716, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999526627576067, 0.00972996628830991, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.593580874204508, -0.06019222565020976, 0.}, 
      Optica`Optica`RayEnd :> {5.656639372597604, 0.018885723647427514`, 0.}, 
      RotationMatrix :> {{0.6234652535848404, 0.7818510584327365, 
       0.}, {-0.7818510584327365, 0.6234652535848404, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008338405573499956, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10114196104837841`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.75064418867955, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3648831647242815, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 55, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6234652535848404, 0.7818510584327365, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.46397806998668, 0.3961971742504616, 0.}, 
      Optica`Optica`RayEnd :> {6.612509852193087, 0.3238578492146921, 0.}, 
      RotationMatrix :> {{0.8990430371413274, -0.43786027151101214`, 0.}, {
       0.43786027151101214`, 0.8990430371413274, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9672822419658496`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1652109810879477, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.053951475829608`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2664084690613324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8990430371413274, -0.43786027151101214`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.612509852193087, 0.3238578492146921, 0.}, 
      Optica`Optica`RayEnd :> {6.898387262851132, 0.1809591662737341, 0.}, 
      RotationMatrix :> {{0.8944772755545145, -0.44711341236488594`, 0.}, {
       0.44711341236488594`, 0.8944772755545145, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9572924151053797`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31960276518016745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.526963568296257`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3151937324938385, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8944772755545145, -0.44711341236488594`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.898387262851132, 0.1809591662737341, 0.}, 
      Optica`Optica`RayEnd :> {6.5900884129714665`, 0.26520729191273357`, 0.},
       RotationMatrix :> {{-0.9646313595123946, 0.26360261805465574`, 
       0.}, {-0.26360261805465574`, -0.9646313595123946, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009964671947203912, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3196027651801672, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.999975660762905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08378521027950564, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9646313595123946, 0.26360261805465574`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5901068238903555`, 0.47152052588080956`, 
       0.}, Optica`Optica`RayEnd :> {6.7103606959140265`, 0.5772951254941001, 
       0.}, RotationMatrix :> {{0.7508646384074936, 0.6604561263166412, 
       0.}, {-0.6604561263166412, 0.7508646384074936, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      76.09079065304638, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16015386245744243`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.264599327920553`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3811449247375621, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7508646384074936, 0.6604561263166412, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.7103606959140265`, 0.5772951254941001, 0.}, 
      Optica`Optica`RayEnd :> {6.935844594623621, 0.7973177727561169, 0.}, 
      RotationMatrix :> {{0.7157210905042805, 0.6983862259576451, 
       0.}, {-0.6983862259576451, 0.7157210905042805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      75.78805238539758, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31504436812211745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.730864992741287`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33286379768071034`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7157210905042805, 0.6983862259576451, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.935844594623621, 0.7973177727561169, 0.}, 
      Optica`Optica`RayEnd :> {6.623695705447773, 0.8399326160826954, 0.}, 
      RotationMatrix :> {{-0.9908092978664267, 0.13526616451070833`, 
       0.}, {-0.13526616451070833`, -0.9908092978664267, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.30153377945895193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31504436812211745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.19713065756202, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2782192589029508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9908092978664267, 0.13526616451070833`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.569286664841523, 0.616946076728329, 0.}, 
      Optica`Optica`RayEnd :> {6.4874006132775435`, 0.8597499173682634, 0.}, 
      RotationMatrix :> {{-0.31956756811125786`, 0.9475634909658854, 
       0.}, {-0.9475634909658854, -0.31956756811125786`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.6006943562348837`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25624018121723496`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.610779386114498`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19460904742377685`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.31956756811125786`, 0.9475634909658854, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.4874006132775435`, 0.8597499173682634, 0.}, 
      Optica`Optica`RayEnd :> {6.385731150277527, 1.1815774722078438`, 0.}, 
      RotationMatrix :> {{-0.3012383512237693, 0.9535488743383761, 
       0.}, {-0.9535488743383761, -0.3012383512237693, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.591139600561047, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33750504405228493`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.11028685131188, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4238845577687778, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3012383512237693, 0.9535488743383761, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.385731150277527, 1.1815774722078438`, 0.}, 
      Optica`Optica`RayEnd :> {6.595407208774853, 0.9171051574870768, 0.}, 
      RotationMatrix :> {{0.6212531107086032, -0.7836099619293283, 0.}, {
       0.7836099619293283, 0.6212531107086032, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009529401298553416, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3375050440522846, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.60979431650926, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16150911654754554`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6212531107086032, -0.7836099619293283, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.427090072857617, 0.65385405811834, 0.}, 
      Optica`Optica`RayEnd :> {6.407772164511959, 0.6552256069035045, 0.}, 
      RotationMatrix :> {{-0.997489072354497, 0.07082055163131887, 
       0.}, {-0.07082055163131887, -0.997489072354497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1703885547219331, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01936653631709344, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.510793093004128`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21438606949538386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.997489072354497, 0.07082055163131887, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.407772164511959, 0.6552256069035045, 0.}, 
      Optica`Optica`RayEnd :> {6.17426127708289, 0.6847681835117939, 0.}, 
      RotationMatrix :> {{-0.9920918143905646, 0.12551426938494628`, 
       0.}, {-0.12551426938494628`, -0.9920918143905646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16967267903905908`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2353722549081946, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.859144030268256`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1725625088079654, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9920918143905646, 0.12551426938494628`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.338170829330356, 0.5369120297766741, 0.}, 
      Optica`Optica`RayEnd :> {6.29429118719413, 0.4498904721833331, 0.}, 
      RotationMatrix :> {{-0.4502388903216692, -0.8929081372917997, 0.}, {
       0.8929081372917997, -0.4502388903216692, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008062961392420711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0974585782780279, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.832860820287603`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08594316703795846, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4502388903216692, -0.8929081372917997, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.29429118719413, 0.4498904721833331, 0.}, 
      Optica`Optica`RayEnd :> {6.149860507509465, 0.15542061427856801`, 0.}, 
      RotationMatrix :> {{-0.4403605273706925, -0.8978210322407274, 0.}, {
       0.8978210322407274, -0.4403605273706925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008042596384623464, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.327982802062283, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.318275367339782`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4233229630620845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4403605273706925, -0.8978210322407274, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.850888149584709, 0.023020528021387654`, 0.},
       Optica`Optica`RayEnd :> {5.152008776889274, -0.5523167722276326, 0.}, 
      RotationMatrix :> {{-0.7720442899254092, -0.6355687330207254, 0.}, {
       0.6355687330207254, -0.7720442899254092, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2075408754361802, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9052322280149973, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.872294071739526`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35994847481914943`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7720442899254092, -0.6355687330207254, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.152008776889274, -0.5523167722276326, 0.}, 
      Optica`Optica`RayEnd :> {4.976148157166832, -0.6651470108793203, 0.}, 
      RotationMatrix :> {{-0.8416636466845998, -0.5400021350416871, 0.}, {
       0.5400021350416871, -0.8416636466845998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20455874324321377`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.208944060272979, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.181531280943535`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3259063048263108, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8416636466845998, -0.5400021350416871, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.367192815857526, 0.6330714094465906, 0.}, 
      Optica`Optica`RayEnd :> {5.339669363981522, 0.6417085268261644, 0.}, 
      RotationMatrix :> {{-0.9541236237749215, 0.2994129431982049, 
       0.}, {-0.2994129431982049, -0.9541236237749215, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07761958856652082, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028846840378093732`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.004279797855647`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09156276818225634, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9541236237749215, 0.2994129431982049, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.339669363981522, 0.6417085268261644, 0.}, 
      Optica`Optica`RayEnd :> {5.090655489293798, 0.7360701536815027, 0.}, 
      RotationMatrix :> {{-0.9351119305886533, 0.3543524760330611, 
       0.}, {-0.3543524760330611, -0.9351119305886533, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07727506301232216, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2662931212212958, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.398393617263164`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06907323498632226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9351119305886533, 0.3543524760330611, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.865531100028655, 0.6558574549179828, 0.}, 
      Optica`Optica`RayEnd :> {5.866032082750782, 0.6559443778978106, 0.}, 
      RotationMatrix :> {{0.9852795533817598, 0.17095087507187307`, 
       0.}, {-0.17095087507187307`, 0.9852795533817598, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10749039752990319`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0005084675921739751, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.563844974890351`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40278556923938497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9852795533817598, 0.17095087507187307`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.866032082750782, 0.6559443778978106, 0.}, 
      Optica`Optica`RayEnd :> {6.043512798331155, 0.6573804419320666, 0.}, 
      RotationMatrix :> {{0.9999672663865977, 0.008091115826275752, 
       0.}, {-0.008091115826275752, 0.9999672663865977, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10385264082103, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17748652535567822`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      11.826525032416756`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04711815972023915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999672663865977, 0.008091115826275752, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.898362925789411, 0.8443488925545409, 0.}, 
      Optica`Optica`RayEnd :> {5.899262128321833, 0.8727879726536775, 0.}, 
      RotationMatrix :> {{0.031602758770109984`, 0.999500508072966, 
       0.}, {-0.999500508072966, 0.031602758770109984`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.62079048873837, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02845329228893244, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.884458596619766`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2560634125904246, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.031602758770109984`, 0.999500508072966, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.899262128321833, 0.8727879726536775, 0.}, 
      Optica`Optica`RayEnd :> {5.934985647022961, 1.0862925640458698`, 0.}, 
      RotationMatrix :> {{0.1650256017195334, 0.9862892835152904, 
       0.}, {-0.9862892835152904, 0.1650256017195334, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.5302938238138175`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21647258564062283`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.204838023367888`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3819151601017152, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.1650256017195334, 0.9862892835152904, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.934985647022961, 1.0862925640458698`, 0.}, 
      Optica`Optica`RayEnd :> {6.151457852592751, 1.0858869168008731`, 0.}, 
      RotationMatrix :> {{0.9999982442542005, -0.0018738966128036272`, 0.}, {
       0.0018738966128036272`, 0.9999982442542005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08872431744798197, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21647258564062308`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.52521745011601, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09035989883336391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999982442542005, -0.0018738966128036272`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.720389387508421, 0.9145797299183803, 0.}, 
      Optica`Optica`RayEnd :> {5.666533260694018, 0.9274747733141636, 0.}, 
      RotationMatrix :> {{-0.9725118467863625, 0.23285340422716097`, 
       0.}, {-0.23285340422716097`, -0.9725118467863625, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10276256486215848`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.055378376101400714`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.203705765564232`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32247748678687355`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9725118467863625, 0.23285340422716097`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.666533260694018, 0.9274747733141636, 0.}, 
      Optica`Optica`RayEnd :> {5.343756785437981, 1.0083714905520778`, 0.}, 
      RotationMatrix :> {{-0.9699990736721646, 0.24310861168445136`, 
       0.}, {-0.24310861168445136`, -0.9699990736721646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10250354332498902`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33275957061906086`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.696189930080441`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0721994446664617, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9699990736721646, 0.24310861168445136`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.601759200889874, 0.5103319550200578, 0.}, 
      Optica`Optica`RayEnd :> {6.839475126009467, 0.4509905851077668, 0.}, 
      RotationMatrix :> {{0.9702265786535564, -0.24219906290944476`, 0.}, {
       0.24219906290944476`, 0.9702265786535564, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07540023015279645, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24501073290476763`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.963848469626406`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.010526486462427513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9702265786535564, -0.24219906290944476`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.839475126009467, 0.4509905851077668, 0.}, 
      Optica`Optica`RayEnd :> {7.143881683462895, 0.3832461284525548, 0.}, 
      RotationMatrix :> {{0.9761200897923513, -0.2172316052138152, 0.}, {
       0.2172316052138152, 0.9761200897923513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07518882025403502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3118535932583701, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.425391787648794`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2774272740043305, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9761200897923513, -0.2172316052138152, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.090506017080307, 0.737171203163886, 0.}, 
      Optica`Optica`RayEnd :> {4.991659151421143, 0.8352725985202283, 0.}, 
      RotationMatrix :> {{-0.7097781717432817, 0.7044252599933964, 
       0.}, {-0.7044252599933964, -0.7097781717432817, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2860171772896278, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13926444851972225`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.441227562478652`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28240375643888527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7097781717432817, 0.7044252599933964, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.991659151421143, 0.8352725985202283, 0.}, 
      Optica`Optica`RayEnd :> {4.839439865992445, 1.0218694340316077`, 0.}, 
      RotationMatrix :> {{-0.632115635090214, 0.7748740696877754, 
       0.}, {-0.7748740696877754, -0.632115635090214, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28287139440904074`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24080923960530265`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.7976252370945, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06265196473653517, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.632115635090214, 0.7748740696877754, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.561073218499606, -0.23407451704225998`, 0.},
       Optica`Optica`RayEnd :> {4.44134789660697, -0.2691230503460128, 0.}, 
      RotationMatrix :> {{-0.9597223309441734, -0.28095025802992724`, 0.}, {
       0.28095025802992724`, -0.9597223309441734, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015413036235610177`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12474995947510187`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.18006450595674, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38606793388928595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9597223309441734, -0.28095025802992724`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.44134789660697, -0.2691230503460128, 0.}, 
      Optica`Optica`RayEnd :> {4.122856680468086, -0.3469255217782274, 0.}, 
      RotationMatrix :> {{-0.9714348318602362, -0.23730648421118783`, 0.}, {
       0.23730648421118783`, -0.9714348318602362, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01535772897019159, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3278564919573598, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.665292114053631`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30027406874602514`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9714348318602362, -0.23730648421118783`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.346770984931949, -0.966173849270861, 0.}, 
      Optica`Optica`RayEnd :> {5.040126630241996, -1.3128848690005974`, 0.}, 
      RotationMatrix :> {{-0.662499282211319, -0.7490625481690343, 0.}, {
       0.7490625481690343, -0.662499282211319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013193225956728961`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.46285990479328726`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.796834126778984`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23634892377228034`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 22, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.662499282211319, -0.7490625481690343, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.040126630241996, -1.3128848690005974`, 0.}, 
      Optica`Optica`RayEnd :> {4.899821121356265, -1.4982348238119843`, 0.}, 
      RotationMatrix :> {{-0.6035539303667938, -0.7973221765000615, 0.}, {
       0.7973221765000615, -0.6035539303667938, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013111306819803749`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23246557072449925`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.140883171451243`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15069181790200745`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6035539303667938, -0.7973221765000615, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.370658469300976, -1.1285576357412543`, 0.}, 
      Optica`Optica`RayEnd :> {5.461859781943019, -1.371691218610847, 0.}, 
      RotationMatrix :> {{0.3512119602500902, -0.9362959782981494, 0.}, {
       0.9362959782981494, 0.3512119602500902, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14746502488154556`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25967598762041266`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.767482102661578`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4297299800496498, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3512119602500902, -0.9362959782981494, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.461859781943019, -1.371691218610847, 0.}, 
      Optica`Optica`RayEnd :> {5.5760497386044126`, -1.6632283365645302`, 0.},
       RotationMatrix :> {{0.3647045956037672, -0.931123277523171, 0.}, {
       0.931123277523171, 0.3647045956037672, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1470860527947584, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3131025987548983, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.230873948818827`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14181682785476635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3647045956037672, -0.931123277523171, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.525299534917696, -1.1835598797215485`, 0.}, 
      Optica`Optica`RayEnd :> {5.600761982400861, -1.1933424117791065`, 0.}, 
      RotationMatrix :> {{0.9917018985840854, -0.12855871944259545`, 0.}, {
       0.12855871944259545`, 0.9917018985840854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011256013943783253`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07609388223508266, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.76439650633948, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028912237522287835`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9917018985840854, -0.12855871944259545`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.600761982400861, -1.1933424117791065`, 0.}, 
      Optica`Optica`RayEnd :> {5.916170905633331, -1.2320732494795885`, 0.}, 
      RotationMatrix :> {{0.9925448225350814, -0.12188016761886804`, 0.}, {
       0.12188016761886804`, 0.9925448225350814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011228016663161554`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3177780147267062, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.234707968135005`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3791451063761998, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9925448225350814, -0.12188016761886804`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.62020904994084, -0.6927533534632233, 0.}, 
      Optica`Optica`RayEnd :> {4.421059584571563, -0.814860172281644, 0.}, 
      RotationMatrix :> {{-0.8525107048635936, -0.5227097646811074, 0.}, {
       0.5227097646811074, -0.8525107048635936, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18277405755786433`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23360347762570516`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.86158117120515, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3544439880978478, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8525107048635936, -0.5227097646811074, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.421059584571563, -0.814860172281644, 0.}, 
      Optica`Optica`RayEnd :> {4.211636102543155, -0.9174096462932262, 0.}, 
      RotationMatrix :> {{-0.8981055512395002, -0.43977996638409217`, 0.}, {
       0.43977996638409217`, -0.8981055512395002, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18113716219857534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23318359600313907`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.206692893289796`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39913294126605325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8981055512395002, -0.43977996638409217`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.3916852340172055`, 0.011356320668955004`, 
       0.}, Optica`Optica`RayEnd :> {4.165796928560684, 0.1098764015693789, 
       0.}, RotationMatrix :> {{-0.9166127857600603, 0.3997761886120555, 
       0.}, {-0.3997761886120555, -0.9166127857600603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06717310943434061, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2464380913792448, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.216741078003583`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24002600520805728`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9166127857600603, 0.3997761886120555, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.165796928560684, 0.1098764015693789, 0.}, 
      Optica`Optica`RayEnd :> {3.956690241253088, 0.17168039885872202`, 0.}, 
      RotationMatrix :> {{-0.9589896935910013, 0.2834409419724635, 
       0.}, {-0.2834409419724635, -0.9589896935910013, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06609561949505885, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21804894119829535`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.53945351097706, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41333141945532453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9589896935910013, 0.2834409419724635, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.917328532690551, 0.6491059597694256, 0.}, 
      Optica`Optica`RayEnd :> {4.891472330682532, 0.879007572435998, 0.}, 
      RotationMatrix :> {{-0.11176178065484343`, 0.9937350272506541, 
       0.}, {-0.9937350272506541, -0.11176178065484343`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025350327995798387`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23135102050557316`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.452569497534004`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3670018400589766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.11176178065484343`, 0.9937350272506541, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.891472330682532, 0.879007572435998, 0.}, 
      Optica`Optica`RayEnd :> {4.8894263217254865`, 1.1211417280571658`, 0.}, 
      RotationMatrix :> {{-0.00844959651558487, 0.999964301522171, 
       0.}, {-0.999964301522171, -0.00844959651558487, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02507899940711894, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2421427997505361, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.810940841164797`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3612111348500695, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.00844959651558487, 0.999964301522171, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.856008136082876, 0.892256352907218, 0.}, 
      Optica`Optica`RayEnd :> {5.877142979456383, 0.9362061847735541, 0.}, 
      RotationMatrix :> {{0.43337965196357453`, 0.9012114498073863, 
       0.}, {-0.9012114498073863, 0.43337965196357453`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009235389218195503, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04876750276056676, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.860003626880593`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0665618183291323, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.43337965196357453`, 0.9012114498073863, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.877142979456383, 0.9362061847735541, 0.}, 
      Optica`Optica`RayEnd :> {5.996981320663829, 1.1193631448066796`, 0.}, 
      RotationMatrix :> {{0.547511351917881, 0.8367982549701298, 
       0.}, {-0.8367982549701298, 0.547511351917881, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009064769491379732, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2188782767474384, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.183943476466801`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35940895295526976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.547511351917881, 0.8367982549701298, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.440801978911579, -0.6713898163737759, 0.}, 
      Optica`Optica`RayEnd :> {3.3397884269225475`, -0.6863708108810382, 0.}, 
      RotationMatrix :> {{-0.9891807031225911, -0.14670220369815834`, 0.}, {
       0.14670220369815834`, -0.9891807031225911, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23351496938053268`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10211840128922574`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.708473362761376`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18399781899913412`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9891807031225911, -0.14670220369815834`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3397884269225475`, -0.6863708108810382, 0.},
       Optica`Optica`RayEnd :> {3.060092723143652, -0.7433532091214999, 0.}, 
      RotationMatrix :> {{-0.979871513820895, -0.19962919726920533`, 0.}, {
       0.19962919726920533`, -0.979871513820895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23255393365007304`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28544120309024446`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.130926343334938`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13258783360653154`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.979871513820895, -0.19962919726920533`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.652262238794404, 1.3610242766510867`, 0.}, 
      Optica`Optica`RayEnd :> {2.634322296068684, 1.4088634427580893`, 0.}, 
      RotationMatrix :> {{-0.35112782469810205`, 0.9363275338912014, 
       0.}, {-0.9363275338912014, -0.35112782469810205`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015168831362062506`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.051092341488871894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.966363709711853`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27229770938974, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.35112782469810205`, 0.9363275338912014, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.634322296068684, 1.4088634427580893`, 0.}, 
      Optica`Optica`RayEnd :> {2.5179669445967625`, 1.6546179606098674`, 0.}, 
      RotationMatrix :> {{-0.42792208290091827`, 0.9038156288567595, 
       0.}, {-0.9038156288567595, -0.42792208290091827`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01506031858180493, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2719077984551275, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.368787251425442`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15180455766712608`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.42792208290091827`, 0.9038156288567595, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3652191267041047`, 0.8967965807865681, 0.}, 
      Optica`Optica`RayEnd :> {2.3584371703534224`, 0.8983914028520312, 0.}, 
      RotationMatrix :> {{-0.973446997041405, 0.22891252467060544`, 
       0.}, {-0.22891252467060544`, -0.973446997041405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2337839631807564, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.006966949789042982, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.834077281328776`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.029773360633715728`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.973446997041405, 0.22891252467060544`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3584371703534224`, 0.8983914028520312, 0.}, 
      Optica`Optica`RayEnd :> {2.22879531666272, 0.9020263899058154, 0.}, 
      RotationMatrix :> {{-0.999607147702107, 0.028027669593773064`, 
       0.}, {-0.028027669593773064`, -0.999607147702107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21848697272013848`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12969280380669815`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.02602263096269, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43213020045954514`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999607147702107, 0.028027669593773064`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.22879531666272, 0.9020263899058154, 0.}, 
      Optica`Optica`RayEnd :> {2.167926937343688, 0.7875044978575388, 0.}, 
      RotationMatrix :> {{-0.4693273453302296, -0.883024259533836, 0.}, {
       0.883024259533836, -0.4693273453302296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014296075282482465`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12969280380669806`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.217967980596603`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.033285636167506905`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 52, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4693273453302296, -0.883024259533836, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.423048150401369, 0.3838397198217184, 0.}, 
      Optica`Optica`RayEnd :> {2.070299296037435, -0.3079337586645584, 0.}, 
      RotationMatrix :> {{-0.4542692396463146, -0.8908644441839394, 0.}, {
       0.8908644441839394, -0.4542692396463146, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01350681722002278, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7765193492708801, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.214659757922732`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03639175218574628, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4542692396463146, -0.8908644441839394, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.070299296037435, -0.3079337586645584, 0.}, 
      Optica`Optica`RayEnd :> {1.9265945208348418`, -0.5911279665573725, 0.}, 
      RotationMatrix :> {{-0.45251523093629237`, -0.8917566740824955, 0.}, {
       0.8917566740824955, -0.45251523093629237`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01347350134962201, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3175689244873722, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.684661766164043`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4239510826250854, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45251523093629237`, -0.8917566740824955, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.592996513027466, 2.1249490237982482`, 0.}, 
      Optica`Optica`RayEnd :> {4.611110226660915, 2.157782503145335, 0.}, 
      RotationMatrix :> {{0.48305057166566157`, 0.8755924538353889, 
       0.}, {-0.8755924538353889, 0.48305057166566157`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011721950444193009`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.037498586475094325`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.020951113963944`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3244840146937712, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.48305057166566157`, 0.8755924538353889, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.611110226660915, 2.157782503145335, 0.}, 
      Optica`Optica`RayEnd :> {4.764975851525028, 2.414726189496874, 0.}, 
      RotationMatrix :> {{0.5137575793584906, 0.8579353994629807, 
       0.}, {-0.8579353994629807, 0.5137575793584906, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01168525852973367, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29949071516616743`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.464197372409872`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15207694573588917`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5137575793584906, 0.8579353994629807, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.495720909980971, 1.6579704444939585`, 0.}, 
      Optica`Optica`RayEnd :> {2.4243203082646443`, 1.7714919169140946`, 0.}, 
      RotationMatrix :> {{-0.532408022033309, 0.8464878605594882, 
       0.}, {-0.8464878605594882, -0.532408022033309, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24086062680934622`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13410880144826154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.254290965914677`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4325193251081551, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.532408022033309, 0.8464878605594882, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4243203082646443`, 1.7714919169140946`, 0.},
       Optica`Optica`RayEnd :> {2.312530256982746, 1.9047407108645917`, 0.}, 
      RotationMatrix :> {{-0.6427236300727108, 0.7660981238367296, 
       0.}, {-0.7660981238367296, -0.6427236300727108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23591873599117533`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1739317586148992, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.511709968664729`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17000553573826338`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6427236300727108, 0.7660981238367296, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9343541138804152`, 1.6684119244566258`, 0.},
       Optica`Optica`RayEnd :> {2.944238569475594, 1.8455352239882736`, 0.}, 
      RotationMatrix :> {{0.05571881351451869, 0.9984465002294987, 
       0.}, {-0.9984465002294987, 0.05571881351451869, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03091036261790038, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17739888866447537`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.228540983865383`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3861561720624508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.05571881351451869, 0.9984465002294987, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.944238569475594, 1.8455352239882736`, 0.}, 
      Optica`Optica`RayEnd :> {2.9696703051931497`, 2.143299400268076, 0.}, 
      RotationMatrix :> {{0.08509916162572595, 0.9963724869197256, 
       0.}, {-0.9963724869197256, 0.08509916162572595, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03082021752639167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29884825222376094`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.670836397156549`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3267006419953637, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08509916162572595, 0.9963724869197256, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3495590308742202`, -1.5735559140602946`, 
       0.}, Optica`Optica`RayEnd :> {2.344019420635874, -1.5839933710191287`, 
       0.}, RotationMatrix :> {{-0.4688061261135009, -0.883301090296198, 
       0.}, {0.883301090296198, -0.4688061261135009, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012595311974366787`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01181642032767567, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.856168923539181`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0040466111620024526`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4688061261135009, -0.883301090296198, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.344019420635874, -1.5839933710191287`, 0.}, 
      Optica`Optica`RayEnd :> {2.203960725449316, -1.846230942491997, 0.}, 
      RotationMatrix :> {{-0.4711083883678509, -0.8820753292148273, 0.}, {
       0.8820753292148273, -0.4711083883678509, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012564226001410135`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2972961183556703, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.296167178705574`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41778985332797475`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 51, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4711083883678509, -0.8820753292148273, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.122821027838444, -1.6979744077857233`, 0.}, 
      Optica`Optica`RayEnd :> {2.0942813412035988`, -1.7940861426641752`, 0.},
       RotationMatrix :> {{-0.28465800911072336`, -0.9586291346757194, 0.}, {
       0.9586291346757194, -0.28465800911072336`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21784691437421075`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10025955961683163`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 11.75224908555545, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05548554542372017, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.28465800911072336`, -0.9586291346757194, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0942813412035988`, -1.7940861426641752`, 
       0.}, Optica`Optica`RayEnd :> {1.9941947604424164`, -2.117172517617665, 
       0.}, RotationMatrix :> {{-0.29590942551059934`, -0.9552160027417811, 
       0.}, {0.9552160027417811, -0.29590942551059934`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21729486882195345`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3382338382377665, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.252835166147344`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3266802748514827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.29590942551059934`, -0.9552160027417811, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.17184458169658, -1.8244238040708087`, 0.}, 
      Optica`Optica`RayEnd :> {2.3314998299859577`, -2.030808955936765, 0.}, 
      RotationMatrix :> {{0.611869296866437, -0.790958888661207, 0.}, {
       0.790958888661207, 0.611869296866437, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04711475385647763, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26093031486792917`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.168265357109425`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21695876989596052`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.611869296866437, -0.790958888661207, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3314998299859577`, -2.030808955936765, 0.}, 
      Optica`Optica`RayEnd :> {2.4515426952274284`, -2.1199870179428464`, 0.},
       RotationMatrix :> {{0.8027330854934174, -0.5963384889928014, 0.}, {
       0.5963384889928014, 0.8027330854934174, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0386882498429953, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1495426903547691, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.389588538834483`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3142032390398948, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8027330854934174, -0.5963384889928014, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3031174647941777`, -1.8584853486187098`, 
       0.}, Optica`Optica`RayEnd :> {2.3538526555372528`, -1.856724289753587, 
       0.}, RotationMatrix :> {{0.9993981241324486, 0.03468990459114335, 
       0.}, {-0.03468990459114335, 0.9993981241324486, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010189724455510725`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.050765745420141915`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.087362293566894`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3237285598354256, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9993981241324486, 0.03468990459114335, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3538526555372528`, -1.856724289753587, 0.}, 
      Optica`Optica`RayEnd :> {2.6087330171752736`, -1.8690807179268634`, 0.},
       RotationMatrix :> {{0.9988269447904178, -0.04842245719332368, 0.}, {
       0.04842245719332368, 0.9988269447904178, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01011723167946918, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25517970151626407`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.465028251810965`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2128961421464088, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9988269447904178, -0.04842245719332368, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9545503044322277`, -1.6599496305216161`, 
       0.}, Optica`Optica`RayEnd :> {
       2.8843245852369903`, -1.7199217785169294`, 0.}, 
      RotationMatrix :> {{-0.7604395602658442, -0.6494087119701191, 0.}, {
       0.6494087119701191, -0.7604395602658442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26301713298528495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09234885040789663, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.122421176742902`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4113170013809804, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7604395602658442, -0.6494087119701191, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8843245852369903`, -1.7199217785169294`, 
       0.}, 
      Optica`Optica`RayEnd :> {2.6583334482814975`, -1.8881915848497568`, 0.},
       RotationMatrix :> {{-0.8020796044115993, -0.5972171365482842, 0.}, {
       0.5972171365482842, -0.8020796044115993, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2616521920850118, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2817564936354149, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.539420787323316`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3902640830703706, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8020796044115993, -0.5972171365482842, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1711990803001635`, -0.4115125146935025, 0.},
       Optica`Optica`RayEnd :> {3.1507501855607156`, -0.41455067932681255`, 
       0.}, RotationMatrix :> {{-0.9891423790165267, -0.1469603825305497, 
       0.}, {0.1469603825305497, -0.9891423790165267, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008945336412051759, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02067335822753806, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.994739274294433`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3395107008886745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9891423790165267, -0.1469603825305497, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1507501855607156`, -0.41455067932681255`, 
       0.}, Optica`Optica`RayEnd :> {2.844387562893518, -0.4646491925784466, 
       0.}, RotationMatrix :> {{-0.986891802294198, -0.16138330323955222`, 
       0.}, {0.16138330323955222`, -0.986891802294198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008922328194784484, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3104318243955474, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.454178374399843`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.011706717323782838`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.986891802294198, -0.16138330323955222`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8956096724243867`, 0.5941363996724759, 0.}, 
      Optica`Optica`RayEnd :> {2.874159596136431, 0.6005179289230769, 0.}, 
      RotationMatrix :> {{-0.9584816626210209, 0.28515417307001395`, 
       0.}, {-0.28515417307001395`, -0.9584816626210209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21619370086259623`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022379224480204764`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.336716437984848`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1253400390121111, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9584816626210209, 0.28515417307001395`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.874159596136431, 0.6005179289230769, 0.}, 
      Optica`Optica`RayEnd :> {2.5947838776974526`, 0.699565467163501, 0.}, 
      RotationMatrix :> {{-0.942518915857385, 0.3341527992565968, 
       0.}, {-0.3341527992565968, -0.942518915857385, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21533601896397675`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29641391142249646`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.775409026890141`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.056082938237452765`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.942518915857385, 0.3341527992565968, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.3638619846663005`, 1.897890825549716, 0.}, 
      Optica`Optica`RayEnd :> {4.3728757462880425`, 2.152400317364623, 0.}, 
      RotationMatrix :> {{0.03539401950614821, 0.9993734353999999, 
       0.}, {-0.9993734353999999, 0.03539401950614821, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009261000887279972, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2546690584316357, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.227855329488843`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20412274565843413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.03539401950614821, 0.9993734353999999, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.3728757462880425`, 2.152400317364623, 0.}, 
      Optica`Optica`RayEnd :> {4.352532376797479, 2.369357454152633, 0.}, 
      RotationMatrix :> {{-0.09335725790224841, 0.9956326744321786, 
       0.}, {-0.9956326744321786, -0.09335725790224841, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009097216469408765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21790881552952593`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.550360376472542`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11571360441649856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.09335725790224841, 0.9956326744321786, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.186980434491088, 1.4262010764902882`, 0.}, 
      Optica`Optica`RayEnd :> {6.350438183835544, 1.5591974553303574`, 0.}, 
      RotationMatrix :> {{0.7756796117964934, 0.6311268809385652, 
       0.}, {-0.6311268809385652, 0.7756796117964934, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01107592380966364, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2107284333100927, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.836646252722499`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17172972739441886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.7756796117964934, 0.6311268809385652, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.350438183835544, 1.5591974553303574`, 0.}, 
      Optica`Optica`RayEnd :> {6.52218963097219, 1.6623099573089042`, 0.}, 
      RotationMatrix :> {{0.8573571608444222, 0.514721962566969, 
       0.}, {-0.514721962566969, 0.8573571608444222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010822634391580802`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20032660247158396`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.133129624380443`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18767161616622063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.8573571608444222, 0.514721962566969, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.3477706183017695`, 1.0780641496062522`, 0.},
       Optica`Optica`RayEnd :> {4.284510727295245, 1.1144763410521983`, 0.}, 
      RotationMatrix :> {{-0.8666827001332426, 0.49885979722738955`, 
       0.}, {-0.49885979722738955`, -0.8666827001332426, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.43789635368952373`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07299083158899818, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.542822825612381`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1609195190854098, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8666827001332426, 0.49885979722738955`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.284510727295245, 1.1144763410521983`, 0.}, 
      Optica`Optica`RayEnd :> {4.096591811836374, 1.2499734969440517`, 0.}, 
      RotationMatrix :> {{-0.8111339329234585, 0.5848604473377582, 
       0.}, {-0.5848604473377582, -0.8111339329234585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4333137727847597, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23167433617476849`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.885700843151039`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06256198459982122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8111339329234585, 0.5848604473377582, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.886363500432843, -0.05497944326763965, 0.}, 
      Optica`Optica`RayEnd :> {3.766450187298416, -0.08152062867129992, 0.}, 
      RotationMatrix :> {{-0.9763698579625721, -0.21610622495001539`, 0.}, {
       0.21610622495001539`, -0.9763698579625721, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00990728218981653, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12281545989616517`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.037024668272371`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08962039973658253, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9763698579625721, -0.21610622495001539`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.766450187298416, -0.08152062867129992, 0.}, 
      Optica`Optica`RayEnd :> {3.560933992060265, -0.15747189595957234`, 0.}, 
      RotationMatrix :> {{-0.9379950480456531, -0.3466486547526657, 0.}, {
       0.3466486547526657, -0.9379950480456531, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00970568834935842, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21910157805880925`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.361295003799409`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24818859621682585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9379950480456531, -0.3466486547526657, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.335781837376667, -0.5225924266413898, 0.}, 
      Optica`Optica`RayEnd :> {5.1406776893927555`, -0.5831849702109122, 0.}, 
      RotationMatrix :> {{-0.9550045624258553, -0.29659110867623917`, 0.}, {
       0.29659110867623917`, -0.9550045624258553, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028827781455019248`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2042965611476427, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.711018099010078`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2769843381764971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9550045624258553, -0.29659110867623917`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1406776893927555`, -0.5831849702109122, 0.},
       Optica`Optica`RayEnd :> {4.908455139197296, -0.6337664010897093, 0.}, 
      RotationMatrix :> {{-0.9770904560336162, -0.21282443639774998`, 0.}, {
       0.21282443639774998`, -0.9770904560336162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028607857665319522`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23766740199074157`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.062765853956375`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3882220122721848, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9770904560336162, -0.21282443639774998`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.624663377518157, -0.777283667465705, 0.}, 
      Optica`Optica`RayEnd :> {5.285262011497718, -0.8898514129071506, 0.}, 
      RotationMatrix :> {{-0.9491571208775148, -0.31480273170273915`, 0.}, {
       0.31480273170273915`, -0.9491571208775148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02075453185408701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3575818571604415, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.53898230446386, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005496196215492466, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9491571208775148, -0.31480273170273915`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.285262011497718, -0.8898514129071506, 0.}, 
      Optica`Optica`RayEnd :> {5.147244857449752, -0.8967049223682861, 0.}, 
      RotationMatrix :> {{-0.9987693695924061, -0.049595830106850314`, 0.}, {
       0.049595830106850314`, -0.9987693695924061, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017174531323319905`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1381872114322954, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.743499377383657`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4092966991525711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9987693695924061, -0.049595830106850314`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.6616951298003775`, -0.6959549043217395, 0.},
       Optica`Optica`RayEnd :> {6.649809728695999, -0.6757401709390647, 0.}, 
      RotationMatrix :> {{-0.506842111659063, 0.8620389050669244, 
       0.}, {-0.8620389050669244, -0.506842111659063, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015423351977895943`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023449908425079054`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.46427112346515, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06493765506389962, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.506842111659063, 0.8620389050669244, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.649809728695999, -0.6757401709390647, 0.}, 
      Optica`Optica`RayEnd :> {6.477344047574457, -0.3900611068834905, 0.}, 
      RotationMatrix :> {{-0.5168256340031118, 0.8560906868067668, 
       0.}, {-0.8560906868067668, -0.5168256340031118, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015384292576962095`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3337018711430702, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.958149892756893`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4084553865236776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5168256340031118, 0.8560906868067668, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.903791814934578, -0.8427133549804139, 0.}, 
      Optica`Optica`RayEnd :> {6.952683447459978, -0.8740524240884584, 0.}, 
      RotationMatrix :> {{0.8418926026039051, -0.539645110865301, 0.}, {
       0.539645110865301, 0.8418926026039051, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.502044578431068, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058073479175589124`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.929663171507856`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2547176059747129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8418926026039051, -0.539645110865301, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.952683447459978, -0.8740524240884584, 0.}, 
      Optica`Optica`RayEnd :> {7.098021325764257, -0.9968067045346964, 0.}, 
      RotationMatrix :> {{0.7639663868748405, -0.6452560419906204, 0.}, {
       0.6452560419906204, 0.7639663868748405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.400012755553523, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19024119490232136`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.211220139963292`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3885508337415809, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7639663868748405, -0.6452560419906204, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.098021325764257, -0.9968067045346964, 0.}, 
      Optica`Optica`RayEnd :> {6.997752704567444, -1.1584789527443164`, 0.}, 
      RotationMatrix :> {{-0.5270605099400041, -0.8498277583497627, 0.}, {
       0.8498277583497627, -0.5270605099400041, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10013970936750122`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19024119490232122`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.492777108418727`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10922620444350448`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5270605099400041, -0.8498277583497627, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.621496895843233, -0.8213024594383405, 0.}, 
      Optica`Optica`RayEnd :> {6.386503912598267, -0.79754594807913, 0.}, 
      RotationMatrix :> {{-0.9949287837009535, 0.10058188387249878`, 
       0.}, {-0.10058188387249878`, -0.9949287837009535, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015337483644859371`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23619075766491968`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.587336787920584`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3739427812869002, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9949287837009535, 0.10058188387249878`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.386503912598267, -0.79754594807913, 0.}, 
      Optica`Optica`RayEnd :> {6.084428116973464, -0.7640639246493693, 0.}, 
      RotationMatrix :> {{-0.9939132948195543, 0.11016515956025943`, 
       0.}, {-0.11016515956025943`, -0.9939132948195543, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015298968107760425`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3039257017682273, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.03714682653756, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009225479041633539, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9939132948195543, 0.11016515956025943`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.574334237508879, -0.139023951860052, 0.}, 
      Optica`Optica`RayEnd :> {6.577263296573113, -0.10557389463469018`, 0.}, 
      RotationMatrix :> {{0.08723135229332263, 0.9961880802223434, 
       0.}, {-0.9961880802223434, 0.08723135229332263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01974539408494728, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03357805407378091, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.250307544241366`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009878968941908298, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.08723135229332263, 0.9961880802223434, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.577263296573113, -0.10557389463469018`, 0.},
       Optica`Optica`RayEnd :> {6.584222943013781, 0.1716058667428289, 0.}, 
      RotationMatrix :> {{0.025100871668764846`, 0.9996849234841286, 
       0.}, {-0.9996849234841286, 0.025100871668764846`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01965111971513255, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2772671217362014, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.660662884410945`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.015221544269966802`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.025100871668764846`, 0.9996849234841286, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5835171622575075`, 0.5978111898525217, 0.}, 
      Optica`Optica`RayEnd :> {6.601474680697096, 0.6918967745999689, 0.}, 
      RotationMatrix :> {{0.18747936257188869`, 0.9822685420034779, 
       0.}, {-0.9822685420034779, 0.18747936257188869`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029499901700446484`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09578397426384659, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.438877597517532`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14398511729398802`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.18747936257188869`, 0.9822685420034779, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.601474680697096, 0.6918967745999689, 0.}, 
      Optica`Optica`RayEnd :> {6.672516915681058, 0.8885179867466502, 0.}, 
      RotationMatrix :> {{0.3398142700950556, 0.9404925634154502, 
       0.}, {-0.9404925634154502, 0.3398142700950556, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.028596646778779558`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20906195306068182`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.74828928804734, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41678675653064934`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3398142700950556, 0.9404925634154502, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5368369334040395`, 0.16326730455128366`, 
       0.}, Optica`Optica`RayEnd :> {5.348854642305988, 0.16858535696493876`, 
       0.}, RotationMatrix :> {{-0.999600072964193, 0.028278863661387585`, 
       0.}, {-0.028278863661387585`, -0.999600072964193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11402359536099986`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1880575003767379, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.254190727426376`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24984600861103534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.999600072964193, 0.028278863661387585`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.348854642305988, 0.16858535696493876`, 0.}, 
      Optica`Optica`RayEnd :> {5.062238178947538, 0.1912066990993062, 0.}, 
      RotationMatrix :> {{-0.9968998603720471, 0.07868080064534219, 
       0.}, {-0.07868080064534219, -0.9968998603720471, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1135790028857132, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2875077776131728, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.679702238293872`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17914233942716692`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9968998603720471, 0.07868080064534219, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.447483270690153, 0.11587933936681133`, 0.}, 
      Optica`Optica`RayEnd :> {5.325030926814644, -0.026245639924664915`, 0.},
       RotationMatrix :> {{-0.6527280186041213, -0.7575923268679121, 0.}, {
       0.7575923268679121, -0.6527280186041213, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04389862265346749, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18760086955877528`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.403268944481907`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1320394201390007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6527280186041213, -0.7575923268679121, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.325030926814644, -0.026245639924664915`, 
       0.}, Optica`Optica`RayEnd :> {5.1212892282563045`, -0.285848443696126, 
       0.}, RotationMatrix :> {{-0.617386910539281, -0.7866596485741222, 
       0.}, {0.7866596485741222, -0.617386910539281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04373972409248053, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3300065082046727, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.891678576624821`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23809339224779136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.617386910539281, -0.7866596485741222, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.42785836360701, 0.01665958676336221, 0.}, 
      Optica`Optica`RayEnd :> {5.4982581522663425`, -0.377555216146243, 0.}, 
      RotationMatrix :> {{0.17580101582467716`, -0.9844257223554306, 0.}, {
       0.9844257223554306, 0.17580101582467716`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02383006559327609, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.40045154647764514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.838178953904793`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24649777932841221`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17580101582467716`, -0.9844257223554306, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.4982581522663425`, -0.377555216146243, 0.}, 
      Optica`Optica`RayEnd :> {5.548883626199007, -0.6931337635867161, 0.}, 
      RotationMatrix :> {{0.1583959427732378, -0.9873756758767034, 0.}, {
       0.9873756758767034, 0.1583959427732378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02376757003658947, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31961345124313173`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.311206861744628`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09805911887384833, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1583959427732378, -0.9873756758767034, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.492443700937656, -0.061176333521544085`, 
       0.}, Optica`Optica`RayEnd :> {5.6973141732691275`, -0.1747465325449184,
        0.}, RotationMatrix :> {{0.8746040633773366, -0.4848378412663883, 
       0.}, {0.4848378412663883, 0.8746040633773366, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01293598732385119, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2342436776938262, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.765150512086075`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42492984283969715`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8746040633773366, -0.4848378412663883, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.6973141732691275`, -0.1747465325449184, 0.},
       Optica`Optica`RayEnd :> {5.903281161164852, -0.3033895933541004, 0.}, 
      RotationMatrix :> {{0.8481579979841073, -0.5297433439464726, 0.}, {
       0.5297433439464726, 0.8481579979841073, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01288417361574604, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2428403533130198, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.124554234989345`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40563490163435717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8481579979841073, -0.5297433439464726, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.612509852193087, 0.3238578492146921, 0.}, 
      Optica`Optica`RayEnd :> {6.5127792552332116`, 0.4029728818525733, 0.}, 
      RotationMatrix :> {{-0.7834274855973037, 0.6214832055741216, 
       0.}, {-0.6214832055741216, -0.7834274855973037, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009989826860471058, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12730035490628477`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.22453395140403, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09870181037706167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7834274855973037, 0.6214832055741216, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5127792552332116`, 0.4029728818525733, 0.}, 
      Optica`Optica`RayEnd :> {6.34098319847574, 0.5569745163120173, 0.}, 
      RotationMatrix :> {{-0.7446177303798583, 0.6674911502064638, 
       0.}, {-0.6674911502064638, -0.7446177303798583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00994384498497979, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2307171179899678, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.565995286029183`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10704613736909331`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7446177303798583, 0.6674911502064638, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.898387262851132, 0.1809591662737341, 0.}, 
      Optica`Optica`RayEnd :> {6.97435174451669, 0.14200277352684282`, 0.}, 
      RotationMatrix :> {{0.8898162818393892, -0.4563189504869638, 0.}, {
       0.4563189504869638, 0.8898162818393892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9473277431581772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0853709728805229, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.641360671956157`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.421326521649622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8898162818393892, -0.4563189504869638, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.97435174451669, 0.14200277352684282`, 0.}, 
      Optica`Optica`RayEnd :> {7.1533879505423, 0.03752729228343482, 0.}, 
      RotationMatrix :> {{0.8636997457535194, -0.5040066955758679, 0.}, {
       0.5040066955758679, 0.8636997457535194, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.93090829127967, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20728986769518293`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.948149676145027`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4188139381942175, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8636997457535194, -0.5040066955758679, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1533879505423, 0.03752729228343482, 0.}, 
      Optica`Optica`RayEnd :> {6.964087541651995, -0.04693834832296653, 0.}, 
      RotationMatrix :> {{-0.9132159279905991, -0.4074759733582686, 0.}, {
       0.4074759733582686, -0.9132159279905991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016351152913349525`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20728986769518284`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.254938680333897`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38968147660692454`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9132159279905991, -0.4074759733582686, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5900884129714665`, 0.26520729191273357`, 
       0.}, Optica`Optica`RayEnd :> {6.400758126154542, 0.3190506142465829, 
       0.}, RotationMatrix :> {{-0.9618601208589481, 0.27354178456171807`, 
       0.}, {-0.27354178456171807`, -0.9618601208589481, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0099395803753412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19683765103791986`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.263738113153718`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3919858463538214, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9618601208589481, 0.27354178456171807`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.400758126154542, 0.3190506142465829, 0.}, 
      Optica`Optica`RayEnd :> {6.103008723708266, 0.39029214819013164`, 0.}, 
      RotationMatrix :> {{-0.9725488945092793, 0.2326986200835291, 
       0.}, {-0.2326986200835291, -0.9725488945092793, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009905449424197901, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3061536588312212, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.716845528223924`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2888314719036447, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9725488945092793, 0.2326986200835291, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.7103606959140265`, 0.5772951254941001, 0.}, 
      Optica`Optica`RayEnd :> {6.739719792815295, 0.3986426170525476, 0.}, 
      RotationMatrix :> {{0.16216121622643997`, -0.9867642778049686, 0.}, {
       0.9867642778049686, 0.16216121622643997`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3027382676488262, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1810488203311943, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.507204747164353`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27303061022757047`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.16216121622643997`, -0.9867642778049686, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.739719792815295, 0.3986426170525476, 0.}, 
      Optica`Optica`RayEnd :> {6.788286169112373, 0.08275477138089243, 0.}, 
      RotationMatrix :> {{0.15196012574472711`, -0.9883866248506431, 0.}, {
       0.9883866248506431, 0.15196012574472711`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3019759219363605, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.319599474263818, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.980211969074803`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13459558071028083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15196012574472711`, -0.9883866248506431, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.935844594623621, 0.7973177727561169, 0.}, 
      Optica`Optica`RayEnd :> {6.9767342513768655`, 0.8415684967397441, 0.}, 
      RotationMatrix :> {{0.6786638751632282, 0.734449007452818, 
       0.}, {-0.734449007452818, 0.6786638751632282, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      75.48651860593858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0602502332150948, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.811600305249513`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3474992186145835, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6786638751632282, 0.734449007452818, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9767342513768655`, 0.8415684967397441, 0.}, 
      Optica`Optica`RayEnd :> {7.156710522321821, 1.057504153542214, 0.}, 
      RotationMatrix :> {{0.6402471506018536, 0.7681689828066522, 
       0.}, {-0.7681689828066522, 0.6402471506018536, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      75.18908972622434, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2811043684860949, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.227634770608933`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29101472326364913`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6402471506018536, 0.7681689828066522, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.156710522321821, 1.057504153542214, 0.}, 
      Optica`Optica`RayEnd :> {6.875687281178761, 1.0642572209501147`, 0.}, 
      RotationMatrix :> {{-0.999711397786268, 0.02402334565012143, 
       0.}, {-0.02402334565012143, -0.999711397786268, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.29625696266042756`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28110436848609477`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.643669235968353`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2282363266626249, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999711397786268, 0.02402334565012143, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.623695705447773, 0.8399326160826954, 0.}, 
      Optica`Optica`RayEnd :> {6.188869344374059, 0.8765301252217953, 0.}, 
      RotationMatrix :> {{-0.9964767665561046, 0.08386926560957816, 
       0.}, {-0.08386926560957816, -0.9964767665561046, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.30033408350038, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.43636377251072833`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.781858112726397`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25508391160095134`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9964767665561046, 0.08386926560957816, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.188869344374059, 0.8765301252217953, 0.}, 
      Optica`Optica`RayEnd :> {5.881209576075601, 0.9157210836573269, 0.}, 
      RotationMatrix :> {{-0.9919840705344243, 0.12636298431880122`, 
       0.}, {-0.12636298431880122`, -0.9919840705344243, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29929508032626695`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3101458757626098, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.240874008855059`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12777387698494808`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9919840705344243, 0.12636298431880122`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.4874006132775435`, 0.8597499173682634, 0.}, 
      Optica`Optica`RayEnd :> {6.471949617710071, 0.6611436641888342, 0.}, 
      RotationMatrix :> {{-0.077562759262289, -0.9969874715239, 0.}, {
       0.9969874715239, -0.077562759262289, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00955475567383658, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1992063680357573, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.877715919282412`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2451395777162983, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.077562759262289, -0.9969874715239, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.471949617710071, 0.6611436641888342, 0.}, 
      Optica`Optica`RayEnd :> {6.453084848827884, 0.3971828149358141, 0.}, 
      RotationMatrix :> {{-0.07128623460586464, -0.9974559001558498, 0.}, {
       0.9974559001558498, -0.07128623460586464, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009531017240429419, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2646341048378949, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.269374394442497`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3046206660767583, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.07128623460586464, -0.9974559001558498, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.385731150277527, 1.1815774722078438`, 0.}, 
      Optica`Optica`RayEnd :> {6.364102736692175, 1.2549358388771608`, 0.}, 
      RotationMatrix :> {{-0.282797138434122, 0.9591797425370655, 
       0.}, {-0.9591797425370655, -0.282797138434122, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.581610199262495, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07648031272562254, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.212770470364214`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4054293183948725, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.282797138434122, 0.9591797425370655, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.364102736692175, 1.2549358388771608`, 0.}, 
      Optica`Optica`RayEnd :> {6.285753978708785, 1.4070605913421486`, 0.}, 
      RotationMatrix :> {{-0.4578709686016178, 0.8890186590346771, 
       0.}, {-0.8890186590346771, -0.4578709686016178, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.3948656574795173`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17111536514899403`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.466021210784726`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0027900045169841903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4578709686016178, 0.8890186590346771, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.285753978708785, 1.4070605913421486`, 0.}, 
      Optica`Optica`RayEnd :> {6.114937969488056, 1.3969433197743022`, 0.}, 
      RotationMatrix :> {{-0.9982505607956075, -0.059125441827138636`, 0.}, {
       0.059125441827138636`, -0.9982505607956075, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1770077133886069, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17111536514899411`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.719271951205238`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4021384659421463, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9982505607956075, -0.059125441827138636`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.114937969488056, 1.3969433197743022`, 0.}, 
      Optica`Optica`RayEnd :> {6.055094413422918, 1.2366335665228163`, 0.}, 
      RotationMatrix :> {{-0.3497263732747259, -0.9368518900210996, 0.}, {
       0.9368518900210996, -0.3497263732747259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00922915183109922, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17111536514899428`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.97252269162575, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10906585269068017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 60, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3497263732747259, -0.9368518900210996, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.595407208774853, 0.9171051574870768, 0.}, 
      Optica`Optica`RayEnd :> {6.639117835616823, 0.8597328288639436, 0.}, 
      RotationMatrix :> {{0.6060289730501683, -0.7954425710406489, 0.}, {
       0.7954425710406489, 0.6060289730501683, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009504114203310814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07212629888299157, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.70644355701247, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.334690289176042, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6060289730501683, -0.7954425710406489, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.639117835616823, 0.8597328288639436, 0.}, 
      Optica`Optica`RayEnd :> {6.853458526119032, 0.5885561136172155, 0.}, 
      RotationMatrix :> {{0.6200965340821851, -0.7845255180166294, 0.}, {
       0.7845255180166294, 0.6200965340821851, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009479162575955621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34565697229618986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.218015876010831`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011643400025154542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6200965340821851, -0.7845255180166294, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.17426127708289, 0.6847681835117939, 0.}, 
      Optica`Optica`RayEnd :> {5.9129569581717885`, 0.7325369742730579, 0.}, 
      RotationMatrix :> {{-0.983697910208221, 0.17982886712643842`, 
       0.}, {-0.17982886712643842`, -0.983697910208221, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16895981105816463`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26563471996783194`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.21509455502515, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3571177824801786, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.983697910208221, 0.17982886712643842`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.9129569581717885`, 0.7325369742730579, 0.}, 
      Optica`Optica`RayEnd :> {5.615981264787904, 0.7888893143257181, 0.}, 
      RotationMatrix :> {{-0.9824687359397828, 0.18642741992766196`, 
       0.}, {-0.18642741992766196`, -0.9824687359397828, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16853957652470247`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30227495544660876`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.66246148908613, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06153502189175683, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9824687359397828, 0.18642741992766196`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.149860507509465, 0.15542061427856801`, 0.}, 
      Optica`Optica`RayEnd :> {6.145120821954897, 0.14548131807801748`, 0.}, 
      RotationMatrix :> {{-0.4304285643566291, -0.9026246456783079, 0.}, {
       0.9026246456783079, -0.4304285643566291, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008022282813701877, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0110115497600681, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.333030844018273`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11918276307359899`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 57, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4304285643566291, -0.9026246456783079, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.976148157166832, -0.6651470108793203, 0.}, 
      Optica`Optica`RayEnd :> {4.922093988224713, -0.6914005885171679, 0.}, 
      RotationMatrix :> {{-0.8995166891795418, -0.43688639929331174`, 0.}, {
       0.43688639929331174`, -0.8995166891795418, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20161946098232789`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06009245808593309, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.262055174778686`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3966999261127353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8995166891795418, -0.43688639929331174`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.922093988224713, -0.6914005885171679, 0.}, 
      Optica`Optica`RayEnd :> {4.655926041426688, -0.8105216709669426, 0.}, 
      RotationMatrix :> {{-0.9127595064292533, -0.40849734812239014`, 0.}, {
       0.40849734812239014`, -0.9127595064292533, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2010189555938405, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29160797003285505`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.693634970427311`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32621674442819887`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9127595064292533, -0.40849734812239014`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.090655489293798, 0.7360701536815027, 0.}, 
      Optica`Optica`RayEnd :> {4.813642807021752, 0.8598979484814954, 0.}, 
      RotationMatrix :> {{-0.9129397491423096, 0.40809436952251166`, 
       0.}, {-0.40809436952251166`, -0.9129397491423096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0769320666836668, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3034293145109464, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.804988898707832`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03650660548058359, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9129397491423096, 0.40809436952251166`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.813642807021752, 0.8598979484814954, 0.}, 
      Optica`Optica`RayEnd :> {4.679967194926414, 0.8613803822979871, 0.}, 
      RotationMatrix :> {{-0.9999385140040391, 0.011089103272740763`, 
       0.}, {-0.011089103272740763`, -0.9999385140040391, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017436484983645455`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13368383177887855`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.002840969740571`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4072714083041462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9999385140040391, 0.011089103272740763`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.679967194926414, 0.8613803822979871, 0.}, 
      Optica`Optica`RayEnd :> {4.593536982293348, 0.7593941811564283, 0.}, 
      RotationMatrix :> {{-0.6465270443177235, -0.7628910675619344, 0.}, {
       0.7628910675619344, -0.6465270443177235, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013484543723114452`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13368383177887846`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.200693040773311`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13027509750710914`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6465270443177235, -0.7628910675619344, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.593536982293348, 0.7593941811564283, 0.}, 
      Optica`Optica`RayEnd :> {4.616922886965641, 0.6277717425612483, 0.}, 
      RotationMatrix :> {{0.17493442820351796`, -0.9845800860413071, 0.}, {
       0.9845800860413071, 0.17493442820351796`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010428301322837948`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13368383177887863`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.398545111806051`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28858966841049677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.17493442820351796`, -0.9845800860413071, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.616922886965641, 0.6277717425612483, 0.}, 
      Optica`Optica`RayEnd :> {4.733194800845937, 0.5618004691030476, 0.}, 
      RotationMatrix :> {{0.8697530010406669, -0.49348730194479473`, 0.}, {
       0.49348730194479473`, 0.8697530010406669, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008064749591302904, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13368383177887883`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.59639718283879, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28242947535571095`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8697530010406669, -0.49348730194479473`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.043512798331155, 0.6573804419320666, 0.}, 
      Optica`Optica`RayEnd :> {6.210986383001262, 0.6311070841589409, 0.}, 
      RotationMatrix :> {{0.987916824561663, -0.15498499200890262`, 0.}, {
       0.15498499200890262`, 0.987916824561663, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10033799533117782`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16952194810976592`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.053684442883842`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3749703932441102, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.987916824561663, -0.15498499200890262`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.210986383001262, 0.6311070841589409, 0.}, 
      Optica`Optica`RayEnd :> {6.382123401893994, 0.6275245760517915, 0.}, 
      RotationMatrix :> {{0.9997809648895369, -0.020928980972465233`, 0.}, {
       0.020928980972465233`, 0.9997809648895369, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09835373539021006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17117451212090246`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.307022720822777`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07835764855033917, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9997809648895369, -0.020928980972465233`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.899262128321833, 0.8727879726536775, 0.}, 
      Optica`Optica`RayEnd :> {5.841682554284794, 0.9015937670123577, 0.}, 
      RotationMatrix :> {{-0.8943277182840005, 0.44741248564264746`, 
       0.}, {-0.44741248564264746`, -0.8943277182840005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09049666492455452, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06438308112323816, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.970731925324905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0012219466370474161`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8943277182840005, 0.44741248564264746`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.841682554284794, 0.9015937670123577, 0.}, 
      Optica`Optica`RayEnd :> {5.712539000534084, 0.9118442775173976, 0.}, 
      RotationMatrix :> {{-0.9968647702960146, 0.07912414133924511, 
       0.}, {-0.07912414133924511, -0.9968647702960146, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.034900456856099216`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12954972188691216`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.162465513717535`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38738138157021235`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9968647702960146, 0.07912414133924511, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.712539000534084, 0.9118442775173976, 0.}, 
      Optica`Optica`RayEnd :> {5.622717590410879, 0.8184888024532366, 0.}, 
      RotationMatrix :> {{-0.6933354145029623, -0.720615017187405, 0.}, {
       0.720615017187405, -0.6933354145029623, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02144093445513161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12954972188691236`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.354199102110165`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15925605365526566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6933354145029623, -0.720615017187405, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.622717590410879, 0.8184888024532366, 0.}, 
      Optica`Optica`RayEnd :> {5.637941798653708, 0.6898367370817262, 0.}, 
      RotationMatrix :> {{0.11751633288814578`, -0.9930709498845091, 0.}, {
       0.9930709498845091, 0.11751633288814578`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01317213904117977, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12954972188691266`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.545932690502795`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2654814456031151, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.11751633288814578`, -0.9930709498845091, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.637941798653708, 0.6898367370817262, 0.}, 
      Optica`Optica`RayEnd :> {5.747071877350697, 0.620024443289261, 0.}, 
      RotationMatrix :> {{0.8423798762937615, -0.53888416567506, 0.}, {
       0.53888416567506, 0.8423798762937615, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008092242774364275, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.129549721886913, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.737666278895427`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30289672433054965`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 61, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8423798762937615, -0.53888416567506, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.934985647022961, 1.0862925640458698`, 0.}, 
      Optica`Optica`RayEnd :> {6.02114616024396, 1.3648656312182066`, 0.}, 
      RotationMatrix :> {{0.2954819128541646, 0.9553483339473843, 
       0.}, {-0.9553483339473843, 0.2954819128541646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.441569506365835, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2915931888647423, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.595572896446642`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2465199515033849, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2954819128541646, 0.9553483339473843, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.02114616024396, 1.3648656312182066`, 0.}, 
      Optica`Optica`RayEnd :> {6.10158126102411, 1.6554902335190946`, 0.}, 
      RotationMatrix :> {{0.26673876034450883`, 0.9637688694546394, 
       0.}, {-0.9637688694546394, 0.26673876034450883`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.428545035069252, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3015501034655141, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.041867049575602`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012216172299766872`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26673876034450883`, 0.9637688694546394, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.10158126102411, 1.6554902335190946`, 0.}, 
      Optica`Optica`RayEnd :> {5.8798616310272624`, 1.4511061084650112`, 0.}, 
      RotationMatrix :> {{-0.7352663038373112, -0.6777783283946291, 0.}, {
       0.6777783283946291, -0.7352663038373112, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0129862782991946, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.301550103465514, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.488161202704562`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22497567839677457`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7352663038373112, -0.6777783283946291, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.151457852592751, 1.0858869168008731`, 0.}, 
      Optica`Optica`RayEnd :> {6.298381427932044, 1.0657737383879953`, 0.}, 
      RotationMatrix :> {{0.9907594861945902, -0.1356305294372569, 0.}, {
       0.1356305294372569, 0.9907594861945902, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08698668081496037, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14829388704983434`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.723931258762788`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10415811769891664`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9907594861945902, -0.1356305294372569, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.298381427932044, 1.0657737383879953`, 0.}, 
      Optica`Optica`RayEnd :> {6.637302678486836, 1.0169603213082352`, 0.}, 
      RotationMatrix :> {{0.9897868983256409, -0.14255488733433927`, 0.}, {
       0.14255488733433927`, 0.9897868983256409, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08677016129752341, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34241840453548444`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.230710497475304`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41271578466901077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9897868983256409, -0.14255488733433927`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.343756785437981, 1.0083714905520778`, 0.}, 
      Optica`Optica`RayEnd :> {5.161225427054131, 1.0561727505257825`, 0.}, 
      RotationMatrix :> {{-0.9673781618517749, 0.25333671658936446`, 
       0.}, {-0.25333671658936446`, -0.9673781618517749, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10224517467300984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1886866642042501, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.949030060114136`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32559806674320074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9673781618517749, 0.25333671658936446`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.161225427054131, 1.0561727505257825`, 0.}, 
      Optica`Optica`RayEnd :> {4.879946877019573, 1.1112905707736813`, 0.}, 
      RotationMatrix :> {{-0.9813366916595402, 0.19229741964651353`, 
       0.}, {-0.19229741964651353`, -0.9813366916595402, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1017535771684494, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2866279763359166, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.373239465091293`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3315840030094588, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9813366916595402, 0.19229741964651353`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.143881683462895, 0.3832461284525548, 0.}, 
      Optica`Optica`RayEnd :> {7.32151291507871, 0.3484715981465151, 0.}, 
      RotationMatrix :> {{0.9813712090598536, -0.19212118578751253`, 0.}, {
       0.19212118578751253`, 0.9813712090598536, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07497800311401193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18100310053520355`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.667935942365967`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.312668710117008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9813712090598536, -0.19212118578751253`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.32151291507871, 0.3484715981465151, 0.}, 
      Optica`Optica`RayEnd :> {7.5841933507179515`, 0.3253409192139103, 0.}, 
      RotationMatrix :> {{0.9961454416211456, -0.08771692617398118, 0.}, {
       0.08771692617398118, 0.9961454416211456, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07414352473640408, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.263696870621373, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.0582073108856, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09736103700938936, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9961454416211456, -0.08771692617398118, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.839439865992445, 1.0218694340316077`, 0.}, 
      Optica`Optica`RayEnd :> {4.750805233635593, 1.157338521753208, 0.}, 
      RotationMatrix :> {{-0.5475033003142191, 0.8368035230237968, 
       0.}, {-0.8368035230237968, -0.5475033003142191, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27976021067395124`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16188876360376886`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.01455618032355, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1993874931522745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5475033003142191, 0.8368035230237968, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.750805233635593, 1.157338521753208, 0.}, 
      Optica`Optica`RayEnd :> {4.628638705595014, 1.3647266179686772`, 0.}, 
      RotationMatrix :> {{-0.5075556463540013, 0.8616189795113453, 
       0.}, {-0.8616189795113453, -0.5075556463540013, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.278727566910716, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24069583092643385`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.370786010094672`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2903236426786664, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5075556463540013, 0.8616189795113453, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.122856680468086, -0.3469255217782274, 0.}, 
      Optica`Optica`RayEnd :> {4.05452514831685, -0.36037909558971937`, 0.}, 
      RotationMatrix :> {{-0.9811637000839113, -0.1931781396474474, 0.}, {
       0.1931781396474474, -0.9811637000839113, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015302620166228706`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0696433552784231, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.75861421012672, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.003496791894076423, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9811637000839113, -0.1931781396474474, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.05452514831685, -0.36037909558971937`, 0.}, 
      Optica`Optica`RayEnd :> {3.8418719011631226`, -0.4257345527276301, 0.}, 
      RotationMatrix :> {{-0.955875373386699, -0.293772480931824, 0.}, {
       0.293772480931824, -0.955875373386699, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015138093205970727`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22246963681080062`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.087869272606705`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2210098491383078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.955875373386699, -0.293772480931824, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.899821121356265, -1.4982348238119843`, 0.}, 
      Optica`Optica`RayEnd :> {4.8447250389984315`, -1.5838618799218238`, 0.},
       RotationMatrix :> {{-0.541105825384651, -0.8409545087189886, 0.}, {
       0.8409545087189886, -0.541105825384651, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013029896333682863`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10182127002359946`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.277323673282867`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05894062360649335, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 24, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.541105825384651, -0.8409545087189886, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8447250389984315`, -1.5838618799218238`, 
       0.}, Optica`Optica`RayEnd :> {
       4.6801569042007625`, -1.8359346973849022`, 0.}, 
      RotationMatrix :> {{-0.5466704862173666, -0.8373478246815166, 0.}, {
       0.8373478246815166, -0.5466704862173666, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012997495591885134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30103716762977634`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.722858681374936`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4308497730027916, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5466704862173666, -0.8373478246815166, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5760497386044126`, -1.6632283365645302`, 
       0.}, Optica`Optica`RayEnd :> {
       5.6059430288850525`, -1.7364162622695076`, 0.}, 
      RotationMatrix :> {{0.3781210777048861, -0.9257561507196671, 0.}, {
       0.9257561507196671, 0.3781210777048861, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14670805463275563`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07905745551685771, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.336810939211416`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01477431823978348, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3781210777048861, -0.9257561507196671, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.6059430288850525`, -1.7364162622695076`, 
       0.}, Optica`Optica`RayEnd :> {5.698922125620347, -1.8758034494156233`, 
       0.}, RotationMatrix :> {{0.5549245590981283, -0.8319006753872409, 
       0.}, {0.8319006753872409, 0.5549245590981283, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1374711393535217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1675526793883565, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.584788904706183`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4059512074348353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5549245590981283, -0.8319006753872409, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.698922125620347, -1.8758034494156233`, 0.}, 
      Optica`Optica`RayEnd :> {5.864952223193942, -1.8532666557235384`, 0.}, 
      RotationMatrix :> {{0.9909128172684633, 0.13450571948090823`, 
       0.}, {-0.13450571948090823`, 0.9909128172684633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008655348002035998, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16755267938835627`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.83276687020095, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0846085192660949, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 59, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9909128172684633, 0.13450571948090823`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.916170905633331, -1.2320732494795885`, 0.}, 
      Optica`Optica`RayEnd :> {6.120371921029847, -1.2557540571998236`, 0.}, 
      RotationMatrix :> {{0.9933427707315731, -0.11519609296899384`, 0.}, {
       0.11519609296899384`, 0.9933427707315731, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011200089020666285`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20556953894789667`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.510171150325187`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06383324744810324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9933427707315731, -0.11519609296899384`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.120371921029847, -1.2557540571998236`, 0.}, 
      Optica`Optica`RayEnd :> {6.446986340259031, -1.2858947444894115`, 0.}, 
      RotationMatrix :> {{0.9957690048360163, -0.09189172437107362, 0.}, {
       0.09189172437107362, 0.9957690048360163, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011169332644271364`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3280021949297071, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.995614398821154`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3353449847907909, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9957690048360163, -0.09189172437107362, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.211636102543155, -0.9174096462932262, 0.}, 
      Optica`Optica`RayEnd :> {4.1540997221684615`, -0.9391112416421967, 0.}, 
      RotationMatrix :> {{-0.9356567474404794, -0.35291139251815407`, 0.}, {
       0.35291139251815407`, -0.9356567474404794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17951492661350738`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06149304275535432, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.28909357058197, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2840308920148464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9356567474404794, -0.35291139251815407`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1540997221684615`, -0.9391112416421967, 0.},
       Optica`Optica`RayEnd :> {3.854644651235509, -1.0547381333962738`, 0.}, 
      RotationMatrix :> {{-0.9328731605177395, -0.36020503381496977`, 0.}, {
       0.36020503381496977`, -0.9328731605177395, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1790670088391891, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3210029869084847, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.764177991206529`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14485633784479876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9328731605177395, -0.36020503381496977`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.956690241253088, 0.17168039885872202`, 0.}, 
      Optica`Optica`RayEnd :> {3.9225528304364947`, 0.177311715770142, 0.}, 
      RotationMatrix :> {{-0.9866655848570586, 0.16276063301264962`, 
       0.}, {-0.16276063301264962`, -0.9866655848570586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06503541302797344, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03459876511405726, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.585815856229896`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.358533818267427, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9866655848570586, 0.16276063301264962`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9225528304364947`, 0.177311715770142, 0.}, 
      Optica`Optica`RayEnd :> {3.6037690263909803`, 0.23251298497403247`, 0.},
       RotationMatrix :> {{-0.9853364009277426, 0.17062290879821201`, 
       0.}, {-0.17062290879821201`, -0.9853364009277426, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06487305345468208, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3235278872731829, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.064637129394207`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04758394739597535, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9853364009277426, 0.17062290879821201`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8894263217254865`, 1.1211417280571658`, 0.},
       Optica`Optica`RayEnd :> {4.911625254895543, 1.3538738076488344`, 0.}, 
      RotationMatrix :> {{0.09495310148652444, 0.9954817469537496, 
       0.}, {-0.9954817469537496, 0.09495310148652444, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024810574891437957`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23378839471828228`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.124217290087294`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42302084037476284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09495310148652444, 0.9954817469537496, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.911625254895543, 1.3538738076488344`, 0.}, 
      Optica`Optica`RayEnd :> {4.955364090593181, 1.6592345551760308`, 0.}, 
      RotationMatrix :> {{0.1417894588417155, 0.9898968377368285, 
       0.}, {-0.9898968377368285, 0.1417894588417155, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02471879451365109, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3084773441900607, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.580763759488585`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35914493449863877`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1417894588417155, 0.9898968377368285, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.996981320663829, 1.1193631448066796`, 0.}, 
      Optica`Optica`RayEnd :> {6.067545715787124, 1.2013709460128568`, 0.}, 
      RotationMatrix :> {{0.652239487131337, 0.7580129625716507, 
       0.}, {-0.7580129625716507, 0.652239487131337, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008897301888474594, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10818786123123234`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.328915210516653`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22151318371939716`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.652239487131337, 0.7580129625716507, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.067545715787124, 1.2013709460128568`, 0.}, 
      Optica`Optica`RayEnd :> {6.267562956917228, 1.4159252596804341`, 0.}, 
      RotationMatrix :> {{0.6818927853080329, 0.731452137425856, 
       0.}, {-0.731452137425856, 0.6818927853080329, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008867776320461054, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2933265249899224, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.763038467501739`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06716090663178226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6818927853080329, 0.731452137425856, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.060092723143652, -0.7433532091214999, 0.}, 
      Optica`Optica`RayEnd :> {2.9321073113160727`, -0.7766782465086752, 0.}, 
      RotationMatrix :> {{-0.9677325264771427, -0.25197967616092787`, 0.}, {
       0.25197967616092787`, -0.9677325264771427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23159685308222092`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13225287806899227`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.308145199947388`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4214583797630963, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9677325264771427, -0.25197967616092787`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9321073113160727`, -0.7766782465086752, 0.},
       Optica`Optica`RayEnd :> {2.660008727854707, -0.8391463939340966, 0.}, 
      RotationMatrix :> {{-0.9746447210638077, -0.22375805617329653`, 0.}, {
       0.22375805617329653`, -0.9746447210638077, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2309243587133448, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27917719922021916`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.721327454793313`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23789116870765983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9746447210638077, -0.22375805617329653`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5179669445967625`, 1.6546179606098674`, 0.},
       Optica`Optica`RayEnd :> {2.4031273095709067`, 1.8526055614273562`, 0.},
       RotationMatrix :> {{-0.5017404074465232, 0.8650182446257402, 
       0.}, {-0.8650182446257402, -0.5017404074465232, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014952582065927799`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22888257218568875`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.675489898154265`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41842200450474876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5017404074465232, 0.8650182446257402, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4031273095709067`, 1.8526055614273562`, 0.},
       Optica`Optica`RayEnd :> {2.3465003261523547`, 2.0016919364102153`, 0.},
       RotationMatrix :> {{-0.3550761780770455, 0.9348373696864061, 
       0.}, {-0.9348373696864061, -0.3550761780770455, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014456281109720108`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15947840749334863`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.911517941244421`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13119659960362945`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3550761780770455, 0.9348373696864061, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3584371703534224`, 0.8983914028520312, 0.}, 
      Optica`Optica`RayEnd :> {2.2418943733926846`, 1.0564346421307682`, 0.}, 
      RotationMatrix :> {{-0.5934956622751659, 0.8048371877967382, 
       0.}, {-0.8048371877967382, -0.5934956622751659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015296990460617858`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1963667207169989, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.097208687089555`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26231522433063464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5934956622751659, 0.8048371877967382, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2418943733926846`, 1.0564346421307682`, 0.},
       Optica`Optica`RayEnd :> {2.094867808752803, 1.28922010582574, 0.}, 
      RotationMatrix :> {{-0.5340038091082082, 0.8454820706898072, 
       0.}, {-0.8454820706898072, -0.5340038091082082, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015209278402895503`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2753286814291025, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.504695135604626`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2018036008379464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5340038091082082, 0.8454820706898072, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.22879531666272, 0.9020263899058154, 0.}, 
      Optica`Optica`RayEnd :> {2.1107622699206594`, 0.8811695801798028, 0.}, 
      RotationMatrix :> {{-0.9847443421772634, -0.17400741521518098`, 0.}, {
       0.17400741521518098`, -0.9847443421772634, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20419089743765598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11986161451924696`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.18663719441848, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12838481902419024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9847443421772634, -0.17400741521518098`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1107622699206594`, 0.8811695801798028, 0.}, 
      Optica`Optica`RayEnd :> {1.8849683746156314`, 0.8698811764446064, 0.}, 
      RotationMatrix :> {{-0.9987526236797839, -0.04993192057940048, 0.}, {
       0.04993192057940048, -0.9987526236797839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20084734110354682`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2260758970255492, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.521229522016293`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3877241077508799, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9987526236797839, -0.04993192057940048, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.167926937343688, 0.7875044978575387, 0.}, 
      Optica`Optica`RayEnd :> {2.1018694891400234`, 0.5625338826359672, 0.}, 
      RotationMatrix :> {{-0.28173301011795826`, -0.9594928405203836, 0.}, {
       0.9594928405203836, -0.28173301011795826`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013360652149753193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2344682583556936, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.532155446793233`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005075661271111976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.28173301011795826`, -0.9594928405203836, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1018694891400234`, 0.5625338826359672, 0.}, 
      Optica`Optica`RayEnd :> {2.030548797235382, 0.33793803114345605`, 0.}, 
      RotationMatrix :> {{-0.30265785863074235`, -0.9530992711197788, 0.}, {
       0.9530992711197788, -0.30265785863074235`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01332445518595478, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23564791024195994`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.880914353951333`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29259390317835116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.30265785863074235`, -0.9530992711197788, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.764975851525028, 2.414726189496874, 0.}, 
      Optica`Optica`RayEnd :> {5.040372770179408, 2.839708033129257, 0.}, 
      RotationMatrix :> {{0.543819979582786, 0.8392019005022441, 
       0.}, {-0.8392019005022441, 0.543819979582786, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011648681467882966`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.50641191753503, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.142789341906813`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09761098000536395, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.543819979582786, 0.8392019005022441, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.040372770179408, 2.839708033129257, 0.}, 
      Optica`Optica`RayEnd :> {5.14196656423911, 3.043244514731989, 0.}, 
      RotationMatrix :> {{0.4466000046751872, 0.8947337234195004, 
       0.}, {-0.8947337234195004, 0.4466000046751872, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01150095117809422, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2274827429381505, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.479463801455275`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3332259906797349, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4466000046751872, 0.8947337234195004, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.312530256982746, 1.9047407108645917`, 0.}, 
      Optica`Optica`RayEnd :> {2.160245365407655, 2.042717078838258, 0.}, 
      RotationMatrix :> {{-0.7410639837047086, 0.6714344138154577, 
       0.}, {-0.6714344138154577, -0.7410639837047086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23107824109305267`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2054949301594607, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.787073175078406`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43155297795209235`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7410639837047086, 0.6714344138154577, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.160245365407655, 2.042717078838258, 0.}, 
      Optica`Optica`RayEnd :> {1.981736479233178, 2.1791356728325355`, 0.}, 
      RotationMatrix :> {{-0.7945472300109391, 0.6072023544766142, 
       0.}, {-0.6072023544766142, -0.7945472300109391, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22941892763031516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2246674325099838, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.119580975193182`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.352887266363194, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7945472300109391, 0.6072023544766142, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9696703051931497`, 2.143299400268076, 0.}, 
      Optica`Optica`RayEnd :> {2.989624174191954, 2.316567486165755, 0.}, 
      RotationMatrix :> {{0.11440568567074283`, 0.9934341141143722, 
       0.}, {-0.9934341141143722, 0.11440568567074283`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03073033532851586, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17441326348264585`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.904550170223294`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3330352624809419, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.11440568567074283`, 0.9934341141143722, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.989624174191954, 2.316567486165755, 0.}, 
      Optica`Optica`RayEnd :> {3.0356327260310234`, 2.687957121083041, 0.}, 
      RotationMatrix :> {{0.12294237103789243`, 0.9924138115743761, 
       0.}, {-0.9924138115743761, 0.12294237103789243`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030653458184703334`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3742286036185947, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.458408503578815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2319620517961507, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.12294237103789243`, 0.9924138115743761, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.203960725449316, -1.846230942491997, 0.}, 
      Optica`Optica`RayEnd :> {2.183252305621113, -1.8847619765155457`, 0.}, 
      RotationMatrix :> {{-0.4734074457181746, -0.8808435674616654, 0.}, {
       0.8808435674616654, -0.4734074457181746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012533216750468534`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04374333360301874, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.354783245733618`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3040950667087891, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4734074457181746, -0.8808435674616654, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.183252305621113, -1.8847619765155457`, 0.}, 
      Optica`Optica`RayEnd :> {2.0330784063531713`, -2.120040053223454, 0.}, 
      RotationMatrix :> {{-0.5380262977609901, -0.8429280532273216, 0.}, {
       0.8429280532273216, -0.5380262977609901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012457273060717559`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791199982099283, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.767880843084312`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23195738040889063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 58, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5380262977609901, -0.8429280532273216, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9941947604424164`, -2.117172517617665, 0.}, 
      Optica`Optica`RayEnd :> {1.9225117896096935`, -2.339296137369611, 0.}, 
      RotationMatrix :> {{-0.3071199342550494, -0.9516708180790107, 0.}, {
       0.9516708180790107, -0.3071199342550494, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2167442222075358, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2334038362133581, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.565596306673244`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42708034657053395`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3071199342550494, -0.9516708180790107, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9225117896096935`, -2.339296137369611, 0.}, 
      Optica`Optica`RayEnd :> {1.871705955361084, -2.579383011099843, 0.}, 
      RotationMatrix :> {{-0.2070296802215987, -0.9783346623253935, 0.}, {
       0.9783346623253935, -0.2070296802215987, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21442058623731008`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24540362615750727`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.928793673386355`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2851450241387762, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.2070296802215987, -0.9783346623253935, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3314998299859577`, -2.030808955936765, 0.}, 
      Optica`Optica`RayEnd :> {2.343528762848731, -2.080123389095915, 0.}, 
      RotationMatrix :> {{0.2369751897593237, -0.9715157021060092, 0.}, {
       0.9715157021060092, 0.2369751897593237, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00842650401348229, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05076030480232933, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.236284165544546`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06547584871463719, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2369751897593237, -0.9715157021060092, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.343528762848731, -2.080123389095915, 0.}, 
      Optica`Optica`RayEnd :> {2.392586079497609, -2.3630622067704063`, 0.}, 
      RotationMatrix :> {{0.1708360433150209, -0.9852994703664809, 0.}, {
       0.9852994703664809, 0.1708360433150209, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008382122169376241, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28716022507274147`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.661281298652204`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10522114769649174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.1708360433150209, -0.9852994703664809, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4515426952274284`, -2.1199870179428464`, 
       0.}, Optica`Optica`RayEnd :> {2.556943566838984, -2.160322154999426, 
       0.}, RotationMatrix :> {{0.9339489206143823, -0.3574065104096873, 
       0.}, {0.3574065104096873, 0.9339489206143823, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031768831489039896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11285507085571611`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.540814333781142`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1645292948459806, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9339489206143823, -0.3574065104096873, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.556943566838984, -2.160322154999426, 0.}, 
      Optica`Optica`RayEnd :> {2.8588435170927085`, -2.274866792392901, 0.}, 
      RotationMatrix :> {{0.9349658277349367, -0.35473779185184684`, 0.}, {
       0.35473779185184684`, 0.9349658277349367, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03169040267991834, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3228994486195415, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.018705517738065`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30546580852776084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9349658277349367, -0.35473779185184684`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6087330171752736`, -1.8690807179268634`, 
       0.}, Optica`Optica`RayEnd :> {2.626161706169526, -1.8713873058769472`, 
       0.}, RotationMatrix :> {{0.991355877975899, -0.13120031708282623`, 
       0.}, {0.13120031708282623`, 0.991355877975899, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010045254638921875`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01758065835029674, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.488586334000363`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4152497921648321, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.991355877975899, -0.13120031708282623`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.626161706169526, -1.8713873058769472`, 0.}, 
      Optica`Optica`RayEnd :> {2.8201946499746575`, -1.8649612329970076`, 0.},
       RotationMatrix :> {{0.9994520344312882, 0.03310031527280058, 
       0.}, {-0.03310031527280058, 0.9994520344312882, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009699307143704223, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.194139325471022, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 12.775912535697476`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06650547157165353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9994520344312882, 0.03310031527280058, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6583334482814975`, -1.8881915848497568`, 
       0.}, Optica`Optica`RayEnd :> {2.628396231651677, -1.9075178484490787`, 
       0.}, RotationMatrix :> {{-0.840144094927703, -0.5423632544320368, 
       0.}, {0.5423632544320368, -0.840144094927703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2602943346155405, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.035633430991855085`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.587169584852402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32547650290325086`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.840144094927703, -0.5423632544320368, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.628396231651677, -1.9075178484490787`, 0.}, 
      Optica`Optica`RayEnd :> {2.3601829633056144`, -2.072207955493204, 0.}, 
      RotationMatrix :> {{-0.8521744144140566, -0.5232578402834108, 0.}, {
       0.5232578402834108, -0.8521744144140566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2595849112566412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31473987461883846`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.052984599288283`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.345539391121776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8521744144140566, -0.5232578402834108, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.844387562893518, -0.4646491925784466, 0.}, 
      Optica`Optica`RayEnd :> {2.711766618665485, -0.4883288901651158, 0.}, 
      RotationMatrix :> {{-0.9844309330044857, -0.17577183546836372`, 0.}, {
       0.17577183546836372`, -0.9844309330044857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008899379156740599, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1347183837704828, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.634701008652291`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35650017140974455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9844309330044857, -0.17577183546836372`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.711766618665485, -0.4883288901651158, 0.}, 
      Optica`Optica`RayEnd :> {2.37955614645619, -0.5501416006647808, 0.}, 
      RotationMatrix :> {{-0.9831267973074115, -0.18292539576579153`, 0.}, {
       0.18292539576579153`, -0.9831267973074115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008877209848899389, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33791213210661475`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.13481096417008, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05712149344073794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9831267973074115, -0.18292539576579153`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5947838776974526`, 0.699565467163501, 0.}, 
      Optica`Optica`RayEnd :> {2.411995464801956, 0.7751817178667965, 0.}, 
      RotationMatrix :> {{-0.9240531454994891, 0.38226402432415724`, 
       0.}, {-0.38226402432415724`, -0.9240531454994891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21448173965403708`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19781158019508904`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.040476544351561`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3852689566101825, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9240531454994891, 0.38226402432415724`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.411995464801956, 0.7751817178667965, 0.}, 
      Optica`Optica`RayEnd :> {2.187360460058735, 0.8624833169471092, 0.}, 
      RotationMatrix :> {{-0.9320837840673121, 0.3622427631834212, 
       0.}, {-0.3622427631834212, -0.9320837840673121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21390216141656454`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24100301773622376`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.397161010601172`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.271427543048658, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9320837840673121, 0.3622427631834212, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.352532376797479, 2.369357454152633, 0.}, 
      Optica`Optica`RayEnd :> {4.345611921107683, 2.399961550671878, 0.}, 
      RotationMatrix :> {{-0.22055965580636486`, 0.9753734865325063, 
       0.}, {-0.9753734865325063, -0.22055965580636486`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008936328642938847, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03137679764911769, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.592405285322359`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2036018338902022, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 63, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22055965580636486`, 0.9753734865325063, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.52218963097219, 1.6623099573089042`, 0.}, 
      Optica`Optica`RayEnd :> {6.625069808407641, 1.7056084372372071`, 0.}, 
      RotationMatrix :> {{0.9216978103531939, 0.38790868305585574`, 
       0.}, {-0.38790868305585574`, 0.9216978103531939, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010575137314652998`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11162029059831177`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.282700813782181`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.006371263684616907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9216978103531939, 0.38790868305585574`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.625069808407641, 1.7056084372372071`, 0.}, 
      Optica`Optica`RayEnd :> {6.865402790228393, 1.7961382788338658`, 0.}, 
      RotationMatrix :> {{0.9358097282176724, 0.3525055355213116, 
       0.}, {-0.3525055355213116, 0.9358097282176724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010540848720848851`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2568182126921106, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.662791768566505`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1664824294923158, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9358097282176724, 0.3525055355213116, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.096591811836374, 1.2499734969440517`, 0.}, 
      Optica`Optica`RayEnd :> {3.9862592797803313`, 1.3481438736691491`, 0.}, 
      RotationMatrix :> {{-0.7470830404213084, 0.6647307204536691, 
       0.}, {-0.6647307204536691, -0.7470830404213084, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.42877914854273486`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1476844287534923, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.083597977680718`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3327008805468265, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7470830404213084, 0.6647307204536691, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9862592797803313`, 1.3481438736691491`, 0.},
       Optica`Optica`RayEnd :> {3.8677830330422824`, 1.489527299309895, 0.}, 
      RotationMatrix :> {{-0.6422831292278108, 0.7664674695701909, 
       0.}, {-0.7664674695701909, -0.6422831292278108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4182358096509167, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18446109098410765`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.356600392337198`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014289779190539205`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6422831292278108, 0.7664674695701909, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8677830330422824`, 1.489527299309895, 0.}, 
      Optica`Optica`RayEnd :> {3.9779876884070617`, 1.6374489948889326`, 0.}, 
      RotationMatrix :> {{0.597441198991249, 0.8019127220264679, 
       0.}, {-0.8019127220264679, 0.597441198991249, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010284086557917411`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18446109098410762`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.629602806993677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35348289560043894`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.597441198991249, 0.8019127220264679, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.560933992060265, -0.15747189595957234`, 0.},
       Optica`Optica`RayEnd :> {3.4144325205014994`, -0.2356454770595336, 0.},
       RotationMatrix :> {{-0.8822542428189671, -0.4707732479951796, 0.}, {
       0.4707732479951796, -0.8822542428189671, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009508196549776105, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16605357554378639`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.583806795028083`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34048700927053216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8822542428189671, -0.4707732479951796, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4144325205014994`, -0.2356454770595336, 0.},
       Optica`Optica`RayEnd :> {3.136273110507371, -0.3775728539432791, 0.}, 
      RotationMatrix :> {{-0.8907497994584358, -0.45449399860147366`, 0.}, {
       0.45449399860147366`, -0.8907497994584358, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009483135678169314, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3122755797006586, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.045974652985057`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30079994262717386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8907497994584358, -0.45449399860147366`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.908455139197296, -0.6337664010897093, 0.}, 
      Optica`Optica`RayEnd :> {4.902628181296575, -0.6345152162075803, 0.}, 
      RotationMatrix :> {{-0.9918436354880198, -0.12746059289799383`, 0.}, {
       0.12746059289799383`, -0.9918436354880198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028389611648616347`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005874875526982264, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.070638187162531`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2478384191659382, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9918436354880198, -0.12746059289799383`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.902628181296575, -0.6345152162075803, 0.}, 
      Optica`Optica`RayEnd :> {4.621919019136533, -0.6819973016660933, 0.}, 
      RotationMatrix :> {{-0.9859939089041371, -0.1667813287030066, 0.}, {
       0.1667813287030066, -0.9859939089041371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02829547433083988, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2846966493657453, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.491989228223835`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09612521554475707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9859939089041371, -0.1667813287030066, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.147244857449752, -0.8967049223682861, 0.}, 
      Optica`Optica`RayEnd :> {5.137138975144561, -0.8944342626544151, 0.}, 
      RotationMatrix :> {{-0.975675127495185, 0.21922145330066212`, 
       0.}, {-0.21922145330066212`, -0.975675127495185, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01421205393836006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01035783532899422, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.757378876724509`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11885882372178458`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.975675127495185, 0.21922145330066212`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.137138975144561, -0.8944342626544151, 0.}, 
      Optica`Optica`RayEnd :> {4.950544740297555, -0.8794548318219492, 0.}, 
      RotationMatrix :> {{-0.9967932047725457, 0.08002066557632384, 
       0.}, {-0.08002066557632384, -0.9967932047725457, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013895593409651902`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1871945293703974, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.034426780192698`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4117050734625103, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9967932047725457, 0.08002066557632384, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.477344047574457, -0.3900611068834905, 0.}, 
      Optica`Optica`RayEnd :> {6.37136217824953, -0.2190326212415336, 0.}, 
      RotationMatrix :> {{-0.5267393580018712, 0.8500268517710348, 
       0.}, {-0.8500268517710348, -0.5267393580018712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015345332093358513`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20120362702145028`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.227762752965637`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31431396487850805`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5267393580018712, 0.8500268517710348, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.37136217824953, -0.2190326212415336, 0.}, 
      Optica`Optica`RayEnd :> {6.258025463924768, -0.11781453791912785`, 0.}, 
      RotationMatrix :> {{-0.7458572661530691, 0.6661058013008669, 
       0.}, {-0.6661058013008669, -0.7458572661530691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01208765519280617, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15195496439864747`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.452656100275634`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1329003431580093, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7458572661530691, 0.6661058013008669, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.952683447459978, -0.8740524240884584, 0.}, 
      Optica`Optica`RayEnd :> {7.052469467204013, -0.8069688713511451, 0.}, 
      RotationMatrix :> {{0.8298962621891257, 0.5579177304984291, 
       0.}, {-0.5579177304984291, 0.8298962621891257, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.102031822877546, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12023914830127837`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.09078363023157, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11868176800645894`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.8298962621891257, 0.5579177304984291, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.052469467204013, -0.8069688713511451, 0.}, 
      Optica`Optica`RayEnd :> {7.353433065589417, -0.6194021000598979, 0.}, 
      RotationMatrix :> {{0.8486762488256513, 0.5289126815261863, 
       0.}, {-0.5289126815261863, 0.8486762488256513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10171591638734098`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3546271016796576, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.615631740717463`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08568040801621667, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.8486762488256513, 0.5289126815261863, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.098021325764257, -0.9968067045346964, 0.}, 
      Optica`Optica`RayEnd :> {7.224219046840725, -1.1355461267955338`, 0.}, 
      RotationMatrix :> {{0.6728799609735263, -0.7397516867978507, 0.}, {
       0.7397516867978507, 0.6728799609735263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.299873046186019, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18754863927569534`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.462535316592723`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3504321589346009, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6728799609735263, -0.7397516867978507, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.224219046840725, -1.1355461267955338`, 0.}, 
      Optica`Optica`RayEnd :> {7.404873413023072, -1.354943595196123, 0.}, 
      RotationMatrix :> {{0.6356529438227172, -0.7719749575015457, 0.}, {
       0.7719749575015457, 0.6356529438227172, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.279616600698042, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28420283102272786`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.883155506506359`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28277482227131384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6356529438227172, -0.7719749575015457, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.404873413023072, -1.354943595196123, 0.}, 
      Optica`Optica`RayEnd :> {7.120685522106613, -1.3520295228243422`, 0.}, 
      RotationMatrix :> {{-0.999947431536079, 0.01025349522837049, 
       0.}, {-0.01025349522837049, -0.999947431536079, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02017902408934035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.284202831022728, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.303775696419997`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2064293998235206, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.999947431536079, 0.01025349522837049, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.997752704567444, -1.1584789527443164`, 0.}, 
      Optica`Optica`RayEnd :> {6.91710714484928, -1.2568947932735157`, 0.}, 
      RotationMatrix :> {{-0.6338190654039287, -0.7734813458193351, 0.}, {
       0.7734813458193351, -0.6338190654039287, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0982826838666087, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12723751007200973`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.66327537191522, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3529330528887607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6338190654039287, -0.7734813458193351, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.91710714484928, -1.2568947932735157`, 0.}, 
      Optica`Optica`RayEnd :> {6.750245482442702, -1.435074784336653, 0.}, 
      RotationMatrix :> {{-0.6835440507544367, -0.729909261948508, 0.}, {
       0.729909261948508, -0.6835440507544367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0977787930460281, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24411252240789755`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.024561905078908`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33028177594652613`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6835440507544367, -0.729909261948508, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.084428116973464, -0.7640639246493693, 0.}, 
      Optica`Optica`RayEnd :> {5.9151743398878, -0.7436509199874607, 0.}, 
      RotationMatrix :> {{-0.992805500822268, 0.11973820416661245`, 
       0.}, {-0.11973820416661245`, -0.992805500822268, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015260549290999206`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17048029744545468`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.26559042511447, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39134791806459074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.992805500822268, 0.11973820416661245`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.9151743398878, -0.7436509199874607, 0.}, 
      Optica`Optica`RayEnd :> {5.614645344029233, -0.7065919626854019, 0.}, 
      RotationMatrix :> {{-0.992482647288619, 0.12238543553452148`, 
       0.}, {-0.12238543553452148`, -0.992482647288619, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015222883000252874`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.302805290026569, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.713742254353791`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04851053877923521, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.992482647288619, 0.12238543553452148`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.584222943013781, 0.1716058667428289, 0.}, 
      Optica`Optica`RayEnd :> {6.574033746401171, 0.4458597481085579, 0.}, 
      RotationMatrix :> {{-0.03712681018710209, 0.9993105623205084, 
       0.}, {-0.9993105623205084, -0.03712681018710209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01955729545822849, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27444309277476414`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.02841662872913, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18227719542043766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.03712681018710209, 0.9993105623205084, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.574033746401171, 0.44585974810855794`, 0.}, 
      Optica`Optica`RayEnd :> {6.5469469278676025`, 0.6368635855234813, 0.}, 
      RotationMatrix :> {{-0.14040811487637145`, 0.9900937133811443, 
       0.}, {-0.9900937133811443, -0.14040811487637145`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01934716147380595, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1929149077844866, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.31393069225017, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04563989012152169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.14040811487637145`, 0.9900937133811443, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.672516915681058, 0.8885179867466502, 0.}, 
      Optica`Optica`RayEnd :> {6.804524202477089, 1.1273984324969137`, 0.}, 
      RotationMatrix :> {{0.4836704186055283, 0.8752502077497342, 
       0.}, {-0.8752502077497342, 0.4836704186055283, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0277210485409145, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27292817943388387`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.114013048488745`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.014880981286184196`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4836704186055283, 0.8752502077497342, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.804524202477089, 1.1273984324969137`, 0.}, 
      Optica`Optica`RayEnd :> {6.881204474904297, 1.3242995202150794`, 0.}, 
      RotationMatrix :> {{0.3628886537891379, 0.9318325090653936, 
       0.}, {-0.9318325090653936, 0.3628886537891379, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.027185381555830897`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21130523543941696`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.426744796939083`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32703996589451323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3628886537891379, 0.9318325090653936, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.062238178947538, 0.1912066990993062, 0.}, 
      Optica`Optica`RayEnd :> {4.854268663032112, 0.21823571056275384`, 0.}, 
      RotationMatrix :> {{-0.991659899439686, 0.1288822867708011, 
       0.}, {-0.1288822867708011, -0.991659899439686, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1131361439329352, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20971859004577484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.96072514895521, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28988971922855766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.991659899439686, 0.1288822867708011, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.854268663032112, 0.21823571056275384`, 0.}, 
      Optica`Optica`RayEnd :> {4.5969460739394234`, 0.25932011660617466`, 0.},
       RotationMatrix :> {{-0.9874927882007858, 0.15766417871995314`, 
       0.}, {-0.15766417871995314`, -0.9874927882007858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11280753395326751`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2605817401072178, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.346386124313893`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05592771067944334, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9874927882007858, 0.15766417871995314`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1212892282563045`, -0.28584844369612605`, 
       0.}, Optica`Optica`RayEnd :> {5.058741770078805, -0.37352533270738797`,
        0.}, RotationMatrix :> {{-0.580753054102128, -0.8140797811953386, 
       0.}, {0.8140797811953386, -0.580753054102128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04358140069196921, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1077006099850843, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.035997394004834`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07866410196669993, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.580753054102128, -0.8140797811953386, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.058741770078805, -0.37352533270738797`, 0.},
       Optica`Optica`RayEnd :> {4.892604669438865, -0.6189034417401148, 0.}, 
      RotationMatrix :> {{-0.5606473967072029, -0.8280546458811977, 0.}, {
       0.8280546458811977, -0.5606473967072029, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04346055979354915, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29633081615235757`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.474567001910323`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33938106936887935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5606473967072029, -0.8280546458811977, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.548883626199007, -0.6931337635867161, 0.}, 
      Optica`Optica`RayEnd :> {5.577185086091668, -0.8919322091923785, 0.}, 
      RotationMatrix :> {{0.14094150740125255`, -0.9900179248334154, 0.}, {
       0.9900179248334154, 0.14094150740125255`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023705238377672685`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20080287499755425`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.580282714241351`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0141657271172832, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14094150740125255`, -0.9900179248334154, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.577185086091668, -0.8919322091923785, 0.}, 
      Optica`Optica`RayEnd :> {5.594092515281308, -1.1510887972667576`, 0.}, 
      RotationMatrix :> {{0.06510180719408744, -0.9978786272388358, 0.}, {
       0.9978786272388358, 0.06510180719408744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023557862314608866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2597075245428136, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.964649850564715`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07898327597463918, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06510180719408744, -0.9978786272388358, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.903281161164852, -0.3033895933541004, 0.}, 
      Optica`Optica`RayEnd :> {5.971531298262972, -0.3511333900671929, 0.}, 
      RotationMatrix :> {{0.8194084215176003, -0.5732101174491205, 0.}, {
       0.5732101174491205, 0.8194084215176003, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012832567441884733`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08329196442930964, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.23616546732462, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19713221544600562`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8194084215176003, -0.5732101174491205, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.971531298262972, -0.3511333900671929, 0.}, 
      Optica`Optica`RayEnd :> {6.089186185011931, -0.46412778297490015`, 0.}, 
      RotationMatrix :> {{0.7212473429970422, -0.6926776091514053, 0.}, {
       0.6926776091514053, 0.7212473429970422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012462827083531003`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16312696038512908`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.477593368694611`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38805064964416247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7212473429970422, -0.6926776091514053, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.34098319847574, 0.5569745163120173, 0.}, 
      Optica`Optica`RayEnd :> {6.300445387111725, 0.5979718692414645, 0.}, 
      RotationMatrix :> {{-0.7031102786860972, 0.7110808224146943, 
       0.}, {-0.7110808224146943, -0.7031102786860972, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009898074758088963, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05765498328337413, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.643252963628905`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24418922545684146`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7031102786860972, 0.7110808224146943, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.300445387111725, 0.5979718692414645, 0.}, 
      Optica`Optica`RayEnd :> {6.16874912920781, 0.7568037859242456, 0.}, 
      RotationMatrix :> {{-0.6382841348253419, 0.7698008594631888, 
       0.}, {-0.7698008594631888, -0.6382841348253419, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009821291566382246, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20632857800852625`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.948619259081523`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09915339087034417, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6382841348253419, 0.7698008594631888, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.97435174451669, 0.14200277352684282`, 0.}, 
      Optica`Optica`RayEnd :> {6.96810564813093, 0.297035070841694, 0.}, 
      RotationMatrix :> {{-0.04025634215495033, 0.9991893849097392, 
       0.}, {-0.9991893849097392, -0.04025634215495033, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016419451878506252`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15515807078840801`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.849272486812623`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3309734246900812, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 25, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.04025634215495033, 0.9991893849097392, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.96810564813093, 0.29703507084169406`, 0.}, 
      Optica`Optica`RayEnd :> {6.962721548274071, 0.6105183577215063, 0.}, 
      RotationMatrix :> {{-0.017172545229810807`, 0.9998525409730824, 
       0.}, {-0.9998525409730824, -0.017172545229810807`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01637449812895876, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3135295196376879, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.3132961758764, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3436480155943355, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.017172545229810807`, 0.9998525409730824, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1533879505423, 0.03752729228343482, 0.}, 
      Optica`Optica`RayEnd :> {7.39375033838211, -0.12084842573426254`, 0.}, 
      RotationMatrix :> {{0.8350299452392858, -0.5502044988489962, 0.}, {
       0.5502044988489962, 0.8350299452392858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.914557138366321, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28784882411723717`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.333867100462125`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25171979961387453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8350299452392858, -0.5502044988489962, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.39375033838211, -0.12084842573426254`, 0.}, 
      Optica`Optica`RayEnd :> {7.5496058187056825`, -0.19014294206542603`, 
       0.}, 
      RotationMatrix :> {{0.9137562418887829, -0.40626288337637717`, 0.}, {
       0.40626288337637717`, 0.9137562418887829, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7807874059594893`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17056570798510884`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.586304348280086`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15590550628333574`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9137562418887829, -0.40626288337637717`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5496058187056825`, -0.19014294206542603`, 
       0.}, Optica`Optica`RayEnd :> {7.664545060342192, -0.06412059693375714, 
       0.}, RotationMatrix :> {{0.6738707504239021, 0.7388492483065314, 
       0.}, {-0.7388492483065314, 0.6738707504239021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.129198502335155, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17056570798510864`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.838741596098046`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4015926767288006, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6738707504239021, 0.7388492483065314, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.964087541651995, -0.04693834832296653, 0.}, 
      Optica`Optica`RayEnd :> {6.8111748949094295`, -0.1054241267005212, 0.}, 
      RotationMatrix :> {{-0.9340127521389022, -0.3572396658294165, 0.}, {
       0.3572396658294165, -0.9340127521389022, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016283138047119023`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16371580194423838`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.474317854939176`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07237137505338113, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9340127521389022, -0.3572396658294165, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8111748949094295`, -0.1054241267005212, 0.},
       Optica`Optica`RayEnd :> {6.543886199459315, -0.22501170017298794`, 0.},
       RotationMatrix :> {{-0.9128041822979482, -0.40839750829231775`, 0.}, {
       0.40839750829231775`, -0.9128041822979482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016214232730260462`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29282150611670676`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.907693683991903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.030255989273331445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9128041822979482, -0.40839750829231775`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.103008723708266, 0.39029214819013164`, 0.}, 
      Optica`Optica`RayEnd :> {6.033355543856384, 0.40387788023287086`, 0.}, 
      RotationMatrix :> {{-0.9815041834266985, 0.1914406903348646, 
       0.}, {-0.1914406903348646, -0.9815041834266985, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00987143567335703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07096574933456039, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.811939632332235`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.007141696761486682, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9815041834266985, 0.1914406903348646, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.033355543856384, 0.40387788023287086`, 0.}, 
      Optica`Optica`RayEnd :> {5.819217854866354, 0.46843169438588755`, 0.}, 
      RotationMatrix :> {{-0.9574408586696894, 0.28862952404396836`, 
       0.}, {-0.28862952404396836`, -0.9574408586696894, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009772716261754294, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2236563094743658, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.142950970354297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2162769234154685, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9574408586696894, 0.28862952404396836`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.788286169112373, 0.08275477138089243, 0.}, 
      Optica`Optica`RayEnd :> {6.8157708955746745`, -0.10919306060865114`, 
       0.}, RotationMatrix :> {{0.14174282199027954`, -0.9899035167198018, 
       0.}, {0.9899035167198018, 0.14174282199027954`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.30121549593820734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19390559660358847`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.240045468523611`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09012484075276268, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14174282199027954`, -0.9899035167198018, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8157708955746745`, -0.10919306060865114`, 
       0.}, Optica`Optica`RayEnd :> {6.8256738210161805`, -0.3516744978920914,
        0.}, RotationMatrix :> {{0.0408059162131716, -0.9991670917329106, 
       0.}, {0.9991670917329106, 0.0408059162131716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2981272510973552, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24268357043554264`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.599217152768215`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12992882356238586`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0408059162131716, -0.9991670917329106, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9767342513768655`, 0.8415684967397441, 0.}, 
      Optica`Optica`RayEnd :> {7.037289686503661, 0.6105007043935301, 0.}, 
      RotationMatrix :> {{0.2535070053606427, -0.9673335506603078, 0.}, {
       0.9673335506603078, 0.2535070053606427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29742887971425863`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23887085503080668`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.131687250990794`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14247973464683417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2535070053606427, -0.9673335506603078, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.037289686503661, 0.6105007043935301, 0.}, 
      Optica`Optica`RayEnd :> {7.0967852982839235`, 0.326322821662418, 0.}, 
      RotationMatrix :> {{0.204917664951201, -0.9787792144252688, 0.}, {
       0.9787792144252688, 0.204917664951201, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2962795400380463, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2903391066574488, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.561389128843818`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06173953670310367, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.204917664951201, -0.9787792144252688, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.156710522321821, 1.057504153542214, 0.}, 
      Optica`Optica`RayEnd :> {7.192065638887377, 1.1046249733468794`, 0.}, 
      RotationMatrix :> {{0.6001575361283644, 0.7998818236641774, 
       0.}, {-0.7998818236641774, 0.6001575361283644, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      74.89283276356394, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05890972692542202, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.306573804688998`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2778775224086185, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6001575361283644, 0.7998818236641774, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.192065638887377, 1.1046249733468794`, 0.}, 
      Optica`Optica`RayEnd :> {7.353649000460349, 1.3495682650002878`, 0.}, 
      RotationMatrix :> {{0.5506541614333041, 0.8347334871060246, 
       0.}, {-0.8347334871060246, 0.5506541614333041, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      74.54594837632067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2934389184536172, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.740863404000352`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27276631606679513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5506541614333041, 0.8347334871060246, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.353649000460349, 1.3495682650002878`, 0.}, 
      Optica`Optica`RayEnd :> {7.060538310049242, 1.3634434958074577`, 0.}, 
      RotationMatrix :> {{-0.9988814433878126, 0.047284903039755244`, 
       0.}, {-0.047284903039755244`, -0.9988814433878126, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3452777077564049, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2934389184536172, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.175153003311706`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2676142023243001, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9988814433878126, 0.047284903039755244`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.875687281178761, 1.0642572209501147`, 0.}, 
      Optica`Optica`RayEnd :> {6.635547121943515, 1.057748727360387, 0.}, 
      RotationMatrix :> {{-0.9996329187554892, -0.02709294632151572, 0.}, {
       0.02709294632151572, -0.9996329187554892, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.29508966314603813`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24022834255419812`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.965575214990979`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3869379329092527, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9996329187554892, -0.02709294632151572, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.635547121943515, 1.057748727360387, 0.}, 
      Optica`Optica`RayEnd :> {6.295198604732274, 1.0441447323620774`, 0.}, 
      RotationMatrix :> {{-0.9992021243811962, -0.0399388862151133, 0.}, {
       0.0399388862151133, -0.9992021243811962, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2943378479465851, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3406202898357702, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.46969324394792, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.041133610246141025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9992021243811962, -0.0399388862151133, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.881209576075601, 0.9157210836573269, 0.}, 
      Optica`Optica`RayEnd :> {5.673185502654298, 0.9513089607076581, 0.}, 
      RotationMatrix :> {{-0.9856801103546575, 0.16862597679844443`, 
       0.}, {-0.16862597679844443`, -0.9856801103546575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29825967157468253`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2110462321761298, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.523675959971072`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3753343041217139, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9856801103546575, 0.16862597679844443`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.673185502654298, 0.9513089607076581, 0.}, 
      Optica`Optica`RayEnd :> {5.34378759472657, 1.0085816823173743`, 0.}, 
      RotationMatrix :> {{-0.985218757465966, 0.17130090465965828`, 
       0.}, {-0.17130090465965828`, -0.985218757465966, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29752346497243076`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3343398665845106, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.018498962516148`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07282790955168016, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.985218757465966, 0.17130090465965828`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.453084848827884, 0.3971828149358141, 0.}, 
      Optica`Optica`RayEnd :> {6.439182291361847, 0.18377233116537578`, 0.}, 
      RotationMatrix :> {{-0.06500688600318408, -0.9978848153831023, 0.}, {
       0.9978848153831023, -0.06500688600318408, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009507337784272946, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21386284316642984`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.555950604285513`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3948349909409025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.06500688600318408, -0.9978848153831023, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.439182291361847, 0.18377233116537578`, 0.}, 
      Optica`Optica`RayEnd :> {6.433388240338392, -0.11117953659543571`, 0.}, 
      RotationMatrix :> {{-0.019640266938392985`, -0.999807111354279, 0.}, {
       0.999807111354279, -0.019640266938392985`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009473108443659173, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29500877160324174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.992563586258312`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40657798840927944`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.019640266938392985`, -0.999807111354279, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.364102736692175, 1.2549358388771608`, 0.}, 
      Optica`Optica`RayEnd :> {6.422826032225031, 1.365065552474647, 0.}, 
      RotationMatrix :> {{0.4705099362349001, 0.8823946962126583, 
       0.}, {-0.8823946962126583, 0.4705099362349001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1867445417829799, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12480776921050828`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.380012881106294`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.428643355639208, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4705099362349001, 0.8823946962126583, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.422826032225031, 1.365065552474647, 0.}, 
      Optica`Optica`RayEnd :> {6.57323765724591, 1.646089620359747, 0.}, 
      RotationMatrix :> {{0.4718874544402706, 0.8816587947397115, 
       0.}, {-0.8816587947397115, 0.4718874544402706, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18628405188088945`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3187446998337556, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.851755036860252`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.023549007113154184`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4718874544402706, 0.8816587947397115, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.285753978708785, 1.4070605913421486`, 0.}, 
      Optica`Optica`RayEnd :> {6.174197682692963, 1.5494748272910812`, 0.}, 
      RotationMatrix :> {{-0.6166567608270429, 0.787232138143698, 
       0.}, {-0.787232138143698, -0.6166567608270429, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.2178579440909103`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18090500761915915`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.7084339209944, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38178952605014893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6166567608270429, 0.787232138143698, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.174197682692963, 1.5494748272910812`, 0.}, 
      Optica`Optica`RayEnd :> {6.036656461720002, 1.6775537955970146`, 0.}, 
      RotationMatrix :> {{-0.7318320123460498, 0.6814850737217437, 
       0.}, {-0.6814850737217437, -0.7318320123460498, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.1221576234966264`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18794097368334872`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.986586562045757`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20226071439071636`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7318320123460498, 0.6814850737217437, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.036656461720002, 1.6775537955970146`, 0.}, 
      Optica`Optica`RayEnd :> {5.875024991266699, 1.5816524017169022`, 0.}, 
      RotationMatrix :> {{-0.8600118818455528, -0.510274007847225, 0.}, {
       0.510274007847225, -0.8600118818455528, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09285415661781521, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18794097368334886`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.264739203097113`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1913173264784951, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8600118818455528, -0.510274007847225, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.114937969488056, 1.3969433197743022`, 0.}, 
      Optica`Optica`RayEnd :> {5.995683381404745, 1.3667402332319012`, 0.}, 
      RotationMatrix :> {{-0.9693930628289708, -0.24551392982693748`, 0.}, {
       0.24551392982693748`, -0.9693930628289708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1677785615575076, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12301984886841667`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.884118548688917`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3138497625883437, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 63, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9693930628289708, -0.24551392982693748`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.055094413422918, 1.2366335665228163`, 0.}, 
      Optica`Optica`RayEnd :> {6.036231460668536, 1.1256743437386747`, 0.}, 
      RotationMatrix :> {{-0.16759449984852248`, -0.9858560156638103, 0.}, {
       0.9858560156638103, -0.16759449984852248`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008747945436807911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11255114440766383`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.12334122513202, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2672670501305916, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.16759449984852248`, -0.9858560156638103, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.036231460668536, 1.1256743437386747`, 0.}, 
      Optica`Optica`RayEnd :> {5.987631729229609, 0.8005725958373693, 0.}, 
      RotationMatrix :> {{-0.14784794525748984`, -0.9890101036304622, 0.}, {
       0.9890101036304622, -0.14784794525748984`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008724604657246544, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32871428381562573`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.609838365179145`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37916267191914893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.14784794525748984`, -0.9890101036304622, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.853458526119032, 0.5885561136172155, 0.}, 
      Optica`Optica`RayEnd :> {6.87794882615238, 0.5586810616236928, 0.}, 
      RotationMatrix :> {{0.6339674759468782, -0.7733597089592551, 0.}, {
       0.7733597089592551, 0.6339674759468782, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009454276455358273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03863021521217712, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.269780364395148`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3248970359335221, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6339674759468782, -0.7733597089592551, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.87794882615238, 0.5586810616236928, 0.}, 
      Optica`Optica`RayEnd :> {7.082999887296782, 0.31698239836342923`, 0.}, 
      RotationMatrix :> {{0.6469286666066743, -0.7625505231278186, 0.}, {
       0.7625505231278186, 0.6469286666066743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009429612362099857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31696085168084, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.73888242488279, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01000833307199564, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6469286666066743, -0.7625505231278186, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.615981264787904, 0.7888893143257181, 0.}, 
      Optica`Optica`RayEnd :> {5.369808577478939, 0.8373156111747763, 0.}, 
      RotationMatrix :> {{-0.9811952997173442, 0.19301757384391344`, 
       0.}, {-0.19301757384391344`, -0.9811952997173442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16812038719283007`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2508906100343942, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.998654906532218`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23527812355951566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9811952997173442, 0.19301757384391344`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.369808577478939, 0.8373156111747763, 0.}, 
      Optica`Optica`RayEnd :> {5.132603163998297, 0.8633038107538517, 0.}, 
      RotationMatrix :> {{-0.9940518104830969, 0.10890820940258225`, 
       0.}, {-0.10890820940258225`, -0.9940518104830969, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16687660816130284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23862479900857828`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.351819609064915`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35004580985806183`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9940518104830969, 0.10890820940258225`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.655926041426688, -0.8105216709669426, 0.}, 
      Optica`Optica`RayEnd :> {4.593039866070804, -0.836333126310018, 0.}, 
      RotationMatrix :> {{-0.9251066232505742, -0.3797074342410476, 0.}, {
       0.3797074342410476, -0.9251066232505742, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.200420238756517, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06797721881497223, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.784724443639375`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011318523028835625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9251066232505742, -0.3797074342410476, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.593039866070804, -0.836333126310018, 0.}, 
      Optica`Optica`RayEnd :> {4.359421295530483, -0.9513629506393492, 0.}, 
      RotationMatrix :> {{-0.8971438841137577, -0.44173844206416985`, 0.}, {
       0.44173844206416985`, -0.8971438841137577, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19935506263517028`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2604025671658008, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.17012024304476, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05463447470907114, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8971438841137577, -0.44173844206416985`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.813642807021752, 0.8598979484814954, 0.}, 
      Optica`Optica`RayEnd :> {4.672920885593271, 0.9332801431723884, 0.}, 
      RotationMatrix :> {{-0.8866828604568774, 0.4623780974181294, 
       0.}, {-0.4623780974181294, -0.8866828604568774, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05949558170002157, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1587060353867354, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.017654986126058`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2809582994540771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8866828604568774, 0.4623780974181294, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.672920885593271, 0.9332801431723884, 0.}, 
      Optica`Optica`RayEnd :> {4.356816966072465, 1.0969723235612296`, 0.}, 
      RotationMatrix :> {{-0.8879995623899459, 0.45984429668667615`, 
       0.}, {-0.45984429668667615`, -0.8879995623899459, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05934870297569491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3559730577682385, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.54449511162305, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24196634378843132`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8879995623899459, 0.45984429668667615`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.382123401893994, 0.6275245760517915, 0.}, 
      Optica`Optica`RayEnd :> {6.382254773277838, 0.6275395844991265, 0.}, 
      RotationMatrix :> {{0.9935373004106537, 0.11350609099387525`, 
       0.}, {-0.11350609099387525`, 0.9935373004106537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09640871569417986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0001322259202444539, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.307199903555905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3732152307923661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9935373004106537, 0.11350609099387525`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.382254773277838, 0.6275395844991265, 0.}, 
      Optica`Optica`RayEnd :> {6.560609031189221, 0.6257838054686258, 0.}, 
      RotationMatrix :> {{0.9999515480576416, -0.009843857837521855, 0.}, {
       0.009843857837521855, 0.9999515480576416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0948712557500937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17836289994033044`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.571176995467594`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11116505839076407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999515480576416, -0.009843857837521855, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.841682554284794, 0.9015937670123577, 0.}, 
      Optica`Optica`RayEnd :> {5.674320094655733, 1.010871541214962, 0.}, 
      RotationMatrix :> {{-0.8373166734928811, 0.5467181982436791, 
       0.}, {-0.5467181982436791, -0.8373166734928811, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05559620806845538, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19987952578431953`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.238570489875894`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38764255443576323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8373166734928811, 0.5467181982436791, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.674320094655733, 1.010871541214962, 0.}, 
      Optica`Optica`RayEnd :> {5.441039746564652, 1.1369156045927298`, 0.}, 
      RotationMatrix :> {{-0.8797907800263997, 0.47536110840132695`, 
       0.}, {-0.47536110840132695`, -0.8797907800263997, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.055201250034786715`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2651543450865445, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.630998920603979`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40484246661737083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8797907800263997, 0.47536110840132695`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.712539000534084, 0.9118442775173976, 0.}, 
      Optica`Optica`RayEnd :> {5.64849501488751, 0.8916496320041639, 0.}, 
      RotationMatrix :> {{-0.9537098850194715, -0.3007282082149016, 0.}, {
       0.3007282082149016, -0.9537098850194715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013459522400967618`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06715248174791281, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.252449839259738`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2222117339775008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9537098850194715, -0.3007282082149016, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.64849501488751, 0.8916496320041639, 0.}, 
      Optica`Optica`RayEnd :> {5.415740315443308, 0.8455727215350262, 0.}, 
      RotationMatrix :> {{-0.9809629929395483, -0.19419476430399063`, 0.}, {
       0.19419476430399063`, -0.9809629929395483, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013295512126931313`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2372716413559399, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.603611868466528`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4145622966398341, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9809629929395483, -0.19419476430399063`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.622717590410879, 0.8184888024532366, 0.}, 
      Optica`Optica`RayEnd :> {5.563056991588514, 0.6697420551766223, 0.}, 
      RotationMatrix :> {{-0.37226137428868944`, -0.9281279379550509, 0.}, {
       0.9281279379550509, -0.37226137428868944`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00826879541395185, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16026534833586484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.568954668880224`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05509111243615075, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.37226137428868944`, -0.9281279379550509, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.563056991588514, 0.6697420551766223, 0.}, 
      Optica`Optica`RayEnd :> {5.43041916475558, 0.3419012486380427, 0.}, 
      RotationMatrix :> {{-0.37504784773641575`, -0.9270054540876665, 0.}, {
       0.9270054540876665, -0.37504784773641575`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008248378369815169, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35365574721589027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.092365174759742`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38514735223775876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.37504784773641575`, -0.9270054540876665, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.02114616024396, 1.3648656312182066`, 0.}, 
      Optica`Optica`RayEnd :> {6.051328059475833, 1.2725527638858225`, 0.}, 
      RotationMatrix :> {{0.31076390324224085`, -0.9504871363893602, 0.}, {
       0.9504871363893602, 0.31076390324224085`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01302447129658328, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09712163773520933, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.725715891011822`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.005475205737550559, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.31076390324224085`, -0.9504871363893602, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.051328059475833, 1.2725527638858225`, 0.}, 
      Optica`Optica`RayEnd :> {6.132844253351959, 1.133288049183445, 0.}, 
      RotationMatrix :> {{0.5051579020959115, -0.8630269369782478, 0.}, {
       0.8630269369782478, 0.5051579020959115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01201864247176827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1613677496440505, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      12.964540160485017`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4271791082188854, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5051579020959115, -0.8630269369782478, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.10158126102411, 1.6554902335190946`, 0.}, 
      Optica`Optica`RayEnd :> {6.111402240816899, 1.6956126639955889`, 0.}, 
      RotationMatrix :> {{0.2377563233656335, 0.9713248327411665, 
       0.}, {-0.9713248327411665, 0.2377563233656335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.415558756770056, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04130691311913142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.097218313155238`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08693219696693287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2377563233656335, 0.9713248327411665, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.111402240816899, 1.6956126639955889`, 0.}, 
      Optica`Optica`RayEnd :> {6.184072372672007, 1.8586024464312514`, 0.}, 
      RotationMatrix :> {{0.40721549411083485`, 0.9133321090140583, 
       0.}, {-0.9133321090140583, 0.40721549411083485`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.219363342218478, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17845620539018378`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.36133349713271, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4243596795825109, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.40721549411083485`, 0.9133321090140583, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.184072372672007, 1.8586024464312514`, 0.}, 
      Optica`Optica`RayEnd :> {6.36240697690967, 1.8520156282570719`, 0.}, 
      RotationMatrix :> {{0.9993185938687008, -0.036909997944749695`, 0.}, {
       0.036909997944749695`, 0.9993185938687008, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.18747791291442026`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17845620539018395`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.625448681110182`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.053634275622963704`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9993185938687008, -0.036909997944749695`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.36240697690967, 1.8520156282570719`, 0.}, 
      Optica`Optica`RayEnd :> {6.4228553982991645`, 1.6841090899871713`, 0.}, 
      RotationMatrix :> {{0.33872972507359816`, -0.9408837193572666, 0.}, {
       0.9408837193572666, 0.33872972507359816`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008330159073777816, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17845620539018398`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.889563865087654`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35819289573106766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 66, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.33872972507359816`, -0.9408837193572666, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8798616310272624`, 1.4511061084650112`, 0.},
       Optica`Optica`RayEnd :> {5.833820172339405, 1.4060403563564783`, 0.}, 
      RotationMatrix :> {{-0.7146385134871368, -0.6994939564005498, 0.}, {
       0.6994939564005498, -0.7146385134871368, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012948197299062807`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06442622083603396, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.574492338624848`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04577362788830458, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7146385134871368, -0.6994939564005498, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.833820172339405, 1.4060403563564783`, 0.}, 
      Optica`Optica`RayEnd :> {5.599442986112421, 1.1595858165884754`, 0.}, 
      RotationMatrix :> {{-0.6891285847229114, -0.7246390782436425, 0.}, {
       0.7246390782436425, -0.6891285847229114, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012907460466375639`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3401066091623869, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.07785012018518, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23184162520066287`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6891285847229114, -0.7246390782436425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.637302678486836, 1.0169603213082352`, 0.}, 
      Optica`Optica`RayEnd :> {6.858767059798419, 0.9834814317062208, 0.}, 
      RotationMatrix :> {{0.9887659171429442, -0.14947227534386234`, 0.}, {
       0.14947227534386234`, 0.9887659171429442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08655418072123228, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2239805979068419, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.530844498670472`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0305084600023938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9887659171429442, -0.14947227534386234`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.858767059798419, 0.9834814317062208, 0.}, 
      Optica`Optica`RayEnd :> {7.162702661414744, 0.9438053337150264, 0.}, 
      RotationMatrix :> {{0.9915868807006633, -0.12944287551784187`, 0.}, {
       0.12944287551784187`, 0.9915868807006633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08632282556897239, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.306514343353919, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.984485726834272`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33213937097040164`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9915868807006633, -0.12944287551784187`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.879946877019573, 1.1112905707736813`, 0.}, 
      Optica`Optica`RayEnd :> {4.630680122811341, 1.1441015350696153`, 0.}, 
      RotationMatrix :> {{-0.9914477571862711, 0.13050419445485825`, 
       0.}, {-0.13050419445485825`, -0.9914477571862711, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10126434327769537`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2514169328655816, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.710138155131173`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09992862116086007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9914477571862711, 0.13050419445485825`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.630680122811341, 1.1441015350696153`, 0.}, 
      Optica`Optica`RayEnd :> {4.395280740220098, 1.1447153361225655`, 0.}, 
      RotationMatrix :> {{-0.999996600520636, 0.0026074790833754413`, 
       0.}, {-0.0026074790833754413`, -0.999996600520636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09949505690056722, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23540018282930641`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.058530425718546`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3760360187080714, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999996600520636, 0.0026074790833754413`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5841933507179515`, 0.3253409192139103, 0.}, 
      Optica`Optica`RayEnd :> {7.626714297149007, 0.32609206755954295`, 0.}, 
      RotationMatrix :> {{0.9998440038220597, 0.017662616484311777`, 
       0.}, {-0.017662616484311777`, 0.9998440038220597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07331833380489744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04252758057108228, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.11519426885085, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33851110201066054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9998440038220597, 0.017662616484311777`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.626714297149007, 0.32609206755954295`, 0.}, 
      Optica`Optica`RayEnd :> {7.891581672955386, 0.3077814576649613, 0.}, 
      RotationMatrix :> {{0.9976189669440538, -0.06896663536434017, 0.}, {
       0.06896663536434017, 0.9976189669440538, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07275867915652669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2654995389850397, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.508133586548709`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2136622778268778, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9976189669440538, -0.06896663536434017, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.628638705595014, 1.3647266179686772`, 0.}, 
      Optica`Optica`RayEnd :> {4.628289473465782, 1.3653888162929944`, 0.}, 
      RotationMatrix :> {{-0.4664854711917487, 0.8845288605619447, 
       0.}, {-0.8845288605619447, -0.4664854711917487, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27769873481583474`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0007486452436344371, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.371789194721142`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13949084246473148`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4664854711917487, 0.8845288605619447, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.628289473465782, 1.3653888162929944`, 0.}, 
      Optica`Optica`RayEnd :> {4.503571201537513, 1.5849363906658709`, 0.}, 
      RotationMatrix :> {{-0.49393555235692693`, 0.8694985164552367, 
       0.}, {-0.8694985164552367, -0.49393555235692693`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2768719222552171, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25249907874245264`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.745487831259972`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3409974565097846, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.49393555235692693`, 0.8694985164552367, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8418719011631226`, -0.4257345527276301, 0.},
       Optica`Optica`RayEnd :> {3.6865263052883464`, -0.4917694976009767, 0.},
       RotationMatrix :> {{-0.9203030502693476, -0.3912062060664872, 0.}, {
       0.3912062060664872, -0.9203030502693476, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014975335166352324`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1687983059811777, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.314059002621482`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36153628431999923`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9203030502693476, -0.3912062060664872, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6865263052883464`, -0.4917694976009767, 0.},
       Optica`Optica`RayEnd :> {3.3847302367062975`, -0.6145580846091381, 0.},
       RotationMatrix :> {{-0.9262695987464098, -0.37686155340942523`, 0.}, {
       0.37686155340942523`, -0.9262695987464098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014936601135951322`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3258188209895821, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.796270857686064`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25442736223641393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9262695987464098, -0.37686155340942523`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6801569042007625`, -1.8359346973849022`, 
       0.}, Optica`Optica`RayEnd :> {4.628435784582611, -1.9140209948334994`, 
       0.}, RotationMatrix :> {{-0.5522111079699226, -0.833704319429035, 
       0.}, {0.833704319429035, -0.5522111079699226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01296517541926786, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09366186024090042, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.848365574097743`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18240435074462413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.5522111079699226, -0.833704319429035, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.628435784582611, -1.9140209948334994`, 0.}, 
      Optica`Optica`RayEnd :> {4.444584970458577, -2.17407961338191, 0.}, 
      RotationMatrix :> {{-0.5772698884286177, -0.8165534127744559, 0.}, {
       0.8165534127744559, -0.5772698884286177, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012926979602887445`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3184832914540061, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.319720845449671`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3780506280026243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.5772698884286177, -0.8165534127744559, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.6059430288850525`, -1.7364162622695076`, 
       0.}, Optica`Optica`RayEnd :> {5.580392820833384, -1.8113373396360717`, 
       0.}, RotationMatrix :> {{-0.32277501149021404`, -0.946475721800349, 
       0.}, {0.946475721800349, -0.32277501149021404`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009236915279233931, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07915794947603322, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.442882591509301`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.007810122608896826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 26, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.32277501149021404`, -0.946475721800349, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.580392820833384, -1.8113373396360717`, 0.}, 
      Optica`Optica`RayEnd :> {5.466710937071036, -2.126897206581193, 0.}, 
      RotationMatrix :> {{-0.33893148254761013`, -0.9408110597447708, 0.}, {
       0.9408110597447708, -0.33893148254761013`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009212778928076043, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33541258223593623`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.939293213218487`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32484733794044635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.33893148254761013`, -0.9408110597447708, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.698922125620347, -1.8758034494156233`, 0.}, 
      Optica`Optica`RayEnd :> {6.1387084261467875`, -2.3126263188259486`, 0.},
       RotationMatrix :> {{0.7094931449697943, -0.7047123365181498, 0.}, {
       0.7047123365181498, 0.7094931449697943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1288157913514856, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6198598304218492, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.415401077471461`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26169885781784324`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7094931449697943, -0.7047123365181498, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.1387084261467875`, -2.3126263188259486`, 
       0.}, Optica`Optica`RayEnd :> {6.275115027170251, -2.3916007283932794`, 
       0.}, RotationMatrix :> {{0.8654203243568335, -0.501046566887862, 0.}, {
       0.501046566887862, 0.8654203243568335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11020071862710995`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15761890168784629`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.648677051969473`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2627281761886999, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8654203243568335, -0.501046566887862, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.275115027170251, -2.39160072839328, 0.}, 
      Optica`Optica`RayEnd :> {6.415962670666085, -2.3208500429481655`, 0.}, 
      RotationMatrix :> {{0.8935961486064217, 0.44887183381870777`, 
       0.}, {-0.44887183381870777`, 0.8935961486064217, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015925022623388713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15761890168784598`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.881953026467485`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.211638246717272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 65, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8935961486064217, 0.44887183381870777`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.864952223193942, -1.8532666557235384`, 0.}, 
      Optica`Optica`RayEnd :> {6.087955228348104, -1.7755293071353104`, 0.}, 
      RotationMatrix :> {{0.9442717924838862, 0.3291667995397902, 
       0.}, {-0.3291667995397902, 0.9442717924838862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008110396898927022, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23616400164570983`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.149226632406203`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08167386762664074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9442717924838862, 0.3291667995397902, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.087955228348104, -1.7755293071353104`, 0.}, 
      Optica`Optica`RayEnd :> {6.29649179032783, -1.714548594238228, 0.}, 
      RotationMatrix :> {{0.9598048522405408, 0.2806682126916288, 
       0.}, {-0.2806682126916288, 0.9598048522405408, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008078540266813651, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2172697517551874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.47078586500388, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15449651245302595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9598048522405408, 0.2806682126916288, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.446986340259031, -1.2858947444894115`, 0.}, 
      Optica`Optica`RayEnd :> {6.634975538592947, -1.2988093106254066`, 0.}, 
      RotationMatrix :> {{0.997648581465386, -0.06853690903522433, 0.}, {
       0.06853690903522433, 0.997648581465386, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011138660727445219`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1884322814931389, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.24811365602196, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015706165023651183`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.997648581465386, -0.06853690903522433, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.634975538592947, -1.2988093106254066`, 0.}, 
      Optica`Optica`RayEnd :> {6.920460688392599, -1.3157020578048386`, 0.}, 
      RotationMatrix :> {{0.9982539169634744, -0.05906875034297252, 0.}, {
       0.05906875034297252, 0.9982539169634744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011110705312078101`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2859845024881561, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.67137071970443, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3909082105631478, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9982539169634744, -0.05906875034297252, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.854644651235509, -1.0547381333962738`, 0.}, 
      Optica`Optica`RayEnd :> {3.3777554314599088`, -1.2431677270440258`, 0.},
       RotationMatrix :> {{-0.930032719118252, -0.3674767222144963, 0.}, {
       0.3674767222144963, -0.930032719118252, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17862020868966294`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5127660672279686, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.451284521292006`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4302627286361166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.930032719118252, -0.3674767222144963, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3777554314599088`, -1.2431677270440258`, 
       0.}, Optica`Optica`RayEnd :> {3.08320727731976, -1.3467014046111412`, 
       0.}, RotationMatrix :> {{-0.9434162715747592, -0.33161082390051716`, 
       0.}, {0.33161082390051716`, -0.9434162715747592, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17803973008588353`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3122144094976083, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.913361847348467`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3170786959815689, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9434162715747592, -0.33161082390051716`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6037690263909803`, 0.23251298497403247`, 
       0.}, Optica`Optica`RayEnd :> {3.4006273323013927`, 0.2693601613068275, 
       0.}, RotationMatrix :> {{-0.9839445672305586, 0.17847433601912885`, 
       0.}, {-0.17847433601912885`, -0.9839445672305586, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06471109920873179, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20645644160763704`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.34128876114844, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4243677774598775, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9839445672305586, 0.17847433601912885`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4006273323013927`, 0.2693601613068275, 0.}, 
      Optica`Optica`RayEnd :> {3.0823029265595387`, 0.3204098587077727, 0.}, 
      RotationMatrix :> {{-0.9873835675674664, 0.1583467413549859, 
       0.}, {-0.1583467413549859, -0.9873835675674664, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06453786688081013, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.322391840615783, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.8184286852598, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17221897413353246`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9873835675674664, 0.1583467413549859, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.955364090593181, 1.6592345551760308`, 0.}, 
      Optica`Optica`RayEnd :> {4.990563917608184, 1.8428149348015401`, 0.}, 
      RotationMatrix :> {{0.18831035796382498`, 0.9821095708135297, 
       0.}, {-0.9821095708135297, 0.18831035796382498`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024627353653903755`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18692453986925364`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.831242642913384`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38364641664834326`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.18831035796382498`, 0.9821095708135297, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.990563917608184, 1.8428149348015401`, 0.}, 
      Optica`Optica`RayEnd :> {5.042768365054769, 2.0940943312606244`, 0.}, 
      RotationMatrix :> {{0.20341114780236672`, 0.9790934097162144, 
       0.}, {-0.9790934097162144, 0.20341114780236672`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024563707780477777`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25664496764605566`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.211077195029546`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22417909856085133`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.20341114780236672`, 0.9790934097162144, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.267562956917228, 1.4159252596804341`, 0.}, 
      Optica`Optica`RayEnd :> {6.3414793017053155`, 1.4891410751493424`, 0.}, 
      RotationMatrix :> {{0.710465422849919, 0.7037321102057843, 
       0.}, {-0.7037321102057843, 0.710465422849919, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00883834873261919, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10403932747576128`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.902451166319258`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04803409799231373, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.710465422849919, 0.7037321102057843, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.3414793017053155`, 1.4891410751493424`, 0.},
       Optica`Optica`RayEnd :> {6.540441563317021, 1.658662282854143, 0.}, 
      RotationMatrix :> {{0.7611774360680673, 0.6485436845894373, 
       0.}, {-0.6485436845894373, 0.7611774360680673, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008784764056170971, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26138749282882445`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.289304655705918`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1323655831269353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7611774360680673, 0.6485436845894373, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.660008727854707, -0.8391463939340966, 0.}, 
      Optica`Optica`RayEnd :> {2.54432612307239, -0.8621886350649688, 0.}, 
      RotationMatrix :> {{-0.9807340832785364, -0.19534753107169953`, 0.}, {
       0.19534753107169953`, -0.9807340832785364, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23025381708549322`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11795511826773367`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.879387313272076`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10071595507794567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9807340832785364, -0.19534753107169953`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.54432612307239, -0.8621886350649688, 0.}, 
      Optica`Optica`RayEnd :> {2.3362231553334047`, -0.9367987626976133, 0.}, 
      RotationMatrix :> {{-0.9413290910173204, -0.337490062675192, 0.}, {
       0.337490062675192, -0.9413290910173204, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22443726071711514`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22107355411069113`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.206576173355899`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26623613124668416`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9413290910173204, -0.337490062675192, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3465003261523547`, 2.0016919364102153`, 0.},
       Optica`Optica`RayEnd :> {2.322593379298374, 2.1193979559844265`, 0.}, 
      RotationMatrix :> {{-0.1990432259686228, 0.9799907112804711, 
       0.}, {-0.9799907112804711, -0.1990432259686228, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013976453203989363`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1201093216694009, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.072464432281418`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08336614604124339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1990432259686228, 0.9799907112804711, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.322593379298374, 2.1193979559844265`, 0.}, 
      Optica`Optica`RayEnd :> {2.258971730969517, 2.3682680267369927`, 0.}, 
      RotationMatrix :> {{-0.2476769042472682, 0.9688426864576568, 
       0.}, {-0.9688426864576568, -0.2476769042472682, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013922465758562676`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2568735608280231, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.452637302306892`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1634629008169722, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2476769042472682, 0.9688426864576568, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0948678087528037`, 1.28922010582574, 0.}, 
      Optica`Optica`RayEnd :> {2.057027867898407, 1.3599474591186946`, 0.}, 
      RotationMatrix :> {{-0.4717397888564077, 0.8817378134171812, 
       0.}, {-0.8817378134171812, -0.4717397888564077, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015122069281034293`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08021358755030637, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.612181342922037`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10997854120786196`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4717397888564077, 0.8817378134171812, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.057027867898407, 1.3599474591186946`, 0.}, 
      Optica`Optica`RayEnd :> {1.8907195989671668`, 1.684804414747426, 0.}, 
      RotationMatrix :> {{-0.45569813156848177`, 0.8901343791164312, 
       0.}, {-0.8901343791164312, -0.45569813156848177`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015082284760137343`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36495271191658957`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.15231135655859, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3997048158828596, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.45569813156848177`, 0.8901343791164312, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.030548797235382, 0.3379380311434561, 0.}, 
      Optica`Optica`RayEnd :> {1.9734752681722851`, 0.17096375846217324`, 0.},
       RotationMatrix :> {{-0.3234378166503089, -0.946249427350147, 0.}, {
       0.946249427350147, -0.3234378166503089, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013288356287742805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1764590475355672, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.117369477648992`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21582376657426988`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3234378166503089, -0.946249427350147, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9734752681722851`, 0.1709637584621732, 0.}, 
      Optica`Optica`RayEnd :> {1.8604948557158172`, -0.18781759303254186`, 
       0.}, RotationMatrix :> {{-0.3003601983328228, -0.9538258495435461, 
       0.}, {0.9538258495435461, -0.3003601983328228, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013251577968552922`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.37614974648297705`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.674071102443799`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4306788118792402, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3003601983328228, -0.9538258495435461, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.14196656423911, 3.043244514731989, 0.}, 
      Optica`Optica`RayEnd :> {5.170744503251183, 3.121852289530835, 0.}, 
      RotationMatrix :> {{0.34378167233747065`, 0.9390496055932573, 
       0.}, {-0.9390496055932573, 0.34378167233747065`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011355094425544969`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08370992792141616, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.591635104869972`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35135390427363505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.34378167233747065`, 0.9390496055932573, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.170744503251183, 3.121852289530835, 0.}, 
      Optica`Optica`RayEnd :> {5.261063463459581, 3.37564683895124, 0.}, 
      RotationMatrix :> {{0.33527625564536245`, 0.9421198609521114, 
       0.}, {-0.9421198609521114, 0.33527625564536245`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011326642907984163`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26938668840281005`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.99032740370613, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04762737186439561, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33527625564536245`, 0.9421198609521114, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0356327260310234`, 2.687957121083041, 0.}, 
      Optica`Optica`RayEnd :> {3.0616699245015138`, 2.8842848435931794`, 0.}, 
      RotationMatrix :> {{0.13146996899500815`, 0.9913201537608584, 
       0.}, {-0.9913201537608584, 0.13146996899500815`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030576773362099727`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19804673774190198`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.723791132152963`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19948387775241572`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.13146996899500815`, 0.9913201537608584, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0616699245015138`, 2.8842848435931794`, 0.},
       Optica`Optica`RayEnd :> {3.0949401737714983`, 3.1903948146437107`, 0.},
       RotationMatrix :> {{0.10805091992262104`, 0.994145360952751, 
       0.}, {-0.994145360952751, 0.10805091992262104`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030492686970856185`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3079126887009433, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.179501911430359`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09632709292226663, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 64, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10805091992262104`, 0.994145360952751, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.392586079497609, -2.3630622067704063`, 0.}, 
      Optica`Optica`RayEnd :> {2.394983681095318, -2.386009537355096, 0.}, 
      RotationMatrix :> {{0.1039171364290255, -0.9945859584552713, 0.}, {
       0.9945859584552713, 0.1039171364290255, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00833797408153295, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02307224467589494, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 12.692198106517903`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2900611724380023, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.1039171364290255, -0.9945859584552713, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.394983681095318, -2.386009537355096, 0.}, 
      Optica`Optica`RayEnd :> {2.4434141231202973`, -2.618182018279854, 0.}, 
      RotationMatrix :> {{0.20420145620509228`, -0.9789288867347409, 0.}, {
       0.9789288867347409, 0.20420145620509228`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008252250294128315, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23716991506827365`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.043209580818948`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4286944566926582, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.20420145620509228`, -0.9789288867347409, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8588435170927085`, -2.274866792392901, 0.}, 
      Optica`Optica`RayEnd :> {2.9627488659543375`, -2.3139506941956443`, 0.},
       RotationMatrix :> {{0.9359751091257243, -0.35206617999615925`, 0.}, {
       0.35206617999615925`, 0.9359751091257243, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03161216749070068, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11101294024654661`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.167462857668436`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2790933279611107, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9359751091257243, -0.35206617999615925`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9627488659543375`, -2.3139506941956443`, 
       0.}, Optica`Optica`RayEnd :> {3.131828495403569, -2.4140370798315542`, 
       0.}, RotationMatrix :> {{0.8605346299116557, -0.509391942145544, 0.}, {
       0.509391942145544, 0.8605346299116557, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030314999018646115`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19648207471509846`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.458256328246781`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28805324360970563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8605346299116557, -0.509391942145544, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8201946499746575`, -1.8649612329970076`, 
       0.}, Optica`Optica`RayEnd :> {3.108523759879753, -1.8071764067739187`, 
       0.}, RotationMatrix :> {{0.9805027734277066, 0.19650524496963212`, 
       0.}, {-0.19650524496963212`, 0.9805027734277066, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009365273698826688, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2940625133543838, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.16995630359235, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23365286410306518`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9805027734277066, 0.19650524496963212`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.108523759879753, -1.8071764067739187`, 0.}, 
      Optica`Optica`RayEnd :> {3.4145530314090804`, -1.7368927213868033`, 0.},
       RotationMatrix :> {{0.9746268256398903, 0.2238359907233659, 
       0.}, {-0.2238359907233659, 0.9746268256398903, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009338396665339768, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31399635581383095`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.63467091019682, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.424067198360775, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9746268256398903, 0.2238359907233659, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3601829633056144`, -2.072207955493204, 0.}, 
      Optica`Optica`RayEnd :> {2.3453218671299387`, -2.0808772665983004`, 0.},
       RotationMatrix :> {{-0.8637703418813584, -0.5038856978384691, 0.}, {
       0.5038856978384691, -0.8637703418813584, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2588774214069859, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01720491600036557, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.076039186728773`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.059796149189903815`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8637703418813584, -0.5038856978384691, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3453218671299387`, -2.0808772665983004`, 
       0.}, Optica`Optica`RayEnd :> {2.108755056526315, -2.2415706126908783`, 
       0.}, RotationMatrix :> {{-0.8272061986052553, -0.561898482814327, 
       0.}, {0.561898482814327, -0.8272061986052553, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.257487750986994, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28598287948337003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.499293848364161`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013139169750535584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8272061986052553, -0.561898482814327, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.37955614645619, -0.5501416006647808, 0.}, 
      Optica`Optica`RayEnd :> {2.3117054913161614`, -0.563277382484079, 0.}, 
      RotationMatrix :> {{-0.9817706795724902, -0.19006928403024645`, 0.}, {
       0.19006928403024645`, -0.9817706795724902, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00885509576718143, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06911049245183576, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.227419024055541`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03652720503276222, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9817706795724902, -0.19006928403024645`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3117054913161614`, -0.563277382484079, 0.}, 
      Optica`Optica`RayEnd :> {2.0670908527082337`, -0.6339946714700225, 0.}, 
      RotationMatrix :> {{-0.9606609305734639, -0.277723921313462, 0.}, {
       0.277723921313462, -0.9606609305734639, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008782603006572872, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2546316091588173, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.60427380561059, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19986853393291262`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9606609305734639, -0.277723921313462, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.187360460058735, 0.8624833169471092, 0.}, 
      Optica`Optica`RayEnd :> {2.117252386810888, 0.8880033394673086, 0.}, 
      RotationMatrix :> {{-0.9396806848530521, 0.3420529352514002, 
       0.}, {-0.3420529352514002, -0.9396806848530521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2133241493307555, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07460840089398087, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.497136267799107`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15514211396556693`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9396806848530521, 0.3420529352514002, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.117252386810888, 0.8880033394673086, 0.}, 
      Optica`Optica`RayEnd :> {1.82287096155126, 1.0079416589077277`, 0.}, 
      RotationMatrix :> {{-0.9260867029505805, 0.3773107719349167, 
       0.}, {-0.3773107719349167, -0.9260867029505805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21263547278197578`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.317876743421223, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.967593848062517`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021031729167206525`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9260867029505805, 0.3773107719349167, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.865402790228393, 1.7961382788338658`, 0.}, 
      Optica`Optica`RayEnd :> {7.3413858183556036`, 1.955001466937924, 0.}, 
      RotationMatrix :> {{0.9485623552374743, 0.3165903634451561, 
       0.}, {-0.3165903634451561, 0.9485623552374743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010506671303630892`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5017941366733316, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.33519591170877, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2476918448241146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9485623552374743, 0.3165903634451561, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3413858183556036`, 1.955001466937924, 0.}, 
      Optica`Optica`RayEnd :> {7.6650107297416685`, 2.069805418458244, 0.}, 
      RotationMatrix :> {{0.9424559133892579, 0.33433045227382446`, 
       0.}, {-0.33433045227382446`, 0.9424559133892579, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010478898418429052`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34338466849048194`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.843405221074683`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38654064417784134`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9424559133892579, 0.33433045227382446`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9862592797803313`, 1.3481438736691491`, 0.},
       Optica`Optica`RayEnd :> {3.9406505601097632`, 1.3331172926123287`, 0.},
       RotationMatrix :> {{-0.9497791096215826, -0.31292114490144957`, 0.}, {
       0.31292114490144957`, -0.9497791096215826, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010543338891818188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048020344107947435`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.147945238785367`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3477171748173569, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9497791096215826, -0.31292114490144957`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9406505601097632`, 1.3331172926123287`, 0.},
       Optica`Optica`RayEnd :> {3.6579620877190564`, 1.2411682766713321`, 0.},
       RotationMatrix :> {{-0.9509596180832698, -0.30931505746555854`, 0.}, {
       0.30931505746555854`, -0.9509596180832698, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010517277329279352`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29726653689090027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.5878997133839, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17181144443668792`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9509596180832698, -0.30931505746555854`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8677830330422824`, 1.489527299309895, 0.}, 
      Optica`Optica`RayEnd :> {3.7888325516111925`, 1.6179286271643638`, 0.}, 
      RotationMatrix :> {{-0.5237811431493117, 0.8518528711468903, 
       0.}, {-0.8518528711468903, -0.5237811431493117, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4079517230929995, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15073181320806744`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.558581022036009`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20003855768689463`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5237811431493117, 0.8518528711468903, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7888325516111925`, 1.6179286271643638`, 0.},
       Optica`Optica`RayEnd :> {3.64293783700036, 1.8804307999132586`, 0.}, 
      RotationMatrix :> {{-0.4857960338317726, 0.8740722015447692, 
       0.}, {-0.8740722015447692, -0.4857960338317726, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4065136136684532, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30032092575987224`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.00305599216062, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30980541975078896`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4857960338317726, 0.8740722015447692, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9779876884070617`, 1.6374489948889326`, 0.},
       Optica`Optica`RayEnd :> {4.122485381220374, 1.7816297349162387`, 0.}, 
      RotationMatrix :> {{0.7078827182449516, 0.7063299917249295, 
       0.}, {-0.7063299917249295, 0.7078827182449516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010031209033109072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20412660047919257`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.903132451635795`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09268977524291643, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7078827182449516, 0.7063299917249295, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.122485381220374, 1.7816297349162387`, 0.}, 
      Optica`Optica`RayEnd :> {4.297582025844731, 1.9168082156473396`, 0.}, 
      RotationMatrix :> {{0.7915549862990817, 0.611097949321597, 
       0.}, {-0.611097949321597, 0.7915549862990817, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009860713068529951, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2212059145038334, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.230517205101469`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21935129334518644`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7915549862990817, 0.611097949321597, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.136273110507371, -0.3775728539432791, 0.}, 
      Optica`Optica`RayEnd :> {3.134336033072358, -0.3785168038398527, 0.}, 
      RotationMatrix :> {{-0.8989450055595333, -0.43806149908382785`, 0.}, {
       0.43806149908382785`, -0.8989450055595333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00945814085981273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0021548341923400293`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.048862130802792`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2366778900890481, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8989450055595333, -0.43806149908382785`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.134336033072358, -0.3785168038398527, 0.}, 
      Optica`Optica`RayEnd :> {2.8550571286116426`, -0.5179270523033074, 0.}, 
      RotationMatrix :> {{-0.8947207164590222, -0.44662606231505764`, 0.}, {
       0.44662606231505764`, -0.8947207164590222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009434397517409005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31214087180857863`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.510830621079489`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18168407636267384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8947207164590222, -0.44662606231505764`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.621919019136533, -0.6819973016660933, 0.}, 
      Optica`Optica`RayEnd :> {4.417776698132674, -0.7249371646637658, 0.}, 
      RotationMatrix :> {{-0.9785859771348164, -0.20583849337550228`, 0.}, {
       0.20583849337550228`, -0.9785859771348164, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02820164916367357, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20860948937932222`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.771525943992126`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32778501857669967`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9785859771348164, -0.20583849337550228`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.417776698132674, -0.7249371646637658, 0.}, 
      Optica`Optica`RayEnd :> {4.118371926014607, -0.7916360463911913, 0.}, 
      RotationMatrix :> {{-0.9760733701080334, -0.2174414315762897, 0.}, {
       0.2174414315762897, -0.9760733701080334, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028130144925547763`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30674412527505873`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.225507249399213`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05296272117199598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9760733701080334, -0.2174414315762897, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.950544740297555, -0.8794548318219492, 0.}, 
      Optica`Optica`RayEnd :> {4.650177889460393, -0.8977408237269249, 0.}, 
      RotationMatrix :> {{-0.9981520173235642, -0.06076635839754817, 0.}, {
       0.06076635839754817, -0.9981520173235642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013586179523650327`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3009229512379916, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.437663534851607`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27106206719713777`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9981520173235642, -0.06076635839754817, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.650177889460393, -0.8977408237269249, 0.}, 
      Optica`Optica`RayEnd :> {4.364103526572395, -0.9270059505467887, 0.}, 
      RotationMatrix :> {{-0.9948081696809649, -0.10176790032229555`, 0.}, {
       0.10176790032229555`, -0.9948081696809649, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013540244654536173`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2875673638463804, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.86326323334425, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13353238910238563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9948081696809649, -0.10176790032229555`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.258025463924768, -0.11781453791912785`, 0.},
       Optica`Optica`RayEnd :> {6.169782539508914, -0.07606490709734837, 0.}, 
      RotationMatrix :> {{-0.9039345061696613, 0.4276709115146959, 
       0.}, {-0.4276709115146959, -0.9039345061696613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009521553992527193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09762092697376464, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.583468142420479`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22304976191033185`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9039345061696613, 0.4276709115146959, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.169782539508914, -0.07606490709734837, 0.}, 
      Optica`Optica`RayEnd :> {5.8600330983876, 0.07567180311158178, 0.}, 
      RotationMatrix :> {{-0.8980367105665967, 0.43992052290695305`, 
       0.}, {-0.43992052290695305`, -0.8980367105665967, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009497200546697086, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3449184621037191, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.093947466333983`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16023481144866786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8980367105665967, 0.43992052290695305`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.353433065589417, -0.6194021000598979, 0.}, 
      Optica`Optica`RayEnd :> {7.385488297624597, -0.6009307024520898, 0.}, 
      RotationMatrix :> {{0.8664429323462608, 0.49927612098638635`, 
       0.}, {-0.49927612098638635`, 0.8664429323462608, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1014009879930647, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036996356988424295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.665206859081952`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39942814109485125`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8664429323462608, 0.49927612098638635`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.385488297624597, -0.6009307024520898, 0.}, 
      Optica`Optica`RayEnd :> {7.626023718036561, -0.44921376867471036`, 0.}, 
      RotationMatrix :> {{0.8458065452019363, 0.5334897263242888, 
       0.}, {-0.5334897263242888, 0.8458065452019363, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10106380707993437`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2843858584169928, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.0860979295391, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3746971139210001, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.8458065452019363, 0.5334897263242888, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.224219046840725, -1.1355461267955338`, 0.}, 
      Optica`Optica`RayEnd :> {7.269024531048093, -0.9459605645839262, 0.}, 
      RotationMatrix :> {{0.22999799195941656`, 0.973191103378281, 
       0.}, {-0.973191103378281, 0.22999799195941656`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020256445487972553`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1948081538697702, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.723578242778215`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16375881543214338`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.22999799195941656`, 0.973191103378281, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.269024531048093, -0.9459605645839262, 0.}, 
      Optica`Optica`RayEnd :> {7.334496159081358, -0.6055118865612469, 0.}, 
      RotationMatrix :> {{0.1888494197885076, 0.9820060573364829, 
       0.}, {-0.9820060573364829, 0.1888494197885076, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020187025190116295`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3466869429971602, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.236674918414012`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.023144528843638653`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.1888494197885076, 0.9820060573364829, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.404873413023072, -1.354943595196123, 0.}, 
      Optica`Optica`RayEnd :> {7.416265530500333, -1.3702567653724946`, 0.}, 
      RotationMatrix :> {{0.5968849831742314, -0.8023268142478458, 0.}, {
       0.8023268142478458, 0.5968849831742314, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.259437576608702, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019085950892376725`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.908730680702144`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4066822093019787, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5968849831742314, -0.8023268142478458, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.416265530500333, -1.3702567653724946`, 0.}, 
      Optica`Optica`RayEnd :> {7.5948414737607, -1.6208355140056565`, 0.}, 
      RotationMatrix :> {{0.5803579601602823, -0.8143614910336785, 0.}, {
       0.8143614910336785, 0.5803579601602823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.2453551903496605`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3076996535225399, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.364126167915503`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1422209262218577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5803579601602823, -0.8143614910336785, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5948414737607, -1.6208355140056565`, 0.}, 
      Optica`Optica`RayEnd :> {7.33511329940802, -1.4558495987725213`, 0.}, 
      RotationMatrix :> {{-0.844096414732081, 0.5361914235013897, 
       0.}, {-0.5361914235013897, -0.844096414732081, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014044680021468097`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30769965352253986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.819521655128861`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18223510542956667`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.844096414732081, 0.5361914235013897, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.120685522106613, -1.3520295228243422`, 0.}, 
      Optica`Optica`RayEnd :> {6.9146782862872165`, -1.3397586999505606`, 0.},
       RotationMatrix :> {{-0.9982307115204045, 0.05945962140365959, 
       0.}, {-0.05945962140365959, -0.9982307115204045, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020101898600125026`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2063723680727343, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.580314669637461`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3315823408736166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9982307115204045, 0.05945962140365959, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9146782862872165`, -1.3397586999505606`, 
       0.}, 
      Optica`Optica`RayEnd :> {6.636570319863082, -1.3161057789349486`, 0.}, 
      RotationMatrix :> {{-0.9964028014191775, 0.08474347953686345, 
       0.}, {-0.08474347953686345, -0.9964028014191775, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020045701722223426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791119876700724, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.99340041138917, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07593898534511273, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9964028014191775, 0.08474347953686345, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.750245482442702, -1.435074784336653, 0.}, 
      Optica`Optica`RayEnd :> {6.676997172033755, -1.5035954304728814`, 0.}, 
      RotationMatrix :> {{-0.7302811962529004, -0.6831466712203409, 0.}, {
       0.6831466712203409, -0.7302811962529004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09727748565061539, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10030151506678103`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.158965935268395`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39038642681586366`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7302811962529004, -0.6831466712203409, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.676997172033755, -1.5035954304728814`, 0.}, 
      Optica`Optica`RayEnd :> {6.489914395050555, -1.6575550106708106`, 0.}, 
      RotationMatrix :> {{-0.7721501218731773, -0.6354401539808743, 0.}, {
       0.6354401539808743, -0.7721501218731773, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.096802406225178, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24228808839575336`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.51755230609411, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38169140406013674`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7721501218731773, -0.6354401539808743, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.614645344029233, -0.7065919626854019, 0.}, 
      Optica`Optica`RayEnd :> {5.536595683944297, -0.696756088761932, 0.}, 
      RotationMatrix :> {{-0.9921527351505715, 0.125031796488893, 
       0.}, {-0.125031796488893, -0.9921527351505715, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015185309677946384`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07866698071753105, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.819156008515282`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13647836374167951`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9921527351505715, 0.125031796488893, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.536595683944297, -0.696756088761932, 0.}, 
      Optica`Optica`RayEnd :> {5.3712579755478105`, -0.6419208330212081, 0.}, 
      RotationMatrix :> {{-0.9491598113917534, 0.3147946194565133, 
       0.}, {-0.3147946194565133, -0.9491598113917534, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014311953167502712`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17419375158125572`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.07696276085554, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3156320969962272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9491598113917534, 0.3147946194565133, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5469469278676025`, 0.6368635855234813, 0.}, 
      Optica`Optica`RayEnd :> {6.49118398859179, 0.8602635747106462, 0.}, 
      RotationMatrix :> {{-0.24217975457500945`, 0.9702313984168869, 
       0.}, {-0.9702313984168869, -0.24217975457500945`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019139285280676866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2302543388635778, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.622471506327363`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18431332489559263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.24217975457500945`, 0.9702313984168869, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.49118398859179, 0.8602635747106462, 0.}, 
      Optica`Optica`RayEnd :> {6.41150589720002, 1.1926671838836118`, 0.}, 
      RotationMatrix :> {{-0.23309971376864544`, 0.9724528386718685, 
       0.}, {-0.9724528386718685, -0.23309971376864544`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01909127551823867, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3418197736220784, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.12836477128804, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3749990412845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23309971376864544`, 0.9724528386718685, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.881204474904297, 1.3242995202150794`, 0.}, 
      Optica`Optica`RayEnd :> {6.8980403815701745`, 1.3937316749718944`, 0.}, 
      RotationMatrix :> {{0.23565117547166153`, 0.9718377042998609, 
       0.}, {-0.9718377042998609, 0.23565117547166153`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02666006551827676, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07144418707940124, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.52248000762548, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4131458548726178, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.23565117547166153`, 0.9718377042998609, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8980403815701745`, 1.3937316749718944`, 0.},
       Optica`Optica`RayEnd :> {6.966496046375656, 1.6530371043377268`, 0.}, 
      RotationMatrix :> {{0.25525132003400863`, 0.9668747403986184, 
       0.}, {-0.9668747403986184, 0.25525132003400863`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02658880912907812, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26818926850744607`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.919400125016502`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22030427211365294`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.25525132003400863`, 0.9668747403986184, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.5969460739394234`, 0.25932011660617466`, 
       0.}, Optica`Optica`RayEnd :> {4.46026753674279, 0.28523889220537657`, 
       0.}, RotationMatrix :> {{-0.9824904929676053, 0.1863127242790235, 
       0.}, {-0.1863127242790235, -0.9824904929676053, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1124798784388572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1391143610802755, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.532799368161463`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3970403039654316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9824904929676053, 0.1863127242790235, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.46026753674279, 0.28523889220537657`, 0.}, 
      Optica`Optica`RayEnd :> {4.151550991487545, 0.3339560449741226, 0.}, 
      RotationMatrix :> {{-0.9877765487319169, 0.15587652092365464`, 
       0.}, {-0.15587652092365464`, -0.9877765487319169, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1121465306727456, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31253682389156484`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.99535386752098, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2142055554261047, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9877765487319169, 0.15587652092365464`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.892604669438865, -0.6189034417401148, 0.}, 
      Optica`Optica`RayEnd :> {4.892404349855441, -0.6192154998693977, 0.}, 
      RotationMatrix :> {{-0.5402056119664658, -0.8415330634027018, 0.}, {
       0.8415330634027018, -0.5402056119664658, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04334005395830969, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00037082099664763384`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.47506390204583, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19360502258168066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5402056119664658, -0.8415330634027018, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.892404349855441, -0.6192154998693977, 0.}, 
      Optica`Optica`RayEnd :> {4.727886367284384, -0.8570999932866199, 0.}, 
      RotationMatrix :> {{-0.5688095868188919, -0.8224692419433818, 0.}, {
       0.8224692419433818, -0.5688095868188919, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043206165761176765`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28923208466146866`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.903127387344805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3630084109283906, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5688095868188919, -0.8224692419433818, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.594092515281308, -1.1510887972667576`, 0.}, 
      Optica`Optica`RayEnd :> {5.591763735583777, -1.3605670779720842`, 0.}, 
      RotationMatrix :> {{-0.01111635916422822, -0.9999382113705483, 0.}, {
       0.9999382113705483, -0.01111635916422822, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023411402492234893`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20949122488099417`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.245368091905247`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09140092972600045, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.01111635916422822, -0.9999382113705483, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.591763735583777, -1.3605670779720842`, 0.}, 
      Optica`Optica`RayEnd :> {5.578707936680302, -1.6625646141888275`, 0.}, 
      RotationMatrix :> {{-0.04319113247116778, -0.999066827632595, 0.}, {
       0.999066827632595, -0.04319113247116778, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02334105314434112, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3022796152008784, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.692741922402547`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1334836441702167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04319113247116778, -0.999066827632595, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.089186185011931, -0.46412778297490015`, 0.},
       Optica`Optica`RayEnd :> {6.205953928125927, -0.6174656362047188, 0.}, 
      RotationMatrix :> {{0.6058426260865167, -0.7955845099149386, 0.}, {
       0.7955845099149386, 0.6058426260865167, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012103739927135081`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1927360969436334, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.73585973859908, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3328867317467345, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6058426260865167, -0.7955845099149386, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.205953928125927, -0.6174656362047188, 0.}, 
      Optica`Optica`RayEnd :> {6.366015524438264, -0.8484054132965815, 0.}, 
      RotationMatrix :> {{0.5696434572742602, -0.8218919220825984, 0.}, {
       0.8218919220825984, 0.5696434572742602, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012060594818937327`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28098557837955446`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.15171839460082, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2324908876310367, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5696434572742602, -0.8218919220825984, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.16874912920781, 0.7568037859242456, 0.}, 
      Optica`Optica`RayEnd :> {6.128686699457673, 0.8147673432488303, 0.}, 
      RotationMatrix :> {{-0.5685748162680555, 0.8226315568380211, 
       0.}, {-0.8226315568380211, -0.5685748162680555, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009745104011571878, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07046114003622869, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.04303718673007, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00706621414189129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5685748162680555, 0.8226315568380211, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.128686699457673, 0.8147673432488302, 0.}, 
      Optica`Optica`RayEnd :> {5.940507675890693, 1.090761132862692, 0.}, 
      RotationMatrix :> {{-0.5633397669057407, 0.8262253367106247, 
       0.}, {-0.8262253367106247, -0.5633397669057407, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009720889215466981, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33404178902652704`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.53741903448933, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3952678057621355, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5633397669057407, 0.8262253367106247, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.962721548274071, 0.6105183577215063, 0.}, 
      Optica`Optica`RayEnd :> {6.964111540215825, 0.845293925448589, 0.}, 
      RotationMatrix :> {{0.00592040983871546, 0.9999824742200939, 
       0.}, {-0.9999824742200939, 0.00592040983871546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016329667455358837`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23477968242412323`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.627900950324726`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3765490606011601, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.00592040983871546, 0.9999824742200939, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.964111540215825, 0.845293925448589, 0.}, 
      Optica`Optica`RayEnd :> {6.975305451484222, 1.144078691628268, 0.}, 
      RotationMatrix :> {{0.03743853383922596, 0.999298932344055, 
       0.}, {-0.999298932344055, 0.03743853383922596, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01628091859219892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2989943814698365, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.070412634900084`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35087963437360636`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.03743853383922596, 0.999298932344055, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.39375033838211, -0.12084842573426252`, 0.}, 
      Optica`Optica`RayEnd :> {7.408684917542238, -0.34354261569780986`, 0.}, 
      RotationMatrix :> {{0.06691287328211659, -0.9977588222557248, 0.}, {
       0.9977588222557248, 0.06691287328211659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.13376973240683207`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2231944083040851, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.6329476075896, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41780520122580367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.06691287328211659, -0.9977588222557248, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.408684917542238, -0.34354261569780986`, 0.},
       Optica`Optica`RayEnd :> {7.438952443142733, -0.6266931228462788, 0.}, 
      RotationMatrix :> {{0.10628999264588601`, -0.9943351736026124, 0.}, {
       0.9943351736026124, 0.10628999264588601`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1333275609806711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28476364375462637`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.054397800346447`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3503081064711954, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.10628999264588601`, -0.9943351736026124, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5496058187056825`, -0.19014294206542603`, 
       0.}, Optica`Optica`RayEnd :> {7.600626168023581, -0.20339427849454242`,
        0.}, RotationMatrix :> {{0.9678869449174599, -0.25138588237676734`, 
       0.}, {0.25138588237676734`, 0.9678869449174599, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.6515889036243343`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.052713128930827545`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.656939941047394`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1085104721459548, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9678869449174599, -0.25138588237676734`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.600626168023581, -0.20339427849454242`, 0.},
       Optica`Optica`RayEnd :> {7.882934929861941, -0.2757101473357457, 0.}, 
      RotationMatrix :> {{0.9687224492686636, -0.24814676359550103`, 0.}, {
       0.24814676359550103`, 0.9687224492686636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.642568569406351, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29142378402760044`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.088247141408242`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3460613214564372, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9687224492686636, -0.24814676359550103`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.882934929861941, -0.2757101473357457, 0.}, 
      Optica`Optica`RayEnd :> {7.605830110964485, -0.1854840910062472, 0.}, 
      RotationMatrix :> {{-0.9508654889719339, 0.3096042988754595, 
       0.}, {-0.3096042988754595, -0.9508654889719339, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008998051745461854, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2914237840276005, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.51955434176909, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16993653387948152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9508654889719339, 0.3096042988754595, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.664545060342192, -0.06412059693375713, 0.}, 
      Optica`Optica`RayEnd :> {7.733352346359235, 0.0420126293025313, 0.}, 
      RotationMatrix :> {{0.5439913852223792, 0.8390908012866286, 
       0.}, {-0.8390908012866286, 0.5439913852223792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12478348207262034`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12648598467954586`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.008232815568638`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2955720919420466, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5439913852223792, 0.8390908012866286, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.733352346359235, 0.0420126293025313, 0.}, 
      Optica`Optica`RayEnd :> {7.8898389876045965`, 0.310250823629456, 0.}, 
      RotationMatrix :> {{0.5039055290400694, 0.8637587729238108, 
       0.}, {-0.8637587729238108, 0.5039055290400694, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12432259782539284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3105475773275706, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.467843230013443`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20559178602801959`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5039055290400694, 0.8637587729238108, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.543886199459315, -0.22501170017298794`, 0.},
       Optica`Optica`RayEnd :> {6.379552487833043, -0.3097494748182285, 0.}, 
      RotationMatrix :> {{-0.8887961074960566, -0.4583028248874949, 0.}, {
       0.4583028248874949, -0.8887961074960566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01614561899986869, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18489472471840468`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.155452615114566`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37887825200660175`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8887961074960566, -0.4583028248874949, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.379552487833043, -0.3097494748182285, 0.}, 
      Optica`Optica`RayEnd :> {6.125657458194816, -0.41832732762270464`, 0.}, 
      RotationMatrix :> {{-0.9194519662858212, -0.39320234192224324`, 0.}, {
       0.39320234192224324`, -0.9194519662858212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016053205872168536`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2761373502346729, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.564135893461883`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41953003564582614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9194519662858212, -0.39320234192224324`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.819217854866354, 0.46843169438588755`, 0.}, 
      Optica`Optica`RayEnd :> {5.667336484476603, 0.5313895380341801, 0.}, 
      RotationMatrix :> {{-0.9237794640937799, 0.3829249296123312, 
       0.}, {-0.3829249296123312, -0.9237794640937799, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00967498409481887, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1644130187920394, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.36326441553563, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.395683601902494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9237794640937799, 0.3829249296123312, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.667336484476603, 0.5313895380341801, 0.}, 
      Optica`Optica`RayEnd :> {5.370259476906691, 0.6360526074102332, 0.}, 
      RotationMatrix :> {{-0.9431771516177101, 0.3322903258692661, 
       0.}, {-0.3322903258692661, -0.9431771516177101, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009634840293621137, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31497477124034884`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.829427076971346`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36270059943878685`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9431771516177101, 0.3322903258692661, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8256738210161805`, -0.3516744978920914, 0.},
       Optica`Optica`RayEnd :> {6.825576837079949, -0.35327326938085934`, 0.},
       RotationMatrix :> {{-0.06055023251655212, -0.9981651513362859, 0.}, {
       0.9981651513362859, -0.06055023251655212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2950706688247494, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0016017103849274373`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.601363444684019`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2986120237907005, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.06055023251655212, -0.9981651513362859, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.825576837079949, -0.35327326938085934`, 0.},
       Optica`Optica`RayEnd :> {6.840886796903556, -0.5681950703666385, 0.}, 
      RotationMatrix :> {{0.07105497123498378, -0.9974724011534327, 0.}, {
       0.9974724011534327, 0.07105497123498378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2895606635512515, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2154664136443806, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.920253736877703`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35244407991911175`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.07105497123498378, -0.9974724011534327, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.0967852982839235`, 0.326322821662418, 0.}, 
      Optica`Optica`RayEnd :> {7.1057991123948865`, 0.2691809260645134, 0.}, 
      RotationMatrix :> {{0.155817684634513, -0.9877858316229984, 0.}, {
       0.9877858316229984, 0.155817684634513, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2951346416981715, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05784846650818694, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.638906073964788`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2693639988573276, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.155817684634513, -0.9877858316229984, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1057991123948865`, 0.2691809260645134, 0.}, 
      Optica`Optica`RayEnd :> {7.149448457539012, 0.10347078033821686`, 0.}, 
      RotationMatrix :> {{0.25471930398713377`, -0.9670150341004576, 0.}, {
       0.9670150341004576, 0.25471930398713377`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29212706276233985`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1713625330349122, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.89252262285646, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42350995840334527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.25471930398713377`, -0.9670150341004576, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.192065638887377, 1.1046249733468794`, 0.}, 
      Optica`Optica`RayEnd :> {7.277988308189711, 0.951860803297774, 0.}, 
      RotationMatrix :> {{0.4902301360584129, -0.8715930321544276, 0.}, {
       0.8715930321544276, 0.4902301360584129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3468843872432643, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1752700680402397, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.54143569586292, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19139491033329725`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4902301360584129, -0.8715930321544276, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.277988308189711, 0.951860803297774, 0.}, 
      Optica`Optica`RayEnd :> {7.390408105692144, 0.7150344162751484, 0.}, 
      RotationMatrix :> {{0.42883042186192816`, -0.9033850061218195, 0.}, {
       0.9033850061218195, 0.42883042186192816`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.34500226009211427`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2621544362788438, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.929424261555608`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23689133474274876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.42883042186192816`, -0.9033850061218195, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.353649000460349, 1.3495682650002878`, 0.}, 
      Optica`Optica`RayEnd :> {7.3775247299827535`, 1.391018043860573, 0.}, 
      RotationMatrix :> {{0.4991325166880318, 0.86652566654697, 
       0.}, {-0.86652566654697, 0.4991325166880318, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      74.20067066856427, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047834450219413585`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.804961567294367`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3584923013136844, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4991325166880318, 0.86652566654697, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3775247299827535`, 1.391018043860573, 0.}, 
      Optica`Optica`RayEnd :> {7.543884862887944, 1.6644691373106297`, 0.}, 
      RotationMatrix :> {{0.5197455095770224, 0.8543211370875242, 
       0.}, {-0.8543211370875242, 0.5197455095770224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      73.99593692078204, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3200799811441888, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.278679939387766`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10022738335330869`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5197455095770224, 0.8543211370875242, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.543884862887944, 1.6644691373106297`, 0.}, 
      Optica`Optica`RayEnd :> {7.512885661753796, 1.345893802643445, 0.}, 
      RotationMatrix :> {{-0.09684829717664795, -0.9952991546936945, 0.}, {
       0.9952991546936945, -0.09684829717664795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20416884847466557`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32007998114418856`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.752398311481166`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1927837342919525, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.09684829717664795, -0.9952991546936945, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.060538310049242, 1.3634434958074577`, 0.}, 
      Optica`Optica`RayEnd :> {6.863122473350959, 1.3608280192880524`, 0.}, 
      RotationMatrix :> {{-0.9999122493160311, -0.013247402302120834`, 0.}, {
       0.013247402302120834`, -0.9999122493160311, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.34367846999673873`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19743316159325025`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.439713439846662`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22292913473889847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9999122493160311, -0.013247402302120834`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.863122473350959, 1.3608280192880524`, 0.}, 
      Optica`Optica`RayEnd :> {6.57982954868064, 1.3401081333321252`, 0.}, 
      RotationMatrix :> {{-0.9973359944621915, -0.07294459644216718, 0.}, {
       0.07294459644216718, -0.9973359944621915, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.34210884544200904`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28404963446955833`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.860106898861607`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2125379735435438, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9973359944621915, -0.07294459644216718, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.295198604732274, 1.0441447323620774`, 0.}, 
      Optica`Optica`RayEnd :> {6.189895363322487, 1.0385792570356913`, 0.}, 
      RotationMatrix :> {{-0.9986062580634089, -0.05277822805471595, 0.}, {
       0.05277822805471595, -0.9986062580634089, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2935879481856063, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10545021179218457`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.610996527749446`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2605088323045261, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9986062580634089, -0.05277822805471595, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.189895363322487, 1.0385792570356913`, 0.}, 
      Optica`Optica`RayEnd :> {5.883323261180942, 1.0085602719018325`, 0.}, 
      RotationMatrix :> {{-0.9952402144015582, -0.09745211972009421, 0.}, {
       0.09745211972009421, -0.9952402144015582, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.292540606754237, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3080382983980286, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.066893209378529`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14964129436996923`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9952402144015582, -0.09745211972009421, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.34378759472657, 1.0085816823173743`, 0.}, 
      Optica`Optica`RayEnd :> {5.166006433166219, 1.0399900566600764`, 0.}, 
      RotationMatrix :> {{-0.984750145401162, 0.17397457036127253`, 
       0.}, {-0.17397457036127253`, -0.984750145401162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2967890755791845, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18053428312816078`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.260414901907883`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36238498668853647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.984750145401162, 0.17397457036127253`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.166006433166219, 1.0399900566600764`, 0.}, 
      Optica`Optica`RayEnd :> {4.858833762293857, 1.081384031628743, 0.}, 
      RotationMatrix :> {{-0.9910419642174088, 0.1335508336181376, 
       0.}, {-0.1335508336181376, -0.9910419642174088, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29578886132670673`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3099492069590869, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.719139728207331`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2416407656165378, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9910419642174088, 0.1335508336181376, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.433388240338392, -0.11117953659543567`, 0.},
       Optica`Optica`RayEnd :> {6.441161199556236, -0.41274450725640877`, 0.},
       RotationMatrix :> {{0.025766846926596882`, -0.9996679796809841, 0.}, {
       0.9996679796809841, 0.025766846926596882`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00943900233920104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30166512961354325`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.39679485994046, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.386414911838435, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.025766846926596882`, -0.9996679796809841, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.441161199556236, -0.41274450725640877`, 0.},
       Optica`Optica`RayEnd :> {6.468322005052908, -0.690413361520776, 0.}, 
      RotationMatrix :> {{0.0973526197059986, -0.9952499522413343, 0.}, {
       0.9952499522413343, 0.0973526197059986, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009385218372845817, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27899408951394383`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.809706112421097`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4250282965438688, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0973526197059986, -0.9952499522413343, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.57323765724591, 1.646089620359747, 0.}, 
      Optica`Optica`RayEnd :> {6.8197075233683275`, 2.104862101175398, 0.}, 
      RotationMatrix :> {{0.4732638216614665, 0.8809207428062883, 
       0.}, {-0.8809207428062883, 0.4732638216614665, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18582469749230796`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5207874653446926, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.54961024042214, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15591773185019542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4732638216614665, 0.8809207428062883, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8197075233683275`, 2.104862101175398, 0.}, 
      Optica`Optica`RayEnd :> {6.902671251455068, 2.2927415826140214`, 0.}, 
      RotationMatrix :> {{0.4039488020220524, 0.9147815943409376, 
       0.}, {-0.9147815943409376, 0.4039488020220524, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18464906523227212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20538179014629487`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.853575289838657`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24606488785988262`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4039488020220524, 0.9147815943409376, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.174197682692963, 1.5494748272910812`, 0.}, 
      Optica`Optica`RayEnd :> {6.186069607961884, 1.5868232171547578`, 0.}, 
      RotationMatrix :> {{0.30293362611627744`, 0.9530116568899053, 
       0.}, {-0.9530116568899053, 0.30293362611627744`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09570032059428298, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.039189856276848394`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.760948328405377`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4281999721170763, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.30293362611627744`, 0.9530116568899053, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.186069607961884, 1.5868232171547578`, 0.}, 
      Optica`Optica`RayEnd :> {6.287150018382918, 1.8816042394023436`, 0.}, 
      RotationMatrix :> {{0.32436059378947335`, 0.9459335099236835, 
       0.}, {-0.9459335099236835, 0.32436059378947335`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09543951924306254, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31162974897820056`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.222160356893113`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19722420337019445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32436059378947335`, 0.9459335099236835, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.036656461720002, 1.6775537955970146`, 0.}, 
      Optica`Optica`RayEnd :> {5.625588209786038, 1.954739381579031, 0.}, 
      RotationMatrix :> {{-0.8291155956865832, 0.559077212010364, 
       0.}, {-0.559077212010364, -0.8291155956865832, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.0293034668788104`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.49579124319035583`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.650946827920833`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1352941307767149, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8291155956865832, 0.559077212010364, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.625588209786038, 1.954739381579031, 0.}, 
      Optica`Optica`RayEnd :> {5.434632846005179, 2.0883302110018165`, 0.}, 
      RotationMatrix :> {{-0.8193889796180508, 0.5732379087957188, 
       0.}, {-0.5732379087957188, -0.8193889796180508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.0213846701845166`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23304604837359494`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.995854979513753`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2164514332292174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8193889796180508, 0.5732379087957188, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.875024991266699, 1.5816524017169022`, 0.}, 
      Optica`Optica`RayEnd :> {5.386838787639893, 1.17707328175869, 0.}, 
      RotationMatrix :> {{-0.7699580350856063, -0.638094526075182, 0.}, {
       0.638094526075182, -0.7699580350856063, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0900926386418106, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.6340426119100471, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.114356303056576`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30150003199133574`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7699580350856063, -0.638094526075182, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.386838787639893, 1.17707328175869, 0.}, 
      Optica`Optica`RayEnd :> {5.216418216343868, 1.0764549847096392`, 0.}, 
      RotationMatrix :> {{-0.8611140652032541, -0.5084118081920648, 0.}, {
       0.5084118081920648, -0.8611140652032541, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08730617473994005, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1979070812828954, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.407258783355262`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2936727848384837, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8611140652032541, -0.5084118081920648, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.995683381404745, 1.3667402332319012`, 0.}, 
      Optica`Optica`RayEnd :> {5.915766996348002, 1.329938586737978, 0.}, 
      RotationMatrix :> {{-0.908317295061435, -0.4182818326108335, 0.}, {
       0.4182818326108335, -0.908317295061435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1597814174755787, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08798289484440285, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.014333233058634`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2576436305371558, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.908317295061435, -0.4182818326108335, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.915766996348002, 1.329938586737978, 0.}, 
      Optica`Optica`RayEnd :> {5.589348707423781, 1.1826893079768626`, 0.}, 
      RotationMatrix :> {{-0.9115438114378106, -0.41120296670796114`, 0.}, {
       0.41120296670796114`, -0.9115438114378106, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15938277195077405`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.358093911481171, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.494179074443403`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1675408757158388, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9115438114378106, -0.41120296670796114`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.987631729229609, 0.8005725958373693, 0.}, 
      Optica`Optica`RayEnd :> {5.972639396864549, 0.6844474588014469, 0.}, 
      RotationMatrix :> {{-0.1280422700152831, -0.9917687114893938, 0.}, {
       0.9917687114893938, -0.1280422700152831, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00870132615424994, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11708892979849185`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.766737531109124`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20019848634276857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1280422700152831, -0.9917687114893938, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.972639396864549, 0.6844474588014469, 0.}, 
      Optica`Optica`RayEnd :> {5.934336026432902, 0.3840163419848044, 0.}, 
      RotationMatrix :> {{-0.1264709419540575, -0.9919703124797902, 0.}, {
       0.9919703124797902, -0.1264709419540575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008679869408958098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.302863012165763, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.214974789114454`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3087542202846538, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1264709419540575, -0.9919703124797902, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.082999887296782, 0.31698239836342923`, 0.}, 
      Optica`Optica`RayEnd :> {7.114516242080115, 0.28107956277846663`, 0.}, 
      RotationMatrix :> {{0.6597055919522317, -0.751524139297571, 0.}, {
       0.751524139297571, 0.6597055919522317, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009405012611945766, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04777336309984665, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.802898731436585`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32043752614926274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6597055919522317, -0.751524139297571, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.114516242080115, 0.28107956277846663`, 0.}, 
      Optica`Optica`RayEnd :> {7.269243314924368, 0.10997104284251003`, 0.}, 
      RotationMatrix :> {{0.6707097454322452, -0.7417199184208364, 0.}, {
       0.7417199184208364, 0.6707097454322452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009380802278179341, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23069155308685285`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.144322230005127`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.035755988847562536`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.6707097454322452, -0.7417199184208364, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.132603163998297, 0.8633038107538517, 0.}, 
      Optica`Optica`RayEnd :> {5.098684704037478, 0.8641184408836207, 0.}, 
      RotationMatrix :> {{-0.9997117091523277, 0.024010384914266644`, 
       0.}, {-0.024010384914266644`, -0.9997117091523277, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16564203078761788`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03392824116222378, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.397283452222295`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.039726440496895554`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9997117091523277, 0.024010384914266644`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0986847040374785`, 0.8641184408836207, 0.}, 
      Optica`Optica`RayEnd :> {4.874911054466808, 0.8967438186105634, 0.}, 
      RotationMatrix :> {{-0.98953820852963, 0.14427104304041727`, 
       0.}, {-0.14427104304041727`, -0.98953820852963, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16314354674625212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22613947358655198`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.731969873130392`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3136604824245467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.98953820852963, 0.14427104304041727`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.359421295530483, -0.9513629506393492, 0.}, 
      Optica`Optica`RayEnd :> {4.158007169770423, -1.0681850780699813`, 0.}, 
      RotationMatrix :> {{-0.8650275834696324, -0.5017243066034248, 0.}, {
       0.5017243066034248, -0.8650275834696324, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19829554761959076`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23284127536394428`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.482127552032445`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3084021781792399, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8650275834696324, -0.5017243066034248, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.158007169770423, -1.0681850780699813`, 0.}, 
      Optica`Optica`RayEnd :> {3.9514534114328006`, -1.1585364994661662`, 0.},
       RotationMatrix :> {{-0.9161831460009936, -0.40075983204872384`, 0.}, {
       0.40075983204872384`, -0.9161831460009936, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19571861166878693`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22545029259619068`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.815793985074807`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38764741018471066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9161831460009936, -0.40075983204872384`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.356816966072465, 1.0969723235612296`, 0.}, 
      Optica`Optica`RayEnd :> {4.309155676079274, 1.1214810476127461`, 0.}, 
      RotationMatrix :> {{-0.8893090237076697, 0.4573067464537458, 
       0.}, {-0.4573067464537458, -0.8893090237076697, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.059202186855767495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05359362012822458, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.61631056259487, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08246259301144312, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8893090237076697, 0.4573067464537458, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.309155676079274, 1.1214810476127461`, 0.}, 
      Optica`Optica`RayEnd :> {4.0960916602283275`, 1.2544517791728071`, 0.}, 
      RotationMatrix :> {{-0.8483457835266612, 0.5294425668309403, 
       0.}, {-0.5294425668309403, -0.8483457835266612, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.058782329376076733`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25115232489895495`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.988016003445324`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.048420502761211195`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8483457835266612, 0.5294425668309403, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.560609031189221, 0.6257838054686258, 0.}, 
      Optica`Optica`RayEnd :> {6.650244092232106, 0.6137514666967877, 0.}, 
      RotationMatrix :> {{0.9911101824549541, -0.13304362530428523`, 0.}, {
       0.13304362530428523`, 0.9911101824549541, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09335831416062572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0904390476756689, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.69236531935299, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3668587852214282, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9911101824549541, -0.13304362530428523`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.650244092232106, 0.6137514666967877, 0.}, 
      Optica`Optica`RayEnd :> {6.885969195992962, 0.6114723626851394, 0.}, 
      RotationMatrix :> {{0.9999532635009123, -0.009668030506491315, 0.}, {
       0.009668030506491315, 0.9999532635009123, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09186435675773418, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23573612124187143`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.041254778790961`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10133506676439627`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999532635009123, -0.009668030506491315, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.441039746564652, 1.1369156045927298`, 0.}, 
      Optica`Optica`RayEnd :> {5.380342865732236, 1.1634631615150444`, 0.}, 
      RotationMatrix :> {{-0.9161979513995855, 0.4007259834989512, 
       0.}, {-0.4007259834989512, -0.9161979513995855, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05480909780125768, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06624865373219319, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.719772116605117`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2641150035082131, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9161979513995855, 0.4007259834989512, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.380342865732236, 1.1634631615150444`, 0.}, 
      Optica`Optica`RayEnd :> {5.0774646795014835`, 1.2986243324192273`, 0.}, 
      RotationMatrix :> {{-0.9131965765983617, 0.40751934001839873`, 
       0.}, {-0.40751934001839873`, -0.9131965765983617, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.054672499688885344`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33166811395523077`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.21064092525886, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17087999534510062`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9131965765983617, 0.40751934001839873`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.415740315443308, 0.8455727215350262, 0.}, 
      Optica`Optica`RayEnd :> {5.3671627411517635`, 0.8414132536242973, 0.}, 
      RotationMatrix :> {{-0.9963541918148147, -0.08531309660917358, 0.}, {
       0.08531309660917358, -0.9963541918148147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013133500391118599`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048755326861287536`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      12.668944006460654`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22098117361058392`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9963541918148147, -0.08531309660917358, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3671627411517635`, 0.8414132536242973, 0.}, 
      Optica`Optica`RayEnd :> {5.096699440575585, 0.8041596610668059, 0.}, 
      RotationMatrix :> {{-0.9906467387468849, -0.1364515995148461, 0.}, {
       0.1364515995148461, -0.9906467387468849, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0130814633506536, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2730168989586535, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.07300901691946, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15521969155453438`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9906467387468849, -0.1364515995148461, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.43041916475558, 0.3419012486380427, 0.}, 
      Optica`Optica`RayEnd :> {5.2825728163768, -0.02039618674577165, 0.}, 
      RotationMatrix :> {{-0.3778309366007295, -0.9258746045482693, 0.}, {
       0.9258746045482693, -0.3778309366007295, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008228011738788303, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3913029189957939, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.616711086214107`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24239916037906079`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3778309366007295, -0.9258746045482693, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.2825728163768, -0.02039618674577165, 0.}, 
      Optica`Optica`RayEnd :> {5.165712099764965, -0.3395329293425942, 0.}, 
      RotationMatrix :> {{-0.3438497716874839, -0.9390246719391688, 0.}, {
       0.9390246719391688, -0.3438497716874839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008201918012840724, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3398598057469318, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.119703598719566`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3873483668297971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3438497716874839, -0.9390246719391688, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.132844253351959, 1.133288049183445, 0.}, 
      Optica`Optica`RayEnd :> {6.826067983688849, 0.37884217744721077`, 0.}, 
      RotationMatrix :> {{0.6765983779426478, -0.7363522492431032, 0.}, {
       0.7363522492431032, 0.6765983779426478, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011090489861349362`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0245719660824408`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.337466595035487`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00935830214143607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6765983779426478, -0.7363522492431032, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.826067983688849, 0.37884217744721077`, 0.}, 
      Optica`Optica`RayEnd :> {6.9089651371026575`, 0.23662464116783447`, 0.},
       RotationMatrix :> {{0.5035851051673649, -0.8639456243616106, 0.}, {
       0.8639456243616106, 0.5035851051673649, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010209838977461047`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16461398989602394`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.581095300081602`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4303821269267826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5035851051673649, -0.8639456243616106, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.111402240816899, 1.6956126639955889`, 0.}, 
      Optica`Optica`RayEnd :> {6.028279707946844, 1.8198766499719492`, 0.}, 
      RotationMatrix :> {{-0.5559955581411162, 0.8311852617361231, 
       0.}, {-0.8311852617361231, -0.5559955581411162, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19619541455157707`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14950215276532478`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.297551197860773`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23151073252779916`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5559955581411162, 0.8311852617361231, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.028279707946844, 1.8198766499719492`, 0.}, 
      Optica`Optica`RayEnd :> {5.871677664455433, 2.085412051030004, 0.}, 
      RotationMatrix :> {{-0.5079952315845788, 0.8613598810528204, 
       0.}, {-0.8613598810528204, -0.5079952315845788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1953461399360908, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3082746328207167, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.753797654435434`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26018430259494263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5079952315845788, 0.8613598810528204, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.184072372672007, 1.8586024464312514`, 0.}, 
      Optica`Optica`RayEnd :> {6.320906309499774, 2.0591489993432495`, 0.}, 
      RotationMatrix :> {{0.5636113683105038, 0.8260400871090703, 
       0.}, {-0.8260400871090703, 0.5636113683105038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      4.03188542930406, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24278065440366217`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.686659574033618`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16220125895256654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5636113683105038, 0.8260400871090703, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.320906309499774, 2.0591489993432495`, 0.}, 
      Optica`Optica`RayEnd :> {6.440837379378749, 2.2750571618804605`, 0.}, 
      RotationMatrix :> {{0.48558751948519985`, 0.8741880580974608, 
       0.}, {-0.8741880580974608, 0.48558751948519985`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.997855174516123, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24698136806753257`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.052191998773566`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31582907365587365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.48558751948519985`, 0.8741880580974608, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.440837379378749, 2.2750571618804605`, 0.}, 
      Optica`Optica`RayEnd :> {6.2077278035136985`, 2.356664280519256, 0.}, 
      RotationMatrix :> {{-0.9438346612498736, 0.33041811727466663`, 
       0.}, {-0.33041811727466663`, -0.9438346612498736, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033743029800710284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24698136806753254`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.417724423513514`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.430440949257498, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 70, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9438346612498736, 0.33041811727466663`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.36240697690967, 1.8520156282570719`, 0.}, 
      Optica`Optica`RayEnd :> {6.6517446872126405`, 1.7884474615593178`, 0.}, 
      RotationMatrix :> {{0.9767054381020376, -0.21458445233032525`, 0.}, {
       0.21458445233032525`, 0.9767054381020376, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17914775384064238`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29623845533738397`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.022408211262277`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2969069476831516, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9767054381020376, -0.21458445233032525`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.6517446872126405`, 1.7884474615593178`, 0.},
       Optica`Optica`RayEnd :> {6.897227864791424, 1.7236485654343994`, 0.}, 
      RotationMatrix :> {{0.9668822693443413, -0.2552227991922654, 0.}, {
       0.2552227991922654, 0.9668822693443413, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17853621610004966`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25389148747680557`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.39816761272795, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4000803530161025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9668822693443413, -0.2552227991922654, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.599442986112421, 1.1595858165884754`, 0.}, 
      Optica`Optica`RayEnd :> {5.578820183056489, 1.1362831538007814`, 0.}, 
      RotationMatrix :> {{-0.6627344808173159, -0.7488544637883929, 0.}, {
       0.7488544637883929, -0.6627344808173159, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012866851797439688`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.031117745722991082`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.11954789945399, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04713092590736069, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6627344808173159, -0.7488544637883929, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.578820183056489, 1.1362831538007814`, 0.}, 
      Optica`Optica`RayEnd :> {5.372007422895698, 0.8886497691912926, 0.}, 
      RotationMatrix :> {{-0.641010105957357, -0.7675324384418789, 0.}, {
       0.7675324384418789, -0.641010105957357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012829652935721525`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3226357248329388, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.597048772206739`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28576366472080317`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.641010105957357, -0.7675324384418789, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.162702661414744, 0.9438053337150264, 0.}, 
      Optica`Optica`RayEnd :> {7.19531982452479, 0.9402167803239351, 0.}, 
      RotationMatrix :> {{0.9940021516645783, -0.10936051612070777`, 0.}, {
       0.10936051612070777`, 0.9940021516645783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0860920888178808, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.032813976363557006`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.028456455161438`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4020756396476656, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9940021516645783, -0.10936051612070777`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.19531982452479, 0.9402167803239352, 0.}, 
      Optica`Optica`RayEnd :> {7.3821519417883765`, 0.8912266074744308, 0.}, 
      RotationMatrix :> {{0.9672986456923544, -0.25364015857457567`, 0.}, {
       0.25364015857457567`, 0.9672986456923544, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08394844419421651, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1931483292110468, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.314315982393786`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19467785151965156`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9672986456923544, -0.25364015857457567`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.395280740220098, 1.1447153361225655`, 0.}, 
      Optica`Optica`RayEnd :> {4.341300350337997, 1.1378960908493214`, 0.}, 
      RotationMatrix :> {{-0.9921148471854955, -0.1253320788708921, 0.}, {
       0.1253320788708921, -0.9921148471854955, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09775668342113808, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05440941644532004, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.131439043755275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.031361981041229586`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9921148471854955, -0.1253320788708921, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.341300350337997, 1.1378960908493214`, 0.}, 
      Optica`Optica`RayEnd :> {4.156171182713343, 1.1450378863667876`, 0.}, 
      RotationMatrix :> {{-0.9992567229584378, 0.03854869157782631, 
       0.}, {-0.03854869157782631, -0.9992567229584378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09441775778949685, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18526687223735094`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.405634014666555`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3939267703369243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9992567229584378, 0.03854869157782631, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.891581672955386, 0.3077814576649613, 0.}, 
      Optica`Optica`RayEnd :> {8.077006186780842, 0.27867406472608236`, 0.}, 
      RotationMatrix :> {{0.9879022325546919, -0.1550779768808405, 0.}, {
       0.1550779768808405, 0.9879022325546919, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07220329647274092, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18769520678777366`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.759645163644326`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19363874115934254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9879022325546919, -0.1550779768808405, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.077006186780842, 0.27867406472608236`, 0.}, 
      Optica`Optica`RayEnd :> {8.382099314299674, 0.22347529134967298`, 0.}, 
      RotationMatrix :> {{0.9840243442716078, -0.17803395710041184`, 0.}, {
       0.17803395710041184`, 0.9840243442716078, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07200528489167993, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3100463207997843, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.218513718428007`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4227489749749967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9840243442716078, -0.17803395710041184`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.503571201537513, 1.5849363906658709`, 0.}, 
      Optica`Optica`RayEnd :> {4.440374935192335, 1.6884978939291888`, 0.}, 
      RotationMatrix :> {{-0.5209018640525349, 0.8536165696766871, 
       0.}, {-0.8536165696766871, -0.5209018640525349, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27604757142353303`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12132086810655811`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.90805779452276, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3080050017382753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5209018640525349, 0.8536165696766871, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.440374935192335, 1.6884978939291888`, 0.}, 
      Optica`Optica`RayEnd :> {4.278409306365115, 1.9170346464985808`, 0.}, 
      RotationMatrix :> {{-0.5782204101559004, 0.8158806023427339, 
       0.}, {-0.8158806023427339, -0.5782204101559004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27456430801567877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28011053567540084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.322621387322354`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26957357194082854`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5782204101559004, 0.8158806023427339, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3847302367062975`, -0.6145580846091381, 0.},
       Optica`Optica`RayEnd :> {3.2969396556608648`, -0.6486966623067383, 0.},
       RotationMatrix :> {{-0.9320125746784562, -0.3624259381463129, 0.}, {
       0.3624259381463129, -0.9320125746784562, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014897967291963146`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09419463152170494, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.922491663925149`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009198146389188007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9320125746784562, -0.3624259381463129, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2969396556608648`, -0.6486966623067383, 0.},
       Optica`Optica`RayEnd :> {3.056035109608411, -0.7627206856098533, 0.}, 
      RotationMatrix :> {{-0.9038664875990404, -0.4278146474764203, 0.}, {
       0.4278146474764203, -0.9038664875990404, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014813936086023877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26652669322033823`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.316951169891249`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07207453439840122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9038664875990404, -0.4278146474764203, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.444584970458577, -2.17407961338191, 0.}, 
      Optica`Optica`RayEnd :> {4.401395049186998, -2.231397359948631, 0.}, 
      RotationMatrix :> {{-0.6017963705877412, -0.7986495654211688, 0.}, {
       0.7986495654211688, -0.6017963705877412, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012888896312588756`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07176833125363867, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.415890409329547`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42036918959038483`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6017963705877412, -0.7986495654211688, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.401395049186998, -2.231397359948631, 0.}, 
      Optica`Optica`RayEnd :> {4.250973596039403, -2.385515828997722, 0.}, 
      RotationMatrix :> {{-0.698471268595943, -0.7156380977463215, 0.}, {
       0.7156380977463215, -0.698471268595943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012667005466950527`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2153581112219131, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.734620413937979`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21782873369398403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.698471268595943, -0.7156380977463215, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.466710937071036, -2.126897206581193, 0.}, 
      Optica`Optica`RayEnd :> {5.3881037401442144`, -2.333911060676379, 0.}, 
      RotationMatrix :> {{-0.35498860602468074`, -0.9348706271953642, 0.}, {
       0.9348706271953642, -0.35498860602468074`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009188705645965512, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2214358308766559, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.236017226593207`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42251841516417676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.35498860602468074`, -0.9348706271953642, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3881037401442144`, -2.333911060676379, 0.}, 
      Optica`Optica`RayEnd :> {5.334963802773455, -2.54581248256604, 0.}, 
      RotationMatrix :> {{-0.24324460772902484`, -0.9699649791671617, 0.}, {
       0.9699649791671617, -0.24324460772902484`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009059551948214036, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2184629614891925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.559342409597212`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24636096547916925`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.24324460772902484`, -0.9699649791671617, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.1387084261467875`, -2.3126263188259486`, 
       0.}, Optica`Optica`RayEnd :> {6.225760321846037, -2.5817075108829264`, 
       0.}, RotationMatrix :> {{0.3078081730063904, -0.9514484371895662, 
       0.}, {0.9514484371895662, 0.3078081730063904, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0186150727243756, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28281216463164593`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.794369378077867`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2051884765800791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3078081730063904, -0.9514484371895662, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.225760321846037, -2.5817075108829264`, 0.}, 
      Optica`Optica`RayEnd :> {6.290875589312144, -2.815415160633884, 0.}, 
      RotationMatrix :> {{0.2683956153137737, -0.9633087738001458, 0.}, {
       0.9633087738001458, 0.2683956153137737, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01855211657722031, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24260928178719599`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.153431115122917`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.060147439528292115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.2683956153137737, -0.9633087738001458, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.275115027170251, -2.39160072839328, 0.}, 
      Optica`Optica`RayEnd :> {6.376396982301569, -2.4193695636149584`, 0.}, 
      RotationMatrix :> {{0.964408877523486, -0.26441542495453885`, 0.}, {
       0.26441542495453885`, 0.964408877523486, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09427569600372121, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1050197250272102, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.789403483505936`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10022876438808376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.964408877523486, -0.26441542495453885`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.376396982301569, -2.4193695636149584`, 0.}, 
      Optica`Optica`RayEnd :> {6.709709089406296, -2.50852625996953, 0.}, 
      RotationMatrix :> {{0.9660373307547429, -0.2584025456303619, 0.}, {
       0.2584025456303619, 0.9660373307547429, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09404150968592384, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34503025555370426`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.300048261725419`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33204873820822844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9660373307547429, -0.2584025456303619, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.415962670666085, -2.3208500429481655`, 0.}, 
      Optica`Optica`RayEnd :> {7.324472913554798, -1.5196546351294475`, 0.}, 
      RotationMatrix :> {{0.7500144622157977, 0.6614214287934339, 
       0.}, {-0.6614214287934339, 0.7500144622157977, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0136237096309247, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2113236326199166`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.505126694178173`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02128205638370639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7500144622157977, 0.6614214287934339, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.324472913554798, -1.5196546351294475`, 0.}, 
      Optica`Optica`RayEnd :> {7.529897953148777, -1.3640197673514542`, 0.}, 
      RotationMatrix :> {{0.7970737745559296, 0.6038819403783847, 
       0.}, {-0.6038819403783847, 0.7970737745559296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013542091135676294`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25772399764178144`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.88655821068801, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10273811919775393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7970737745559296, 0.6038819403783847, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.29649179032783, -1.714548594238228, 0.}, 
      Optica`Optica`RayEnd :> {6.511435683837266, -1.6634132159734705`, 0.}, 
      RotationMatrix :> {{0.9728487647744171, 0.2314417440240428, 
       0.}, {-0.2314417440240428, 0.9728487647744171, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008046808763596223, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22094276242338282`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.766849166651212`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3259910196651864, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 68, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9728487647744171, 0.2314417440240428, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.920460688392599, -1.3157020578048386`, 0.}, 
      Optica`Optica`RayEnd :> {7.111345118114919, -1.3251806879671508`, 0.}, 
      RotationMatrix :> {{0.9987693971707067, -0.04959527472716471, 0.}, {
       0.04959527472716471, 0.9987693971707067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011082820058220305`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.191119622069972, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.927471013278193`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12079041299555202`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9987693971707067, -0.04959527472716471, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.111345118114919, -1.3251806879671508`, 0.}, 
      Optica`Optica`RayEnd :> {7.41383491331418, -1.3315744125057838`, 0.}, 
      RotationMatrix :> {{0.9997766885978474, -0.021132272388992575`, 0.}, {
       0.021132272388992575`, 0.9997766885978474, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01105083673751191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30255735970748937`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.375255905645277`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34479952706222194`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9997766885978474, -0.021132272388992575`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.08320727731976, -1.3467014046111412`, 0.}, 
      Optica`Optica`RayEnd :> {3.061437346951778, -1.3534291110795635`, 0.}, 
      RotationMatrix :> {{-0.9554172643363621, -0.2952589558472727, 0.}, {
       0.2952589558472727, -0.9554172643363621, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17746113791708212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022785782904083552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.943894796439938`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11575200494268742`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9554172643363621, -0.2952589558472727, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.061437346951778, -1.3534291110795635`, 0.}, 
      Optica`Optica`RayEnd :> {2.866810299806632, -1.442451087010559, 0.}, 
      RotationMatrix :> {{-0.9093868035476544, -0.41595148939916005`, 0.}, {
       0.41595148939916005`, -0.9093868035476544, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1743001972414755, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21402009176499662`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.260644532252133`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2051774743209216, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9093868035476544, -0.41595148939916005`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0823029265595387`, 0.3204098587077727, 0.}, 
      Optica`Optica`RayEnd :> {2.875842145644434, 0.349209221182765, 0.}, 
      RotationMatrix :> {{-0.9904108814950988, 0.1381531245252942, 
       0.}, {-0.1381531245252942, -0.9904108814950988, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06436509829774531, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20845972593055223`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.09776471800674, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1904930564905135, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9904108814950988, 0.1381531245252942, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.875842145644434, 0.349209221182765, 0.}, 
      Optica`Optica`RayEnd :> {2.605303873416047, 0.3617660148907954, 0.}, 
      RotationMatrix :> {{-0.9989246023076666, 0.04636419852073553, 
       0.}, {-0.04636419852073553, -0.9989246023076666, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06381637470298848, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2708295216710074, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.498592410079832`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34048873294972054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9989246023076666, 0.04636419852073553, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.042768365054769, 2.0940943312606244`, 0.}, 
      Optica`Optica`RayEnd :> {5.073874337603238, 2.2330401138623297`, 0.}, 
      RotationMatrix :> {{0.21846370253545944`, 0.9758450751397465, 
       0.}, {-0.9758450751397465, 0.21846370253545944`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024500226390709316`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14238508359721702`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.401873207049817`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.008901681524375649, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.21846370253545944`, 0.9758450751397465, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.073874337603238, 2.2330401138623297`, 0.}, 
      Optica`Optica`RayEnd :> {5.1481400246627125`, 2.369639803748075, 0.}, 
      RotationMatrix :> {{0.4776460070452585, 0.8785523842968728, 
       0.}, {-0.8785523842968728, 0.4776460070452585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019871883268168213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15548269212776555`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.63198759139891, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4147306083904585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4776460070452585, 0.8785523842968728, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.540441563317021, 1.658662282854143, 0.}, 
      Optica`Optica`RayEnd :> {6.625737115933364, 1.7209443206159765`, 0.}, 
      RotationMatrix :> {{0.807613557412659, 0.5897120838877816, 
       0.}, {-0.5897120838877816, 0.807613557412659, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008731504250084504, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10561431495727215`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.430827837748662`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04977424646495686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.807613557412659, 0.5897120838877816, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.625737115933364, 1.7209443206159765`, 0.}, 
      Optica`Optica`RayEnd :> {6.811440419389403, 1.8345145594733225`, 0.}, 
      RotationMatrix :> {{0.8531082743851521, 0.5217339093595396, 
       0.}, {-0.5217339093595396, 0.8531082743851521, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008670982290149471, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2176784694649433, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.752991972556778`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07485768987151586, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8531082743851521, 0.5217339093595396, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3362231553334047`, -0.9367987626976133, 0.},
       Optica`Optica`RayEnd :> {2.1561864118925493`, -1.033264979160073, 0.}, 
      RotationMatrix :> {{-0.8814433638435615, -0.47228973769937743`, 0.}, {
       0.47228973769937743`, -0.8814433638435615, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21876763927652582`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20425219682385426`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.480274117099864`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41013641200942386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8814433638435615, -0.47228973769937743`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1561864118925493`, -1.033264979160073, 0.}, 
      Optica`Optica`RayEnd :> {1.8528470577585507`, -1.17291256256883, 0.}, 
      RotationMatrix :> {{-0.9083636665781958, -0.4181811201388893, 0.}, {
       0.4181811201388893, -0.9083636665781958, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2177562740382631, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33394043079318375`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.974505954673775`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40618175901635606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9083636665781958, -0.4181811201388893, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.258971730969517, 2.3682680267369927`, 0.}, 
      Optica`Optica`RayEnd :> {2.1707816353633187`, 2.6531790411572076`, 0.}, 
      RotationMatrix :> {{-0.2956939876231818, 0.9552827150553398, 
       0.}, {-0.9552827150553398, -0.2956939876231818, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013868686852757673`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2982478484431805, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.852289419220753`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3451138813922913, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2956939876231818, 0.9552827150553398, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1707816353633187`, 2.6531790411572076`, 0.},
       Optica`Optica`RayEnd :> {2.114866436608288, 2.87721879600748, 0.}, 
      RotationMatrix :> {{-0.24214945419698597`, 0.9702389612008485, 
       0.}, {-0.9702389612008485, -0.24214945419698597`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013809783044862618`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23091193387346767`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.194039081353486`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37346409153705185`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.24214945419698597`, 0.9702389612008485, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.261063463459581, 3.37564683895124, 0.}, 
      Optica`Optica`RayEnd :> {5.317602229717479, 3.5391865573943955`, 0.}, 
      RotationMatrix :> {{0.326743423889562, 0.9451130805067329, 
       0.}, {-0.9451130805067329, 0.326743423889562, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011298262679029265`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1730371971526112, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.22219724789063, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03543816198498518, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.326743423889562, 0.9451130805067329, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.317602229717479, 3.5391865573943955`, 0.}, 
      Optica`Optica`RayEnd :> {5.410142819605809, 3.6812770041790377`, 0.}, 
      RotationMatrix :> {{0.5457418248810821, 0.8379533761346549, 
       0.}, {-0.8379533761346549, 0.5457418248810821, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009928046162535169, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16956844000090188`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.473158539091965`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42362391460275006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5457418248810821, 0.8379533761346549, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0949401737714983`, 3.1903948146437107`, 0.},
       Optica`Optica`RayEnd :> {3.100638485469136, 3.2575318555276516`, 0.}, 
      RotationMatrix :> {{0.08457174768191165, 0.996417392207717, 
       0.}, {-0.996417392207717, 0.08457174768191165, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030408831817915934`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06737843137722456, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.26978900947584, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04977645693171608, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08457174768191165, 0.996417392207717, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.100638485469136, 3.2575318555276516`, 0.}, 
      Optica`Optica`RayEnd :> {3.1531498249152365`, 3.3914826324245704`, 0.}, 
      RotationMatrix :> {{0.36497682288163297`, 0.93101660498577, 
       0.}, {-0.93101660498577, 0.36497682288163297`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023802575426291463`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14387581937807264`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.482725222155388`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3746266545776469, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 69, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.36497682288163297`, 0.93101660498577, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4434141231202973`, -2.618182018279854, 0.}, 
      Optica`Optica`RayEnd :> {2.507203505473403, -2.8192627123809926`, 0.}, 
      RotationMatrix :> {{0.3023820744691531, -0.9531868028040101, 0.}, {
       0.9531868028040101, 0.3023820744691531, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008167407844043167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21095622968091335`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.325890928591372`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12676177390048393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {0.3023820744691531, -0.9531868028040101, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.507203505473403, -2.8192627123809926`, 0.}, 
      Optica`Optica`RayEnd :> {2.5716690254112136`, -3.0748271865089367`, 0.},
       RotationMatrix :> {{0.2445862027323238, -0.9696275519151577, 0.}, {
       0.9696275519151577, 0.2445862027323238, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008129882585708893, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2635697321339173, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 13.71597413214957, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11781401453620782`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {0.2445862027323238, -0.9696275519151577, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.131828495403569, -2.4140370798315542`, 0.}, 
      Optica`Optica`RayEnd :> {3.5736524678233232`, -2.793166685997226, 0.}, 
      RotationMatrix :> {{0.7588971863879019, -0.6512104579109012, 0.}, {
       0.6512104579109012, 0.7588971863879019, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029071058343938503`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5821921339868044, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.2383937877891, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15902395088447796`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7588971863879019, -0.6512104579109012, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5736524678233232`, -2.793166685997226, 0.}, 
      Optica`Optica`RayEnd :> {3.7370821451708434`, -2.897242151157988, 0.}, 
      RotationMatrix :> {{0.8434866731869127, -0.537150102072106, 0.}, {
       0.537150102072106, 0.8434866731869127, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02840872678841154, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1937549015801755, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.52515104212776, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19957137838754474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8434866731869127, -0.537150102072106, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4145530314090804`, -1.7368927213868033`, 
       0.}, Optica`Optica`RayEnd :> {
       3.6175598185970927`, -1.6842546957809021`, 0.}, 
      RotationMatrix :> {{0.9679892104712908, 0.25099180945036276`, 
       0.}, {-0.25099180945036276`, 0.9679892104712908, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009311596765202315, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20972009294315686`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.915695834740651`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39301418492394663`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9679892104712908, 0.25099180945036276`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6175598185970927`, -1.6842546957809021`, 
       0.}, Optica`Optica`RayEnd :> {3.767724301347901, -1.6731776431117509`, 
       0.}, RotationMatrix :> {{0.9972903324480155, 0.0735662477344537, 
       0.}, {-0.0735662477344537, 0.9972903324480155, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008892737407424346, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1505724841252647, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 14.138543111246044`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0022129279614545583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9972903324480155, 0.0735662477344537, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.108755056526315, -2.2415706126908783`, 0.}, 
      Optica`Optica`RayEnd :> {2.0154221800005097`, -2.3147975971414723`, 0.},
       RotationMatrix :> {{-0.7867521845269705, -0.6172689852422844, 0.}, {
       0.6172689852422844, -0.7867521845269705, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2561055404059701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11863059087903421`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.658258840142066`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23635324876137828`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7867521845269705, -0.6172689852422844, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0154221800005097`, -2.3147975971414723`, 
       0.}, Optica`Optica`RayEnd :> {1.841612151678042, -2.4839424729838475`, 
       0.}, RotationMatrix :> {{-0.7166591236509767, -0.6974236162389497, 
       0.}, {0.6974236162389497, -0.7166591236509767, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25319534593083126`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24252817355760856`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.017200537007326`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00201762286010565, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7166591236509767, -0.6974236162389497, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.6650107297416685`, 2.069805418458244, 0.}, 
      Optica`Optica`RayEnd :> {8.063843397574225, 2.219770844068518, 0.}, 
      RotationMatrix :> {{0.9360177276403691, 0.35195285698934203`, 
       0.}, {-0.35195285698934203`, 0.9360177276403691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010451198946883183`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.42609520744653434`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.414372799053039`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09569465958369894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9360177276403691, 0.35195285698934203`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.063843397574225, 2.219770844068518, 0.}, 
      Optica`Optica`RayEnd :> {8.34571974139002, 2.320663474652185, 0.}, 
      RotationMatrix :> {{0.9415062759833304, 0.3369954484618469, 
       0.}, {-0.3369954484618469, 0.9415062759833304, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010424100011493862`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2993887040438444, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.85746808103793, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26233494131475343`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9415062759833304, 0.3369954484618469, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6579620877190564`, 1.2411682766713321`, 0.},
       Optica`Optica`RayEnd :> {3.1701167073340666`, 1.0845330539530924`, 0.},
       RotationMatrix :> {{-0.9521264351354322, -0.3057045166763061, 0.}, {
       0.3057045166763061, -0.9521264351354322, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010491280187039336`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5123745779788142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.274481647875511`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23004189756137494`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9521264351354322, -0.3057045166763061, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1701167073340666`, 1.0845330539530924`, 0.},
       Optica`Optica`RayEnd :> {2.847931087938611, 0.9721552211046295, 0.}, 
      RotationMatrix :> {{-0.9442115730581255, -0.32933949854686456`, 0.}, {
       0.32933949854686456`, -0.9442115730581255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01046206966147482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34122184962418545`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.779489985319305`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.050961325834923375`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9442115730581255, -0.32933949854686456`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.64293783700036, 1.8804307999132586`, 0.}, 
      Optica`Optica`RayEnd :> {3.627751011380789, 1.9108336284133907`, 0.}, 
      RotationMatrix :> {{-0.44687014786224416`, 0.8945988324101348, 
       0.}, {-0.8945988324101348, -0.44687014786224416`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4050805738602362, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.033984873888359406`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.048595723171022`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1027272622670726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.44687014786224416`, 0.8945988324101348, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.627751011380789, 1.9108336284133907`, 0.}, 
      Optica`Optica`RayEnd :> {3.5075177202934777`, 2.1367499951643203`, 0.}, 
      RotationMatrix :> {{-0.4698109681336203, 0.8827670441409505, 
       0.}, {-0.8827670441409505, -0.4698109681336203, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4039430340575549, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25591844218740206`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.427355017608377`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3485071297125135, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4698109681336203, 0.8827670441409505, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.297582025844731, 1.9168082156473396`, 0.}, 
      Optica`Optica`RayEnd :> {4.376064366816332, 1.9628549605429493`, 0.}, 
      RotationMatrix :> {{0.8625068150575165, 0.5060454465552867, 
       0.}, {-0.5060454465552867, 0.8625068150575165, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009693114947455218, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09099329953279002, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.352448226475408`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.032562114814977006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8625068150575165, 0.5060454465552867, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.376064366816332, 1.9628549605429493`, 0.}, 
      Optica`Optica`RayEnd :> {4.637363154484737, 2.100095438023548, 0.}, 
      RotationMatrix :> {{0.8853161559889517, 0.4649895740174681, 
       0.}, {-0.4649895740174681, 0.8853161559889517, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009657370105847711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2951474294248223, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.789266422024145`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07230668967115318, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8853161559889517, 0.4649895740174681, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8550571286116426`, -0.5179270523033074, 0.},
       Optica`Optica`RayEnd :> {2.704601447193009, -0.5948348992005054, 0.}, 
      RotationMatrix :> {{-0.8904148320843857, -0.45514989487435353`, 0.}, {
       0.45514989487435353`, -0.8904148320843857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009410713779352138, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1689725687367868, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.737253863186783`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3063296168063141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8904148320843857, -0.45514989487435353`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.704601447193009, -0.5948348992005054, 0.}, 
      Optica`Optica`RayEnd :> {2.4748039084685063`, -0.6836136830671304, 0.}, 
      RotationMatrix :> {{-0.9328071800678015, -0.3603758660259533, 0.}, {
       0.3603758660259533, -0.9328071800678015, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009309332837770938, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24635052520479117`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.101852640489874`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4122383382710711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9328071800678015, -0.3603758660259533, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.118371926014607, -0.7916360463911913, 0.}, 
      Optica`Optica`RayEnd :> {3.8896606650171655`, -0.8454441103070542, 0.}, 
      RotationMatrix :> {{-0.9734231939642597, -0.2290137232840416, 0.}, {
       0.2290137232840416, -0.9734231939642597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0280588219837724, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23495563123580043`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.540347795255185`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10329770351956694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9734231939642597, -0.2290137232840416, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8896606650171655`, -0.8454441103070542, 0.},
       Optica`Optica`RayEnd :> {3.7044712285073365`, -0.8600566613744223, 0.},
       RotationMatrix :> {{-0.9969013862426118, -0.07866146520094322, 0.}, {
       0.07866146520094322, -0.9969013862426118, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027285911110495113`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18576505065141927`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.815280070219286`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41981160600186046`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9969013862426118, -0.07866146520094322, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.364103526572395, -0.9270059505467887, 0.}, 
      Optica`Optica`RayEnd :> {4.161058715726155, -0.9562585138170068, 0.}, 
      RotationMatrix :> {{-0.9897808004558247, -0.14259721963988975`, 0.}, {
       0.14259721963988975`, -0.9897808004558247, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013494465091201462`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20514118959746547`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.138152427404854`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3293879029946876, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9897808004558247, -0.14259721963988975`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.161058715726155, -0.9562585138170068, 0.}, 
      Optica`Optica`RayEnd :> {3.8477455568113452`, -1.0070624334439158`, 0.},
       RotationMatrix :> {{-0.9871072795811094, -0.16006004685111574`, 0.}, {
       0.16006004685111574`, -0.9871072795811094, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013459071982889852`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31740537770906513`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.60791238641427, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0032520609337078074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9871072795811094, -0.16006004685111574`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8600330983876, 0.07567180311158181, 0.}, 
      Optica`Optica`RayEnd :> {5.767312050664425, 0.12266667029449653`, 0.}, 
      RotationMatrix :> {{-0.8919729245770007, 0.4520888207217167, 
       0.}, {-0.4520888207217167, -0.8919729245770007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009472909390102981, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10395051819218161`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.233241160711506`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03935688335179436, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8919729245770007, 0.4520888207217167, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.767312050664425, 0.12266667029449653`, 0.}, 
      Optica`Optica`RayEnd :> {5.5831585270802275`, 0.2281089080558495, 0.}, 
      RotationMatrix :> {{-0.8678131663699074, 0.49689064015639883`, 
       0.}, {-0.49689064015639883`, -0.8678131663699074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00943571583997411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21220411342053958`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.547303248573904`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03578035635486027, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8678131663699074, 0.49689064015639883`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.626023718036561, -0.4492137686747103, 0.}, 
      Optica`Optica`RayEnd :> {7.72673538027961, -0.3799163735965593, 0.}, 
      RotationMatrix :> {{0.8238198860450582, 0.5668516519837505, 
       0.}, {-0.5668516519837505, 0.8238198860450582, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10072774736858355`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12224961299069746`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.249912410946635`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2965764545774041, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {0.8238198860450582, 0.5668516519837505, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.72673538027961, -0.3799163735965593, 0.}, 
      Optica`Optica`RayEnd :> {7.888559142148566, -0.24197956494456557`, 0.}, 
      RotationMatrix :> {{0.7610413645415925, 0.648703353973656, 
       0.}, {-0.648703353973656, 0.7610413645415925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09965710111863778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21263464695697465`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.564611688442957`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42060867034177307`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.7610413645415925, 0.648703353973656, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.334496159081358, -0.6055118865612469, 0.}, 
      Optica`Optica`RayEnd :> {7.342652343122805, -0.5507698702134257, 0.}, 
      RotationMatrix :> {{0.14736641259282302`, 0.9890819685139961, 
       0.}, {-0.9890819685139961, 0.14736641259282302`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02011784280062146, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05534628887236306, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.31083894550298, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23451835499540066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.14736641259282302`, 0.9890819685139961, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.342652343122805, -0.5507698702134257, 0.}, 
      Optica`Optica`RayEnd :> {7.397588857222164, -0.3497113918811222, 0.}, 
      RotationMatrix :> {{0.26357458552800483`, 0.9646390194594764, 
       0.}, {-0.9646390194594764, 0.26357458552800483`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019825809161793266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20842872232657986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.619313454546317`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42648564305437797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.26357458552800483`, 0.9646390194594764, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.416265530500333, -1.3702567653724946`, 0.}, 
      Optica`Optica`RayEnd :> {7.410231089580755, -1.3423576688021113`, 0.}, 
      RotationMatrix :> {{-0.21140655099458677`, 0.9773982147500438, 
       0.}, {-0.9773982147500438, -0.21140655099458677`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014082386259038229`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028544247523020136`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.94697997238299, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31764702296223885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.21140655099458677`, 0.9773982147500438, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.410231089580755, -1.3423576688021113`, 0.}, 
      Optica`Optica`RayEnd :> {7.341191770303148, -1.1511869589989376`, 0.}, 
      RotationMatrix :> {{-0.33966819212927735`, 0.940545330781897, 
       0.}, {-0.940545330781897, -0.33966819212927735`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013809884103596163`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2032551792524971, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.247797637676687`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00236947593980058, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.33966819212927735`, 0.940545330781897, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5948414737607, -1.6208355140056565`, 0.}, 
      Optica`Optica`RayEnd :> {7.666658242611352, -1.7260979029653378`, 0.}, 
      RotationMatrix :> {{0.5635883614852665, -0.8260557843138394, 0.}, {
       0.8260557843138394, 0.5635883614852665, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.231310510328191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12742770035454346`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.534879286390591`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21392833977752224`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5635883614852665, -0.8260557843138394, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.666658242611352, -1.7260979029653378`, 0.}, 
      Optica`Optica`RayEnd :> {7.823226157153527, -1.930649643545257, 0.}, 
      RotationMatrix :> {{0.6078076765327134, -0.7940842703063097, 0.}, {
       0.7940842703063097, 0.6078076765327134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.209477790497711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25759450001574175`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.91611914641389, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16941887823052035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6078076765327134, -0.7940842703063097, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.823226157153527, -1.930649643545257, 0.}, 
      Optica`Optica`RayEnd :> {7.898725692883722, -1.6843677998318296`, 0.}, 
      RotationMatrix :> {{0.29309451764529615`, 0.9560834711081827, 
       0.}, {-0.9560834711081827, 0.29309451764529615`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02174160161941837, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2575945000157418, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.297359006437187`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12333496680642272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.29309451764529615`, 0.9560834711081827, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.33511329940802, -1.4558495987725213`, 0.}, 
      Optica`Optica`RayEnd :> {7.307758015701156, -1.4376774421161653`, 0.}, 
      RotationMatrix :> {{-0.8329584375083858, 0.5533355594786841, 
       0.}, {-0.5533355594786841, -0.8329584375083858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014007074744085104`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.032841114844447364`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.863528749020421`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11743759570648026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8329584375083858, 0.5533355594786841, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.307758015701156, -1.4376774421161653`, 0.}, 
      Optica`Optica`RayEnd :> {7.106842406878487, -1.2806810371144008`, 0.}, 
      RotationMatrix :> {{-0.7879652245364943, 0.6157197454371199, 
       0.}, {-0.6157197454371199, -0.7879652245364943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013918848862568497`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2549802993410704, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.240899592045206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021148893998513885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7879652245364943, 0.6157197454371199, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.636570319863082, -1.3161057789349486`, 0.}, 
      Optica`Optica`RayEnd :> {6.443841666585319, -1.2947815133730185`, 0.}, 
      RotationMatrix :> {{-0.9939345881933329, 0.10997288026122386`, 
       0.}, {-0.10997288026122386`, -0.9939345881933329, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019989661948342154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19390476553198865`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.253232797202035`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3140220902068126, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9939345881933329, 0.10997288026122386`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.443841666585319, -1.2947815133730185`, 0.}, 
      Optica`Optica`RayEnd :> {6.119803288382871, -1.2507439383342212`, 0.}, 
      RotationMatrix :> {{-0.9908912591212323, 0.13466444444298797`, 
       0.}, {-0.13466444444298797`, -0.9908912591212323, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019934029997220225`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32701709215784336`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.737218093595644`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04892687975860997, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9908912591212323, 0.13466444444298797`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.489914395050555, -1.6575550106708106`, 0.}, 
      Optica`Optica`RayEnd :> {6.32590391948947, -1.7759094604061625`, 0.}, 
      RotationMatrix :> {{-0.8109081174130106, -0.5851735000097722, 0.}, {
       0.5851735000097722, -0.8109081174130106, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09632964697135038, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20225531356661824`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.788574426273378`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3873718976099119, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8109081174130106, -0.5851735000097722, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.32590391948947, -1.7759094604061625`, 0.}, 
      Optica`Optica`RayEnd :> {6.141316224293418, -1.8963876196907001`, 0.}, 
      RotationMatrix :> {{-0.8374135911182645, -0.5465697370056378, 0.}, {
       0.5465697370056378, -0.8374135911182645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09597518380971577, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22042596054544267`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.114804847880633`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41955287271902053`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8374135911182645, -0.5465697370056378, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3712579755478105`, -0.6419208330212081, 0.},
       Optica`Optica`RayEnd :> {5.1564270156805865`, -0.520304833930549, 0.}, 
      RotationMatrix :> {{-0.8702332913122522, 0.49263984683726586`, 
       0.}, {-0.49263984683726586`, -0.8702332913122522, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01348882622830329, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2468659404460081, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.407763121053192`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4251190135964414, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8702332913122522, 0.49263984683726586`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1564270156805865`, -0.520304833930549, 0.}, 
      Optica`Optica`RayEnd :> {4.909899322736532, -0.39632633971432635`, 0.}, 
      RotationMatrix :> {{-0.8933888699026219, 0.4492842386887352, 
       0.}, {-0.4492842386887352, -0.8933888699026219, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013437340610427924`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.275946680386701, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.816164208025508`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39202613399680103`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8933888699026219, 0.4492842386887352, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.41150589720002, 1.1926671838836118`, 0.}, 
      Optica`Optica`RayEnd :> {6.354979373850421, 1.4386060953362028`, 0.}, 
      RotationMatrix :> {{-0.22399930425752176`, 0.974589304113351, 
       0.}, {-0.974589304113351, -0.22399930425752176`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019043386185443257`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25235133446938235`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.466515559477012`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20656013731780043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22399930425752176`, 0.974589304113351, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.354979373850421, 1.4386060953362028`, 0.}, 
      Optica`Optica`RayEnd :> {6.362812811651092, 1.5853767994063988`, 0.}, 
      RotationMatrix :> {{0.053296089324221085`, 0.9985787534605091, 
       0.}, {-0.9985787534605091, 0.053296089324221085`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015376806516702356`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14697959831567786`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.684045364984215`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2538531940280179, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.053296089324221085`, 0.9985787534605091, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.966496046375656, 1.6530371043377268`, 0.}, 
      Optica`Optica`RayEnd :> {7.051610080316026, 1.9509057415606017`, 0.}, 
      RotationMatrix :> {{0.2747471187047909, 0.9615165213158926, 
       0.}, {-0.9615165213158926, 0.2747471187047909, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026517743192262206`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3097904514581028, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.334519329970359`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08594122820829884, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2747471187047909, 0.9615165213158926, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.051610080316026, 1.9509057415606017`, 0.}, 
      Optica`Optica`RayEnd :> {7.076721279197129, 2.116419354507405, 0.}, 
      RotationMatrix :> {{0.1500002879175425, 0.9886859529823685, 
       0.}, {-0.9886859529823685, 0.1500002879175425, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026059017545362138`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.167407671209985, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.582282683361136`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2281699085685243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1500002879175425, 0.9886859529823685, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.151550991487545, 0.3339560449741226, 0.}, 
      Optica`Optica`RayEnd :> {3.5911278109148954`, 0.404730043300868, 0.}, 
      RotationMatrix :> {{-0.9921199645349501, 0.1252915638467686, 
       0.}, {-0.1252915638467686, -0.9921199645349501, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11181417082318149`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5648744109643473, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.752285578213204`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19746199650696766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9921199645349501, 0.1252915638467686, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5911278109148954`, 0.40473004330086804`, 
       0.}, Optica`Optica`RayEnd :> {3.3223761266728817`, 
       0.45320832530609795`, 0.}, 
      RotationMatrix :> {{-0.9841175103565202, 0.17751824078016298`, 
       0.}, {-0.17751824078016298`, -0.9841175103565202, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11136090835582428`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27308901773798555`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.156457324465423`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14023527851212902`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9841175103565202, 0.17751824078016298`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.727886367284384, -0.8570999932866199, 0.}, 
      Optica`Optica`RayEnd :> {4.664926309399225, -0.9417618929029387, 0.}, 
      RotationMatrix :> {{-0.5967414467837574, -0.8024335771205164, 0.}, {
       0.8024335771205164, -0.5967414467837574, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04307269117795738, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1055064269869199, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.044505999507278`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3837323211066095, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5967414467837574, -0.8024335771205164, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.664926309399225, -0.9417618929029387, 0.}, 
      Optica`Optica`RayEnd :> {4.5046753581612275`, -1.1223702829451243`, 0.},
       RotationMatrix :> {{-0.6636930049804283, -0.7480050769480439, 0.}, {
       0.7480050769480439, -0.6636930049804283, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04274634605243103, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2414534280690859, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.401857073049525`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2725939856244508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6636930049804283, -0.7480050769480439, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.578707936680302, -1.6625646141888275`, 0.}, 
      Optica`Optica`RayEnd :> {5.567958176702326, -1.8050679294545213`, 0.}, 
      RotationMatrix :> {{-0.07522143833073767, -0.9971668542503077, 0.}, {
       0.9971668542503077, -0.07522143833073767, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023270915190478556`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14290819501098534`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.884238903717268`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.048717767343396154`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.07522143833073767, -0.9971668542503077, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.567958176702326, -1.8050679294545213`, 0.}, 
      Optica`Optica`RayEnd :> {5.532598262384877, -2.126137966057005, 0.}, 
      RotationMatrix :> {{-0.10946959338642762`, -0.993990144882639, 0.}, {
       0.993990144882639, -0.10946959338642762`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02319900721475991, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3230112876424874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.362295609428148`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15584409299606355`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10946959338642762`, -0.993990144882639, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.366015524438264, -0.8484054132965815, 0.}, 
      Optica`Optica`RayEnd :> {6.390699751889108, -0.8876621830023901, 0.}, 
      RotationMatrix :> {{0.5323036003626034, -0.8465535287511415, 0.}, {
       0.8465535287511415, 0.5323036003626034, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01201760350620879, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.046372460066076725`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.213857491089364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3123570708682646, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5323036003626034, -0.8465535287511415, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.390699751889108, -0.8876621830023901, 0.}, 
      Optica`Optica`RayEnd :> {6.558502686551672, -1.1361041517412096`, 0.}, 
      RotationMatrix :> {{0.5597125335674733, -0.8286868405902679, 0.}, {
       0.8286868405902679, 0.5597125335674733, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011981220273258689`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2998019958442395, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.657564444938838`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11474417792070478`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5597125335674733, -0.8286868405902679, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.940507675890693, 1.090761132862692, 0.}, 
      Optica`Optica`RayEnd :> {5.906650267057244, 1.1411021167992952`, 0.}, 
      RotationMatrix :> {{-0.5580820031231205, 0.8297858023550926, 
       0.}, {-0.8297858023550926, -0.5580820031231205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009696734588689125, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06066744428950892, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.618713409837273`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2151661369551212, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5580820031231205, 0.8297858023550926, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.906650267057244, 1.1411021167992952`, 0.}, 
      Optica`Optica`RayEnd :> {5.7072547024128575`, 1.4150411308714208`, 0.}, 
      RotationMatrix :> {{-0.5884943908323917, 0.80850129991164, 
       0.}, {-0.80850129991164, -0.5884943908323917, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009665706492078707, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3388232203239054, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.120171775916653`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36335824550513446`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5884943908323917, 0.80850129991164, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.975305451484222, 1.144078691628268, 0.}, 
      Optica`Optica`RayEnd :> {6.991925785457024, 1.3846612093021353`, 0.}, 
      RotationMatrix :> {{0.06891944920209155, 0.9976222278606665, 
       0.}, {-0.9976222278606665, 0.06891944920209155, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01623231525874228, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24115593152909232`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.393561583149067`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13207967455719077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.06891944920209155, 0.9976222278606665, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.991925785457024, 1.3846612093021353`, 0.}, 
      Optica`Optica`RayEnd :> {7.001660413572281, 1.6459442831685513`, 0.}, 
      RotationMatrix :> {{0.03723118665679459, 0.9993066790230745, 
       0.}, {-0.9993066790230745, 0.03723118665679459, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016183740011021297`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2614643525867826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.780528824977505`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09582970381108441, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.03723118665679459, 0.9993066790230745, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.438952443142733, -0.6266931228462786, 0.}, 
      Optica`Optica`RayEnd :> {7.470287291566744, -0.8397595192879214, 0.}, 
      RotationMatrix :> {{0.145501057396918, -0.9893580960887612, 0.}, {
       0.9893580960887612, 0.145501057396918, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1328868511375348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2153582179030626, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.342977812336551`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.421181276979638, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.145501057396918, -0.9893580960887612, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.470287291566744, -0.8397595192879214, 0.}, 
      Optica`Optica`RayEnd :> {7.523807089318023, -1.1364673427704632`, 0.}, 
      RotationMatrix :> {{0.17751406032210787`, -0.9841182644316478, 0.}, {
       0.9841182644316478, 0.17751406032210787`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1324858712460342, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30149610489537837`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.789192047581711`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30049237962175807`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.17751406032210787`, -0.9841182644316478, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.600626168023581, -0.20339427849454245`, 0.},
       Optica`Optica`RayEnd :> {7.538987903316532, -0.1919606194188685, 0.}, 
      RotationMatrix :> {{-0.9832272225985134, 0.18238483692789056`, 
       0.}, {-0.18238483692789056`, -0.9832272225985134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009020334217983232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06268974585970889, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.740944200499404`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1905596736229362, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9832272225985134, 0.18238483692789056`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.538987903316532, -0.1919606194188685, 0.}, 
      Optica`Optica`RayEnd :> {7.40231010193742, -0.133882634183127, 0.}, 
      RotationMatrix :> {{-0.9203553515386959, 0.3910831457555841, 
       0.}, {-0.3910831457555841, -0.9203553515386959, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008270635030373886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1485054671009489, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.960732291808808`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2964228544172283, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9203553515386959, 0.3910831457555841, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.882934929861941, -0.2757101473357457, 0.}, 
      Optica`Optica`RayEnd :> {8.129580112651137, -0.3380120252934028, 0.}, 
      RotationMatrix :> {{0.9695471136563382, -0.24490486806240447`, 0.}, {
       0.24490486806240447`, 0.9695471136563382, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.633570517660891, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2543921582717657, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.429132633492408`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2981447243338071, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9695471136563382, -0.24490486806240447`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.129580112651137, -0.3380120252934028, 0.}, 
      Optica`Optica`RayEnd :> {8.371022184652178, -0.3716808198235361, 0.}, 
      RotationMatrix :> {{0.9904165683159343, -0.1381123499376085, 0.}, {
       0.1381123499376085, 0.9904165683159343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.590303230054508, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24377830473048245`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.789924524493522`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06541995177479076, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9904165683159343, -0.1381123499376085, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.371022184652178, -0.3716808198235361, 0.}, 
      Optica`Optica`RayEnd :> {8.400837322111133, -0.12973264472074333`, 0.}, 
      RotationMatrix :> {{0.12230431043450568`, 0.9924926476549538, 
       0.}, {-0.9924926476549538, 0.12230431043450568`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0427520758696878, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2437783047304826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.150716415494635`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18380543768226706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12230431043450568`, 0.9924926476549538, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.605830110964485, -0.1854840910062472, 0.}, 
      Optica`Optica`RayEnd :> {7.583808442483033, -0.17839516500404123`, 0.}, 
      RotationMatrix :> {{-0.9518958370077016, 0.3064217934276332, 
       0.}, {-0.3064217934276332, -0.9518958370077016, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008975824316198333, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023134535970530057`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.550554619969601`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.034171954365296665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9518958370077016, 0.3064217934276332, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.583808442483033, -0.17839516500404123`, 0.},
       Optica`Optica`RayEnd :> {7.380663139819714, -0.0912541415179408, 0.}, 
      RotationMatrix :> {{-0.9190159886132998, 0.3942202590850948, 
       0.}, {-0.3942202590850948, -0.9190159886132998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008896853607336734, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22104653801490837`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.877703496231666`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15022112292948303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9190159886132998, 0.3942202590850948, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.8898389876045965`, 0.310250823629456, 0.}, 
      Optica`Optica`RayEnd :> {7.923392072908012, 0.37453662136558347`, 0.}, 
      RotationMatrix :> {{0.4627033282632306, 0.8865131865991214, 
       0.}, {-0.8865131865991214, 0.4627033282632306, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12386341584104354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07251533164751142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.565013774421109`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40973660908384657`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4627033282632306, 0.8865131865991214, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.923392072908012, 0.37453662136558347`, 0.}, 
      Optica`Optica`RayEnd :> {8.080195487154919, 0.6661707831798577, 0.}, 
      RotationMatrix :> {{0.4735603887564788, 0.8807613514459023, 
       0.}, {-0.8807613514459023, 0.4735603887564788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12354873668994602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3311159842964417, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.055065431179843`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07335736124784917, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4735603887564788, 0.8807613514459023, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.125657458194816, -0.41832732762270464`, 0.},
       Optica`Optica`RayEnd :> {6.080637716367729, -0.43385538527627593`, 0.},
       RotationMatrix :> {{-0.9453470365188422, -0.3260659144176867, 0.}, {
       0.3260659144176867, -0.9453470365188422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015961321692052968`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04762244983902242, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.627949976246173`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30477694808892464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9453470365188422, -0.3260659144176867, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.080637716367729, -0.43385538527627593`, 0.},
       Optica`Optica`RayEnd :> {5.825637039936708, -0.5234217821511212, 0.}, 
      RotationMatrix :> {{-0.943493038739633, -0.33139234428370995`, 0.}, {
       0.33139234428370995`, -0.943493038739633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01592172875302877, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.270272981315966, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.027953988593802`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14003068573575975`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.943493038739633, -0.33139234428370995`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.370259476906691, 0.6360526074102332, 0.}, 
      Optica`Optica`RayEnd :> {5.342481872083101, 0.6441757256033335, 0.}, 
      RotationMatrix :> {{-0.9598017725172795, 0.2806787442480967, 
       0.}, {-0.2806787442480967, -0.9598017725172795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009594863058565406, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028940980959784226`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.868207991457457`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10364977992379855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9598017725172795, 0.2806787442480967, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.342481872083101, 0.6441757256033335, 0.}, 
      Optica`Optica`RayEnd :> {5.091004786913011, 0.7337025154327036, 0.}, 
      RotationMatrix :> {{-0.9420813313156502, 0.33538450349789867`, 
       0.}, {-0.33538450349789867`, -0.9420813313156502, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009552742827458662, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2669377651491017, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.263275883878126`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0768724471146779, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9420813313156502, 0.33538450349789867`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.840886796903556, -0.5681950703666385, 0.}, 
      Optica`Optica`RayEnd :> {6.866761886098688, -0.694019397587685, 0.}, 
      RotationMatrix :> {{0.20142947378364678`, -0.9795030204604998, 0.}, {
       0.9795030204604998, 0.20142947378364678`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2841535494198482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12845731416110578`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.092386537853585`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1230844252937226, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.20142947378364678`, -0.9795030204604998, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.866761886098688, -0.694019397587685, 0.}, 
      Optica`Optica`RayEnd :> {6.881191250877583, -0.8861829153964238, 0.}, 
      RotationMatrix :> {{0.07487819336356952, -0.9971926875777855, 0.}, {
       0.9971926875777855, 0.07487819336356952, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27922743402544303`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19270449954412555`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.37758919717889, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.194074445425734, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.07487819336356952, -0.9971926875777855, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.149448457539012, 0.10347078033821677`, 0.}, 
      Optica`Optica`RayEnd :> {7.238157393487466, -0.13316628934978925`, 0.}, 
      RotationMatrix :> {{0.35101948620910406`, -0.9363681542542419, 0.}, {
       0.9363681542542419, 0.35101948620910406`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2891501326551351, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2527179812906734, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.231164717785962`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2634139652097113, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35101948620910406`, -0.9363681542542419, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.238157393487466, -0.13316628934978925`, 0.},
       Optica`Optica`RayEnd :> {7.331543225782122, -0.40876767013290327`, 0.},
       RotationMatrix :> {{0.32092102678487916`, -0.9471059574130754, 0.}, {
       0.9471059574130754, 0.32092102678487916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2882825865942385, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29099318679811853`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.661834634247178`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04918996529189873, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32092102678487916`, -0.9471059574130754, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.390408105692144, 0.7150344162751484, 0.}, 
      Optica`Optica`RayEnd :> {7.419974370971576, 0.6397102217070847, 0.}, 
      RotationMatrix :> {{0.3653806175742206, -0.9308582084834834, 0.}, {
       0.9308582084834834, 0.3653806175742206, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.34313034499645995`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08091908507825142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.037855835560466`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34691769049453625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3653806175742206, -0.9308582084834834, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.419974370971576, 0.6397102217070847, 0.}, 
      Optica`Optica`RayEnd :> {7.548191576253571, 0.30072193789939994`, 0.}, 
      RotationMatrix :> {{0.35377471567299984`, -0.9353306637497176, 0.}, {
       0.9353306637497176, 0.35377471567299984`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.34225796082991805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3624261418402439, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.574246525484027`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021790061741466804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35377471567299984`, -0.9353306637497176, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3775247299827535`, 1.391018043860573, 0.}, 
      Optica`Optica`RayEnd :> {7.341954503215509, 1.3691737677150844`, 0.}, 
      RotationMatrix :> {{-0.8521401507293794, -0.5233136378071086, 0.}, {
       0.5233136378071086, -0.8521401507293794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20473374778223055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0417422260138772, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.860896150152962`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21373869997074604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8521401507293794, -0.5233136378071086, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.341954503215509, 1.3691737677150844`, 0.}, 
      Optica`Optica`RayEnd :> {7.055504511607546, 1.1912081890792554`, 0.}, 
      RotationMatrix :> {{-0.8494155018550746, -0.5277246490436948, 0.}, {
       0.5277246490436948, -0.8494155018550746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20422639908246404`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33723188590551084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.359999341293118`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24249082298861957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8494155018550746, -0.5277246490436948, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.543884862887944, 1.6644691373106297`, 0.}, 
      Optica`Optica`RayEnd :> {7.590368247538926, 1.7369085399029403`, 0.}, 
      RotationMatrix :> {{0.5400602485764446, 0.8416263588478844, 
       0.}, {-0.8416263588478844, 0.5400602485764446, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      73.79176807230742, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0860707389101667, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.39401472952739, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.003812841491004166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5400602485764446, 0.8416263588478844, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.590368247538926, 1.7369085399029403`, 0.}, 
      Optica`Optica`RayEnd :> {7.738157029364659, 1.911472297130765, 0.}, 
      RotationMatrix :> {{0.6461485639682196, 0.7632116569352217, 
       0.}, {-0.7632116569352217, 0.6461485639682196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      72.40537642210035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22872260354199592`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.732524182769543`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3150627694712295, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6461485639682196, 0.7632116569352217, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.738157029364659, 1.911472297130765, 0.}, 
      Optica`Optica`RayEnd :> {7.932904742021405, 1.7915249845889867`, 0.}, 
      RotationMatrix :> {{0.8514580965802399, -0.5244226442173853, 0.}, {
       0.5244226442173853, 0.8514580965802399, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.3603442758456952`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2287226035419961, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.071033636011698`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.336623410496395, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8514580965802399, -0.5244226442173853, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.932904742021405, 1.7915249845889867`, 0.}, 
      Optica`Optica`RayEnd :> {7.843510263820795, 1.5809955172019488`, 0.}, 
      RotationMatrix :> {{-0.390842342716668, -0.9204576378844092, 0.}, {
       0.9204576378844092, -0.390842342716668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02555799914688803, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22872260354199594`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.409543089253852`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.032228636559607275`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 75, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.390842342716668, -0.9204576378844092, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.512885661753796, 1.345893802643445, 0.}, 
      Optica`Optica`RayEnd :> {7.496842644551443, 1.2139061125156703`, 0.}, 
      RotationMatrix :> {{-0.12066127301569289`, -0.9926937378639151, 0.}, {
       0.9926937378639151, -0.12066127301569289`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20360550783162337`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13295912434361357`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.930563538101607`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3153071259485915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12066127301569289`, -0.9926937378639151, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.496842644551443, 1.2139061125156703`, 0.}, 
      Optica`Optica`RayEnd :> {7.464985043809726, 0.8755865366445774, 0.}, 
      RotationMatrix :> {{-0.09374950869195185, -0.9955958163933879, 0.}, {
       0.9955958163933879, -0.09374950869195185, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20302652711350602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3398161887588858, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.433491497464757`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3822028922825804, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.09374950869195185, -0.9955958163933879, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.57982954868064, 1.3401081333321252`, 0.}, 
      Optica`Optica`RayEnd :> {6.359754642466834, 1.3107156326557965`, 0.}, 
      RotationMatrix :> {{-0.991198859075352, -0.13238134977299332`, 0.}, {
       0.13238134977299332`, -0.991198859075352, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3405463895680606, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22202901486297502`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.157625778777994`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3551872908742769, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.991198859075352, -0.13238134977299332`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.359754642466834, 1.3107156326557965`, 0.}, 
      Optica`Optica`RayEnd :> {6.051399004163451, 1.2658168799102762`, 0.}, 
      RotationMatrix :> {{-0.9895649330016388, -0.1440876239427284, 0.}, {
       0.1440876239427284, -0.9895649330016388, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3396831595089225, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31160728115945924`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.618804554893995`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.016004541490973054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9895649330016388, -0.1440876239427284, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.883323261180942, 1.0085602719018325`, 0.}, 
      Optica`Optica`RayEnd :> {5.67637167252377, 0.978887154996747, 0.}, 
      RotationMatrix :> {{-0.9898766371963097, -0.14193041651782967`, 0.}, {
       0.14193041651782967`, -0.9898766371963097, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2914970015936533, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20906806048411672`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.347044410427246`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42481335503115414`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9898766371963097, -0.14193041651782967`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.67637167252377, 0.978887154996747, 0.}, 
      Optica`Optica`RayEnd :> {5.348678083172981, 0.9374527928655113, 0.}, 
      RotationMatrix :> {{-0.992100753197418, -0.12544359491466678`, 0.}, {
       0.12544359491466678`, -0.992100753197418, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2907377575713962, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3303027321516211, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.835892454011645`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13984459587215015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.992100753197418, -0.12544359491466678`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.858833762293857, 1.081384031628743, 0.}, 
      Optica`Optica`RayEnd :> {4.6671547952838885`, 1.099269044092898, 0.}, 
      RotationMatrix :> {{-0.9956751103125859, 0.0929035774554402, 
       0.}, {-0.0929035774554402, -0.9956751103125859, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2947920179144425, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1925115582630084, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.977105216279762`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2515807751427352, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9956751103125859, 0.0929035774554402, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6671547952838885`, 1.099269044092898, 0.}, 
      Optica`Optica`RayEnd :> {4.363292513720586, 1.1077631715094527`, 0.}, 
      RotationMatrix :> {{-0.9996095193434801, 0.027942956856708986`, 
       0.}, {-0.027942956856708986`, -0.9996095193434801, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2933092808604072, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3039809802560426, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.426997067058704`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2722686937850284, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9996095193434801, 0.027942956856708986`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.468322005052908, -0.690413361520776, 0.}, 
      Optica`Optica`RayEnd :> {6.4922024195277235`, -0.830163736610522, 0.}, 
      RotationMatrix :> {{0.16843760653728979`, -0.9857123174151716, 0.}, {
       0.9857123174151716, 0.16843760653728979`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009331740870556703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14177602594660943`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.999685987189553`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.305914784067169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.16843760653728979`, -0.9857123174151716, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.4922024195277235`, -0.830163736610522, 0.}, 
      Optica`Optica`RayEnd :> {6.544058705200856, -1.1397096353662313`, 0.}, 
      RotationMatrix :> {{0.16522137546057344`, -0.9862565067419911, 0.}, {
       0.9862565067419911, 0.16522137546057344`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009308691707241247, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3138594236283073, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.464197934159447`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16032071954724936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.16522137546057344`, -0.9862565067419911, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.902671251455068, 2.2927415826140214`, 0.}, 
      Optica`Optica`RayEnd :> {6.918722068695445, 2.3383097548097824`, 0.}, 
      RotationMatrix :> {{0.3322298308658552, 0.9431984624048346, 
       0.}, {-0.9431984624048346, 0.3322298308658552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1834808706876179, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04831239024666962, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.918313892769195`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4003867237326231, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3322298308658552, 0.9431984624048346, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.918722068695445, 2.3383097548097824`, 0.}, 
      Optica`Optica`RayEnd :> {7.023459793219201, 2.629803328498619, 0.}, 
      RotationMatrix :> {{0.33814789247765026`, 0.9410929830855835, 
       0.}, {-0.9410929830855835, 0.33814789247765026`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18302503380982799`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30973939762371777`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.376728201252297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11821454050873383`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33814789247765026`, 0.9410929830855835, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.287150018382918, 1.8816042394023436`, 0.}, 
      Optica`Optica`RayEnd :> {6.356777134173283, 2.0706436486224016`, 0.}, 
      RotationMatrix :> {{0.3456223921478206, 0.9383736793229109, 
       0.}, {-0.9383736793229109, 0.3456223921478206, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0951794286245165, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2014542962846744, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.492109113914577`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.048226539856705775`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3456223921478206, 0.9383736793229109, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.356777134173283, 2.0706436486224016`, 0.}, 
      Optica`Optica`RayEnd :> {6.42157587195393, 2.311129214326098, 0.}, 
      RotationMatrix :> {{0.2601704758698748, 0.9655626978532477, 
       0.}, {-0.9655626978532477, 0.2601704758698748, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0944078045663355, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24906261005978383`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.860721776803057`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2083418853260214, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2601704758698748, 0.9655626978532477, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.434632846005179, 2.0883302110018165`, 0.}, 
      Optica`Optica`RayEnd :> {5.377379804505068, 2.129866926644981, 0.}, 
      RotationMatrix :> {{-0.8094205353186699, 0.5872294245049692, 
       0.}, {-0.5872294245049692, -0.8094205353186699, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.013486573740879, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07073336912260426, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.090637694138042`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19913733719252197`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8094205353186699, 0.5872294245049692, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.377379804505068, 2.129866926644981, 0.}, 
      Optica`Optica`RayEnd :> {5.105130303168906, 2.32777283886906, 0.}, 
      RotationMatrix :> {{-0.8088685216600074, 0.5879895531959334, 
       0.}, {-0.5879895531959334, -0.8088685216600074, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.006058013087019, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3365806605719258, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.588777071784492`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29034653810302113`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8088685216600074, 0.5879895531959334, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.216418216343868, 1.0764549847096392`, 0.}, 
      Optica`Optica`RayEnd :> {5.161659475834462, 1.054922119649615, 0.}, 
      RotationMatrix :> {{-0.930632857107919, -0.3659542119871698, 0.}, {
       0.3659542119871698, -0.930632857107919, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08460589303001663, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.058840325796766894`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.48610481992293, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.328609191229051, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.930632857107919, -0.3659542119871698, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.161659475834462, 1.054922119649615, 0.}, 
      Optica`Optica`RayEnd :> {4.851961525503718, 0.934645522777102, 0.}, 
      RotationMatrix :> {{-0.9321687772798607, -0.3620239918355801, 0.}, {
       0.3620239918355801, -0.9321687772798607, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08439661581420521, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.332233773410075, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.977810804569842`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19967196777475835`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9321687772798607, -0.3620239918355801, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.589348707423781, 1.1826893079768626`, 0.}, 
      Optica`Optica`RayEnd :> {5.518103669062487, 1.1512149591504777`, 0.}, 
      RotationMatrix :> {{-0.9147151604987089, -0.40409921449295166`, 0.}, {
       0.40409921449295166`, -0.9147151604987089, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15898512102382034`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07788767633680707, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.609452835421878`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22667185881366508`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9147151604987089, -0.40409921449295166`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.518103669062487, 1.1512149591504777`, 0.}, 
      Optica`Optica`RayEnd :> {5.461139648466303, 1.1443863509174352`, 0.}, 
      RotationMatrix :> {{-0.9928914176042102, -0.11902366507506512`, 0.}, {
       0.11902366507506512`, -0.9928914176042102, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12103378312832232`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057371853141438625`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.686331118631406`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3639647780656256, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9928914176042102, -0.11902366507506512`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.461139648466303, 1.1443863509174352`, 0.}, 
      Optica`Optica`RayEnd :> {5.409836078855042, 1.1187061391187512`, 0.}, 
      RotationMatrix :> {{-0.8942289084646228, -0.4476099409822895, 0.}, {
       0.4476099409822895, -0.8942289084646228, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028891974108604036`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057371853141438924`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.763209401840934`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40209558569383597`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8942289084646228, -0.4476099409822895, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.934336026432902, 0.3840163419848044, 0.}, 
      Optica`Optica`RayEnd :> {5.904292357145209, 0.1453567907485327, 0.}, 
      RotationMatrix :> {{-0.12489929648669358`, -0.9921694239075947, 0.}, {
       0.9921694239075947, -0.12489929648669358`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008658465574212347, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24054314261804854`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.537302600222638`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36058193007362177`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12489929648669358`, -0.9921694239075947, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.904292357145209, 0.1453567907485327, 0.}, 
      Optica`Optica`RayEnd :> {5.900457870164396, -0.1016796735186661, 0.}, 
      RotationMatrix :> {{-0.01552007778502694, -0.9998795563394353, 0.}, {
       0.9998795563394353, -0.01552007778502694, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008553618377615537, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24706622182735746`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.902960608527128`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34965775697463497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.01552007778502694, -0.9998795563394353, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.269243314924368, 0.10997104284251004`, 0.}, 
      Optica`Optica`RayEnd :> {7.3793113611938725`, -0.008201718506410174, 
       0.}, RotationMatrix :> {{0.6815682112711706, -0.7317545854892994, 
       0.}, {0.7317545854892994, 0.6815682112711706, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009356654266526165, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16149234141102387`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.360721967495898`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1346214152270417, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6815682112711706, -0.7317545854892994, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3793113611938725`, -0.008201718506410174, 
       0.}, Optica`Optica`RayEnd :> {7.5649167357676115`, -0.1860555186724132,
        0.}, RotationMatrix :> {{0.722023216690794, -0.6918688275673924, 
       0.}, {0.6918688275673924, 0.722023216690794, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009316071866090764, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25706288978408826`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.741175044376348`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10342002454448615`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.722023216690794, -0.6918688275673924, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.874911054466808, 0.8967438186105634, 0.}, 
      Optica`Optica`RayEnd :> {4.67989996195875, 0.9497794729162449, 0.}, 
      RotationMatrix :> {{-0.964950969671903, 0.26243023097435564`, 
       0.}, {-0.26243023097435564`, -0.964950969671903, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16068274892785345`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2020943018217443, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.00277623757153, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32109725590572646`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.964950969671903, 0.26243023097435564`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.67989996195875, 0.9497794729162449, 0.}, 
      Optica`Optica`RayEnd :> {4.338030659768891, 1.0456952774415846`, 0.}, 
      RotationMatrix :> {{-0.9628231966015137, 0.2701323603088719, 
       0.}, {-0.2701323603088719, -0.9628231966015137, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16028158611906965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3550696570217231, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.528279329963679`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09797256259860301, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9628231966015137, 0.2701323603088719, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9514534114328006`, -1.1585364994661662`, 
       0.}, Optica`Optica`RayEnd :> {3.88193336815691, -1.17997311673636, 0.},
       RotationMatrix :> {{-0.9556017458036147, -0.2946613368209053, 0.}, {
       0.2946613368209053, -0.9556017458036147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19317516410929736`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07275001702453757, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.913279007887688`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07688209814455385, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9556017458036147, -0.2946613368209053, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.88193336815691, -1.17997311673636, 0.}, 
      Optica`Optica`RayEnd :> {3.6682505014656734`, -1.260811247870144, 0.}, 
      RotationMatrix :> {{-0.9353077634148139, -0.3538352550212848, 0.}, {
       0.3538352550212848, -0.9353077634148139, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1922473465867297, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22846262487021288`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.251403692695604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08433686445886855, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9353077634148139, -0.3538352550212848, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.0960916602283275`, 1.2544517791728071`, 0.},
       Optica`Optica`RayEnd :> {3.959387763546078, 1.3564299397503847`, 0.}, 
      RotationMatrix :> {{-0.8015445978580942, 0.5979349944973161, 
       0.}, {-0.5979349944973161, -0.8015445978580942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.058365449494218354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17055058077560867`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.21655378168464, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39700607306614477`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8015445978580942, 0.5979349944973161, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.959387763546078, 1.3564299397503847`, 0.}, 
      Optica`Optica`RayEnd :> {3.8700807173829546`, 1.4673964527622854`, 0.}, 
      RotationMatrix :> {{-0.6269776034599785, 0.7790372807251149, 
       0.}, {-0.7790372807251149, -0.6269776034599785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.050483767032209075`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14244056832378382`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.42736582280384, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0886885599666829, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.6269776034599785, 0.7790372807251149, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.885969195992962, 0.6114723626851394, 0.}, 
      Optica`Optica`RayEnd :> {7.2096543937444535`, 0.6485669109904696, 0.}, 
      RotationMatrix :> {{0.993497322128942, 0.11385548261994437`, 
       0.}, {-0.11385548261994437`, 0.993497322128942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09039430626384935, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32580379487875627`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.477831863928495`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3709921986806899, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.993497322128942, 0.11385548261994437`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.2096543937444535`, 0.6485669109904696, 0.}, 
      Optica`Optica`RayEnd :> {7.379052243606461, 0.6990117450102403, 0.}, 
      RotationMatrix :> {{0.9584075066608065, 0.28540331318366874`, 
       0.}, {-0.28540331318366874`, 0.9584075066608065, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08664499971912516, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17674929368219172`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.73942081857814, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17972683120558744`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9584075066608065, 0.28540331318366874`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0774646795014835`, 1.2986243324192273`, 0.},
       Optica`Optica`RayEnd :> {5.01246476383433, 1.3282117434903686`, 0.}, 
      RotationMatrix :> {{-0.9101448317519575, 0.41429021860912885`, 
       0.}, {-0.41429021860912885`, -0.9101448317519575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05453624201350348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07141711230951438, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.306339855753608`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22184313669905908`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9101448317519575, 0.41429021860912885`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.01246476383433, 1.3282117434903686`, 0.}, 
      Optica`Optica`RayEnd :> {4.842566133514247, 1.440068636143774, 0.}, 
      RotationMatrix :> {{-0.8352331187821285, 0.549896024071349, 
       0.}, {-0.549896024071349, -0.8352331187821285, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.052956282245871136`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20341462341413796`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.607393498406532`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16788655614302495`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8352331187821285, 0.549896024071349, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.096699440575585, 0.8041596610668059, 0.}, 
      Optica`Optica`RayEnd :> {4.895066441242999, 0.7657285500947084, 0.}, 
      RotationMatrix :> {{-0.9823163290099132, -0.18722881658678187`, 0.}, {
       0.18722881658678187`, -0.9823163290099132, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013029632489310678`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20526279913906506`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.348061167765808`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3377331067527859, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9823163290099132, -0.18722881658678187`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.895066441242999, 0.7657285500947084, 0.}, 
      Optica`Optica`RayEnd :> {4.588794290327433, 0.7038109943929166, 0.}, 
      RotationMatrix :> {{-0.9801704337530773, -0.1981563039529729, 0.}, {
       0.1981563039529729, -0.9801704337530773, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012996707814092888`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3124682609970676, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      13.810514194041469`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0466084092957007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9801704337530773, -0.1981563039529729, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.165712099764965, -0.3395329293425942, 0.}, 
      Optica`Optica`RayEnd :> {5.134211892678214, -0.4363437224036853, 0.}, 
      RotationMatrix :> {{-0.3094120967425376, -0.9509280490075919, 0.}, {
       0.9509280490075919, -0.3094120967425376, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00817590703866301, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10180664369099719`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.256124501265502`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23932452249613007`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3094120967425376, -0.9509280490075919, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.134211892678214, -0.4363437224036853, 0.}, 
      Optica`Optica`RayEnd :> {5.0400177056328745`, -0.6635405089458228, 0.}, 
      RotationMatrix :> {{-0.38298255360788336`, -0.923755575697372, 0.}, {
       0.923755575697372, -0.38298255360788336`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008122867838280187, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24594902863846785`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.620129063650435`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14150469786015826`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.38298255360788336`, -0.923755575697372, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9089651371026575`, 0.23662464116783447`, 
       0.}, Optica`Optica`RayEnd :> {6.947263191339536, 0.11802716847812038`, 
       0.}, RotationMatrix :> {{0.3072993205886305, -0.9516129084694918, 
       0.}, {0.9516129084694918, 0.3072993205886305, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0093991170136647, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12462785197024911`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.748096621721736`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31841399912839746`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3072993205886305, -0.9516129084694918, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.947263191339536, 0.11802716847812038`, 0.}, 
      Optica`Optica`RayEnd :> {7.021149725198444, -0.07154571447836382, 0.}, 
      RotationMatrix :> {{0.36314523141482674`, -0.9317325479453163, 0.}, {
       0.9317325479453163, 0.36314523141482674`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009356549167343929, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20346276769501692`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.049221517910361`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3068487622119464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36314523141482674`, -0.9317325479453163, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.871677664455433, 2.085412051030004, 0.}, 
      Optica`Optica`RayEnd :> {5.821416870401075, 2.182867931844339, 0.}, 
      RotationMatrix :> {{-0.4583619345440708, 0.8887656254384593, 
       0.}, {-0.8887656254384593, -0.4583619345440708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19450054159088923`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10965307165908508`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.900732770458609`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3741616564982686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4583619345440708, 0.8887656254384593, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.821416870401075, 2.182867931844339, 0.}, 
      Optica`Optica`RayEnd :> {5.728774910946679, 2.3223324043258624`, 0.}, 
      RotationMatrix :> {{-0.5533169026795729, 0.8329708309473285, 
       0.}, {-0.8329708309473285, -0.5533169026795729, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19212239195866207`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1674301995940386, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.148529465857786`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1606733280850331, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5533169026795729, 0.8329708309473285, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.320906309499774, 2.0591489993432495`, 0.}, 
      Optica`Optica`RayEnd :> {6.3633446608630795`, 2.0310033450348413`, 0.}, 
      RotationMatrix :> {{0.8333764188916647, -0.5527058389734122, 0.}, {
       0.5527058389734122, 0.8333764188916647, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03403025478793858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05092338876080178, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.754896914973092`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12476018724181169`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8333764188916647, -0.5527058389734122, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.3633446608630795`, 2.0310033450348413`, 0.},
       Optica`Optica`RayEnd :> {6.6258440355301405`, 1.8689699323790148`, 0.},
       RotationMatrix :> {{0.8509408023139001, -0.5252616024014841, 0.}, {
       0.5252616024014841, 0.8509408023139001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03392739336227029, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3084813584602668, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.211449325494286`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09606761870595609, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8509408023139001, -0.5252616024014841, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.440837379378749, 2.2750571618804605`, 0.}, 
      Optica`Optica`RayEnd :> {6.472040952293647, 2.3458184217531763`, 0.}, 
      RotationMatrix :> {{0.4034818471751288, 0.9149876496435048, 
       0.}, {-0.9149876496435048, 0.4034818471751288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9641121447154126`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0773357540949168, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.155821909260755`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23636461687306098`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4034818471751288, 0.9149876496435048, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.472040952293647, 2.3458184217531763`, 0.}, 
      Optica`Optica`RayEnd :> {6.583810886957185, 2.633564846050262, 0.}, 
      RotationMatrix :> {{0.3620763359734007, 0.9321484468302653, 
       0.}, {-0.9321484468302653, 0.3620763359734007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.949966292510657, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30869163090445084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.612685522999342`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12302529011468033`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3620763359734007, 0.9321484468302653, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.583810886957185, 2.633564846050262, 0.}, 
      Optica`Optica`RayEnd :> {6.299114145669607, 2.5142405463846695`, 0.}, 
      RotationMatrix :> {{-0.9222690633154838, -0.38654854139057243`, 0.}, {
       0.38654854139057243`, -0.9222690633154838, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014095373023719666`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3086916309044505, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.06954913673793, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.002410754160916017, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9222690633154838, -0.38654854139057243`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.2077278035136985`, 2.356664280519256, 0.}, 
      Optica`Optica`RayEnd :> {6.164941740114911, 2.3673631501433543`, 0.}, 
      RotationMatrix :> {{-0.9701299413364021, 0.24258585474554797`, 
       0.}, {-0.24258585474554797`, -0.9701299413364021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03345822907371311, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.044103435607654055`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.47682302722777, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11879992851789876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9701299413364021, 0.24258585474554797`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.164941740114911, 2.3673631501433543`, 0.}, 
      Optica`Optica`RayEnd :> {5.8856226064772645`, 2.454866553037327, 0.}, 
      RotationMatrix :> {{-0.9542694808522411, 0.2989477511438968, 
       0.}, {-0.2989477511438968, -0.9542694808522411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03330863362328728, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2927046701610862, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.910025939066177`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09939531833986566, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9542694808522411, 0.2989477511438968, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.897227864791424, 1.7236485654343994`, 0.}, 
      Optica`Optica`RayEnd :> {7.0821012120622076`, 1.6664828386215798`, 0.}, 
      RotationMatrix :> {{0.9553690195022145, -0.2954150242885018, 0.}, {
       0.2954150242885018, 0.9553690195022145, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1779267659011658, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19350988308905961`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.65747085606729, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15430224114937713`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9553690195022145, -0.2954150242885018, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.0821012120622076`, 1.6664828386215795`, 0.},
       Optica`Optica`RayEnd :> {7.354603703684484, 1.6013214427552687`, 0.}, 
      RotationMatrix :> {{0.9725807027695446, -0.23256563933715085`, 0.}, {
       0.23256563933715085`, 0.9725807027695446, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17703044897375564`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2801849664981954, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.072144606484619`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1304924617591747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9725807027695446, -0.23256563933715085`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.372007422895698, 0.8886497691912926, 0.}, 
      Optica`Optica`RayEnd :> {5.350843936590856, 0.8617804958970844, 0.}, 
      RotationMatrix :> {{-0.6187595802589355, -0.7855804108032383, 0.}, {
       0.7855804108032383, -0.6187595802589355, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012792561618205705`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03420308465524864, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.642880905644772`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14088169828340977`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6187595802589355, -0.7855804108032383, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.350843936590856, 0.8617804958970844, 0.}, 
      Optica`Optica`RayEnd :> {5.161374580802137, 0.6278061110068232, 0.}, 
      RotationMatrix :> {{-0.6293216643366328, -0.7771449303679262, 0.}, {
       0.7771449303679262, -0.6293216643366328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012759855650103761`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3010691773791664, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.088463288165938`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4257046735607984, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6293216643366328, -0.7771449303679262, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3821519417883765`, 0.8912266074744308, 0.}, 
      Optica`Optica`RayEnd :> {7.622852413903404, 0.7885214531920586, 0.}, 
      RotationMatrix :> {{0.9197694973635048, -0.3924590064193769, 0.}, {
       0.3924590064193769, 0.9197694973635048, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08185817511685006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2616965150562062, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.664989312569103`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09057078283433105, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9197694973635048, -0.3924590064193769, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.622852413903404, 0.7885214531920586, 0.}, 
      Optica`Optica`RayEnd :> {7.929742957745927, 0.6652030754613594, 0.}, 
      RotationMatrix :> {{0.927889430523467, -0.37285547430986565`, 0.}, {
       0.37285547430986565`, 0.927889430523467, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08163762128954866, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3307404241789785, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.15448514035399, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2242898854194647, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.927889430523467, -0.37285547430986565`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.156171182713343, 1.1450378863667876`, 0.}, 
      Optica`Optica`RayEnd :> {4.153496893426275, 1.1455877333499838`, 0.}, 
      RotationMatrix :> {{-0.9795106854531603, 0.20139219717525927`, 
       0.}, {-0.20139219717525927`, -0.9795106854531603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09119287473769258, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0027302298247324397`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.409292522631697`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16267424242793946`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9795106854531603, 0.20139219717525927`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.153496893426274, 1.1455877333499838`, 0.}, 
      Optica`Optica`RayEnd :> {3.934429269750753, 1.1647759852781359`, 0.}, 
      RotationMatrix :> {{-0.9961858812182052, 0.08725646143126976, 
       0.}, {-0.08725646143126976, -0.9961858812182052, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08995559488743221, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21990637270187996`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.734753954230479`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38870967193291345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9961858812182052, 0.08725646143126976, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.278409306365115, 1.9170346464985808`, 0.}, 
      Optica`Optica`RayEnd :> {4.201877408545196, 2.010677723111943, 0.}, 
      RotationMatrix :> {{-0.6328158740977575, 0.7743023114326155, 
       0.}, {-0.7743023114326155, -0.6328158740977575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2730890145034687, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12093865048666005`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.484679178974478`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36847250650310254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6328158740977575, 0.7743023114326155, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.201877408545196, 2.010677723111943, 0.}, 
      Optica`Optica`RayEnd :> {4.055325171769849, 2.140045002997775, 0.}, 
      RotationMatrix :> {{-0.7496944920831122, 0.6617840799990918, 
       0.}, {-0.6617840799990918, -0.7496944920831122, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2640567711830703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19548261101416897`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.773993443275447`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20813773997354443`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7496944920831122, 0.6617840799990918, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.055325171769849, 2.140045002997775, 0.}, 
      Optica`Optica`RayEnd :> {3.8871266030435763`, 2.040432289515257, 0.}, 
      RotationMatrix :> {{-0.8604272669249398, -0.5095732708179249, 0.}, {
       0.5095732708179249, -0.8604272669249398, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008733507688182688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19548261101416872`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.063307707576417`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19800392428989697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 74, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8604272669249398, -0.5095732708179249, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.056035109608411, -0.7627206856098533, 0.}, 
      Optica`Optica`RayEnd :> {2.9121687742877462`, -0.8438138098897752, 0.}, 
      RotationMatrix :> {{-0.8711397086299197, -0.49103524114688396`, 0.}, {
       0.49103524114688396`, -0.8711397086299197, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014730378853710223`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16514725926904378`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.538248497311768`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24597539727870438`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8711397086299197, -0.49103524114688396`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9121687742877462`, -0.8438138098897752, 0.},
       Optica`Optica`RayEnd :> {2.7442304120272185`, -0.9084906570121896, 0.},
       RotationMatrix :> {{-0.9331869478602629, -0.3593913192374669, 0.}, {
       0.3593913192374669, -0.9331869478602629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014371721753125401`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1799621851179975, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.804592531286405`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36771310959837716`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9331869478602629, -0.3593913192374669, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.250973596039403, -2.385515828997722, 0.}, 
      Optica`Optica`RayEnd :> {4.141155509164145, -2.4725244263466686`, 0.}, 
      RotationMatrix :> {{-0.7838051307544255, -0.6210068574525064, 0.}, {
       0.6210068574525064, -0.7838051307544255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012448934618477603`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14010891555348262`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.922366360779645`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4146701473950497, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7838051307544255, -0.6210068574525064, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.141155509164145, -2.4725244263466686`, 0.}, 
      Optica`Optica`RayEnd :> {3.9103644313012382`, -2.63264420570771, 0.}, 
      RotationMatrix :> {{-0.8216230753945222, -0.5700311587792786, 0.}, {
       0.5700311587792786, -0.8216230753945222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012388138816846063`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28089653853999463`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.338093237818837`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.406876123041199, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8216230753945222, -0.5700311587792786, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.334963802773455, -2.54581248256604, 0.}, 
      Optica`Optica`RayEnd :> {5.330985085163504, -2.576600492582407, 0.}, 
      RotationMatrix :> {{-0.12816369849168885`, -0.9917530269119077, 0.}, {
       0.9917530269119077, -0.12816369849168885`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008932213596201732, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.031044029290470954`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.600941408846444`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02361974803757773, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.12816369849168885`, -0.9917530269119077, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.330985085163504, -2.576600492582407, 0.}, 
      Optica`Optica`RayEnd :> {5.275954050371112, -2.8917611585853704`, 0.}, 
      RotationMatrix :> {{-0.172010068531061, -0.9850951915038157, 0.}, {
       0.9850951915038157, -0.172010068531061, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008900564346459292, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3199291486966342, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.074436548917463`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1470350690113048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.172010068531061, -0.9850951915038157, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.290875589312144, -2.815415160633884, 0.}, 
      Optica`Optica`RayEnd :> {6.329760945790908, -2.9810678518678104`, 0.}, 
      RotationMatrix :> {{0.22852839080867687`, -0.9735372486938526, 0.}, {
       0.9735372486938526, 0.22852839080867687`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0184893733476573, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17015547320472255`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.381439449217245`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15993778307378792`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.22852839080867687`, -0.9735372486938526, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.329760945790908, -2.9810678518678104`, 0.}, 
      Optica`Optica`RayEnd :> {6.402864922916759, -3.1706687047615048`, 0.}, 
      RotationMatrix :> {{0.35975305977712224`, -0.9330475529044583, 0.}, {
       0.9330475529044583, 0.35975305977712224`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018103943472246403`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20320599127396136`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.682184316302708`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4293661288225574, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.35975305977712224`, -0.9330475529044583, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.709709089406296, -2.50852625996953, 0.}, 
      Optica`Optica`RayEnd :> {6.863121642356406, -2.5485397701708075`, 0.}, 
      RotationMatrix :> {{0.9676282953832779, -0.2523796385876872, 0.}, {
       0.2523796385876872, 0.9676282953832779, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09380790510057467, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1585449223447353, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.512498457667364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3190913811098373, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9676282953832779, -0.2523796385876872, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.863121642356406, -2.5485397701708075`, 0.}, 
      Optica`Optica`RayEnd :> {7.065516021771263, -2.5757373891090496`, 0.}, 
      RotationMatrix :> {{0.9910915693396486, -0.1331822104632304, 0.}, {
       0.1331822104632304, 0.9910915693396486, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.092370580340839, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2042136021293262, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.814734588818768`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.043895313678140584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9910915693396486, -0.1331822104632304, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.529897953148777, -1.3640197673514542`, 0.}, 
      Optica`Optica`RayEnd :> {7.627798623920488, -1.3007128758044786`, 0.}, 
      RotationMatrix :> {{0.8397289580950468, 0.5430057798372013, 
       0.}, {-0.5430057798372013, 0.8397289580950468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013460961609948455`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11658603627746987`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.04278349929982, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16986962536921588`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8397289580950468, 0.5430057798372013, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.627798623920488, -1.3007128758044786`, 0.}, 
      Optica`Optica`RayEnd :> {7.907913549349928, -1.128131966537967, 0.}, 
      RotationMatrix :> {{0.8513834876466261, 0.5245437607699355, 
       0.}, {-0.5245437607699355, 0.8513834876466261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013424507334127814`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3290114613377421, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.529720462079677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1427264254675252, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8513834876466261, 0.5245437607699355, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.41383491331418, -1.3315744125057838`, 0.}, 
      Optica`Optica`RayEnd :> {7.641643426389006, -1.3299004596253732`, 0.}, 
      RotationMatrix :> {{0.999973004027504, 0.0073478715427765275`, 
       0.}, {-0.0073478715427765275`, 0.999973004027504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011018945715766977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22781466315320673`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.680527554270574`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2567152773757342, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.999973004027504, 0.0073478715427765275`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.641643426389006, -1.3299004596253732`, 0.}, 
      Optica`Optica`RayEnd :> {7.9396332096186235`, -1.3113566863266601`, 0.},
       RotationMatrix :> {{0.9980693464507662, 0.062109416961843335`, 
       0.}, {-0.062109416961843335`, 0.9980693464507662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010972780041362174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2985662111448456, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.122405546764945`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2955083537278272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9980693464507662, 0.062109416961843335`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.866810299806632, -1.442451087010559, 0.}, 
      Optica`Optica`RayEnd :> {2.419159283002482, -1.7220162844483655`, 0.}, 
      RotationMatrix :> {{-0.8481827774550288, -0.5297036681283912, 0.}, {
       0.5297036681283912, -0.8481827774550288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1711955592926065, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5277765933273558, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.96786516731079, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4177318517299221, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8481827774550288, -0.5297036681283912, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.419159283002482, -1.7220162844483655`, 0.}, 
      Optica`Optica`RayEnd :> {2.195908819104282, -1.8418698879684676`, 0.}, 
      RotationMatrix :> {{-0.8810604903992962, -0.4730036070236158, 0.}, {
       0.4730036070236158, -0.8810604903992962, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17032709141775013`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25338834998380516`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.342879925286823`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4321142913489444, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8810604903992962, -0.4730036070236158, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.605303873416047, 0.3617660148907954, 0.}, 
      Optica`Optica`RayEnd :> {2.300476159870274, 0.3477845166552455, 0.}, 
      RotationMatrix :> {{-0.9989497711377134, -0.04581871608753076, 0.}, {
       0.04581871608753076, -0.9989497711377134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06327232907177721, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3051481889811156, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.907490983314526`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20647503908971204`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9989497711377134, -0.04581871608753076, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.300476159870274, 0.3477845166552455, 0.}, 
      Optica`Optica`RayEnd :> {2.0921927069666446`, 0.3256054024297014, 0.}, 
      RotationMatrix :> {{-0.9943782110729956, -0.1058866060617143, 0.}, {
       0.1058866060617143, -0.9943782110729956, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0629808306555191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20946099842521557`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.217493260983844`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1990000177496967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9943782110729956, -0.1058866060617143, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1481400246627125`, 2.369639803748075, 0.}, 
      Optica`Optica`RayEnd :> {5.367259958218387, 2.59304855884162, 0.}, 
      RotationMatrix :> {{0.7002208840789133, 0.713926266150605, 
       0.}, {-0.713926266150605, 0.7002208840789133, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01611788145653439, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31292973194295737`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.051313432202473`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24744278357561406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7002208840789133, 0.713926266150605, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.367259958218387, 2.59304855884162, 0.}, 
      Optica`Optica`RayEnd :> {5.507286540201194, 2.678637279603003, 0.}, 
      RotationMatrix :> {{0.8532359548130628, 0.5215250764960783, 
       0.}, {-0.5215250764960783, 0.8532359548130628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014107026393222017`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1641123785195907, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.29419975241147, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2688809953594156, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8532359548130628, 0.5215250764960783, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.811440419389403, 1.8345145594733225`, 0.}, 
      Optica`Optica`RayEnd :> {6.985714678248692, 1.922396766792331, 0.}, 
      RotationMatrix :> {{0.8928950132488656, 0.45026491681598757`, 
       0.}, {-0.45026491681598757`, 0.8928950132488656, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008610879834978966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19517889144119943`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.014531687087985`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19622334658070756`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8928950132488656, 0.45026491681598757`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.985714678248692, 1.922396766792331, 0.}, 
      Optica`Optica`RayEnd :> {7.089412134823265, 2.004929234284356, 0.}, 
      RotationMatrix :> {{0.7824324652537326, 0.6227354472944082, 
       0.}, {-0.6227354472944082, 0.7824324652537326, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00802715695922945, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1325321496481421, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.210679268567233`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32232314721138144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 73, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7824324652537326, 0.6227354472944082, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.114866436608288, 2.87721879600748, 0.}, 
      Optica`Optica`RayEnd :> {2.0728522647269667`, 3.096887373596184, 0.}, 
      RotationMatrix :> {{-0.18785650791297345`, 0.9821964836196181, 
       0.}, {-0.9821964836196181, -0.18785650791297345`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013751129416283115`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22365034008182855`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.493730537063136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08599842168519688, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 72, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18785650791297345`, 0.9821964836196181, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5716690254112136`, -3.0748271865089367`, 
       0.}, Optica`Optica`RayEnd :> {2.599163998917913, -3.2201451736631674`, 
       0.}, RotationMatrix :> {{0.18590721312697273`, -0.9825673046195673, 
       0.}, {0.9825673046195673, 0.18590721312697273`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008092529737647243, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14789621685050403`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.914155062729247`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17662597823506612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 77, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.18590721312697273`, -0.9825673046195673, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7370821451708434`, -2.897242151157988, 0.}, 
      Optica`Optica`RayEnd :> {3.9134400662329862`, -2.9770441415149165`, 0.},
       RotationMatrix :> {{0.9110671280290425, -0.4122580359737234, 0.}, {
       0.4122580359737234, 0.9110671280290425, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02776148526105819, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19357291645860014`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.784538750182284`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23179945281138153`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9110671280290425, -0.4122580359737234, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9134400662329862`, -2.9770441415149165`, 
       0.}, Optica`Optica`RayEnd :> {4.16312011496545, -3.0916553002213503`, 
       0.}, RotationMatrix :> {{0.9088241314719134, -0.417179455455709, 0.}, {
       0.417179455455709, 0.9088241314719134, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02769265687691364, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2747286742134445, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.191137188018182`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3099326494486273, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9088241314719134, -0.417179455455709, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.767724301347901, -1.6731776431117509`, 0.}, 
      Optica`Optica`RayEnd :> {4.05889476923608, -1.7042871649611344`, 0.}, 
      RotationMatrix :> {{0.9943406949998522, -0.10623832767514307`, 0.}, {
       0.10623832767514307`, 0.9943406949998522, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008492719411232584, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2928276689794154, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.530932187678461`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07499872977128523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9943406949998522, -0.10623832767514307`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.05889476923608, -1.7042871649611344`, 0.}, 
      Optica`Optica`RayEnd :> {4.4193349084766895`, -1.7443209047785018`, 0.},
       RotationMatrix :> {{0.993888323284036, -0.11039022076093429`, 0.}, {
       0.11039022076093429`, 0.993888323284036, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00847171375373309, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.36265657901043896`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.06766392461391, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4142802936440285, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.993888323284036, -0.11039022076093429`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.847931087938611, 0.9721552211046295, 0.}, 
      Optica`Optica`RayEnd :> {2.413079136039623, 0.8082127062037942, 0.}, 
      RotationMatrix :> {{-0.935710112544709, -0.35276987581363584`, 0.}, {
       0.35276987581363584`, -0.935710112544709, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010432940465813664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4647293494738316, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.40222731361424, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40532944498584245`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.935710112544709, -0.35276987581363584`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.413079136039623, 0.8082127062037942, 0.}, 
      Optica`Optica`RayEnd :> {2.18705552402088, 0.7293805768078586, 0.}, 
      RotationMatrix :> {{-0.9442174808723289, -0.32932256044054026`, 0.}, {
       0.32932256044054026`, -0.9442174808723289, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01040388742614954, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23937664425565167`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.756504747112604`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2695006764497434, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9442174808723289, -0.32932256044054026`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5075177202934777`, 2.1367499951643203`, 0.},
       Optica`Optica`RayEnd :> {3.45669261763965, 2.226579398023197, 0.}, 
      RotationMatrix :> {{-0.49243876630098304`, 0.8703470925119279, 
       0.}, {-0.8703470925119279, -0.49243876630098304`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4028086886731848, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10321101044827802`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.56565777160907, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4268766833043448, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.49243876630098304`, 0.8703470925119279, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.45669261763965, 2.226579398023197, 0.}, 
      Optica`Optica`RayEnd :> {3.332308243559459, 2.3879252482139632`, 0.}, 
      RotationMatrix :> {{-0.6105497793950628, 0.7919778828228984, 
       0.}, {-0.7919778828228984, -0.6105497793950628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3936760800675188, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20372519699119673`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.867171063156041`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1431473004651249, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6105497793950628, 0.7919778828228984, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.332308243559459, 2.3879252482139632`, 0.}, 
      Optica`Optica`RayEnd :> {3.1486487051213468`, 2.299759893171285, 0.}, 
      RotationMatrix :> {{-0.9015062503341126, -0.43276608070472533`, 0.}, {
       0.43276608070472533`, -0.9015062503341126, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008925551155592217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20372519699119665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.168684354703013`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21407164684317193`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9015062503341126, -0.43276608070472533`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.637363154484737, 2.100095438023548, 0.}, 
      Optica`Optica`RayEnd :> {4.669297845975176, 2.114999261324612, 0.}, 
      RotationMatrix :> {{0.9061726216548176, 0.4229080039006534, 
       0.}, {-0.4229080039006534, 0.9061726216548176, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009621757078802242, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.035241289272370184`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.836489749649122`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3999221001396874, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9061726216548176, 0.4229080039006534, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.669297845975176, 2.114999261324612, 0.}, 
      Optica`Optica`RayEnd :> {4.888010749790684, 2.239795602771776, 0.}, 
      RotationMatrix :> {{0.8685551014139723, 0.4955926107275657, 
       0.}, {-0.4955926107275657, 0.8685551014139723, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009555005386657857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2518123530210715, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.209172032120307`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3968513728229452, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8685551014139723, 0.4955926107275657, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4748039084685063`, -0.6836136830671304, 0.},
       Optica`Optica`RayEnd :> {2.3839809742100564`, -0.7082420446104155, 0.},
       RotationMatrix :> {{-0.9651445870461537, -0.26171726365585657`, 0.}, {
       0.26171726365585657`, -0.9651445870461537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009209044065769745, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0941029307706274, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.227950567722514`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42022969473909666`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9651445870461537, -0.26171726365585657`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3839809742100564`, -0.7082420446104155, 0.},
       Optica`Optica`RayEnd :> {2.074965366139089, -0.7819802989291605, 0.}, 
      RotationMatrix :> {{-0.972690408371029, -0.23210637531744, 0.}, {
       0.23210637531744, -0.972690408371029, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009181855406227324, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31769163693973074`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.698134190393315`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24737728305757323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.972690408371029, -0.23210637531744, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7044712285073365`, -0.8600566613744223, 0.},
       Optica`Optica`RayEnd :> {3.6789730870763115`, -0.8581771474698388, 0.},
       RotationMatrix :> {{-0.9972943061801329, 0.07351235855750864, 
       0.}, {-0.07351235855750864, -0.9972943061801329, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026534290910731333`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02556731876740462, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.849540277367607`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20209266745903298`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9972943061801329, 0.07351235855750864, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6789730870763115`, -0.8581771474698388, 0.},
       Optica`Optica`RayEnd :> {3.4125453660218863`, -0.8593377419620716, 0.},
       RotationMatrix :> {{-0.9999905121892354, -0.004356091311139995, 0.}, {
       0.004356091311139995, -0.9999905121892354, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026363873661098672`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2664302488942087, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.243857045731037`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29149231801926656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999905121892354, -0.004356091311139995, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8477455568113452`, -1.0070624334439158`, 
       0.}, Optica`Optica`RayEnd :> {3.6896996591254667`, -1.035563739061351, 
       0.}, RotationMatrix :> {{-0.9841256844511959, -0.17747291963413825`, 
       0.}, {0.17747291963413825`, -0.9841256844511959, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013423771703164444`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16059523715613003`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.823110004203484`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2557291350339528, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9841256844511959, -0.17747291963413825`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6896996591254667`, -1.035563739061351, 0.}, 
      Optica`Optica`RayEnd :> {3.422089061304332, -1.0631783556271799`, 0.}, 
      RotationMatrix :> {{-0.9947181029425473, -0.10264451119460762`, 0.}, {
       0.10264451119460762`, -0.9947181029425473, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013341396477410651`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2690315950111859, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.22127676482004, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32817394982121334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9947181029425473, -0.10264451119460762`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5831585270802275`, 0.2281089080558495, 0.}, 
      Optica`Optica`RayEnd :> {5.169421741661696, 0.4938376082481516, 0.}, 
      RotationMatrix :> {{-0.841404993684461, 0.5404050671513475, 
       0.}, {-0.5404050671513475, -0.841404993684461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009398668323140206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4917213333935696, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.206209835321287`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32890915867528286`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.841404993684461, 0.5404050671513475, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.169421741661696, 0.4938376082481516, 0.}, 
      Optica`Optica`RayEnd :> {4.9164044126609205`, 0.6481537547206977, 0.}, 
      RotationMatrix :> {{-0.8537402464738157, 0.5206991372672214, 
       0.}, {-0.5206991372672214, -0.8537402464738157, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009372900830459567, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29636336115792616`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.644827609835017`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34665071138695697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8537402464738157, 0.5206991372672214, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.888559142148566, -0.24197956494456557`, 0.},
       Optica`Optica`RayEnd :> {7.960429604410104, -0.1666218653883848, 0.}, 
      RotationMatrix :> {{0.6901647206912055, 0.7236523048489721, 
       0.}, {-0.7236523048489721, 0.6901647206912055, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09859783488484906, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10413523048462901`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.70415289729236, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36423137010786266`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.6901647206912055, 0.7236523048489721, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.960429604410104, -0.1666218653883848, 0.}, 
      Optica`Optica`RayEnd :> {8.150256002333505, 0.05231239248044924, 0.}, 
      RotationMatrix :> {{0.6550948339893427, 0.755546662013985, 
       0.}, {-0.755546662013985, 0.6550948339893427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09823175194889973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2897693403677317, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.133011521036604`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28747412245786774`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.6550948339893427, 0.755546662013985, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.397588857222164, -0.3497113918811222, 0.}, 
      Optica`Optica`RayEnd :> {7.4653602179059835`, -0.18272877991268882`, 
       0.}, RotationMatrix :> {{0.3760658831069337, 0.9265929265664624, 
       0.}, {-0.9265929265664624, 0.3760658831069337, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019538014727289936`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18021140371446168`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.860796735523696`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39341626572882926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3760658831069337, 0.9265929265664624, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4653602179059835`, -0.18272877991268882`, 
       0.}, Optica`Optica`RayEnd :> {7.574921277472411, 0.08747559165130749, 
       0.}, RotationMatrix :> {{0.37576032805796444`, 0.926716880097568, 
       0.}, {-0.926716880097568, 0.37576032805796444`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019489859011447036`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29157165188956974`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.292322780320259`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0674069347873748, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.37576032805796444`, 0.926716880097568, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.341191770303148, -1.1511869589989376`, 0.}, 
      Optica`Optica`RayEnd :> {7.236059442686831, -0.9493030010524817, 0.}, 
      RotationMatrix :> {{-0.46188062005253916`, 0.8869421022929747, 
       0.}, {-0.8869421022929747, -0.46188062005253916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01354265501930516, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2276179667472473, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.552805713117998`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24471093749817607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.46188062005253916`, 0.8869421022929747, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.236059442686831, -0.9493030010524817, 0.}, 
      Optica`Optica`RayEnd :> {7.093124318394603, -0.6399737634313856, 0.}, 
      RotationMatrix :> {{-0.4194640540318645, 0.9077719467879324, 
       0.}, {-0.9077719467879324, -0.4194640540318645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013492489451439745`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34075655093289586`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.057125408498683`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32866065096462793`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4194640540318645, 0.9077719467879324, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.666658242611352, -1.7260979029653378`, 0.}, 
      Optica`Optica`RayEnd :> {7.3802853501272025`, -1.7513157008069478`, 0.},
       RotationMatrix :> {{-0.9961451839411424, -0.08771985243300023, 0.}, {
       0.08771985243300023, -0.9961451839411424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021832719830477885`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.287481079164732, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.920103932471331`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3361350398566757, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9961451839411424, -0.08771985243300023, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3802853501272025`, -1.7513157008069478`, 
       0.}, Optica`Optica`RayEnd :> {7.095556880334739, -1.782516190304264, 
       0.}, RotationMatrix :> {{-0.9940496676374372, -0.10892776629445923`, 
       0.}, {0.10892776629445923`, -0.9940496676374372, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021773850230226044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2864328403923505, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.344024536252011`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04575486992597548, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9940496676374372, -0.10892776629445923`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.823226157153527, -1.930649643545257, 0.}, 
      Optica`Optica`RayEnd :> {7.863139321655691, -1.9772863051707465`, 0.}, 
      RotationMatrix :> {{0.6502172287052222, -0.759748350110022, 0.}, {
       0.759748350110022, 0.6502172287052222, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.1877361888782945`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06138435393605778, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.998374180688206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03569063237363223, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6502172287052222, -0.759748350110022, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.863139321655691, -1.9772863051707465`, 0.}, 
      Optica`Optica`RayEnd :> {8.022041265246742, -2.1317672179825253`, 0.}, 
      RotationMatrix :> {{0.7170109036000785, -0.697061951420818, 0.}, {
       0.697061951420818, 0.7170109036000785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.144021869820614, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.221617192699876, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.326367625884023`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20567912863196453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7170109036000785, -0.697061951420818, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.022041265246742, -2.1317672179825253`, 0.}, 
      Optica`Optica`RayEnd :> {8.147211336256754, -1.948883010289454, 0.}, 
      RotationMatrix :> {{0.5648030709400922, 0.8252257212766947, 
       0.}, {-0.8252257212766947, 0.5648030709400922, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04334596152732044, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22161719269987604`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.65436107107984, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35037400406929997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5648030709400922, 0.8252257212766947, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.898725692883722, -1.6843677998318296`, 0.}, 
      Optica`Optica`RayEnd :> {7.90382085132422, -1.663804587281601, 0.}, 
      RotationMatrix :> {{0.24050726356896748`, 0.9706473387232705, 
       0.}, {-0.9706473387232705, 0.24050726356896748`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021650863687520526`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.021185050151454908`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.325746973640136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3958055555865036, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.24050726356896748`, 0.9706473387232705, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.90382085132422, -1.663804587281601, 0.}, 
      Optica`Optica`RayEnd :> {7.981703858840445, -1.3971231822573906`, 0.}, 
      RotationMatrix :> {{0.28033479538585027`, 0.9599022879939259, 
       0.}, {-0.9599022879939259, 0.28033479538585027`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021577543430302697`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27782140782427006`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.736922657220056`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28752616543910364`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.28033479538585027`, 0.9599022879939259, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.106842406878487, -1.2806810371144008`, 0.}, 
      Optica`Optica`RayEnd :> {6.978182730931252, -1.1631478453094757`, 0.}, 
      RotationMatrix :> {{-0.7383102707158302, 0.6744612250941615, 
       0.}, {-0.6744612250941615, -0.7383102707158302, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013831178686387337`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17426234071279076`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.474411128600346`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1754707155506866, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7383102707158302, 0.6744612250941615, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.978182730931252, -1.1631478453094757`, 0.}, 
      Optica`Optica`RayEnd :> {6.81221724320332, -0.9879310810174107, 0.}, 
      RotationMatrix :> {{-0.6876805730651335, 0.7260133810260038, 
       0.}, {-0.7260133810260038, -0.6876805730651335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013751558650465753`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2413409571658974, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.831595745205874`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10874389157492037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6876805730651335, 0.7260133810260038, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.119803288382871, -1.2507439383342212`, 0.}, 
      Optica`Optica`RayEnd :> {5.918159887220145, -1.2182123801542875`, 0.}, 
      RotationMatrix :> {{-0.9872346325758475, 0.15927266006076196`, 
       0.}, {-0.15927266006076196`, -0.9872346325758475, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019878552871827406`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20425073686546766`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.01091408099537, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40631830944112113`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9872346325758475, 0.15927266006076196`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.918159887220145, -1.2182123801542875`, 0.}, 
      Optica`Optica`RayEnd :> {5.603984831371815, -1.169398971513567, 0.}, 
      RotationMatrix :> {{-0.9881442864571066, 0.15352807281463313`, 
       0.}, {-0.15352807281463313`, -0.9881442864571066, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019829222934472254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3179445149399925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.481471963106557`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10410283406555773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9881442864571066, 0.15352807281463313`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.141316224293418, -1.8963876196907001`, 0.}, 
      Optica`Optica`RayEnd :> {6.137011277797102, -1.8989182429969074`, 0.}, 
      RotationMatrix :> {{-0.8620827921270294, -0.5067674609902111, 0.}, {
       0.5067674609902111, -0.8620827921270294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09562202496234898, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.004993657843110863, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.121496349390402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21852151873018427`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8620827921270294, -0.5067674609902111, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.137011277797102, -1.8989182429969074`, 0.}, 
      Optica`Optica`RayEnd :> {5.930221352069838, -2.022155952212378, 0.}, 
      RotationMatrix :> {{-0.8590216946976411, -0.5119391839259746, 0.}, {
       0.5119391839259746, -0.8590216946976411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09538462304405353, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.240727244729309, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.47777267158978, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23088619338068733`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8590216946976411, -0.5119391839259746, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.909899322736532, -0.39632633971432635`, 0.},
       Optica`Optica`RayEnd :> {4.826113860211855, -0.35923044026463574`, 0.},
       RotationMatrix :> {{-0.914386119633283, 0.40484320943050006`, 
       0.}, {-0.40484320943050006`, -0.914386119633283, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013386051508454167`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09163028694954285, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.938948792537897`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08620884949118782, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.914386119633283, 0.40484320943050006`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.826113860211855, -0.35923044026463574`, 0.},
       Optica`Optica`RayEnd :> {4.561283549930273, -0.227086100596803, 0.}, 
      RotationMatrix :> {{-0.8947928975388386, 0.4464814335602877, 
       0.}, {-0.4464814335602877, -0.8947928975388386, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013337406193758792`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2959682749047379, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.376981839396908`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02586067579105672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8947928975388386, 0.4464814335602877, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.362812811651092, 1.5853767994063988`, 0.}, 
      Optica`Optica`RayEnd :> {6.367294364003814, 1.5983522727364021`, 0.}, 
      RotationMatrix :> {{0.3264627292543668, 0.9452100752783952, 
       0.}, {-0.9452100752783952, 0.3264627292543668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012416183568909675`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.013727607935391082`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.702440359617638`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07274340843747784, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3264627292543668, 0.9452100752783952, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.367294364003814, 1.5983522727364021`, 0.}, 
      Optica`Optica`RayEnd :> {6.407879210301261, 1.8004025358513511`, 0.}, 
      RotationMatrix :> {{0.19693160471978854`, 0.9804172290726477, 
       0.}, {-0.9804172290726477, 0.19693160471978854`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012172288816274489`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20608599800521998`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.007447636665365`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2581219859061583, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19693160471978854`, 0.9804172290726477, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.076721279197129, 2.116419354507405, 0.}, 
      Optica`Optica`RayEnd :> {7.078080013573787, 2.1759753661073877`, 0.}, 
      RotationMatrix :> {{0.022808459965970446`, 0.9997398532388216, 
       0.}, {-0.9997398532388216, 0.022808459965970446`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02560822731052177, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05957150893509081, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.662108505334158`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2915846693027989, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.022808459965970446`, 0.9997398532388216, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.078080013573787, 2.1759753661073877`, 0.}, 
      Optica`Optica`RayEnd :> {7.1079055127338115`, 2.388170150014077, 0.}, 
      RotationMatrix :> {{0.13918896777701611`, 0.990265838676246, 
       0.}, {-0.990265838676246, 0.13918896777701611`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025250848033238505`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2142806260896004, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.979243831946768`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39225619768046444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13918896777701611`, 0.990265838676246, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3223761266728817`, 0.45320832530609795`, 
       0.}, Optica`Optica`RayEnd :> {3.1763382067299815`, 0.4876034430521933, 
       0.}, RotationMatrix :> {{-0.9733677297130519, 0.22924934624390694`, 
       0.}, {-0.22924934624390694`, -0.9733677297130519, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11090948328405656`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15003365684411182`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.357502424636532`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.322699669043745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9733677297130519, 0.22924934624390694`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1763382067299815`, 0.4876034430521933, 0.}, 
      Optica`Optica`RayEnd :> {2.8863540324988484`, 0.559232777351813, 0.}, 
      RotationMatrix :> {{-0.9708213872776642, 0.23980374059691204`, 
       0.}, {-0.23980374059691204`, -0.9708213872776642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11062956885746135`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2986998206171521, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.799578159149917`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06911587041498038, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9708213872776642, 0.23980374059691204`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.5046753581612275`, -1.1223702829451243`, 
       0.}, Optica`Optica`RayEnd :> {4.415850647724226, -1.2065811131300719`, 
       0.}, RotationMatrix :> {{-0.7257033868234058, -0.6880076993413939, 
       0.}, {0.6880076993413939, -0.7257033868234058, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04242247351772829, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12239809273291526`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.565870517311632`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41901292147334795`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7257033868234058, -0.6880076993413939, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.415850647724226, -1.2065811131300719`, 0.}, 
      Optica`Optica`RayEnd :> {4.2133081495809765`, -1.3706139949046245`, 0.},
       RotationMatrix :> {{-0.7771136836854389, -0.6293602486881797, 0.}, {
       0.6293602486881797, -0.7771136836854389, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04214961154879319, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26063432210162296`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.951609314022035`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35393506171583844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7771136836854389, -0.6293602486881797, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.532598262384877, -2.126137966057005, 0.}, 
      Optica`Optica`RayEnd :> {5.5055179968266055`, -2.312780313975175, 0.}, 
      RotationMatrix :> {{-0.14358824289099748`, -0.9896375177323642, 0.}, {
       0.9896375177323642, -0.14358824289099748`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023127321437305916`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1885966776460118, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.615015157473804`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15517412490265503`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.14358824289099748`, -0.9896375177323642, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5055179968266055`, -2.312780313975175, 0.}, 
      Optica`Optica`RayEnd :> {5.458210494903547, -2.6254920219548468`, 0.}, 
      RotationMatrix :> {{-0.1495795547238638, -0.9887496937084785, 0.}, {
       0.9887496937084785, -0.1495795547238638, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02306989640155276, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31626984055670526`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.083094521497728`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28882441172969464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1495795547238638, -0.9887496937084785, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.558502686551672, -1.1361041517412096`, 0.}, 
      Optica`Optica`RayEnd :> {6.641624614133751, -1.2508878463061588`, 0.}, 
      RotationMatrix :> {{0.5865223123234584, -0.8099330695475667, 0.}, {
       0.8099330695475667, 0.5865223123234584, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011944947190359654`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1417199752432235, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.847469211764757`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15117443153664206`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5865223123234584, -0.8099330695475667, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.641624614133751, -1.2508878463061588`, 0.}, 
      Optica`Optica`RayEnd :> {6.796596113038852, -1.4367323507430918`, 0.}, 
      RotationMatrix :> {{0.6404308866499154, -0.7680158067545246, 0.}, {
       0.7680158067545246, 0.6404308866499154, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01188117040879269, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2419800514552863, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.20559968791858, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19338243777125963`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.6404308866499154, -0.7680158067545246, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.7072547024128575`, 1.4150411308714208`, 0.},
       Optica`Optica`RayEnd :> {5.655358674577875, 1.4810432047924222`, 0.}, 
      RotationMatrix :> {{-0.6180958665972741, 0.7861027284619766, 
       0.}, {-0.7861027284619766, -0.6180958665972741, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009634777680724621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0839611306910682, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.232679691042684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2597311724192647, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6180958665972741, 0.7861027284619766, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.655358674577875, 1.4810432047924222`, 0.}, 
      Optica`Optica`RayEnd :> {5.507576983832616, 1.6542440114158796`, 0.}, 
      RotationMatrix :> {{-0.6490777649630646, 0.7607220616168248, 
       0.}, {-0.7607220616168248, -0.6490777649630646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009602697319747713, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22767948421968945`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.569645327687825`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3810406006922477, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6490777649630646, 0.7607220616168248, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.001660413572281, 1.6459442831685513`, 0.}, 
      Optica`Optica`RayEnd :> {7.003201024612557, 1.9257747184821181`, 0.}, 
      RotationMatrix :> {{0.005505432926096704, 0.9999848449893105, 
       0.}, {-0.9999848449893105, 0.005505432926096704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016135310124861718`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27983467621107594`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.155507291100347`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12962972476097526`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.005505432926096704, 0.9999848449893105, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.003201024612557, 1.9257747184821181`, 0.}, 
      Optica`Optica`RayEnd :> {6.9982269963100165`, 2.1711805332934513`, 0.}, 
      RotationMatrix :> {{-0.020264421676917582`, 0.9997946555238727, 
       0.}, {-0.9997946555238727, -0.020264421676917582`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016090017719086726`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24545621788980798`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.518782493577262`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14909077654292677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.020264421676917582`, 0.9997946555238727, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.523807089318023, -1.1364673427704632`, 0.}, 
      Optica`Optica`RayEnd :> {7.578043295185931, -1.389808408822895, 0.}, 
      RotationMatrix :> {{0.2093402672976954, -0.977842856745259, 0.}, {
       0.977842856745259, 0.2093402672976954, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1320861012927029, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25908157359319994`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.136361356196598`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07138421385630347, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.2093402672976954, -0.977842856745259, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.578043295185931, -1.389808408822895, 0.}, 
      Optica`Optica`RayEnd :> {7.601329198023765, -1.6135517013908613`, 0.}, 
      RotationMatrix :> {{0.10351509522683813`, -0.9946278827079895, 0.}, {
       0.9946278827079895, 0.10351509522683813`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1305648895256623, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2249517598066921, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.469289960710503`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.171758696923204, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {0.10351509522683813`, -0.9946278827079895, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.129580112651137, -0.3380120252934028, 0.}, 
      Optica`Optica`RayEnd :> {8.112982644365966, -0.7014769110622621, 0.}, 
      RotationMatrix :> {{-0.04561703479556778, -0.9989590012290094, 0.}, {
       0.9989590012290094, -0.04561703479556778, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04326728760638411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36384364655775864`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.916683119879805`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17479131469489717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.04561703479556778, -0.9989590012290094, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.112982644365966, -0.7014769110622621, 0.}, 
      Optica`Optica`RayEnd :> {8.144168730365307, -0.8780716570571427, 0.}, 
      RotationMatrix :> {{0.17390597004042746`, -0.9847622624696267, 0.}, {
       0.9847622624696267, 0.17390597004042746`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03955961226727557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1793272881436473, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.182087506332403`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3246695159599802, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.17390597004042746`, -0.9847622624696267, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.400837322111133, -0.12973264472074342`, 0.},
       Optica`Optica`RayEnd :> {8.41846620837065, 1.152756908452858, 0.}, 
      RotationMatrix :> {{0.013744533810289991`, 0.9999055394337697, 
       0.}, {-0.9999055394337697, 0.013744533810289991`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04224299909425905, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2826107093074557`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.869414765966624`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11967169524720767`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.013744533810289991`, 0.9999055394337697, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.41846620837065, 1.152756908452858, 0.}, 
      Optica`Optica`RayEnd :> {8.397711101966816, 1.425990015523278, 0.}, 
      RotationMatrix :> {{-0.07574296177570125, 0.9971273758860725, 
       0.}, {-0.9971273758860725, -0.07574296177570125, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04190150848794057, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2740202642893226, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.274964757114823`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04496834886036661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.07574296177570125, 0.9971273758860725, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.380663139819714, -0.09125414151794078, 0.}, 
      Optica`Optica`RayEnd :> {7.153035130388449, 0.03280620533953821, 0.}, 
      RotationMatrix :> {{-0.8780583067374427, 0.47855366467030125`, 
       0.}, {-0.47855366467030125`, -0.8780583067374427, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00881857769514655, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2592401981561465, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.225085361760902`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40737003389731197`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8780583067374427, 0.47855366467030125`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.153035130388449, 0.03280620533953821, 0.}, 
      Optica`Optica`RayEnd :> {6.9578493651101825`, 0.12924088828540214`, 0.},
       RotationMatrix :> {{-0.8965450447166521, 0.4429525739783169, 
       0.}, {-0.4429525739783169, -0.8965450447166521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008789188700428658, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2177088216911108, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.547294417863746`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36654759950546406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8965450447166521, 0.4429525739783169, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.080195487154919, 0.6661707831798577, 0.}, 
      Optica`Optica`RayEnd :> {8.087933797518698, 0.6801485323010795, 0.}, 
      RotationMatrix :> {{0.48434596087168846`, 0.874876557113791, 
       0.}, {-0.874876557113791, 0.48434596087168846`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12323485699175779`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01597682439604313, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.076474375870541`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29097362274858335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.48434596087168846`, 0.874876557113791, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.087933797518698, 0.6801485323010795, 0.}, 
      Optica`Optica`RayEnd :> {8.246315232740649, 0.938381580360709, 0.}, 
      RotationMatrix :> {{0.5228249532863644, 0.8524400672311869, 
       0.}, {-0.8524400672311869, 0.5228249532863644, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12279693417128397`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3029339633206085, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.524816641585042`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18218251749614758`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5228249532863644, 0.8524400672311869, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.825637039936708, -0.5234217821511212, 0.}, 
      Optica`Optica`RayEnd :> {5.652425320378326, -0.5853602408820765, 0.}, 
      RotationMatrix :> {{-0.9416090301801618, -0.3367082331680866, 0.}, {
       0.3367082331680866, -0.9416090301801618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015882234026474134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18395290827366034`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.274450885680507`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34483868575685017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9416090301801618, -0.3367082331680866, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.652425320378326, -0.5853602408820765, 0.}, 
      Optica`Optica`RayEnd :> {5.388581737806026, -0.6601193636767255, 0.}, 
      RotationMatrix :> {{-0.9621234351574744, -0.2726141880401323, 0.}, {
       0.2726141880401323, -0.9621234351574744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015798993829612164`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27423049156797197`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.680312013201105`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3717778607805181, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9621234351574744, -0.2726141880401323, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.091004786913011, 0.7337025154327036, 0.}, 
      Optica`Optica`RayEnd :> {4.850167520404469, 0.8353921946611623, 0.}, 
      RotationMatrix :> {{-0.9212456776211309, 0.3889812353628172, 
       0.}, {-0.3889812353628172, -0.9212456776211309, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009510807498820831, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2614256678310176, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.61358627877169, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10314699846981323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9212456776211309, 0.3889812353628172, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.850167520404469, 0.8353921946611623, 0.}, 
      Optica`Optica`RayEnd :> {4.690582381629045, 0.865765952717761, 0.}, 
      RotationMatrix :> {{-0.9823650457179294, 0.18697303803385784`, 
       0.}, {-0.18697303803385784`, -0.9823650457179294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008799909207814084, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16244993596936924`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.854012184006356`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.384994414323059, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9823650457179294, 0.18697303803385784`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.881191250877583, -0.8861829153964238, 0.}, 
      Optica`Optica`RayEnd :> {6.880779105955508, -0.8939636586819787, 0.}, 
      RotationMatrix :> {{-0.052895709496769625`, -0.9986000420172394, 0.}, {
       0.9986000420172394, -0.052895709496769625`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2743867182782657, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00779165126994914, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.388030009880623`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4315657686709443, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.052895709496769625`, -0.9986000420172394, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.880779105955508, -0.8939636586819787, 0.}, 
      Optica`Optica`RayEnd :> {6.882842248520935, -1.1463896616883769`, 0.}, 
      RotationMatrix :> {{0.0081729838968701, -0.9999666006093506, 0.}, {
       0.9999666006093506, 0.0081729838968701, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.273103411309412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2524344341626779, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.761632972441387`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4303417070310749, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0081729838968701, -0.9999666006093506, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.331543225782122, -0.40876767013290327`, 0.},
       Optica`Optica`RayEnd :> {7.335812371414638, -0.42283003841443123`, 0.},
       RotationMatrix :> {{0.29049483713537644`, -0.9568765592267847, 0.}, {
       0.9568765592267847, 0.29049483713537644`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28741764345854515`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.014696115341033338`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.681527428804163`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18609927342004415`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.29049483713537644`, -0.9568765592267847, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.335812371414638, -0.42283003841443123`, 0.},
       Optica`Optica`RayEnd :> {7.4207183716486735`, -0.620736054269777, 0.}, 
      RotationMatrix :> {{0.39426895496335795`, -0.9189950985462877, 0.}, {
       0.9189950985462877, 0.39426895496335795`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28387955112004487`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21535045852627865`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.000246107423056`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3924311888950628, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.39426895496335795`, -0.9189950985462877, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.548191576253571, 0.30072193789939994`, 0.}, 
      Optica`Optica`RayEnd :> {7.581851068272584, 0.2082720020311536, 0.}, 
      RotationMatrix :> {{0.34211408488869544`, -0.9396584235352599, 0.}, {
       0.9396584235352599, 0.34211408488869544`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3413877946372311, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09838674730379535, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.706084766871113`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.008027904207480617, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.34211408488869544`, -0.9396584235352599, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.581851068272584, 0.2082720020311536, 0.}, 
      Optica`Optica`RayEnd :> {7.675336249011812, 0.05918582749291684, 0.}, 
      RotationMatrix :> {{0.5312501308474284, -0.847215024934396, 0.}, {
       0.847215024934396, 0.5312501308474284, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3160805289196947, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17597206157879594`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.96652341800773, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4180954602671726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5312501308474284, -0.847215024934396, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.675336249011812, 0.05918582749291684, 0.}, 
      Optica`Optica`RayEnd :> {7.850782598441062, 0.07277791814304135, 0.}, 
      RotationMatrix :> {{0.9970125249154337, 0.07724004894969222, 
       0.}, {-0.07724004894969222, 0.9970125249154337, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023431224136205592`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17597206157879647`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.22696206914435, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0487908563198856, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9970125249154337, 0.07724004894969222, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.055504511607546, 1.1912081890792554`, 0.}, 
      Optica`Optica`RayEnd :> {6.983547199606125, 1.1459838153379867`, 0.}, 
      RotationMatrix :> {{-0.8466680200706099, -0.5321214746556583, 0.}, {
       0.5321214746556583, -0.8466680200706099, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20372030763855262`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08498881532742861, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.473884353831872`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3310675485959692, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8466680200706099, -0.5321214746556583, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.983547199606125, 1.1459838153379867`, 0.}, 
      Optica`Optica`RayEnd :> {6.863324853607964, 1.031608164437147, 0.}, 
      RotationMatrix :> {{-0.7245044629513491, -0.689270109001962, 0.}, {
       0.689270109001962, -0.7245044629513491, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19112322792901326`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16593734358574083`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.71947162233877, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12365334157095595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7245044629513491, -0.689270109001962, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.863324853607964, 1.031608164437147, 0.}, 
      Optica`Optica`RayEnd :> {6.914027006419358, 0.8736066021139147, 0.}, 
      RotationMatrix :> {{0.3055499848061395, -0.9521760377078218, 0.}, {
       0.9521760377078218, 0.3055499848061395, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011818137153208003`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16593734358574094`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.965058890845667`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38246465391684215`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3055499848061395, -0.9521760377078218, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.590368247538926, 1.7369085399029403`, 0.}, 
      Optica`Optica`RayEnd :> {7.503845818473073, 1.867324869727871, 0.}, 
      RotationMatrix :> {{-0.552833016831545, 0.8332920589450805, 
       0.}, {-0.8332920589450805, -0.552833016831545, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.38639165020708, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15650734748394624`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.603734575155878`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2223555251897767, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.552833016831545, 0.8332920589450805, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.503845818473073, 1.867324869727871, 0.}, 
      Optica`Optica`RayEnd :> {7.346007987984193, 2.1354637918059716`, 0.}, 
      RotationMatrix :> {{-0.5072804921099433, 0.8617810060129503, 
       0.}, {-0.8617810060129503, -0.5072804921099433, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3806870656860148`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3111450823436584, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.064229297024493`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2696017856103391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5072804921099433, 0.8617810060129503, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.738157029364659, 1.911472297130765, 0.}, 
      Optica`Optica`RayEnd :> {8.066377499692184, 2.2089179863153836`, 0.}, 
      RotationMatrix :> {{0.7409915707070802, 0.6715143275768979, 
       0.}, {-0.6715143275768979, 0.7409915707070802, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      71.04503214625467, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4429476438096654, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.326074025474496`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13153143423847657`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7409915707070802, 0.6715143275768979, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.066377499692184, 2.2089179863153836`, 0.}, 
      Optica`Optica`RayEnd :> {8.279619357017198, 2.3844659508650694`, 0.}, 
      RotationMatrix :> {{0.7720421118333067, 0.6355713788049043, 
       0.}, {-0.6355713788049043, 0.7720421118333067, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      70.78086318727493, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2762049557356987, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.73485735996333, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.032029899424421304`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7720421118333067, 0.6355713788049043, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.279619357017198, 2.3844659508650694`, 0.}, 
      Optica`Optica`RayEnd :> {8.269418053371558, 2.1084494459656544`, 0.}, 
      RotationMatrix :> {{-0.03693381828891451, -0.9993177137760545, 0.}, {
       0.9993177137760545, -0.03693381828891451, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.26318669129995625`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2762049557356987, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.143640694452163`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06877532583830848, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.03693381828891451, -0.9993177137760545, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.932904742021405, 1.7915249845889867`, 0.}, 
      Optica`Optica`RayEnd :> {8.353376858084014, 1.4486758481567938`, 0.}, 
      RotationMatrix :> {{0.7750163029571825, -0.6319412394760926, 0.}, {
       0.6319412394760926, 0.7750163029571825, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.3347862766988072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5425332531176951, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.79802819518941, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0950816393370375, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7750163029571825, -0.6319412394760926, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.353376858084014, 1.4486758481567938`, 0.}, 
      Optica`Optica`RayEnd :> {8.471556087494077, 1.3036155224815655`, 0.}, 
      RotationMatrix :> {{0.6316148986198838, -0.7752822839723563, 0.}, {
       0.7752822839723563, 0.6316148986198838, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2472027523639106`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18710646260607772`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.074945759846404`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39733224814225104`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6316148986198838, -0.7752822839723563, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.471556087494077, 1.3036155224815655`, 0.}, 
      Optica`Optica`RayEnd :> {8.394212442133696, 1.133243022143843, 0.}, 
      RotationMatrix :> {{-0.41336704399791463`, -0.9105644880712325, 0.}, {
       0.9105644880712325, -0.41336704399791463`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08183663146610168, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18710646260607788`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.351863324503398`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03305449866544607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.41336704399791463`, -0.9105644880712325, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.843510263820795, 1.5809955172019488`, 0.}, 
      Optica`Optica`RayEnd :> {7.742433758337944, 1.4098870680789055`, 0.}, 
      RotationMatrix :> {{-0.5086061080389209, -0.8609993187369552, 0.}, {
       0.8609993187369552, -0.5086061080389209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02507781826033543, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19873238619288455`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.675844486752316`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.365149924853263, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5086061080389209, -0.8609993187369552, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.742433758337944, 1.4098870680789055`, 0.}, 
      Optica`Optica`RayEnd :> {7.6564143033686465`, 1.2250070433451765`, 0.}, 
      RotationMatrix :> {{-0.42184664525464016`, -0.9066671979769674, 0.}, {
       0.9066671979769674, -0.42184664525464016`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02483729915265739, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20391167249267317`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.977633762041473`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19685869335172057`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.42184664525464016`, -0.9066671979769674, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.464985043809726, 0.8755865366445774, 0.}, 
      Optica`Optica`RayEnd :> {7.449521888375906, 0.6445117044053194, 0.}, 
      RotationMatrix :> {{-0.06676905737327457, -0.9977684565957592, 0.}, {
       0.9977684565957592, -0.06676905737327457, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20244919280798096`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2315916390338213, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.743824293770079`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28338525963434236`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06676905737327457, -0.9977684565957592, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.449521888375906, 0.6445117044053194, 0.}, 
      Optica`Optica`RayEnd :> {7.430375912009466, 0.283208622726918, 0.}, 
      RotationMatrix :> {{-0.05291720985586097, -0.9985989029140127, 0.}, {
       0.9985989029140127, -0.05291720985586097, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20193058988788956`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36181001263278195`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.279303112466597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32533429090051263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05291720985586097, -0.9985989029140127, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.051399004163451, 1.2658168799102762`, 0.}, 
      Optica`Optica`RayEnd :> {5.9381947141431874`, 1.2479646951500007`, 0.}, 
      RotationMatrix :> {{-0.9877927582059827, -0.15577376812485502`, 0.}, {
       0.15577376812485502`, -0.9877927582059827, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.338822117598471, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11460327996923562`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.77237295005277, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42577419628540886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9877927582059827, -0.15577376812485502`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.9381947141431874`, 1.2479646951500007`, 0.},
       Optica`Optica`RayEnd :> {5.585010064392459, 1.196668184852395, 0.}, 
      RotationMatrix :> {{-0.9896166714303332, -0.1437318462524819, 0.}, {
       0.1437318462524819, -0.9896166714303332, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3379617789708981, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3568903596179884, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.300570682287393`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1286354027315862, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9896166714303332, -0.1437318462524819, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.348678083172981, 0.9374527928655113, 0.}, 
      Optica`Optica`RayEnd :> {5.146843271438939, 0.915336947551428, 0.}, 
      RotationMatrix :> {{-0.9940502934311412, -0.10892205529396426`, 0.}, {
       0.10892205529396426`, -0.9940502934311412, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28998049110459306`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20304285715501708`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.107969882599367`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24217716877345224`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9940502934311412, -0.10892205529396426`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.146843271438939, 0.915336947551428, 0.}, 
      Optica`Optica`RayEnd :> {4.869019545342316, 0.9045133912008863, 0.}, 
      RotationMatrix :> {{-0.9992419858973441, -0.03892882762081214, 0.}, {
       0.03892882762081214, -0.9992419858973441, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28837576716301516`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2780344801536043, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.519460913226702`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29029366928223693`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9992419858973441, -0.03892882762081214, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.363292513720586, 1.1077631715094527`, 0.}, 
      Optica`Optica`RayEnd :> {4.180835378956244, 1.1009827641266325`, 0.}, 
      RotationMatrix :> {{-0.999310220398237, -0.037136012274155875`, 0.}, {
       0.037136012274155875`, -0.999310220398237, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2918340016377845, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18258307684637706`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.67165839003285, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3078641541893153, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999310220398237, -0.037136012274155875`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.180835378956244, 1.1009827641266325`, 0.}, 
      Optica`Optica`RayEnd :> {3.8802831926153463`, 1.0795703200884155`, 0.}, 
      RotationMatrix :> {{-0.9974717891678294, -0.07106356179033355, 0.}, {
       0.07106356179033355, -0.9974717891678294, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2909368741618161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30131397158775025`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.11760306798272, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11964794127866395`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9974717891678294, -0.07106356179033355, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.544058705200856, -1.1397096353662313`, 0.}, 
      Optica`Optica`RayEnd :> {6.585515200998242, -1.3922282078274029`, 0.}, 
      RotationMatrix :> {{0.1620033863814059, -0.9867902020191301, 0.}, {
       0.9867902020191301, 0.1620033863814059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009285699474774697, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2558989458392252, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.807102521584008`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08797364913753557, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1620033863814059, -0.9867902020191301, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.585515200998242, -1.3922282078274029`, 0.}, 
      Optica`Optica`RayEnd :> {6.613447268885137, -1.6437226269738707`, 0.}, 
      RotationMatrix :> {{0.11038563181077117`, -0.9938888329635944, 0.}, {
       0.9938888329635944, 0.11038563181077117`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009248513187835832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2530407937038165, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.181602896265655`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.022169775740473355`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.11038563181077117`, -0.9938888329635944, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.023459793219201, 2.629803328498619, 0.}, 
      Optica`Optica`RayEnd :> {7.10368184781019, 2.848736495535804, 0.}, 
      RotationMatrix :> {{0.3440526119583747, 0.9389503715344166, 
       0.}, {-0.9389503715344166, 0.3440526119583747, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1825703294057307, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23316798594946855`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.689173302424585`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0009243123761599743, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3440526119583747, 0.9389503715344166, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.10368184781019, 2.848736495535804, 0.}, 
      Optica`Optica`RayEnd :> {7.1516229963101905`, 3.04052253545903, 0.}, 
      RotationMatrix :> {{0.24251009927874215`, 0.9701488812279349, 
       0.}, {-0.9701488812279349, 0.24251009927874215`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18050619647547012`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19768722474892614`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.981750395052996`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23445490686064063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.24251009927874215`, 0.9701488812279349, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.42157587195393, 2.311129214326098, 0.}, 
      Optica`Optica`RayEnd :> {6.428421427838424, 2.3501891946211466`, 0.}, 
      RotationMatrix :> {{0.1726264578406715, 0.9849873633978163, 
       0.}, {-0.9849873633978163, 0.1726264578406715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.093642436100311, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03965531106948152, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.913859893636163`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3424804034714952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1726264578406715, 0.9849873633978163, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.428421427838424, 2.3501891946211466`, 0.}, 
      Optica`Optica`RayEnd :> {6.488034289750155, 2.6797783985379304`, 0.}, 
      RotationMatrix :> {{0.17798235830250506`, 0.9840336783530723, 
       0.}, {-0.9840336783530723, 0.17798235830250506`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09341025455145736, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33493691442390494`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.409566526983543`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19317845810091397`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17798235830250506`, 0.9840336783530723, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.105130303168906, 2.32777283886906, 0.}, 
      Optica`Optica`RayEnd :> {4.973860009185009, 2.4233855638274715`, 0.}, 
      RotationMatrix :> {{-0.8083157941629097, 0.5887491629775654, 
       0.}, {-0.5887491629775654, -0.8083157941629097, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      2.99864776461476, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16239976372086096`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.806392755170446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4199910842474747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8083157941629097, 0.5887491629775654, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.973860009185009, 2.4233855638274715`, 0.}, 
      Optica`Optica`RayEnd :> {4.911576044151911, 2.523739366932794, 0.}, 
      RotationMatrix :> {{-0.5273347317536183, 0.8496576255682865, 
       0.}, {-0.8496576255682865, -0.5273347317536183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.1357602968139426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11811087205649655`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.981196845814061`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05671313101578396, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5273347317536183, 0.8496576255682865, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.911576044151911, 2.523739366932794, 0.}, 
      Optica`Optica`RayEnd :> {4.949638783966609, 2.6355490531667902`, 0.}, 
      RotationMatrix :> {{0.32226279555782045`, 0.9466502472398438, 
       0.}, {-0.9466502472398438, 0.32226279555782045`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.7055825790302638, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649673`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.156000936457676`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34803479790858977`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.32226279555782045`, 0.9466502472398438, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.949638783966609, 2.6355490531667902`, 0.}, 
      Optica`Optica`RayEnd :> {5.0602158577717615`, 2.677056749400575, 0.}, 
      RotationMatrix :> {{0.9362141848572478, 0.3514299362206897, 
       0.}, {-0.3514299362206897, 0.9362141848572478, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.4383378933279654, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649688`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.33080502710129, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2133799816414947, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9362141848572478, 0.3514299362206897, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0602158577717615`, 2.677056749400575, 0.}, 
      Optica`Optica`RayEnd :> {5.162450707646214, 2.6179110515934285`, 0.}, 
      RotationMatrix :> {{0.8655837358101117, -0.5007642122805998, 0.}, {
       0.5007642122805998, 0.8655837358101117, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2723141336500434, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649717`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.505609117744907`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21417789671618312`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8655837358101117, -0.5007642122805998, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.162450707646214, 2.6179110515934285`, 0.}, 
      Optica`Optica`RayEnd :> {5.18158680607505, 2.5013606855070525`, 0.}, 
      RotationMatrix :> {{0.16201809448736626`, -0.9867877872464178, 0.}, {
       0.9867877872464178, 0.16201809448736626`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1691731162518658, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649728`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.680413208388522`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3474005277571894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.16201809448736626`, -0.9867877872464178, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.18158680607505, 2.5013606855070525`, 0.}, 
      Optica`Optica`RayEnd :> {5.1036313876707275`, 2.412630020912711, 0.}, 
      RotationMatrix :> {{-0.6600189893359888, -0.7512489159498992, 0.}, {
       0.7512489159498992, -0.6600189893359888, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10509753158513789`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649771`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.855217299032137`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05759000721346179, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6600189893359888, -0.7512489159498992, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1036313876707275`, 2.412630020912711, 0.}, 
      Optica`Optica`RayEnd :> {4.985587288433265, 2.416601007334562, 0.}, 
      RotationMatrix :> {{-0.9994346598422919, 0.03362083737685828, 
       0.}, {-0.03362083737685828, -0.9994346598422919, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06529105445361282, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649808`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.030021389675756`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4204693739853585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9994346598422919, 0.03362083737685828, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.985587288433265, 2.416601007334562, 0.}, 
      Optica`Optica`RayEnd :> {4.913771130957169, 2.5103699660752623`, 0.}, 
      RotationMatrix :> {{-0.6080401933002588, 0.7939062434137816, 
       0.}, {-0.7939062434137816, -0.6080401933002588, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.040561578634327314`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649821`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.204825480319375`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10510998723020021`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6080401933002588, 0.7939062434137816, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.913771130957169, 2.5103699660752623`, 0.}, 
      Optica`Optica`RayEnd :> {4.9406965792129025`, 2.6253708283945265`, 0.}, 
      RotationMatrix :> {{0.22796756798860668`, 0.973668725976838, 
       0.}, {-0.973668725976838, 0.22796756798860668`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025198576973167956`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649846`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.379629570962994`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3111899096394381, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22796756798860668`, 0.973668725976838, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.9406965792129025`, 2.6253708283945265`, 0.},
       Optica`Optica`RayEnd :> {5.046675111958901, 2.677512258130888, 0.}, 
      RotationMatrix :> {{0.8972800801547143, 0.44146172853096544`, 
       0.}, {-0.44146172853096544`, 0.8972800801547143, 0.}, {0., 0., 
       0.9999999999999994}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01565442724004946, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649877`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.554433661606613`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2566545173254848, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8972800801547143, 0.44146172853096544`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.046675111958901, 2.677512258130888, 0.}, 
      Optica`Optica`RayEnd :> {5.154212732686672, 2.6286672151259234`, 0.}, 
      RotationMatrix :> {{0.9104802873382325, -0.4135524711188265, 0.}, {
       0.4135524711188265, 0.9104802873382325, 0.}, {0., 0., 
       0.9999999999999993}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009725195691602856, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11811087205649919`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.72923775225023, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16888344154216936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 88, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9104802873382325, -0.4135524711188265, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.851961525503718, 0.934645522777102, 0.}, 
      Optica`Optica`RayEnd :> {4.424351740191631, 0.7706489542266817, 0.}, 
      RotationMatrix :> {{-0.9336880995517444, -0.35808732560012607`, 0.}, {
       0.35808732560012607`, -0.9336880995517444, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08418785625681557, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.45797926043758985`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.591503013556213`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3884436120195187, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9336880995517444, -0.35808732560012607`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.424351740191631, 0.7706489542266817, 0.}, 
      Optica`Optica`RayEnd :> {4.1188388464948025`, 0.6604338486612473, 0.}, 
      RotationMatrix :> {{-0.9406610586110866, -0.33934756933366816`, 0.}, {
       0.33934756933366816`, -0.9406610586110866, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08396323415536613, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32478531018167933`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.0721852726251, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2549014990698939, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9406610586110866, -0.33934756933366816`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.518103669062487, 1.1512149591504777`, 0.}, 
      Optica`Optica`RayEnd :> {5.398525796497053, 1.2200248889577248`, 0.}, 
      RotationMatrix :> {{-0.8667413351073741, 0.4987579152417394, 
       0.}, {-0.4987579152417394, -0.8667413351073741, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037951337895498025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13796258205525613`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.813637456863658`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39652744288799957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8667413351073741, 0.4987579152417394, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.398525796497053, 1.2200248889577248`, 0.}, 
      Optica`Optica`RayEnd :> {5.143855725421484, 1.3816868608239041`, 0.}, 
      RotationMatrix :> {{-0.8442627822724414, 0.5359294304939741, 
       0.}, {-0.5359294304939741, -0.8442627822724414, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03781867161783675, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30164787128255516`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.217845604382282`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42068866342773364`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8442627822724414, 0.5359294304939741, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.461139648466303, 1.1443863509174352`, 0.}, 
      Optica`Optica`RayEnd :> {5.3780326268083885`, 1.1592845253399489`, 0.}, 
      RotationMatrix :> {{-0.9843092237170148, 0.17645212411758365`, 
       0.}, {-0.17645212411758365`, -0.9843092237170148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09214180901971822, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08443182249586224, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.811290215925283`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2518142899996523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9843092237170148, 0.17645212411758365`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3780326268083885`, 1.1592845253399489`, 0.},
       Optica`Optica`RayEnd :> {5.072201536619233, 1.2023600096651306`, 0.}, 
      RotationMatrix :> {{-0.9902261997419257, 0.13947068991248052`, 
       0.}, {-0.13947068991248052`, -0.9902261997419257, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09184567454461695, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3088497257180846, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.225148848387516`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11863276947128498`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9902261997419257, 0.13947068991248052`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.409836078855042, 1.1187061391187512`, 0.}, 
      Optica`Optica`RayEnd :> {5.327993242796761, 1.1048759326021627`, 0.}, 
      RotationMatrix :> {{-0.9860207359744215, -0.1666226522068942, 0.}, {
       0.1666226522068942, -0.9860207359744215, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02199517103167116, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0830031591347835, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.886054077360413`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03966782184469018, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 77, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9860207359744215, -0.1666226522068942, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.900457870164396, -0.10167967351866608`, 0.},
       Optica`Optica`RayEnd :> {5.924279037284031, -0.35385045836149054`, 0.},
       RotationMatrix :> {{0.09404574284126331, -0.9955678772707737, 0.}, {
       0.9955678772707737, 0.09404574284126331, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008450040797966445, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2532934123327878, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.242373781053065`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3433015581739146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09404574284126331, -0.9955678772707737, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.924279037284031, -0.35385045836149054`, 0.},
       Optica`Optica`RayEnd :> {5.953065952582621, -0.6208304854292546, 0.}, 
      RotationMatrix :> {{0.10720285513377549`, -0.9942371688139435, 0.}, {
       0.9942371688139435, 0.10720285513377549`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008428470707011719, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26852750575222684`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.63979448956636, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25792000676534116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10720285513377549`, -0.9942371688139435, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5649167357676115`, -0.1860555186724132, 0.},
       Optica`Optica`RayEnd :> {7.598560623249983, -0.21481323580048364`, 0.},
       RotationMatrix :> {{0.7601479057897611, -0.6497500760472753, 0.}, {
       0.6497500760472753, 0.7601479057897611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009275665482763417, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04425965950326113, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.800482988110717`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06934719834630042, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7601479057897611, -0.6497500760472753, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.598560623249983, -0.21481323580048364`, 0.},
       Optica`Optica`RayEnd :> {7.8015864440438545`, -0.3685024860381718, 0.},
       RotationMatrix :> {{0.7973155032407722, -0.6035627459443745, 0.}, {
       0.6035627459443745, 0.7973155032407722, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009233652315384836, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25463674037272743`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.177345363862354`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05468217309789174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7973155032407722, -0.6035627459443745, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.338030659768891, 1.0456952774415846`, 0.}, 
      Optica`Optica`RayEnd :> {4.184804334084109, 1.0900086345508422`, 0.}, 
      RotationMatrix :> {{-0.9606339470634645, 0.277817241634259, 
       0.}, {-0.277817241634259, -0.9606339470634645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15988142485899107`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1595054246762524, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.742016599029856`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3360451726634594, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9606339470634645, 0.277817241634259, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.184804334084109, 1.0900086345508422`, 0.}, 
      Optica`Optica`RayEnd :> {3.9180161944865612`, 1.1494482120242693`, 0.}, 
      RotationMatrix :> {{-0.9760681243452357, 0.21746497795546982`, 
       0.}, {-0.21746497795546982`, -0.9760681243452357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1591171623905866, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2733294254194742, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.14654414865068, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34030775887257386`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9760681243452357, 0.21746497795546982`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6682505014656734`, -1.260811247870144, 0.}, 
      Optica`Optica`RayEnd :> {3.515237747523003, -1.3299214132440937`, 0.}, 
      RotationMatrix :> {{-0.9113535491993664, -0.4116244749303874, 0.}, {
       0.4116244749303874, -0.9113535491993664, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1913239853583196, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16789615191282636`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47638453625879, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26551937528666164`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9113535491993664, -0.4116244749303874, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.515237747523003, -1.3299214132440937`, 0.}, 
      Optica`Optica`RayEnd :> {3.3631369823812154`, -1.436960415300968, 0.}, 
      RotationMatrix :> {{-0.8177934369899713, -0.5755118542794134, 0.}, {
       0.5755118542794134, -0.8177934369899713, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18133119751960128`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1859892220480766, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.751648584889946`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18572195727246302`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8177934369899713, -0.5755118542794134, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3631369823812154`, -1.436960415300968, 0.}, 
      Optica`Optica`RayEnd :> {3.3994379955641585`, -1.6193726603941647`, 0.},
       RotationMatrix :> {{0.19517804732555738`, -0.980767826675703, 0.}, {
       0.980767826675703, 0.19517804732555738`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009470867868241547, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18598922204807655`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.0269126335211, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34930096776510017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.19517804732555738`, -0.980767826675703, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8700807173829546`, 1.4673964527622854`, 0.},
       Optica`Optica`RayEnd :> {3.8010335980801604`, 1.619771714514598, 0.}, 
      RotationMatrix :> {{-0.4127406867748857, 0.9108485743967519, 
       0.}, {-0.9108485743967519, -0.4127406867748857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043666428612270575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16728934538128862`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.651533545614766`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16473589756409163`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4127406867748857, 0.9108485743967519, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8010335980801604`, 1.619771714514598, 0.}, 
      Optica`Optica`RayEnd :> {3.6764578941698423`, 1.912287471595425, 0.}, 
      RotationMatrix :> {{-0.39182388545016567`, 0.9200402397671176, 
       0.}, {-0.9200402397671176, -0.39182388545016567`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043547136433508146`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31793800361913416`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.122081790971086`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40770141397134113`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.39182388545016567`, 0.9200402397671176, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.379052243606461, 0.6990117450102403, 0.}, 
      Optica`Optica`RayEnd :> {7.634981857793197, 0.8273299019140062, 0.}, 
      RotationMatrix :> {{0.893932961776235, 0.4482006914876052, 
       0.}, {-0.4482006914876052, 0.893932961776235, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08305120407046669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28629620467088107`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.12305773283712, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20557137907765444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.893932961776235, 0.4482006914876052, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.634981857793197, 0.8273299019140062, 0.}, 
      Optica`Optica`RayEnd :> {7.8600772293281915`, 0.9108912178091552, 0.}, 
      RotationMatrix :> {{0.9374871593797277, 0.34801986437289506`, 
       0.}, {-0.34801986437289506`, 0.9374871593797277, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08205377451641607, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24010501827451688`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.478413159883406`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0436573213540275, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9374871593797277, 0.34801986437289506`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.842566133514247, 1.440068636143774, 0.}, 
      Optica`Optica`RayEnd :> {4.720940674311308, 1.5505265746309072`, 0.}, 
      RotationMatrix :> {{-0.7402752269538942, 0.6723039404602349, 
       0.}, {-0.6723039404602349, -0.7402752269538942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05142209521165748, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16429762171484166`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.82755231150442, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2384239020680438, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7402752269538942, 0.6723039404602349, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.720940674311308, 1.5505265746309072`, 0.}, 
      Optica`Optica`RayEnd :> {4.563509470794093, 1.7232149979237499`, 0.}, 
      RotationMatrix :> {{-0.673707106878165, 0.7389984669414758, 
       0.}, {-0.7389984669414758, -0.673707106878165, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05096531262506663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2336790007258816, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.173397232578724`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05931126402142739, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.673707106878165, 0.7389984669414758, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.588794290327433, 0.7038109943929166, 0.}, 
      Optica`Optica`RayEnd :> {4.405729173165847, 0.664674750076516, 0.}, 
      RotationMatrix :> {{-0.9779029828102619, -0.20905921699554758`, 0.}, {
       0.20905921699554758`, -0.9779029828102619, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012963866336481724`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18720171671375826`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.061364494437905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.257841331174208, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9779029828102619, -0.20905921699554758`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.405729173165847, 0.664674750076516, 0.}, 
      Optica`Optica`RayEnd :> {4.1420754931227135`, 0.6299410302479087, 0.}, 
      RotationMatrix :> {{-0.9914336388450469, -0.13061140748980546`, 0.}, {
       0.13061140748980546`, -0.9914336388450469, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012877801990218384`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2659317474342229, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.454943480640555`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3471204228680364, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9914336388450469, -0.13061140748980546`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0400177056328745`, -0.6635405089458228, 0.},
       Optica`Optica`RayEnd :> {4.818081978692056, -1.098864073309862, 0.}, 
      RotationMatrix :> {{-0.45419730185583845`, -0.8909011230135894, 0.}, {
       0.8909011230135894, -0.45419730185583845`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008070172716757851, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.48863286072813555`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.274897097026136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11881300353489305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.45419730185583845`, -0.8909011230135894, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.818081978692056, -1.098864073309862, 0.}, 
      Optica`Optica`RayEnd :> {4.6730830867006965`, -1.3644129827131524`, 0.},
       RotationMatrix :> {{-0.47924444759406676`, -0.8776814681023271, 0.}, {
       0.8776814681023271, -0.47924444759406676`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008046922784696818, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3025572705522026, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.722681857443396`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34433972769576576`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.47924444759406676`, -0.8776814681023271, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.021149725198444, -0.07154571447836386, 0.}, 
      Optica`Optica`RayEnd :> {7.098059280499725, -0.2388328067404872, 0.}, 
      RotationMatrix :> {{0.4177150518985496, -0.9085780843809691, 0.}, {
       0.9085780843809691, 0.4177150518985496, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009314174107381465, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1841196647133516, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.295941868626253`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15236421645060802`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4177150518985496, -0.9085780843809691, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.098059280499725, -0.2388328067404872, 0.}, 
      Optica`Optica`RayEnd :> {7.212311557604752, -0.4341530931148644, 0.}, 
      RotationMatrix :> {{0.5049107632945319, -0.8631715479030415, 0.}, {
       0.8631715479030415, 0.5049107632945319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009224364734456833, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.226282118367874, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.630839403810706`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33201084514457474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5049107632945319, -0.8631715479030415, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.728774910946679, 2.3223324043258624`, 0.}, 
      Optica`Optica`RayEnd :> {5.6539520195670985`, 2.4117933223224775`, 0.}, 
      RotationMatrix :> {{-0.641560410640963, 0.7670725125424569, 
       0.}, {-0.7670725125424569, -0.641560410640963, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18977331985818377`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11662641606084558`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.30480886337932, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21176477877069377`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.641560410640963, 0.7670725125424569, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.6539520195670985`, 2.4117933223224775`, 0.},
       Optica`Optica`RayEnd :> {5.435909779053422, 2.6593680888455133`, 0.}, 
      RotationMatrix :> {{-0.6609292633781169, 0.750448205281656, 
       0.}, {-0.750448205281656, -0.6609292633781169, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18924189136883612`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3299025366182558, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.793064617574338`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4225560099967061, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6609292633781169, 0.750448205281656, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.6258440355301405`, 1.8689699323790148`, 0.},
       Optica`Optica`RayEnd :> {6.697475812834526, 1.8279146946195524`, 0.}, 
      RotationMatrix :> {{0.8676017472591461, -0.49725969890277216`, 0.}, {
       0.49725969890277216`, 0.8676017472591461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03382484285031562, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08256297031521495, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.322083705716674`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42410882006911516`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8676017472591461, -0.49725969890277216`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.697475812834526, 1.8279146946195524`, 0.}, 
      Optica`Optica`RayEnd :> {6.8978100437530285`, 1.696982269817469, 0.}, 
      RotationMatrix :> {{0.837075512912143, -0.5470873656765174, 0.}, {
       0.5470873656765174, 0.837075512912143, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033673916425846, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23932635446657577`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.676286710327206`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41278743980301075`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.837075512912143, -0.5470873656765174, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.472040952293647, 2.3458184217531763`, 0.}, 
      Optica`Optica`RayEnd :> {6.577898380087658, 2.1413614120070266`, 0.}, 
      RotationMatrix :> {{0.4597785724559023, -0.8880335941339221, 0.}, {
       0.8880335941339221, 0.4597785724559023, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014145852204755924`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23023567024573188`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.464337707390037`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07725327014695917, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4597785724559023, -0.8880335941339221, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.577898380087658, 2.1413614120070266`, 0.}, 
      Optica`Optica`RayEnd :> {6.665193389335898, 1.9205603235213684`, 0.}, 
      RotationMatrix :> {{0.36766455575464896`, -0.929958479955818, 0.}, {
       0.929958479955818, 0.36766455575464896`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014001271585279368`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2374311254155649, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.815735773005073`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2814394980199925, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36766455575464896`, -0.929958479955818, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.583810886957185, 2.633564846050262, 0.}, 
      Optica`Optica`RayEnd :> {6.585555138189024, 2.638730032428786, 0.}, 
      RotationMatrix :> {{0.31994344624651766`, 0.9474366423164667, 
       0.}, {-0.9474366423164667, 0.31994344624651766`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.935870919486937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005451748589642052, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.619990866109463`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2982527551791751, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.31994344624651766`, 0.9474366423164667, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.585555138189024, 2.638730032428786, 0.}, 
      Optica`Optica`RayEnd :> {6.692367912281009, 2.8987001271996897`, 0.}, 
      RotationMatrix :> {{0.38003862587697507`, 0.9249706172855111, 
       0.}, {-0.9249706172855111, 0.38003862587697507`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.9164072744211462`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2810576789280412, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.035956230922963`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31267457278251465`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.38003862587697507`, 0.9249706172855111, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.692367912281009, 2.8987001271996897`, 0.}, 
      Optica`Optica`RayEnd :> {6.872093610858287, 2.6826165966951008`, 0.}, 
      RotationMatrix :> {{0.6394619754306459, -0.7688227246760692, 0.}, {
       0.7688227246760692, 0.6394619754306459, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019367393565932853`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2810576789280412, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.451921595736463`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3266812722080029, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6394619754306459, -0.7688227246760692, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.299114145669607, 2.5142405463846695`, 0.}, 
      Optica`Optica`RayEnd :> {6.215984381681101, 2.4749307830443343`, 0.}, 
      RotationMatrix :> {{-0.904021599748348, -0.42748678013294916`, 0.}, {
       0.42748678013294916`, -0.904021599748348, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014045073976597542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09195550638574033, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.192769515294822`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4119881020004386, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.904021599748348, -0.42748678013294916`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.215984381681101, 2.4749307830443343`, 0.}, 
      Optica`Optica`RayEnd :> {5.939781396097772, 2.361951907883309, 0.}, 
      RotationMatrix :> {{-0.9255625216682942, -0.37859479457994005`, 0.}, {
       0.37859479457994005`, -0.9255625216682942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013987573944107053`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2984163458622785, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.634425707170994`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3774034803713181, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9255625216682942, -0.37859479457994005`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8856226064772645`, 2.454866553037327, 0.}, 
      Optica`Optica`RayEnd :> {5.683048452564097, 2.531613486608514, 0.}, 
      RotationMatrix :> {{-0.9351375769650296, 0.35428478960854654`, 
       0.}, {-0.35428478960854654`, -0.9351375769650296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033159707030700245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2166249746594699, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.200303405109867`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39591031719591274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9351375769650296, 0.35428478960854654`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.683048452564097, 2.531613486608514, 0.}, 
      Optica`Optica`RayEnd :> {5.391351704172249, 2.625593379193287, 0.}, 
      RotationMatrix :> {{-0.9518189895454611, 0.30666041665114885`, 
       0.}, {-0.30666041665114885`, -0.9518189895454611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03303044008086781, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.306462417324902, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.653867782750723`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34329127605646426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9518189895454611, 0.30666041665114885`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.354603703684484, 1.6013214427552687`, 0.}, 
      Optica`Optica`RayEnd :> {7.356213552333505, 1.6010458639601983`, 0.}, 
      RotationMatrix :> {{0.985662529018893, -0.1687287138814219, 0.}, {
       0.1687287138814219, 0.985662529018893, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17613864729749557`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001633265546396514, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.07433318231679, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28117393291136483`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.985662529018893, -0.1687287138814219, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.356213552333505, 1.6010458639601983`, 0.}, 
      Optica`Optica`RayEnd :> {7.653693099468152, 1.5369387176341482`, 0.}, 
      RotationMatrix :> {{0.9775583522657434, -0.2106648236310075, 0.}, {
       0.2106648236310075, 0.9775583522657434, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17552946217379214`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3043087366039695, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.524710112490665`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38360668169202117`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9775583522657434, -0.2106648236310075, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.161374580802137, 0.6278061110068232, 0.}, 
      Optica`Optica`RayEnd :> {5.155851148044681, 0.62117069692608, 0.}, 
      RotationMatrix :> {{-0.6397687619377657, -0.7685674539353179, 0.}, {
       0.7685674539353179, -0.6397687619377657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01272723329937115, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008633483042728039, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.100032155443193`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24215262722774614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6397687619377657, -0.7685674539353179, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.155851148044681, 0.62117069692608, 0.}, 
      Optica`Optica`RayEnd :> {4.963243164986898, 0.40461823168334243`, 0.}, 
      RotationMatrix :> {{-0.664589139688411, -0.7472089904492693, 0.}, {
       0.7472089904492693, -0.664589139688411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012688689233488683`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28981512269081816`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.528958537025604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40621819769638495`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.664589139688411, -0.7472089904492693, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.929742957745927, 0.6652030754613594, 0.}, 
      Optica`Optica`RayEnd :> {7.943743831431117, 0.6599192684195407, 0.}, 
      RotationMatrix :> {{0.9355915983682046, -0.3530840708143414, 0.}, {
       0.3530840708143414, 0.9355915983682046, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08141766170943962, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01496472788940086, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.174537875725788`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4184286972307555, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9355915983682046, -0.3530840708143414, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.943743831431117, 0.6599192684195407, 0.}, 
      Optica`Optica`RayEnd :> {8.18182694304322, 0.5465277883779298, 0.}, 
      RotationMatrix :> {{0.9028331827585994, -0.4299909814286531, 0.}, {
       0.4299909814286531, 0.9028331827585994, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08083291346468757, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2637066472065659, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.564823713591505`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37007219395645174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9028331827585994, -0.4299909814286531, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.934429269750753, 1.1647759852781359`, 0.}, 
      Optica`Optica`RayEnd :> {3.8711843852292245`, 1.1630018869658185`, 0.}, 
      RotationMatrix :> {{-0.9996067956140623, -0.02804022400382912, 0.}, {
       0.02804022400382912, -0.9996067956140623, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08873510210998069, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06326976246962861, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.819535435939782`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.003169483831530707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9996067956140623, -0.02804022400382912, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8711843852292245`, 1.1630018869658185`, 0.},
       Optica`Optica`RayEnd :> {3.693844003873882, 1.1857485126662142`, 0.}, 
      RotationMatrix :> {{-0.9918741290460972, 0.12722308017433315`, 
       0.}, {-0.12722308017433315`, -0.9918741290460972, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08613915523312513, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1787932320867104, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.084149419428114`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35811985627318654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9918741290460972, 0.12722308017433315`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.201877408545196, 2.010677723111943, 0.}, 
      Optica`Optica`RayEnd :> {4.220711907001162, 2.085100957738307, 0.}, 
      RotationMatrix :> {{0.2453382967133802, 0.9694375277271751, 
       0.}, {-0.9694375277271751, 0.2453382967133802, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0090322433203985, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07676950035227906, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 14.58755030944653, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2965461697084588, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2453382967133802, 0.9694375277271751, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.220711907001162, 2.085100957738307, 0.}, 
      Optica`Optica`RayEnd :> {4.2970211362664825`, 2.4039905965296344`, 0.}, 
      RotationMatrix :> {{0.23272613805335798`, 0.972542309962281, 
       0.}, {-0.972542309962281, 0.23272613805335798`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009009215361748977, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32789281815790106`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.072831680320224`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08219250258345595, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.23272613805335798`, 0.972542309962281, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.055325171769849, 2.140045002997775, 0.}, 
      Optica`Optica`RayEnd :> {3.8070783438029028`, 2.2959531760368335`, 0.}, 
      RotationMatrix :> {{-0.8468404285209505, 0.5318470537875085, 
       0.}, {-0.5318470537875085, -0.8468404285209505, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25532326349488754`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2931447526667114, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.16680741184884, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19777270721870926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8468404285209505, 0.5318470537875085, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8070783438029028`, 2.2959531760368335`, 0.},
       Optica`Optica`RayEnd :> {3.675134321503202, 2.346331015390589, 0.}, 
      RotationMatrix :> {{-0.9342202438713691, 0.3566967002103044, 
       0.}, {-0.3566967002103044, -0.9342202438713691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24035783209437522`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14123438575140534`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.37583430276092, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3313430962773228, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9342202438713691, 0.3566967002103044, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.675134321503202, 2.346331015390589, 0.}, 
      Optica`Optica`RayEnd :> {3.573380697926003, 2.248385357970332, 0.}, 
      RotationMatrix :> {{-0.7204592779289716, -0.6934972450169251, 0.}, {
       0.6934972450169251, -0.7204592779289716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014088252666628965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14123438575140515`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.584861193673, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11833331167738906`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 79, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7204592779289716, -0.6934972450169251, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8871266030435763`, 2.040432289515257, 0.}, 
      Optica`Optica`RayEnd :> {3.7699581791501924`, 1.9423212098599785`, 0.}, 
      RotationMatrix :> {{-0.7667042521487605, -0.6420004592965722, 0.}, {
       0.6420004592965722, -0.7667042521487605, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008444652544654986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1528208870173973, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.26808769617973, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2518331317774399, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7667042521487605, -0.6420004592965722, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7699581791501924`, 1.9423212098599785`, 0.},
       Optica`Optica`RayEnd :> {3.608033170338925, 1.7741434996327017`, 0.}, 
      RotationMatrix :> {{-0.6935885736702984, -0.7203713559505269, 0.}, {
       0.7203713559505269, -0.6935885736702984, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008347331480467958, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2334597410600356, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.613608112948583`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.016816929181173057`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6935885736702984, -0.7203713559505269, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7442304120272185`, -0.9084906570121896, 0.},
       Optica`Optica`RayEnd :> {2.6368300877082387`, -0.932727835487602, 0.}, 
      RotationMatrix :> {{-0.9754693042652878, -0.22013549562983972`, 0.}, {
       0.22013549562983972`, -0.9754693042652878, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014021797280334971`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11010118293765514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.952128116422863`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22134473650000538`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9754693042652878, -0.22013549562983972`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6368300877082387`, -0.932727835487602, 0.}, 
      Optica`Optica`RayEnd :> {2.30918847720457, -1.0191991468394757`, 0.}, 
      RotationMatrix :> {{-0.9668928365428473, -0.2551827632151642, 0.}, {
       0.2551827632151642, -0.9668928365428473, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013977533816082882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.338860314318969, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.453641381614936`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03623234819835638, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9668928365428473, -0.2551827632151642, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9103644313012382`, -2.63264420570771, 0.}, 
      Optica`Optica`RayEnd :> {3.8531464172669496`, -2.667180887666956, 0.}, 
      RotationMatrix :> {{-0.8561309317108144, -0.5167589648646382, 0.}, {
       0.5167589648646382, -0.8561309317108144, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012327639918492539`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06683325168493706, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.427649795076652`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2501257513969146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.8561309317108144, -0.5167589648646382, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8531464172669496`, -2.667180887666956, 0.}, 
      Optica`Optica`RayEnd :> {3.589108696355187, -2.8258811301481175`, 0.}, 
      RotationMatrix :> {{-0.8570951026520814, -0.515158213571149, 0.}, {
       0.515158213571149, -0.8570951026520814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012297234943880136`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30806117091879254`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.883580328036466`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2652016058101836, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.8570951026520814, -0.515158213571149, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.275954050371112, -2.8917611585853704`, 0.}, 
      Optica`Optica`RayEnd :> {5.232309234713183, -3.089513230492525, 0.}, 
      RotationMatrix :> {{-0.21551812384600966`, -0.9764998403962469, 0.}, {
       0.9764998403962469, -0.21551812384600966`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008869027238572677, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2025111154415652, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.34580144360916, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2989767468319127, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.21551812384600966`, -0.9764998403962469, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.232309234713183, -3.089513230492525, 0.}, 
      Optica`Optica`RayEnd :> {5.172461097552453, -3.4101727141824996`, 0.}, 
      RotationMatrix :> {{-0.18347252564124686`, -0.98302483810676, 0.}, {
       0.98302483810676, -0.18347252564124686`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008842181070358002, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3261967259215377, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.828572597973036`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42341086758475727`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.18347252564124686`, -0.98302483810676, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.402864922916759, -3.1706687047615048`, 0.}, 
      Optica`Optica`RayEnd :> {6.477872133810045, -3.3062105155783237`, 0.}, 
      RotationMatrix :> {{0.48419302735656633`, -0.8749612061453256, 0.}, {
       0.8749612061453256, 0.48419302735656633`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01772654827632767, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15491179479139797`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.88976612132318, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2652862888224462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.48419302735656633`, -0.8749612061453256, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.477872133810045, -3.3062105155783237`, 0.}, 
      Optica`Optica`RayEnd :> {6.601170038740591, -3.55634550583027, 0.}, 
      RotationMatrix :> {{0.442129979403896, -0.8969509915888995, 0.}, {
       0.8969509915888995, 0.442129979403896, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017660669639167025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27887252770504867`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.302497462326652`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17457695310418353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.442129979403896, -0.8969509915888995, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.065516021771263, -2.5757373891090496`, 0.}, 
      Optica`Optica`RayEnd :> {7.330498288687872, -2.5789224955651515`, 0.}, 
      RotationMatrix :> {{0.9999277667377791, -0.012019205747357237`, 0.}, {
       0.012019205747357237`, 0.9999277667377791, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09095527827165098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.265001408832863, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.169836476654805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12302103775279374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9999277667377791, -0.012019205747357237`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.330498288687872, -2.5789224955651515`, 0.}, 
      Optica`Optica`RayEnd :> {7.638935893568386, -2.5748739356299155`, 0.}, 
      RotationMatrix :> {{0.9999138648545481, 0.01312489510967778, 
       0.}, {-0.01312489510967778, 0.9999138648545481, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09070150533705124, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30846417448705005`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.62636345489564, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36722415684388077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999138648545481, 0.01312489510967778, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.907913549349928, -1.128131966537967, 0.}, 
      Optica`Optica`RayEnd :> {7.925750905818889, -1.1176724675766507`, 0.}, 
      RotationMatrix :> {{0.8626321846492808, 0.5058317052214195, 
       0.}, {-0.5058317052214195, 0.8626321846492808, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013388151781880133`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.020677823974552454`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.557428746205577`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3101158213115245, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8626321846492808, 0.5058317052214195, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.925750905818889, -1.1176724675766507`, 0.}, 
      Optica`Optica`RayEnd :> {8.17711503024882, -0.9657857867526604, 0.}, 
      RotationMatrix :> {{0.8558841096733909, 0.5171676621837321, 
       0.}, {-0.5171676621837321, 0.8558841096733909, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013353982074667318`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29368943948013176`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.992089116636173`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2942324078144845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8558841096733909, 0.5171676621837321, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.9396332096186235`, -1.3113566863266601`, 
       0.}, Optica`Optica`RayEnd :> {8.12417255435784, -1.2896757064740478`, 
       0.}, RotationMatrix :> {{0.9931690347974079, 0.11668448191419796`, 
       0.}, {-0.11668448191419796`, 0.9931690347974079, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010926807785597252`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18580859679828715`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.37138906647465, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20980926612965756`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9931690347974079, 0.11668448191419796`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.12417255435784, -1.2896757064740478`, 0.}, 
      Optica`Optica`RayEnd :> {8.40513098295746, -1.2478631540215561`, 0.}, 
      RotationMatrix :> {{0.9891067500316196, 0.14719998995206032`, 
       0.}, {-0.14719998995206032`, 0.9891067500316196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010894464334518713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2840526855070387, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.791787041025067`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39464326730127647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9891067500316196, 0.14719998995206032`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.195908819104282, -1.8418698879684676`, 0.}, 
      Optica`Optica`RayEnd :> {2.1672204988726462`, -1.8549278598035843`, 0.},
       RotationMatrix :> {{-0.9101533076202891, -0.4142715976600941, 0.}, {
       0.4142715976600941, -0.9101533076202891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16946302924391063`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0315203164032275, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.38511714926715, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2194773137373501, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9101533076202891, -0.4142715976600941, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1672204988726462`, -1.8549278598035843`, 
       0.}, Optica`Optica`RayEnd :> {
       1.8631456608056345`, -1.9991716919118454`, 0.}, 
      RotationMatrix :> {{-0.9034981553000941, -0.42859197772394964`, 0.}, {
       0.42859197772394964`, -0.9034981553000941, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1690240168438554, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3365528045444812, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.88321529999298, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.144463053777111, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9034981553000941, -0.42859197772394964`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.507286540201194, 2.678637279603003, 0.}, 
      Optica`Optica`RayEnd :> {5.573136455120478, 2.6991648220460918`, 0.}, 
      RotationMatrix :> {{0.9546884156727704, 0.29760717225936417`, 
       0.}, {-0.29760717225936417`, 0.9546884156727704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012347044132055179`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06897529480640045, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.386626647452047`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2964945010933336, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9546884156727704, 0.29760717225936417`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.573136455120478, 2.6991648220460918`, 0.}, 
      Optica`Optica`RayEnd :> {5.859102310574856, 2.798613824550409, 0.}, 
      RotationMatrix :> {{0.9445146091520907, 0.32846940968417854`, 
       0.}, {-0.32846940968417854`, 0.9445146091520907, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012309762312982598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30276488334160795`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.834718674797628`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4241054299314752, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9445146091520907, 0.32846940968417854`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0728522647269667`, 3.096887373596184, 0.}, 
      Optica`Optica`RayEnd :> {2.0379501329067837`, 3.357334989361348, 0.}, 
      RotationMatrix :> {{-0.13282095326280763`, 0.9911400478107818, 
       0.}, {-0.9911400478107818, -0.13282095326280763`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01369256098645535, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26277579676095003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.882638716269343`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1529552981465409, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13282095326280763`, 0.9911400478107818, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0379501329067837`, 3.357334989361348, 0.}, 
      Optica`Optica`RayEnd :> {2.0003485458539485`, 3.6568472194308046`, 0.}, 
      RotationMatrix :> {{-0.1245649482614858, 0.9922114561244559, 
       0.}, {-0.9922114561244559, -0.1245649482614858, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013658338411207886`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3018633056700847, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.287135545867255`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26587832448302035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 78, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.1245649482614858, 0.9922114561244559, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.16312011496545, -3.0916553002213503`, 0.}, 
      Optica`Optica`RayEnd :> {4.204481116344392, -3.110912839801599, 0.}, 
      RotationMatrix :> {{0.906554550533619, -0.42208867185318727`, 0.}, {
       0.42208867185318727`, 0.906554550533619, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02762399913733004, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.045624393319294736`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.252273875066036`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28641713379642353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.906554550533619, -0.42208867185318727`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.204481116344392, -3.110912839801599, 0.}, 
      Optica`Optica`RayEnd :> {4.346900401770584, -3.2046491384338243`, 0.}, 
      RotationMatrix :> {{0.8353109600993406, -0.549777773230164, 0.}, {
       0.549777773230164, 0.8353109600993406, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02694271009682234, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17049852357887652`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.504611689962774`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.332299978648132, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8353109600993406, -0.549777773230164, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.4193349084766895`, -1.7443209047785018`, 
       0.}, Optica`Optica`RayEnd :> {4.617159875700941, -1.7671299287408804`, 
       0.}, RotationMatrix :> {{0.9934186153169569, -0.11454018832593424`, 
       0.}, {0.11454018832593424`, 0.9934186153169569, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008450760051046375, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19913555491521973`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.334505568200305`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20704344007000697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9934186153169569, -0.11454018832593424`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.617159875700941, -1.7671299287408804`, 0.}, 
      Optica`Optica`RayEnd :> {4.8834535086676665`, -1.782800960434623, 0.}, 
      RotationMatrix :> {{0.9982729004251172, -0.058747053345887125`, 0.}, {
       0.058747053345887125`, 0.9982729004251172, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008414614059508836, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2667543442813321, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.729301997736677`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24089503106559118`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9982729004251172, -0.058747053345887125`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.45669261763965, 2.226579398023197, 0.}, 
      Optica`Optica`RayEnd :> {3.5395831023513624`, 2.3579201842494855`, 0.}, 
      RotationMatrix :> {{0.5337094751864679, 0.8456678994121661, 
       0.}, {-0.8456678994121661, 0.5337094751864679, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009132608605665917, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1553101238885675, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.773773337619751`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04213175448860568, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.5337094751864679, 0.8456678994121661, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5395831023513624`, 2.3579201842494855`, 0.},
       Optica`Optica`RayEnd :> {3.6246736316529993`, 2.5441255502263878`, 0.},
       RotationMatrix :> {{0.4156307765101584, 0.9095334285322136, 
       0.}, {-0.9095334285322136, 0.4156307765101584, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008953168700008701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20472624769536715`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.076768184208895`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3491103010786065, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.4156307765101584, 0.9095334285322136, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.332308243559459, 2.3879252482139632`, 0.}, 
      Optica`Optica`RayEnd :> {3.2156463427626463`, 2.5015423567450736`, 0.}, 
      RotationMatrix :> {{-0.7163936602428322, 0.6976962975133792, 
       0.}, {-0.6976962975133792, -0.7163936602428322, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3847505289119267, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1628460820790463, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.085384813141964`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4314431319893003, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7163936602428322, 0.6976962975133792, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2156463427626463`, 2.5015423567450736`, 0.},
       Optica`Optica`RayEnd :> {2.990766656968944, 2.68440669863797, 0.}, 
      RotationMatrix :> {{-0.7758613387984399, 0.6309034656410542, 
       0.}, {-0.6309034656410542, -0.7758613387984399, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3816464895602496, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2898452011308737, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.514355710815657`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33071218127597535`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7758613387984399, 0.6309034656410542, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1486487051213468`, 2.299759893171285, 0.}, 
      Optica`Optica`RayEnd :> {2.610436075581841, 1.9398455583721346`, 0.}, 
      RotationMatrix :> {{-0.8312611145805722, -0.5558821452306824, 0.}, {
       0.5558821452306824, -0.8312611145805722, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00872318817885908, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6474651828397756, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.03628769970831, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37641703803505566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8312611145805722, -0.5558821452306824, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.610436075581841, 1.9398455583721346`, 0.}, 
      Optica`Optica`RayEnd :> {2.427325078483299, 1.8400499517806694`, 0.}, 
      RotationMatrix :> {{-0.8780630737863054, -0.4785449179052535, 0.}, {
       0.4785449179052535, -0.8780630737863054, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008651437781788993, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20853968532003855`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.344926433981968`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39214820526829297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8780630737863054, -0.4785449179052535, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.888010749790684, 2.239795602771776, 0.}, 
      Optica`Optica`RayEnd :> {5.352094276162099, 2.5575525177369407`, 0.}, 
      RotationMatrix :> {{0.8251198862797183, 0.564957673871012, 
       0.}, {-0.564957673871012, 0.8251198862797183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009488716789597621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5624437540390202, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.962846662532595`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14290258356349017`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8251198862797183, 0.564957673871012, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.352094276162099, 2.5575525177369407`, 0.}, 
      Optica`Optica`RayEnd :> {5.5648705308709445`, 2.67124674879148, 0.}, 
      RotationMatrix :> {{0.8819850976427333, 0.47127729367765875`, 
       0.}, {-0.47127729367765875`, 0.8819850976427333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00937395846192137, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2412469953035826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.3198922155819, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11112707057389765`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8819850976427333, 0.47127729367765875`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4125453660218863`, -0.8593377419620716, 0.},
       Optica`Optica`RayEnd :> {3.353904435352324, -0.8641742816307323, 0.}, 
      RotationMatrix :> {{-0.9966160107848178, -0.08219809637307021, 0.}, {
       0.08219809637307021, -0.9966160107848178, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026194550921173086`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058840044746404994`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.322702705691219`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.255050527271154, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9966160107848178, -0.08219809637307021, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.353904435352324, -0.8641742816307323, 0.}, 
      Optica`Optica`RayEnd :> {3.0780660610831423`, -0.8695988186114041, 0.}, 
      RotationMatrix :> {{-0.9998066874553039, -0.019661834086694537`, 0.}, {
       0.019661834086694537`, -0.9998066874553039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02606860083849863, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2758917075972379, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.73102243293513, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2618640892017596, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9998066874553039, -0.019661834086694537`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.422089061304332, -1.0631783556271799`, 0.}, 
      Optica`Optica`RayEnd :> {3.093326910640336, -1.0721338202571287`, 0.}, 
      RotationMatrix :> {{-0.9996291988972409, -0.027229849651815907`, 0.}, {
       0.027229849651815907`, -0.9996291988972409, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013259526748768102`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32888410125142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.661981460496943`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22985220725035893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9996291988972409, -0.027229849651815907`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.093326910640336, -1.0721338202571287`, 0.}, 
      Optica`Optica`RayEnd :> {2.844101538872602, -1.0632252089375354`, 0.}, 
      RotationMatrix :> {{-0.9993617518195836, 0.035722387939401565`, 
       0.}, {-0.035722387939401565`, -0.9993617518195836, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013195382163280214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2493845409972494, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.031070581172873`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23886775847440142`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9993617518195836, 0.035722387939401565`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.9164044126609205`, 0.6481537547206977, 0.}, 
      Optica`Optica`RayEnd :> {4.891964282972589, 0.6622910721049998, 0.}, 
      RotationMatrix :> {{-0.8656140679128932, 0.5007117788022301, 
       0.}, {-0.5007117788022301, -0.8656140679128932, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009347203982220907, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028234441414820517`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.682661761330877`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31503114351604095`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8656140679128932, 0.5007117788022301, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.891964282972589, 0.6622910721049998, 0.}, 
      Optica`Optica`RayEnd :> {4.620435270414352, 0.8139180346299864, 0.}, 
      RotationMatrix :> {{-0.8730938402384506, 0.48755219837231295`, 
       0.}, {-0.48755219837231295`, -0.8730938402384506, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009323085692243398, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31099636722219953`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.142936384819734`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.303787466415339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8730938402384506, 0.48755219837231295`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.150256002333505, 0.05231239248044925, 0.}, 
      Optica`Optica`RayEnd :> {8.164078058226643, 0.069870449653405, 0.}, 
      RotationMatrix :> {{0.6185528529147435, 0.7857431947850589, 
       0.}, {-0.7857431947850589, 0.6185528529147435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09786702823869965, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022345796043144555`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.162954887734417`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39369446430022625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.6185528529147435, 0.7857431947850589, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.164078058226643, 0.069870449653405, 0.}, 
      Optica`Optica`RayEnd :> {8.347403889598631, 0.3164039243675053, 0.}, 
      RotationMatrix :> {{0.5967154851049246, 0.8024528832498479, 
       0.}, {-0.8024528832498479, 0.5967154851049246, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09758750040512609, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3072248600013327, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.61764768053639, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1818522409356843, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.5967154851049246, 0.8024528832498479, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.574921277472411, 0.0874755916513075, 0.}, 
      Optica`Optica`RayEnd :> {7.596749065410667, 0.14135927252437472`, 0.}, 
      RotationMatrix :> {{0.3754547321525647, 0.9268407328685145, 
       0.}, {-0.9268407328685145, 0.3754547321525647, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019441821985911233`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0581369365438877, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.370226275289069`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20483538927066952`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3754547321525647, 0.9268407328685145, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.596749065410667, 0.14135927252437472`, 0.}, 
      Optica`Optica`RayEnd :> {7.71725703465744, 0.3774451573715266, 0.}, 
      RotationMatrix :> {{0.4546379289074377, 0.890676346154289, 
       0.}, {-0.890676346154289, 0.4546379289074377, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019292251155254413`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2650636068494575, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.762520413426266`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3328272989911809, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.4546379289074377, 0.890676346154289, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.093124318394603, -0.6399737634313856, 0.}, 
      Optica`Optica`RayEnd :> {7.067044428207292, -0.5757241701134088, 0.}, 
      RotationMatrix :> {{-0.3761108048562297, 0.9265746934113832, 
       0.}, {-0.9265746934113832, -0.3761108048562297, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013442509710075531`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06934097571932175, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.150042315962574`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0985376968777724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.3761108048562297, 0.9265746934113832, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.067044428207292, -0.5757241701134088, 0.}, 
      Optica`Optica`RayEnd :> {6.939023855942025, -0.28788288655888045`, 0.}, 
      RotationMatrix :> {{-0.4063799677637056, 0.9137041763067352, 
       0.}, {-0.9137041763067352, -0.4063799677637056, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013401727792807969`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31502677892751424`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.616281948775296`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29803730126526273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4063799677637056, 0.9137041763067352, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.095556880334739, -1.782516190304264, 0.}, 
      Optica`Optica`RayEnd :> {6.836140707000324, -1.8165518686022184`, 0.}, 
      RotationMatrix :> {{-0.9915026869781982, -0.13008620878099555`, 0.}, {
       0.13008620878099555`, -0.9915026869781982, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02171513936557199, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2616394052597439, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.694621339300067`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24200760765449436`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9915026869781982, -0.13008620878099555`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.836140707000324, -1.8165518686022184`, 0.}, 
      Optica`Optica`RayEnd :> {6.603624631246455, -1.8298685568134114`, 0.}, 
      RotationMatrix :> {{-0.9983639758675461, -0.05717841979230881, 0.}, {
       0.05717841979230881, -0.9983639758675461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021587779468350228`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2328971010315358, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.03930904882674, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3051262849036108, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9983639758675461, -0.05717841979230881, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.863139321655691, -1.9772863051707465`, 0.}, 
      Optica`Optica`RayEnd :> {7.7142040229293976`, -2.10792373154992, 0.}, 
      RotationMatrix :> {{-0.7517780614626389, -0.6594162162879195, 0.}, {
       0.6594162162879195, -0.7517780614626389, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04371431905767775, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19811072756835818`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.263842555629806`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36966509257863345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7517780614626389, -0.6594162162879195, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.7142040229293976`, -2.10792373154992, 0.}, 
      Optica`Optica`RayEnd :> {7.608643324015406, -2.241089960054466, 0.}, 
      RotationMatrix :> {{-0.6211999935831811, -0.7836520707381913, 0.}, {
       0.7836520707381913, -0.6211999935831811, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04173424052011483, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16993029620799016`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.515339394017632`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03907315642172593, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6211999935831811, -0.7836520707381913, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.022041265246742, -2.1317672179825253`, 0.}, 
      Optica`Optica`RayEnd :> {8.079759756486173, -2.178409227415667, 0.}, 
      RotationMatrix :> {{0.7777881546394693, -0.6285265201266602, 0.}, {
       0.6285265201266602, 0.7777881546394693, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.100675908293293, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07420849867041822, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.425807014102384`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16379210594986893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7777881546394693, -0.6285265201266602, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.079759756486173, -2.178409227415667, 0.}, 
      Optica`Optica`RayEnd :> {8.33682100981092, -2.372116296911316, 0.}, 
      RotationMatrix :> {{0.7986392118474391, -0.6018101106658986, 0.}, {
       0.6018101106658986, 0.7986392118474391, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.085012741178588, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32187406968173615`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.902180637231353`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.044646344060852446`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7986392118474391, -0.6018101106658986, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.33682100981092, -2.372116296911316, 0.}, 
      Optica`Optica`RayEnd :> {8.241396205327685, -2.0647126153737987`, 0.}, 
      RotationMatrix :> {{-0.2964662688659263, 0.9550433243705314, 
       0.}, {-0.9550433243705314, -0.2964662688659263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015615068625707015`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3218740696817361, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.37855426036032, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24520890687167102`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2964662688659263, 0.9550433243705314, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.147211336256754, -1.948883010289454, 0.}, 
      Optica`Optica`RayEnd :> {8.177544675768603, -1.8944705060288458`, 0.}, 
      RotationMatrix :> {{0.48692020792912327`, 0.8734464557774902, 
       0.}, {-0.8734464557774902, 0.48692020792912327`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04298070795175712, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06229632497869996, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.737838146551299`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3454113891774642, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.48692020792912327`, 0.8734464557774902, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.177544675768603, -1.8944705060288458`, 0.}, 
      Optica`Optica`RayEnd :> {8.311903601845028, -1.6379705011059962`, 0.}, 
      RotationMatrix :> {{0.4640118201498591, 0.8858290076313909, 
       0.}, {-0.8858290076313909, 0.4640118201498591, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04285973902290488, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28955927466035736`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.16638587304863, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10051588586443531`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4640118201498591, 0.8858290076313909, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.981703858840445, -1.3971231822573906`, 0.}, 
      Optica`Optica`RayEnd :> {8.05729602739823, -1.1730735280725026`, 0.}, 
      RotationMatrix :> {{0.3196852847316798, 0.9475237826704008, 
       0.}, {-0.9475237826704008, 0.3196852847316798, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021504471470806186`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2364580797681406, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.053776484109363`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20345165643578467`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3196852847316798, 0.9475237826704008, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.05729602739823, -1.1730735280725026`, 0.}, 
      Optica`Optica`RayEnd :> {8.13369358484671, -0.909805201904108, 0.}, 
      RotationMatrix :> {{0.2786918270180039, 0.9603805837028189, 
       0.}, {-0.9603805837028189, 0.2786918270180039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02142982434960078, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.274129163621097, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.459487646268588`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07264294776889381, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2786918270180039, 0.9603805837028189, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.81221724320332, -0.9879310810174107, 0.}, 
      Optica`Optica`RayEnd :> {6.775781437771898, -0.9434245706739666, 0.}, 
      RotationMatrix :> {{-0.633460501286603, 0.7737750275821295, 
       0.}, {-0.7737750275821295, -0.633460501286603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013672396952207486`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05751866984195245, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.90867076279409, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21786678874391158`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.633460501286603, 0.7737750275821295, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.775781437771898, -0.9434245706739666, 0.}, 
      Optica`Optica`RayEnd :> {6.631251815124599, -0.7413559237850313, 0.}, 
      RotationMatrix :> {{-0.5817574793312943, 0.8133623025700775, 
       0.}, {-0.8133623025700775, -0.5817574793312943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013603579244059243`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2484362088708006, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.276356351922875`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19552234882288427`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5817574793312943, 0.8133623025700775, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.603984831371815, -1.169398971513567, 0.}, 
      Optica`Optica`RayEnd :> {5.574104318307114, -1.1649342600888264`, 0.}, 
      RotationMatrix :> {{-0.9890205136377064, 0.14777829205876963`, 
       0.}, {-0.14777829205876963`, -0.9890205136377064, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019780015412603533`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.030212227807891474`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.52195634836913, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0028833069767945363`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9890205136377064, 0.14777829205876963`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.574104318307114, -1.1649342600888264`, 0.}, 
      Optica`Optica`RayEnd :> {5.35587456765623, -1.1072220852942924`, 0.}, 
      RotationMatrix :> {{-0.9667649525711814, 0.2556668271012899, 
       0.}, {-0.2556668271012899, -0.9667649525711814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019538039861123544`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22573196315245736`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.856039653834767`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2503278691151229, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9667649525711814, 0.2556668271012899, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.930221352069838, -2.022155952212378, 0.}, 
      Optica`Optica`RayEnd :> {5.770604205594284, -2.118585400139093, 0.}, 
      RotationMatrix :> {{-0.8559295719511272, -0.517092417136009, 0.}, {
       0.517092417136009, -0.8559295719511272, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09514781052627358, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18648397217039694`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.727661194298111`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09511050747581218, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8559295719511272, -0.517092417136009, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.770604205594284, -2.118585400139093, 0.}, 
      Optica`Optica`RayEnd :> {5.56054423222673, -2.2685416838301906`, 0.}, 
      RotationMatrix :> {{-0.8138920576843389, -0.5810161085876645, 0.}, {
       0.5810161085876645, -0.8138920576843389, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0945532599995545, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2580931603697049, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.109639071645276`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0006841820076440297, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8138920576843389, -0.5810161085876645, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.561283549930273, -0.227086100596803, 0.}, 
      Optica`Optica`RayEnd :> {4.41769083502157, -0.14698272811855934`, 0.}, 
      RotationMatrix :> {{-0.8733048297376845, 0.4871741725059262, 
       0.}, {-0.4871741725059262, -0.8733048297376845, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013288937657603401`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16442450564693942`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.597310676963808`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23951891215589866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8733048297376845, 0.4871741725059262, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.41769083502157, -0.14698272811855936`, 0.}, 
      Optica`Optica`RayEnd :> {4.212331653106352, -0.06959946598404876, 0.}, 
      RotationMatrix :> {{-0.9357683423156423, 0.35261538468965703`, 
       0.}, {-0.35261538468965703`, -0.9357683423156423, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012947902499315668`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21945514998620091`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.922104298943385`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36762204148074035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9357683423156423, 0.35261538468965703`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.407879210301261, 1.8004025358513511`, 0.}, 
      Optica`Optica`RayEnd :> {6.412338370545742, 1.87009568796768, 0.}, 
      RotationMatrix :> {{0.06385219490892266, 0.9979593665101363, 
       0.}, {-0.9979593665101363, 0.06385219490892266, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01193318496013604, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06983566110516692, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.101027422546288`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3734257481909907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06385219490892266, 0.9979593665101363, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.412338370545742, 1.87009568796768, 0.}, 
      Optica`Optica`RayEnd :> {6.448658799778517, 2.1357213457488884`, 0.}, 
      RotationMatrix :> {{0.1354748029281862, 0.9907807919875963, 
       0.}, {-0.9907807919875963, 0.1354748029281862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011864851132445337`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26809730258126907`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.497811430366568`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4150522367631313, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1354748029281862, 0.9907807919875963, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1079055127338115`, 2.388170150014077, 0.}, 
      Optica`Optica`RayEnd :> {7.1101305241034725`, 2.3966544690921925`, 0.}, 
      RotationMatrix :> {{0.2536717482099696, 0.9672903618666412, 
       0.}, {-0.9672903618666412, 0.2536717482099696, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0248984562135517, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.008771222595191574, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.990997270224325`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2278372362831523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2536717482099696, 0.9672903618666412, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1101305241034725`, 2.3966544690921925`, 0.},
       Optica`Optica`RayEnd :> {7.1162682073205294`, 2.5548130859784597`, 0.},
       RotationMatrix :> {{0.03877794896386383, 0.9992478524741275, 
       0.}, {-0.9992478524741275, 0.03877794896386383, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022851189005179948`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15827766504042798`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.225248214484157`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2616441177358119, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.03877794896386383, 0.9992478524741275, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8863540324988484`, 0.559232777351813, 0.}, 
      Optica`Optica`RayEnd :> {2.8356563595576576`, 0.5723412860644501, 0.}, 
      RotationMatrix :> {{-0.9681606052909278, 0.25032986710079935`, 
       0.}, {-0.25032986710079935`, -0.9681606052909278, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11035036088160324`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05236494096550905, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.8697471800437, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01853531620247255, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9681606052909278, 0.25032986710079935`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8356563595576576`, 0.5723412860644501, 0.}, 
      Optica`Optica`RayEnd :> {2.6055738337734273`, 0.6567341618634729, 0.}, 
      RotationMatrix :> {{-0.9388376901079143, 0.3443599739122355, 
       0.}, {-0.3443599739122355, -0.9388376901079143, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10928234430771655`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24507167554999135`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.232453259857685`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18599999927855626`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9388376901079143, 0.3443599739122355, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.2133081495809765`, -1.3706139949046245`, 
       0.}, Optica`Optica`RayEnd :> {4.108618644472275, -1.4426546388240173`, 
       0.}, RotationMatrix :> {{-0.8237971538565243, -0.566884687831564, 
       0.}, {0.566884687831564, -0.8237971538565243, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0418785046320254, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12708165428662596`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.121898730766114`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3558327540485184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8237971538565243, -0.566884687831564, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.108618644472275, -1.4426546388240173`, 0.}, 
      Optica`Optica`RayEnd :> {3.8962224611401854`, -1.5783964706025564`, 0.},
       RotationMatrix :> {{-0.8426165682041946, -0.5385139914503481, 0.}, {
       0.5385139914503481, -0.8426165682041946, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041749658315437824`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2520674187367975, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.494958510496575`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38601016896151724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8426165682041946, -0.5385139914503481, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.458210494903547, -2.6254920219548468`, 0.}, 
      Optica`Optica`RayEnd :> {5.407019887660409, -2.9505475865878963`, 0.}, 
      RotationMatrix :> {{-0.1555653793730551, -0.9878255983423981, 0.}, {
       0.9878255983423981, -0.1555653793730551, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023012613951906694`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3290616938642841, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.52403719127587, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1843230379758143, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1555653793730551, -0.9878255983423981, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.407019887660409, -2.9505475865878963`, 0.}, 
      Optica`Optica`RayEnd :> {5.421649245250298, -3.0825725534329287`, 0.}, 
      RotationMatrix :> {{0.11013344497570929`, -0.99391680954584, 0.}, {
       0.99391680954584, 0.11013344497570929`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019248099947778104`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13283301537616585`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.720630054032593`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28160554191830983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.11013344497570929`, -0.99391680954584, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.796596113038852, -1.4367323507430918`, 0.}, 
      Optica`Optica`RayEnd :> {6.821543249800346, -1.4628040299671872`, 0.}, 
      RotationMatrix :> {{0.6913530092336669, -0.7225171393285791, 0.}, {
       0.7225171393285791, 0.6913530092336669, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011817734145923898`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036084513162308075`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.253952935556073`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21062870937050487`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.6913530092336669, -0.7225171393285791, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.821543249800346, -1.4628040299671872`, 0.}, 
      Optica`Optica`RayEnd :> {7.016042773262057, -1.6516751997741703`, 0.}, 
      RotationMatrix :> {{0.717410668429018, -0.6966505098140888, 0.}, {
       0.6966505098140888, 0.717410668429018, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011780119441163816`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2711132298710099, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.655200515765168`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.029686086210345193`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.717410668429018, -0.6966505098140888, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.507576983832616, 1.6542440114158796`, 0.}, 
      Optica`Optica`RayEnd :> {4.430740033522393, 2.8184667495682527`, 0.}, 
      RotationMatrix :> {{-0.6790185060664495, 0.7341211537745567, 
       0.}, {-0.7341211537745567, -0.6790185060664495, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00957072377488993, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5858727570597932`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.694714822147947`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39937818410191106`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.6790185060664495, 0.7341211537745567, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.430740033522393, 2.8184667495682527`, 0.}, 
      Optica`Optica`RayEnd :> {4.262747380025582, 2.9608335378144637`, 0.}, 
      RotationMatrix :> {{-0.7628953032524637, 0.6465220462407532, 
       0.}, {-0.6465220462407532, -0.7628953032524637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009424671261420842, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22020407358730074`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.020616851057152`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26829443529558317`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7628953032524637, 0.6465220462407532, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9982269963100165`, 2.1711805332934513`, 0.},
       Optica`Optica`RayEnd :> {6.991086841474694, 2.3261666890661976`, 0.}, 
      RotationMatrix :> {{-0.046020818240224595`, 0.9989404808538392, 
       0.}, {-0.9989404808538392, -0.046020818240224595`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01604485245075161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15515054074119894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.726684218170469`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21798751225293936`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.046020818240224595`, 0.9989404808538392, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.991086841474694, 2.3261666890661976`, 0.}, 
      Optica`Optica`RayEnd :> {6.976035586645406, 2.6360109109681593`, 0.}, 
      RotationMatrix :> {{-0.04851963288570492, 0.9988222290401009, 
       0.}, {-0.9988222290401009, -0.04851963288570492, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016005257171484762`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3102095777340993, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.185794393216934`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2605754002817038, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.04851963288570492, 0.9988222290401009, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.601329198023765, -1.6135517013908613`, 0.}, 
      Optica`Optica`RayEnd :> {7.600403197491476, -1.8782348697021982`, 0.}, 
      RotationMatrix :> {{-0.0034985030263823547`, -0.999993880219561, 0.}, {
       0.999993880219561, -0.0034985030263823547`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1290611972797337, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2646847881241257, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.823967576796832`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20889186604847446`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.0034985030263823547`, -0.999993880219561, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.600403197491476, -1.8782348697021982`, 0.}, 
      Optica`Optica`RayEnd :> {7.575596281441464, -2.0742213214166454`, 0.}, 
      RotationMatrix :> {{-0.12557273527339094`, -0.9920844158416955, 0.}, {
       0.9920844158416955, -0.12557273527339094`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12705050018888117`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19755017676411113`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.116341838407717`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0891184469324538, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.12557273527339094`, -0.9920844158416955, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.144168730365307, -0.8780716570571427, 0.}, 
      Optica`Optica`RayEnd :> {8.229428519827426, -1.0824469116506141`, 0.}, 
      RotationMatrix :> {{0.38501333507895286`, -0.9229110096923657, 0.}, {
       0.9229110096923657, 0.38501333507895286`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03616965632267346, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22144632846193466`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.478825586471395`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3302335284224384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.38501333507895286`, -0.9229110096923657, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.229428519827426, -1.0824469116506141`, 0.}, 
      Optica`Optica`RayEnd :> {8.336491908698271, -1.3533739219868754`, 0.}, 
      RotationMatrix :> {{0.36751849608503284`, -0.9300162122433112, 0.}, {
       0.9300162122433112, 0.36751849608503284`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036073961902658234`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2913142876109145, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.909970732135548`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015616519867868273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.36751849608503284`, -0.9300162122433112, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.397711101966816, 1.425990015523278, 0.}, 
      Optica`Optica`RayEnd :> {8.355766015401802, 1.677308046114456, 0.}, 
      RotationMatrix :> {{-0.16462332222623183`, 0.986356508458883, 
       0.}, {-0.986356508458883, -0.16462332222623183`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04156277847714569, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25479431466807656`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.616389138770046`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2434128852324654, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.16462332222623183`, 0.986356508458883, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.355766015401802, 1.677308046114456, 0.}, 
      Optica`Optica`RayEnd :> {8.300925599643978, 1.8751161064027455`, 0.}, 
      RotationMatrix :> {{-0.267163216279225, 0.9636512937091614, 
       0.}, {-0.9636512937091614, -0.267163216279225, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041104093087562646`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20526933505885978`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.92018775465716, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01621912599831199, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.267163216279225, 0.9636512937091614, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9578493651101825`, 0.12924088828540214`, 
       0.}, Optica`Optica`RayEnd :> {6.888620916030578, 0.16005448555398563`, 
       0.}, RotationMatrix :> {{-0.9135890649744072, 0.4066386852713211, 
       0.}, {-0.4066386852713211, -0.9135890649744072, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00875989764815006, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07577635474604133, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.648834733223442`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25631192999813884`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9135890649744072, 0.4066386852713211, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.888620916030578, 0.16005448555398563`, 0.}, 
      Optica`Optica`RayEnd :> {6.597317163585998, 0.2927098512295937, 0.}, 
      RotationMatrix :> {{-0.91007842184727, 0.4144360820295245, 
       0.}, {-0.4144360820295245, -0.91007842184727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008737986765164067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32008642931374326`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.122562648607783`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16942134467166378`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.91007842184727, 0.4144360820295245, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.246315232740649, 0.938381580360709, 0.}, 
      Optica`Optica`RayEnd :> {8.368445590996329, 1.1189421761208362`, 0.}, 
      RotationMatrix :> {{0.5602666458655181, 0.8283123115894159, 
       0.}, {-0.8283123115894159, 0.5602666458655181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12236056753711465`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21798613063429736`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.816918056635, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04991302059663104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5602666458655181, 0.8283123115894159, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.368445590996329, 1.1189421761208362`, 0.}, 
      Optica`Optica`RayEnd :> {8.468165047516123, 1.3220799330813995`, 0.}, 
      RotationMatrix :> {{0.4406635225216263, 0.8976723566640734, 
       0.}, {-0.8976723566640734, 0.4406635225216263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11976412636108417`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22629387599219705`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.15183299310345, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3630671791619965, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4406635225216263, 0.8976723566640734, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.388581737806026, -0.6601193636767255, 0.}, 
      Optica`Optica`RayEnd :> {5.32799048777566, -0.672957898133279, 0.}, 
      RotationMatrix :> {{-0.9782804914008488, -0.2072855039420589, 0.}, {
       0.2072855039420589, -0.9782804914008488, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015716189902003127`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06193647993900283, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.763306896319369`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19471617914471634`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9782804914008488, -0.2072855039420589, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.32799048777566, -0.672957898133279, 0.}, 
      Optica`Optica`RayEnd :> {5.063027041023098, -0.7413790643896072, 0.}, 
      RotationMatrix :> {{-0.9682388495753991, -0.2500270588814485, 0.}, {
       0.2500270588814485, -0.9682388495753991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015660870595436388`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2736550458275416, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.16831636414413, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07064577457098914, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9682388495753991, -0.2500270588814485, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.690582381629045, 0.865765952717761, 0.}, 
      Optica`Optica`RayEnd :> {4.613324960534719, 0.8639604577822312, 0.}, 
      RotationMatrix :> {{-0.9997270366802105, -0.02336347856388596, 0.}, {
       0.02336347856388596, -0.9997270366802105, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008142147980113375, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07727851529440923, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.957565394500865`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03869494710519531, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 90, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9997270366802105, -0.02336347856388596, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.882842248520935, -1.1463896616883769`, 0.}, 
      Optica`Optica`RayEnd :> {6.886544713685529, -1.1997565696185986`, 0.}, 
      RotationMatrix :> {{0.06921118182149412, -0.9976020310278398, 0.}, {
       0.9976020310278398, 0.06921118182149412, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2718261063685962, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05349518773055935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.833316524000336`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16127364133101244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06921118182149412, -0.9976020310278398, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.886544713685529, -1.1997565696185986`, 0.}, 
      Optica`Optica`RayEnd :> {6.87725476830333, -1.3985091703707337`, 0.}, 
      RotationMatrix :> {{-0.04669027658474571, -0.998909414347687, 0.}, {
       0.998909414347687, -0.04669027658474571, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26809663024753516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1989695941367472, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.127791523322722`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11642385447714701`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04669027658474571, -0.998909414347687, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4207183716486735`, -0.620736054269777, 0.}, 
      Optica`Optica`RayEnd :> {7.534987210262611, -0.8222687521754535, 0.}, 
      RotationMatrix :> {{0.49323138584329945`, -0.8698981549693606, 0.}, {
       0.8698981549693606, 0.49323138584329945`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28038501246615904`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23167389970240232`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.310689133024274`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2713283032349091, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.49323138584329945`, -0.8698981549693606, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.534987210262611, -0.8222687521754535, 0.}, 
      Optica`Optica`RayEnd :> {7.665234411496248, -1.0794506771927341`, 0.}, 
      RotationMatrix :> {{0.45180384358798825`, -0.8921173055821303, 0.}, {
       0.8921173055821303, 0.45180384358798825`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2793503516646433, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.288282632124777, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.737347428568944`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1779962289068613, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.45180384358798825`, -0.8921173055821303, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.581851068272584, 0.2082720020311536, 0.}, 
      Optica`Optica`RayEnd :> {7.545049759835014, 0.09611452520613893, 0.}, 
      RotationMatrix :> {{-0.3117676366633089, -0.9501583766558995, 0.}, {
       0.9501583766558995, -0.3117676366633089, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025307265717536664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11804082306757638`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.864259469781665`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17094515379046615`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3117676366633089, -0.9501583766558995, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.545049759835014, 0.09611452520613893, 0.}, 
      Optica`Optica`RayEnd :> {7.4586303530034055`, -0.17982614486075948`, 
       0.}, RotationMatrix :> {{-0.2988670927346044, -0.9542947452859439, 
       0.}, {0.9542947452859439, -0.2988670927346044, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02524255363827332, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28915664833113564`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.292211309311746`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4084276518379489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.2988670927346044, -0.9542947452859439, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.675336249011812, 0.0591858274929169, 0.}, 
      Optica`Optica`RayEnd :> {8.30451965388601, -0.5884010241932411, 0.}, 
      RotationMatrix :> {{0.6968421135372873, -0.7172245595354956, 0.}, {
       0.7172245595354956, 0.6968421135372873, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2926493047834892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9029066881167064, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.176418380084115`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18384836117138856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6968421135372873, -0.7172245595354956, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.30451965388601, -0.5884010241932411, 0.}, 
      Optica`Optica`RayEnd :> {8.454284569695465, -0.7830988991393053, 0.}, 
      RotationMatrix :> {{0.6097039055154245, -0.7926292623914648, 0.}, {
       0.7926292623914648, 0.6097039055154245, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28868765007548547`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24563548708589877`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.539958900971246`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4022529008240797, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.6097039055154245, -0.7926292623914648, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.850782598441062, 0.07277791814304138, 0.}, 
      Optica`Optica`RayEnd :> {7.87963114875032, 0.08133101104005919, 0.}, 
      RotationMatrix :> {{0.9587494486833137, 0.2842525191611169, 
       0.}, {-0.2842525191611169, 0.9587494486833137, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021694254553177014`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.030089769906910917`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.26728236081961, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30191480806864585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9587494486833137, 0.2842525191611169, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.87963114875032, 0.08133101104005919, 0.}, 
      Optica`Optica`RayEnd :> {8.093840169841501, 0.11788342776077729`, 0.}, 
      RotationMatrix :> {{0.9857515794176407, 0.1682076801921542, 
       0.}, {-0.1682076801921542, 0.9857515794176407, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021376871550046972`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21730527808814654`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.588894172390066`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03042043166249108, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9857515794176407, 0.1682076801921542, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.983547199606125, 1.1459838153379867`, 0.}, 
      Optica`Optica`RayEnd :> {6.852980997598422, 1.167184912738187, 0.}, 
      RotationMatrix :> {{-0.987071770600787, 0.16027888096385756`, 
       0.}, {-0.16027888096385756`, -0.987071770600787, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012597079709539365`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13227630036287347`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.651134596318123`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17495943617945622`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.987071770600787, 0.16027888096385756`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.852980997598422, 1.167184912738187, 0.}, 
      Optica`Optica`RayEnd :> {6.569808117033248, 1.2291413933762683`, 0.}, 
      RotationMatrix :> {{-0.9768910769012311, 0.21373774554521724`, 
       0.}, {-0.21373774554521724`, -0.9768910769012311, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012544637138556657`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28987149873803614`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.080144414450416`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12801544356389144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9768910769012311, 0.21373774554521724`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.863324853607964, 1.031608164437147, 0.}, 
      Optica`Optica`RayEnd :> {6.783168053508213, 0.9171501968809312, 0.}, 
      RotationMatrix :> {{-0.5736363085510192, -0.8191101180622536, 0.}, {
       0.8191101180622536, -0.5736363085510192, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1793050907758053, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1397345302326211, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.906715892850482`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2151216980163771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5736363085510192, -0.8191101180622536, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.783168053508213, 0.9171501968809312, 0.}, 
      Optica`Optica`RayEnd :> {6.61876224892598, 0.6526344388411479, 0.}, 
      RotationMatrix :> {{-0.5278810623375086, -0.8493183054811797, 0.}, {
       0.8493183054811797, -0.5278810623375086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.178553439888321, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3114447861687407, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.367654176380219`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2559629316601262, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5278810623375086, -0.8493183054811797, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.914027006419358, 0.8736066021139146, 0.}, 
      Optica`Optica`RayEnd :> {7.066867649932133, 0.6002952428894279, 0.}, 
      RotationMatrix :> {{0.48808372587206317`, -0.8727968128601548, 0.}, {
       0.8727968128601548, 0.48808372587206317`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011087360641710873`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31314431400000814`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.384672271605677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04680238617350885, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.48808372587206317`, -0.8727968128601548, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.066867649932133, 0.6002952428894279, 0.}, 
      Optica`Optica`RayEnd :> {7.150151747661281, 0.39767247546671286`, 0.}, 
      RotationMatrix :> {{0.3801689421901667, -0.9249170640625077, 0.}, {
       0.9249170640625077, 0.3801689421901667, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010922902169554315`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21907128249179036`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.708897769693527`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3168070746004548, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3801689421901667, -0.9249170640625077, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.346007987984193, 2.1354637918059716`, 0.}, 
      Optica`Optica`RayEnd :> {7.327120090947857, 2.1718958268236905`, 0.}, 
      RotationMatrix :> {{-0.4602636248299924, 0.8877822906875057, 
       0.}, {-0.8877822906875057, -0.4602636248299924, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.375005953813934, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04103712745779785, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.119219047817943`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1909326373843794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4602636248299924, 0.8877822906875057, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.327120090947857, 2.1718958268236905`, 0.}, 
      Optica`Optica`RayEnd :> {7.184201931052216, 2.420319605206351, 0.}, 
      RotationMatrix :> {{-0.4986664328231548, 0.8667939713538788, 
       0.}, {-0.8667939713538788, -0.4986664328231548, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3701762291127424`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2866007224238509, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.543388117005241`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30351008336906904`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4986664328231548, 0.8667939713538788, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.066377499692184, 2.2089179863153836`, 0.}, 
      Optica`Optica`RayEnd :> {7.898965312849362, 2.243527325900353, 0.}, 
      RotationMatrix :> {{-0.9792925141756927, 0.20245041782977324`, 
       0.}, {-0.20245041782977324`, -0.9792925141756927, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2641689589797744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17095217661674764`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.555149942140938`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35626855929039974`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9792925141756927, 0.20245041782977324`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.898965312849362, 2.243527325900353, 0.}, 
      Optica`Optica`RayEnd :> {7.585569373781221, 2.3098714954677755`, 0.}, 
      RotationMatrix :> {{-0.9783187999875878, 0.20710462474518854`, 
       0.}, {-0.20710462474518854`, -0.9783187999875878, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26351488861141836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3203413233724191, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.02925510073212, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08120817888912812, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9783187999875878, 0.20710462474518854`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.269418053371558, 2.1084494459656544`, 0.}, 
      Optica`Optica`RayEnd :> {8.251000233336963, 1.8908622107119537`, 0.}, 
      RotationMatrix :> {{-0.0843440637813451, -0.996436690866433, 0.}, {
       0.996436690866433, -0.0843440637813451, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2622080760166959, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21836533845868483`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.436250247986802`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19641972233657484`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.0843440637813451, -0.996436690866433, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.251000233336963, 1.8908622107119537`, 0.}, 
      Optica`Optica`RayEnd :> {8.226143229094154, 1.6084734436314265`, 0.}, 
      RotationMatrix :> {{-0.08768500806499306, -0.996148251697829, 0.}, {
       0.996148251697829, -0.08768500806499306, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2615603495313354, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28348066324387494`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.855801629587738`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27372447824114043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.08768500806499306, -0.996148251697829, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.394212442133696, 1.133243022143843, 0.}, 
      Optica`Optica`RayEnd :> {8.251696866129556, 0.9374730351937544, 0.}, 
      RotationMatrix :> {{-0.5885427671349389, -0.8084660854068948, 0.}, {
       0.8084660854068948, -0.5885427671349389, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07646682752923194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2421499064510034, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.676344199147742`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16662762065239073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5885427671349389, -0.8084660854068948, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.251696866129556, 0.9374730351937544, 0.}, 
      Optica`Optica`RayEnd :> {8.084613540559982, 0.6849672883762922, 0.}, 
      RotationMatrix :> {{-0.5518299997001511, -0.8339566244301503, 0.}, {
       0.8339566244301503, -0.5518299997001511, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07619447622862997, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3027804317640638, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.124459238158558`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27631933863722424`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5518299997001511, -0.8339566244301503, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.6564143033686465`, 1.2250070433451765`, 0.},
       Optica`Optica`RayEnd :> {7.6385450164797195`, 1.1740699618890027`, 0.},
       RotationMatrix :> {{-0.331032072091207, -0.9436195034265673, 0.}, {
       0.9436195034265673, -0.331032072091207, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024599086842187857`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.053980530575306974`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.049967673012382`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09111356000812504, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.331032072091207, -0.9436195034265673, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.6385450164797195`, 1.1740699618890027`, 0.},
       Optica`Optica`RayEnd :> {7.517440732883323, 0.8653015214522295, 0.}, 
      RotationMatrix :> {{-0.36513618755352245`, -0.9309541151629753, 0.}, {
       0.9309541151629753, -0.36513618755352245`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024521132686194165`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33166880666585735`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.54083750687785, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26741525767977314`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.36513618755352245`, -0.9309541151629753, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.430375912009466, 0.283208622726918, 0.}, 
      Optica`Optica`RayEnd :> {7.421668960201598, 0.06043892671619491, 0.}, 
      RotationMatrix :> {{-0.039055172424785595`, -0.9992370557114408, 0.}, {
       0.9992370557114408, -0.039055172424785595`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20141331544426683`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2229397866476384, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.57804242657443, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37003628811032757`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.039055172424785595`, -0.9992370557114408, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.421668960201598, 0.06043892671619491, 0.}, 
      Optica`Optica`RayEnd :> {7.432955462470727, -0.16461433324118624`, 0.}, 
      RotationMatrix :> {{0.050087414328705566`, -0.9987448377467908, 0.}, {
       0.9987448377467908, 0.050087414328705566`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19979764395859306`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22533609331599694`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.911539844682107`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4018224905042424, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.050087414328705566`, -0.9987448377467908, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.585010064392459, 1.196668184852395, 0.}, 
      Optica`Optica`RayEnd :> {5.38361273321551, 1.1699175830622408`, 0.}, 
      RotationMatrix :> {{-0.9912937903191394, -0.13166860398254848`, 0.}, {
       0.13166860398254848`, -0.9912937903191394, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.33710362491899387`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20316613817595922`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.57281330744318, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.282337305663464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9912937903191394, -0.13166860398254848`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.38361273321551, 1.1699175830622408`, 0.}, 
      Optica`Optica`RayEnd :> {5.095547716240053, 1.1493290099655205`, 0.}, 
      RotationMatrix :> {{-0.9974556228700514, -0.07129011435617845, 0.}, {
       0.07129011435617845, -0.9974556228700514, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.335538024806492, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28879983266482295`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.000237059787118`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2781222968970381, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9974556228700514, -0.07129011435617845, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.869019545342315, 0.9045133912008863, 0.}, 
      Optica`Optica`RayEnd :> {4.6601133026574955`, 0.9110461907966975, 0.}, 
      RotationMatrix :> {{-0.9995114067544852, 0.03125616367484854, 
       0.}, {-0.03125616367484854, -0.9995114067544852, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2867799236082485, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2090083627591193, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.79953211932392, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21859296494332575`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9995114067544852, 0.03125616367484854, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6601133026574955`, 0.9110461907966975, 0.}, 
      Optica`Optica`RayEnd :> {4.349677723758777, 0.9390518793580136, 0.}, 
      RotationMatrix :> {{-0.9959553731423793, 0.08984928886097476, 
       0.}, {-0.08984928886097476, -0.9959553731423793, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28549430929952446`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31169627402004, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.26084260487358, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20149839548184606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9959553731423793, 0.08984928886097476, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8802831926153463`, 1.0795703200884155`, 0.},
       Optica`Optica`RayEnd :> {3.6903964674858494`, 1.0595389433095326`, 0.},
       RotationMatrix :> {{-0.9944818182062075, -0.10490907137743066`, 0.}, {
       0.10490907137743066`, -0.9944818182062075, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2900425045471786, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19094036879628845`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.37346316216975, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3458520902351315, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9944818182062075, -0.10490907137743066`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6903964674858494`, 1.0595389433095326`, 0.},
       Optica`Optica`RayEnd :> {3.3824431749592, 1.0217437832545335`, 0.}, 
      RotationMatrix :> {{-0.9925526803510646, -0.12181615955166485`, 0.}, {
       0.12181615955166485`, -0.9925526803510646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2892851428382827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.310263927167802, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.832653774378095`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.019551243521048214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9925526803510646, -0.12181615955166485`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.613447268885137, -1.6437226269738707`, 0.}, 
      Optica`Optica`RayEnd :> {6.61359122751234, -1.6461805843378567`, 0.}, 
      RotationMatrix :> {{0.05846820418709955, -0.9982892712531446, 0.}, {
       0.9982892712531446, 0.05846820418709955, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009211475820204557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0024621694680747102`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.184902203352877`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3461926233389503, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.05846820418709955, -0.9982892712531446, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.61359122751234, -1.6461805843378567`, 0.}, 
      Optica`Optica`RayEnd :> {6.645263755494122, -1.866185420573217, 0.}, 
      RotationMatrix :> {{0.1424938298289274, -0.9897956902617245, 0.}, {
       0.9897956902617245, 0.1424938298289274, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009144178844074995, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22227297855498412`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.513866211614253`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4321216933131855, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1424938298289274, -0.9897956902617245, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1516229963101905`, 3.04052253545903, 0.}, 
      Optica`Optica`RayEnd :> {7.1594300176847945`, 3.096458406591349, 0.}, 
      RotationMatrix :> {{0.13823104713110107`, 0.9904000088898619, 
       0.}, {-0.9904000088898619, 0.13823104713110107`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17846540055055785`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05647806000629715, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.057430995461434`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37369849770671837`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13823104713110107`, 0.9904000088898619, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1594300176847945`, 3.096458406591349, 0.}, 
      Optica`Optica`RayEnd :> {7.211612833848461, 3.428151601916212, 0.}, 
      RotationMatrix :> {{0.15541105427626567`, 0.9878498895119332, 
       0.}, {-0.9878498895119332, 0.15541105427626567`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17799828216807748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33577287282862617`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.5543748472478, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25364979986025965`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15541105427626567`, 0.9878498895119332, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.488034289750155, 2.6797783985379304`, 0.}, 
      Optica`Optica`RayEnd :> {6.512358282793377, 2.8102062193222936`, 0.}, 
      RotationMatrix :> {{0.18333299134353187`, 0.9830508706496484, 
       0.}, {-0.9830508706496484, 0.18333299134353187`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09317864868467558, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1326765731850377, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.587353135051494`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18691044211969832`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.18333299134353187`, 0.9830508706496484, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.512358282793377, 2.8102062193222936`, 0.}, 
      Optica`Optica`RayEnd :> {6.560121556279733, 3.120599832514311, 0.}, 
      RotationMatrix :> {{0.15208956539625448`, 0.98836671539342, 
       0.}, {-0.98836671539342, 0.15208956539625448`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09289994309639356, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3140470114561326, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.05214271200657, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03884132054238387, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15208956539625448`, 0.98836671539342, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.973860009185009, 2.4233855638274715`, 0.}, 
      Optica`Optica`RayEnd :> {4.42036330315144, 2.7385215816048163`, 0.}, 
      RotationMatrix :> {{-0.8690183803972727, 0.49477980408632294`, 
       0.}, {-0.49477980408632294`, -0.8690183803972727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8628874678008174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6369217481689365, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.659867897716822`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3093443290327457, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8690183803972727, 0.49477980408632294`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.42036330315144, 2.7385215816048163`, 0.}, 
      Optica`Optica`RayEnd :> {4.138474141033417, 2.894172329501781, 0.}, 
      RotationMatrix :> {{-0.875412529266712, 0.4833765650120591, 
       0.}, {-0.4833765650120591, -0.875412529266712, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8581358924226263`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3220072282426058, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.13643859551588, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2941238954880902, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.875412529266712, 0.4833765650120591, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.911576044151911, 2.523739366932794, 0.}, 
      Optica`Optica`RayEnd :> {4.88366247065081, 2.686708323647802, 0.}, 
      RotationMatrix :> {{-0.16882302749175626`, 0.9856463794832895, 
       0.}, {-0.9856463794832895, -0.16882302749175626`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4301777177836793, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16534221614088643`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.202755415442848`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22592954348268363`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.16882302749175626`, 0.9856463794832895, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.88366247065081, 2.686708323647802, 0.}, 
      Optica`Optica`RayEnd :> {4.821355136964984, 2.914793700563985, 0.}, 
      RotationMatrix :> {{-0.2635198202505637, 0.964653981661357, 
       0.}, {-0.964653981661357, -0.2635198202505637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4261380628670148, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23644268437410781`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.552690588316526`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03222273264261277, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2635198202505637, 0.964653981661357, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.949638783966609, 2.6355490531667902`, 0.}, 
      Optica`Optica`RayEnd :> {5.30327979785749, 3.0437173209918855`, 0.}, 
      RotationMatrix :> {{0.654819695027326, 0.7557851328283184, 
       0.}, {-0.7557851328283184, 0.654819695027326, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2672446857022981, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.540058609379676, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.879679473026442`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16952933755436228`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.654819695027326, 0.7557851328283184, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.30327979785749, 3.0437173209918855`, 0.}, 
      Optica`Optica`RayEnd :> {5.4372327959670805`, 3.147729248239088, 0.}, 
      RotationMatrix :> {{0.789848418083539, 0.6133021086307548, 
       0.}, {-0.6133021086307548, 0.789848418083539, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2514363227260545, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1695932979578646, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.13067755400408, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2901868960771059, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.789848418083539, 0.6133021086307548, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.4372327959670805`, 3.147729248239088, 0.}, 
      Optica`Optica`RayEnd :> {5.5885091764360935`, 3.0710654143640497`, 0.}, 
      RotationMatrix :> {{0.8919950392532463, -0.4520451857365578, 0.}, {
       0.4520451857365578, 0.8919950392532463, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014873248628385755`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16959329795786504`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.381675634981722`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24413388957996074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8919950392532463, -0.4520451857365578, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0602158577717615`, 2.677056749400575, 0.}, 
      Optica`Optica`RayEnd :> {5.1235570583401175`, 2.675363415373785, 0.}, 
      RotationMatrix :> {{0.9996428505520377, -0.02672398436227935, 0.}, {
       0.02672398436227935, 0.9996428505520377, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16602375967792204`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06336383092559178, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.415712560541586`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18639129420398548`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9996428505520377, -0.02672398436227935, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1235570583401175`, 2.675363415373785, 0.}, 
      Optica`Optica`RayEnd :> {5.3812716959614155`, 2.6789453650180284`, 0.}, 
      RotationMatrix :> {{0.9999034242994321, 0.013897556413578961`, 
       0.}, {-0.013897556413578961`, 0.9999034242994321, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16546651203471324`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2577395289968748, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.79716706345696, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31941925485884315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999034242994321, 0.013897556413578961`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.162450707646214, 2.6179110515934285`, 0.}, 
      Optica`Optica`RayEnd :> {5.522941060404558, 2.1538937358320926`, 0.}, 
      RotationMatrix :> {{0.6135036350833503, -0.7896918954500636, 0.}, {
       0.7896918954500636, 0.6135036350833503, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1031410173981778, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5875928554349433, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.29298354402773, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31354154005928025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6135036350833503, -0.7896918954500636, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.522941060404558, 2.1538937358320926`, 0.}, 
      Optica`Optica`RayEnd :> {5.644278954911342, 1.9798251660506894`, 0.}, 
      RotationMatrix :> {{0.5718477776437675, -0.8203597498682411, 0.}, {
       0.8203597498682411, 0.5718477776437675, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10273052734101643`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21218565368347314`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.607018311479273`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2569436647470679, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.5718477776437675, -0.8203597498682411, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.18158680607505, 2.5013606855070525`, 0.}, 
      Optica`Optica`RayEnd :> {5.152322539864831, 2.372367037486031, 0.}, 
      RotationMatrix :> {{-0.22124387230273998`, -0.9752185134463391, 0.}, {
       0.9752185134463391, -0.22124387230273998`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06407558466672793, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13227153324352808`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.857657062934848`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.422833045095208, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.22124387230273998`, -0.9752185134463391, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.152322539864831, 2.372367037486031, 0.}, 
      Optica`Optica`RayEnd :> {5.118213821951841, 2.1161797360726418`, 0.}, 
      RotationMatrix :> {{-0.13197519710502423`, -0.9912530188347921, 0.}, {
       0.9912530188347921, -0.13197519710502423`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06354535848363348, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25844794068272753`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.240160015145285`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3382830137792641, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13197519710502423`, -0.9912530188347921, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1036313876707275`, 2.412630020912711, 0.}, 
      Optica`Optica`RayEnd :> {4.883622081333916, 2.302493471582756, 0.}, 
      RotationMatrix :> {{-0.894212655040459, -0.4476424103740527, 0.}, {
       0.4476424103740527, -0.894212655040459, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039806477131525075`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24603689636539197`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.18490674016176, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3506094819795322, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.894212655040459, -0.4476424103740527, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.883622081333916, 2.302493471582756, 0.}, 
      Optica`Optica`RayEnd :> {4.60282190644634, 2.1683820226624086`, 0.}, 
      RotationMatrix :> {{-0.9023646010421642, -0.43097346413209103`, 0.}, {
       0.43097346413209103`, -0.9023646010421642, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03970141247948349, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3111826135059738, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.6454570081506, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29094505234124396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9023646010421642, -0.43097346413209103`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.985587288433265, 2.416601007334562, 0.}, 
      Optica`Optica`RayEnd :> {4.384889466004231, 2.6844616944699413`, 0.}, 
      RotationMatrix :> {{-0.9133121062066911, 0.40726035487915657`, 
       0.}, {-0.40726035487915657`, -0.9133121062066911, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024729475819285418`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.6577136318973635, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.91135765641822, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13138239892680412`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9133121062066911, 0.40726035487915657`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.384889466004231, 2.6844616944699413`, 0.}, 
      Optica`Optica`RayEnd :> {4.108774052035784, 2.8195567145089377`, 0.}, 
      RotationMatrix :> {{-0.8982492005507269, 0.439486488654633, 
       0.}, {-0.439486488654633, -0.8982492005507269, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024651918776346305`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3073928858485561, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.366299127474086`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06419375227402802, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8982492005507269, 0.439486488654633, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.913771130957169, 2.5103699660752623`, 0.}, 
      Optica`Optica`RayEnd :> {4.870247198990103, 2.669012116609145, 0.}, 
      RotationMatrix :> {{-0.26457625775450316`, 0.9643647670008592, 
       0.}, {-0.9643647670008592, -0.26457625775450316`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015363001661159345`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16450429957873125`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.425261241754875`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16118539418227748`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.26457625775450316`, 0.9643647670008592, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.870247198990103, 2.669012116609145, 0.}, 
      Optica`Optica`RayEnd :> {4.781731117882949, 2.928205971915999, 0.}, 
      RotationMatrix :> {{-0.32317937065998037`, 0.9463377274418566, 
       0.}, {-0.9463377274418566, -0.32317937065998037`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015290852539424834`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27389149538347923`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.830620654922424`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16199385854257997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.32317937065998037`, 0.9463377274418566, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.9406965792129025`, 2.6253708283945265`, 0.},
       Optica`Optica`RayEnd :> {5.457306936761345, 3.355448852941872, 0.}, 
      RotationMatrix :> {{0.5776239750725581, 0.8163029728117959, 
       0.}, {-0.8163029728117959, 0.5776239750725581, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009544149733118451, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8943713901133485, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.578087233714882`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33092222357484724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5776239750725581, 0.8163029728117959, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.457306936761345, 3.355448852941872, 0.}, 
      Optica`Optica`RayEnd :> {5.634090986696744, 3.6286175405357364`, 0.}, 
      RotationMatrix :> {{0.5433115874088591, 0.8395311304455985, 
       0.}, {-0.8395311304455985, 0.5433115874088591, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009511743778559264, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3253824398969871, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.059653244762423`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20637755631611293`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5433115874088591, 0.8395311304455985, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1188388464948025`, 0.6604338486612473, 0.}, 
      Optica`Optica`RayEnd :> {4.1166751170879525`, 0.6597018252416424, 0.}, 
      RotationMatrix :> {{-0.947257940793193, -0.3204721416975875, 0.}, {
       0.3204721416975875, -0.947257940793193, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08373921136943206, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.002284202975420043, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.075246104612162`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13969541375954359`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.947257940793193, -0.3204721416975875, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1166751170879525`, 0.6597018252416424, 0.}, 
      Optica`Optica`RayEnd :> {3.832018778269499, 0.5492703607319532, 0.}, 
      RotationMatrix :> {{-0.9323011105486101, -0.3616830646710283, 0.}, {
       0.3616830646710283, -0.9323011105486101, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0834447391571244, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3053266113251198, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.52712948937334, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01194528956397733, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9323011105486101, -0.3616830646710283, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.143855725421484, 1.3816868608239041`, 0.}, 
      Optica`Optica`RayEnd :> {5.132335989322367, 1.3897219659560067`, 0.}, 
      RotationMatrix :> {{-0.8201910997557105, 0.5720896432216872, 
       0.}, {-0.5720896432216872, -0.8201910997557105, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03768646910093345, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01404518544830381, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.238632478845771`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17647035133200312`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8201910997557105, 0.5720896432216872, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.132335989322367, 1.3897219659560067`, 0.}, 
      Optica`Optica`RayEnd :> {4.8547025614206625`, 1.5800455557922033`, 0.}, 
      RotationMatrix :> {{-0.824803138715788, 0.5654200052744717, 
       0.}, {-0.5654200052744717, -0.824803138715788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037592344494505804`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3366056879147879, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.689684100651586`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24644121533762903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.824803138715788, 0.5654200052744717, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.072201536619233, 1.2023600096651306`, 0.}, 
      Optica`Optica`RayEnd :> {4.851498967343398, 1.2250555314779823`, 0.}, 
      RotationMatrix :> {{-0.9947542477803563, 0.10229362894597613`, 
       0.}, {-0.10229362894597613`, -0.9947542477803563, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09155049181583227, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22186642557023512`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.553511158231464`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2600849901396447, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9947542477803563, 0.10229362894597613`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.851498967343398, 1.2250555314779823`, 0.}, 
      Optica`Optica`RayEnd :> {4.613741195307599, 1.2388990593583549`, 0.}, 
      RotationMatrix :> {{-0.9983092025849776, 0.058126895961730075`, 
       0.}, {-0.058126895961730075`, -0.9983092025849776, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09122629485963236, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23816045311428494`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.872646165404605`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18723644239510345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9983092025849776, 0.058126895961730075`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.327993242796761, 1.1048759326021627`, 0.}, 
      Optica`Optica`RayEnd :> {5.210763959576821, 0.9057866227232705, 0.}, 
      RotationMatrix :> {{-0.5073992753760861, -0.8617110741703522, 0.}, {
       0.8617110741703522, -0.5073992753760861, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021995171031671156`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23103951643022994`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.227992561677153`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33121363392530756`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.5073992753760861, -0.8617110741703522, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.210763959576821, 0.9057866227232705, 0.}, 
      Optica`Optica`RayEnd :> {5.090100669028041, 0.7405292894550553, 0.}, 
      RotationMatrix :> {{-0.5896925977632256, -0.8076277856433979, 0.}, {
       0.8076277856433979, -0.5896925977632256, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02178238613968048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20462066338711055`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.502184250615882`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05438444296975686, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.5896925977632256, -0.8076277856433979, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.953065952582621, -0.6208304854292546, 0.}, 
      Optica`Optica`RayEnd :> {5.979795162103256, -0.8413281452657155, 0.}, 
      RotationMatrix :> {{0.12034121974929338`, -0.9927325877743973, 0.}, {
       0.9927325877743973, 0.12034121974929338`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008406955677190412, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2221118381242964, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.937424352652915`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3682198951635766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.12034121974929338`, -0.9927325877743973, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.979795162103256, -0.8413281452657155, 0.}, 
      Optica`Optica`RayEnd :> {6.021253812479882, -1.1394772355398624`, 0.}, 
      RotationMatrix :> {{0.1377282475702545, -0.9904700549846148, 0.}, {
       0.9904700549846148, 0.1377282475702545, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008384926219419794, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3010177731004477, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.382930656841577`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2619646707313838, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1377282475702545, -0.9904700549846148, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.8015864440438545`, -0.3685024860381718, 0.},
       Optica`Optica`RayEnd :> {7.865477093546045, -0.4111577264223858, 0.}, 
      RotationMatrix :> {{0.8316807760820552, -0.555254074001758, 0.}, {
       0.555254074001758, 0.8316807760820552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009191829442302282, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07682112096322759, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.28028566595308, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40498243212562635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8316807760820552, -0.555254074001758, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.865477093546045, -0.4111577264223858, 0.}, 
      Optica`Optica`RayEnd :> {8.090697161067123, -0.5731585137979203, 0.}, 
      RotationMatrix :> {{0.8118037281095526, -0.5839303957043434, 0.}, {
       0.5839303957043434, 0.8118037281095526, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009163249487429402, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2774316743353072, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.690884543969336`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3386792629141013, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8118037281095526, -0.5839303957043434, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9180161944865612`, 1.1494482120242693`, 0.},
       Optica`Optica`RayEnd :> {3.8621851503738815`, 1.158281382640382, 0.}, 
      RotationMatrix :> {{-0.9877145623329302, 0.1562688176043695, 
       0.}, {-0.1562688176043695, -0.9877145623329302, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15835655323663772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05652548442822359, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.222288297784498`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.037304268953977954`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9877145623329302, 0.1562688176043695, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8621851503738815`, 1.158281382640382, 0.}, 
      Optica`Optica`RayEnd :> {3.6713872384178625`, 1.2136497580075274`, 0.}, 
      RotationMatrix :> {{-0.9603793296253583, 0.2786961485710682, 
       0.}, {-0.2786961485710682, -0.9603793296253583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15573397530720887`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1986693237457004, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.516318896928134`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26432233112817677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9603793296253583, 0.2786961485710682, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.515237747523003, -1.3299214132440937`, 0.}, 
      Optica`Optica`RayEnd :> {3.3736817974158426`, -1.2779634997862737`, 0.},
       RotationMatrix :> {{-0.9387603764932424, 0.3445706829175469, 
       0.}, {-0.3445706829175469, -0.9387603764932424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009992787838718266, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15079029074058828`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.67844352585118, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3672774533768513, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9387603764932424, 0.3445706829175469, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3736817974158426`, -1.2779634997862737`, 
       0.}, Optica`Optica`RayEnd :> {3.062560437831467, -1.1680963505251802`, 
       0.}, RotationMatrix :> {{-0.9429336187983898, 0.33298076602075966`, 
       0.}, {-0.33298076602075966`, -0.9429336187983898, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00996739686590369, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3299504369998466, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.166770172610953`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2205118211543104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9429336187983898, 0.33298076602075966`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3631369823812154`, -1.436960415300968, 0.}, 
      Optica`Optica`RayEnd :> {3.2347894055906963`, -1.5697014360895865`, 0.},
       RotationMatrix :> {{-0.6951096006358186, -0.718903778752005, 0.}, {
       0.718903778752005, -0.6951096006358186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17186032965135978`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18464365428576912`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.999071081632877`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2948887374947094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6951096006358186, -0.718903778752005, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2347894055906963`, -1.5697014360895865`, 
       0.}, Optica`Optica`RayEnd :> {
       3.0912834629691233`, -1.7539364159912485`, 0.}, 
      RotationMatrix :> {{-0.614506272846346, -0.7889119346495471, 0.}, {
       0.7889119346495471, -0.614506272846346, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16989633312019414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23353047635602503`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.344696186639794`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06981704658450961, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.614506272846346, -0.7889119346495471, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3994379955641585`, -1.6193726603941647`, 
       0.}, Optica`Optica`RayEnd :> {3.4950612409166117`, -1.855056788319011, 
       0.}, RotationMatrix :> {{0.3759604613239186, -0.9266357059390197, 
       0.}, {0.9266357059390197, 0.3759604613239186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008976207603462818, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2543438876942609, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.36773344303141, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31923902102297824`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.3759604613239186, -0.9266357059390197, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4950612409166117`, -1.855056788319011, 0.}, 
      Optica`Optica`RayEnd :> {3.589344272267322, -2.1020351712178833`, 0.}, 
      RotationMatrix :> {{0.3566427811956743, -0.934240829026977, 0.}, {
       0.934240829026977, 0.3566427811956743, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008952112530770833, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2643626517116611, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.758990167564665`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.018408157084473766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3566427811956743, -0.934240829026977, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6764578941698423`, 1.912287471595425, 0.}, 
      Optica`Optica`RayEnd :> {3.659701915750172, 1.9542676047755663`, 0.}, 
      RotationMatrix :> {{-0.3707025523354642, 0.928751644785608, 
       0.}, {-0.928751644785608, -0.3707025523354642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.043428170148673055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04520060170642487, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.182650597257695`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.290109880341259, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3707025523354642, 0.928751644785608, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.659701915750172, 1.9542676047755663`, 0.}, 
      Optica`Optica`RayEnd :> {3.5671895390265544`, 2.1378958136711663`, 0.}, 
      RotationMatrix :> {{-0.44992833634526747`, 0.8930646629184136, 
       0.}, {-0.8930646629184136, -0.44992833634526747`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04309512000844569, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20561580423026468`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.486961987518486`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15460951095656747`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.44992833634526747`, 0.8930646629184136, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.8600772293281915`, 0.9108912178091552, 0.}, 
      Optica`Optica`RayEnd :> {7.917087917971804, 0.9252157528523273, 0.}, 
      RotationMatrix :> {{0.9698541668528468, 0.24368605835822812`, 
       0.}, {-0.24368605835822812`, 0.9698541668528468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08106832390627644, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058782743418642563`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.557182036064386`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36051648553621163`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9698541668528468, 0.24368605835822812`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.917087917971804, 0.9252157528523273, 0.}, 
      Optica`Optica`RayEnd :> {8.192257270270463, 1.011642970905468, 0.}, 
      RotationMatrix :> {{0.9540478274175413, 0.29965437256924604`, 
       0.}, {-0.29965437256924604`, 0.9540478274175413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08070835521041393, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2884230165310484, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.984048100530337`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3758270202900077, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9540478274175413, 0.29965437256924604`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.563509470794093, 1.7232149979237499`, 0.}, 
      Optica`Optica`RayEnd :> {4.491949144930795, 1.8183417237540334`, 0.}, 
      RotationMatrix :> {{-0.6011568217446502, 0.7991310753999431, 
       0.}, {-0.7991310753999431, -0.6011568217446502, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.050512587639212486`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11903770077102209`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.332907751611893`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36137455251421186`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6011568217446502, 0.7991310753999431, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.491949144930795, 1.8183417237540334`, 0.}, 
      Optica`Optica`RayEnd :> {4.380048048528092, 2.0105057011738268`, 0.}, 
      RotationMatrix :> {{-0.5032180906402802, 0.8641594489747535, 
       0.}, {-0.8641594489747535, -0.5032180906402802, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0497964265762504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2223709729122076, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.66201679152196, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11495528227187349`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5032180906402802, 0.8641594489747535, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1420754931227135`, 0.6299410302479087, 0.}, 
      Optica`Optica`RayEnd :> {4.13941268460613, 0.6298041521065122, 0.}, 
      RotationMatrix :> {{-0.9986814436190989, -0.05133589553978195, 0.}, {
       0.05133589553978195, -0.9986814436190989, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012792309006811277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0026663242153910473`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.458516355089179`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24445703644656896`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9986814436190989, -0.05133589553978195, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.13941268460613, 0.6298041521065122, 0.}, 
      Optica`Optica`RayEnd :> {3.84117167131676, 0.5997028117287332, 0.}, 
      RotationMatrix :> {{-0.9949451963960387, -0.10041940135475233`, 0.}, {
       0.10041940135475233`, -0.9949451963960387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012743424265618152`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2997562221212583, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      14.902155563828641`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16446731269684647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9949451963960387, -0.10041940135475233`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6730830867006965`, -1.3644129827131524`, 
       0.}, Optica`Optica`RayEnd :> {4.655793407407262, -1.394049582502252, 
       0.}, RotationMatrix :> {{-0.503907182357983, -0.8637578083977225, 
       0.}, {0.8637578083977225, -0.503907182357983, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008023739835011482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03431123805882087, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.768658916442217`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16817746641900874`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 90, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.503907182357983, -0.8637578083977225, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.212311557604752, -0.4341530931148644, 0.}, 
      Optica`Optica`RayEnd :> {7.338588345914811, -0.6082107515768171, 0.}, 
      RotationMatrix :> {{0.5872265901009059, -0.8094225916531254, 0.}, {
       0.8094225916531254, 0.5872265901009059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009135421323814214, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21503928881755788`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.918992050826233`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.036252769662518, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5872265901009059, -0.8094225916531254, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.338588345914811, -0.6082107515768171, 0.}, 
      Optica`Optica`RayEnd :> {7.418876778563906, -0.7867706051417519, 0.}, 
      RotationMatrix :> {{0.4100949289066539, -0.9120428439964025, 0.}, {
       0.9120428439964025, 0.4100949289066539, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008517132002126502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19578011574820176`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.20874662213357, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3970986612390407, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4100949289066539, -0.9120428439964025, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.435909779053422, 2.6593680888455133`, 0.}, 
      Optica`Optica`RayEnd :> {5.3888323111581675`, 2.7101479142359346`, 0.}, 
      RotationMatrix :> {{-0.6798675074497078, 0.7333349659699312, 
       0.}, {-0.7333349659699312, -0.6798675074497078, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18871195105622218`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06924506227963424, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.885853001029048`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3995978669464272, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6798675074497078, 0.7333349659699312, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3888323111581675`, 2.7101479142359346`, 0.},
       Optica`Optica`RayEnd :> {5.224191606502897, 2.8622039459876105`, 0.}, 
      RotationMatrix :> {{-0.7346255172645006, 0.678472806664986, 
       0.}, {-0.678472806664986, -0.7346255172645006, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18750941602837956`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2241151454530695, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.217543416299591`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33129561524231455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7346255172645006, 0.678472806664986, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8978100437530285`, 1.696982269817469, 0.}, 
      Optica`Optica`RayEnd :> {6.956747605735684, 1.6533453290572493`, 0.}, 
      RotationMatrix :> {{0.8036909608752538, -0.595046922021625, 0.}, {
       0.595046922021625, 0.8036909608752538, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03352366343497384, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07333361310729362, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.774553751890979`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2517765652413333, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8036909608752538, -0.595046922021625, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.956747605735684, 1.6533453290572493`, 0.}, 
      Optica`Optica`RayEnd :> {7.093661954241497, 1.5245104065784694`, 0.}, 
      RotationMatrix :> {{0.728268057670746, -0.685292372769811, 0.}, {
       0.685292372769811, 0.728268057670746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03304788095536744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1879999363746826, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.052793657725509`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41815534017111305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.728268057670746, -0.685292372769811, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.665193389335898, 1.9205603235213684`, 0.}, 
      Optica`Optica`RayEnd :> {6.69219454215379, 1.82495236190656, 0.}, 
      RotationMatrix :> {{0.2717846656745479, -0.96235809109924, 0.}, {
       0.96235809109924, 0.2717846656745479, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013858168682042577`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09934759472495487, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.948861549936513`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43055338997369896`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2717846656745479, -0.96235809109924, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.69219454215379, 1.82495236190656, 0.}, 
      Optica`Optica`RayEnd :> {6.7707649418967755`, 1.571081812287572, 0.}, 
      RotationMatrix :> {{0.2956542651189007, -0.9552950096786864, 0.}, {
       0.9552950096786864, 0.2956542651189007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013819595685257417`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26575094295151513`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.342172945504755`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22048174423647393`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2956542651189007, -0.9552950096786864, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.585555138189024, 2.638730032428786, 0.}, 
      Optica`Optica`RayEnd :> {6.578523583257114, 2.6384968249285388`, 0.}, 
      RotationMatrix :> {{-0.9994504664902579, -0.033147624838056944`, 0.}, {
       0.033147624838056944`, -0.9994504664902579, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0194636450657914, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007035421131576518, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.629418330425775`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10202013897499644`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9994504664902579, -0.033147624838056944`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.578523583257114, 2.6384968249285388`, 0.}, 
      Optica`Optica`RayEnd :> {6.327120076572609, 2.606217434266993, 0.}, 
      RotationMatrix :> {{-0.9918576754896702, -0.12735129199276649`, 0.}, {
       0.12735129199276649`, -0.9918576754896702, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019289780411100174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25346731985553256`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.004549963811963`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2766489326989976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9918576754896702, -0.12735129199276649`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.692367912281009, 2.8987001271996897`, 0.}, 
      Optica`Optica`RayEnd :> {6.829041889572819, 3.1787664066759094`, 0.}, 
      RotationMatrix :> {{0.4385695084171239, 0.8986972717699554, 
       0.}, {-0.8986972717699554, 0.4385695084171239, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.8970398808552136`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31163584031432295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.453548256944156`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01487038613218572, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4385695084171239, 0.8986972717699554, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.829041889572819, 3.1787664066759094`, 0.}, 
      Optica`Optica`RayEnd :> {6.883506851961149, 3.3440089025840014`, 0.}, 
      RotationMatrix :> {{0.3130402146814892, 0.9497398717502419, 
       0.}, {-0.9497398717502419, 0.3130402146814892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.818583817398182, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17398711039010323`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.71104918032151, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30913122198391296`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3130402146814892, 0.9497398717502419, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.883506851961149, 3.3440089025840014`, 0.}, 
      Optica`Optica`RayEnd :> {6.730079919853941, 3.4260557860474723`, 0.}, 
      RotationMatrix :> {{-0.8818293019707185, 0.47156874598072546`, 
       0.}, {-0.47156874598072546`, -0.8818293019707185, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07687656874273986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17398711039010334`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.968550103698863`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3340267400652449, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 92, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8818293019707185, 0.47156874598072546`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.872093610858287, 2.6826165966951008`, 0.}, 
      Optica`Optica`RayEnd :> {6.91602272532324, 2.622319810077522, 0.}, 
      RotationMatrix :> {{0.5888457465127058, -0.8082454372366682, 0.}, {
       0.8082454372366682, 0.5888457465127058, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019271618048410034`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07460207486444824, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.551888376054825`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4060067008800814, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5888457465127058, -0.8082454372366682, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.91602272532324, 2.622319810077522, 0.}, 
      Optica`Optica`RayEnd :> {7.090703027845902, 2.372357661055526, 0.}, 
      RotationMatrix :> {{0.5728168804933994, -0.8196833665640711, 0.}, {
       0.8196833665640711, 0.5728168804933994, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01922031977264812, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30494964179861483`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.003213845916775`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13446549629732651`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5728168804933994, -0.8196833665640711, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.939781396097772, 2.361951907883309, 0.}, 
      Optica`Optica`RayEnd :> {5.772658749981498, 2.303802156351581, 0.}, 
      RotationMatrix :> {{-0.9444614831544184, -0.3286221338220463, 0.}, {
       0.3286221338220463, -0.9444614831544184, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013930309314701081`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1769501976492453, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.871538972020982`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.039480507426938864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9444614831544184, -0.3286221338220463, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.772658749981498, 2.303802156351581, 0.}, 
      Optica`Optica`RayEnd :> {5.589205417729699, 2.225663533370224, 0.}, 
      RotationMatrix :> {{-0.9200220035673978, -0.3918667030404979, 0.}, {
       0.3918667030404979, -0.9200220035673978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013856605921443037`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1994010268672453, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.166652491784504`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08105810909685572, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9200220035673978, -0.3918667030404979, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.391351704172249, 2.625593379193287, 0.}, 
      Optica`Optica`RayEnd :> {5.355124772949332, 2.6352776953953128`, 0.}, 
      RotationMatrix :> {{-0.9660767374370904, 0.2582551788113956, 
       0.}, {-0.2582551788113956, -0.9660767374370904, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03290167705419436, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03749902033561328, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.704116470000445`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15841110363229638`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9660767374370904, 0.2582551788113956, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.355124772949332, 2.6352776953953128`, 0.}, 
      Optica`Optica`RayEnd :> {5.1144186586145235`, 2.7118462900651146`, 0.}, 
      RotationMatrix :> {{-0.9529483280822111, 0.30313278279545663`, 
       0.}, {-0.30313278279545663`, -0.9529483280822111, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03278073812803582, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2525909403915164, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.07795106177989, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.054324310833512225`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9529483280822111, 0.30313278279545663`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.653693099468152, 1.5369387176341482`, 0.}, 
      Optica`Optica`RayEnd :> {7.849169220663623, 1.4859892362381888`, 0.}, 
      RotationMatrix :> {{0.9676708011649942, -0.252216614386715, 0.}, {
       0.252216614386715, 0.9676708011649942, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17492238395008286`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20200684050829573`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.79539927877178, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08123798996400766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9676708011649942, -0.252216614386715, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.849169220663623, 1.4859892362381888`, 0.}, 
      Optica`Optica`RayEnd :> {8.113793252067586, 1.4194705564399406`, 0.}, 
      RotationMatrix :> {{0.9698289482108617, -0.24378640489619624`, 0.}, {
       0.24378640489619624`, 0.9698289482108617, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17448462683892865`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27285639585427907`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.199226744636114`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32888742059579024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9698289482108617, -0.24378640489619624`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.963243164986898, 0.40461823168334243`, 0.}, 
      Optica`Optica`RayEnd :> {4.864035069368825, 0.3001735008972025, 0.}, 
      RotationMatrix :> {{-0.6886969216269891, -0.7250493432460354, 0.}, {
       0.7250493432460354, -0.6886969216269891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012650261897218986`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1440518935146431, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.721988074335226`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3775230612502488, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6886969216269891, -0.7250493432460354, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.864035069368825, 0.3001735008972025, 0.}, 
      Optica`Optica`RayEnd :> {4.694976960098423, 0.14421027926079488`, 0.}, 
      RotationMatrix :> {{-0.7349993366060027, -0.678067824917784, 0.}, {
       0.678067824917784, -0.7349993366060027, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012585585767993008`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23001124062378003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.06240471045842, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35714425377480075`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7349993366060027, -0.678067824917784, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.693844003873882, 1.1857485126662142`, 0.}, 
      Optica`Optica`RayEnd :> {3.4228500119969545`, 1.264608325084982, 0.}, 
      RotationMatrix :> {{-0.9601713484824793, 0.2794118493431083, 
       0.}, {-0.2794118493431083, -0.9601713484824793, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08361915282499986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28223503263789823`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.462344363162897`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4097938056501906, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9601713484824793, 0.2794118493431083, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4228500119969545`, 1.264608325084982, 0.}, 
      Optica`Optica`RayEnd :> {3.1565195605696372`, 1.3367049720306945`, 0.}, 
      RotationMatrix :> {{-0.9652579306141116, 0.2612989234316925, 
       0.}, {-0.2612989234316925, -0.9652579306141116, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08339803321601268, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.275916356634204, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.87070057098152, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2139773694789121, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9652579306141116, 0.2612989234316925, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.2970211362664825`, 2.4039905965296344`, 0.},
       Optica`Optica`RayEnd :> {4.354927469531008, 2.660660901539697, 0.}, 
      RotationMatrix :> {{0.22007471704656215`, 0.9754830182616588, 
       0.}, {-0.9754830182616588, 0.22007471704656215`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00898624611352839, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26312124373775087`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.42541414692881, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014751948952568705`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.22007471704656215`, 0.9754830182616588, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.354927469531008, 2.660660901539697, 0.}, 
      Optica`Optica`RayEnd :> {4.388221823160652, 2.9095274470816745`, 0.}, 
      RotationMatrix :> {{0.13260255922972647`, 0.9911692899226283, 
       0.}, {-0.9911692899226283, 0.13260255922972647`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008914558721356186, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25108379372952966`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.797018161648515`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14560753670908175`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13260255922972647`, 0.9911692899226283, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8070783438029028`, 2.2959531760368335`, 0.},
       Optica`Optica`RayEnd :> {3.7064987451471687`, 2.657886923554598, 0.}, 
      RotationMatrix :> {{-0.2677487632254505, 0.9634887647457243, 
       0.}, {-0.9634887647457243, -0.2677487632254505, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014965431400512286`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3756491624614669, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.670177289547205`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41122311092981323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.2677487632254505, 0.9634887647457243, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7064987451471687`, 2.657886923554598, 0.}, 
      Optica`Optica`RayEnd :> {3.675537600714022, 2.844785459439058, 0.}, 
      RotationMatrix :> {{-0.16343021893141432`, 0.9865548963641254, 
       0.}, {-0.9865548963641254, -0.16343021893141432`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014794145320095998`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18944565231317614`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.950556854970705`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2975398598932371, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.16343021893141432`, 0.9865548963641254, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.675134321503202, 2.346331015390589, 0.}, 
      Optica`Optica`RayEnd :> {3.5557058479751067`, 2.3666693537413117`, 0.}, 
      RotationMatrix :> {{-0.98580739253648, 0.16788026930055444`, 
       0.}, {-0.16788026930055444`, -0.98580739253648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22626957942774628`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12114787780278878`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.538172459016657`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015770831732549288`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.98580739253648, 0.16788026930055444`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5557058479751067`, 2.3666693537413117`, 0.},
       Optica`Optica`RayEnd :> {3.3314682700404803`, 2.4287451418733497`, 0.},
       RotationMatrix :> {{-0.9637529799935005, 0.26679616480310864`, 
       0.}, {-0.26679616480310864`, -0.9637529799935005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22395049021830984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23267121616177924`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.88252585893609, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2288987780263201, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9637529799935005, 0.26679616480310864`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.573380697926003, 2.248385357970332, 0.}, 
      Optica`Optica`RayEnd :> {3.4922244091376218`, 2.1318753049699684`, 0.}, 
      RotationMatrix :> {{-0.571566592858381, -0.8205556836243728, 0.}, {
       0.8205556836243728, -0.571566592858381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013262488590337719`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1419892096606314, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.775126734618246`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3895106707338082, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.571566592858381, -0.8205556836243728, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4922244091376218`, 2.1318753049699684`, 0.},
       Optica`Optica`RayEnd :> {3.4118601926906513`, 1.9774712451865195`, 0.},
       RotationMatrix :> {{-0.46168781947884624`, -0.8870424777567691, 0.}, {
       0.8870424777567691, -0.46168781947884624`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013029652756978094`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17406613962154224`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.03274462125813, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11957854284353497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46168781947884624`, -0.8870424777567691, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.608033170338925, 1.7741434996327017`, 0.}, 
      Optica`Optica`RayEnd :> {3.494865762782598, 1.6280956073710566`, 0.}, 
      RotationMatrix :> {{-0.6125050190984126, -0.7904666985896704, 0.}, {
       0.7904666985896704, -0.6125050190984126, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008251132000559797, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18476160035864853`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.861188657429173`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14624144031135453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6125050190984126, -0.7904666985896704, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.494865762782598, 1.6280956073710566`, 0.}, 
      Optica`Optica`RayEnd :> {3.345010882115403, 1.4163935745926908`, 0.}, 
      RotationMatrix :> {{-0.5777587149980167, -0.8162076128313435, 0.}, {
       0.8162076128313435, -0.5777587149980167, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008222372346247762, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2593727740960325, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.2450603630913, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26796663695041184`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5777587149980167, -0.8162076128313435, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.30918847720457, -1.0191991468394757`, 0.}, 
      Optica`Optica`RayEnd :> {2.1501325925922243`, -1.0673780166924594`, 0.},
       RotationMatrix :> {{-0.9570576031723645, -0.28989781684236343`, 0.}, {
       0.28989781684236343`, -0.9570576031723645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013933410081013042`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1661925928858642, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.676339456081994`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3520792556380051, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9570576031723645, -0.28989781684236343`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1501325925922243`, -1.0673780166924594`, 
       0.}, Optica`Optica`RayEnd :> {1.822712616640818, -1.1460593338038179`, 
       0.}, RotationMatrix :> {{-0.9723195189281357, -0.2336552013359822, 
       0.}, {0.2336552013359822, -0.9723195189281357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013871411983682134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3367411324955677, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.174716332175436`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33626819693811105`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9723195189281357, -0.2336552013359822, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.589108696355187, -2.8258811301481175`, 0.}, 
      Optica`Optica`RayEnd :> {3.5793722792052693`, -2.831708477702094, 0.}, 
      RotationMatrix :> {{-0.8580562805913345, -0.5135556633294629, 0.}, {
       0.5135556633294629, -0.8580562805913345, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012266904960303113`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.011347061224477793`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.898785390077267`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04854272279055603, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.8580562805913345, -0.5135556633294629, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5793722792052693`, -2.831708477702094, 0.}, 
      Optica`Optica`RayEnd :> {3.3311028726883682`, -2.9944225439346672`, 0.},
       RotationMatrix :> {{-0.8363764932857659, -0.5481554172668595, 0.}, {
       0.5481554172668595, -0.8363764932857659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012225610598768887`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2968392924836474, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.338107542953065`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10440376301568152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8363764932857659, -0.5481554172668595, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.172461097552453, -3.4101727141824996`, 0.}, 
      Optica`Optica`RayEnd :> {5.1639613154432675`, -3.465730359428305, 0.}, 
      RotationMatrix :> {{-0.15123070431164554`, -0.9884984947249053, 0.}, {
       0.9884984947249053, -0.15123070431164554`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008815416164352637, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05620407673080678, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.903886060792317`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.385944617000145, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.15123070431164554`, -0.9884984947249053, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1639613154432675`, -3.465730359428305, 0.}, 
      Optica`Optica`RayEnd :> {5.10378493535895, -3.621029082309203, 0.}, 
      RotationMatrix :> {{-0.36131127943792035`, -0.9324452580987974, 0.}, {
       0.9324452580987974, -0.36131127943792035`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00808866082489783, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16654996261929958`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.15038000546888, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07098924179340438, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.36131127943792035`, -0.9324452580987974, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.601170038740591, -3.55634550583027, 0.}, 
      Optica`Optica`RayEnd :> {6.628715581397982, -3.6196351682442374`, 0.}, 
      RotationMatrix :> {{0.39907087863225454`, -0.9169200803928769, 0.}, {
       0.9169200803928769, 0.39907087863225454`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017595035832233152`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06902418625934026, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.39498987191417, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39828731949020624`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.39907087863225454`, -0.9169200803928769, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.628715581397982, -3.6196351682442374`, 0.}, 
      Optica`Optica`RayEnd :> {6.770942851840212, -3.9269453409866735`, 0.}, 
      RotationMatrix :> {{0.42001180186032905`, -0.9075186423969698, 0.}, {
       0.9075186423969698, 0.42001180186032905`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01754692263322301, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3386268428941119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.896157599397455`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15056175770390537`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.42001180186032905`, -0.9075186423969698, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.638935893568386, -2.5748739356299155`, 0.}, 
      Optica`Optica`RayEnd :> {7.862015843501545, -2.566332486898788, 0.}, 
      RotationMatrix :> {{0.9992677914270247, 0.038260698066761814`, 
       0.}, {-0.038260698066761814`, 0.9992677914270247, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09044844045044562, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22324341067231224`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.925509625196536`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32685430425289225`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9992677914270247, 0.038260698066761814`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.862015843501545, -2.566332486898788, 0.}, 
      Optica`Optica`RayEnd :> {8.11164321715692, -2.5383145838870496`, 0.}, 
      RotationMatrix :> {{0.9937601082399834, 0.11153854612131314`, 
       0.}, {-0.11153854612131314`, 0.9937601082399834, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08991535508416518, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2511948020307275, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.297277932202014`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26485768119556047`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9937601082399834, 0.11153854612131314`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.17711503024882, -0.9657857867526604, 0.}, 
      Optica`Optica`RayEnd :> {8.229584526554289, -0.9331285216554779, 0.}, 
      RotationMatrix :> {{0.8489870762537798, 0.528413611060558, 
       0.}, {-0.528413611060558, 0.8489870762537798, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013319899576571198`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06180246763825286, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.07490442327143, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.360284012780347, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8489870762537798, 0.528413611060558, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.229584526554289, -0.9331285216554779, 0.}, 
      Optica`Optica`RayEnd :> {8.45538678793015, -0.7653751126454883, 0.}, 
      RotationMatrix :> {{0.8027190251372729, 0.596357415215629, 
       0.}, {-0.596357415215629, 0.8027190251372729, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013226833351632132`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2812967605162313, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.491223628835453`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4300166282610139, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8027190251372729, 0.596357415215629, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.859102310574856, 2.798613824550409, 0.}, 
      Optica`Optica`RayEnd :> {6.084440878437667, 2.8852840868237886`, 0.}, 
      RotationMatrix :> {{0.9333434102805019, 0.35898478865539984`, 
       0.}, {-0.35898478865539984`, 0.9333434102805019, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012272593066119079`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24143157318171796`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.15823698286113, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31740051551588583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9333434102805019, 0.35898478865539984`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.084440878437667, 2.8852840868237886`, 0.}, 
      Optica`Optica`RayEnd :> {6.2854634585950215`, 2.930051637924093, 0.}, 
      RotationMatrix :> {{0.9760883847367492, 0.21737402140551024`, 
       0.}, {-0.21737402140551024`, 0.9760883847367492, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011960144256608192`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2059471081725556, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.463038702956514`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03935930731727433, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 91, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9760883847367492, 0.21737402140551024`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.346900401770584, -3.2046491384338243`, 0.}, 
      Optica`Optica`RayEnd :> {4.4508501385809875`, -3.297385501936052, 0.}, 
      RotationMatrix :> {{0.7462082912063601, -0.6657125401664623, 0.}, {
       0.6657125401664623, 0.7462082912063601, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026278223647221502`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13930391558951113`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.691278936852719`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3524284632391846, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7462082912063601, -0.6657125401664623, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.4508501385809875`, -3.297385501936052, 0.}, 
      Optica`Optica`RayEnd :> {4.653245556053751, -3.501540898488227, 0.}, 
      RotationMatrix :> {{0.7040390830373959, -0.7101612278601686, 0.}, {
       0.7101612278601686, 0.7040390830373959, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026154910625220514`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.287477531218267, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.116745683055754`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3516101523972383, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7040390830373959, -0.7101612278601686, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8834535086676665`, -1.782800960434623, 0.}, 
      Optica`Optica`RayEnd :> {5.105640936272439, -1.7834163468424353`, 0.}, 
      RotationMatrix :> {{0.9999961644791919, -0.0027696618756466312`, 0.}, {
       0.0027696618756466312`, 0.9999961644791919, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008378622673319966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2221882798125435, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.027034292685485`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19973324558306274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999961644791919, -0.0027696618756466312`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.105640936272439, -1.7834163468424353`, 0.}, 
      Optica`Optica`RayEnd :> {5.421968446816875, -1.7712630858995746`, 0.}, 
      RotationMatrix :> {{0.9992627729603212, 0.038391543022520506`, 
       0.}, {-0.038391543022520506`, 0.9992627729603212, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008350282437598965, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31656088779061975`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.495544406615604`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3270774280243379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9992627729603212, 0.038391543022520506`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6246736316529993`, 2.5441255502263878`, 0.},
       Optica`Optica`RayEnd :> {3.6704688145865982`, 2.6952186852900835`, 0.},
       RotationMatrix :> {{0.2900618356378631, 0.9570079056655666, 
       0.}, {-0.9570079056655666, 0.2900618356378631, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008777254477004986, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15788075957284362`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.288328402036505`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2696523370952972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2900618356378631, 0.9570079056655666, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6704688145865982`, 2.6952186852900835`, 0.},
       Optica`Optica`RayEnd :> {3.7481042170747867`, 2.8938741145769025`, 0.},
       RotationMatrix :> {{0.3639954406636548, 0.9314007296411532, 
       0.}, {-0.9314007296411532, 0.3639954406636548, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008720520321501175, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2132867443247079, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.603992783637073`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3515244692317782, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3639954406636548, 0.9314007296411532, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.990766656968944, 2.68440669863797, 0.}, 
      Optica`Optica`RayEnd :> {2.8845911525099703`, 2.7559991259945607`, 0.}, 
      RotationMatrix :> {{-0.8291239210694847, 0.5590648652082897, 
       0.}, {-0.5590648652082897, -0.8291239210694847, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3785674925660814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12805746132860127`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.685952708995982`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4251509010321577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8291239210694847, 0.5590648652082897, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8845911525099703`, 2.7559991259945607`, 0.},
       Optica`Optica`RayEnd :> {2.656496102702559, 2.8886382820148584`, 0.}, 
      RotationMatrix :> {{-0.8644647703860328, 0.5026934063237989, 
       0.}, {-0.5026934063237989, -0.8644647703860328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.37661141892337874`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2638569640097116, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.076461015730356`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4235043777685494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8644647703860328, 0.5026934063237989, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.427325078483299, 1.8400499517806694`, 0.}, 
      Optica`Optica`RayEnd :> {2.4097248437291436`, 1.8324302484370008`, 0.}, 
      RotationMatrix :> {{-0.917689966824735, -0.39729727508405777`, 0.}, {
       0.39729727508405777`, -0.917689966824735, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00858027754961896, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019178846223036998`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.370626087920837`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27359384862740427`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.917689966824735, -0.39729727508405777`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4097248437291436`, 1.8324302484370008`, 0.},
       Optica`Optica`RayEnd :> {2.1617716970949905`, 1.7234169393512568`, 0.},
       RotationMatrix :> {{-0.9154321402816424, -0.4024723550001566, 0.}, {
       0.4024723550001566, -0.9154321402816424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008558993392664983, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2708591229469698, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.77149758988235, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1762470992067214, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9154321402816424, -0.4024723550001566, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5648705308709445`, 2.67124674879148, 0.}, 
      Optica`Optica`RayEnd :> {5.588892206482666, 2.680871821839608, 0.}, 
      RotationMatrix :> {{0.92825796265734, 0.37193703064261335`, 
       0.}, {-0.37193703064261335`, 0.92825796265734, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009260588043070206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.025878232752190873`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.354569047469834`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35421427455487864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.92825796265734, 0.37193703064261335`, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.588892206482666, 2.680871821839608, 0.}, 
      Optica`Optica`RayEnd :> {5.858952183105744, 2.80193995526425, 0.}, 
      RotationMatrix :> {{0.9125007926334485, 0.4090749362199156, 
       0.}, {-0.4090749362199156, 0.9125007926334485, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009229627545588556, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2959558816860792, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.792583752365232`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41844773875045227`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9125007926334485, 0.4090749362199156, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0780660610831423`, -0.8695988186114041, 0.},
       Optica`Optica`RayEnd :> {3.0428885243697246`, -0.8680864942479819, 0.},
       RotationMatrix :> {{-0.9990771575790528, 0.04295152155350107, 
       0.}, {-0.04295152155350107, -0.9990771575790528, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025943256355949695`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03521003002276568, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.778203873165637`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0035006862417224513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9990771575790528, 0.04295152155350107, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0428885243697246`, -0.8680864942479819, 0.},
       Optica`Optica`RayEnd :> {2.8724930742377612`, -0.8881629628885982, 0.},
       RotationMatrix :> {{-0.9931303365945864, -0.1170133946842153, 0.}, {
       0.1170133946842153, -0.9931303365945864, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025117912326129387`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17157410649265215`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.032133550774763`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3654483235518655, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9931303365945864, -0.1170133946842153, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.844101538872602, -1.0632252089375354`, 0.}, 
      Optica`Optica`RayEnd :> {2.666467982513889, -1.0456368429455045`, 0.}, 
      RotationMatrix :> {{-0.9951337784093648, 0.09853305571584284, 
       0.}, {-0.09853305571584284, -0.9951337784093648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013131547885084987`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17850218755778227`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.2702635125003, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41300749439364215`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9951337784093648, 0.09853305571584284, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.666467982513889, -1.0456368429455045`, 0.}, 
      Optica`Optica`RayEnd :> {2.3099577862941993`, -1.0111371331343069`, 0.},
       RotationMatrix :> {{-0.9953503553543676, 0.09632066287113297, 
       0.}, {-0.09632066287113297, -0.9953503553543676, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013099150648358019`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3581755854125995, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.800363378910948`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05873580701699333, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9953503553543676, 0.09632066287113297, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.620435270414352, 0.8139180346299864, 0.}, 
      Optica`Optica`RayEnd :> {4.568674019498865, 0.8418032120599352, 0.}, 
      RotationMatrix :> {{-0.8803735679490369, 0.47428090922646554`, 
       0.}, {-0.47428090922646554`, -0.8803735679490369, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009299029633914253, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05879464445538948, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.221721208389955`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10100355650508407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8803735679490369, 0.47428090922646554`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.568674019498865, 0.8418032120599352, 0.}, 
      Optica`Optica`RayEnd :> {4.335307961329535, 0.9947123023651957, 0.}, 
      RotationMatrix :> {{-0.8364379841236406, 0.548061582958686, 
       0.}, {-0.548061582958686, -0.8364379841236406, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009229151067912247, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27899983333950834`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.634640961732426`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04519542216453377, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8364379841236406, 0.548061582958686, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.71725703465744, 0.3774451573715266, 0.}, 
      Optica`Optica`RayEnd :> {7.859452932420811, 0.6047336633735261, 0.}, 
      RotationMatrix :> {{0.530375951490463, 0.8477625552479806, 
       0.}, {-0.8477625552479806, 0.530375951490463, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01914383101064954, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2681039692010398, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.12177973215566, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.045688297999611376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.530375951490463, 0.8477625552479806, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.859452932420811, 0.6047336633735261, 0.}, 
      Optica`Optica`RayEnd :> {7.9507690227662335`, 0.8052219787546446, 0.}, 
      RotationMatrix :> {{0.4144989195895972, 0.9100498039442984, 
       0.}, {-0.9100498039442984, 0.4144989195895972, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018786695888718015`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22030477289503356`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.447830796040307`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34564760409268425`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.4144989195895972, 0.9100498039442984, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.939023855942025, -0.28788288655888045`, 0.},
       Optica`Optica`RayEnd :> {6.761532495199798, 0.0782594081300623, 0.}, 
      RotationMatrix :> {{-0.43620947938646315`, 0.899845147841222, 
       0.}, {-0.899845147841222, -0.43620947938646315`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013361069599816009`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.40689478136025764`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.16152095579804, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21373793523437157`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.43620947938646315`, 0.899845147841222, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.761532495199798, 0.0782594081300623, 0.}, 
      Optica`Optica`RayEnd :> {6.639163844367371, 0.35600074813492016`, 0.}, 
      RotationMatrix :> {{-0.40318702963914976`, 0.9151175985253258, 
       0.}, {-0.9151175985253258, -0.40318702963914976`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013318726843723708`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3035034409265285, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.610706048369302`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3664934676963052, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.40318702963914976`, 0.9151175985253258, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.603624631246455, -1.8298685568134114`, 0.}, 
      Optica`Optica`RayEnd :> {6.570468399754491, -1.8293367952577892`, 0.}, 
      RotationMatrix :> {{-0.9998714151570613, 0.016035995504339984`, 
       0.}, {-0.016035995504339984`, -0.9998714151570613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021461166540473097`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03316049542906071, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.083744112701684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.032392571869766976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9998714151570613, 0.016035995504339984`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.570468399754491, -1.8293367952577892`, 0.}, 
      Optica`Optica`RayEnd :> {6.364338814151551, -1.8536428419150592`, 0.}, 
      RotationMatrix :> {{-0.99311953644671, -0.11710502264152285`, 0.}, {
       0.11710502264152285`, -0.99311953644671, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021046991752128888`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20755767864607017`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.390929477097867`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3399470888392747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.99311953644671, -0.11710502264152285`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.608643324015406, -2.241089960054466, 0.}, 
      Optica`Optica`RayEnd :> {7.5302611664733945`, -2.388115128296302, 0.}, 
      RotationMatrix :> {{-0.47044213250485, -0.8824308471287076, 0.}, {
       0.8824308471287076, -0.47044213250485, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03984385138180222, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1666138131052795, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.738601903578706`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11357661473527231`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.47044213250485, -0.8824308471287076, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5302611664733945`, -2.388115128296302, 0.}, 
      Optica`Optica`RayEnd :> {7.388525244576338, -2.6663777250317304`, 0.}, 
      RotationMatrix :> {{-0.45387367276148965`, -0.891066040860045, 0.}, {
       0.891066040860045, -0.45387367276148965`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03973858991586621, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3122805538261264, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.200777123241373`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39871560456725885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.45387367276148965`, -0.891066040860045, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.079759756486173, -2.178409227415667, 0.}, 
      Optica`Optica`RayEnd :> {7.8944045676906915`, -2.180664402454299, 0.}, 
      RotationMatrix :> {{-0.9999259929988153, -0.012165875444566931`, 0.}, {
       0.012165875444566931`, -0.9999259929988153, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015663167114706073`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18536890739242967`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.67420135000824, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2622813532577894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999259929988153, -0.012165875444566931`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.8944045676906915`, -2.180664402454299, 0.}, 
      Optica`Optica`RayEnd :> {7.618630463181174, -2.1975476124328246`, 0.}, 
      RotationMatrix :> {{-0.9981312364158126, -0.061106749963001625`, 0.}, {
       0.061106749963001625`, -0.9981312364158126, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015603551854063535`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27629042599627973`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.08311118048273, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18206870889704702`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9981312364158126, -0.061106749963001625`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.241396205327685, -2.0647126153737987`, 0.}, 
      Optica`Optica`RayEnd :> {8.182546427716614, -1.895598670219838, 0.}, 
      RotationMatrix :> {{-0.3286578037792653, 0.9444490711600015, 
       0.}, {-0.9444490711600015, -0.3286578037792653, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015567117837656668`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1790609470834141, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.618495929452095`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33278382819808866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3286578037792653, 0.9444490711600015, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.182546427716614, -1.895598670219838, 0.}, 
      Optica`Optica`RayEnd :> {8.10977393330874, -1.6417027819848846`, 0.}, 
      RotationMatrix :> {{-0.27552897016149613`, 0.9612927684122798, 
       0.}, {-0.9612927684122798, -0.27552897016149613`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015500840483340902`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2641192117301588, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.00939236281273, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3614053737071096, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.27552897016149613`, 0.9612927684122798, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.13369358484671, -0.909805201904108, 0.}, 
      Optica`Optica`RayEnd :> {8.142056766957792, -0.8755510463406937, 0.}, 
      RotationMatrix :> {{0.23718397082460585`, 0.9714647517969308, 
       0.}, {-0.9714647517969308, 0.23718397082460585`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021355436346258933`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03526031747426134, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.5067364716841, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31754050249413374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.23718397082460585`, 0.9714647517969308, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.142056766957792, -0.8755510463406937, 0.}, 
      Optica`Optica`RayEnd :> {8.232240954122844, -0.5926830924116476, 0.}, 
      RotationMatrix :> {{0.30375642785201584`, 0.9527497218779878, 
       0.}, {-0.9527497218779878, 0.30375642785201584`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02123954235960414, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2968963909760879, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.94614313032871, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3548301354097768, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.30375642785201584`, 0.9527497218779878, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.631251815124599, -0.7413559237850313, 0.}, 
      Optica`Optica`RayEnd :> {6.605605728708971, -0.7000616123378564, 0.}, 
      RotationMatrix :> {{-0.5275875992442662, 0.8495006327976873, 
       0.}, {-0.8495006327976873, -0.5275875992442662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013535107918258687`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04861010086735206, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.341493887085125`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08529743818148174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5275875992442662, 0.8495006327976873, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.605605728708971, -0.7000616123378564, 0.}, 
      Optica`Optica`RayEnd :> {6.436956136237303, -0.4163147868373776, 0.}, 
      RotationMatrix :> {{-0.510930491153965, 0.8596220292716837, 
       0.}, {-0.8596220292716837, -0.510930491153965, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013499134451970375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3300832410505855, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.83001708383999, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37578139437696423`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.510930491153965, 0.8596220292716837, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.35587456765623, -1.1072220852942924`, 0.}, 
      Optica`Optica`RayEnd :> {5.178150371177928, -1.038544202537983, 0.}, 
      RotationMatrix :> {{-0.9327774609887539, 0.36045278230494116`, 
       0.}, {-0.36045278230494116`, -0.9327774609887539, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019299024477585434`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1905322586696206, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.11135288045206, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3567652211635249, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9327774609887539, 0.36045278230494116`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.178150371177928, -1.038544202537983, 0.}, 
      Optica`Optica`RayEnd :> {4.902025869288929, -0.9353251541593269, 0.}, 
      RotationMatrix :> {{-0.9366940784124226, 0.35014883045228357`, 
       0.}, {-0.35014883045228357`, -0.9366940784124226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019250282026786802`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29478621489418955`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.54763647849546, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22322174367013614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9366940784124226, 0.35014883045228357`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.56054423222673, -2.2685416838301906`, 0.}, 
      Optica`Optica`RayEnd :> {5.507209445819916, -2.3131470319159875`, 0.}, 
      RotationMatrix :> {{-0.7670905150254096, -0.6415388856164932, 0.}, {
       0.6415388856164932, -0.7670905150254096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0939624246432305, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06952867407707142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.20280749490855, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14997149424824296`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7670905150254096, -0.6415388856164932, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.507209445819916, -2.3131470319159875`, 0.}, 
      Optica`Optica`RayEnd :> {5.317042174504154, -2.496568643107816, 0.}, 
      RotationMatrix :> {{-0.7197572422136407, -0.6942258366562098, 0.}, {
       0.6942258366562098, -0.7197572422136407, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09343608168659631, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2642102922520029, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.593838727441515`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09091987148562042, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7197572422136407, -0.6942258366562098, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.212331653106352, -0.0695994659840488, 0.}, 
      Optica`Optica`RayEnd :> {4.165340332262248, -0.05949132258521739, 0.}, 
      RotationMatrix :> {{-0.9776376918757037, 0.21029632289687455`, 
       0.}, {-0.21029632289687455`, -0.9776376918757037, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012615619355837918`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04806619183630821, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.986512996004038`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23765759323416275`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9776376918757037, 0.21029632289687455`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.165340332262248, -0.05949132258521739, 0.}, 
      Optica`Optica`RayEnd :> {3.865264422165415, 0.015582195435765321`, 0.}, 
      RotationMatrix :> {{-0.9701009985748249, 0.24270157099641432`, 
       0.}, {-0.24270157099641432`, -0.9701009985748249, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012577171129079178`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30932440079710827`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.444313109183756`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0307684841697958, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9701009985748249, 0.24270157099641432`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.448658799778517, 2.1357213457488884`, 0.}, 
      Optica`Optica`RayEnd :> {6.493406679852289, 2.34785971181047, 0.}, 
      RotationMatrix :> {{0.20639547129876512`, 0.9784686553116354, 
       0.}, {-0.9784686553116354, 0.20639547129876512`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011796908609508758`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21680650157773018`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.788332142480726`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1781521566120714, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.20639547129876512`, 0.9784686553116354, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.493406679852289, 2.34785971181047, 0.}, 
      Optica`Optica`RayEnd :> {6.547614972963494, 2.660373650005636, 0.}, 
      RotationMatrix :> {{0.17090673844000404`, 0.9852872102873351, 
       0.}, {-0.9852872102873351, 0.17090673844000404`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011759641439691458`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3171805489122595, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.25775935487087, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.010404187125226614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17090673844000404`, 0.9852872102873351, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1162682073205294`, 2.5548130859784597`, 0.},
       Optica`Optica`RayEnd :> {7.065798112577622, 2.833912076653831, 0.}, 
      RotationMatrix :> {{-0.17794619375455054`, 0.9840402187554469, 
       0.}, {-0.9840402187554469, -0.17794619375455054`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020972257656129187`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2836255930965488, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.605306509233532`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1474531820625877, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.17794619375455054`, 0.9840402187554469, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.065798112577622, 2.833912076653831, 0.}, 
      Optica`Optica`RayEnd :> {7.015837296923768, 3.1035802932107157`, 0.}, 
      RotationMatrix :> {{-0.18216772268147102`, 0.9832674716541001, 
       0.}, {-0.9832674716541001, -0.18216772268147102`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02092037523015651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2742572334903296, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.01120721479922, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3088201502899563, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18216772268147102`, 0.9832674716541001, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6055738337734273`, 0.6567341618634729, 0.}, 
      Optica`Optica`RayEnd :> {2.4061119345070474`, 0.7531081223307664, 0.}, 
      RotationMatrix :> {{-0.9004066463864504, 0.43504927438521857`, 
       0.}, {-0.43504927438521857`, -0.9004066463864504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10822466444132209`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22152424137123883`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.529295743295144`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31970832488624273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9004066463864504, 0.43504927438521857`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4061119345070474`, 0.7531081223307664, 0.}, 
      Optica`Optica`RayEnd :> {2.1844334948319033`, 0.8577212354772984, 0.}, 
      RotationMatrix :> {{-0.9043563185988853, 0.4267782199342781, 
       0.}, {-0.4267782199342781, -0.9043563185988853, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1079533728649814, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2451228958278188, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.892077629120315`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2520744910538141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9043563185988853, 0.4267782199342781, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8962224611401854`, -1.5783964706025564`, 
       0.}, Optica`Optica`RayEnd :> {3.750287447374651, -1.6648115713326714`, 
       0.}, RotationMatrix :> {{-0.8604593336881885, -0.509519121396713, 
       0.}, {0.509519121396713, -0.8604593336881885, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04162120841637863, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1696012909058852, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.722224240310462`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07376429116319622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8604593336881885, -0.509519121396713, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.750287447374651, -1.6648115713326714`, 0.}, 
      Optica`Optica`RayEnd :> {3.566128926377194, -1.7924870565715108`, 0.}, 
      RotationMatrix :> {{-0.8218137376088763, -0.569756246720761, 0.}, {
       0.569756246720761, -0.8218137376088763, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0413847438651463, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22408790772137577`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.053874343738098`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.008575502225023844, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8218137376088763, -0.569756246720761, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.421649245250298, -3.0825725534329287`, 0.}, 
      Optica`Optica`RayEnd :> {5.532067868258321, -3.3615206858124775`, 0.}, 
      RotationMatrix :> {{0.3680532172171919, -0.9298047264324234, 0.}, {
       0.9298047264324234, 0.3680532172171919, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01609940323919443, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3000072213547975, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.12263973064802, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11240053943223138`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3680532172171919, -0.9298047264324234, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.532067868258321, -3.3615206858124775`, 0.}, 
      Optica`Optica`RayEnd :> {5.613537725456426, -3.6216851368345666`, 0.}, 
      RotationMatrix :> {{0.2988379113159399, -0.9543038838652631, 0.}, {
       0.9543038838652631, 0.2988379113159399, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01600462836506241, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.272622228014343, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.52612062810925, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18555796744916417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2988379113159399, -0.9543038838652631, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.016042773262057, -1.6516751997741703`, 0.}, 
      Optica`Optica`RayEnd :> {7.108282798810705, -1.7348892010832604`, 0.}, 
      RotationMatrix :> {{0.7425011976910184, -0.6698447368065256, 0.}, {
       0.6698447368065256, 0.7425011976910184, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01174262446037085, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12422879025042678`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.82166709470074, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20869081012353552`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7425011976910184, -0.6698447368065256, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.108282798810705, -1.7348892010832604`, 0.}, 
      Optica`Optica`RayEnd :> {7.322692665885227, -1.9171446844618552`, 0.}, 
      RotationMatrix :> {{0.7619268734991144, -0.6476630601168056, 0.}, {
       0.6476630601168056, 0.7619268734991144, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011708367027352314`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2814047837554994, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.23814617465888, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0343394689202492, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7619268734991144, -0.6476630601168056, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.262747380025582, 2.9608335378144637`, 0.}, 
      Optica`Optica`RayEnd :> {3.930376204807889, 3.179382975753243, 0.}, 
      RotationMatrix :> {{-0.8355507338847508, 0.5494132971676727, 
       0.}, {-0.5494132971676727, -0.8355507338847508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00928084755918825, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3977869466673669, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.553651359591424`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25845238323337094`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8355507338847508, 0.5494132971676727, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.930376204807889, 3.179382975753243, 0.}, 
      Optica`Optica`RayEnd :> {3.6460075670016345`, 3.363384076381549, 0.}, 
      RotationMatrix :> {{-0.839573032911366, 0.5432468337763318, 
       0.}, {-0.5432468337763318, -0.839573032911366, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009257721782905237, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3387062550355585, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.05493661704405, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30045246954213983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.839573032911366, 0.5432468337763318, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.976035586645406, 2.6360109109681593`, 0.}, 
      Optica`Optica`RayEnd :> {6.965115949693173, 2.849766562718292, 0.}, 
      RotationMatrix :> {{-0.0510181438925025, 0.9986977265387977, 
       0.}, {-0.9986977265387977, -0.0510181438925025, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015965759604935754`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21403438304695957`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47260046649986, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4297214390702765, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.0510181438925025, 0.9986977265387977, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.965115949693173, 2.849766562718292, 0.}, 
      Optica`Optica`RayEnd :> {6.967666509375516, 3.0871540433788582`, 0.}, 
      RotationMatrix :> {{0.010743668832124131`, 0.9999422851245091, 
       0.}, {-0.9999422851245091, 0.010743668832124131`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015890154412593283`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2374011822402405, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.823954216215416`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4308799211257419, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {0.010743668832124131`, 0.9999422851245091, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.575596281441464, -2.0742213214166454`, 0.}, 
      Optica`Optica`RayEnd :> {7.497597923677322, -2.381853343242259, 0.}, 
      RotationMatrix :> {{-0.24576781199588527`, -0.9693287278249595, 0.}, {
       0.9693287278249595, -0.24576781199588527`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12507112856901748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3173660420814079, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.541612334796802`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2126192554037235, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.24576781199588527`, -0.9693287278249595, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.497597923677322, -2.381853343242259, 0.}, 
      Optica`Optica`RayEnd :> {7.425253906713074, -2.687134026360825, 0.}, 
      RotationMatrix :> {{-0.23058921052332987`, -0.9730511887820839, 0.}, {
       0.9730511887820839, -0.23058921052332987`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1247474454342944, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31373548137859986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.00594084723713, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39308645346398935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.23058921052332987`, -0.9730511887820839, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.300925599643978, 1.8751161064027455`, 0.}, 
      Optica`Optica`RayEnd :> {8.213321694087746, 2.097332886682772, 0.}, 
      RotationMatrix :> {{-0.3667563116383905, 0.9303170469648527, 
       0.}, {-0.9303170469648527, -0.3667563116383905, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040650469734116866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23886134410307297`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.24026195575528, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24754598962663643`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3667563116383905, 0.9303170469648527, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.213321694087746, 2.097332886682772, 0.}, 
      Optica`Optica`RayEnd :> {8.118134773638745, 2.367199620738484, 0.}, 
      RotationMatrix :> {{-0.33263316089710765`, 0.9430562975091142, 
       0.}, {-0.9430562975091142, -0.33263316089710765`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040521575965739895`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2861618492644697, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.663781492666693`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3911238325894945, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.33263316089710765`, 0.9430562975091142, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.597317163585998, 0.2927098512295937, 0.}, 
      Optica`Optica`RayEnd :> {6.363415043055312, 0.4016498220837778, 0.}, 
      RotationMatrix :> {{-0.9065012301352761, 0.4222031735589295, 
       0.}, {-0.4222031735589295, -0.9065012301352761, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008716130687246871, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25802736141437055`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.468319312903038`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16870288229024524`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9065012301352761, 0.4222031735589295, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.363415043055312, 0.4016498220837778, 0.}, 
      Optica`Optica`RayEnd :> {6.182146425329703, 0.4503276617857824, 0.}, 
      RotationMatrix :> {{-0.9657830781776701, 0.259351201858917, 
       0.}, {-0.259351201858917, -0.9657830781776701, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008365667326248064, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18769081983466027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.746101726258335`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38108435458283085`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9657830781776701, 0.259351201858917, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.063027041023098, -0.7413790643896072, 0.}, 
      Optica`Optica`RayEnd :> {4.900853631799341, -0.7909446785446752, 0.}, 
      RotationMatrix :> {{-0.9563307578392378, -0.2922866428878143, 0.}, {
       0.2922866428878143, -0.9563307578392378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015605746006908698`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16957878630838516`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.395551937797364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23792348753095166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9563307578392378, -0.2922866428878143, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.900853631799341, -0.7909446785446752, 0.}, 
      Optica`Optica`RayEnd :> {4.68166825234663, -0.834249674863952, 0.}, 
      RotationMatrix :> {{-0.9810359820309461, -0.1938256999486313, 0.}, {
       0.1938256999486313, -0.9810359820309461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015445256537428079`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22342236520107325`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.72621703829495, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40418897433777323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9810359820309461, -0.1938256999486313, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.87725476830333, -1.3985091703707337`, 0.}, 
      Optica`Optica`RayEnd :> {6.876882042036348, -1.4007800698946995`, 0.}, 
      RotationMatrix :> {{-0.1619644577872173, -0.9867965922183213, 0.}, {
       0.9867965922183213, -0.1619644577872173, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.264418322839897, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0023012843192544512`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.130875244310523`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42661951025617784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1619644577872173, -0.9867965922183213, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.876882042036348, -1.4007800698946995`, 0.}, 
      Optica`Optica`RayEnd :> {6.857503797053943, -1.631596318035911, 0.}, 
      RotationMatrix :> {{-0.08366096566611052, -0.9964942763627963, 0.}, {
       0.9964942763627963, -0.08366096566611052, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2626869904616622, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23162827285239468`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.473685088132068`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37716964211625614`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.08366096566611052, -0.9964942763627963, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.665234411496248, -1.0794506771927341`, 0.}, 
      Optica`Optica`RayEnd :> {7.68024549226014, -1.1129053057541303`, 0.}, 
      RotationMatrix :> {{0.40937784560109597`, -0.9123649376927001, 0.}, {
       0.9123649376927001, 0.40937784560109597`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2783195089094803, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.036668034006217154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.786482594137274`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38893890680898513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.40937784560109597`, -0.9123649376927001, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.68024549226014, -1.1129053057541303`, 0.}, 
      Optica`Optica`RayEnd :> {7.821491369572861, -1.4078409622156671`, 0.}, 
      RotationMatrix :> {{0.43192753445733145`, -0.901908312955153, 0.}, {
       0.901908312955153, 0.43192753445733145`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2775450987620716, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3270129038894914, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.270461691893722`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15246060768330844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.43192753445733145`, -0.901908312955153, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4586303530034055`, -0.17982614486075948`, 
       0.}, Optica`Optica`RayEnd :> {7.409973767999245, -0.34290258960178854`,
        0.}, RotationMatrix :> {{-0.2859116966586871, -0.958255968785872, 
       0.}, {0.958255968785872, -0.2859116966586871, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025178007031378655`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17018046331362782`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.520253130152007`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4151877154242266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.2859116966586871, -0.958255968785872, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.409973767999245, -0.34290258960178854`, 0.},
       Optica`Optica`RayEnd :> {7.360966391982671, -0.5777872347677663, 0.}, 
      RotationMatrix :> {{-0.20424612808853926`, -0.9789195672581273, 0.}, {
       0.9789195672581273, -0.20424612808853926`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024994843945423804`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23994274200062227`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.875368388312928`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32334119964894126`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.20424612808853926`, -0.9789195672581273, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.093840169841501, 0.11788342776077729`, 0.}, 
      Optica`Optica`RayEnd :> {8.099263833995069, 0.11815372593931085`, 0.}, 
      RotationMatrix :> {{0.9987604541717333, 0.04977504578272464, 
       0.}, {-0.04977504578272464, 0.9987604541717333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021064131802596874`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005430395377504411, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.596170902195922`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3117605499310523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9987604541717333, 0.04977504578272464, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.099263833995069, 0.11815372593931085`, 0.}, 
      Optica`Optica`RayEnd :> {8.367052651840087, 0.14943348693084343`, 0.}, 
      RotationMatrix :> {{0.993247021072944, 0.11601877059218449`, 
       0.}, {-0.11601877059218449`, 0.993247021072944, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02095541557519201, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26960948501586435`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.995192940019402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2850059605725839, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.993247021072944, 0.11601877059218449`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.569808117033248, 1.2291413933762683`, 0.}, 
      Optica`Optica`RayEnd :> {6.364174656875045, 1.2860135822578602`, 0.}, 
      RotationMatrix :> {{-0.9638173234752536, 0.26656362649280835`, 
       0.}, {-0.26656362649280835`, -0.9638173234752536, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012492412889860909`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2133531481014958, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.366037632906421`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4067793370673723, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9638173234752536, 0.26656362649280835`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.364174656875045, 1.2860135822578602`, 0.}, 
      Optica`Optica`RayEnd :> {6.075636979375578, 1.354708650666049, 0.}, 
      RotationMatrix :> {{-0.972809540916189, 0.23160655669136987`, 
       0.}, {-0.23160655669136987`, -0.972809540916189, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012452970345813984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29660243384097834`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.805009234991068`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2674582932997668, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.972809540916189, 0.23160655669136987`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.61876224892598, 0.6526344388411479, 0.}, 
      Optica`Optica`RayEnd :> {6.586204528821855, 0.5932172930600468, 0.}, 
      RotationMatrix :> {{-0.4805389649281757, -0.876973376554703, 0.}, {
       0.876973376554703, -0.4805389649281757, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1778049399379028, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06775250808015246, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.458442537207624`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25619570033372197`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4805389649281757, -0.876973376554703, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.586204528821855, 0.5932172930600468, 0.}, 
      Optica`Optica`RayEnd :> {6.462835957629652, 0.3962580859494457, 0.}, 
      RotationMatrix :> {{-0.5308312184649676, -0.8474775616516329, 0.}, {
       0.8474775616516329, -0.5308312184649676, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17701340302364668`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23240639755317058`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.802404005586316`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2745115317341724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5308312184649676, -0.8474775616516329, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.150151747661281, 0.39767247546671286`, 0.}, 
      Optica`Optica`RayEnd :> {7.1720769430198406`, 0.31847101385484194`, 0.},
       RotationMatrix :> {{0.2667941261135189, -0.9637535443625217, 0.}, {
       0.9637535443625217, 0.2667941261135189, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010760883104749801`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0821802026826879, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.819019241288329`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3588969220284815, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.2667941261135189, -0.9637535443625217, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1720769430198406`, 0.31847101385484194`, 
       0.}, Optica`Optica`RayEnd :> {7.234378837136803, 0.09399011306815416, 
       0.}, RotationMatrix :> {{0.267429019901665, -0.963577562687319, 0.}, {
       0.963577562687319, 0.267429019901665, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010734358805697898`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23296609373160737`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.163809060011108`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12814438205427953`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.267429019901665, -0.963577562687319, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.184201931052216, 2.420319605206351, 0.}, 
      Optica`Optica`RayEnd :> {7.133875783682815, 2.4995612934954696`, 0.}, 
      RotationMatrix :> {{-0.5361141523727072, 0.8441454943466159, 
       0.}, {-0.8441454943466159, -0.5361141523727072, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3653634688767773`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0938720739728087, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.669176696128805`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39981593282677375`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5361141523727072, 0.8441454943466159, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.133875783682815, 2.4995612934954696`, 0.}, 
      Optica`Optica`RayEnd :> {7.013927724321256, 2.6322695172548927`, 0.}, 
      RotationMatrix :> {{-0.6705404129683545, 0.7418730043452365, 
       0.}, {-0.7418730043452365, -0.6705404129683545, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.3145257902223082`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17888266992077553`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 15.933923047611552`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14879189973604445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6705404129683545, 0.7418730043452365, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.013927724321256, 2.6322695172548927`, 0.}, 
      Optica`Optica`RayEnd :> {6.848681154583996, 2.563767102786102, 0.}, 
      RotationMatrix :> {{-0.9237707029442557, -0.38294606458596026`, 0.}, {
       0.38294606458596026`, -0.9237707029442557, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04894479838493547, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17888266992077556`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.1986693990943, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2670283460243132, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9237707029442557, -0.38294606458596026`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.585569373781221, 2.3098714954677755`, 0.}, 
      Optica`Optica`RayEnd :> {7.496013510024986, 2.3292753428951984`, 0.}, 
      RotationMatrix :> {{-0.9773229662449039, 0.2117541490744905, 
       0.}, {-0.2117541490744905, -0.9773229662449039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26286243769164735`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09163384761163247, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.152044456531705`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1333956446900742, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9773229662449039, 0.2117541490744905, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.496013510024986, 2.3292753428951984`, 0.}, 
      Optica`Optica`RayEnd :> {7.311736426290701, 2.4019540191871216`, 0.}, 
      RotationMatrix :> {{-0.9302625523342098, 0.36689451307513515`, 
       0.}, {-0.36689451307513515`, -0.9302625523342098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25418655224553155`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19809147780043143`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.445219843676345`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2680974061341959, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9302625523342098, 0.36689451307513515`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.311736426290701, 2.4019540191871216`, 0.}, 
      Optica`Optica`RayEnd :> {7.324263802301104, 2.5996489822677544`, 0.}, 
      RotationMatrix :> {{0.06324035818957935, 0.997998325197018, 
       0.}, {-0.997998325197018, 0.06324035818957935, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008389534193592906, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1980914778004315, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.738395230820984`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31922695164775433`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.06324035818957935, 0.997998325197018, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.226143229094154, 1.6084734436314265`, 0.}, 
      Optica`Optica`RayEnd :> {8.210443865659897, 1.4367162884544131`, 0.}, 
      RotationMatrix :> {{-0.09102496632144297, -0.9958486107366817, 0.}, {
       0.9958486107366817, -0.09102496632144297, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2609142231095817, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17247315839498492`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.08691566183702, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4267916108066211, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.09102496632144297, -0.9958486107366817, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.210443865659897, 1.4367162884544131`, 0.}, 
      Optica`Optica`RayEnd :> {8.201544877431438, 1.1301121692279588`, 0.}, 
      RotationMatrix :> {{-0.02901214211915975, -0.9995790592092536, 0.}, {
       0.9995790592092536, -0.02901214211915975, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25967082701411404`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3067332357572619, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.540880850757766`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42435399882999014`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.02901214211915975, -0.9995790592092536, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.084613540559982, 0.6849672883762922, 0.}, 
      Optica`Optica`RayEnd :> {8.074604986041667, 0.6682651451625644, 0.}, 
      RotationMatrix :> {{-0.5140148994875186, -0.8577812559766247, 0.}, {
       0.8577812559766247, -0.5140148994875186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07592309495952186, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019471331528119692`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.150550822406238`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09102021759033675, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5140148994875186, -0.8577812559766247, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.074604986041667, 0.6682651451625644, 0.}, 
      Optica`Optica`RayEnd :> {7.911408050797058, 0.38375460538032846`, 0.}, 
      RotationMatrix :> {{-0.49756206815710197`, -0.8674283764848986, 0.}, {
       0.8674283764848986, -0.49756206815710197`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0757219415205776, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32799312023335564`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.635980640351605`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3820877203564579, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.49756206815710197`, -0.8674283764848986, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.517440732883323, 0.8653015214522295, 0.}, 
      Optica`Optica`RayEnd :> {7.419272103491942, 0.6395345000659645, 0.}, 
      RotationMatrix :> {{-0.39875704426700465`, -0.9170566065665966, 0.}, {
       0.9170566065665966, -0.39875704426700465`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024443425565811028`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24618657100298622`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.87072751202185, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34834329895625843`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39875704426700465`, -0.9170566065665966, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.419272103491942, 0.6395345000659645, 0.}, 
      Optica`Optica`RayEnd :> {7.3181519197722915`, 0.352797237396545, 0.}, 
      RotationMatrix :> {{-0.3325826152751267, -0.9430741243490653, 0.}, {
       0.9430741243490653, -0.3325826152751267, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024305773443645085`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30404530806879365`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.320714567963666`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30081704166295686`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3325826152751267, -0.9430741243490653, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.432955462470727, -0.16461433324118624`, 0.},
       Optica`Optica`RayEnd :> {7.455973551255673, -0.3288069164334586, 0.}, 
      RotationMatrix :> {{0.13883197427914748`, -0.9903159510569105, 0.}, {
       0.9903159510569105, 0.13883197427914748`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19819493285909787`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16579818089069295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.133709407075635`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3073894487485443, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.13883197427914748`, -0.9903159510569105, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.455973551255673, -0.3288069164334586, 0.}, 
      Optica`Optica`RayEnd :> {7.4981801653118625`, -0.6300356770624768, 0.}, 
      RotationMatrix :> {{0.13875936859639051`, -0.9903261269030168, 0.}, {
       0.9903261269030168, 0.13875936859639051`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19770644826205294`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3041712749425599, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.583882893990623`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18717165418607418`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13875936859639051`, -0.9903261269030168, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.095547716240053, 1.1493290099655205`, 0.}, 
      Optica`Optica`RayEnd :> {5.079872856413603, 1.1491620785190124`, 0.}, 
      RotationMatrix :> {{-0.999943297520989, -0.010649025441330812`, 0.}, {
       0.010649025441330812`, -0.999943297520989, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3339796957629762, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.015675748680260563`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.021242563018667`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026120558655982166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999943297520989, -0.010649025441330812`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.079872856413603, 1.1491620785190124`, 0.}, 
      Optica`Optica`RayEnd :> {4.884183329433145, 1.1158944386613112`, 0.}, 
      RotationMatrix :> {{-0.985855496842639, -0.1675975517278003, 0.}, {
       0.1675975517278003, -0.985855496842639, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.32382384725927527`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1984971708401334, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.315018375862063`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3454300311418324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.985855496842639, -0.1675975517278003, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.884183329433145, 1.1158944386613112`, 0.}, 
      Optica`Optica`RayEnd :> {4.859839177235601, 0.9188957354033456, 0.}, 
      RotationMatrix :> {{-0.12264231321034846`, -0.9924509373316214, 0.}, {
       0.9924509373316214, -0.12264231321034846`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00984702356572182, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19849717084013352`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.60879418870546, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2470390956721223, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.12264231321034846`, -0.9924509373316214, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.349677723758777, 0.9390518793580136, 0.}, 
      Optica`Optica`RayEnd :> {4.172850117231622, 0.9655380592388819, 0.}, 
      RotationMatrix :> {{-0.9889674768101342, 0.14813281139503, 
       0.}, {-0.14813281139503, -0.9889674768101342, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2842144583096899, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17880022414640354`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.50043490522976, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25943754088513055`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9889674768101342, 0.14813281139503, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.172850117231622, 0.9655380592388819, 0.}, 
      Optica`Optica`RayEnd :> {3.8771242751091632`, 1.0203648055844956`, 0.}, 
      RotationMatrix :> {{-0.9832446582159893, 0.1822908173488759, 
       0.}, {-0.1822908173488759, -0.9832446582159893, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2833336055578053, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3007652669672541, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.945567500341294`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06731073290374089, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9832446582159893, 0.1822908173488759, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3824431749592, 1.0217437832545335`, 0.}, 
      Optica`Optica`RayEnd :> {3.1976610322841617`, 0.995866649072636, 0.}, 
      RotationMatrix :> {{-0.9903361278218381, -0.1386879732739911, 0.}, {
       0.1386879732739911, -0.9903361278218381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28852975875938647`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1865852789612463, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.082678048186164`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4244514659287972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9903361278218381, -0.1386879732739911, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1976610322841617`, 0.995866649072636, 0.}, 
      Optica`Optica`RayEnd :> {2.851433958250631, 0.9509216586411364, 0.}, 
      RotationMatrix :> {{-0.9916792289351448, -0.1287334723317752, 0.}, {
       0.1287334723317752, -0.9916792289351448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2878040356395935, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3491321224962084, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.599393589480552`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11150058263939108`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9916792289351448, -0.1287334723317752, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.645263755494122, -1.866185420573217, 0.}, 
      Optica`Optica`RayEnd :> {6.699133125138902, -2.0989175663572746`, 0.}, 
      RotationMatrix :> {{0.2255031258269043, -0.9742424442828871, 0.}, {
       0.9742424442828871, 0.2255031258269043, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009077373524557748, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23888524581308446`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.833972441003787`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38503987735744505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2255031258269043, -0.9742424442828871, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.699133125138902, -2.0989175663572746`, 0.}, 
      Optica`Optica`RayEnd :> {6.773314947406275, -2.362531201942003, 0.}, 
      RotationMatrix :> {{0.27088258019182554`, -0.9626123974625603, 0.}, {
       0.9626123974625603, 0.27088258019182554`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009043961861891115, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27385231717315495`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.239273870420057`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30924098339056266`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.27088258019182554`, -0.9626123974625603, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.211612833848461, 3.428151601916212, 0.}, 
      Optica`Optica`RayEnd :> {7.235215586903052, 3.562892476138304, 0.}, 
      RotationMatrix :> {{0.1725441807826435, 0.9850017795303952, 
       0.}, {-0.9850017795303952, 0.1725441807826435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1775323864292164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13679251857426092`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.73767682213731, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39348733498682553`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1725441807826435, 0.9850017795303952, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.235215586903052, 3.562892476138304, 0.}, 
      Optica`Optica`RayEnd :> {7.295863451371103, 3.872524143458744, 0.}, 
      RotationMatrix :> {{0.19221843072580141`, 0.9813521665993861, 
       0.}, {-0.9813521665993861, 0.19221843072580141`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17705865641862906`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3155153449076142, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.204639532600577`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2480258638308131, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19221843072580141`, 0.9813521665993861, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.560121556279733, 3.120599832514311, 0.}, 
      Optica`Optica`RayEnd :> {6.598423449002021, 3.4356287083046526`, 0.}, 
      RotationMatrix :> {{0.12069337918833256`, 0.9926898348528108, 
       0.}, {-0.9926898348528108, 0.12069337918833256`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09262207114120274, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31734874754414283`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47739003371572, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22914184097202328`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12069337918833256`, 0.9926898348528108, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.598423449002021, 3.4356287083046526`, 0.}, 
      Optica`Optica`RayEnd :> {6.590262861182729, 3.6107477297384736`, 0.}, 
      RotationMatrix :> {{-0.04654972066873944, 0.99891597419686, 
       0.}, {-0.99891597419686, -0.04654972066873944, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08926632481016271, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17530906097944668`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.736847443965303`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1868199769463598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04654972066873944, 0.99891597419686, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.138474141033417, 2.894172329501781, 0.}, 
      Optica`Optica`RayEnd :> {4.080013278153141, 2.925462430168098, 0.}, 
      RotationMatrix :> {{-0.8816570535010593, 0.4718907076981169, 
       0.}, {-0.4718907076981169, -0.8816570535010593, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8533964366538942`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0663079398595281, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.22529123492765, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33679971398517483`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8816570535010593, 0.4718907076981169, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.080013278153141, 2.925462430168098, 0.}, 
      Optica`Optica`RayEnd :> {3.8485975650478776`, 3.044158711728051, 0.}, 
      RotationMatrix :> {{-0.8897838057480901, 0.45638227291213257`, 
       0.}, {-0.45638227291213257`, -0.8897838057480901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8485406563067763`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26008083268125864`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.610210867295912`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2984857007991393, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8897838057480901, 0.45638227291213257`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.821355136964984, 2.914793700563985, 0.}, 
      Optica`Optica`RayEnd :> {4.75847914606916, 3.0799802186572953`, 0.}, 
      RotationMatrix :> {{-0.3557373755010468, 0.9345859616277286, 
       0.}, {-0.9345859616277286, -0.3557373755010468, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4221363429971257, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17674834084348112`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.78953336504679, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30150898145526744`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3557373755010468, 0.9345859616277286, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.75847914606916, 3.0799802186572953`, 0.}, 
      Optica`Optica`RayEnd :> {4.667391997490735, 3.360284447263403, 0.}, 
      RotationMatrix :> {{-0.30905008861815875`, 0.9510457626871103, 
       0.}, {-0.9510457626871103, -0.30905008861815875`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.420515972296579, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2947326402192554, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.225737672571288`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36513874472619706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.30905008861815875`, 0.9510457626871103, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.30327979785749, 3.0437173209918855`, 0.}, 
      Optica`Optica`RayEnd :> {5.300767807755573, 3.1573029335704743`, 0.}, 
      RotationMatrix :> {{-0.0221099836056744, 0.9997555444332158, 
       0.}, {-0.9997555444332158, -0.0221099836056744, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015808362976243297`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11361338600325836`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.031921410270808`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13064382831447385`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.0221099836056744, 0.9997555444332158, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.300767807755573, 3.1573029335704743`, 0.}, 
      Optica`Optica`RayEnd :> {5.277758717143984, 3.366557381576849, 0.}, 
      RotationMatrix :> {{-0.10929871360017601`, 0.9940089492581773, 
       0.}, {-0.9940089492581773, -0.10929871360017601`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015685949146524682`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21051565799537336`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.34348458410396, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0226527144928818, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10929871360017601`, 0.9940089492581773, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.4372327959670805`, 3.147729248239088, 0.}, 
      Optica`Optica`RayEnd :> {5.668793819653014, 3.263500829221451, 0.}, 
      RotationMatrix :> {{0.8944409893174275, 0.4471859978005355, 
       0.}, {-0.4471859978005355, 0.8944409893174275, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23656307409766864`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25888910107154606`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.47758894943995, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06448776702018966, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8944409893174275, 0.4471859978005355, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.668793819653014, 3.263500829221451, 0.}, 
      Optica`Optica`RayEnd :> {5.898000674453068, 3.368881404682121, 0.}, 
      RotationMatrix :> {{0.9085725735222924, 0.41772703843907166`, 
       0.}, {-0.41772703843907166`, 0.9085725735222924, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.235847264520867, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25227137763082674`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.850950588333575`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15474135213146342`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9085725735222924, 0.41772703843907166`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.5885091764360935`, 3.0710654143640497`, 0.},
       Optica`Optica`RayEnd :> {5.751131827436362, 2.943367950001699, 0.}, 
      RotationMatrix :> {{0.7865003355000915, -0.6175898495427553, 0.}, {
       0.6175898495427553, 0.7865003355000915, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013993449232803616`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2067674273741609, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.658743987663097`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09930163484113105, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7865003355000915, -0.6175898495427553, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.751131827436362, 2.943367950001699, 0.}, 
      Optica`Optica`RayEnd :> {5.8574455005292645`, 2.816628517706533, 0.}, 
      RotationMatrix :> {{0.6426693405359817, -0.7661436671637024, 0.}, {
       0.7661436671637024, 0.6426693405359817, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013015058505972097`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16542515160943796`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.903573212045064`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39115727417861346`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6426693405359817, -0.7661436671637024, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3812716959614155`, 2.6789453650180284`, 0.},
       Optica`Optica`RayEnd :> {5.58057510902941, 2.6898228005408806`, 0.}, 
      RotationMatrix :> {{0.9985139799401893, 0.054496163754909815`, 
       0.}, {-0.054496163754909815`, 0.9985139799401893, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1649111347559417, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.199600022705674, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.064631093882564`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32597131511329774`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9985139799401893, 0.054496163754909815`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.58057510902941, 2.6898228005408806`, 0.}, 
      Optica`Optica`RayEnd :> {5.8427720735431, 2.7228770601336127`, 0.}, 
      RotationMatrix :> {{0.9921470962123676, 0.1250765344793572, 
       0.}, {-0.1250765344793572, 0.9921470962123676, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16398664728395093`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2642722692175938, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.455754052324604`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2772924076062639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9921470962123676, 0.1250765344793572, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.644278954911342, 1.9798251660506894`, 0.}, 
      Optica`Optica`RayEnd :> {5.730922672863257, 1.8407078588253922`, 0.}, 
      RotationMatrix :> {{0.5286618112346851, -0.8488325449357259, 0.}, {
       0.8488325449357259, 0.5286618112346851, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10232167098973927`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16389252280122124`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.82663429203291, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17835237223782396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5286618112346851, -0.8488325449357259, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.730922672863257, 1.8407078588253922`, 0.}, 
      Optica`Optica`RayEnd :> {5.820946895856471, 1.666690518766145, 0.}, 
      RotationMatrix :> {{0.45948434116543396`, -0.8881858703130591, 0.}, {
       0.8881858703130591, 0.45948434116543396`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.101642624684561, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19592446342105305`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.116602497896068`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27821825781373793`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.45948434116543396`, -0.8881858703130591, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.118213821951841, 2.1161797360726418`, 0.}, 
      Optica`Optica`RayEnd :> {5.116121369485934, 2.0659492119851817`, 0.}, 
      RotationMatrix :> {{-0.04162089370699612, -0.999133475170875, 0.}, {
       0.999133475170875, -0.04162089370699612, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06301951992816199, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05027408783282901, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.307527292841275`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07495256615002514, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.04162089370699612, -0.999133475170875, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.116121369485934, 2.0659492119851817`, 0.}, 
      Optica`Optica`RayEnd :> {5.092211361633606, 1.8481257845740613`, 0.}, 
      RotationMatrix :> {{-0.10911246465281621`, -0.9940294110625634, 0.}, {
       0.9940294110625634, -0.10911246465281621`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06268682856734187, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21913177315174076`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.63184231710585, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03406756533917754, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.10911246465281621`, -0.9940294110625634, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.60282190644634, 2.1683820226624086`, 0.}, 
      Optica`Optica`RayEnd :> {4.528702525048912, 2.134656689007143, 0.}, 
      RotationMatrix :> {{-0.9102058556996427, -0.41415613028190246`, 0.}, {
       0.41415613028190246`, -0.9102058556996427, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03959662513359669, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08143144864790507, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.754575149338795`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27251486922707746`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9102058556996427, -0.41415613028190246`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.528702525048912, 2.1346566890071426`, 0.}, 
      Optica`Optica`RayEnd :> {4.387311192534063, 2.0334509906640714`, 0.}, 
      RotationMatrix :> {{-0.8131567068985361, -0.5820448178842651, 0.}, {
       0.5820448178842651, -0.8131567068985361, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037343383810377724`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1738795625927131, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.01191690197601, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18598942227035675`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8131567068985361, -0.5820448178842651, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.108774052035784, 2.8195567145089377`, 0.}, 
      Optica`Optica`RayEnd :> {4.033330609019542, 2.859855657210858, 0.}, 
      RotationMatrix :> {{-0.8820496370399158, 0.47115648971201873`, 
       0.}, {-0.47115648971201873`, -0.8820496370399158, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024574604969250673`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08553196991206077, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.48091196715625, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05908773368640745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8820496370399158, 0.47115648971201873`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.033330609019542, 2.859855657210858, 0.}, 
      Optica`Optica`RayEnd :> {3.8238202808915664`, 2.9838764681221184`, 0.}, 
      RotationMatrix :> {{-0.8605318478879331, 0.5093966418917364, 
       0.}, {-0.5093966418917364, -0.8605318478879331, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024488139417201616`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24346609441845965`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.84124178689557, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06988133071229813, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8605318478879331, 0.5093966418917364, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.781731117882949, 2.928205971915999, 0.}, 
      Optica`Optica`RayEnd :> {4.714349277427727, 3.0919392338751, 0.}, 
      RotationMatrix :> {{-0.38056755568133294`, 0.9247531214128094, 
       0.}, {-0.9247531214128094, -0.38056755568133294`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015219042250939311`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1770561873951337, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.067875946031904`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4005702204610636, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.38056755568133294`, 0.9247531214128094, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.714349277427727, 3.0919392338751, 0.}, 
      Optica`Optica`RayEnd :> {4.641487887169879, 3.3291496725314924`, 0.}, 
      RotationMatrix :> {{-0.2936203587050388, 0.9559221123888301, 
       0.}, {-0.9559221123888301, -0.2936203587050388, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015088822067630016`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24814829114435677`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.43513541692555, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26946774354414804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.2936203587050388, 0.9559221123888301, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.634090986696744, 3.6286175405357364`, 0.}, 
      Optica`Optica`RayEnd :> {5.647119825236141, 3.6507051496787444`, 0.}, 
      RotationMatrix :> {{0.508066395005652, 0.8613179077819987, 
       0.}, {-0.8613179077819987, 0.508066395005652, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009479447854324441, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02564396832278396, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.094016162314954`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3175939156204215, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.508066395005652, 0.8613179077819987, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.647119825236141, 3.6507051496787444`, 0.}, 
      Optica`Optica`RayEnd :> {5.825246023854241, 3.9303156676656474`, 0.}, 
      RotationMatrix :> {{0.537288136061813, 0.843398754354796, 
       0.}, {-0.843398754354796, 0.537288136061813, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009450198465022392, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3315282558139492, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.5846779809196, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13418791225451637`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.537288136061813, 0.843398754354796, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.832018778269499, 0.5492703607319532, 0.}, 
      Optica`Optica`RayEnd :> {3.6155978878735318`, 0.4541974514948907, 0.}, 
      RotationMatrix :> {{-0.915552353804271, -0.4021988158155837, 0.}, {
       0.4021988158155837, -0.915552353804271, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08315130246786985, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2363828671257334, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.843882531321825`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34794549194161534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.915552353804271, -0.4021988158155837, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6155978878735318`, 0.4541974514948907, 0.}, 
      Optica`Optica`RayEnd :> {3.3805055831974253`, 0.37158406636224844`, 0.},
       RotationMatrix :> {{-0.9434433379005137, -0.3315338115051555, 0.}, {
       0.3315338115051555, -0.9434433379005137, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08263711157970306, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24918539909271845`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.212676921979046`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40769294873696993`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9434433379005137, -0.3315338115051555, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8547025614206625`, 1.5800455557922033`, 0.},
       Optica`Optica`RayEnd :> {4.828195341595365, 1.5979025979241401`, 0.}, 
      RotationMatrix :> {{-0.8293609427671583, 0.5587131881496707, 
       0.}, {-0.5587131881496707, -0.8293609427671583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03749845497090089, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03196101776490246, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.736986406943641`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13902022239888723`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8293609427671583, 0.5587131881496707, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.828195341595365, 1.5979025979241401`, 0.}, 
      Optica`Optica`RayEnd :> {4.573649858233891, 1.7627108399105784`, 0.}, 
      RotationMatrix :> {{-0.8394161948553518, 0.5434891459951717, 
       0.}, {-0.5434891459951717, -0.8394161948553518, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037399703149124115`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3032410917510804, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.14332946989009, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18719197330907347`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8394161948553518, 0.5434891459951717, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.613741195307599, 1.2388990593583549`, 0.}, 
      Optica`Optica`RayEnd :> {4.409518578935311, 1.2417270050109548`, 0.}, 
      RotationMatrix :> {{-0.9999041389902599, 0.013846040233464488`, 
       0.}, {-0.013846040233464488`, -0.9999041389902599, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09090324594386706, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20424219523535453`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.17492461435293, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38185845370326477`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999041389902599, 0.013846040233464488`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.409518578935311, 1.2417270050109548`, 0.}, 
      Optica`Optica`RayEnd :> {4.098053619989534, 1.2406365255603116`, 0.}, 
      RotationMatrix :> {{-0.9999938710991453, -0.003501108987969863, 0.}, {
       0.003501108987969863, -0.9999938710991453, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09066534806994662, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31146686789533, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.59229021733267, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0920461940591869, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999938710991453, -0.003501108987969863, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.090100669028041, 0.7405292894550553, 0.}, 
      Optica`Optica`RayEnd :> {5.047734840827478, 0.6931117933551798, 0.}, 
      RotationMatrix :> {{-0.6662675572148171, -0.7457127746009183, 0.}, {
       0.7457127746009183, -0.6662675572148171, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02157165976363377, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06358680944583758, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.59629272859572, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18476800645312097`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.6662675572148171, -0.7457127746009183, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.047734840827478, 0.6931117933551798, 0.}, 
      Optica`Optica`RayEnd :> {4.875021438164752, 0.5253603907749506, 0.}, 
      RotationMatrix :> {{-0.7173361129061857, -0.6967272788693175, 0.}, {
       0.6967272788693175, -0.7173361129061857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02145096558646744, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2407705391591159, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.918925251068936`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05784161080500666, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7173361129061857, -0.6967272788693175, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.021253812479882, -1.1394772355398624`, 0.}, 
      Optica`Optica`RayEnd :> {6.054017287501334, -1.3481992558309215`, 0.}, 
      RotationMatrix :> {{0.15507293390029694`, -0.9879030241737057, 0.}, {
       0.9879030241737057, 0.15507293390029694`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008362954487302588, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21127784325352855`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.666042966801307`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.046499940161154885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.15507293390029694`, -0.9879030241737057, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.054017287501334, -1.3481992558309215`, 0.}, 
      Optica`Optica`RayEnd :> {6.070713347817326, -1.596189391324968, 0.}, 
      RotationMatrix :> {{0.06717343464185534, -0.9977413140080026, 0.}, {
       0.9977413140080026, 0.06717343464185534, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008296795959606034, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2485515353652654, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.0338992391419, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1128115464460166, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.06717343464185534, -0.9977413140080026, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.090697161067123, -0.5731585137979203, 0.}, 
      Optica`Optica`RayEnd :> {8.163270847579373, -0.6293038944579838, 0.}, 
      RotationMatrix :> {{0.7909383671724909, -0.611895823923087, 0.}, {
       0.611895823923087, 0.7909383671724909, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009134758395587078, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0917564370681516, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.813838169640658`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3789174036165124, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7909383671724909, -0.611895823923087, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.163270847579373, -0.6293038944579838, 0.}, 
      Optica`Optica`RayEnd :> {8.43413732121714, -0.8473346537407715, 0.}, 
      RotationMatrix :> {{0.7789888149763834, -0.6270378187491479, 0.}, {
       0.6270378187491479, 0.7789888149763834, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009110517163747832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34771548503681704`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.328457087495146`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26206623449405164`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7789888149763834, -0.6270378187491479, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6713872384178625`, 1.2136497580075274`, 0.},
       Optica`Optica`RayEnd :> {3.4149910609401246`, 1.324466377966882, 0.}, 
      RotationMatrix :> {{-0.9179318882511648, 0.39673800994062913`, 
       0.}, {-0.39673800994062913`, -0.9179318882511648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1531548304713613, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27931939260354205`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.89060688301688, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32195509422070084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9179318882511648, 0.39673800994062913`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4149910609401246`, 1.324466377966882, 0.}, 
      Optica`Optica`RayEnd :> {3.2065309528116637`, 1.3940584934118068`, 0.}, 
      RotationMatrix :> {{-0.9485393045002333, 0.31665941927915764`, 
       0.}, {-0.31665941927915764`, -0.9485393045002333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15200720131031964`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21976960484341174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.21586589818513, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41856377150820406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9485393045002333, 0.31665941927915764`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.062560437831467, -1.1680963505251802`, 0.}, 
      Optica`Optica`RayEnd :> {2.9761983032071324`, -1.13879043959612, 0.}, 
      RotationMatrix :> {{-0.9469637783524812, 0.3213403219149313, 
       0.}, {-0.3213403219149313, -0.9469637783524812, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00994207040976963, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09119898416240009, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.28897681138857, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23535632680775706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9469637783524812, 0.3213403219149313, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9761983032071324`, -1.13879043959612, 0.}, 
      Optica`Optica`RayEnd :> {2.843136121561057, -1.0614196196331982`, 0.}, 
      RotationMatrix :> {{-0.8644815345770532, 0.5026645764078687, 
       0.}, {-0.5026645764078687, -0.8644815345770532, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00932575546924344, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15392136942656143`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.51678043813988, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23263485172967396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8644815345770532, 0.5026645764078687, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0912834629691233`, -1.7539364159912485`, 
       0.}, Optica`Optica`RayEnd :> {
       3.0188197633552356`, -1.8708259074624283`, 0.}, 
      RotationMatrix :> {{-0.5268987789970127, -0.8499280420667719, 0.}, {
       0.8499280420667719, -0.5268987789970127, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16795478087493373`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13752869147244426`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.52898463321287, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32514655100111167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5268987789970127, -0.8499280420667719, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0188197633552356`, -1.8708259074624283`, 
       0.}, Optica`Optica`RayEnd :> {2.910787109517695, -2.0825841162416596`, 
       0.}, RotationMatrix :> {{-0.45444614768030106`, -0.8907742131755572, 
       0.}, {0.8907742131755572, -0.45444614768030106`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16675850431367437`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23772377516893506`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.880815820462892`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21429166085909046`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.45444614768030106`, -0.8907742131755572, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.589344272267322, -2.1020351712178833`, 0.}, 
      Optica`Optica`RayEnd :> {3.7667858207547886`, -2.597483960778643, 0.}, 
      RotationMatrix :> {{0.3371713842259424, -0.9414432843560789, 0.}, {
       0.9414432843560789, 0.3371713842259424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008928082137123013, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5262651481970391, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.4641854661487, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10571721623502901`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3371713842259424, -0.9414432843560789, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7667858207547886`, -2.597483960778643, 0.}, 
      Optica`Optica`RayEnd :> {3.836149343049395, -2.845038464983356, 0.}, 
      RotationMatrix :> {{0.26980399544400047`, -0.9629152631682877, 0.}, {
       0.9629152631682877, 0.26980399544400047`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008878183979121459, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25708856601793045`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.844676543855236`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16359889438290084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26980399544400047`, -0.9629152631682877, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5671895390265544`, 2.1378958136711663`, 0.},
       Optica`Optica`RayEnd :> {3.4381985078642834`, 2.3465934659157877`, 0.},
       RotationMatrix :> {{-0.5257570329490828, 0.850634787852329, 
       0.}, {-0.850634787852329, -0.5257570329490828, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042764624025935026`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24534342496330086`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.81572217696931, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3372606555892785, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.5257570329490828, 0.850634787852329, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4381985078642834`, 2.3465934659157877`, 0.},
       Optica`Optica`RayEnd :> {3.3278659338480487`, 2.5662557517157665`, 0.},
       RotationMatrix :> {{-0.4488447516147086, 0.8936097520438832, 
       0.}, {-0.8936097520438832, -0.4488447516147086, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042428635352687254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24581455752644016`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.179527722108443`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20531036951850623`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4488447516147086, 0.8936097520438832, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.380048048528092, 2.0105057011738268`, 0.}, 
      Optica`Optica`RayEnd :> {4.3348175139279395`, 2.1146606225039792`, 0.}, 
      RotationMatrix :> {{-0.39832454111067855`, 0.9172445475166185, 
       0.}, {-0.9172445475166185, -0.39832454111067855`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04909041915403561, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11355196562590122`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      14.814176425460667`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0472606636631141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.39832454111067855`, 0.9172445475166185, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.3348175139279395`, 2.1146606225039792`, 0.},
       Optica`Optica`RayEnd :> {4.199617787190727, 2.409714096482288, 0.}, 
      RotationMatrix :> {{-0.41657038811013153`, 0.9091034659211091, 
       0.}, {-0.9091034659211091, -0.41657038811013153`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04895945632813861, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3245543384650491, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.294516846388941`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3461517631719023, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.41657038811013153`, 0.9091034659211091, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.84117167131676, 0.5997028117287332, 0.}, 
      Optica`Optica`RayEnd :> {3.605395170373543, 0.5641122271604382, 0.}, 
      RotationMatrix :> {{-0.9887980476343677, -0.14925957588865593`, 0.}, {
       0.14925957588865593`, -0.9887980476343677, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012694726333383463`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2384475793690091, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.221675320183113`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27590894883116757`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9887980476343677, -0.14925957588865593`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.605395170373543, 0.5641122271604382, 0.}, 
      Optica`Optica`RayEnd :> {3.3170462945642005`, 0.5115606526621097, 0.}, 
      RotationMatrix :> {{-0.9837950606213925, -0.17929662210133596`, 0.}, {
       0.17929662210133596`, -0.9837950606213925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012657291554271059`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2930985195506194, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.65546112911803, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05096740716949277, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9837950606213925, -0.17929662210133596`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.224191606502897, 2.8622039459876105`, 0.}, 
      Optica`Optica`RayEnd :> {5.137604686626926, 2.930542326395737, 0.}, 
      RotationMatrix :> {{-0.7849696794030547, 0.6195341817994099, 
       0.}, {-0.6195341817994099, -0.7849696794030547, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18631454395185035`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11030606932718484`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.36535354919802, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.303417653563508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7849696794030547, 0.6195341817994099, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.137604686626926, 2.930542326395737, 0.}, 
      Optica`Optica`RayEnd :> {4.886521337520707, 3.1181709029604834`, 0.}, 
      RotationMatrix :> {{-0.8010461408400552, 0.5986026062800373, 
       0.}, {-0.5986026062800373, -0.8010461408400552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18578832793871375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3134443027750038, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.829251117305025`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38802754798609407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8010461408400552, 0.5986026062800373, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.093661954241497, 1.5245104065784694`, 0.}, 
      Optica`Optica`RayEnd :> {7.1663719160576385`, 1.4378542619639703`, 0.}, 
      RotationMatrix :> {{0.6427711275073402, -0.7660582730073093, 0.}, {
       0.7660582730073093, 0.6427711275073402, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032578850988604406`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1131195206264319, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.204373815364928`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3383152589810769, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6427711275073402, -0.7660582730073093, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1663719160576385`, 1.4378542619639703`, 0.},
       Optica`Optica`RayEnd :> {7.352014452126943, 1.193465846067691, 0.}, 
      RotationMatrix :> {{0.6048918704230016, -0.7963076196396474, 0.}, {
       0.7963076196396474, 0.6048918704230016, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03245583209334701, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.306902018602901, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.65858880289722, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2639318359995088, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6048918704230016, -0.7963076196396474, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.7707649418967755`, 1.571081812287572, 0.}, 
      Optica`Optica`RayEnd :> {6.829062553610241, 1.3980842767110477`, 0.}, 
      RotationMatrix :> {{0.3193406639066718, -0.947639984580455, 0.}, {
       0.947639984580455, 0.3193406639066718, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013781130053024898`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1825561799749457, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.586798226671183`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07523538563416286, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3193406639066718, -0.947639984580455, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.829062553610241, 1.3980842767110477`, 0.}, 
      Optica`Optica`RayEnd :> {6.869205868538643, 1.1908184192383027`, 0.}, 
      RotationMatrix :> {{0.19014674174504642`, -0.9817556807086688, 0.}, {
       0.9817556807086688, 0.19014674174504642`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013513575193398476`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21111755352730163`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.899252205891589`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2543472147826863, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19014674174504642`, -0.9817556807086688, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.327120076572609, 2.606217434266993, 0.}, 
      Optica`Optica`RayEnd :> {6.191739739163332, 2.5756248385797793`, 0.}, 
      RotationMatrix :> {{-0.9754056301994296, -0.22041745977860344`, 0.}, {
       0.22041745977860344`, -0.9754056301994296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019117468852863858`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13879388555671698`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.190533770457963`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23788405852606698`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9754056301994296, -0.22041745977860344`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.191739739163332, 2.5756248385797793`, 0.}, 
      Optica`Optica`RayEnd :> {5.882439085046726, 2.4952029161458746`, 0.}, 
      RotationMatrix :> {{-0.9678196472706175, -0.25164484965318923`, 0.}, {
       0.25164484965318923`, -0.9678196472706175, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019059989290064604`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31958501254740584`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.663519589028123`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.021294354986144765`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9678196472706175, -0.25164484965318923`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.829041889572819, 3.1787664066759094`, 0.}, 
      Optica`Optica`RayEnd :> {7.0636939052972245`, 3.176395837595149, 0.}, 
      RotationMatrix :> {{0.9999489737778557, -0.010101972114996749`, 0.}, {
       0.010101972114996749`, 0.9999489737778557, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07845606345703046, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.234663989741275, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.767998003197464`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23967687341805147`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9999489737778557, -0.010101972114996749`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.0636939052972245`, 3.176395837595149, 0.}, 
      Optica`Optica`RayEnd :> {7.36873589652042, 3.1892380843199777`, 0.}, 
      RotationMatrix :> {{0.999114974206817, 0.0420626712859562, 
       0.}, {-0.0420626712859562, 0.999114974206817, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07814151938321014, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3053122003955186, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.21986005978283, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29514962543502926`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.999114974206817, 0.0420626712859562, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.883506851961149, 3.3440089025840014`, 0.}, 
      Optica`Optica`RayEnd :> {6.887209292294565, 3.364039245201363, 0.}, 
      RotationMatrix :> {{0.1817625789483115, 0.9833424453841386, 
       0.}, {-0.9833424453841386, 0.1817625789483115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.741707248655444, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02036965119464261, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.73834451292233, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42427826246217654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1817625789483115, 0.9833424453841386, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.887209292294565, 3.364039245201363, 0.}, 
      Optica`Optica`RayEnd :> {6.942088537623861, 3.6182506337634655`, 0.}, 
      RotationMatrix :> {{0.2110191476033463, 0.9774819278865241, 
       0.}, {-0.9774819278865241, 0.2110191476033463, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7307488563514473`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2600676097528972, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.12324457535662, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2773557601388137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.2110191476033463, 0.9774819278865241, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.942088537623861, 3.6182506337634655`, 0.}, 
      Optica`Optica`RayEnd :> {7.0291737225527635`, 3.3731969004548623`, 0.}, 
      RotationMatrix :> {{0.3348559438510854, -0.9422693335069319, 0.}, {
       0.9422693335069319, 0.3348559438510854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010926298301470265`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26006760975289706`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.508144637790906`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04737307256148052, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 96, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.3348559438510854, -0.9422693335069319, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.730079919853941, 3.4260557860474723`, 0.}, 
      Optica`Optica`RayEnd :> {6.614471715614493, 3.468972186371477, 0.}, 
      RotationMatrix :> {{-0.9374882242578014, 0.3480169958176652, 
       0.}, {-0.3480169958176652, -0.9374882242578014, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07532887276321726, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12331696681414196`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.133794839229814`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3301347058420965, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9374882242578014, 0.3480169958176652, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.614471715614493, 3.468972186371477, 0.}, 
      Optica`Optica`RayEnd :> {6.3305081301654775`, 3.5734870220448216`, 0.}, 
      RotationMatrix :> {{-0.9384538415383891, 0.34540467180082945`, 
       0.}, {-0.34540467180082945`, -0.9384538415383891, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07514292080116731, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30258663013571285`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.581623051830668`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1851443533586183, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9384538415383891, 0.34540467180082945`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.090703027845902, 2.372357661055526, 0.}, 
      Optica`Optica`RayEnd :> {7.258892531326898, 2.1212958894635108`, 0.}, 
      RotationMatrix :> {{0.5565659042857912, -0.8308034630323458, 0.}, {
       0.8308034630323458, 0.5565659042857912, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019169158045519, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3021915323699611, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.408150499292525`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08102089467116462, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 94, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5565659042857912, -0.8308034630323458, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.589205417729699, 2.225663533370224, 0.}, 
      Optica`Optica`RayEnd :> {5.358245643211889, 2.1082057756821846`, 0.}, 
      RotationMatrix :> {{-0.8913530322241144, -0.45330979687723005`, 0.}, {
       0.45330979687723005`, -0.8913530322241144, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013783292482927213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25911144761746746`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.51386183159191, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11772999314647845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8913530322241144, -0.45330979687723005`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.358245643211889, 2.1082057756821846`, 0.}, 
      Optica`Optica`RayEnd :> {5.195563023826857, 2.0683216790920302`, 0.}, 
      RotationMatrix :> {{-0.9712373410913343, -0.23811347561579527`, 0.}, {
       0.23811347561579527`, -0.9712373410913343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01242147399553092, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16750037555417, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.76176238741208, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3600836404604806, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9712373410913343, -0.23811347561579527`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1144186586145235`, 2.7118462900651146`, 0.},
       Optica`Optica`RayEnd :> {4.908658190760104, 2.788062173697886, 0.}, 
      RotationMatrix :> {{-0.9377364358890823, 0.3473476310643849, 
       0.}, {-0.3473476310643849, -0.9377364358890823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03266024374529178, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21942249440199552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.37197720427856, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40741475877840216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9377364358890823, 0.3473476310643849, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.908658190760104, 2.788062173697886, 0.}, 
      Optica`Optica`RayEnd :> {4.631857465184819, 2.876601243636376, 0.}, 
      RotationMatrix :> {{-0.9524612588409527, 0.30465972888963655`, 
       0.}, {-0.30465972888963655`, -0.9524612588409527, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03254310426332896, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29061625657312634`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.80208926400679, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3274025856261691, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9524612588409527, 0.30465972888963655`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.113793252067586, 1.4194705564399406`, 0.}, 
      Optica`Optica`RayEnd :> {8.169498280706339, 1.4059822232091812`, 0.}, 
      RotationMatrix :> {{0.9719136539600106, -0.2353377344288402, 0.}, {
       0.2353377344288402, 0.9719136539600106, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1740479652495941, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05731479171198518, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.276028565530176`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35243614001930773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9719136539600106, -0.2353377344288402, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.169498280706339, 1.4059822232091812`, 0.}, 
      Optica`Optica`RayEnd :> {8.469682112473555, 1.3151141464055818`, 0.}, 
      RotationMatrix :> {{0.9571099533512492, -0.28972493368015156`, 0.}, {
       0.28972493368015156`, 0.9571099533512492, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1732988597622128, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31363568074508624`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.740209373032904`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3765736727966392, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9571099533512492, -0.28972493368015156`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.694976960098423, 0.14421027926079488`, 0.}, 
      Optica`Optica`RayEnd :> {4.66760203244225, 0.12211145550534279`, 0.}, 
      RotationMatrix :> {{-0.7781036395990352, -0.6281359136705474, 0.}, {
       0.6281359136705474, -0.7781036395990352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012521240303991646`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03518159569370324, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.109548048687984`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20660387976428785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7781036395990352, -0.6281359136705474, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.66760203244225, 0.12211145550534279`, 0.}, 
      Optica`Optica`RayEnd :> {4.428739814516301, -0.06855911911277814, 0.}, 
      RotationMatrix :> {{-0.7815374283222268, -0.6238583558240435, 0.}, {
       0.6238583558240435, -0.7815374283222268, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01249019145047567, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3056311947064769, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.56188221685357, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3319852067486795, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7815374283222268, -0.6238583558240435, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1565195605696372`, 1.3367049720306945`, 0.},
       Optica`Optica`RayEnd :> {3.0764932009547103`, 1.3567604682757834`, 0.},
       RotationMatrix :> {{-0.9700028583470895, 0.24309351039975224`, 
       0.}, {-0.24309351039975224`, -0.9700028583470895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08317749832810706, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08250115855461902, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.981252123444708`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.008521146294501458, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9700028583470895, 0.24309351039975224`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0764932009547103`, 1.3567604682757834`, 0.},
       Optica`Optica`RayEnd :> {2.8263520093400993`, 1.444130763380094, 0.}, 
      RotationMatrix :> {{-0.9440689537504765, 0.32974810168442065`, 
       0.}, {-0.32974810168442065`, -0.9440689537504765, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08249257582622119, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26496072201175724`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.37339399202211, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17523877739088736`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9440689537504765, 0.32974810168442065`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.388221823160652, 2.9095274470816745`, 0.}, 
      Optica`Optica`RayEnd :> {4.388688848237903, 2.920111326351133, 0.}, 
      RotationMatrix :> {{0.044083180987473936`, 0.9990278640528631, 
       0.}, {-0.9990278640528631, 0.044083180987473936`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008843443212274158, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.010594178250966629`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.81121436050481, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24041229163728595`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.044083180987473936`, 0.9990278640528631, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.388688848237903, 2.920111326351133, 0.}, 
      Optica`Optica`RayEnd :> {4.425356686909021, 3.1169129380419007`, 0.}, 
      RotationMatrix :> {{0.18316662920395643`, 0.9830818816080686, 
       0.}, {-0.9830818816080686, 0.18316662920395643`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008649489005714219, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20018842313404364`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.107493226743195`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3821670894424817, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.18316662920395643`, 0.9830818816080686, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.675537600714022, 2.844785459439058, 0.}, 
      Optica`Optica`RayEnd :> {3.6666652177736796`, 2.9995176613208825`, 0.}, 
      RotationMatrix :> {{-0.057246215911042814`, 0.9983600907307275, 
       0.}, {-0.9983600907307275, -0.057246215911042814`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014624819685761025`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15498636545915181`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.158238584685968`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39829330182980005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.057246215911042814`, 0.9983600907307275, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6666652177736796`, 2.9995176613208825`, 0.},
       Optica`Optica`RayEnd :> {3.6155601683525647`, 3.140748752813215, 0.}, 
      RotationMatrix :> {{-0.3402624493683713, 0.9403305086775802, 
       0.}, {-0.9403305086775802, -0.3402624493683713, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011409047810579394`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1501930333951956, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.380524274110858`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11264254315645789`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3402624493683713, 0.9403305086775802, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3314682700404803`, 2.4287451418733497`, 0.},
       Optica`Optica`RayEnd :> {3.2138668225961746`, 2.4745554143657085`, 0.},
       RotationMatrix :> {{-0.9318001000897785, 0.36297186319696845`, 
       0.}, {-0.36297186319696845`, -0.9318001000897785, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.221655169890112, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12620888045941908`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.05164575875171, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.394525768796124, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9318001000897785, 0.36297186319696845`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2138668225961746`, 2.4745554143657085`, 0.},
       Optica`Optica`RayEnd :> {2.868843846892141, 2.60011284487213, 0.}, 
      RotationMatrix :> {{-0.9397107067233132, 0.3419704485325761, 
       0.}, {-0.3419704485325761, -0.9397107067233132, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22105176618492475`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3671587151614967, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.595040657190726`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26563204640741234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9397107067233132, 0.3419704485325761, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4118601926906513`, 1.9774712451865195`, 0.},
       Optica`Optica`RayEnd :> {3.3814054766801434`, 1.8943963373611692`, 0.},
       RotationMatrix :> {{-0.34419404170582346`, -0.9388985364000786, 0.}, {
       0.9388985364000786, -0.34419404170582346`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012800904582199806`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08848124116145263, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.151309484414476`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09410929167048557, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.34419404170582346`, -0.9388985364000786, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3814054766801434`, 1.8943963373611692`, 0.},
       Optica`Optica`RayEnd :> {3.26131283152225, 1.5996640494127237`, 0.}, 
      RotationMatrix :> {{-0.3773414261297282, -0.9260742130771068, 0.}, {
       0.9260742130771068, -0.3773414261297282, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012760774007616042`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3182599016218429, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.622334138814804`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2758910734439414, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3773414261297282, -0.9260742130771068, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.345010882115403, 1.4163935745926908`, 0.}, 
      Optica`Optica`RayEnd :> {3.3381077552641885`, 1.405688281109693, 0.}, 
      RotationMatrix :> {{-0.5419320596946654, -0.8404223002009749, 0.}, {
       0.8404223002009749, -0.5419320596946654, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008193712934874038, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.012737993126119911`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.2621292738803, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06041730478714764, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5419320596946654, -0.8404223002009749, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3381077552641885`, 1.405688281109693, 0.}, 
      Optica`Optica`RayEnd :> {3.191782608675725, 1.1704668874483517`, 0.}, 
      RotationMatrix :> {{-0.5282112403161848, -0.8491129993137766, 0.}, {
       0.8491129993137766, -0.5282112403161848, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008172425749640224, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2770201302434879, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.672119066640665`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37901240317945506`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5282112403161848, -0.8491129993137766, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3311028726883682`, -2.9944225439346672`, 
       0.}, 
      Optica`Optica`RayEnd :> {2.9000758278077194`, -3.30278184605173, 0.}, 
      RotationMatrix :> {{-0.8133023357655823, -0.581841310529123, 0.}, {
       0.581841310529123, -0.8133023357655823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012184455247384334`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5299714828372059, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.04826932995492, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3828776813844237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8133023357655823, -0.581841310529123, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9000758278077194`, -3.30278184605173, 0.}, 
      Optica`Optica`RayEnd :> {2.69371070634779, -3.4233066182279197`, 0.}, 
      RotationMatrix :> {{-0.8635144946115043, -0.5043240204430458, 0.}, {
       0.5043240204430458, -0.8635144946115043, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012080212992138361`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23898281122979118`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.40196389057501, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37964280975541864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8635144946115043, -0.5043240204430458, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.770942851840212, -3.9269453409866735`, 0.}, 
      Optica`Optica`RayEnd :> {6.968359650415052, -4.329024738210822, 0.}, 
      RotationMatrix :> {{0.4407314169630475, -0.8976390243866093, 0.}, {
       0.8976390243866093, 0.4407314169630475, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01749894099858938, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4479299432184386, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.496383723310164`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3047167632123439, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.4407314169630475, -0.8976390243866093, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.968359650415052, -4.329024738210822, 0.}, 
      Optica`Optica`RayEnd :> {7.114318319292503, -4.651750633423436, 0.}, 
      RotationMatrix :> {{0.41208260825668297`, -0.9111464887559895, 0.}, {
       0.9111464887559895, 0.41208260825668297`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01744661169277578, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35419759522230027`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.02059616423917, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09645709533979605, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.41208260825668297`, -0.9111464887559895, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.2854634585950215`, 2.930051637924093, 0.}, 
      Optica`Optica`RayEnd :> {6.330169129435359, 2.933234084288223, 0.}, 
      RotationMatrix :> {{0.9974758208408028, 0.07100694922305975, 
       0.}, {-0.07100694922305975, 0.9974758208408028, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011655650103300682`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04481880152508711, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.52309589700013, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12003839343910121`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9974758208408028, 0.07100694922305975, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.330169129435359, 2.933234084288223, 0.}, 
      Optica`Optica`RayEnd :> {6.65303976200892, 2.961530386470526, 0.}, 
      RotationMatrix :> {{0.9961816188604269, 0.08730511007162572, 
       0.}, {-0.08730511007162572, 0.9961816188604269, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011625347850951798`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3241082012162659, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.002776034800203`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4151331797928702, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 95, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9961816188604269, 0.08730511007162572, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.653245556053751, -3.501540898488227, 0.}, 
      Optica`Optica`RayEnd :> {4.773889911495325, -3.6391532943810976`, 0.}, 
      RotationMatrix :> {{0.6592269628729996, -0.7519440214678486, 0.}, {
       0.7519440214678486, 0.6592269628729996, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026032176261107487`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18300883039703075`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.361977515787775`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.021455025231947426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6592269628729996, -0.7519440214678486, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.773889911495325, -3.6391532943810976`, 0.}, 
      Optica`Optica`RayEnd :> {4.854366695460026, -3.7783913530293813`, 0.}, 
      RotationMatrix :> {{0.5004087189011744, -0.8657893011857358, 0.}, {
       0.8657893011857358, 0.5004087189011744, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02451448565971566, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.160822105860619, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.59999423246149, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42213949969867476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5004087189011744, -0.8657893011857358, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.421968446816875, -1.7712630858995746`, 0.}, 
      Optica`Optica`RayEnd :> {5.607815702618099, -1.7564436272019612`, 0.}, 
      RotationMatrix :> {{0.996835848229259, 0.07948768259959767, 
       0.}, {-0.07948768259959767, 0.996835848229259, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00832203806118468, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18643717130694734`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.745370216166915`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.078136602580048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.996835848229259, 0.07948768259959767, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.607815702618099, -1.7564436272019612`, 0.}, 
      Optica`Optica`RayEnd :> {5.921928558588366, -1.7290781022400192`, 0.}, 
      RotationMatrix :> {{0.9962265159529583, 0.08679129514087686, 
       0.}, {-0.08679129514087686, 0.9962265159529583, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008301303467120947, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3153026454729496, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.21201813146688, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42872995490205845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9962265159529583, 0.08679129514087686, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7481042170747867`, 2.8938741145769025`, 0.},
       Optica`Optica`RayEnd :> {3.8509603849960232`, 3.1063593674367422`, 0.},
       RotationMatrix :> {{0.4357007000298271, 0.9000916064454325, 
       0.}, {-0.9000916064454325, 0.4357007000298271, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008664152882538302, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23607069695824523`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.920327517561121`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.051632270254747384`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.4357007000298271, 0.9000916064454325, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8509603849960232`, 3.1063593674367422`, 0.},
       Optica`Optica`RayEnd :> {3.933775921915895, 3.33685800507418, 0.}, 
      RotationMatrix :> {{0.33812672914295605`, 0.9411005870995336, 
       0.}, {-0.9411005870995336, 0.33812672914295605`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008566952064386606, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24492454982716932`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.282815851305333`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.276684014825025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.33812672914295605`, 0.9411005870995336, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.656496102702559, 2.8886382820148584`, 0.}, 
      Optica`Optica`RayEnd :> {2.6041384557393847`, 2.9145896264108724`, 0.}, 
      RotationMatrix :> {{-0.8959788788014028, 0.44409666598813996`, 
       0.}, {-0.44409666598813996`, -0.8959788788014028, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3746654523928048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0584362513469244, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.154765592535234`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2876486435537588, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8959788788014028, 0.44409666598813996`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6041384557393847`, 2.9145896264108724`, 0.},
       Optica`Optica`RayEnd :> {2.319455317078221, 3.0548251894317278`, 0.}, 
      RotationMatrix :> {{-0.8970659319687213, 0.44189672289019044`, 
       0.}, {-0.44189672289019044`, -0.8970659319687213, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3737409020829626, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31734918083043406`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.624442380164275`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23141890697453307`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8970659319687213, 0.44189672289019044`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1617716970949905`, 1.7234169393512568`, 0.},
       Optica`Optica`RayEnd :> {2.0981549132147475`, 1.6950179459541808`, 0.},
       RotationMatrix :> {{-0.9131451304642116, -0.4076346044063221, 0.}, {
       0.4076346044063221, -0.9131451304642116, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00853776203299345, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06966776885499273, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.86485240014804, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011244414421406598`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9131451304642116, -0.4076346044063221, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0981549132147475`, 1.6950179459541808`, 0.},
       Optica`Optica`RayEnd :> {1.8170903467914052`, 1.5473035894966969`, 0.},
       RotationMatrix :> {{-0.8851963146167892, -0.46521767441581063`, 0.}, {
       0.46521767441581063`, -0.8851963146167892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008495656917114966, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3175166477562872, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.334777038827347`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028457526285340436`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8851963146167892, -0.46521767441581063`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.858952183105744, 2.80193995526425, 0.}, 
      Optica`Optica`RayEnd :> {6.340608338011412, 3.0416477975838894`, 0.}, 
      RotationMatrix :> {{0.8952585162200147, 0.4455470672505177, 
       0.}, {-0.4455470672505177, 0.8952585162200147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009198770556912162, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5380079007115509, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.51351433931871, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21044852593345847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8952585162200147, 0.4455470672505177, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.340608338011412, 3.0416477975838894`, 0.}, 
      Optica`Optica`RayEnd :> {6.558434112117004, 3.121394561388964, 0.}, 
      RotationMatrix :> {{0.9390471480478572, 0.3437883851196627, 
       0.}, {-0.3437883851196627, 0.9390471480478572, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009084833907498703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2319646830922386, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.856822070295223`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04450746035349828, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9390471480478572, 0.3437883851196627, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8724930742377612`, -0.8881629628885982, 0.},
       Optica`Optica`RayEnd :> {2.8708371103867525`, -0.888634715180869, 0.}, 
      RotationMatrix :> {{-0.9617354057140762, -0.27397994341918835`, 0.}, {
       0.27397994341918835`, -0.9617354057140762, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02431882532272911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.001721849732441992, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.034440829416233`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04505228967684855, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9617354057140762, -0.27397994341918835`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8708371103867525`, -0.888634715180869, 0.}, 
      Optica`Optica`RayEnd :> {2.7207957282082207`, -0.8988499529645195, 0.}, 
      RotationMatrix :> {{-0.9976903921488153, -0.06792555788466942, 0.}, {
       0.06792555788466942, -0.9976903921488153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022553581274540324`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15038872114962845`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.257016136717684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42113181004879857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9976903921488153, -0.06792555788466942, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3099577862941993`, -1.0111371331343069`, 
       0.}, Optica`Optica`RayEnd :> {2.1558050837059786`, -0.9965654936102184,
        0.}, RotationMatrix :> {{-0.9955620136883198, 0.09410779404947259, 
       0.}, {-0.09410779404947259, -0.9955620136883198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013066833339828143`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15483987985552186`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.007848817917345`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4041053895860915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9955620136883198, 0.09410779404947259, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1558050837059786`, -0.9965654936102184, 0.},
       Optica`Optica`RayEnd :> {1.779063316539821, -0.9682283827490923, 0.}, 
      RotationMatrix :> {{-0.9971832026650952, 0.07500440202137448, 
       0.}, {-0.07500440202137448, -0.9971832026650952, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013032187873623657`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3778059700156086, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.567001653540448`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12672250502905924`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9971832026650952, 0.07500440202137448, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.335307961329535, 0.9947123023651957, 0.}, 
      Optica`Optica`RayEnd :> {4.167880082384757, 1.1262556643233088`, 0.}, 
      RotationMatrix :> {{-0.7863345707225942, 0.6178008925912246, 
       0.}, {-0.6178008925912246, -0.7863345707225942, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009159797611967821, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21292193574920976`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.919956355636366`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23253167011342857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.7863345707225942, 0.6178008925912246, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.167880082384757, 1.1262556643233088`, 0.}, 
      Optica`Optica`RayEnd :> {4.019750937957919, 1.1993746870569428`, 0.}, 
      RotationMatrix :> {{-0.8967050361352947, 0.44262860071351035`, 
       0.}, {-0.44262860071351035`, -0.8967050361352947, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008516651925285315, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16519272052408576`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.164441582012014`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.288008522853316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8967050361352947, 0.44262860071351035`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.9507690227662335`, 0.8052219787546446, 0.}, 
      Optica`Optica`RayEnd :> {7.976217467467496, 0.8887484947175992, 0.}, 
      RotationMatrix :> {{0.2914480770145259, 0.9565866497105917, 
       0.}, {-0.9565866497105917, 0.2914480770145259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018436223252223514`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08731725033819457, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.56483591149349, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3800158870255161, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2914480770145259, 0.9565866497105917, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.976217467467496, 0.8887484947175992, 0.}, 
      Optica`Optica`RayEnd :> {8.073286747564538, 1.2026505553483355`, 0.}, 
      RotationMatrix :> {{0.2954313016560805, 0.9553639861339724, 
       0.}, {-0.9553639861339724, 0.2954313016560805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01839062436127478, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32856802766973575`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.051116592444696`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13025389974567617`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2954313016560805, 0.9553639861339724, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.639163844367371, 0.35600074813492016`, 0.}, 
      Optica`Optica`RayEnd :> {6.5917685741927246`, 0.47514305546185914`, 0.},
       RotationMatrix :> {{-0.36963086915041304`, 0.9291786806481895, 
       0.}, {-0.9291786806481895, -0.36963086915041304`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013276518276663214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1282232468396993, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.7825251991345, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29543795323830857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.36963086915041304`, 0.9291786806481895, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5917685741927246`, 0.47514305546185914`, 
       0.}, Optica`Optica`RayEnd :> {6.499397579882815, 0.6579562769550734, 
       0.}, RotationMatrix :> {{-0.4509763026128048, 0.8925359233564125, 
       0.}, {-0.8925359233564125, -0.4509763026128048, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013169861514621333`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20482449692975804`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.085665454590544`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14946618197562028`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.4509763026128048, 0.8925359233564125, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.364338814151551, -1.8536428419150592`, 0.}, 
      Optica`Optica`RayEnd :> {6.301717809521697, -1.869685007195425, 0.}, 
      RotationMatrix :> {{-0.9687178195714703, -0.24816483643879983`, 0.}, {
       0.24816483643879983`, -0.9687178195714703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02064081004072096, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06464318438733353, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.477551344176895`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18614808159145155`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9687178195714703, -0.24816483643879983`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.301717809521697, -1.869685007195425, 0.}, 
      Optica`Optica`RayEnd :> {6.135532990828835, -1.892394399522408, 0.}, 
      RotationMatrix :> {{-0.990791955746978, -0.1353931328652912, 0.}, {
       0.1353931328652912, -0.990791955746978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02036317876011437, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16772927730077414`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.72579067458204, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40299208607459047`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.990791955746978, -0.1353931328652912, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.388525244576338, -2.6663777250317304`, 0.}, 
      Optica`Optica`RayEnd :> {7.385285491719142, -2.67304322521958, 0.}, 
      RotationMatrix :> {{-0.4371467746017095, -0.8993901808755316, 0.}, {
       0.8993901808755316, -0.4371467746017095, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03963360653490009, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.00741113293160617, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.210708041369724`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07385284752311151, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.4371467746017095, -0.8993901808755316, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.385285491719142, -2.67304322521958, 0.}, 
      Optica`Optica`RayEnd :> {7.249945292601955, -2.9372034400351885`, 0.}, 
      RotationMatrix :> {{-0.4559789567159755, -0.8899905567095697, 0.}, {
       0.8899905567095697, -0.4559789567159755, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039526969423696795`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29681237943944977`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.64999036294011, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35822335389180543`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.4559789567159755, -0.8899905567095697, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.618630463181174, -2.1975476124328246`, 0.}, 
      Optica`Optica`RayEnd :> {7.383847382218892, -2.223507775755651, 0.}, 
      RotationMatrix :> {{-0.9939425315822856, -0.10990106419774384`, 0.}, {
       0.10990106419774384`, -0.9939425315822856, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015544163493847673`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23621393944026484`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.399637859332685`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39613135691610957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9939425315822856, -0.10990106419774384`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.383847382218892, -2.223507775755651, 0.}, 
      Optica`Optica`RayEnd :> {7.071484832429513, -2.258721142881024, 0.}, 
      RotationMatrix :> {{-0.9937056387893299, -0.11202278088982245`, 0.}, {
       0.11202278088982245`, -0.9937056387893299, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015505816997499491`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3143411263821975, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.864862726378337`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04584933297711024, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9937056387893299, -0.11202278088982245`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.10977393330874, -1.6417027819848846`, 0.}, 
      Optica`Optica`RayEnd :> {8.10964461137912, -1.6411335578766304`, 0.}, 
      RotationMatrix :> {{-0.2215442380076121, 0.9751503220558491, 
       0.}, {-0.9751503220558491, -0.2215442380076121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015434845306351783`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0005837296008416803, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.010174560477857`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17293571268103983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2215442380076121, 0.9751503220558491, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.10964461137912, -1.6411335578766304`, 0.}, 
      Optica`Optica`RayEnd :> {8.037465293458888, -1.4027113492410619`, 0.}, 
      RotationMatrix :> {{-0.2897506183835745, 0.9571021780073096, 
       0.}, {-0.9571021780073096, -0.2897506183835745, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015348831316798414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24910841717230692`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.37885501789287, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1163072992474806, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2897506183835745, 0.9571021780073096, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.232240954122844, -0.5926830924116476, 0.}, 
      Optica`Optica`RayEnd :> {8.307891776053028, -0.40206142026351155`, 0.}, 
      RotationMatrix :> {{0.3688762777852217, 0.9294785052314658, 
       0.}, {-0.9294785052314658, 0.3688762777852217, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02112427731894346, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20508454049797095`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.220956414595992`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13883420446247152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3688762777852217, 0.9294785052314658, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.307891776053028, -0.40206142026351155`, 0.},
       Optica`Optica`RayEnd :> {8.397117182488653, -0.1252058009954891, 0.}, 
      RotationMatrix :> {{0.30674476237418513`, 0.9517918106161687, 
       0.}, {-0.9517918106161687, 0.30674476237418513`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02101616993305529, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29087833723720774`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.65145635370706, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16776878347075422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.30674476237418513`, 0.9517918106161687, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.436956136237303, -0.4163147868373776, 0.}, 
      Optica`Optica`RayEnd :> {6.378723026894536, -0.3138436879739406, 0.}, 
      RotationMatrix :> {{-0.49407927959086817`, 0.8694168536892807, 
       0.}, {-0.8694168536892807, -0.49407927959086817`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013463256595579277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11786187308034282`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.98795199376765, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37056464549402474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.49407927959086817`, 0.8694168536892807, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.378723026894536, -0.3138436879739406, 0.}, 
      Optica`Optica`RayEnd :> {6.236712677796566, -0.11373154791280835`, 0.}, 
      RotationMatrix :> {{-0.5787342186384962, 0.8155162194444011, 
       0.}, {-0.8155162194444011, -0.5787342186384962, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013327980320105749`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24538094435137728`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.351115791407686`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19452518929351054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5787342186384962, 0.8155162194444011, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.902025869288929, -0.9353251541593269, 0.}, 
      Optica`Optica`RayEnd :> {4.425748637850462, -0.7632457802846241, 0.}, 
      RotationMatrix :> {{-0.9404968769060976, 0.33980233155450307`, 
       0.}, {-0.33980233155450307`, -0.9404968769060976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01920166268202976, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5064102211644242, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.22622617485579, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41219354276899456`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9404968769060976, 0.33980233155450307`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.425748637850462, -0.7632457802846241, 0.}, 
      Optica`Optica`RayEnd :> {4.152490345497259, -0.6774240377395112, 0.}, 
      RotationMatrix :> {{-0.9540530532323976, 0.2996377339687704, 
       0.}, {-0.2996377339687704, -0.9540530532323976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0191355626097128, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28641834060211363`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.650125318946916`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3169961919554478, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9540530532323976, 0.2996377339687704, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.317042174504154, -2.496568643107816, 0.}, 
      Optica`Optica`RayEnd :> {5.267414443626319, -2.551733145538712, 0.}, 
      RotationMatrix :> {{-0.6688134126227949, -0.7434303054731164, 0.}, {
       0.7434303054731164, -0.6688134126227949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09291268710968995, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07420265494260385, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.693270285064603`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17083853329016216`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6688134126227949, -0.7434303054731164, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.267414443626319, -2.551733145538712, 0.}, 
      Optica`Optica`RayEnd :> {5.077151719566918, -2.7896193673170946`, 0.}, 
      RotationMatrix :> {{-0.6246024562837295, -0.7809428734576761, 0.}, {
       0.7809428734576761, -0.6246024562837295, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09250139933565829, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3046141143783355, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.14409917434454, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19307286888728054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6246024562837295, -0.7809428734576761, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.865264422165415, 0.01558219543576532, 0.}, 
      Optica`Optica`RayEnd :> {3.5553008412191462`, 0.10418403203907302`, 0.},
       RotationMatrix :> {{-0.9614904986836407, 0.2748381722779496, 
       0.}, {-0.2748381722779496, -0.9614904986836407, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012538840079773187`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3223782048503175, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.876299903683183`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08914264829423911, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9614904986836407, 0.2748381722779496, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5553008412191462`, 0.10418403203907302`, 
       0.}, Optica`Optica`RayEnd :> {3.3735957448722327`, 
       0.12285257957385658`, 0.}, 
      RotationMatrix :> {{-0.9947635717067949, 0.10220291779171578`, 
       0.}, {-0.10220291779171578`, -0.9947635717067949, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01201232796385104, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18266159066837112`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.14663905787237, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4264924455783983, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9947635717067949, 0.10220291779171578`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.547614972963494, 2.660373650005636, 0.}, 
      Optica`Optica`RayEnd :> {6.554837225932531, 2.7133042740968643`, 0.}, 
      RotationMatrix :> {{0.13519481114784568`, 0.9908190364737133, 
       0.}, {-0.9908190364737133, 0.13519481114784568`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011722491999187169`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.053421081088234124`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.329343603529104`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07092163032217683, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13519481114784568`, 0.9908190364737133, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.554837225932531, 2.7133042740968643`, 0.}, 
      Optica`Optica`RayEnd :> {6.613477516367497, 2.8636309481357225`, 0.}, 
      RotationMatrix :> {{0.36341459999046116`, 0.931627515970719, 
       0.}, {-0.931627515970719, 0.36341459999046116`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010454560928429111`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16135920361070896`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.568155224872953`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3873322002346191, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36341459999046116`, 0.931627515970719, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.015837296923768, 3.1035802932107157`, 0.}, 
      Optica`Optica`RayEnd :> {6.969200230953496, 3.3494134145434793`, 0.}, 
      RotationMatrix :> {{-0.1863858963622646, 0.9824766142953404, 
       0.}, {-0.9824766142953404, -0.1863858963622646, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020868621154033862`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25021778407324435`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.346499045457367`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1887059261323159, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1863858963622646, 0.9824766142953404, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.969200230953496, 3.3494134145434793`, 0.}, 
      Optica`Optica`RayEnd :> {6.920138022643766, 3.6150100035364083`, 0.}, 
      RotationMatrix :> {{-0.18165128204723766`, 0.9833630111665758, 
       0.}, {-0.9833630111665758, -0.18165128204723766`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020816945212477858`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27009007454718953`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.746232355787207`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34167112076384437`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18165128204723766`, 0.9833630111665758, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1844334948319033`, 0.8577212354772984, 0.}, 
      Optica`Optica`RayEnd :> {2.1176780270552102`, 0.888479135663443, 0.}, 
      RotationMatrix :> {{-0.908230015608811, 0.41847131173739793`, 
       0.}, {-0.41847131173739793`, -0.908230015608811, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10768276134729257`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0735006183779835, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.990568457746814`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1569378188093941, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.908230015608811, 0.41847131173739793`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1176780270552102`, 0.888479135663443, 0.}, 
      Optica`Optica`RayEnd :> {1.8258596958523285`, 1.0332433360189008`, 0.}, 
      RotationMatrix :> {{-0.8958287043132981, 0.4443995190460462, 
       0.}, {-0.4443995190460462, -0.8958287043132981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10737113842549359`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32575237854939726`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.472681977999923`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09594243510198663, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.8958287043132981, 0.4443995190460462, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.566128926377194, -1.7924870565715108`, 0.}, 
      Optica`Optica`RayEnd :> {3.4861205041345973`, -1.8568951960375732`, 0.},
       RotationMatrix :> {{-0.7789588170193912, -0.6270750843302183, 0.}, {
       0.6270750843302183, -0.7789588170193912, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04114962275121717, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1027120054289146, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.191508431012842`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34455795576006365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7789588170193912, -0.6270750843302183, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4861205041345973`, -1.8568951960375732`, 
       0.}, Optica`Optica`RayEnd :> {3.383789456511689, -1.9729749954037983`, 
       0.}, RotationMatrix :> {{-0.6612861880588224, -0.7501337064034862, 
       0.}, {0.7501337064034862, -0.6612861880588224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03958053518457367, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1547454785397783, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.420531739251714`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05535498409423818, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6612861880588224, -0.7501337064034862, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.613537725456426, -3.6216851368345666`, 0.}, 
      Optica`Optica`RayEnd :> {5.625609448203834, -3.6732339857997185`, 0.}, 
      RotationMatrix :> {{0.2280115800109916, -0.9736584202793556, 0.}, {
       0.9736584202793556, 0.2280115800109916, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015910411416999663`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.052943463427720126`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.597064869102397`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28952738998638844`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2280115800109916, -0.9736584202793556, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.625609448203834, -3.6732339857997185`, 0.}, 
      Optica`Optica`RayEnd :> {5.7020451715431815`, -3.9112365439015684`, 0.},
       RotationMatrix :> {{0.30577313590065663`, -0.9521044004527431, 0.}, {
       0.9521044004527431, 0.30577313590065663`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01580250332956923, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24997527370808828`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.96702827419037, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3773922554431888, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.30577313590065663`, -0.9521044004527431, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.322692665885227, -1.9171446844618552`, 0.}, 
      Optica`Optica`RayEnd :> {7.338693997548402, -1.9299532556065953`, 0.}, 
      RotationMatrix :> {{0.7806901425322303, -0.6249183157445511, 0.}, {
       0.6249183157445511, 0.7806901425322303, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011674209535511395`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.020496392603694923`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.26561134074783, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11203329150872493`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7806901425322303, -0.6249183157445511, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.338693997548402, -1.9299532556065953`, 0.}, 
      Optica`Optica`RayEnd :> {7.555889127695717, -2.088286515364006, 0.}, 
      RotationMatrix :> {{0.808075164501131, -0.5890793906736771, 0.}, {
       0.5890793906736771, 0.808075164501131, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011632371798397366`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26878085070390806`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.663406999789615`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.006672053105183043, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.808075164501131, -0.5890793906736771, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6460075670016345`, 3.363384076381549, 0.}, 
      Optica`Optica`RayEnd :> {3.641308145352485, 3.366375990633749, 0.}, 
      RotationMatrix :> {{-0.843549823586792, 0.5370509241465758, 
       0.}, {-0.5370509241465758, -0.843549823586792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009234653630834382, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0055710066172109845`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.062401765911112`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16080849674918357`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.843549823586792, 0.5370509241465758, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.641308145352485, 3.366375990633749, 0.}, 
      Optica`Optica`RayEnd :> {3.3690487587760924`, 3.5453326097585736`, 0.}, 
      RotationMatrix :> {{-0.8356444685436416, 0.5492707184917233, 
       0.}, {-0.5492707184917233, -0.8356444685436416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009210907228012639, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3258076811671901, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.544597134038554`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21442604707248403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.8356444685436416, 0.5492707184917233, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.967666509375516, 3.0871540433788582`, 0.}, 
      Optica`Optica`RayEnd :> {6.9869882325984545`, 3.3530902027251317`, 0.}, 
      RotationMatrix :> {{0.07246448295973265, 0.9973709935171456, 
       0.}, {-0.9973709935171456, 0.07246448295973265, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015814907245503013`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.266637150142568, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.18124799740646, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12493104467522997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {0.07246448295973265, 0.9973709935171456, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9869882325984545`, 3.3530902027251317`, 0.},
       Optica`Optica`RayEnd :> {6.996997111901896, 3.6103894700818837`, 0.}, 
      RotationMatrix :> {{0.038870360244440946`, 0.999244261977254, 
       0.}, {-0.999244261977254, 0.038870360244440946`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015766487599311256`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2574938652613538, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.562338917993262`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08694452269421526, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {0.038870360244440946`, 0.999244261977254, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.425253906713074, -2.687134026360825, 0.}, 
      Optica`Optica`RayEnd :> {7.419796584842048, -2.7118805555779257`, 0.}, 
      RotationMatrix :> {{-0.2153542884066502, -0.976535985238058, 0.}, {
       0.976535985238058, -0.2153542884066502, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12442459998907568`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02534113395838486, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.039897966741368`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23671385137181408`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.2153542884066502, -0.976535985238058, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.419796584842048, -2.7118805555779257`, 0.}, 
      Optica`Optica`RayEnd :> {7.34954007318907, -2.9311449148270943`, 0.}, 
      RotationMatrix :> {{-0.3051378352078038, -0.9523081967119125, 0.}, {
       0.9523081967119125, -0.3051378352078038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12334643097475351`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23024516643481038`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.380660813064885`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0633235699830008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3051378352078038, -0.9523081967119125, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.118134773638745, 2.367199620738484, 0.}, 
      Optica`Optica`RayEnd :> {8.117789784286584, 2.3683044252525343`, 0.}, 
      RotationMatrix :> {{-0.2980687130854866, 0.9545444160852663, 
       0.}, {-0.9545444160852663, -0.2980687130854866, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04039309089137395, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0011574155119794063`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.665332429452747`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15482502063696824`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.2980687130854866, 0.9545444160852663, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.117789784286584, 2.3683044252525343`, 0.}, 
      Optica`Optica`RayEnd :> {8.023701590059098, 2.6198351822922343`, 0.}, 
      RotationMatrix :> {{-0.3503534036569916, 0.9366175807371765, 
       0.}, {-0.9366175807371765, -0.3503534036569916, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040222472700680044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2685522482310544, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.062789756834707`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19520266955550478`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3503534036569916, 0.9366175807371765, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.182146425329703, 0.4503276617857824, 0.}, 
      Optica`Optica`RayEnd :> {6.0872471334290434`, 0.4587794600283177, 0.}, 
      RotationMatrix :> {{-0.9960575327698552, 0.08870959030696235, 
       0.}, {-0.08870959030696235, -0.9960575327698552, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008029295604281504, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0952749101116298, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.873770105807917`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25185218665475984`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9960575327698552, 0.08870959030696235, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.0872471334290434`, 0.4587794600283177, 0.}, 
      Optica`Optica`RayEnd :> {5.809237141424264, 0.4956500394430211, 0.}, 
      RotationMatrix :> {{-0.9913198802536617, 0.1314720312989272, 
       0.}, {-0.1314720312989272, -0.9913198802536617, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00800139876845557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28044428195431914`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.28882764310031, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12641710048814306`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9913198802536617, 0.1314720312989272, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.68166825234663, -0.834249674863952, 0.}, 
      Optica`Optica`RayEnd :> {4.601379121612772, -0.8417789523378222, 0.}, 
      RotationMatrix :> {{-0.995631723246744, -0.09336740150994154, 0.}, {
       0.09336740150994154, -0.995631723246744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015286417541420677`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08064139466351666, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.834276507144065`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.043532402266835656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.995631723246744, -0.09336740150994154, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.601379121612772, -0.8417789523378222, 0.}, 
      Optica`Optica`RayEnd :> {4.382315238116761, -0.8858538580442203, 0.}, 
      RotationMatrix :> {{-0.9803544347472161, -0.197243966375314, 0.}, {
       0.197243966375314, -0.9803544347472161, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015117817506643988`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22345375889740962`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.16498807031223, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26683346308666, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9803544347472161, -0.197243966375314, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.857503797053943, -1.631596318035911, 0.}, 
      Optica`Optica`RayEnd :> {6.855348031303997, -2.0773063315811187`, 0.}, 
      RotationMatrix :> {{-0.0048366437128158635`, -0.9999883033703916, 0.}, {
       0.9999883033703916, -0.0048366437128158635`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2609669943318832, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4457152269111276, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.07094349219298, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.053253505460570935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.0048366437128158635`, -0.9999883033703916, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.855348031303997, -2.0773063315811187`, 0.}, 
      Optica`Optica`RayEnd :> {6.842558002495407, -2.3562116887071047`, 0.}, 
      RotationMatrix :> {{-0.04580981056320023, -0.9989501795666103, 0.}, {
       0.9989501795666103, -0.04580981056320023, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26008655888193055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791984653799128, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.484157220955254`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0985314199792425, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.04580981056320023, -0.9989501795666103, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.821491369572861, -1.4078409622156671`, 0.}, 
      Optica`Optica`RayEnd :> {7.85970811237031, -1.482799807515262, 0.}, 
      RotationMatrix :> {{0.4542103657545514, -0.8908944626840577, 0.}, {
       0.8908944626840577, 0.4542103657545514, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27677284337226055`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08413886093057672, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.383207765540696`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21085965657959999`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4542103657545514, -0.8908944626840577, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.85970811237031, -1.482799807515262, 0.}, 
      Optica`Optica`RayEnd :> {7.987758823987346, -1.6947174978191548`, 0.}, 
      RotationMatrix :> {{0.5171662547329607, -0.8558849601234279, 0.}, {
       0.8558849601234279, 0.5171662547329607, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27518630244426884`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24760067085806958`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.74965675841064, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2706493881412343, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5171662547329607, -0.8558849601234279, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.360966391982671, -0.5777872347677663, 0.}, 
      Optica`Optica`RayEnd :> {7.355657786762561, -0.6212897865834256, 0.}, 
      RotationMatrix :> {{-0.12113117805618308`, -0.9926365083466961, 0.}, {
       0.9926365083466961, -0.12113117805618308`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024813013320613118`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0438252587426144, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.934094235028033`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09336985562265566, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.12113117805618308`, -0.9926365083466961, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.355657786762561, -0.6212897865834256, 0.}, 
      Optica`Optica`RayEnd :> {7.296808618032822, -0.9383558163661906, 0.}, 
      RotationMatrix :> {{-0.18248870914519663`, -0.9832079490293593, 0.}, {
       0.9832079490293593, -0.18248870914519663`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024694866876892138`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3224811496853522, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.411366336562352`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08911714646312384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.18248870914519663`, -0.9832079490293593, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.075636979375578, 1.354708650666049, 0.}, 
      Optica`Optica`RayEnd :> {6.024587853821008, 1.3649310161556567`, 0.}, 
      RotationMatrix :> {{-0.9805343269254088, 0.19634773673494355`, 
       0.}, {-0.19634773673494355`, -0.9805343269254088, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012413652334497018`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05206255829374305, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.874773063104684`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2369110221618389, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9805343269254088, 0.19634773673494355`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.024587853821008, 1.3649310161556567`, 0.}, 
      Optica`Optica`RayEnd :> {5.892238369604698, 1.4306052722726568`, 0.}, 
      RotationMatrix :> {{-0.8957780569485854, 0.44450160032267144`, 
       0.}, {-0.44450160032267144`, -0.8957780569485854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01047614904650106, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14774807575344187`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.09344021521978, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2903498417558497, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8957780569485854, 0.44450160032267144`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.462835957629652, 0.3962580859494457, 0.}, 
      Optica`Optica`RayEnd :> {6.401800641306805, 0.31038149519909297`, 0.}, 
      RotationMatrix :> {{-0.579319010082128, -0.8151009045249935, 0.}, {
       0.8151009045249935, -0.579319010082128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17622538980612734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10535700583033701`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.943582393398968`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4078661896051633, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.579319010082128, -0.8151009045249935, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.401800641306805, 0.31038149519909297`, 0.}, 
      Optica`Optica`RayEnd :> {6.243269221268635, 0.13022919532730273`, 0.}, 
      RotationMatrix :> {{-0.6606217797948594, -0.7507188981640676, 0.}, {
       0.7507188981640676, -0.6606217797948594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17433134228123778`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23997304492049482`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.2987424998813, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2350037134851809, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6606217797948594, -0.7507188981640676, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.234378837136803, 0.09399011306815414, 0.}, 
      Optica`Optica`RayEnd :> {7.300742584987046, -0.14451621421034622`, 0.}, 
      RotationMatrix :> {{0.26806379760949606`, -0.9634011627620005, 0.}, {
       0.9634011627620005, 0.26806379760949606`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010707899885893532`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24756699129853665`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.495548828351147`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06656660202986077, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.26806379760949606`, -0.9634011627620005, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.300742584987046, -0.14451621421034622`, 0.},
       Optica`Optica`RayEnd :> {7.35088627346321, -0.39228288094063185`, 0.}, 
      RotationMatrix :> {{0.19836115866556006`, -0.9801289969860375, 0.}, {
       0.9801289969860375, 0.19836115866556006`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01064693246405689, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25278985469482557`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.86967781329949, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13136064076226314`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19836115866556006`, -0.9801289969860375, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.133875783682815, 2.4995612934954696`, 0.}, 
      Optica`Optica`RayEnd :> {7.180237032875569, 2.637246016100087, 0.}, 
      RotationMatrix :> {{0.3191152439008292, 0.9477159179364423, 
       0.}, {-0.9477159179364423, 0.3191152439008292, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0508376786544684, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14528058461275178`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 15.863852679509892`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3728781464642147, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3191152439008292, 0.9477159179364423, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.180237032875569, 2.637246016100087, 0.}, 
      Optica`Optica`RayEnd :> {7.267663358684314, 2.8974339656723194`, 0.}, 
      RotationMatrix :> {{0.3185122630380613, 0.9479187403434811, 
       0.}, {-0.9479187403434811, 0.3185122630380613, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05071237055720806, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2744833902935105, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.27008809714429, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09607383659973731, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.3185122630380613, 0.9479187403434811, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.013927724321256, 2.6322695172548927`, 0.}, 
      Optica`Optica`RayEnd :> {6.881221144900748, 2.7367065227106515`, 0.}, 
      RotationMatrix :> {{-0.7858361007661335, 0.6184348168826508, 
       0.}, {-0.6184348168826508, -0.7858361007661335, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2655809918373722`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1688731012626278, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.160213003303472`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43280381465935236`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7858361007661335, 0.6184348168826508, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.881221144900748, 2.7367065227106515`, 0.}, 
      Optica`Optica`RayEnd :> {6.656119914545259, 2.8887936551931834`, 0.}, 
      RotationMatrix :> {{-0.828603130264842, 0.5598364515778727, 
       0.}, {-0.5598364515778727, -0.828603130264842, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.258255220130773, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27166350467869993`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.562274990227948`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39326919422045026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.828603130264842, 0.5598364515778727, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.848681154583996, 2.563767102786102, 0.}, 
      Optica`Optica`RayEnd :> {6.592467754632565, 2.4023860998368267`, 0.}, 
      RotationMatrix :> {{-0.8461413189894492, -0.5329585990476124, 0.}, {
       0.5329585990476124, -0.8461413189894492, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.047122397252328675`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3028021374224195, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.604424263240343`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15892534375867276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8461413189894492, -0.5329585990476124, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.592467754632565, 2.4023860998368267`, 0.}, 
      Optica`Optica`RayEnd :> {6.435364607407312, 2.3487108780900354`, 0.}, 
      RotationMatrix :> {{-0.9462941314626605, -0.32330700078923097`, 0.}, {
       0.32330700078923097`, -0.9462941314626605, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04227214269382524, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1660193612132241, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.850132917835914`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.326756013061517, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9462941314626605, -0.32330700078923097`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.496013510024986, 2.3292753428951984`, 0.}, 
      Optica`Optica`RayEnd :> {7.340774332740918, 2.1929983763609657`, 0.}, 
      RotationMatrix :> {{-0.7515136748118328, -0.6597175127058656, 0.}, {
       0.6597175127058656, -0.7515136748118328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008675885446115741, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20656866599658005`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.428846468967123`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26304447881591897`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7515136748118328, -0.6597175127058656, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.340774332740918, 2.1929983763609657`, 0.}, 
      Optica`Optica`RayEnd :> {7.198132313286852, 2.111419819714874, 0.}, 
      RotationMatrix :> {{-0.8680626442618957, -0.4964546763170277, 0.}, {
       0.4964546763170277, -0.8680626442618957, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008125914795933447, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16432226452429957`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.672043420463087`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2665130266571361, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8680626442618957, -0.4964546763170277, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.311736426290701, 2.4019540191871216`, 0.}, 
      Optica`Optica`RayEnd :> {7.132449862213479, 2.5089289844678593`, 0.}, 
      RotationMatrix :> {{-0.8587518476613214, 0.5123917096697269, 
       0.}, {-0.5123917096697269, -0.8587518476613214, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24579701805193852`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20877575351422145`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.7249793533854, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38074162206078854`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8587518476613214, 0.5123917096697269, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.132449862213479, 2.5089289844678593`, 0.}, 
      Optica`Optica`RayEnd :> {6.90909050153152, 2.6189814743779674`, 0.}, 
      RotationMatrix :> {{-0.8970258737658832, 0.4419780331583832, 
       0.}, {-0.4419780331583832, -0.8970258737658832, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24414790491148575`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24899990871417554`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.09349921828238, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41997490984837604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8970258737658832, 0.4419780331583832, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.324263802301104, 2.5996489822677544`, 0.}, 
      Optica`Optica`RayEnd :> {7.351885704301527, 2.7200123734695314`, 0.}, 
      RotationMatrix :> {{0.22367331126865916`, 0.9746641728442227, 
       0.}, {-0.9746641728442227, 0.22367331126865916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008112634084741051, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12349216741037865`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.903874735150893`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3194470450564253, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 98, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.22367331126865916`, 0.9746641728442227, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.201544877431438, 1.1301121692279588`, 0.}, 
      Optica`Optica`RayEnd :> {8.20785455614225, 0.9396647794255726, 0.}, 
      RotationMatrix :> {{0.033112654637445366`, -0.9994516256942404, 0.}, {
       0.9994516256942404, 0.033112654637445366`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25843335636736947`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19055188355924405`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.796220374727152`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28542616390423853`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.033112654637445366`, -0.9994516256942404, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.20785455614225, 0.9396647794255726, 0.}, 
      Optica`Optica`RayEnd :> {8.220310908486281, 0.6114199351966487, 0.}, 
      RotationMatrix :> {{0.03792106161120104, -0.9992807378741362, 0.}, {
       0.9992807378741362, 0.03792106161120104, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25779341729664584`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32848110824914906`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.282372414935892`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25349247671982983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03792106161120104, -0.9992807378741362, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.911408050797058, 0.38375460538032846`, 0.}, 
      Optica`Optica`RayEnd :> {7.878705842196716, 0.3241365905784629, 0.}, 
      RotationMatrix :> {{-0.4809282423586497, -0.8767599589977975, 0.}, {
       0.8767599589977975, -0.4809282423586497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07552132102494946, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0679981039166221, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.72709809959988, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1568126090387138, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4809282423586497, -0.8767599589977975, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.878705842196716, 0.3241365905784629, 0.}, 
      Optica`Optica`RayEnd :> {7.713475040829654, 0.0453881684976358, 0.}, 
      RotationMatrix :> {{-0.509908708624229, -0.8602285213065018, 0.}, {
       0.8602285213065018, -0.509908708624229, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.075290895035326, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3240399674931356, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.20667725148972, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34123945429526403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.509908708624229, -0.8602285213065018, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3181519197722915`, 0.352797237396545, 0.}, 
      Optica`Optica`RayEnd :> {7.29714803826906, 0.27628610566998607`, 0.}, 
      RotationMatrix :> {{-0.26472665979378435`, -0.9643234911555485, 0.}, {
       0.9643234911555485, -0.26472665979378435`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024168896503610877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07934176905187244, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.427032538493176`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19656857478251194`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.26472665979378435`, -0.9643234911555485, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.29714803826906, 0.27628610566998607`, 0.}, 
      Optica`Optica`RayEnd :> {7.232629346704844, 0.09353097316202831, 0.}, 
      RotationMatrix :> {{-0.33289756534755255`, -0.9429629955547945, 0.}, {
       0.9429629955547945, -0.33289756534755255`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024031922073260648`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19380944254385435`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.71387051345808, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13563319038442664`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.33289756534755255`, -0.9429629955547945, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4981801653118625`, -0.6300356770624768, 0.},
       Optica`Optica`RayEnd :> {7.5252117425817255`, -0.8230631277620202, 0.},
       RotationMatrix :> {{0.1386867621677835, -0.9903362974259884, 0.}, {
       0.9903362974259884, 0.1386867621677835, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19721916761708747`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19491101275520897`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.845063651082604`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.296898156278706, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1386867621677835, -0.9903362974259884, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5252117425817255`, -0.8230631277620201, 0.},
       Optica`Optica`RayEnd :> {7.5681643822077485`, -1.1355830966992775`, 
       0.}, RotationMatrix :> {{0.13615967560637937`, -0.9906869044954438, 
       0.}, {0.9906869044954438, 0.13615967560637937`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1967324479978787, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3154578580973808, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.311941281066726`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1773536303881728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13615967560637937`, -0.9906869044954438, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.079872856413603, 1.1491620785190124`, 0.}, 
      Optica`Optica`RayEnd :> {4.946357056947727, 1.3371832328657298`, 0.}, 
      RotationMatrix :> {{-0.5789818274170899, 0.8153404463908106, 
       0.}, {-0.8153404463908106, -0.5789818274170899, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010155848503700847`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23060447347977475`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.330252557481565`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3780266807750048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5789818274170899, 0.8153404463908106, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.946357056947727, 1.3371832328657298`, 0.}, 
      Optica`Optica`RayEnd :> {4.837885967467196, 1.5380887190130017`, 0.}, 
      RotationMatrix :> {{-0.47508830550282766`, 0.8799381239464801, 
       0.}, {-0.8799381239464801, -0.47508830550282766`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00999760033494628, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22831774266833715`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.668162816630705`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12225015066235223`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.47508830550282766`, 0.8799381239464801, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.884183329433145, 1.1158944386613112`, 0.}, 
      Optica`Optica`RayEnd :> {4.6865304189315635`, 1.0490457747668551`, 0.}, 
      RotationMatrix :> {{-0.9472876166194051, -0.320384411917194, 0.}, {
       0.320384411917194, -0.9472876166194051, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.3139768236935531, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2086514243762072, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.59461128452618, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36921827541586166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9472876166194051, -0.320384411917194, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6865304189315635`, 1.0490457747668551`, 0.},
       Optica`Optica`RayEnd :> {4.349692745732636, 0.9390177742939605, 0.}, 
      RotationMatrix :> {{-0.9505719857162861, -0.3105042672354053, 0.}, {
       0.3105042672354053, -0.9505719857162861, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.31318590669708823`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3543526195389712, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.11905316144386, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20159416771332878`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9505719857162861, -0.3105042672354053, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.859839177235601, 0.9188957354033456, 0.}, 
      Optica`Optica`RayEnd :> {4.8632038120715215`, 0.8222252776510854, 0.}, 
      RotationMatrix :> {{0.034784139860007474`, -0.9993948487030532, 0.}, {
       0.9993948487030532, 0.034784139860007474`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009547589555766872, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09672899342808547, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.738411039899095`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16002530480200122`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.034784139860007474`, -0.9993948487030532, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8632038120715215`, 0.8222252776510854, 0.}, 
      Optica`Optica`RayEnd :> {4.846694276822012, 0.5984956863594586, 0.}, 
      RotationMatrix :> {{-0.07359226871754465, -0.9972884126394951, 0.}, {
       0.9972884126394951, -0.07359226871754465, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00943484333847693, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22433790311419338`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.070431136508102`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08875967490034764, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.07359226871754465, -0.9972884126394951, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8771242751091632`, 1.0203648055844956`, 0.},
       Optica`Optica`RayEnd :> {3.689696749116665, 1.0618743042281937`, 0.}, 
      RotationMatrix :> {{-0.9763424179664082, 0.21623016181723217`, 
       0.}, {-0.21623016181723217`, -0.9763424179664082, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2824554827921963, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19196904952965702`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.202806026711034`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3402096343608371, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9763424179664082, 0.21623016181723217`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.689696749116665, 1.0618743042281937`, 0.}, 
      Optica`Optica`RayEnd :> {3.412383262155191, 1.1080402052512859`, 0.}, 
      RotationMatrix :> {{-0.9864244861439053, 0.16421550820714606`, 
       0.}, {-0.16421550820714606`, -0.9864244861439053, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2813076860894983, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28112997077509405`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.618878383458174`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29408261163931665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9864244861439053, 0.16421550820714606`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.851433958250631, 0.9509216586411364, 0.}, 
      Optica`Optica`RayEnd :> {2.5742653848532453`, 0.9177688138836663, 0.}, 
      RotationMatrix :> {{-0.9929222735714449, -0.11876598269585402`, 0.}, {
       0.11876598269585402`, -0.9929222735714449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.287080137891467, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2791442802470702, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.973446925011626`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28219020577833964`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9929222735714449, -0.11876598269585402`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5742653848532453`, 0.9177688138836663, 0.}, 
      Optica`Optica`RayEnd :> {2.3595970983370855`, 0.9048842717050697, 0.}, 
      RotationMatrix :> {{-0.9982036095551594, -0.059912885684549264`, 0.}, {
       0.059912885684549264`, -0.9982036095551594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2857843220414894, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21505460856009578`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.291727745680568`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26872596041064906`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9982036095551594, -0.059912885684549264`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.773314947406275, -2.362531201942003, 0.}, 
      Optica`Optica`RayEnd :> {6.925505318214823, -2.8200025049527064`, 0.}, 
      RotationMatrix :> {{0.31566756841363075`, -0.9488698468450901, 0.}, {
       0.9488698468450901, 0.31566756841363075`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009010673179643778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4821222895128935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.885317738367334`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39261714754540966`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.31566756841363075`, -0.9488698468450901, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.925505318214823, -2.8200025049527064`, 0.}, 
      Optica`Optica`RayEnd :> {7.028902406669837, -3.1251692495618935`, 0.}, 
      RotationMatrix :> {{0.32090213629222714`, -0.9471123581302717, 0.}, {
       0.9471123581302717, 0.32090213629222714`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00898832765291629, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3222075416813558, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.36218490005574, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12356183492562456`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32090213629222714`, -0.9471123581302717, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.590262861182729, 3.6107477297384736`, 0.}, 
      Optica`Optica`RayEnd :> {6.58082047593546, 3.654169993663881, 0.}, 
      RotationMatrix :> {{-0.2124890085030096, 0.9771634567795744, 
       0.}, {-0.9771634567795744, -0.2124890085030096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08603215893289086, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.044437052597641684`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.79639309444614, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2818006060381996, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2124890085030096, 0.9771634567795744, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.58082047593546, 3.654169993663881, 0.}, 
      Optica`Optica`RayEnd :> {6.576370351743306, 3.840641917987641, 0.}, 
      RotationMatrix :> {{-0.02385805534812324, 0.9997153560864238, 
       0.}, {-0.9997153560864238, -0.02385805534812324, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08144387988438724, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18652501753473108`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.072450120397544`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26177753467596154`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.02385805534812324, 0.9997153560864238, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8485975650478776`, 3.044158711728051, 0.}, 
      Optica`Optica`RayEnd :> {3.7427671292921243`, 3.096120721976002, 0.}, 
      RotationMatrix :> {{-0.8976377897407678, 0.4407339315611046, 
       0.}, {-0.4407339315611046, -0.8976377897407678, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.8436975977941865`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11789881950749474`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.768195285435954`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3426606075450049, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8976377897407678, 0.4407339315611046, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7427671292921243`, 3.096120721976002, 0.}, 
      Optica`Optica`RayEnd :> {3.622847132670974, 3.201489704433622, 0.}, 
      RotationMatrix :> {{-0.751212287394225, 0.6600606784742866, 
       0.}, {-0.6600606784742866, -0.751212287394225, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.5501949375025736`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1596352970172039, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.004455525021417`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17634448375421105`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.751212287394225, 0.6600606784742866, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.622847132670974, 3.201489704433622, 0.}, 
      Optica`Optica`RayEnd :> {3.643384671488563, 3.3597983825061997`, 0.}, 
      RotationMatrix :> {{0.1286528681396562, 0.991689689126311, 
       0.}, {-0.991689689126311, 0.1286528681396562, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2467792650334446, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1596352970172039, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.24071576460688, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28989220179070785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1286528681396562, 0.991689689126311, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.643384671488563, 3.3597983825061997`, 0.}, 
      Optica`Optica`RayEnd :> {3.7862216760573277`, 3.4310796435752473`, 0.}, 
      RotationMatrix :> {{0.8947708134584463, 0.44652568949939386`, 
       0.}, {-0.44652568949939386`, 0.8947708134584463, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.039285385455173426`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15963529701720408`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.47697600419234, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23840578480252717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 101, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8947708134584463, 0.44652568949939386`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.667391997490735, 3.360284447263403, 0.}, 
      Optica`Optica`RayEnd :> {4.649074573465307, 3.427865298501506, 0.}, 
      RotationMatrix :> {{-0.26160543499422373`, 0.9651749045543415, 
       0.}, {-0.9651749045543415, -0.26160543499422373`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4189018213903022, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07001927932358322, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.31956350686489, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11872504343656423`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.26160543499422373`, 0.9651749045543415, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.649074573465307, 3.427865298501506, 0.}, 
      Optica`Optica`RayEnd :> {4.5651883069599, 3.6848540105536114`, 0.}, 
      RotationMatrix :> {{-0.3103067966117484, 0.9506364667824153, 
       0.}, {-0.9506364667824153, -0.3103067966117484, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.4172591163243085, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27033331986718906`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.719656820268327`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19069129466634083`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3103067966117484, 0.9506364667824153, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.277758717143984, 3.366557381576849, 0.}, 
      Optica`Optica`RayEnd :> {5.233858861547429, 3.5865970474625457`, 0.}, 
      RotationMatrix :> {{-0.19565295906544738`, 0.9806731971502706, 
       0.}, {-0.9806731971502706, -0.19565295906544738`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015564483242010537`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2243761392940154, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.64414861075794, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24724148189527462`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.19565295906544738`, 0.9806731971502706, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.233858861547429, 3.5865970474625457`, 0.}, 
      Optica`Optica`RayEnd :> {5.1726285273595956`, 3.9255726373682482`, 0.}, 
      RotationMatrix :> {{-0.17775677486930547`, 0.9840744529699276, 
       0.}, {-0.9840744529699276, -0.17775677486930547`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015523502650433552`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34446132493601184`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.15395137166324, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3836604459901514, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.17775677486930547`, 0.9840744529699276, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.898000674453068, 3.368881404682121, 0.}, 
      Optica`Optica`RayEnd :> {5.899134242939919, 3.3693583566555887`, 0.}, 
      RotationMatrix :> {{0.921734227468036, 0.38782214211401317`, 
       0.}, {-0.38782214211401317`, 0.921734227468036, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2351336208922049, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0012298214095449928`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.852598549022364`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39682561532341465`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.921734227468036, 0.38782214211401317`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.899134242939919, 3.3693583566555887`, 0.}, 
      Optica`Optica`RayEnd :> {6.111585282110616, 3.472367027206931, 0.}, 
      RotationMatrix :> {{0.8998106054272417, 0.43628072884400926`, 
       0.}, {-0.43628072884400926`, 0.8998106054272417, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.234174851383517, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23610639604522374`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.202036015169295`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4295049131756125, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8998106054272417, 0.43628072884400926`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8574455005292645`, 2.816628517706533, 0.}, 
      Optica`Optica`RayEnd :> {5.958198181637355, 2.6281149491080376`, 0.}, 
      RotationMatrix :> {{0.4713606375584698, -0.88194055885897, 0.}, {
       0.88194055885897, 0.4713606375584698, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012105074674283072`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21374861004509083`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.189996349505485`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4189779487234311, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4713606375584698, -0.88194055885897, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.958198181637355, 2.6281149491080376`, 0.}, 
      Optica`Optica`RayEnd :> {6.1176548356263805`, 2.335555256105638, 0.}, 
      RotationMatrix :> {{0.47857139049110675`, -0.8780486456930551, 0.}, {
       0.8780486456930551, 0.47857139049110675`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01207483296882638, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33319303484772006`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.68312204108011, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05131666543930639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.47857139049110675`, -0.8780486456930551, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8427720735431, 2.7228770601336127`, 0.}, 
      Optica`Optica`RayEnd :> {6.047190372337455, 2.7635250484531877`, 0.}, 
      RotationMatrix :> {{0.9807975248163596, 0.19502875509550233`, 
       0.}, {-0.19502875509550233`, 0.9807975248163596, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16306734246434534`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2084204880437782, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.735037506303268`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04691241289294572, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9807975248163596, 0.19502875509550233`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.047190372337455, 2.7635250484531877`, 0.}, 
      Optica`Optica`RayEnd :> {6.374197998047203, 2.8252555391612586`, 0.}, 
      RotationMatrix :> {{0.9826447112364727, 0.18549763200372227`, 
       0.}, {-0.18549763200372227`, 0.9826447112364727, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16265773361049068`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3327831737864548, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.22755660350722, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34735047492610494`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9826447112364727, 0.18549763200372227`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.820946895856471, 1.666690518766145, 0.}, 
      Optica`Optica`RayEnd :> {5.867096760510475, 1.5568645856293863`, 0.}, 
      RotationMatrix :> {{0.3873964023573893, -0.921913242903339, 0.}, {
       0.921913242903339, 0.3873964023573893, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.10096808479410525`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11912827370923622`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.276234384666445`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11227261225243237`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3873964023573893, -0.921913242903339, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.867096760510475, 1.5568645856293863`, 0.}, 
      Optica`Optica`RayEnd :> {5.9726659601126935`, 1.3721407739913314`, 0.}, 
      RotationMatrix :> {{0.4961840624403958, -0.8682173553783318, 0.}, {
       0.8682173553783318, 0.4961840624403958, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09942613898925415, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21276217354300664`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.591122401510095`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36880455438215115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.4961840624403958, -0.8682173553783318, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.092211361633606, 1.8481257845740613`, 0.}, 
      Optica`Optica`RayEnd :> {5.088297965282513, 1.8262510277303763`, 0.}, 
      RotationMatrix :> {{-0.17610417354517233`, -0.9843715355799204, 0.}, {
       0.9843715355799204, -0.17610417354517233`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06235589354395006, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.022222053414819656`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.661619868681708`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22573669467050947`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17610417354517233`, -0.9843715355799204, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.088297965282513, 1.8262510277303763`, 0.}, 
      Optica`Optica`RayEnd :> {5.095108047103927, 1.6972718055676446`, 0.}, 
      RotationMatrix :> {{0.052726391575694254`, -0.9986089963701535, 0.}, {
       0.9986089963701535, 0.052726391575694254`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05621955499857236, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12915888263730704`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.85277501498492, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27146306987165825`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.052726391575694254`, -0.9986089963701535, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.387311192534063, 2.0334509906640714`, 0.}, 
      Optica`Optica`RayEnd :> {4.277659440999164, 1.9169985646153616`, 0.}, 
      RotationMatrix :> {{-0.6855286792117156, -0.7280456235554472, 0.}, {
       0.7280456235554472, -0.6855286792117156, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035218362921186554`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15995209954014775`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.22625271535981, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2714703170168967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6855286792117156, -0.7280456235554472, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.277659440999164, 1.9169985646153616`, 0.}, 
      Optica`Optica`RayEnd :> {4.122848840957539, 1.7180552732101344`, 0.}, 
      RotationMatrix :> {{-0.6141307436348971, -0.789204301637065, 0.}, {
       0.789204301637065, -0.6141307436348971, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034906898048323344`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25208085028496974`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.599332373781564`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09830151008711174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6141307436348971, -0.789204301637065, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8238202808915664`, 2.9838764681221184`, 0.},
       Optica`Optica`RayEnd :> {3.648140038558968, 3.098566661548034, 0.}, 
      RotationMatrix :> {{-0.837357255695888, 0.5466560402423538, 
       0.}, {-0.5466560402423538, -0.837357255695888, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02440197809350946, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20980321259245377`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.12237809176946, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2621270636500597, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.837357255695888, 0.5466560402423538, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.648140038558968, 3.098566661548034, 0.}, 
      Optica`Optica`RayEnd :> {3.4661872280868278`, 3.180921472328808, 0.}, 
      RotationMatrix :> {{-0.911027383384556, 0.41234585813790825`, 
       0.}, {-0.41234585813790825`, -0.911027383384556, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023717147410956534`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19972265794708385`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.417967625531144`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3404465869310849, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.911027383384556, 0.41234585813790825`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.641487887169879, 3.3291496725314924`, 0.}, 
      Optica`Optica`RayEnd :> {4.624830179117953, 3.40901924966295, 0.}, 
      RotationMatrix :> {{-0.20416819217873344`, 0.9789358249152323, 
       0.}, {-0.9789358249152323, -0.20416819217873344`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014959716100042153`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0815881645136172, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.5444635573738, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.017295826952048152`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20416819217873344`, 0.9789358249152323, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.624830179117953, 3.40901924966295, 0.}, 
      Optica`Optica`RayEnd :> {4.557058154927904, 3.6857111952687807`, 0.}, 
      RotationMatrix :> {{-0.2379042687822157, 0.9712886074155291, 
       0.}, {-0.9712886074155291, -0.2379042687822157, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014913376547723609`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2848709883894051, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.96607262019012, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2155974218977402, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2379042687822157, 0.9712886074155291, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3805055831974253`, 0.37158406636224844`, 
       0.}, Optica`Optica`RayEnd :> {3.3641239810316463`, 0.3671921510397863, 
       0.}, RotationMatrix :> {{-0.9658892861064563, -0.25895537643532174`, 
       0.}, {0.25895537643532174`, -0.9658892861064563, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08212610034430937, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01696012410678428, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.235403488282138`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17920193491565167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9658892861064563, -0.25895537643532174`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3641239810316463`, 0.3671921510397863, 0.}, 
      Optica`Optica`RayEnd :> {3.072694552474338, 0.27587203506025676`, 0.}, 
      RotationMatrix :> {{-0.9542481123344863, -0.29901595292905137`, 0.}, {
       0.29901595292905137`, -0.9542481123344863, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08184612156414703, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3054021535807402, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.687398675581633`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.036625872626962694`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9542481123344863, -0.29901595292905137`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.573649858233891, 1.7627108399105784`, 0.}, 
      Optica`Optica`RayEnd :> {4.47360863487234, 1.8249231390726355`, 0.}, 
      RotationMatrix :> {{-0.8491920224549151, 0.5280841874161071, 
       0.}, {-0.5280841874161071, -0.8491920224549151, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037301211389323546`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11780754024554142`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.317684629453492`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4003589092353319, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 98, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8491920224549151, 0.5280841874161071, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.098053619989534, 1.2406365255603116`, 0.}, 
      Optica`Optica`RayEnd :> {3.9358161488169614`, 1.2372535926012982`, 0.}, 
      RotationMatrix :> {{-0.9997826734144489, -0.02084720461493538, 0.}, {
       0.02084720461493538, -0.9997826734144489, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09042807278543785, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.162272737352509, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.832453868614383`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.309806455163185, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9997826734144489, -0.02084720461493538, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9358161488169614`, 1.2372535926012982`, 0.},
       Optica`Optica`RayEnd :> {3.667818548636428, 1.2196932435683943`, 0.}, 
      RotationMatrix :> {{-0.9978601724923594, -0.06538406651102652, 0.}, {
       0.06538406651102652, -0.9978601724923594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09010655765813673, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26857229857281006`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.192340748701948`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2440055322926938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9978601724923594, -0.06538406651102652, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.875021438164752, 0.5253603907749506, 0.}, 
      Optica`Optica`RayEnd :> {4.73748714802897, 0.40950604122527534`, 0.}, 
      RotationMatrix :> {{-0.7648125533709097, -0.6442528682173398, 0.}, {
       0.6442528682173398, -0.7648125533709097, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021330946697367084`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17982744860763508`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.185069875008235`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22992858044152598`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7648125533709097, -0.6442528682173398, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.73748714802897, 0.40950604122527534`, 0.}, 
      Optica`Optica`RayEnd :> {4.605132568154086, 0.3230387054496063, 0.}, 
      RotationMatrix :> {{-0.8371787205440416, -0.5469294194576125, 0.}, {
       0.5469294194576125, -0.8371787205440416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021005434590515924`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15809596759563296`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.396918471586382`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17971069776688858`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8371787205440416, -0.5469294194576125, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.070713347817326, -1.596189391324968, 0.}, 
      Optica`Optica`RayEnd :> {6.065334003334559, -1.8492591456462795`, 0.}, 
      RotationMatrix :> {{-0.021251570047966267`, -0.9997741598833687, 0.}, {
       0.9997741598833687, -0.021251570047966267`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008231160805651819, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25312692053456737`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.37308931265822, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14188855322169655`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.021251570047966267`, -0.9997741598833687, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.065334003334559, -1.8492591456462795`, 0.}, 
      Optica`Optica`RayEnd :> {6.055440525207455, -2.0856520759379458`, 0.}, 
      RotationMatrix :> {{-0.04181523064408571, -0.9991253607461784, 0.}, {
       0.9991253607461784, -0.04181523064408571, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008209098769605051, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23659986982526449`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.723257119999612`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18145351327879142`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.04181523064408571, -0.9991253607461784, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2065309528116637`, 1.3940584934118068`, 0.},
       Optica`Optica`RayEnd :> {3.1330446222023243`, 1.4117656203703455`, 0.},
       RotationMatrix :> {{-0.972175531095755, 0.23425357358786675`, 
       0.}, {-0.23425357358786675`, -0.972175531095755, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15086817163443453`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07558957025642454, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.317155922328737`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23037308019209482`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.972175531095755, 0.23425357358786675`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1330446222023243`, 1.4117656203703455`, 0.},
       Optica`Optica`RayEnd :> {2.8155000203866543`, 1.49926532461838, 0.}, 
      RotationMatrix :> {{-0.9640694783622232, 0.2656502228314335, 
       0.}, {-0.2656502228314335, -0.9640694783622232, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1504130030912096, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3293793745603479, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.804637396678054`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01530020613625066, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9640694783622232, 0.2656502228314335, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.843136121561057, -1.0614196196331982`, 0.}, 
      Optica`Optica`RayEnd :> {2.374937088589322, -0.6456031838817202, 0.}, 
      RotationMatrix :> {{-0.7476951024239715, 0.664042192794408, 
       0.}, {-0.664042192794408, -0.7476951024239715, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008747646263565279, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.6261897817089727, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.3558747456299, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32642827625792276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7476951024239715, 0.664042192794408, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.374937088589322, -0.6456031838817202, 0.}, 
      Optica`Optica`RayEnd :> {2.205090409605016, -0.5352505042925035, 0.}, 
      RotationMatrix :> {{-0.8385511235229239, 0.5448229191567119, 
       0.}, {-0.5448229191567119, -0.8385511235229239, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008516627514714629, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20254779251949004`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.655645478558746`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2848707001583598, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8385511235229239, 0.5448229191567119, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.910787109517695, -2.0825841162416596`, 0.}, 
      Optica`Optica`RayEnd :> {2.8685673441515807`, -2.1857190069215964`, 0.},
       RotationMatrix :> {{-0.37884975176662417`, -0.9254581922412088, 0.}, {
       0.9254581922412088, -0.37884975176662417`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16557074836494867`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11144197711424661`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.030148069795985`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3836205989284074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.37884975176662417`, -0.9254581922412088, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8685673441515807`, -2.1857190069215964`, 
       0.}, Optica`Optica`RayEnd :> {
       2.7646409666322525`, -2.3652591978116506`, 0.}, 
      RotationMatrix :> {{-0.5009714870291998, -0.8654637884878554, 0.}, {
       0.8654637884878554, -0.5009714870291998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16220192185862228`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2074496856809549, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.337173604603798`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08701138785721907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5009714870291998, -0.8654637884878554, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.836149343049395, -2.845038464983356, 0.}, 
      Optica`Optica`RayEnd :> {3.9074945903586378`, -3.192587711922769, 0.}, 
      RotationMatrix :> {{0.20108774561412218`, -0.979573232874311, 0.}, {
       0.979573232874311, 0.20108774561412218`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008828564696933742, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3547965943491708, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.320103980283125`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18328817275211315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.20108774561412218`, -0.979573232874311, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9074945903586378`, -3.192587711922769, 0.}, 
      Optica`Optica`RayEnd :> {3.9147952493490976`, -3.3708372984770985`, 0.},
       RotationMatrix :> {{0.04092319838287775, -0.9991622950422592, 0.}, {
       0.9991622950422592, 0.04092319838287775, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00854113758069572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17839903230815005`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.584134548099186`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22071682084557165`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.04092319838287775, -0.9991622950422592, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3278659338480487`, 2.5662557517157665`, 0.},
       Optica`Optica`RayEnd :> {3.311936366792392, 2.6064483382348436`, 0.}, 
      RotationMatrix :> {{-0.368448381763378, 0.9296482076441324, 
       0.}, {-0.9296482076441324, -0.368448381763378, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042095286440483146`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.043234189221889714`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.237461535665776`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20330118199658279`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.368448381763378, 0.9296482076441324, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.311936366792392, 2.6064483382348436`, 0.}, 
      Optica`Optica`RayEnd :> {3.2063272730200887`, 2.8948686695957933`, 0.}, 
      RotationMatrix :> {{-0.34383839732409816`, 0.9390288368977788, 
       0.}, {-0.9390288368977788, -0.34383839732409816`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0419764609277312, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30714746984106395`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.692039791030552`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4134746198441448, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.34383839732409816`, 0.9390288368977788, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.199617787190727, 2.409714096482288, 0.}, 
      Optica`Optica`RayEnd :> {4.180860665318691, 2.4485790599121247`, 0.}, 
      RotationMatrix :> {{-0.43464994515023925`, 0.9005994810019007, 
       0.}, {-0.9005994810019007, -0.43464994515023925`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04882884288328304, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0431545478869255, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.352343940557422`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3116224633321494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.43464994515023925`, 0.9005994810019007, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.180860665318691, 2.4485790599121247`, 0.}, 
      Optica`Optica`RayEnd :> {4.044827874469686, 2.678623059659469, 0.}, 
      RotationMatrix :> {{-0.5090002446473454, 0.8607663741974017, 
       0.}, {-0.8607663741974017, -0.5090002446473454, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04847285641668143, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26725486339059423`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      15.7478811383755, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19247820006633098`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5090002446473454, 0.8607663741974017, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3170462945642005`, 0.5115606526621097, 0.}, 
      Optica`Optica`RayEnd :> {3.1737449217559712`, 0.4809086478989754, 0.}, 
      RotationMatrix :> {{-0.977879845679431, -0.20916741479965506`, 0.}, {
       0.20916741479965506`, -0.977879845679431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01261996716451644, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1465429249220937, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.851828648513637`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30407453621626784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.977879845679431, -0.20916741479965506`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1737449217559712`, 0.4809086478989754, 0.}, 
      Optica`Optica`RayEnd :> {2.918979408019427, 0.4432405576931465, 0.}, 
      RotationMatrix :> {{-0.9892456100535173, -0.14626388135778154`, 0.}, {
       0.14626388135778154`, -0.9892456100535173, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01255782721996194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2575351471337448, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.23298066627158, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3171302613678137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9892456100535173, -0.14626388135778154`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.886521337520707, 3.1181709029604834`, 0.}, 
      Optica`Optica`RayEnd :> {4.885546272031111, 3.1188602060507615`, 0.}, 
      RotationMatrix :> {{-0.8165646067797965, 0.5772540540823904, 
       0.}, {-0.5772540540823904, -0.8165646067797965, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18526359813962467`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0011941069714507821`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.83085122064677, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09636773684976796, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8165646067797965, 0.5772540540823904, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.885546272031111, 3.1188602060507615`, 0.}, 
      Optica`Optica`RayEnd :> {4.630191771136144, 3.308284194420784, 0.}, 
      RotationMatrix :> {{-0.8031470556818607, 0.5957808380181062, 
       0.}, {-0.5957808380181062, -0.8031470556818607, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18475735323859188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31794239808072816`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.301405969806247`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20535225858617845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8031470556818607, 0.5957808380181062, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.352014452126943, 1.193465846067691, 0.}, 
      Optica`Optica`RayEnd :> {7.38442038266304, 1.146214917856264, 0.}, 
      RotationMatrix :> {{0.5655912014693352, -0.8246857539817652, 0.}, {
       0.8246857539817652, 0.5655912014693352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03233327772179539, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.057295676545022205`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.73536500946755, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.300836793500639, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5655912014693352, -0.8246857539817652, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.38442038266304, 1.146214917856264, 0.}, 
      Optica`Optica`RayEnd :> {7.583154901338565, 0.8752202076403494, 0.}, 
      RotationMatrix :> {{0.5913734637399662, -0.8063978090150007, 0.}, {
       0.8063978090150007, 0.5913734637399662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03223665902254091, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33605586124660886`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.232727684112533`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09112701384723391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5913734637399662, -0.8063978090150007, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.869205868538643, 1.1908184192383027`, 0.}, 
      Optica`Optica`RayEnd :> {6.876421105352835, 1.0656697795973613`, 0.}, 
      RotationMatrix :> {{0.057557758970160716`, -0.9983421780042813, 0.}, {
       0.9983421780042813, 0.057557758970160716`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01325121479914858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12535645833487424`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.06722986006032, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23276110059866295`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.057557758970160716`, -0.9983421780042813, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.876421105352835, 1.0656697795973613`, 0.}, 
      Optica`Optica`RayEnd :> {6.915310280175682, 0.8725376930146247, 0.}, 
      RotationMatrix :> {{0.19739840638543144`, -0.980323349286597, 0.}, {
       0.980323349286597, 0.19739840638543144`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012955010863459836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19700855510917198`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.358802521621893`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3858886335455032, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19739840638543144`, -0.980323349286597, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.882439085046726, 2.4952029161458746`, 0.}, 
      Optica`Optica`RayEnd :> {5.665748465648419, 2.431360896350264, 0.}, 
      RotationMatrix :> {{-0.9592341998806472, -0.2826123666426035, 0.}, {
       0.2826123666426035, -0.9592341998806472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019002682548268236`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22589959722585803`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.966225049310772`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2706666722619532, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9592341998806472, -0.2826123666426035, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.665748465648419, 2.431360896350264, 0.}, 
      Optica`Optica`RayEnd :> {5.405927012198225, 2.3787519570622178`, 0.}, 
      RotationMatrix :> {{-0.980110239282221, -0.19845382045742072`, 0.}, {
       0.19845382045742072`, -0.980110239282221, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018857482624384282`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26509411190364995`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.358564334928175`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3836870245590635, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.980110239282221, -0.19845382045742072`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.36873589652042, 3.1892380843199777`, 0.}, 
      Optica`Optica`RayEnd :> {7.586433657280547, 3.2098175772256794`, 0.}, 
      RotationMatrix :> {{0.9955615379628855, 0.09411282659113651, 
       0.}, {-0.09411282659113651, 0.9955615379628855, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07782823637156928, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21866831176059676`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.51287559754203, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16070743195131865`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9955615379628855, 0.09411282659113651, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.586433657280547, 3.2098175772256794`, 0.}, 
      Optica`Optica`RayEnd :> {7.8855943003165185`, 3.2448708046005024`, 0.}, 
      RotationMatrix :> {{0.9932052560071191, 0.11637576826742119`, 
       0.}, {-0.11637576826742119`, 0.9932052560071191, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07761646722590164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30120726931979425`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.958662356135328`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4076521210722545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9932052560071191, 0.11637576826742119`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.887209292294565, 3.364039245201363, 0.}, 
      Optica`Optica`RayEnd :> {6.878341464867088, 3.355366615909915, 0.}, 
      RotationMatrix :> {{-0.7149315172114481, -0.6991944834577399, 0.}, {
       0.6991944834577399, -0.7149315172114481, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01095839230399624, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.012403743874749882`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.754965529714495`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27158284886806755`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7149315172114481, -0.6991944834577399, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.878341464867088, 3.355366615909915, 0.}, 
      Optica`Optica`RayEnd :> {6.686899135231831, 3.1787974319452377`, 0.}, 
      RotationMatrix :> {{-0.7350843405284594, -0.6779756723584106, 0.}, {
       0.6779756723584106, -0.7350843405284594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010926500070207843`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2604358698453927, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.140410617085674`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4252712154423237, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7350843405284594, -0.6779756723584106, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.0291737225527635`, 3.3731969004548623`, 0.},
       Optica`Optica`RayEnd :> {7.05028264096431, 3.3076631218756067`, 0.}, 
      RotationMatrix :> {{0.3065947980470925, -0.9518401282833485, 0.}, {
       0.9518401282833485, 0.3065947980470925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01089429829311552, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06884956478715216, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.60040305460569, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14598671499747515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3065947980470925, -0.9518401282833485, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.05028264096431, 3.3076631218756067`, 0.}, 
      Optica`Optica`RayEnd :> {7.146594245946951, 3.101302362746748, 0.}, 
      RotationMatrix :> {{0.42292122604456045`, -0.9061664508030325, 0.}, {
       0.9061664508030325, 0.42292122604456045`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010715530046262984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2277294187463948, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.937442594350355`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39924186119446836`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.42292122604456045`, -0.9061664508030325, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.3305081301654775`, 3.5734870220448216`, 0.},
       Optica`Optica`RayEnd :> {6.316650533579623, 3.5785436319596386`, 0.}, 
      RotationMatrix :> {{-0.939412179557728, 0.34278966859956184`, 
       0.}, {-0.34278966859956184`, -0.939412179557728, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07495742786805175, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01475134864908688, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.601389859020443`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.028896209853356947`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.939412179557728, 0.34278966859956184`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.316650533579623, 3.5785436319596386`, 0.}, 
      Optica`Optica`RayEnd :> {6.083933215616448, 3.682061863205232, 0.}, 
      RotationMatrix :> {{-0.9136828206976415, 0.40642798028925126`, 
       0.}, {-0.40642798028925126`, -0.9136828206976415, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07455453200892936, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2547025211500459, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.978349590322512`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07585129267114783, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9136828206976415, 0.40642798028925126`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.258892531326898, 2.1212958894635108`, 0.}, 
      Optica`Optica`RayEnd :> {7.319072018686604, 2.0270369739297505`, 0.}, 
      RotationMatrix :> {{0.5381258095419099, -0.8428645283228279, 0.}, {
       0.8428645283228279, 0.5381258095419099, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019117156574398258`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11183163173484231`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.573661314260093`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04120271220745798, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5381258095419099, -0.8428645283228279, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.319072018686604, 2.0270369739297505`, 0.}, 
      Optica`Optica`RayEnd :> {7.341081509098933, 1.9555372819863597`, 0.}, 
      RotationMatrix :> {{0.2942028916843109, -0.9557429876931289, 0.}, {
       0.9557429876931289, 0.2942028916843109, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015863803786497575`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07481058492092023, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.673907498054128`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24615593580903725`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2942028916843109, -0.9557429876931289, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.195563023826857, 2.0683216790920302`, 0.}, 
      Optica`Optica`RayEnd :> {5.114170409498007, 2.067477533124626, 0.}, 
      RotationMatrix :> {{-0.9999462225662196, -0.010370726857229312`, 0.}, {
       0.010370726857229312`, -0.9999462225662196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011194206058731483`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08139699165017854, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.87083435622332, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06549368070971351, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9999462225662196, -0.010370726857229312`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.114170409498007, 2.067477533124626, 0.}, 
      Optica`Optica`RayEnd :> {4.933471172038791, 2.0451250526433418`, 0.}, 
      RotationMatrix :> {{-0.9924358634829188, -0.12276423287306484`, 0.}, {
       0.12276423287306484`, -0.9924358634829188, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011050292583148413`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18207648887763667`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.14030755976222, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3103688516414922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9924358634829188, -0.12276423287306484`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.631857465184819, 2.876601243636376, 0.}, 
      Optica`Optica`RayEnd :> {4.630982662709606, 2.876838106199413, 0.}, 
      RotationMatrix :> {{-0.9652439395626448, 0.2613506019460916, 
       0.}, {-0.2613506019460916, -0.9652439395626448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032426384914735054`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0009063019609420408, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.803303708634452`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0954766397679761, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9652439395626448, 0.2613506019460916, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.630982662709606, 2.876838106199413, 0.}, 
      Optica`Optica`RayEnd :> {4.372429286979578, 2.9644152224685603`, 0.}, 
      RotationMatrix :> {{-0.9471416974195437, 0.3208155311222085, 
       0.}, {-0.3208155311222085, -0.9471416974195437, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03227175994160671, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27298278223252975`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.207318226338597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.100257483009242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9471416974195437, 0.3208155311222085, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.428739814516301, -0.06855911911277818, 0.}, 
      Optica`Optica`RayEnd :> {4.382351075793916, -0.10517391641614338`, 0.}, 
      RotationMatrix :> {{-0.7849477018298978, -0.6195620270739327, 0.}, {
       0.6195620270739327, -0.7849477018298978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012459219588637941`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05909787188909807, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.641073365184962`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09509362523411857, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7849477018298978, -0.6195620270739327, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.382351075793916, -0.10517391641614338`, 0.},
       Optica`Optica`RayEnd :> {4.110370663361457, -0.32787980772381814`, 0.},
       RotationMatrix :> {{-0.7737112161334537, -0.633538439267335, 0.}, {
       0.633538439267335, -0.7737112161334537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012426480776489567`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.351527038462301, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.161333382109166`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2468726410049547, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7737112161334537, -0.633538439267335, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8263520093400993`, 1.444130763380094, 0.}, 
      Optica`Optica`RayEnd :> {2.6487928585431653`, 1.524816379995089, 0.}, 
      RotationMatrix :> {{-0.9104110681980194, 0.4137048306492681, 
       0.}, {-0.4137048306492681, -0.9104110681980194, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08181329329720088, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19503184550290845`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.634736664996005`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3670079867315677, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9104110681980194, 0.4137048306492681, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6487928585431653`, 1.524816379995089, 0.}, 
      Optica`Optica`RayEnd :> {2.379458000813778, 1.6251160758509406`, 0.}, 
      RotationMatrix :> {{-0.9371284812077398, 0.34898454078837515`, 
       0.}, {-0.34898454078837515`, -0.9371284812077398, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08136198035884218, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28740440945971174`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.06009519099638, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40258306743213845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9371284812077398, 0.34898454078837515`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.425356686909021, 3.1169129380419007`, 0.}, 
      Optica`Optica`RayEnd :> {4.516830552912185, 3.3890059587277985`, 0.}, 
      RotationMatrix :> {{0.31866028991525525`, 0.9478689886430117, 
       0.}, {-0.9478689886430117, 0.31866028991525525`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008459788598646096, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28705762499460163`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.49215044423596, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32793527010988066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.31866028991525525`, 0.9478689886430117, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.516830552912185, 3.3890059587277985`, 0.}, 
      Optica`Optica`RayEnd :> {4.608146945359943, 3.6724081726290074`, 0.}, 
      RotationMatrix :> {{0.3066873819293489, 0.9518103013549087, 
       0.}, {-0.9518103013549087, 0.3066873819293489, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008438262258830306, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29775073194499335`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.93282152751455, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04589221665190732, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3066873819293489, 0.9518103013549087, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6155601683525647`, 3.140748752813215, 0.}, 
      Optica`Optica`RayEnd :> {3.488082437448585, 3.3130000643458306`, 0.}, 
      RotationMatrix :> {{-0.5948784662564055, 0.8038156569664632, 
       0.}, {-0.8038156569664632, -0.5948784662564055, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008900374482621383, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21429205818493033`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.667675632078666`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3237231819402243, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5948784662564055, 0.8038156569664632, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.488082437448585, 3.3130000643458306`, 0.}, 
      Optica`Optica`RayEnd :> {3.360907336975386, 3.524693212670782, 0.}, 
      RotationMatrix :> {{-0.5149697168951541, 0.8572083706316248, 
       0.}, {-0.8572083706316248, -0.5149697168951541, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008818277576626286, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24695646423630666`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.0331711991484, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15168223980370824`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5149697168951541, 0.8572083706316248, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.868843846892141, 2.60011284487213, 0.}, 
      Optica`Optica`RayEnd :> {2.8116934041868635`, 2.6194695648763573`, 0.}, 
      RotationMatrix :> {{-0.9471480401673776, 0.3207968048579909, 
       0.}, {-0.3207968048579909, -0.9471480401673776, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22045000510342017`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0603395037328882, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.675895592192795`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.017850736627147843`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9471480401673776, 0.3207968048579909, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8116934041868635`, 2.6194695648763573`, 0.},
       Optica`Optica`RayEnd :> {2.577113124496869, 2.7190939695865692`, 0.}, 
      RotationMatrix :> {{-0.9204328871097435, 0.39090062717629737`, 
       0.}, {-0.39090062717629737`, -0.9204328871097435, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21911161364479734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2548586463773603, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.05308638883129, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1033831840835808, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9204328871097435, 0.39090062717629737`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.26131283152225, 1.5996640494127237`, 0.}, 
      Optica`Optica`RayEnd :> {3.0638595987935724`, 1.1604254624250783`, 0.}, 
      RotationMatrix :> {{-0.4100121481991377, -0.9120800613592691, 0.}, {
       0.9120800613592691, -0.4100121481991377, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012720769241564482`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4815789814909997, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.267649974012745`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14051012253734957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4100121481991377, -0.9120800613592691, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0638595987935724`, 1.1604254624250783`, 0.},
       Optica`Optica`RayEnd :> {2.9275913020691573`, 0.8424886120484518, 0.}, 
      RotationMatrix :> {{-0.3939428586564471, -0.9191349324846632, 0.}, {
       0.9191349324846632, -0.3939428586564471, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01268743223333858, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.345908787861168, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.779594980047275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42065530243978333`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3939428586564471, -0.9191349324846632, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.191782608675725, 1.1704668874483517`, 0.}, 
      Optica`Optica`RayEnd :> {3.153448928015458, 1.10655298156924, 0.}, 
      RotationMatrix :> {{-0.514351084551279, -0.8575797116425522, 0.}, {
       0.8575797116425522, -0.514351084551279, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00815119386830329, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07452823919620839, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.771986907163583`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1574962628352757, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.514351084551279, -0.8575797116425522, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.153448928015458, 1.10655298156924, 0.}, 
      Optica`Optica`RayEnd :> {2.9713169457996758`, 0.8222603747779084, 0.}, 
      RotationMatrix :> {{-0.5394417555634347, -0.8420229167633382, 0.}, {
       0.8420229167633382, -0.5394417555634347, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008127404314064142, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3376304862154197, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.271680026762404`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3652654934623542, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5394417555634347, -0.8420229167633382, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.69371070634779, -3.4233066182279197`, 0.}, 
      Optica`Optica`RayEnd :> {2.670413320797123, -3.4341668154465013`, 0.}, 
      RotationMatrix :> {{-0.9063607097504638, -0.4225047500568897, 0.}, {
       0.4225047500568897, -0.9063607097504638, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011976862565665873`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02570431981443799, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.436407679126358`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2821041017325495, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.9063607097504638, -0.4225047500568897, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.670413320797123, -3.4341668154465013`, 0.}, 
      Optica`Optica`RayEnd :> {2.3865127223489795`, -3.5668852488817966`, 0.},
       RotationMatrix :> {{-0.9058998759128252, -0.4234919300543133, 0.}, {
       0.4234919300543133, -0.9058998759128252, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011947336524091232`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3133907024350482, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.90022591873023, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20701157903933753`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.9058998759128252, -0.4234919300543133, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.65303976200892, 2.961530386470526, 0.}, 
      Optica`Optica`RayEnd :> {6.899423196141074, 2.98718877936853, 0.}, 
      RotationMatrix :> {{0.9946211325466305, 0.10357993382725013`, 
       0.}, {-0.10357993382725013`, 0.9946211325466305, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011595124378120948`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24771586493574024`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.334715293814096`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0709269569708325, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9946211325466305, 0.10357993382725013`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.899423196141074, 2.98718877936853, 0.}, 
      Optica`Optica`RayEnd :> {7.166293012942752, 3.0086036193514536`, 0.}, 
      RotationMatrix :> {{0.9967958743024367, 0.0799874050938041, 
       0.}, {-0.0799874050938041, 0.9967958743024367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011563207725312523`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26772764984449327`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.730952215583947`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33888211362475074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 99, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9967958743024367, 0.0799874050938041, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.854366695460026, -3.7783913530293813`, 0.}, 
      Optica`Optica`RayEnd :> {4.903634815891672, -3.9230067389810745`, 0.}, 
      RotationMatrix :> {{0.3224828772478805, -0.946575297523619, 0.}, {
       0.946575297523619, 0.3224828772478805, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023085277278882387`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15277747721710913`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.804716051932417`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30838748363961277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3224828772478805, -0.946575297523619, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.903634815891672, -3.9230067389810745`, 0.}, 
      Optica`Optica`RayEnd :> {5.000414990405947, -4.159206389957394, 0.}, 
      RotationMatrix :> {{0.37914639967101615`, -0.9253366995945344, 0.}, {
       0.9253366995945344, 0.37914639967101615`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022978405695244324`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2552580602064282, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.18249798103793, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30339220644372855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.37914639967101615`, -0.9253366995945344, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.921928558588366, -1.7290781022400192`, 0.}, 
      Optica`Optica`RayEnd :> {6.121394253571286, -1.7102266949563503`, 0.}, 
      RotationMatrix :> {{0.9955636723237634, 0.09409024577087062, 
       0.}, {-0.09409024577087062, 0.9955636723237634, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008280620533886911, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20035453334425504`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.480493206148182`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35249856099240445`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9955636723237634, 0.09409024577087062, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.121394253571286, -1.7102266949563503`, 0.}, 
      Optica`Optica`RayEnd :> {6.294542797162495, -1.712435348389325, 0.}, 
      RotationMatrix :> {{0.9999186543238591, -0.012754792635057716`, 0.}, {
       0.012754792635057716`, 0.9999186543238591, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00818566325929982, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17316262962239773`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.73677389798933, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14311444845473817`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9999186543238591, -0.012754792635057716`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.933775921915895, 3.33685800507418, 0.}, 
      Optica`Optica`RayEnd :> {3.9501014524724933`, 3.4038499652223475`, 0.}, 
      RotationMatrix :> {{0.23676492187781567`, 0.971566967207198, 
       0.}, {-0.971566967207198, 0.23676492187781567`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008470841716264398, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06895248851526758, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.375212185915792`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37003895023805444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.23676492187781567`, 0.971566967207198, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9501014524724933`, 3.4038499652223475`, 0.},
       Optica`Optica`RayEnd :> {4.021738605429321, 3.6895005923389186`, 0.}, 
      RotationMatrix :> {{0.24325302242326757`, 0.9699628689191901, 
       0.}, {-0.9699628689191901, 0.24325302242326757`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008449774780802957, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29449645576110106`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.81106694044222, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16756809171022174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.24325302242326757`, 0.9699628689191901, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.319455317078221, 3.0548251894317278`, 0.}, 
      Optica`Optica`RayEnd :> {2.2762663904675184`, 3.0759686155040873`, 0.}, 
      RotationMatrix :> {{-0.898147583512537, 0.4396941189401907, 
       0.}, {-0.4396941189401907, -0.898147583512537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.37281863325722814`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048086670168166035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.688878518189618`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22882342123301577`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.898147583512537, 0.4396941189401907, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2762663904675184`, 3.0759686155040873`, 0.},
       Optica`Optica`RayEnd :> {2.11741073100309, 3.1862318942371473`, 0.}, 
      RotationMatrix :> {{-0.8214987206026011, 0.570210357717474, 
       0.}, {-0.570210357717474, -0.8214987206026011, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3627022135869865, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19337298461999008`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.975070535427204`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15206287442552502`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8214987206026011, 0.570210357717474, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.11741073100309, 3.1862318942371473`, 0.}, 
      Optica`Optica`RayEnd :> {2.1829895557969965`, 3.368145414678848, 0.}, 
      RotationMatrix :> {{0.3391312644978799, 0.9407390634177307, 
       0.}, {-0.9407390634177307, 0.3391312644978799, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009841911000837502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19337298461999014`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.26126255266479, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4210073586716423, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3391312644978799, 0.9407390634177307, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.558434112117004, 3.121394561388964, 0.}, 
      Optica`Optica`RayEnd :> {6.726026292771315, 3.1624269201018165`, 0.}, 
      RotationMatrix :> {{0.9713115362892392, 0.23781063784330134`, 
       0.}, {-0.23781063784330134`, 0.9713115362892392, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008972308485813917, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17254214985912128`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.088028551106447`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34530780742901773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9713115362892392, 0.23781063784330134`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.726026292771315, 3.1624269201018165`, 0.}, 
      Optica`Optica`RayEnd :> {6.874329786784559, 3.224916746452884, 0.}, 
      RotationMatrix :> {{0.9215325589344704, 0.38830109814895775`, 
       0.}, {-0.38830109814895775`, 0.9215325589344704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00869483209502335, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16093136653220447`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.32620697357411, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24527334216673008`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9215325589344704, 0.38830109814895775`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7207957282082207`, -0.8988499529645195, 0.},
       Optica`Optica`RayEnd :> {2.580453695055914, -0.8788474812033391, 0.}, 
      RotationMatrix :> {{-0.9899952557837117, 0.14110065033777655`, 
       0.}, {-0.14110065033777655`, -0.9899952557837117, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02091647197415751, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1417603087816897, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.44697495048515, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009866272778698172, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9899952557837117, 0.14110065033777655`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.580453695055914, -0.8788474812033391, 0.}, 
      Optica`Optica`RayEnd :> {2.38258625282617, -0.8872404335930295, 0.}, 
      RotationMatrix :> {{-0.9991016092171261, -0.04237893887002406, 0.}, {
       0.04237893887002406, -0.9991016092171261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019911736844423877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19804536435967537`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.74008208973747, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4045680491657107, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9991016092171261, -0.04237893887002406, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.073286747564538, 1.2026505553483355`, 0.}, 
      Optica`Optica`RayEnd :> {8.201736972220186, 1.6119815177360024`, 0.}, 
      RotationMatrix :> {{0.2994093973193583, 0.9541247364977273, 
       0.}, {-0.9541247364977273, 0.2994093973193583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01834513825149751, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4290120009781779, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.625992673755455`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34206221326027547`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2994093973193583, 0.9541247364977273, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.201736972220186, 1.6119815177360024`, 0.}, 
      Optica`Optica`RayEnd :> {8.28456357642351, 1.882574819793523, 0.}, 
      RotationMatrix :> {{0.2926881654351931, 0.9562079469520111, 
       0.}, {-0.9562079469520111, 0.2926881654351931, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018299469443057163`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2829858326528849, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.044811706081724`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07932774358284016, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.2926881654351931, 0.9562079469520111, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.499397579882815, 0.6579562769550734, 0.}, 
      Optica`Optica`RayEnd :> {6.417094863371823, 0.7900791931475404, 0.}, 
      RotationMatrix :> {{-0.5287320678865597, 0.8487887843205767, 
       0.}, {-0.8487887843205767, -0.5287320678865597, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0130640615784921, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15566053490943138`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.294250571369183`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2745042776888274, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 103, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.5287320678865597, 0.8487887843205767, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.135532990828835, -1.892394399522408, 0.}, 
      Optica`Optica`RayEnd :> {6.132323290557163, -1.8924612836515469`, 0.}, 
      RotationMatrix :> {{-0.9997829569963212, -0.020833600257567933`, 0.}, {
       0.020833600257567933`, -0.9997829569963212, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020089281786825147`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0032103970658944195`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.730092606650338`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1882948942690248, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9997829569963212, -0.020833600257567933`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.132323290557163, -1.8924612836515469`, 0.}, 
      Optica`Optica`RayEnd :> {5.930327422316176, -1.9106077982607501`, 0.}, 
      RotationMatrix :> {{-0.9959890022819746, -0.08947573600343672, 0.}, {
       0.08947573600343672, -0.9959890022819746, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019981090247845213`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2028093360249775, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.030250423967306`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23172921481580155`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9959890022819746, -0.08947573600343672, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.249945292601955, -2.9372034400351885`, 0.}, 
      Optica`Optica`RayEnd :> {7.163782036569682, -3.096999373830829, 0.}, 
      RotationMatrix :> {{-0.47460913832044954`, -0.8801966631513207, 0.}, {
       0.8801966631513207, -0.47460913832044954`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03942061922742455, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18154571641243358`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.89326162293277, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3744211579702791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.47460913832044954`, -0.8801966631513207, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.163782036569682, -3.096999373830829, 0.}, 
      Optica`Optica`RayEnd :> {7.069476274145186, -3.3210102154751135`, 0.}, 
      RotationMatrix :> {{-0.3880060039609695, -0.9216568455180265, 0.}, {
       0.9216568455180265, -0.3880060039609695, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039057655766644425`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24305232770053103`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.252979067929555`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21799917270550612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3880060039609695, -0.9216568455180265, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.071484832429513, -2.258721142881024, 0.}, 
      Optica`Optica`RayEnd :> {6.931722774464518, -2.2747790926863147`, 0.}, 
      RotationMatrix :> {{-0.9934642168848846, -0.11414398700458298`, 0.}, {
       0.11414398700458298`, -0.9934642168848846, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015467565099601897`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.140681521880309, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.053375965697953`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29512706772905967`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9934642168848846, -0.11414398700458298`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.931722774464518, -2.2747790926863147`, 0.}, 
      Optica`Optica`RayEnd :> {6.6658613148600745`, -2.290693316004209, 0.}, 
      RotationMatrix :> {{-0.9982132452323058, -0.05975213002720404, 0.}, {
       0.05975213002720404, -0.9982132452323058, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015402976513957261`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26633733911492147`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.447555227588037`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2550922965522542, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9982132452323058, -0.05975213002720404, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.037465293458888, -1.4027113492410619`, 0.}, 
      Optica`Optica`RayEnd :> {7.931161121804959, -1.1241284316455704`, 0.}, 
      RotationMatrix :> {{-0.3565146648527769, 0.9342897268754011, 
       0.}, {-0.9342897268754011, -0.3565146648527769, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015263296658670286`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29817615412209675`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.77841106441648, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3319252182600775, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3565146648527769, 0.9342897268754011, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.931161121804959, -1.1241284316455704`, 0.}, 
      Optica`Optica`RayEnd :> {7.905259287943307, -0.9688719174246986, 0.}, 
      RotationMatrix :> {{-0.1645581458566042, 0.986367384209472, 
       0.}, {-0.986367384209472, -0.1645581458566042, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014321783793023742`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15740231956808146`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.011366497377242`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19255895038528037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1645581458566042, 0.986367384209472, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.236712677796566, -0.11373154791280835`, 0.},
       Optica`Optica`RayEnd :> {6.183012615094738, -0.052204520762133305`, 
       0.}, RotationMatrix :> {{-0.657560298798442, 0.7534019202551205, 
       0.}, {-0.7534019202551205, -0.657560298798442, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013194063275259375`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08166560967861675, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.46054770837703, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29029054697578766`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.657560298798442, 0.7534019202551205, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.183012615094738, -0.052204520762133305`, 
       0.}, Optica`Optica`RayEnd :> {5.960741327726372, 0.18163303324655297`, 
       0.}, RotationMatrix :> {{-0.6889540837119661, 0.7248049879357928, 
       0.}, {-0.7248049879357928, -0.6889540837119661, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01314859414084821, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3226213366365531, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.93802728659913, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3918647286874737, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6889540837119661, 0.7248049879357928, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.152490345497259, -0.6774240377395112, 0.}, 
      Optica`Optica`RayEnd :> {4.017570463917072, -0.6412550494577799, 0.}, 
      RotationMatrix :> {{-0.965894829789618, 0.25893469791761087`, 
       0.}, {-0.25893469791761087`, -0.965894829789618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019069690081209758`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13968382210884578`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.83730164057277, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13270526034461752`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.965894829789618, 0.25893469791761087`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.017570463917072, -0.6412550494577799, 0.}, 
      Optica`Optica`RayEnd :> {3.844581130049851, -0.5661312995344663, 0.}, 
      RotationMatrix :> {{-0.9172425347815059, 0.3983291759181061, 
       0.}, {-0.3983291759181061, -0.9172425347815059, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018586723648170465`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18859715648536515`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.11642543217111, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23814833789159082`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9172425347815059, 0.3983291759181061, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.077151719566918, -2.7896193673170946`, 0.}, 
      Optica`Optica`RayEnd :> {5.04843387188945, -2.830133321013055, 0.}, 
      RotationMatrix :> {{-0.5782917105219344, -0.8158300665834861, 0.}, {
       0.8158300665834861, -0.5782917105219344, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09209193217018218, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04965979479724701, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.21064329937285, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0931734262398794, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5782917105219344, -0.8158300665834861, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.04843387188945, -2.830133321013055, 0.}, 
      Optica`Optica`RayEnd :> {4.8796782695141685`, -3.08245491405061, 0.}, 
      RotationMatrix :> {{-0.555933905218987, -0.831226499233492, 0.}, {
       0.831226499233492, -0.555933905218987, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09182984584338193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30355335551769724`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.659902265539042`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33268166486698825`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.555933905218987, -0.831226499233492, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3735957448722327`, 0.12285257957385659`, 
       0.}, Optica`Optica`RayEnd :> {3.3126918097624993`, 
       0.11835838566538617`, 0.}, 
      RotationMatrix :> {{-0.9972884743976943, -0.07359143179419202, 0.}, {
       0.07359143179419202, -0.9972884743976943, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011507924352898182`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06106952669488741, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.228472223643518`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.020538085226272092`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9972884743976943, -0.07359143179419202, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3126918097624993`, 0.11835838566538617`, 
       0.}, Optica`Optica`RayEnd :> {3.1309275385333617`, 0.1380248759012769, 
       0.}, RotationMatrix :> {{-0.994197517225027, 0.10756996208789857`, 
       0.}, {-0.10756996208789857`, -0.994197517225027, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010978168210542209`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18282511078530167`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.499053387605766`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3830426767876267, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.994197517225027, 0.10756996208789857`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.613477516367497, 2.8636309481357225`, 0.}, 
      Optica`Optica`RayEnd :> {6.836228146190559, 3.1835285607538286`, 0.}, 
      RotationMatrix :> {{0.5714329314397656, 0.8206487707089772, 
       0.}, {-0.8206487707089772, 0.5714329314397656, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009323772130858846, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3898106279276325, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.09050146629598, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.046694693248807255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5714329314397656, 0.8206487707089772, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.836228146190559, 3.1835285607538286`, 0.}, 
      Optica`Optica`RayEnd :> {6.891693862377186, 3.3137983546813343`, 0.}, 
      RotationMatrix :> {{0.391745088204695, 0.9200737937075999, 
       0.}, {-0.9200737937075999, 0.391745088204695, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008686223664738335, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14158624538425393`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.300049109464677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39122193355662593`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.391745088204695, 0.9200737937075999, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.920138022643766, 3.6150100035364083`, 0.}, 
      Optica`Optica`RayEnd :> {6.893635248830319, 3.7624543145467406`, 0.}, 
      RotationMatrix :> {{-0.17691245300973274`, 0.984226591781628, 
       0.}, {-0.984226591781628, -0.17691245300973274`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020765397233517745`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14980728243018848`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.94697411424366, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41509121271089167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.17691245300973274`, 0.984226591781628, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.893635248830319, 3.7624543145467406`, 0.}, 
      Optica`Optica`RayEnd :> {6.8194450232654305`, 3.8923426367631024`, 0.}, 
      RotationMatrix :> {{-0.49597931021011643`, 0.8683343387448739, 
       0.}, {-0.8683343387448739, -0.49597931021011643`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012562704846381669`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1495833072824322, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.16835740902166, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03847977810733971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.49597931021011643`, 0.8683343387448739, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.383789456511689, -1.9729749954037983`, 0.}, 
      Optica`Optica`RayEnd :> {3.330907938269609, -2.058829454821125, 0.}, 
      RotationMatrix :> {{-0.5244426925882708, -0.851445748236941, 0.}, {
       0.851445748236941, -0.5244426925882708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.038071278926875105`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10083374025309619`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.555648951190864`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10218692747978585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5244426925882708, -0.851445748236941, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.330907938269609, -2.058829454821125, 0.}, 
      Optica`Optica`RayEnd :> {3.182742657092213, -2.311972613455932, 0.}, 
      RotationMatrix :> {{-0.5051383704352685, -0.8630383692015097, 0.}, {
       0.8630383692015097, -0.5051383704352685, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03796757085197436, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2933162274917363, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.989756967878634`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36879236579901187`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5051383704352685, -0.8630383692015097, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.7020451715431815`, -3.9112365439015684`, 
       0.}, Optica`Optica`RayEnd :> {5.771706365735673, -4.080001974130683, 
       0.}, RotationMatrix :> {{0.3815436697856473, -0.924350814380828, 0.}, {
       0.924350814380828, 0.3815436697856473, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01569532709972737, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18257725054546692`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.211681789921293`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20550434984204222`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3815436697856473, -0.924350814380828, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.771706365735673, -4.080001974130683, 0.}, 
      Optica`Optica`RayEnd :> {5.875281126091442, -4.37143559027782, 0.}, 
      RotationMatrix :> {{0.3348773969043811, -0.9422617094218275, 0.}, {
       0.9422617094218275, 0.3348773969043811, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0156346115766811, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3092915834667216, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.66943333345204, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1282454830875747, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3348773969043811, -0.9422617094218275, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.555889127695717, -2.088286515364006, 0.}, 
      Optica`Optica`RayEnd :> {7.648601230646284, -2.149668120186087, 0.}, 
      RotationMatrix :> {{0.8338162642311701, -0.5520420613536402, 0.}, {
       0.5520420613536402, 0.8338162642311701, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011590683998308326`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11119008698643344`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.812401716351435`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33930769163525015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8338162642311701, -0.5520420613536402, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.648601230646284, -2.149668120186087, 0.}, 
      Optica`Optica`RayEnd :> {7.897226245942283, -2.319820684585405, 0.}, 
      RotationMatrix :> {{0.8252442794911413, -0.5647759548415172, 0.}, {
       0.5647759548415172, 0.8252442794911413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011560738412840877`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3012744486387783, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.258287900336825`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27932197335488046`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8252442794911413, -0.5647759548415172, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3690487587760924`, 3.5453326097585736`, 0.},
       Optica`Optica`RayEnd :> {3.2605448101087156`, 3.61893592385977, 0.}, 
      RotationMatrix :> {{-0.8275621089502703, 0.5613741674051096, 
       0.}, {-0.5613741674051096, -0.8275621089502703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00918722188775691, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13111275576042242`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.72028822675752, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09889100783543281, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.8275621089502703, 0.5613741674051096, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2605448101087156`, 3.61893592385977, 0.}, 
      Optica`Optica`RayEnd :> {3.057522303906609, 3.7785231599775653`, 0.}, 
      RotationMatrix :> {{-0.7861874761608554, 0.6179880681112082, 
       0.}, {-0.6179880681112082, -0.7861874761608554, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009136442549007983, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25823675949852937`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.102478630815344`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04298177175312878, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.7861874761608554, 0.6179880681112082, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.34954007318907, -2.9311449148270943`, 0.}, 
      Optica`Optica`RayEnd :> {7.277103947723624, -3.1009969653937595`, 0.}, 
      RotationMatrix :> {{-0.39228252834130706`, -0.9198447792742812, 0.}, {
       0.9198447792742812, -0.39228252834130706`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12227760455364485`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18465294840361154`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.628095763925725`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06499574337091711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.39228252834130706`, -0.9198447792742812, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.277103947723624, -3.1009969653937595`, 0.}, 
      Optica`Optica`RayEnd :> {7.150433843677726, -3.3987902081105528`, 0.}, 
      RotationMatrix :> {{-0.39142323175282867`, -0.920210765881475, 0.}, {
       0.920210765881475, -0.39142323175282867`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12197617804681277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32361416944686083`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.107044734707078`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40221515214550135`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.39142323175282867`, -0.920210765881475, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.023701590059098, 2.6198351822922343`, 0.}, 
      Optica`Optica`RayEnd :> {7.889445456338815, 2.926024376894937, 0.}, 
      RotationMatrix :> {{-0.4015677434562001, 0.9158293222077439, 
       0.}, {-0.9158293222077439, -0.4015677434562001, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04005257519182435, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33432997522353586`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.510791923634244`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3636674681723822, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4015677434562001, 0.9158293222077439, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.889445456338815, 2.926024376894937, 0.}, 
      Optica`Optica`RayEnd :> {7.850770231733905, 3.0919020319561095`, 0.}, 
      RotationMatrix :> {{-0.22706501560791226`, 0.9738796017408818, 
       0.}, {-0.9738796017408818, -0.22706501560791226`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03812215150147079, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1703266551272396, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.76287537322256, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17440673340732865`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22706501560791226`, 0.9738796017408818, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.382315238116761, -0.8858538580442203, 0.}, 
      Optica`Optica`RayEnd :> {4.378244028380549, -0.8871292544932251, 0.}, 
      RotationMatrix :> {{-0.9542699775058238, -0.29894616577409755`, 0.}, {
       0.29894616577409755`, -0.9542699775058238, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014951077029324087`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0042663081016685225`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.170704923168465`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11728735847559851`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9542699775058238, -0.29894616577409755`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.378244028380549, -0.8871292544932251, 0.}, 
      Optica`Optica`RayEnd :> {4.200021876269678, -0.9119070393901738, 0.}, 
      RotationMatrix :> {{-0.9904735532204886, -0.13770308773146467`, 0.}, {
       0.13770308773146467`, -0.9904735532204886, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01442919213850764, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17993630575131309`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.437010655680407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4228017050502978, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9904735532204886, -0.13770308773146467`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.842558002495407, -2.3562116887071047`, 0.}, 
      Optica`Optica`RayEnd :> {6.838998481869474, -2.3971098311794203`, 0.}, 
      RotationMatrix :> {{-0.0867060225159269, -0.9962339412304054, 0.}, {
       0.9962339412304054, -0.0867060225159269, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2592090937945081, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04105274953973577, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.5391679053385, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18368766880467272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.0867060225159269, -0.9962339412304054, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.838998481869474, -2.3971098311794203`, 0.}, 
      Optica`Optica`RayEnd :> {6.860468037503002, -2.5452454429729006`, 0.}, 
      RotationMatrix :> {{0.14343317098433256`, -0.9896600049822053, 0.}, {
       0.9896600049822053, 0.14343317098433256`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2333391156040766, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14968333674971912`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.760699243728084`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3081535262199577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14343317098433256`, -0.9896600049822053, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.860468037503002, -2.5452454429729006`, 0.}, 
      Optica`Optica`RayEnd :> {6.999102128718822, -2.6016873604925377`, 0.}, 
      RotationMatrix :> {{0.9261825279030604, -0.37707548979892075`, 0.}, {
       0.37707548979892075`, 0.9261825279030604, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023288063482978356`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1496833367497192, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.98223058211767, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19014988671592675`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9261825279030604, -0.37707548979892075`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.987758823987346, -1.6947174978191548`, 0.}, 
      Optica`Optica`RayEnd :> {8.249651997048355, -2.065005472982989, 0.}, 
      RotationMatrix :> {{0.5774385115272428, -0.8164341770193122, 0.}, {
       0.8164341770193122, 0.5774385115272428, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2736088560216683, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.45354296229452834`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.35740432788531, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22363568069121093`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5774385115272428, -0.8164341770193122, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.249651997048355, -2.065005472982989, 0.}, 
      Optica`Optica`RayEnd :> {8.393442965850957, -2.303851857405552, 0.}, 
      RotationMatrix :> {{0.5157694425745449, -0.8567274257932581, 0.}, {
       0.8567274257932581, 0.5157694425745449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2719906318120623, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2787892359129408, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.77001239703646, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2905578071219675, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5157694425745449, -0.8567274257932581, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.296808618032822, -0.9383558163661906, 0.}, 
      Optica`Optica`RayEnd :> {7.2484503078147435`, -1.131275623238627, 0.}, 
      RotationMatrix :> {{-0.24314299365088438`, -0.9699904559522662, 0.}, {
       0.9699904559522662, -0.24314299365088438`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024577282984038457`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19888835574473954`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.6778767332603, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.290307996385847, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.24314299365088438`, -0.9699904559522662, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.2484503078147435`, -1.131275623238627, 0.}, 
      Optica`Optica`RayEnd :> {7.185536517567847, -1.4233285737793353`, 0.}, 
      RotationMatrix :> {{-0.21058831332872877`, -0.9775748371809497, 0.}, {
       0.9775748371809497, -0.21058831332872877`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024502237353548752`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29875252454626033`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.120030469588766`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43217050512082145`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.21058831332872877`, -0.9775748371809497, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.892238369604698, 1.4306052722726568`, 0.}, 
      Optica`Optica`RayEnd :> {5.701552488729594, 1.5990694274151984`, 0.}, 
      RotationMatrix :> {{-0.7494245357347973, 0.6620897712838363, 
       0.}, {-0.6620897712838363, -0.7494245357347973, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008841048217494886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2544430716938555, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.434393931289545`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28505659053987464`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.7494245357347973, 0.6620897712838363, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.701552488729594, 1.5990694274151984`, 0.}, 
      Optica`Optica`RayEnd :> {5.589911053871509, 1.723989415994277, 0.}, 
      RotationMatrix :> {{-0.6663668469371244, 0.7456240509151204, 
       0.}, {-0.7456240509151204, -0.6663668469371244, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008715109357626271, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16753749885852218`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.68234942960016, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.014548213874234883`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6663668469371244, 0.7456240509151204, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.243269221268635, 0.13022919532730276`, 0.}, 
      Optica`Optica`RayEnd :> {6.188201289061612, 0.0793996632269098, 0.}, 
      RotationMatrix :> {{-0.7348194413020738, -0.6782627725922362, 0.}, {
       0.6782627725922362, -0.7348194413020738, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17245765173232358`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07494076655000352, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.399163127058305`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3214406869958149, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7348194413020738, -0.6782627725922362, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.188201289061612, 0.0793996632269098, 0.}, 
      Optica`Optica`RayEnd :> {5.940248911892806, -0.1320508901896091, 0.}, 
      RotationMatrix :> {{-0.7608918862770071, -0.6488786769480235, 0.}, {
       0.6488786769480235, -0.7608918862770071, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17188949785270988`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32587070731167894`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.88145177387959, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42893724654496335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7608918862770071, -0.6488786769480235, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.35088627346321, -0.39228288094063185`, 0.}, 
      Optica`Optica`RayEnd :> {7.351114219330654, -0.3940541335758071, 0.}, 
      RotationMatrix :> {{0.12763928488179715`, -0.9918206556403546, 0.}, {
       0.9918206556403546, 0.12763928488179715`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01058631217158876, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0017858597974365236`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.872070865428054`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28070353136331366`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12763928488179715`, -0.9918206556403546, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.351114219330654, -0.3940541335758071, 0.}, 
      Optica`Optica`RayEnd :> {7.401924794015256, -0.6117164683421243, 0.}, 
      RotationMatrix :> {{0.22732591563266707`, -0.9738187347149206, 0.}, {
       0.9738187347149206, 0.22732591563266707`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01047791027299739, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2235142198512298, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.202871910807875`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43111307889272144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.22732591563266707`, -0.9738187347149206, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.267663358684314, 2.8974339656723194`, 0.}, 
      Optica`Optica`RayEnd :> {7.359469019374845, 3.1712319685556047`, 0.}, 
      RotationMatrix :> {{0.31790915326593716`, 0.9481211791062015, 
       0.}, {-0.9481211791062015, 0.31790915326593716`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05058737132769413, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28877954518577015`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.65705268769322, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24512012022416524`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.31790915326593716`, 0.9481211791062015, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.359469019374845, 3.1712319685556047`, 0.}, 
      Optica`Optica`RayEnd :> {7.367555068531391, 3.3293246155986482`, 0.}, 
      RotationMatrix :> {{0.05108076294629277, 0.9986945256968337, 
       0.}, {-0.9986945256968337, 0.05108076294629277, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04165783591531445, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15829930271494708`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.89133565571134, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28830418892855986`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.05108076294629277, 0.9986945256968337, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.656119914545259, 2.8887936551931834`, 0.}, 
      Optica`Optica`RayEnd :> {6.636500606390305, 2.9000693577730754`, 0.}, 
      RotationMatrix :> {{-0.8670093977920703, 0.49829178614565794`, 
       0.}, {-0.49829178614565794`, -0.8670093977920703, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2509718533997882`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.022628714527105773`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.59259746769427, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27779164415046803`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8670093977920703, 0.49829178614565794`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.636500606390305, 2.9000693577730754`, 0.}, 
      Optica`Optica`RayEnd :> {6.351578364845772, 3.0615498507624155`, 0.}, 
      RotationMatrix :> {{-0.8699900225279154, 0.49306932646624446`, 
       0.}, {-0.49306932646624446`, -0.8699900225279154, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.247866025183471, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32750058525572306`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.07729833387274, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27111767971682005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8699900225279154, 0.49306932646624446`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.435364607407312, 2.3487108780900354`, 0.}, 
      Optica`Optica`RayEnd :> {6.3900416727379525`, 2.3443304094935713`, 0.}, 
      RotationMatrix :> {{-0.9953618433719982, -0.09620187502900568, 0.}, {
       0.09620187502900568, -0.9953618433719982, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037921119300415765`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04553412909200792, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.911148650819204`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07239215867908182, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9953618433719982, -0.09620187502900568, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.3900416727379525`, 2.3443304094935713`, 0.},
       Optica`Optica`RayEnd :> {6.149841575224362, 2.298041295074627, 0.}, 
      RotationMatrix :> {{-0.9819329966218261, -0.18922893580338013`, 0.}, {
       0.18922893580338013`, -0.9819329966218261, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037585883610391155`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24461964140115297`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.27318572009291, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24893841933497116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9819329966218261, -0.18922893580338013`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.90909050153152, 2.6189814743779674`, 0.}, 
      Optica`Optica`RayEnd :> {6.851180149953768, 2.6419531208205154`, 0.}, 
      RotationMatrix :> {{-0.9295383144216405, 0.36872553752374493`, 
       0.}, {-0.36872553752374493`, -0.9295383144216405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24250985607999634`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.062300123275482795`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.176981383471524`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2094911482515482, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9295383144216405, 0.36872553752374493`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.851180149953768, 2.6419531208205154`, 0.}, 
      Optica`Optica`RayEnd :> {6.556008619207015, 2.7669057467627027`, 0.}, 
      RotationMatrix :> {{-0.9208862180370004, 0.3898314679826517, 
       0.}, {-0.3898314679826517, -0.9208862180370004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2418475581176971, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3205298602208997, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.651365576598455`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0924763848980405, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9208862180370004, 0.3898314679826517, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.220310908486281, 0.6114199351966487, 0.}, 
      Optica`Optica`RayEnd :> {8.230386758025595, 0.3758248157132166, 0.}, 
      RotationMatrix :> {{0.04272859071324378, -0.9990867167246588, 0.}, {
       0.9990867167246588, 0.04272859071324378, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25715506285888134`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23581048125210968`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.59835845981372, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2307603047238681, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.04272859071324378, -0.9990867167246588, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.230386758025595, 0.3758248157132166, 0.}, 
      Optica`Optica`RayEnd :> {8.241317660936481, 0.05937870694277017, 0.}, 
      RotationMatrix :> {{0.03452210999587167, -0.9994039343135644, 0.}, {
       0.9994039343135644, 0.03452210999587167, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25651258153130724`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31663484393604635`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.06697802883907, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19960294862255606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.03452210999587167, -0.9994039343135644, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.713475040829654, 0.0453881684976358, 0.}, 
      Optica`Optica`RayEnd :> {7.6645860830738215`, -0.031147231682318602`, 
       0.}, RotationMatrix :> {{-0.5383215670242137, -0.8427395151982577, 
       0.}, {0.8427395151982577, -0.5383215670242137, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07506117210724828, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09081738639245975, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.328372549255615`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40233258935798827`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5383215670242137, -0.8427395151982577, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.6645860830738215`, -0.031147231682318602`, 
       0.}, Optica`Optica`RayEnd :> {7.534634195919815, -0.19247479425545638`,
        0.}, RotationMatrix :> {{-0.6273107220740926, -0.7787690658795328, 
       0.}, {0.7787690658795328, -0.6273107220740926, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07415323361893261, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2071571273711755, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.634965097764955`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20437270565078453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6273107220740926, -0.7787690658795328, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.232629346704844, 0.0935309731620283, 0.}, 
      Optica`Optica`RayEnd :> {7.053641669446334, -0.3173519697819334, 0.}, 
      RotationMatrix :> {{-0.39936951381659, -0.916790047630263, 0.}, {
       0.916790047630263, -0.39936951381659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023895723929679133`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.44817561447794935`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.314425836858533`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04728878318013305, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39936951381659, -0.916790047630263, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.053641669446334, -0.31735196978193336`, 0.},
       Optica`Optica`RayEnd :> {6.918235140502793, -0.6120523874165424, 0.}, 
      RotationMatrix :> {{-0.4175094243233421, -0.9086725926323467, 0.}, {
       0.9086725926323467, -0.4175094243233421, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02383202775510653, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32431969449071535`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.79441898470479, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3468762233432972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4175094243233421, -0.9086725926323467, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5681643822077485`, -1.1355830966992775`, 
       0.}, 
      Optica`Optica`RayEnd :> {7.606344688347924, -1.4187334913977332`, 0.}, 
      RotationMatrix :> {{0.13363170276914646`, -0.9910310630928869, 0.}, {
       0.9910310630928869, 0.13363170276914646`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1962469295600287, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28571293599494035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.694796615299946`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19569297640575828`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13363170276914646`, -0.9910310630928869, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.606344688347924, -1.4187334913977334`, 0.}, 
      Optica`Optica`RayEnd :> {7.603390235694879, -1.6110348748944543`, 0.}, 
      RotationMatrix :> {{-0.015361844900005833`, -0.9998819998986217, 0.}, {
       0.9998819998986217, -0.015361844900005833`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1911250966889257, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19232407775739377`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.97943625038089, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18146590414442818`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.015361844900005833`, -0.9998819998986217, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.837885967467196, 1.5380887190130017`, 0.}, 
      Optica`Optica`RayEnd :> {4.818216791195257, 1.5884045492762944`, 0.}, 
      RotationMatrix :> {{-0.36408426811985567`, 0.93136601060358, 
       0.}, {-0.93136601060358, -0.36408426811985567`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009841817985064952, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0540236917500189, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.74055456357573, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09566344247645209, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.36408426811985567`, 0.93136601060358, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.818216791195257, 1.5884045492762944`, 0.}, 
      Optica`Optica`RayEnd :> {4.701971665894905, 1.8586035155755987`, 0.}, 
      RotationMatrix :> {{-0.39519866075757065`, 0.9185956773986156, 
       0.}, {-0.9185956773986156, -0.39519866075757065`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009811690677919238, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2941435203184108, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.17588697364698, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2905397115895493, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.39519866075757065`, 0.9185956773986156, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.349692745732636, 0.9390177742939605, 0.}, 
      Optica`Optica`RayEnd :> {4.257659461780888, 0.9100120270629408, 0.}, 
      RotationMatrix :> {{-0.9537533086851039, -0.30059046254366767`, 0.}, {
       0.30059046254366767`, -0.9537533086851039, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.31239698204415983`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09649590005473262, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.2483576675172, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25887788525506367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9537533086851039, -0.30059046254366767`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.257659461780888, 0.9100120270629408, 0.}, 
      Optica`Optica`RayEnd :> {4.117167632438771, 0.8261175470069844, 0.}, 
      RotationMatrix :> {{-0.8585711449721746, -0.5126944402089497, 0.}, {
       0.5126944402089497, -0.8585711449721746, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2801784840613447, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1636344642664061, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.490536674631482`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24617295542055428`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8585711449721746, -0.5126944402089497, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.117167632438771, 0.8261175470069844, 0.}, 
      Optica`Optica`RayEnd :> {4.117643865374875, 0.662483775743396, 0.}, 
      RotationMatrix :> {{0.0029103461684538146`, -0.9999957649336215, 0.}, {
       0.9999957649336215, 0.0029103461684538146`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.028895701438889386`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1636344642664063, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.732715681745763`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24870193867446239`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0029103461684538146`, -0.9999957649336215, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.846694276822012, 0.5984956863594586, 0.}, 
      Optica`Optica`RayEnd :> {4.807577656537465, 0.386077457015285, 0.}, 
      RotationMatrix :> {{-0.18110397674729442`, -0.9834639544011334, 0.}, {
       0.9834639544011334, -0.18110397674729442`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009323428526295995, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2159898473081533, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.359857531901028`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.037868098235734005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.18110397674729442`, -0.9834639544011334, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.807577656537465, 0.386077457015285, 0.}, 
      Optica`Optica`RayEnd :> {4.751781410101081, 0.14079931650843228`, 0.}, 
      RotationMatrix :> {{-0.22181469945662813`, -0.9750888365195066, 0.}, {
       0.9750888365195066, -0.22181469945662813`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00929171402085879, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2515444042845894, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.73214325024222, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18152608725239186`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22181469945662813`, -0.9750888365195066, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.412383262155191, 1.1080402052512859`, 0.}, 
      Optica`Optica`RayEnd :> {3.109795497765404, 1.1420644005632679`, 0.}, 
      RotationMatrix :> {{-0.9937374908387939, 0.1117398733730132, 
       0.}, {-0.1117398733730132, -0.9937374908387939, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.28016455361656745`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3044946650190065, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.026901234583644`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0009134636894602144, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9937374908387939, 0.1117398733730132, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.109795497765404, 1.1420644005632679`, 0.}, 
      Optica`Optica`RayEnd :> {2.9148613770099985`, 1.1285672376053026`, 0.}, 
      RotationMatrix :> {{-0.9976115226093712, -0.06907423511709103, 0.}, {
       0.06907423511709103, -0.9976115226093712, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2673399707217089, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19540083122289148`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.316094464793522`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3949867928813339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9976115226093712, -0.06907423511709103, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9148613770099985`, 1.1285672376053026`, 0.},
       Optica`Optica`RayEnd :> {2.853419889646802, 0.9430775385026428, 0.}, 
      RotationMatrix :> {{-0.3144382087766592, -0.9492779428920305, 0.}, {
       0.9492779428920305, -0.3144382087766592, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012237535303347718`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19540083122289204`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.6052876950034, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1338650447632489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.3144382087766592, -0.9492779428920305, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3595970983370855`, 0.9048842717050697, 0.}, 
      Optica`Optica`RayEnd :> {2.3474023378701885`, 0.9048738988616299, 0.}, 
      RotationMatrix :> {{-0.9999996382413978, -0.0008505980675463098, 0.}, {
       0.0008505980675463098, -0.9999996382413978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2844943552158621, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01219476487845818, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.308068730617702`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02223633820901364, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999996382413978, -0.0008505980675463098, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3474023378701885`, 0.9048738988616299, 0.}, 
      Optica`Optica`RayEnd :> {2.202642609176679, 0.8816321711879552, 0.}, 
      RotationMatrix :> {{-0.9873551808366898, -0.15852364768370225`, 0.}, {
       0.15852364768370225`, -0.9873551808366898, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27574864497424645`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1466136315513524, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.525056905313704`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3492482972953295, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9873551808366898, -0.15852364768370225`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.202642609176679, 0.8816321711879552, 0.}, 
      Optica`Optica`RayEnd :> {2.1829116023236583`, 0.7363522884607112, 0.}, 
      RotationMatrix :> {{-0.13457825608875892`, -0.9909029685030253, 0.}, {
       0.9909029685030253, -0.13457825608875892`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008476856233695713, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1466136315513524, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.742045080009706`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24116770924494785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13457825608875892`, -0.9909029685030253, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.028902406669837, -3.1251692495618935`, 0.}, 
      Optica`Optica`RayEnd :> {7.058316122578409, -3.2104291544489056`, 0.}, 
      RotationMatrix :> {{0.32612692003556276`, -0.9453259924640373, 0.}, {
       0.9453259924640373, 0.32612692003556276`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008966037540757144, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09019100878076788, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.48304085182197, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12369366132346574`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.32612692003556276`, -0.9453259924640373, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.058316122578409, -3.2104291544489056`, 0.}, 
      Optica`Optica`RayEnd :> {7.152935114196686, -3.3998557454180136`, 0.}, 
      RotationMatrix :> {{0.44685726479991894`, -0.8946052676435202, 0.}, {
       0.8946052676435202, 0.44685726479991894`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00880072066566727, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21174320990538809`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.796420802481943`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39716800017164133`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.44685726479991894`, -0.8946052676435202, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7427671292921243`, 3.096120721976002, 0.}, 
      Optica`Optica`RayEnd :> {3.6491189382290914`, 3.096727167638321, 0.}, 
      RotationMatrix :> {{-0.9999790327560727, 0.006475650409698108, 
       0.}, {-0.006475650409698108, -0.9999790327560727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29350266029161254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09365015464866927, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.89368649266517, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2674857119277927, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999790327560727, 0.006475650409698108, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6491189382290914`, 3.096727167638321, 0.}, 
      Optica`Optica`RayEnd :> {3.350901074353575, 3.083822610252523, 0.}, 
      RotationMatrix :> {{-0.9990650690534624, -0.043231791510411705`, 0.}, {
       0.043231791510411705`, -0.9990650690534624, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2923722035278479, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2984969379002057, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.335461960757478`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1929730162620329, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9990650690534624, -0.043231791510411705`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.622847132670974, 3.201489704433622, 0.}, 
      Optica`Optica`RayEnd :> {3.548730151265034, 3.313291298098303, 0.}, 
      RotationMatrix :> {{-0.5525439897088618, 0.8334837367559205, 
       0.}, {-0.8334837367559205, -0.5525439897088618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.3034156724691288`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13413770267412084`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.18420004660474, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16361212327918773`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5525439897088618, 0.8334837367559205, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.548730151265034, 3.313291298098303, 0.}, 
      Optica`Optica`RayEnd :> {3.3885589709624035`, 3.5767400067352, 0.}, 
      RotationMatrix :> {{-0.5194998236855053, 0.854470557240405, 
       0.}, {-0.854470557240405, -0.5194998236855053, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2991297679476463`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3083180647999504, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.640510782508667`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30990459493573497`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5194998236855053, 0.854470557240405, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.643384671488563, 3.3597983825061997`, 0.}, 
      Optica`Optica`RayEnd :> {3.651399080236819, 3.37910346651708, 0.}, 
      RotationMatrix :> {{0.38341756859857107`, 0.9235751014887523, 
       0.}, {-0.9235751014887523, 0.38341756859857107`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2074938795782712, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.020902560040609145`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.268725195061297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20672086756239041`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.38341756859857107`, 0.9235751014887523, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.651399080236819, 3.37910346651708, 0.}, 
      Optica`Optica`RayEnd :> {3.6715545154570086`, 3.532753025731774, 0.}, 
      RotationMatrix :> {{0.13006368413568622`, 0.9915056419754008, 
       0.}, {-0.9915056419754008, 0.13006368413568622`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17507661322311674`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15496589500849858`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.498074719673873`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.317147855198903, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13006368413568622`, 0.9915056419754008, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6715545154570086`, 3.532753025731774, 0.}, 
      Optica`Optica`RayEnd :> {3.5550668598930115`, 3.63495407620088, 0.}, 
      RotationMatrix :> {{-0.7516986596154482, 0.6595067286482661, 
       0.}, {-0.6595067286482661, -0.7516986596154482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02735263909927003, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1549658950084988, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.72742424428645, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14487709455361908`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7516986596154482, 0.6595067286482661, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7862216760573277`, 3.4310796435752473`, 0.},
       Optica`Optica`RayEnd :> {3.881455294618198, 3.4502254001223314`, 0.}, 
      RotationMatrix :> {{0.9803841289227637, 0.19709632101171412`, 
       0.}, {-0.19709632101171412`, 0.9803841289227637, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03303145034375969, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09713908635537816, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.60714237990855, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3190770961339321, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9803841289227637, 0.19709632101171412`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.881455294618198, 3.4502254001223314`, 0.}, 
      Optica`Optica`RayEnd :> {4.139812661650813, 3.5158217226159985`, 0.}, 
      RotationMatrix :> {{0.9692470990023642, 0.24608953873641212`, 
       0.}, {-0.24608953873641212`, 0.9692470990023642, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032903138430371154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2665546972475228, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.00164333183488, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3764266220094934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9692470990023642, 0.24608953873641212`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.111585282110616, 3.472367027206931, 0.}, 
      Optica`Optica`RayEnd :> {6.264634592188302, 3.5569056035555873`, 0.}, 
      RotationMatrix :> {{0.8753415273128048, 0.4835051298194109, 
       0.}, {-0.4835051298194109, 0.8753415273128048, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2332199913071227, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1748452521697781, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.436328653076796`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15566681443737976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8753415273128048, 0.4835051298194109, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.264634592188302, 3.5569056035555873`, 0.}, 
      Optica`Optica`RayEnd :> {6.377435097169095, 3.658150991890274, 0.}, 
      RotationMatrix :> {{0.7441958247012045, 0.6679615067481759, 
       0.}, {-0.6679615067481759, 0.7441958247012045, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21124556975227035`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15157368697423523`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.660657709798663`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33430240163745334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7441958247012045, 0.6679615067481759, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.377435097169095, 3.658150991890274, 0.}, 
      Optica`Optica`RayEnd :> {6.345897813530606, 3.8064074667022325`, 0.}, 
      RotationMatrix :> {{-0.20806568915783674`, 0.9781148547053529, 
       0.}, {-0.9781148547053529, -0.20806568915783674`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.019903950666125318`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15157368697423523`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.88498676652053, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15402233373085797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20806568915783674`, 0.9781148547053529, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.1176548356263805`, 2.335555256105638, 0.}, 
      Optica`Optica`RayEnd :> {6.144325840184996, 2.2875612976895767`, 0.}, 
      RotationMatrix :> {{0.48575001120931177`, -0.8740977786324325, 0.}, {
       0.8740977786324325, 0.48575001120931177`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01204466681521663, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.054906853202567316`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.75669722437155, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2164913164700943, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.48575001120931177`, -0.8740977786324325, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.144325840184996, 2.2875612976895767`, 0.}, 
      Optica`Optica`RayEnd :> {6.29350856581124, 2.0561842066253853`, 0.}, 
      RotationMatrix :> {{0.5418887891793814, -0.84045020088147, 0.}, {
       0.84045020088147, 0.5418887891793814, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011983669133454427`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27530136922035553`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.164143250817677`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24025246980439569`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5418887891793814, -0.84045020088147, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.374197998047203, 2.8252555391612586`, 0.}, 
      Optica`Optica`RayEnd :> {6.406564721915494, 2.8310406851140684`, 0.}, 
      RotationMatrix :> {{0.9843992790639394, 0.17594902494300865`, 
       0.}, {-0.17594902494300865`, 0.9843992790639394, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16224915365310683`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03287967043115754, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.271615361884972`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4315633901078284, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9843992790639394, 0.17594902494300865`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.406564721915494, 2.8310406851140684`, 0.}, 
      Optica`Optica`RayEnd :> {6.635004169707646, 2.8971105400953423`, 0.}, 
      RotationMatrix :> {{0.9606286565997035, 0.27783553429942703`, 
       0.}, {-0.27783553429942703`, 0.9606286565997035, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1604729420220983, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23780203330676072`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.623562371178977`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2693312705855209, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9606286565997035, 0.27783553429942703`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.9726659601126935`, 1.3721407739913314`, 0.},
       Optica`Optica`RayEnd :> {6.051377142344828, 1.2665536430853388`, 0.}, 
      RotationMatrix :> {{0.5976688838433689, -0.8017430419314038, 0.}, {
       0.8017430419314038, 0.5976688838433689, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09790774118840805, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1316969719520516, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.767596343925845`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013655111657401579`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5976688838433689, -0.8017430419314038, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.051377142344828, 1.2665536430853388`, 0.}, 
      Optica`Optica`RayEnd :> {6.1972652318558445`, 1.114415438426117, 0.}, 
      RotationMatrix :> {{0.692125371029753, -0.7217772999872785, 0.}, {
       0.7217772999872785, 0.692125371029753, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09633888958622767, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21078275066547975`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.079554814910754`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27936331635533895`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.692125371029753, -0.7217772999872785, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.095108047103927, 1.6972718055676446`, 0.}, 
      Optica`Optica`RayEnd :> {5.117654458232004, 1.619604436013454, 0.}, 
      RotationMatrix :> {{0.27878533419369556`, -0.9603534440186635, 0.}, {
       0.9603534440186635, 0.27878533419369556`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.050687083202645936`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0808737346004468, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.961145819349518`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1155240018941103, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.27878533419369556`, -0.9603534440186635, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.117654458232004, 1.619604436013454, 0.}, 
      Optica`Optica`RayEnd :> {5.14685598326838, 1.4104281174482072`, 0.}, 
      RotationMatrix :> {{0.1382616639185478, -0.9903957351940048, 0.}, {
       0.9903957351940048, 0.1382616639185478, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.049494744637069245`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21120478525109163`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.273728901521135`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.244335878499472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1382616639185478, -0.9903957351940048, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.122848840957539, 1.7180552732101344`, 0.}, 
      Optica`Optica`RayEnd :> {4.06868495637522, 1.6330362242929266`, 0.}, 
      RotationMatrix :> {{-0.5373050903862896, -0.8433879533435252, 0.}, {
       0.8433879533435252, -0.5373050903862896, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034598187714824896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10080657256267238`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.734413181015544`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08201161348994922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5373050903862896, -0.8433879533435252, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.06868495637522, 1.6330362242929266`, 0.}, 
      Optica`Optica`RayEnd :> {3.9166370419365357`, 1.3835162247723365`, 0.}, 
      RotationMatrix :> {{-0.5203618490470424, -0.8539458683408112, 0.}, {
       0.8539458683408112, -0.5203618490470424, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034505898670755424`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2921965065600693, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.166864010724446`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37067446051738795`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5203618490470424, -0.8539458683408112, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4661872280868278`, 3.180921472328808, 0.}, 
      Optica`Optica`RayEnd :> {3.397482177038022, 3.200061181694977, 0.}, 
      RotationMatrix :> {{-0.9633188753831106, 0.26835935670406175`, 
       0.}, {-0.26835935670406175`, -0.9633188753831106, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02305153619749623, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07132119260248267, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.51353802361847, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26770781230317336`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9633188753831106, 0.26835935670406175`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.397482177038022, 3.200061181694977, 0.}, 
      Optica`Optica`RayEnd :> {3.1006670786341908`, 3.289236112860523, 0.}, 
      RotationMatrix :> {{-0.9577104027753924, 0.2877338777686674, 
       0.}, {-0.2877338777686674, -0.9577104027753924, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022989948179846304`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30992155618616757`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.972221926773997`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05067376644040157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9577104027753924, 0.2877338777686674, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.072694552474338, 0.27587203506025676`, 0.}, 
      Optica`Optica`RayEnd :> {2.9111937313212852`, 0.21776340620799062`, 0.},
       RotationMatrix :> {{-0.9409461969091942, -0.33855613201081286`, 0.}, {
       0.33855613201081286`, -0.9409461969091942, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08156709726881975, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17163661608235242`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.917391741131986`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3966826737763327, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9409461969091942, -0.33855613201081286`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9111937313212852`, 0.21776340620799062`, 
       0.}, Optica`Optica`RayEnd :> {2.602454551891017, 0.12321755953209027`, 
       0.}, RotationMatrix :> {{-0.9561706057727767, -0.29281013072658607`, 
       0.}, {0.29281013072658607`, -0.9561706057727767, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08126037382539143, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3228913099464557, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.395270879852742`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3316458935354622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9561706057727767, -0.29281013072658607`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.47360863487234, 1.8249231390726355`, 0.}, 
      Optica`Optica`RayEnd :> {4.428650990937275, 1.8365678135129835`, 0.}, 
      RotationMatrix :> {{-0.9680544705093873, 0.25073998908588324`, 
       0.}, {-0.25073998908588324`, -0.9680544705093873, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03730121138932358, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04644123373699054, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.38641765538424, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24218385757812247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9680544705093873, 0.25073998908588324`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.428650990937275, 1.8365678135129835`, 0.}, 
      Optica`Optica`RayEnd :> {4.237518902676637, 1.909981509090571, 0.}, 
      RotationMatrix :> {{-0.9335069385173002, 0.35855933363957593`, 
       0.}, {-0.35855933363957593`, -0.9335069385173002, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036816131696574134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20474629633092487`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.66077769246768, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36536461538396436`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9335069385173002, 0.35855933363957593`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.667818548636428, 1.2196932435683943`, 0.}, 
      Optica`Optica`RayEnd :> {3.392784632189184, 1.1893133403696, 0.}, 
      RotationMatrix :> {{-0.9939546958182265, -0.10979099535433828`, 0.}, {
       0.10979099535433828`, -0.9939546958182265, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08978618567116699, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27670669257298003`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.60186665370996, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18262275955702234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9939546958182265, -0.10979099535433828`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.392784632189184, 1.1893133403696, 0.}, 
      Optica`Optica`RayEnd :> {3.2213753721831653`, 1.1509229207014182`, 0.}, 
      RotationMatrix :> {{-0.9758246736838111, -0.2185548128728425, 0.}, {
       0.2185548128728425, -0.9758246736838111, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08868550331442777, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17565579619844596`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.837245420615876`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4153677425603935, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9758246736838111, -0.2185548128728425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.605132568154086, 0.3230387054496063, 0.}, 
      Optica`Optica`RayEnd :> {4.461195578242246, 0.2522018687756769, 0.}, 
      RotationMatrix :> {{-0.897231063817922, -0.44156134128811564`, 0.}, {
       0.44156134128811564`, -0.897231063817922, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02068488982680287, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16042354719569718`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.634345321436015`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4134747569444483, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.897231063817922, -0.44156134128811564`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.461195578242246, 0.2522018687756769, 0.}, 
      Optica`Optica`RayEnd :> {4.226784094955743, 0.11802907473082361`, 0.}, 
      RotationMatrix :> {{-0.8678866612784639, -0.49676226021601166`, 0.}, {
       0.49676226021601166`, -0.8678866612784639, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020585614942961496`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27009458002407366`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.996272058668275`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41556308172707135`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8678866612784639, -0.49676226021601166`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.055440525207455, -2.0856520759379458`, 0.}, 
      Optica`Optica`RayEnd :> {6.035374206978884, -2.406801521780479, 0.}, 
      RotationMatrix :> {{-0.06236119147705871, -0.9980536467533, 0.}, {
       0.9980536467533, -0.06236119147705871, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008187095866582905, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32177573508923324`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.154436605019185`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1967641789806866, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06236119147705871, -0.9980536467533, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.035374206978884, -2.406801521780479, 0.}, 
      Optica`Optica`RayEnd :> {6.017758252410186, -2.666329052544557, 0.}, 
      RotationMatrix :> {{-0.06772119052733802, -0.9977042850231521, 0.}, {
       0.9977042850231521, -0.06772119052733802, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00816679943348881, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2601247029404664, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.539421165371074`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25707340637659587`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.06772119052733802, -0.9977042850231521, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8155000203866543`, 1.49926532461838, 0.}, 
      Optica`Optica`RayEnd :> {2.6393669072293284`, 1.554001809947269, 0.}, 
      RotationMatrix :> {{-0.954949747376776, 0.29676755210944356`, 
       0.}, {-0.29676755210944356`, -0.954949747376776, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14995920778927538`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18444228467640225`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.051790058144434`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3007562926843254, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.954949747376776, 0.29676755210944356`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6393669072293284`, 1.554001809947269, 0.}, 
      Optica`Optica`RayEnd :> {2.3678358241441186`, 1.6157500856389455`, 0.}, 
      RotationMatrix :> {{-0.9751043920839296, 0.22174630670798018`, 
       0.}, {-0.22174630670798018`, -0.9751043920839296, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14900047646286538`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2784636037839101, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.46391619174462, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3753147689264824, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9751043920839296, 0.22174630670798018`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.205090409605016, -0.5352505042925035, 0.}, 
      Optica`Optica`RayEnd :> {2.1486604500619717`, -0.509633451286922, 0.}, 
      RotationMatrix :> {{-0.9105665345612087, 0.41336253596230765`, 
       0.}, {-0.41336253596230765`, -0.9105665345612087, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0082917097970114, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06197236270080701, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.73868844457783, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30981297756934884`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9105665345612087, 0.41336253596230765`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1486604500619717`, -0.509633451286922, 0.}, 
      Optica`Optica`RayEnd :> {1.8591223699710941`, -0.379751604104828, 0.}, 
      RotationMatrix :> {{-0.9124047082188516, 0.4092891990024551, 
       0.}, {-0.4092891990024551, -0.9124047082188516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00827119083604342, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3173351446816823, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.20834445870672, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22395138533701914`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9124047082188516, 0.4092891990024551, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7646409666322525`, -2.3652591978116506`, 
       0.}, Optica`Optica`RayEnd :> {2.687346924834199, -2.4646689242798066`, 
       0.}, RotationMatrix :> {{-0.6138187137543981, -0.789447013196513, 
       0.}, {0.789447013196513, -0.6138187137543981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15890164002061336`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12592324096032811`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.50591074749064, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40785773608175424`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6138187137543981, -0.789447013196513, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.687346924834199, -2.4646689242798066`, 0.}, 
      Optica`Optica`RayEnd :> {2.5207053132081034`, -2.6411097727657418`, 0.},
       RotationMatrix :> {{-0.6866301372053787, -0.7270069151537156, 0.}, {
       0.7270069151537156, -0.6866301372053787, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1574414362572255, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24269486961981523`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.865099154527964`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26547540069261244`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6866301372053787, -0.7270069151537156, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9147952493490976`, -3.3708372984770985`, 
       0.}, Optica`Optica`RayEnd :> {
       3.9063545629573095`, -3.4404873654517356`, 0.}, 
      RotationMatrix :> {{-0.12030684216510365`, -0.9927367544965079, 0.}, {
       0.9927367544965079, -0.12030684216510365`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008263068083729345, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0701596537643676, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.67814848414344, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09420639684830437, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 103, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12030684216510365`, -0.9927367544965079, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2063272730200887`, 2.8948686695957933`, 0.},
       Optica`Optica`RayEnd :> {3.1824858594920125`, 2.9657044306250255`, 0.},
       RotationMatrix :> {{-0.318989910226595, 0.9477581111093846, 
       0.}, {-0.9477581111093846, -0.318989910226595, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041857970832639396`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07474033743305718, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.79219184319085, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.261002589713039, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.318989910226595, 0.9477581111093846, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1824858594920125`, 2.9657044306250255`, 0.},
       Optica`Optica`RayEnd :> {3.0835451215110132`, 3.193820375821446, 0.}, 
      RotationMatrix :> {{-0.397913825914371, 0.9174227962865253, 
       0.}, {-0.9174227962865253, -0.397913825914371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04155156283495627, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2486486559084547, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.160191853935363`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1330203559274653, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.397913825914371, 0.9174227962865253, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.044827874469686, 2.678623059659469, 0.}, 
      Optica`Optica`RayEnd :> {3.9333640797218736`, 2.8352853936772213`, 0.}, 
      RotationMatrix :> {{-0.5797291888964751, 0.8148092215613627, 
       0.}, {-0.8148092215613627, -0.5797291888964751, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04811946526786577, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19226872974946352`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.005521236239783`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3158075292072025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5797291888964751, 0.8148092215613627, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9333640797218736`, 2.8352853936772213`, 0.},
       Optica`Optica`RayEnd :> {3.830651011562688, 3.011017350880267, 0.}, 
      RotationMatrix :> {{-0.5046140646140347, 0.8633450328771816, 
       0.}, {-0.8633450328771816, -0.5046140646140347, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.047731239538056386`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20354777118181985`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.306771937588877`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17280590742657184`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5046140646140347, 0.8633450328771816, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.918979408019427, 0.4432405576931465, 0.}, 
      Optica`Optica`RayEnd :> {2.5876291796852042`, 0.4157227093399586, 0.}, 
      RotationMatrix :> {{-0.996569282123331, -0.08276270856000137, 0.}, {
       0.08276270856000137, -0.996569282123331, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012495993248684466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3324909108458916, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.678518486805075`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10688051352353245`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.996569282123331, -0.08276270856000137, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5876291796852042`, 0.4157227093399586, 0.}, 
      Optica`Optica`RayEnd :> {2.363445515092777, 0.42283839082818514`, 0.}, 
      RotationMatrix :> {{-0.9994966534700039, 0.03172443383674241, 
       0.}, {-0.03172443383674241, -0.9994966534700039, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012329205797224829`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2242965634893494, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.01047740076931, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3474621672767122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9994966534700039, 0.03172443383674241, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.630191771136144, 3.308284194420784, 0.}, 
      Optica`Optica`RayEnd :> {4.528763188868726, 3.3871844873446237`, 0.}, 
      RotationMatrix :> {{-0.7893092398961589, 0.6139958662845758, 
       0.}, {-0.6139958662845758, -0.7893092398961589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18425249168486746`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1285029708771212, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.47359995078159, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2965147147573379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7893092398961589, 0.6139958662845758, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.528763188868726, 3.3871844873446237`, 0.}, 
      Optica`Optica`RayEnd :> {4.395953481947561, 3.52396953458935, 0.}, 
      RotationMatrix :> {{-0.6966043288416454, 0.7174555101461549, 
       0.}, {-0.7174555101461549, -0.6966043288416454, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18029339692309035`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1906530026048044, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.7557663946367, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04081862575431711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6966043288416454, 0.7174555101461549, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.583154901338565, 0.8752202076403494, 0.}, 
      Optica`Optica`RayEnd :> {7.630096466793213, 0.8152795720390332, 0.}, 
      RotationMatrix :> {{0.6165648410338225, -0.7873041323408229, 0.}, {
       0.7873041323408229, 0.6165648410338225, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03214032904047513, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07613402894647564, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.33474728290081, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16986278555773598`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6165648410338225, -0.7873041323408229, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.630096466793213, 0.8152795720390332, 0.}, 
      Optica`Optica`RayEnd :> {7.825791340319894, 0.5933320850040109, 0.}, 
      RotationMatrix :> {{0.6613533985442243, -0.7500744511273552, 0.}, {
       0.7500744511273552, 0.6613533985442243, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.031997405606215196`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2959006092014427, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.772680184518947`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14896652648729372`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6613533985442243, -0.7500744511273552, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.915310280175682, 0.8725376930146247, 0.}, 
      Optica`Optica`RayEnd :> {7.006439621925628, 0.6147688300325258, 0.}, 
      RotationMatrix :> {{0.33331475673094735`, -0.9428156091969355, 0.}, {
       0.9428156091969355, 0.33331475673094735`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01266542796386836, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2734032619609037, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.725162892649504`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23234195069737817`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33331475673094735`, -0.9428156091969355, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.006439621925628, 0.6147688300325258, 0.}, 
      Optica`Optica`RayEnd :> {7.096466395184083, 0.3260823219419739, 0.}, 
      RotationMatrix :> {{0.297709276667724, -0.9546565804444967, 0.}, {
       0.9546565804444967, 0.297709276667724, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012624684158436088`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3023982801816929, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.17271234731841, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.060504782285835654`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.297709276667724, -0.9546565804444967, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.405927012198225, 2.3787519570622178`, 0.}, 
      Optica`Optica`RayEnd :> {5.334621434201527, 2.3706567906970477`, 0.}, 
      RotationMatrix :> {{-0.9936173493343103, -0.11280320519319283`, 0.}, {
       0.11280320519319283`, -0.9936173493343103, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018713392176377876`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07176362011439326, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.45472758588146, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.029057688168084767`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9936173493343103, -0.11280320519319283`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.334621434201527, 2.3706567906970477`, 0.}, 
      Optica`Optica`RayEnd :> {5.098600632748835, 2.3179016869850884`, 0.}, 
      RotationMatrix :> {{-0.975918342820759, -0.21813616881659476`, 0.}, {
       0.21813616881659476`, -0.975918342820759, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018499332020293288`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24184482563418805`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.81265792782006, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2610199782890495, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.975918342820759, -0.21813616881659476`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.8855943003165185`, 3.2448708046005024`, 0.},
       Optica`Optica`RayEnd :> {8.080559990141701, 3.272152460207569, 0.}, 
      RotationMatrix :> {{0.9903511888766862, 0.13858038349829246`, 
       0.}, {-0.13858038349829246`, 0.9903511888766862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07740527430003738, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19686520500502802`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.222461730842067`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11356562525633869`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9903511888766862, 0.13858038349829246`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.080559990141701, 3.272152460207569, 0.}, 
      Optica`Optica`RayEnd :> {8.370476193877607, 3.3020565011722733`, 0.}, 
      RotationMatrix :> {{0.9947224043468047, 0.10260281814117737`, 
       0.}, {-0.10260281814117737`, 0.9947224043468047, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07716041610470682, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2914543821160678, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.653814216373846`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28745707745835636`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9947224043468047, 0.10260281814117737`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.686899135231831, 3.1787974319452377`, 0.}, 
      Optica`Optica`RayEnd :> {6.59454673071253, 3.0984915207788184`, 0.}, 
      RotationMatrix :> {{-0.7546076565578103, -0.6561762603632721, 0.}, {
       0.6561762603632721, -0.7546076565578103, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010894700652459226`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12238466402603518`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.30440606688056, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08573780341429345, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7546076565578103, -0.6561762603632721, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.59454673071253, 3.0984915207788184`, 0.}, 
      Optica`Optica`RayEnd :> {6.352822588729898, 2.881774653529568, 0.}, 
      RotationMatrix :> {{-0.7445714753446027, -0.6675427462740949, 0.}, {
       0.6675427462740949, -0.7445714753446027, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010866584956333542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3246486737498994, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.78488610403041, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27690663664476406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7445714753446027, -0.6675427462740949, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.146594245946951, 3.101302362746748, 0.}, 
      Optica`Optica`RayEnd :> {7.277212258579763, 2.893757354530947, 0.}, 
      RotationMatrix :> {{0.5326425030401796, -0.8463403357722536, 0.}, {
       0.8463403357722536, 0.5326425030401796, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010539695268388717`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24522641713209106`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.26604599330736, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05924935674544442, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5326425030401796, -0.8463403357722536, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.277212258579763, 2.893757354530947, 0.}, 
      Optica`Optica`RayEnd :> {7.35450132886719, 2.727795098489933, 0.}, 
      RotationMatrix :> {{0.4221677508163196, -0.9065177274442506, 0.}, {
       0.9065177274442506, 0.4221677508163196, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010363912059326562`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18307668015374873`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.536999479934906`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.341876255409508, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.4221677508163196, -0.9065177274442506, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.083933215616448, 3.682061863205232, 0.}, 
      Optica`Optica`RayEnd :> {5.955770445167616, 3.749961683916154, 0.}, 
      RotationMatrix :> {{-0.8836483394894041, 0.4681512705500406, 
       0.}, {-0.4681512705500406, -0.8836483394894041, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07415380171335308, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14503820662741046`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.172700787203244`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41558839112671864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8836483394894041, 0.4681512705500406, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.955770445167616, 3.749961683916154, 0.}, 
      Optica`Optica`RayEnd :> {5.6634007260393116`, 3.889464890278438, 0.}, 
      RotationMatrix :> {{-0.9025252960797181, 0.4306368422885063, 
       0.}, {-0.4306368422885063, -0.9025252960797181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07389998680337813, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3239462875979925, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.652141292848274`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3670769943273006, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9025252960797181, 0.4306368422885063, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.341081509098933, 1.9555372819863597`, 0.}, 
      Optica`Optica`RayEnd :> {7.344366407822268, 1.8424170849010477`, 0.}, 
      RotationMatrix :> {{0.0290267756292118, -0.9995786343737896, 0.}, {
       0.9995786343737896, 0.0290267756292118, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013164105739109632`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11316788214083712`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 16.841395963622567`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08910656867066244, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0290267756292118, -0.9995786343737896, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.344366407822268, 1.8424170849010477`, 0.}, 
      Optica`Optica`RayEnd :> {7.372508919400013, 1.6226560092947893`, 0.}, 
      RotationMatrix :> {{0.1270222823745124, -0.9918998637868484, 0.}, {
       0.9918998637868484, 0.1270222823745124, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013037210331737627`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2215557070118554, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.138280611018452`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21020763131723297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1270222823745124, -0.9918998637868484, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.933471172038791, 2.0451250526433418`, 0.}, 
      Optica`Optica`RayEnd :> {4.698023718464621, 1.9885595114614367`, 0.}, 
      RotationMatrix :> {{-0.9723327778135763, -0.23360001966894872`, 0.}, {
       0.23360001966894872`, -0.9723327778135763, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0109082292690101, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24214698809558383`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.4647845238103, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40758716889535074`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9723327778135763, -0.23360001966894872`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.698023718464621, 1.9885595114614365`, 0.}, 
      Optica`Optica`RayEnd :> {4.385537894137745, 1.9179248820281938`, 0.}, 
      RotationMatrix :> {{-0.9753918105496805, -0.22047860647376866`, 0.}, {
       0.22047860647376866`, -0.9753918105496805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010880347429740273`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32036953862753303`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.93893144097905, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17165687274849073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9753918105496805, -0.22047860647376866`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.372429286979578, 2.9644152224685603`, 0.}, 
      Optica`Optica`RayEnd :> {3.9123037629453368`, 3.1528852667350202`, 0.}, 
      RotationMatrix :> {{-0.9253799185733668, 0.37904090320326694`, 
       0.}, {-0.37904090320326694`, -0.9253799185733668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03211787229650239, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.49722877576985286`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.8736047858702, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1733385228829717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9253799185733668, 0.37904090320326694`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9123037629453368`, 3.1528852667350202`, 0.},
       Optica`Optica`RayEnd :> {3.613683131266335, 3.285649020901551, 0.}, 
      RotationMatrix :> {{-0.9137621713212519, 0.4062495467840799, 
       0.}, {-0.4062495467840799, -0.9137621713212519, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03202407014881213, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32680345176383474`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.357273894480674`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07151407488869597, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9137621713212519, 0.4062495467840799, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.110370663361457, -0.32787980772381814`, 0.},
       Optica`Optica`RayEnd :> {4.064677983430684, -0.3666837619941653, 0.}, 
      RotationMatrix :> {{-0.7622259059090589, -0.6473111063168259, 0.}, {
       0.6473111063168259, -0.7622259059090589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012393827991384323`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0599463749218518, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.241661524504448`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03556835759380125, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.7622259059090589, -0.6473111063168259, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.064677983430684, -0.3666837619941653, 0.}, 
      Optica`Optica`RayEnd :> {3.8437336950449588`, -0.5645446446200453, 0.}, 
      RotationMatrix :> {{-0.7449499008220651, -0.6671204128680173, 0.}, {
       0.6671204128680173, -0.7449499008220651, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012358861385522885`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2965894594279557, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.680613924457823`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23295928892487966`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7449499008220651, -0.6671204128680173, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.379458000813778, 1.6251160758509406`, 0.}, 
      Optica`Optica`RayEnd :> {2.326056895709007, 1.6408456934842706`, 0.}, 
      RotationMatrix :> {{-0.9592515880289835, 0.28255334162573903`, 
       0.}, {-0.28255334162573903`, -0.9592515880289835, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.080913157032625, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05566955089904688, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.134692389201103`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.121037072191267, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9592515880289835, 0.28255334162573903`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.326056895709007, 1.6408456934842706`, 0.}, 
      Optica`Optica`RayEnd :> {2.1664863383255795`, 1.7124017880902116`, 0.}, 
      RotationMatrix :> {{-0.9124570975934192, 0.4091723903825767, 
       0.}, {-0.4091723903825767, -0.9124570975934192, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07930040003714685, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1748800659278012, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.39351488677425, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21685531750188353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9124570975934192, 0.4091723903825767, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.608146945359943, 3.6724081726290074`, 0.}, 
      Optica`Optica`RayEnd :> {4.6303386272555365`, 3.744375749694504, 0.}, 
      RotationMatrix :> {{0.29466574608085605`, 0.955600386190071, 
       0.}, {-0.955600386190071, 0.29466574608085605`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008416790693823655, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07531137293950635, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.03373876725349, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06673016614274432, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 103, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.29466574608085605`, 0.955600386190071, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.360907336975386, 3.524693212670782, 0.}, 
      Optica`Optica`RayEnd :> {3.304799005122269, 3.6423960631976082`, 0.}, 
      RotationMatrix :> {{-0.4303046093344581, 0.9026837448328842, 
       0.}, {-0.9026837448328842, -0.4303046093344581, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008736937931124794, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13039212370952444`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.20789664491916, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06323292578893362, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4303046093344581, 0.9026837448328842, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.304799005122269, 3.6423960631976082`, 0.}, 
      Optica`Optica`RayEnd :> {3.1688661246212564`, 3.9136726985842807`, 0.}, 
      RotationMatrix :> {{-0.44799005259810437`, 0.894038540988669, 
       0.}, {-0.894038540988669, -0.44799005259810437`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008713682529030067, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30342834559087617`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.656970596393656`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35945272881703105`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.44799005259810437`, 0.894038540988669, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.577113124496869, 2.7190939695865692`, 0.}, 
      Optica`Optica`RayEnd :> {2.3044227199070897`, 2.8599001531862447`, 0.}, 
      RotationMatrix :> {{-0.8885373119752599, 0.45880436487437676`, 
       0.}, {-0.45880436487437676`, -0.8885373119752599, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2177813478003957, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30689809073248275`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.464329830412815`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1882381531880209, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8885373119752599, 0.45880436487437676`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3044227199070897`, 2.8599001531862447`, 0.},
       Optica`Optica`RayEnd :> {2.1626895965014343`, 2.9042839244054353`, 0.},
       RotationMatrix :> {{-0.9543031299420431, 0.29884031887083173`, 
       0.}, {-0.29884031887083173`, -0.9543031299420431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20907787479473, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1485200236263115, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.684139465379758`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.367691922148825, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9543031299420431, 0.29884031887083173`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1626895965014343`, 2.9042839244054353`, 0.},
       Optica`Optica`RayEnd :> {2.0713890407219795`, 2.787141251001066, 0.}, 
      RotationMatrix :> {{-0.614735666950704, -0.7887331993638111, 0.}, {
       0.7887331993638111, -0.614735666950704, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008355645043696427, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14852002362631156`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.9039491003467, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.027955120783770167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 105, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.614735666950704, -0.7887331993638111, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9275913020691573`, 0.8424886120484518, 0.}, 
      Optica`Optica`RayEnd :> {2.906504493089363, 0.790802834633577, 0.}, 
      RotationMatrix :> {{-0.377752237363337, -0.9259067162338724, 0.}, {
       0.9259067162338724, -0.377752237363337, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012654182590593201`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05582179771317225, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.854396188982925`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2782332252722311, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.377752237363337, -0.9259067162338724, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.906504493089363, 0.790802834633577, 0.}, 
      Optica`Optica`RayEnd :> {2.7875435276326748`, 0.5557776983030938, 0.}, 
      RotationMatrix :> {{-0.4516069835327995, -0.8922169760906847, 0.}, {
       0.8922169760906847, -0.4516069835327995, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012567539497110194`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2634170192101291, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.244253377413916`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1700411359257293, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4516069835327995, -0.8922169760906847, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9713169457996758`, 0.8222603747779084, 0.}, 
      Optica`Optica`RayEnd :> {2.9206628938257806`, 0.7481077742418967, 0.}, 
      RotationMatrix :> {{-0.5640622730717434, -0.825732252063063, 0.}, {
       0.825732252063063, -0.5640622730717434, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008103684190499815, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08980223353362311, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.39201501969746, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38017714005443976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5640622730717434, -0.825732252063063, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9206628938257806`, 0.7481077742418967, 0.}, 
      Optica`Optica`RayEnd :> {2.7596905406228465`, 0.5532177507000103, 0.}, 
      RotationMatrix :> {{-0.6368255909716009, -0.7710078901565607, 0.}, {
       0.7710078901565607, -0.6368255909716009, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008036156829238536, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25277305982214, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.766119148234228`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2470892452441294, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6368255909716009, -0.7710078901565607, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3865127223489795`, -3.5668852488817966`, 
       0.}, Optica`Optica`RayEnd :> {2.3275229689816683`, -3.594540250413836, 
       0.}, RotationMatrix :> {{-0.9054379668698006, -0.42447860741229515`, 
       0.}, {0.42447860741229515`, -0.9054379668698006, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011917883271790598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0651505188933541, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.987527614047323`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13139206371632955`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9054379668698006, -0.42447860741229515`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3275229689816683`, -3.594540250413836, 0.}, 
      Optica`Optica`RayEnd :> {2.057599674808473, -3.732319033051137, 0.}, 
      RotationMatrix :> {{-0.8906779434447962, -0.4546347996589658, 0.}, {
       0.4546347996589658, -0.8906779434447962, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011881426859347045`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30305375378359223`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.43604716964704, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08095868586914129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8906779434447962, -0.4546347996589658, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.166293012942752, 3.0086036193514536`, 0.}, 
      Optica`Optica`RayEnd :> {7.375858465854501, 3.0204314211510552`, 0.}, 
      RotationMatrix :> {{0.9984110777385308, 0.05634997647723504, 
       0.}, {-0.05634997647723504, 0.9984110777385308, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011531378926044368`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2098989660515668, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.012216830093045`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22158658304988846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9984110777385308, 0.05634997647723504, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.375858465854501, 3.0204314211510552`, 0.}, 
      Optica`Optica`RayEnd :> {7.63197961151276, 3.0213397653388454`, 0.}, 
      RotationMatrix :> {{0.9999937110821879, 0.003546518866896553, 
       0.}, {-0.003546518866896553, 0.9999937110821879, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01148464108005055, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2561227563932238, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.391278509555015`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27441716945061084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 104, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9999937110821879, 0.003546518866896553, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.294542797162495, -1.712435348389325, 0.}, 
      Optica`Optica`RayEnd :> {6.574341747354627, -1.7460994912691292`, 0.}, 
      RotationMatrix :> {{0.9928397383975927, -0.11945398217975066`, 0.}, {
       0.11945398217975066`, 0.9928397383975927, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008091794898757283, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.281816832436338, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.114408453454022`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00809880085283897, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9928397383975927, -0.11945398217975066`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.574341747354627, -1.7460994912691292`, 0.}, 
      Optica`Optica`RayEnd :> {6.852640212802115, -1.7759387147053527`, 0.}, 
      RotationMatrix :> {{0.9943010026269105, -0.1066091749106095, 0.}, {
       0.1066091749106095, 0.9943010026269105, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008071171132543742, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2798935782144769, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.528650949211446`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3646762144011254, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9943010026269105, -0.1066091749106095, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2762663904675184`, 3.0759686155040873`, 0.},
       Optica`Optica`RayEnd :> {2.155549579335169, 3.0016635362683948`, 0.}, 
      RotationMatrix :> {{-0.8516022288570628, -0.5241885574921326, 0.}, {
       0.5241885574921326, -0.8516022288570628, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010116419670241383`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14175257771972233`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.878826972334046`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3713297385691143, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8516022288570628, -0.5241885574921326, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.155549579335169, 3.0016635362683948`, 0.}, 
      Optica`Optica`RayEnd :> {1.939751687198152, 2.8785860260273344`, 0.}, 
      RotationMatrix :> {{-0.8686513221746648, -0.4954239401605525, 0.}, {
       0.4954239401605525, -0.8686513221746648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010085525454068142`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24842866939610228`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.246501403040277`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36777597843138315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8686513221746648, -0.4954239401605525, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1829895557969965`, 3.368145414678848, 0.}, 
      Optica`Optica`RayEnd :> {2.3023266289224917`, 3.587895943765453, 0.}, 
      RotationMatrix :> {{0.47722754227161457`, 0.8787797635911938, 
       0.}, {-0.8787797635911938, 0.47722754227161457`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009574851113911351, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2500632561093346, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.596347315851297`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013875246829043734`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.47722754227161457`, 0.8787797635911938, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3023266289224917`, 3.587895943765453, 0.}, 
      Optica`Optica`RayEnd :> {2.3669117145038703`, 3.764223584864702, 0.}, 
      RotationMatrix :> {{0.3439336281848025, 0.938993961324373, 
       0.}, {-0.938993961324373, 0.3439336281848025, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009338512798426355, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18778357301739523`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.87426700391704, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33341985661248136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3439336281848025, 0.938993961324373, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.874329786784559, 3.224916746452884, 0.}, 
      Optica`Optica`RayEnd :> {7.066713849244671, 3.3448531121491145`, 0.}, 
      RotationMatrix :> {{0.8485997763269044, 0.5290353670766516, 
       0.}, {-0.5290353670766516, 0.8485997763269044, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008425936901320234, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22670765162445747`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.629995226750882`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2552509934552784, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8485997763269044, 0.5290353670766516, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.066713849244671, 3.3448531121491145`, 0.}, 
      Optica`Optica`RayEnd :> {7.253210388579181, 3.423351419153272, 0.}, 
      RotationMatrix :> {{0.9216822990790403, 0.38794553685327304`, 
       0.}, {-0.38794553685327304`, 0.9216822990790403, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008163537134455279, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20234362699691702`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.92946379470632, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14075814548772397`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9216822990790403, 0.38794553685327304`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.38258625282617, -0.8872404335930295, 0.}, 
      Optica`Optica`RayEnd :> {2.1419537588121385`, -0.9426588754758249, 0.}, 
      RotationMatrix :> {{-0.9744905959312655, -0.22442833698427472`, 0.}, {
       0.22442833698427472`, -0.9744905959312655, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01895526476221411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24693157124217574`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.070970395201986`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30270019387446273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9744905959312655, -0.22442833698427472`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1419537588121385`, -0.9426588754758249, 0.},
       Optica`Optica`RayEnd :> {1.7735416284485892`, -1.0338422441077806`, 
       0.}, RotationMatrix :> {{-0.9707099782257054, -0.2402543197802087, 
       0.}, {0.2402543197802087, -0.9707099782257054, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018906009797879823`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3795285292492251, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.63267261849084, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04410606867567773, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9707099782257054, -0.2402543197802087, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.930327422316176, -1.9106077982607501`, 0.}, 
      Optica`Optica`RayEnd :> {5.66751611441676, -1.9525769503209212`, 0.}, 
      RotationMatrix :> {{-0.9874878671997882, -0.15769499717243246`, 0.}, {
       0.15769499717243246`, -0.9874878671997882, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01987348137823251, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2661413032290399, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.386879770294218`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42196980324362976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9874878671997882, -0.15769499717243246`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.66751611441676, -1.9525769503209212`, 0.}, 
      Optica`Optica`RayEnd :> {5.333169237688875, -2.0022077378949565`, 0.}, 
      RotationMatrix :> {{-0.9891614269649492, -0.1468321197989915, 0.}, {
       0.1468321197989915, -0.9891614269649492, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019823295162250266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3380104274322174, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.8871352028939, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12472760010314288`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9891614269649492, -0.1468321197989915, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.069476274145186, -3.3210102154751135`, 0.}, 
      Optica`Optica`RayEnd :> {7.05875444315332, -3.3553768685733916`, 0.}, 
      RotationMatrix :> {{-0.2978258230048031, -0.9546202277091718, 0.}, {
       0.9546202277091718, -0.2978258230048031, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03869803427452041, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03600034034555122, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.301219523992593`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16152647344256182`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.2978258230048031, -0.9546202277091718, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.05875444315332, -3.3553768685733916`, 0.}, 
      Optica`Optica`RayEnd :> {6.965978042793, -3.6638144368616565`, 0.}, 
      RotationMatrix :> {{-0.2880460321741571, -0.9576165638441744, 0.}, {
       0.9576165638441744, -0.2880460321741571, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03860062655474068, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3220887983078523, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.777910945488216`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39577008637556166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.2880460321741571, -0.9576165638441744, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.6658613148600745`, -2.290693316004209, 0.}, 
      Optica`Optica`RayEnd :> {6.603155983884158, -2.2910182688181258`, 0.}, 
      RotationMatrix :> {{-0.9999865725689109, -0.005182150314458081, 0.}, {
       0.005182150314458081, -0.9999865725689109, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015338657633684406`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06270617295873251, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.53158149935274, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09185231604268562, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999865725689109, -0.005182150314458081, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.603155983884158, -2.2910182688181258`, 0.}, 
      Optica`Optica`RayEnd :> {6.426423131981197, -2.3289619051770183`, 0.}, 
      RotationMatrix :> {{-0.9777203802288598, -0.20991154824147568`, 0.}, {
       0.20991154824147568`, -0.9777203802288598, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014280252355921732`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1807601186155008, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.79910647490368, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3617926081104624, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9777203802288598, -0.20991154824147568`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.905259287943307, -0.9688719174246986, 0.}, 
      Optica`Optica`RayEnd :> {7.915357255053708, -0.671240002641347, 0.}, 
      RotationMatrix :> {{0.033908192610710736`, 0.9994249518967767, 
       0.}, {-0.9994249518967767, 0.033908192610710736`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013438347927123846`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2978031659290529, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.410422739722172`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.348545593455585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.033908192610710736`, 0.9994249518967767, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.915357255053708, -0.671240002641347, 0.}, 
      Optica`Optica`RayEnd :> {7.930958569340212, -0.3847901262935921, 0.}, 
      RotationMatrix :> {{0.0543837763711063, 0.998520107392744, 
       0.}, {-0.998520107392744, 0.0543837763711063, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013402351513102574`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2868744196806511, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.834996880849534`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3075493693714524, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.0543837763711063, 0.998520107392744, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.960741327726372, 0.18163303324655294`, 0.}, 
      Optica`Optica`RayEnd :> {5.66440582370264, 0.4679941414438552, 0.}, 
      RotationMatrix :> {{-0.7191054403372897, 0.6949009754470865, 
       0.}, {-0.6949009754470865, -0.7191054403372897, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013103281701318744`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4120890865249725, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.490226662542593`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36579502642407863`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7191054403372897, 0.6949009754470865, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.66440582370264, 0.4679941414438552, 0.}, 
      Optica`Optica`RayEnd :> {5.427593108847438, 0.6724781669937853, 0.}, 
      RotationMatrix :> {{-0.7568799954786049, 0.6535538787615807, 
       0.}, {-0.6535538787615807, -0.7568799954786049, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013047235194754725`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31288013459182096`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.953289261738487`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39054216872140696`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7568799954786049, 0.6535538787615807, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.844581130049851, -0.5661312995344663, 0.}, 
      Optica`Optica`RayEnd :> {3.675606847818308, -0.4607875571318453, 0.}, 
      RotationMatrix :> {{-0.8485963096295119, 0.5290409277959249, 
       0.}, {-0.5290409277959249, -0.8485963096295119, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01811598901200094, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19912210354216067`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.383249050917605`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2857984944017683, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8485963096295119, 0.5290409277959249, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.675606847818308, -0.4607875571318453, 0.}, 
      Optica`Optica`RayEnd :> {3.4805411901108987`, -0.372600169719215, 0.}, 
      RotationMatrix :> {{-0.9112071854386372, 0.41194837686899155`, 
       0.}, {-0.41194837686899155`, -0.9112071854386372, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017769936436893032`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21407388004025518`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.700078393377183`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3609229264811985, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9112071854386372, 0.41194837686899155`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8796782695141685`, -3.08245491405061, 0.}, 
      Optica`Optica`RayEnd :> {4.8505075852022514`, -3.1287419660385773`, 0.},
       RotationMatrix :> {{-0.533166420215159, -0.8460103831247893, 0.}, {
       0.8460103831247893, -0.533166420215159, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09156850539345801, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.054712155915868775`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.733216554466306`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.011813668357485988`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.533166420215159, -0.8460103831247893, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8505075852022514`, -3.1287419660385773`, 
       0.}, Optica`Optica`RayEnd :> {4.676768144014921, -3.4053014779424857`, 
       0.}, RotationMatrix :> {{-0.5319565231228804, -0.8467716678698082, 
       0.}, {0.8467716678698082, -0.5319565231228804, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09134272639066464, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32660458822345667`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.21659134503702, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4197074364069751, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5319565231228804, -0.8467716678698082, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1309275385333617`, 0.13802487590127688`, 
       0.}, Optica`Optica`RayEnd :> {2.9088502337360813`, 
       0.20410577926362702`, 0.}, 
      RotationMatrix :> {{-0.9584680451368133, 0.2851999411844535, 
       0.}, {-0.2851999411844535, -0.9584680451368133, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010472798878679407`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23170026995065957`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.80953174933965, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37172339107988556`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9584680451368133, 0.2851999411844535, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9088502337360813`, 0.20410577926362702`, 
       0.}, Optica`Optica`RayEnd :> {2.568817617378096, 0.3024773324586582, 
       0.}, RotationMatrix :> {{-0.9606087260561901, 0.27790443577730783`, 
       0.}, {-0.27790443577730783`, -0.9606087260561901, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010446684103274234`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3539761894043998, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.333416509658164`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17343681739067493`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9606087260561901, 0.27790443577730783`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.891693862377186, 3.3137983546813343`, 0.}, 
      Optica`Optica`RayEnd :> {6.900480009785586, 3.357864598318122, 0.}, 
      RotationMatrix :> {{0.19553615734683383`, 0.9806964928916763, 
       0.}, {-0.9806964928916763, 0.19553615734683383`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0080922700056281, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04493362009162912, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.36026016038746, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3931903451350043, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.19553615734683383`, 0.9806964928916763, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.900480009785586, 3.357864598318122, 0.}, 
      Optica`Optica`RayEnd :> {6.957214733053927, 3.6183783225821378`, 0.}, 
      RotationMatrix :> {{0.21279244352007798`, 0.9770974239965807, 
       0.}, {-0.9770974239965807, 0.21279244352007798`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008071051389010852, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2666200092908312, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.75485777413789, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22914223079130422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.21279244352007798`, 0.9770974239965807, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.182742657092213, -2.311972613455932, 0.}, 
      Optica`Optica`RayEnd :> {3.129136823338847, -2.408480019606195, 0.}, 
      RotationMatrix :> {{-0.4855779200362494, -0.8741933902594264, 0.}, {
       0.8741933902594264, -0.4855779200362494, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.037864145283075586`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11039594582341014`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.137687535282005`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2733035216702759, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4855779200362494, -0.8741933902594264, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.129136823338847, -2.408480019606195, 0.}, 
      Optica`Optica`RayEnd :> {2.9681142684318607`, -2.6598401862157806`, 0.},
       RotationMatrix :> {{-0.5394149917009823, -0.8420400624247217, 0.}, {
       0.8420400624247217, -0.5394149917009823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03768178656136339, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29851331050184665`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.57948723482474, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.266091685434798, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5394149917009823, -0.8420400624247217, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.875281126091442, -4.37143559027782, 0.}, 
      Optica`Optica`RayEnd :> {5.883357522681043, -4.39835420285686, 0.}, 
      RotationMatrix :> {{0.28737441905475214`, -0.9578183247740369, 0.}, {
       0.9578183247740369, 0.28737441905475214`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015574130924479852`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.028104090183688618`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.707092814298182`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4027598226098324, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.28737441905475214`, -0.9578183247740369, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.883357522681043, -4.39835420285686, 0.}, 
      Optica`Optica`RayEnd :> {5.988617948777935, -4.710701163914752, 0.}, 
      RotationMatrix :> {{0.31935188425828565`, -0.9476362034138847, 0.}, {
       0.9476362034138847, 0.31935188425828565`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015526499000413602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32960640373663924`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.194910291828407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2431071566866736, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.31935188425828565`, -0.9476362034138847, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.897226245942283, -2.319820684585405, 0.}, 
      Optica`Optica`RayEnd :> {7.91112926995619, -2.329652284028459, 0.}, 
      RotationMatrix :> {{0.8164778416445574, -0.5773767696257319, 0.}, {
       0.5773767696257319, 0.8164778416445574, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011530870194514922`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.017028048165891495`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.28110548487912, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41320691833686696`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8164778416445574, -0.5773767696257319, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.91112926995619, -2.329652284028459, 0.}, 
      Optica`Optica`RayEnd :> {8.12604817160651, -2.498956565176562, 0.}, 
      RotationMatrix :> {{0.7855374446359147, -0.6188141264344872, 0.}, {
       0.6188141264344872, 0.7855374446359147, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011484988558032566`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27359472564663195`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.686025678836135`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3704534669430535, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7855374446359147, -0.6188141264344872, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.150433843677726, -3.3987902081105528`, 0.}, 
      Optica`Optica`RayEnd :> {7.147521702715067, -3.405654255286705, 0.}, 
      RotationMatrix :> {{-0.3905635937111233, -0.9205759497550715, 0.}, {
       0.9205759497550715, -0.3905635937111233, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12167549458642282`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0074562529881195124`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.11703611371116, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15369247795974417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3905635937111233, -0.9205759497550715, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.147521702715067, -3.405654255286705, 0.}, 
      Optica`Optica`RayEnd :> {7.018810165197388, -3.6757171600667142`, 0.}, 
      RotationMatrix :> {{-0.43023370064809774`, -0.9027175432141785, 0.}, {
       0.9027175432141785, -0.43023370064809774`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12124974700989788`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29916656301863176`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.559802626978733`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27278100877848455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.43023370064809774`, -0.9027175432141785, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.850770231733905, 3.0919020319561095`, 0.}, 
      Optica`Optica`RayEnd :> {7.84782261656146, 3.157509579376103, 0.}, 
      RotationMatrix :> {{-0.04488271346979933, 0.9989922632491144, 
       0.}, {-0.9989922632491144, -0.04488271346979933, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03628476891038316, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06567372925052722, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.850878170418266`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1596358907850144, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.04488271346979933, 0.9989922632491144, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.84782261656146, 3.157509579376103, 0.}, 
      Optica`Optica`RayEnd :> {7.815550438724145, 3.3888616835434866`, 0.}, 
      RotationMatrix :> {{-0.13815609264931433`, 0.9904104674648154, 
       0.}, {-0.9904104674648154, -0.13815609264931433`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03596607957172944, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.233592143628674, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.196594542988702`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02387198622571368, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13815609264931433`, 0.9904104674648154, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.200021876269678, -0.9119070393901738, 0.}, 
      Optica`Optica`RayEnd :> {4.136410550081083, -0.9101697603019961, 0.}, 
      RotationMatrix :> {{-0.9996272673628381, 0.027300665645813932`, 
       0.}, {-0.027300665645813932`, -0.9996272673628381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013925524252307543`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06363504504675131, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.522281616043053`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19148581895349887`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9996272673628381, 0.027300665645813932`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.136410550081083, -0.9101697603019961, 0.}, 
      Optica`Optica`RayEnd :> {3.872301017939595, -0.9226557924440155, 0.}, 
      RotationMatrix :> {{-0.9988843614748387, -0.04722321887592411, 0.}, {
       0.04722321887592411, -0.9988843614748387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013841783394522045`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2644045120013029, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.91360029380498, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26546808413336664`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9988843614748387, -0.04722321887592411, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.838998481869474, -2.3971098311794203`, 0.}, 
      Optica`Optica`RayEnd :> {6.66306013011406, -2.6212220089192915`, 0.}, 
      RotationMatrix :> {{-0.6174964511576694, -0.7865736664850174, 0.}, {
       0.7865736664850174, -0.6174964511576694, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02586997819043141, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2849220451802905, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.920963445880087`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41838694045389846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.6174964511576694, -0.7865736664850174, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.66306013011406, -2.6212220089192915`, 0.}, 
      Optica`Optica`RayEnd :> {6.575543885995159, -2.7837733642724407`, 0.}, 
      RotationMatrix :> {{-0.47405191455560786`, -0.880496895114436, 0.}, {
       0.880496895114436, -0.47405191455560786`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024862725998632637`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1846132067643726, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.194190991891357`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.057500844261770004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.47405191455560786`, -0.880496895114436, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.860468037503002, -2.5452454429729006`, 0.}, 
      Optica`Optica`RayEnd :> {6.964529303640744, -2.809863803943051, 0.}, 
      RotationMatrix :> {{0.36596936437717137`, -0.9306268985675025, 0.}, {
       0.9306268985675025, 0.36596936437717137`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21005105212109818`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28434419999838, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.141720471725915`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30358636799490524`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36596936437717137`, -0.9306268985675025, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.964529303640744, -2.809863803943051, 0.}, 
      Optica`Optica`RayEnd :> {7.072749319436245, -3.105403635144691, 0.}, 
      RotationMatrix :> {{0.34384965636123105`, -0.9390247141690482, 0.}, {
       0.9390247141690482, 0.34384965636123105`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20947303678310183`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3147306207623793, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.607521790454236`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02475459467436472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.34384965636123105`, -0.9390247141690482, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.999102128718822, -2.6016873604925377`, 0.}, 
      Optica`Optica`RayEnd :> {7.261874385091049, -2.6429865621305675`, 0.}, 
      RotationMatrix :> {{0.9878734246662967, -0.15526138231408942`, 0.}, {
       0.15526138231408942`, 0.9878734246662967, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020963832933877245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26599789994451156`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.338667768043315`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3288078804027443, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9878734246662967, -0.15526138231408942`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.261874385091049, -2.6429865621305675`, 0.}, 
      Optica`Optica`RayEnd :> {7.410905318833086, -2.699039979861575, 0.}, 
      RotationMatrix :> {{0.9359842801040459, -0.3520417977997926, 0.}, {
       0.3520417977997926, 0.9359842801040459, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0195717957129455, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15922375718262038`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.574318928673595`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19007353450983422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9359842801040459, -0.3520417977997926, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.185536517567847, -1.4233285737793353`, 0.}, 
      Optica`Optica`RayEnd :> {7.136704245799847, -1.693602331480489, 0.}, 
      RotationMatrix :> {{-0.17779833635601422`, -0.9840669446684167, 0.}, {
       0.9840669446684167, -0.17779833635601422`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02442742087152347, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2746497676458617, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.48806115823422, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3499366672850245, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.17779833635601422`, -0.9840669446684167, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.136704245799847, -1.693602331480489, 0.}, 
      Optica`Optica`RayEnd :> {7.1268187889837655`, -1.8870016953381006`, 0.},
       RotationMatrix :> {{-0.051047574224750536`, -0.9986962226652144, 0.}, {
       0.9986962226652144, -0.051047574224750536`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024005506395813808`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19365184274101657`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.774665885490926`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31169884021107686`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.051047574224750536`, -0.9986962226652144, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.589911053871509, 1.723989415994277, 0.}, 
      Optica`Optica`RayEnd :> {5.333991827929522, 2.0890188684700233`, 0.}, 
      RotationMatrix :> {{-0.5740622815766303, 0.818811636990482, 
       0.}, {-0.818811636990482, -0.5740622815766303, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008590964470150397, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.44580393827498743`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.279726706888642`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02682567051861831, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5740622815766303, 0.818811636990482, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.333991827929522, 2.0890188684700233`, 0.}, 
      Optica`Optica`RayEnd :> {5.14175033611594, 2.3651174583367935`, 0.}, 
      RotationMatrix :> {{-0.5714107762893368, 0.820664197306314, 
       0.}, {-0.820664197306314, -0.5714107762893368, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008569745768531502, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33643308770263775`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.777647676688545`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40129500991499195`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5714107762893368, 0.820664197306314, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.940248911892806, -0.1320508901896091, 0.}, 
      Optica`Optica`RayEnd :> {5.863056968970465, -0.19280845491380338`, 0.}, 
      RotationMatrix :> {{-0.7857901248228142, -0.618493233375229, 0.}, {
       0.618493233375229, -0.7857901248228142, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1713232157301778, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09823480912253361, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.013086418103786`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12301058580213159`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7857901248228142, -0.618493233375229, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.863056968970465, -0.19280845491380338`, 0.},
       Optica`Optica`RayEnd :> {5.653980257328887, -0.3616574428833441, 0.}, 
      RotationMatrix :> {{-0.7779787634610963, -0.6282905725884665, 0.}, {
       0.6282905725884665, -0.7779787634610963, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17088743869980935`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2687434689237931, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.410826752111, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26562848471722494`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7779787634610963, -0.6282905725884665, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.401924794015256, -0.6117164683421243, 0.}, 
      Optica`Optica`RayEnd :> {7.478801711368002, -0.8356664099524582, 0.}, 
      RotationMatrix :> {{0.3246798429761937, -0.9458239791657609, 0.}, {
       0.9458239791657609, 0.3246798429761937, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010370618390002365`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2367776103624091, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.520153908693505`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4042992703009932, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3246798429761937, -0.9458239791657609, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.478801711368002, -0.8356664099524582, 0.}, 
      Optica`Optica`RayEnd :> {7.583398214968567, -1.132330017951795, 0.}, 
      RotationMatrix :> {{0.33251395142016654`, -0.9430983363949629, 0.}, {
       0.9430983363949629, 0.33251395142016654`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010344701171262202`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3145627518900595, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.985706781490794`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.130390117151073, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33251395142016654`, -0.9430983363949629, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.359469019374845, 3.1712319685556047`, 0.}, 
      Optica`Optica`RayEnd :> {7.505099127366551, 3.3287697191965226`, 0.}, 
      RotationMatrix :> {{0.6788100684338169, 0.7343138913250081, 
       0.}, {-0.7343138913250081, 0.6788100684338169, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00892953541237966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21453734227559557`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.94453272634252, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2895737411407822, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6788100684338169, 0.7343138913250081, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.505099127366551, 3.3287697191965226`, 0.}, 
      Optica`Optica`RayEnd :> {7.666072835015382, 3.5295693043040495`, 0.}, 
      RotationMatrix :> {{0.6254861645496833, 0.780235258083692, 
       0.}, {-0.780235258083692, 0.6254861645496833, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008879945190229206, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25735774310007925`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.325422186130638`, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33485804115902573`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6254861645496833, 0.780235258083692, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.367555068531391, 3.3293246155986482`, 0.}, 
      Optica`Optica`RayEnd :> {7.31726555061554, 3.552830485456761, 0.}, 
      RotationMatrix :> {{-0.21951509176531597`, 0.9756091043482856, 
       0.}, {-0.9756091043482856, -0.21951509176531597`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03430451607983149, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22909366964898956`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.198321173040988`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18794353512308382`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.21951509176531597`, 0.9756091043482856, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.31726555061554, 3.552830485456761, 0.}, 
      Optica`Optica`RayEnd :> {7.249413289851313, 3.865881414191816, 0.}, 
      RotationMatrix :> {{-0.21182658040094715`, 0.9773072699185452, 
       0.}, {-0.9773072699185452, -0.21182658040094715`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03421890285377395, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3203198608776811, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.672394567139957`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3629152639312949, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.21182658040094715`, 0.9773072699185452, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.351578364845772, 3.0615498507624155`, 0.}, 
      Optica`Optica`RayEnd :> {6.332726271625041, 3.072085061703826, 0.}, 
      RotationMatrix :> {{-0.8729391899827773, 0.48782903828309687`, 
       0.}, {-0.48782903828309687`, -0.8729391899827773, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2447679079071583`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.021596112807242662`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.106237125034447`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09124073817999669, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8729391899827773, 0.48782903828309687`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.332726271625041, 3.072085061703826, 0.}, 
      Optica`Optica`RayEnd :> {6.111084384355568, 3.220486449041145, 0.}, 
      RotationMatrix :> {{-0.8309410077156206, 0.5563605321161336, 
       0.}, {-0.5563605321161336, -0.8309410077156206, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.236378070327634, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26673600798545144`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.501006416852913`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.025343360264649943`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8309410077156206, 0.5563605321161336, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.111084384355568, 3.220486449041145, 0.}, 
      Optica`Optica`RayEnd :> {6.316562790117922, 3.3905650271201493`, 0.}, 
      RotationMatrix :> {{0.7703437091761597, 0.6376288651972357, 
       0.}, {-0.6376288651972357, 0.7703437091761597, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00833328938755617, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2667360079854512, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.89577570867138, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14054351298540005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7703437091761597, 0.6376288651972357, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.149841575224362, 2.298041295074627, 0.}, 
      Optica`Optica`RayEnd :> {5.823748620050392, 2.202715441043321, 0.}, 
      RotationMatrix :> {{-0.9598293924660981, -0.28058427852992773`, 0.}, {
       0.28058427852992773`, -0.9598293924660981, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03725361151875023, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3397405390307294, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.72843804239409, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42473235913566754`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9598293924660981, -0.28058427852992773`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.823748620050392, 2.202715441043321, 0.}, 
      Optica`Optica`RayEnd :> {5.604405943891403, 2.1458756573122315`, 0.}, 
      RotationMatrix :> {{-0.9680256633999604, -0.2508511809800098, 0.}, {
       0.2508511809800098, -0.9680256633999604, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0371432684417718, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22658766647631987`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.06378778877904, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25678766822153254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9680256633999604, -0.2508511809800098, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.556008619207015, 2.7669057467627027`, 0.}, 
      Optica`Optica`RayEnd :> {6.455720919383612, 2.812084139995091, 0.}, 
      RotationMatrix :> {{-0.911754966989617, 0.4107345616937556, 
       0.}, {-0.4107345616937556, -0.911754966989617, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2411870689008152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10999413598428458`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.798757718817395`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33356965181665604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.911754966989617, 0.4107345616937556, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.455720919383612, 2.812084139995091, 0.}, 
      Optica`Optica`RayEnd :> {6.337832227099149, 2.9099046679207174`, 0.}, 
      RotationMatrix :> {{-0.7695681227408792, 0.638564722217786, 
       0.}, {-0.638564722217786, -0.7695681227408792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2002580428142613, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15318811785575603`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.025476133243913`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1911554755099804, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7695681227408792, 0.638564722217786, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.337832227099149, 2.9099046679207174`, 0.}, 
      Optica`Optica`RayEnd :> {6.352145538186897, 3.0624226294134362`, 0.}, 
      RotationMatrix :> {{0.09343617042952096, 0.9956252719047787, 
       0.}, {-0.9956252719047787, 0.09343617042952096, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.033983441549087716`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15318811785575626`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.25219454767043, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27377824652983335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.09343617042952096, 0.9956252719047787, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.241317660936481, 0.0593787069427702, 0.}, 
      Optica`Optica`RayEnd :> {8.24463024279155, -0.06646771856770184, 0.}, 
      RotationMatrix :> {{0.026313300867390893`, -0.9996537451525206, 0.}, {
       0.9996537451525206, 0.026313300867390893`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2558717053918702, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12589001553860144`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.235670649660797`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30418534800349234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.026313300867390893`, -0.9996537451525206, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.24463024279155, -0.06646771856770184, 0.}, 
      Optica`Optica`RayEnd :> {8.256952250972121, -0.40676657913585323`, 0.}, 
      RotationMatrix :> {{0.03618565835686322, -0.9993450846075538, 0.}, {
       0.9993450846075538, 0.03618565835686322, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2552285554710081, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3405218735846263, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.739643022566042`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2746886981156694, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03618565835686322, -0.9993450846075538, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.534634195919815, -0.19247479425545638`, 0.},
       Optica`Optica`RayEnd :> {7.38369793090081, -0.3427039428852845, 0.}, 
      RotationMatrix :> {{-0.7087650673113328, -0.7054445969451899, 0.}, {
       0.7054445969451899, -0.7087650673113328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07325627753703859, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2129566932405044, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.92032706670723, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30627914619674623`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7087650673113328, -0.7054445969451899, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.38369793090081, -0.3427039428852845, 0.}, 
      Optica`Optica`RayEnd :> {7.245025077907684, -0.43724862593718694`, 0.}, 
      RotationMatrix :> {{-0.826241179343275, -0.5633165305203048, 0.}, {
       0.5633165305203048, -0.826241179343275, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06969638555442212, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16783580443587667`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.16872405727233, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24395859027890443`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.826241179343275, -0.5633165305203048, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.918235140502793, -0.6120523874165424, 0.}, 
      Optica`Optica`RayEnd :> {6.8745919970061, -0.7022677679808029, 0.}, 
      RotationMatrix :> {{-0.435484439721424, -0.9001962579129712, 0.}, {
       0.9001962579129712, -0.435484439721424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023768501368344793`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10021745788348106`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.928710378268654`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16054907491963774`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.435484439721424, -0.9001962579129712, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8745919970061, -0.7022677679808029, 0.}, 
      Optica`Optica`RayEnd :> {6.746337843806928, -0.9425816125023615, 0.}, 
      RotationMatrix :> {{-0.4708362157263496, -0.882220640180499, 0.}, {
       0.882220640180499, -0.4708362157263496, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02368978988878191, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2723965339015319, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.331857248442923`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30401941488603873`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4708362157263496, -0.882220640180499, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.603390235694879, -1.6110348748944543`, 0.}, 
      Optica`Optica`RayEnd :> {7.564839912479123, -1.8428960138801187`, 0.}, 
      RotationMatrix :> {{-0.1640131703547319, -0.986458149112363, 0.}, {
       0.986458149112363, -0.1640131703547319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18613693812303794`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2350440707436987, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.294395305177446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.043078291303067534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1640131703547319, -0.986458149112363, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.564839912479123, -1.8428960138801187`, 0.}, 
      Optica`Optica`RayEnd :> {7.508878933533153, -2.1061952972400784`, 0.}, 
      RotationMatrix :> {{-0.20789387825478625`, -0.9781513867414304, 0.}, {
       0.9781513867414304, -0.20789387825478625`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18547431890347077`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2691805040905813, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.692782451231505`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16324092864823342`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20789387825478625`, -0.9781513867414304, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.701971665894905, 1.8586035155755987`, 0.}, 
      Optica`Optica`RayEnd :> {4.681822241294973, 1.9014125722190873`, 0.}, 
      RotationMatrix :> {{-0.4258660098712992, 0.9047862408526653, 
       0.}, {-0.9047862408526653, -0.4258660098712992, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009781655595059446, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04731400049048671, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.23928773430423, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27626946698470084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4258660098712992, 0.9047862408526653, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.681822241294973, 1.9014125722190873`, 0.}, 
      Optica`Optica`RayEnd :> {4.550720203660656, 2.1343176423314136`, 0.}, 
      RotationMatrix :> {{-0.490525363487636, 0.8714269147641249, 
       0.}, {-0.8714269147641249, -0.490525363487636, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009724803632390321, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26726862134544965`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.634845293895495`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2129596554288672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.490525363487636, 0.8714269147641249, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.257659461780888, 0.9100120270629408, 0.}, 
      Optica`Optica`RayEnd :> {4.1537787624621005`, 0.9380983931909275, 0.}, 
      RotationMatrix :> {{-0.9653388091912309, 0.26099996833190514`, 
       0.}, {-0.26099996833190514`, -0.9653388091912309, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032218497982814835`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1076106112483129, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.39255588658994, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16395820549626977`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9653388091912309, 0.26099996833190514`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1537787624621005`, 0.9380983931909275, 0.}, 
      Optica`Optica`RayEnd :> {3.876393431753907, 1.0266974747121043`, 0.}, 
      RotationMatrix :> {{-0.9525877177234453, 0.3042640958812541, 
       0.}, {-0.3042640958812541, -0.9525877177234453, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03210303400659668, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29119137854423194`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.823519126835404`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.047313483761430394`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9525877177234453, 0.3042640958812541, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.117167632438771, 0.8261175470069844, 0.}, 
      Optica`Optica`RayEnd :> {3.998399544867169, 0.7106453352719848, 0.}, 
      RotationMatrix :> {{-0.7169851498443802, -0.697088441234418, 0.}, {
       0.697088441234418, -0.7169851498443802, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2512827826224551, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16564929914849685`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.712506735490468`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24711467970045575`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7169851498443802, -0.697088441234418, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.998399544867169, 0.7106453352719848, 0.}, 
      Optica`Optica`RayEnd :> {3.834142400424299, 0.5186169949293943, 0.}, 
      RotationMatrix :> {{-0.6500186501956464, -0.7599182550760503, 0.}, {
       0.7599182550760503, -0.6500186501956464, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2491558155402798, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25269604863403744`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.086496887468844`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08075917503435626, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6500186501956464, -0.7599182550760503, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.117643865374875, 0.662483775743396, 0.}, 
      Optica`Optica`RayEnd :> {4.118875553318521, 0.6573601836489971, 0.}, 
      RotationMatrix :> {{0.2337364405484218, -0.972299992985577, 0.}, {
       0.972299992985577, 0.2337364405484218, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0259155955094754, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.005269558913259179, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.73977689068953, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14899948387274115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2337364405484218, -0.972299992985577, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.118875553318521, 0.6573601836489971, 0.}, 
      Optica`Optica`RayEnd :> {4.13623424416586, 0.45570602404111304`, 0.}, 
      RotationMatrix :> {{0.08576432028060216, -0.996315452739144, 0.}, {
       0.996315452739144, 0.08576432028060216, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025230996322651453`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2023999116479438, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.039328759928488`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22837362206079803`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08576432028060216, -0.996315452739144, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.751781410101081, 0.14079931650843222`, 0.}, 
      Optica`Optica`RayEnd :> {4.6926775436207055`, -0.07678088209334444, 0.},
       RotationMatrix :> {{-0.26214223604311854`, -0.9650292472678292, 0.}, {
       0.9650292472678292, -0.26214223604311854`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009260107395248438, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2254648749950171, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.034266182735543`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3256921365628906, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.26214223604311854`, -0.9650292472678292, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.6926775436207055`, -0.07678088209334447, 
       0.}, Optica`Optica`RayEnd :> {4.627965300614364, -0.36629352393380893`,
        0.}, RotationMatrix :> {{-0.21813842701252312`, -0.9759178380686057, 
       0.}, {0.9759178380686057, -0.21813842701252312`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009226806826398662, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2966567784163322, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.473318214791714`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.405299586865242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.21813842701252312`, -0.9759178380686057, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.109795497765404, 1.1420644005632679`, 0.}, 
      Optica`Optica`RayEnd :> {2.967594342453163, 1.3333641745595262`, 0.}, 
      RotationMatrix :> {{-0.5965747204949516, 0.8025575386639697, 
       0.}, {-0.8025575386639697, -0.5965747204949516, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012824582894858435`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23836269024987042`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.34630723951847, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2989930459730202, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5965747204949516, 0.8025575386639697, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.967594342453163, 1.3333641745595262`, 0.}, 
      Optica`Optica`RayEnd :> {2.825680949044306, 1.5631240269047626`, 0.}, 
      RotationMatrix :> {{-0.5255006441925789, 0.850793202225537, 
       0.}, {-0.850793202225537, -0.5255006441925789, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012728163364922, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2700537001755795, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.74598671577833, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16994602375061915`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5255006441925789, 0.850793202225537, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9148613770099985`, 1.1285672376053026`, 0.},
       Optica`Optica`RayEnd :> {2.906428365600408, 1.1264118496109896`, 0.}, 
      RotationMatrix :> {{-0.968854928538453, -0.24762901172267418`, 0.}, {
       0.24762901172267418`, -0.968854928538453, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.255102435418361, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.008704101265513275, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.32775796048931, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22563811909003537`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.968854928538453, -0.24762901172267418`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.906428365600408, 1.1264118496109896`, 0.}, 
      Optica`Optica`RayEnd :> {2.648326616778112, 1.086860197629454, 0.}, 
      RotationMatrix :> {{-0.9884614912065425, -0.1514723750448822, 0.}, {
       0.1514723750448822, -0.9884614912065425, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2526513120101845, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2611146221864952, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.714207601325324`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38636085648179286`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9884614912065425, -0.1514723750448822, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.853419889646802, 0.9430775385026428, 0.}, 
      Optica`Optica`RayEnd :> {2.841861157799778, 0.8603137646950654, 0.}, 
      RotationMatrix :> {{-0.13831691127762624`, -0.9903880209567442, 0.}, {
       0.9903880209567442, -0.13831691127762624`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011677359921056776`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08356701823556499, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.717267499439057`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.003003581729338316, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13831691127762624`, -0.9903880209567442, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.841861157799778, 0.8603137646950654, 0.}, 
      Optica`Optica`RayEnd :> {2.78724020649285, 0.5557238620463394, 0.}, 
      RotationMatrix :> {{-0.1765105587688012, -0.9842987466430732, 0.}, {
       0.9842987466430732, -0.1765105587688012, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011639207662630451`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30944863405294604`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.175251477837417`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17091956428039032`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1765105587688012, -0.9842987466430732, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3474023378701885`, 0.90487389886163, 0.}, 
      Optica`Optica`RayEnd :> {2.2410664177084985`, 1.0564604651676346`, 0.}, 
      RotationMatrix :> {{-0.5742787610984205, 0.8186598222407536, 
       0.}, {-0.8186598222407536, -0.5742787610984205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00874571024161575, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18516429191687586`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.556188881786316`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2644373866596266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5742787610984205, 0.8186598222407536, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2410664177084985`, 1.0564604651676346`, 0.},
       Optica`Optica`RayEnd :> {2.0974595866669437`, 1.2948117347041475`, 0.},
       RotationMatrix :> {{-0.5160699265246083, 0.8565464557961141, 
       0.}, {-0.8565464557961141, -0.5160699265246083, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008697978940488392, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27827010190005147`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.968028632598394`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21865635136722344`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5160699265246083, 0.8565464557961141, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1829116023236583`, 0.7363522884607112, 0.}, 
      Optica`Optica`RayEnd :> {2.190827813661015, 0.3974883048398931, 0.}, 
      RotationMatrix :> {{0.023354657078453828`, -0.999727242798128, 0.}, {
       0.999727242798128, 0.023354657078453828`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008216267132293393, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3389564364299751, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.196246704825874`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2912072712764672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.023354657078453828`, -0.999727242798128, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.190827813661015, 0.39748830483989306`, 0.}, 
      Optica`Optica`RayEnd :> {2.198137492260498, 0.1574141637177774, 0.}, 
      RotationMatrix :> {{0.030433484755909183`, -0.9995367942230097, 0.}, {
       0.9995367942230097, 0.030433484755909183`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008195810767901284, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24018539638527, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.551721091476075`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.265940165626275, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.030433484755909183`, -0.9995367942230097, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.152935114196686, -3.3998557454180136`, 0.}, 
      Optica`Optica`RayEnd :> {7.343013019922998, -3.681121789661831, 0.}, 
      RotationMatrix :> {{0.5599247188369961, -0.828543486628982, 0.}, {
       0.828543486628982, 0.5599247188369961, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008638451922939694, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33947046688904475`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.251311228113263`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07478803530895871, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5599247188369961, -0.828543486628982, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.343013019922998, -3.681121789661831, 0.}, 
      Optica`Optica`RayEnd :> {7.415501185784918, -3.8244870407543035`, 0.}, 
      RotationMatrix :> {{0.45122052577328914`, -0.8924124814909727, 0.}, {
       0.8924124814909727, 0.45122052577328914`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008493593975680641, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1606490877995666, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.48907187805662, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3538104732977979, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.45122052577328914`, -0.8924124814909727, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.350901074353575, 3.083822610252523, 0.}, 
      Optica`Optica`RayEnd :> {3.199044104206012, 3.069664227035078, 0.}, 
      RotationMatrix :> {{-0.9956817510751641, -0.09283237891971846, 0.}, {
       0.09283237891971846, -0.9956817510751641, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2912461008387395, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.152515570345227, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.53983282502008, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38057929088244635`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9956817510751641, -0.09283237891971846, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.199044104206012, 3.069664227035078, 0.}, 
      Optica`Optica`RayEnd :> {2.8860657647081065`, 3.0378135942946987`, 0.}, 
      RotationMatrix :> {{-0.9948616913238995, -0.10124334613271857`, 0.}, {
       0.10124334613271857`, -0.9948616913238995, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.29051786504563903`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31459482481571255`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.005433165747334`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01036640260581839, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9948616913238995, -0.10124334613271857`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3885589709624035`, 3.5767400067352, 0.}, 
      Optica`Optica`RayEnd :> {3.3350883661874784`, 3.6729827736237035`, 0.}, 
      RotationMatrix :> {{-0.48565959507213724`, 0.8741480181950692, 
       0.}, {-0.8741480181950692, -0.48565959507213724`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.294857956380511, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11009893620444781`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.788043357022627`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19772709418363274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.48565959507213724`, 0.8741480181950692, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3350883661874784`, 3.6729827736237035`, 0.},
       Optica`Optica`RayEnd :> {3.1854391618308204`, 3.917440606065164, 0.}, 
      RotationMatrix :> {{-0.5221060081607413, 0.8528805990538507, 
       0.}, {-0.8528805990538507, -0.5221060081607413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2904129674601188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2866260912871644, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.21224997212763, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3190678655317089, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5221060081607413, 0.8528805990538507, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.651399080236819, 3.37910346651708, 0.}, 
      Optica`Optica`RayEnd :> {3.847707350386743, 3.5520993251997077`, 0.}, 
      RotationMatrix :> {{0.7502497559912606, 0.6611545232659707, 
       0.}, {-0.6611545232659707, 0.7502497559912606, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03241726635515453, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2616572262533472, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.619345878240782`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.026143390714226444`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.7502497559912606, 0.6611545232659707, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.847707350386743, 3.5520993251997077`, 0.}, 
      Optica`Optica`RayEnd :> {4.03176716932845, 3.687293224962993, 0.}, 
      RotationMatrix :> {{0.8059522630023497, 0.5919805315729485, 
       0.}, {-0.5919805315729485, 0.8059522630023497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03215893897230612, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22837558425116095`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.9573417429325, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1343971790024413, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8059522630023497, 0.5919805315729485, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6715545154570086`, 3.532753025731774, 0.}, 
      Optica`Optica`RayEnd :> {3.6447050878359932`, 3.7340071536615724`, 0.}, 
      RotationMatrix :> {{-0.13223893935422507`, 0.9912178685427684, 
       0.}, {-0.9912178685427684, -0.13223893935422507`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.14772397412384664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2030372275528793, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.77014460459473, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1592331182164257, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13223893935422507`, 0.9912178685427684, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6447050878359932`, 3.7340071536615724`, 0.},
       Optica`Optica`RayEnd :> {3.666413661944249, 3.8758765752816933`, 0.}, 
      RotationMatrix :> {{0.15125742965120914`, 0.9884944056368296, 
       0.}, {-0.9884944056368296, 0.15125742965120914`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11735526001872232`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14352071272342987`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.982555259425407`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2936793847791384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15125742965120914`, 0.9884944056368296, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.666413661944249, 3.8758765752816933`, 0.}, 
      Optica`Optica`RayEnd :> {3.7945631340613906`, 3.9404978394038013`, 0.}, 
      RotationMatrix :> {{0.8928987996603012, 0.45025740811805953`, 
       0.}, {-0.45025740811805953`, 0.8928987996603012, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.024125592080625955`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14352071272343012`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.194965914256084`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24613735795334646`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 109, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8928987996603012, 0.45025740811805953`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5550668598930115`, 3.63495407620088, 0.}, 
      Optica`Optica`RayEnd :> {3.3616401828882223`, 3.7300898723231537`, 0.}, 
      RotationMatrix :> {{-0.8973354110899051, 0.4413492494658966, 
       0.}, {-0.4413492494658966, -0.8973354110899051, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023079270704020948`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21555671894175318`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.0162702476684, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3646859538281703, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8973354110899051, 0.4413492494658966, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3616401828882223`, 3.7300898723231537`, 0.},
       Optica`Optica`RayEnd :> {3.0875717529220807`, 3.857537429702332, 0.}, 
      RotationMatrix :> {{-0.9067541685199693, 0.4216596706725204, 
       0.}, {-0.4216596706725204, -0.9067541685199693, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023016772023067712`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30225218640404367`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.463603483546382`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2989006728103102, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9067541685199693, 0.4216596706725204, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.139812661650813, 3.5158217226159985`, 0.}, 
      Optica`Optica`RayEnd :> {4.409143393975804, 3.598808626479347, 0.}, 
      RotationMatrix :> {{0.9556633319278517, 0.29446153570297706`, 
       0.}, {-0.29446153570297706`, 0.9556633319278517, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0327753249494446, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2818259561991061, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.379290113141682`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20872275062350026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9556633319278517, 0.29446153570297706`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.409143393975804, 3.598808626479347, 0.}, 
      Optica`Optica`RayEnd :> {4.642666223636448, 3.6503448995112304`, 0.}, 
      RotationMatrix :> {{0.9765027599997455, 0.21550489486988128`, 
       0.}, {-0.21550489486988128`, 0.9765027599997455, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032548757325003466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23914200678829084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.733220283188352`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09057098904417094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9765027599997455, 0.21550489486988128`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.264634592188302, 3.5569056035555873`, 0.}, 
      Optica`Optica`RayEnd :> {6.323640786141722, 3.551542038427968, 0.}, 
      RotationMatrix :> {{0.9958941717030609, -0.09052512782577593, 0.}, {
       0.09052512782577593, 0.9958941717030609, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02197442155485222, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05924946207137043, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.515722932252434`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11264547509694858`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9958941717030609, -0.09052512782577593, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.323640786141722, 3.551542038427968, 0.}, 
      Optica`Optica`RayEnd :> {6.622413844330305, 3.520465895530815, 0.}, 
      RotationMatrix :> {{0.9946341952370779, -0.1034544231296538, 0.}, {
       0.1034544231296538, 0.9946341952370779, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02191839661334862, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30038486472644227`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.960292532047568`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42793627963736136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9946341952370779, -0.1034544231296538, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.29350856581124, 2.0561842066253853`, 0.}, 
      Optica`Optica`RayEnd :> {6.360070698942792, 1.9664371853324578`, 0.}, 
      RotationMatrix :> {{0.5957062662864553, -0.803202368215539, 0.}, {
       0.803202368215539, 0.5957062662864553, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011922980361622036`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11173649984662878`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.313870160612158`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07514299483739728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5957062662864553, -0.803202368215539, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.360070698942792, 1.9664371853324578`, 0.}, 
      Optica`Optica`RayEnd :> {6.498313174423297, 1.8306402663680825`, 0.}, 
      RotationMatrix :> {{0.7133886703771295, -0.7007685816141807, 0.}, {
       0.7007685816141807, 0.7133886703771295, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011570571696116201`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19378283006292119`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.60066874910528, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3052170676734803, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7133886703771295, -0.7007685816141807, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.635004169707646, 2.8971105400953423`, 0.}, 
      Optica`Optica`RayEnd :> {6.903575285557843, 3.006320190988968, 0.}, 
      RotationMatrix :> {{0.926343085771204, 0.3766808827693319, 
       0.}, {-0.3766808827693319, 0.926343085771204, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.15871617534773266`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28992618391122904`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.012063457620023`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14062537091908253`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.926343085771204, 0.3766808827693319, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.903575285557843, 3.006320190988968, 0.}, 
      Optica`Optica`RayEnd :> {7.119367256792085, 3.0761878458813996`, 0.}, 
      RotationMatrix :> {{0.9513765706480471, 0.3080302271238338, 
       0.}, {-0.3080302271238338, 0.9513765706480471, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.15778811140663979`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2268207751713401, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.347758204873607`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0677195114466511, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9513765706480471, 0.3080302271238338, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.1972652318558445`, 1.114415438426117, 0.}, 
      Optica`Optica`RayEnd :> {6.294695493609805, 1.0352192052585532`, 0.}, 
      RotationMatrix :> {{0.7759808868482246, -0.6307564214863308, 0.}, {
       0.6307564214863308, 0.7759808868482246, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0947951769089147, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1255575535496627, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.2478019366673, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.015125621308418852`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7759808868482246, -0.6307564214863308, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.294695493609805, 1.0352192052585532`, 0.}, 
      Optica`Optica`RayEnd :> {6.529350429469603, 0.870475889649174, 0.}, 
      RotationMatrix :> {{0.8184366525022222, -0.5745967680390797, 0.}, {
       0.5745967680390797, 0.8184366525022222, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09426843411389882, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28671117690340825`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.672134478484345`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0731214897963346, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8184366525022222, -0.5745967680390797, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.14685598326838, 1.4104281174482072`, 0.}, 
      Optica`Optica`RayEnd :> {5.146718110808978, 1.3834846388450577`, 0.}, 
      RotationMatrix :> {{-0.005117032451289333, -0.9999869079037441, 0.}, {
       0.9999869079037441, -0.005117032451289333, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.048330454070413295`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02694383135438313, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.30983363553601, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42609544000434585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.005117032451289333, -0.9999869079037441, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.146718110808978, 1.3834846388450577`, 0.}, 
      Optica`Optica`RayEnd :> {5.162084544223142, 1.0917722028025019`, 0.}, 
      RotationMatrix :> {{0.05260371574833612, -0.9986154660776424, 0.}, {
       0.9986154660776424, 0.05260371574833612, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.048117425433559805`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2921168817746659, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.742166620562514`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4121545521403653, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.05260371574833612, -0.9986154660776424, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9166370419365357`, 1.3835162247723365`, 0.},
       Optica`Optica`RayEnd :> {3.915972049864252, 1.3823742354471145`, 0.}, 
      RotationMatrix :> {{-0.5032112211373739, -0.8641634491931673, 0.}, {
       0.8641634491931673, -0.5032112211373739, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03441385580338529, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001321496906966141, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.16863481657978, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1930735144003248, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5032112211373739, -0.8641634491931673, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9159720498642523`, 1.3823742354471145`, 0.},
       Optica`Optica`RayEnd :> {3.7662921383577954`, 1.1468848888748389`, 0.},
       RotationMatrix :> {{-0.5364240580681338, -0.8439485943620704, 0.}, {
       0.8439485943620704, -0.5364240580681338, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034301104467841105`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27903280856848733`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.58160337326114, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33564114993202293`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5364240580681338, -0.8439485943620704, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1006670786341908`, 3.289236112860523, 0.}, 
      Optica`Optica`RayEnd :> {2.692734014232927, 3.4208220106492813`, 0.}, 
      RotationMatrix :> {{-0.951712307687501, 0.3069913409139257, 
       0.}, {-0.3069913409139257, -0.951712307687501, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022928524710185104`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.42863064931089473`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.546586996850596`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34771290537948846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.951712307687501, 0.3069913409139257, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.692734014232927, 3.4208220106492813`, 0.}, 
      Optica`Optica`RayEnd :> {2.3617301027851787`, 3.5264239061816407`, 0.}, 
      RotationMatrix :> {{-0.9526905938827075, 0.3039418239193364, 
       0.}, {-0.3039418239193364, -0.9526905938827075, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022871896228055025`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3474411457120989, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.0607998925045, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16649357689875735`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9526905938827075, 0.3039418239193364, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.602454551891017, 0.12321755953209025`, 0.}, 
      Optica`Optica`RayEnd :> {2.5955754033611145`, 0.12146873893754633`, 0.},
       RotationMatrix :> {{-0.9691724158954226, -0.2463834983667313, 0.}, {
       0.2463834983667313, -0.9691724158954226, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08095480377927528, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.00709796153612876, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.404782148311153`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08080161186286922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9691724158954226, -0.2463834983667313, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5955754033611145`, 0.1214687389375463, 0.}, 
      Optica`Optica`RayEnd :> {2.319178571095467, 0.03075668096407757, 0.}, 
      RotationMatrix :> {{-0.9501377603525242, -0.31183046091151606`, 0.}, {
       0.31183046091151606`, -0.9501377603525242, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.08052361116729567, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2909018500255139, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.835316886348913`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12401425519295403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9501377603525242, -0.31183046091151606`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.237518902676637, 1.909981509090571, 0.}, 
      Optica`Optica`RayEnd :> {4.19964115086494, 1.929701256250354, 0.}, 
      RotationMatrix :> {{-0.8869932076680759, 0.4617824699473733, 
       0.}, {-0.4617824699473733, -0.8869932076680759, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03633736017183194, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04270354212889497, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.723978934818444`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3492579221667085, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8869932076680759, 0.4617824699473733, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.19964115086494, 1.929701256250354, 0.}, 
      Optica`Optica`RayEnd :> {3.915873650154078, 2.085425531623274, 0.}, 
      RotationMatrix :> {{-0.8766693052251213, 0.481093472493758, 
       0.}, {-0.481093472493758, -0.8766693052251213, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03623889957405221, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3236881900843929, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.15772110953153, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33340761833788857`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8766693052251213, 0.481093472493758, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2213753721831653`, 1.1509229207014182`, 0.},
       Optica`Optica`RayEnd :> {3.1376643673154043`, 1.1221886645158219`, 0.},
       RotationMatrix :> {{-0.9458303158864312, -0.32466138290559504`, 0.}, {
       0.32466138290559504`, -0.9458303158864312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08759831414309759, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08850530952722423, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.968233278716166`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09623251129964805, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9458303158864312, -0.32466138290559504`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1376643673154043`, 1.1221886645158219`, 0.},
       Optica`Optica`RayEnd :> {2.8556411871541107`, 1.0443451746924912`, 0.},
       RotationMatrix :> {{-0.9639540617396426, -0.26606872581279606`, 0.}, {
       0.26606872581279606`, -0.9639540617396426, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08718679004135797, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29256910817132514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.360275883665743`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15486029013140679`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9639540617396426, -0.26606872581279606`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.226784094955743, 0.11802907473082361`, 0.}, 
      Optica`Optica`RayEnd :> {4.177832688135187, 0.08579016512972962, 0.}, 
      RotationMatrix :> {{-0.8351503533567652, -0.5500217152877418, 0.}, {
       0.5500217152877418, -0.8351503533567652, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020486816518151044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05861388506129856, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.083020608558996`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3092666653308184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8351503533567652, -0.5500217152877418, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.177832688135187, 0.08579016512972962, 0.}, 
      Optica`Optica`RayEnd :> {3.9173878228281183`, -0.09386285124665285, 0.},
       RotationMatrix :> {{-0.8231598000828025, -0.5678097775907351, 0.}, {
       0.5678097775907351, -0.8231598000828025, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020431511625259153`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31639648253093733`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.506991895150453`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.368074419126379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8231598000828025, -0.5678097775907351, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.017758252410186, -2.666329052544557, 0.}, 
      Optica`Optica`RayEnd :> {6.006534413084269, -2.8195029085434435`, 0.}, 
      RotationMatrix :> {{-0.07307923571001632, -0.9973261378847138, 0.}, {
       0.9973261378847138, -0.07307923571001632, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008146553316795431, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15358451982794913`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.745224421940527`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24237858997247122`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.07307923571001632, -0.9973261378847138, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.006534413084269, -2.8195029085434435`, 0.}, 
      Optica`Optica`RayEnd :> {5.982587617186125, -3.1717560561794467`, 0.}, 
      RotationMatrix :> {{-0.06782523249632422, -0.9976972175148224, 0.}, {
       0.9976972175148224, -0.06782523249632422, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00812636191240054, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35306618225661207`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.267762371680313`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2993352276995865, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06782523249632422, -0.9976972175148224, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3678358241441186`, 1.6157500856389455`, 0.},
       Optica`Optica`RayEnd :> {2.1502410153074516`, 1.6477252730810639`, 0.},
       RotationMatrix :> {{-0.9893748698070719, 0.14538695606635105`, 
       0.}, {-0.14538695606635105`, -0.9893748698070719, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1480478745750526, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21993161083533302`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.758624550263967`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19687834988375277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9893748698070719, 0.14538695606635105`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1502410153074516`, 1.6477252730810639`, 0.},
       Optica`Optica`RayEnd :> {1.866738553866757, 1.6632737373389903`, 0.}, 
      RotationMatrix :> {{-0.9984994414256234, 0.054761898001416245`, 
       0.}, {-0.054761898001416245`, -0.9984994414256234, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.146813265913905, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2839285128050942, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.178838749215508`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3415727601915217, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9984994414256234, 0.054761898001416245`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5207053132081034`, -2.6411097727657418`, 
       0.}, Optica`Optica`RayEnd :> {2.42761242653415, -2.722429377510061, 
       0.}, RotationMatrix :> {{-0.7531243785336321, -0.6578781577604849, 
       0.}, {0.6578781577604849, -0.7531243785336321, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15599465082627487`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12360891418122621`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.03073509953081, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4053938557699811, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7531243785336321, -0.6578781577604849, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.42761242653415, -2.722429377510061, 0.}, 
      Optica`Optica`RayEnd :> {2.2264786672156953`, -2.866480413713278, 0.}, 
      RotationMatrix :> {{-0.8129985681898351, -0.5822656851655241, 0.}, {
       0.5822656851655241, -0.8129985681898351, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1545458112842911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2473974336342129, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.396883301309444`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.340698142050024, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8129985681898351, -0.5822656851655241, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0835451215110132`, 3.193820375821446, 0.}, 
      Optica`Optica`RayEnd :> {2.980971346924826, 3.384369921390081, 0.}, 
      RotationMatrix :> {{-0.47399296979371064`, 0.8805286279196937, 
       0.}, {-0.8805286279196937, -0.47399296979371064`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.041247397799824295`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21640357794932905`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.450172648387465`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3099558981218884, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.47399296979371064`, 0.8805286279196937, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.980971346924826, 3.384369921390081, 0.}, 
      Optica`Optica`RayEnd :> {2.873754933729199, 3.6211107541915326`, 0.}, 
      RotationMatrix :> {{-0.4125491176473166, 0.910935357491639, 
       0.}, {-0.910935357491639, -0.4125491176473166, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04102605515943896, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2598876318220244, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.83480634348406, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2720279575756967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4125491176473166, 0.910935357491639, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.830651011562688, 3.011017350880267, 0.}, 
      Optica`Optica`RayEnd :> {3.792604485067973, 3.091943737459184, 0.}, 
      RotationMatrix :> {{-0.42546303357306015`, 0.9049758046836435, 
       0.}, {-0.9049758046836435, -0.42546303357306015`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04734614599636355, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08942381239375449, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.42659984619651, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2216992180516342, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.42546303357306015`, 0.9049758046836435, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.792604485067973, 3.091943737459184, 0.}, 
      Optica`Optica`RayEnd :> {3.667143186592133, 3.386655018692026, 0.}, 
      RotationMatrix :> {{-0.3916932562927931, 0.9200958607529691, 
       0.}, {-0.9200958607529691, -0.3916932562927931, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.047194885599491566`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3203049745182661, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      16.900651208483545`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3689879860055504, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3916932562927931, 0.9200958607529691, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.363445515092777, 0.42283839082818514`, 0.}, 
      Optica`Optica`RayEnd :> {2.1629977363500927`, 0.45237841394074313`, 0.},
       RotationMatrix :> {{-0.9893147513698121, 0.14579548251604355`, 
       0.}, {-0.14579548251604355`, -0.9893147513698121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01216464450365523, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20261274631268025`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.281978480828304`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42156681939633117`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9893147513698121, 0.14579548251604355`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1629977363500927`, 0.45237841394074313`, 
       0.}, Optica`Optica`RayEnd :> {1.9255244467780555`, 0.4850253643387584, 
       0.}, RotationMatrix :> {{-0.990682007383404, 0.1361953018528472, 
       0.}, {-0.1361953018528472, -0.990682007383404, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012134089490406542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23970687647719896`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.636744658014557`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11356368556592997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.990682007383404, 0.1361953018528472, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.395953481947561, 3.52396953458935, 0.}, 
      Optica`Optica`RayEnd :> {4.330377895951577, 3.613602019872441, 0.}, 
      RotationMatrix :> {{-0.5904562788743081, 0.8070696269454724, 
       0.}, {-0.8070696269454724, -0.5904562788743081, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17641937255134932`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11105917295181089`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.904585686392128`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10894213973027161`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5904562788743081, 0.8070696269454724, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.330377895951577, 3.613602019872441, 0.}, 
      Optica`Optica`RayEnd :> {4.1545226228344525`, 3.848702210669975, 0.}, 
      RotationMatrix :> {{-0.5989752460106281, 0.8007675409671062, 
       0.}, {-0.8007675409671062, -0.5989752460106281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17597462123819133`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2935935571434351, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.339104150964413`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42854641467272564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5989752460106281, 0.8007675409671062, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.825791340319894, 0.5933320850040109, 0.}, 
      Optica`Optica`RayEnd :> {7.8593814876447174`, 0.5594364396521986, 0.}, 
      RotationMatrix :> {{0.7038986029689855, -0.7103004693355545, 0.}, {
       0.7103004693355545, 0.7038986029689855, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03185511773197192, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04772015057728987, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.836625186292515`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1448612827484081, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7038986029689855, -0.7103004693355545, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.8593814876447174`, 0.5594364396521986, 0.}, 
      Optica`Optica`RayEnd :> {8.081675417603904, 0.3567032731689679, 0.}, 
      RotationMatrix :> {{0.7388674572776949, -0.6738507850971105, 0.}, {
       0.6738507850971105, 0.7388674572776949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03173083555516049, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3008576541971589, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.28189451450431, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06862367939365573, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.7388674572776949, -0.6738507850971105, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.096466395184083, 0.3260823219419739, 0.}, 
      Optica`Optica`RayEnd :> {7.110169719282886, 0.2755412943464901, 0.}, 
      RotationMatrix :> {{0.2616846342054193, -0.9651534345485049, 0.}, {
       0.9651534345485049, 0.2616846342054193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012584071423006818`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05236579572358528, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.242882513588015`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2966651469506515, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2616846342054193, -0.9651534345485049, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.110169719282886, 0.2755412943464901, 0.}, 
      Optica`Optica`RayEnd :> {7.173986439691582, 0.0938575404021978, 0.}, 
      RotationMatrix :> {{0.3314022724160611, -0.9434895515253309, 0.}, {
       0.9434895515253309, 0.3314022724160611, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012510582246910786`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1925657296899216, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.5278797935291, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3529264295548655, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3314022724160611, -0.9434895515253309, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.098600632748835, 2.3179016869850884`, 0.}, 
      Optica`Optica`RayEnd :> {4.888769269933546, 2.2467869132101863`, 0.}, 
      RotationMatrix :> {{-0.9470857787319488, -0.3209805721904308, 0.}, {
       0.3209805721904308, -0.9470857787319488, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01828772047160128, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22155476043176536`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.109541306798626`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40999086619675196`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9470857787319488, -0.3209805721904308, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.888769269933546, 2.2467869132101863`, 0.}, 
      Optica`Optica`RayEnd :> {4.60623413005632, 2.1637909267630078`, 0.}, 
      RotationMatrix :> {{-0.9594597505872762, -0.2818456794116243, 0.}, {
       0.2818456794116243, -0.9594597505872762, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018225971422683965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29447315502738725`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.54536157623916, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3054721818284637, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9594597505872762, -0.2818456794116243, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.352822588729898, 2.881774653529568, 0.}, 
      Optica`Optica`RayEnd :> {6.348498540963568, 2.8777780362125003`, 0.}, 
      RotationMatrix :> {{-0.7343641008168107, -0.6787557494647953, 0.}, {
       0.6787557494647953, -0.7343641008168107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01083854181771943, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00588815243218031, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.79277622828953, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2021817831637771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7343641008168107, -0.6787557494647953, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.348498540963568, 2.8777780362125003`, 0.}, 
      Optica`Optica`RayEnd :> {6.101941934037496, 2.654840751506858, 0.}, 
      RotationMatrix :> {{-0.7417419004547231, -0.6706854352897598, 0.}, {
       0.6706854352897598, -0.7417419004547231, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010811178194709677`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33240215602613354`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.284731419208207`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.372104653423426, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7417419004547231, -0.6706854352897598, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.35450132886719, 2.727795098489933, 0.}, 
      Optica`Optica`RayEnd :> {7.381310718910736, 2.6440872337303665`, 0.}, 
      RotationMatrix :> {{0.30501177626524056`, -0.9523485792185137, 0.}, {
       0.9523485792185137, 0.30501177626524056`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010191060598839815`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08789624575095821, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.65478044924119, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41212332800107226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.30501177626524056`, -0.9523485792185137, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.381310718910736, 2.6440872337303665`, 0.}, 
      Optica`Optica`RayEnd :> {7.4872954362059225`, 2.3272620760423, 0.}, 
      RotationMatrix :> {{0.3172414024712971, -0.9483448173307234, 0.}, {
       0.9483448173307234, 0.3172414024712971, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010165094290472217`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3340822366487162, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.14922215948129, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15881643570515486`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3172414024712971, -0.9483448173307234, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.372508919400013, 1.6226560092947893`, 0.}, 
      Optica`Optica`RayEnd :> {7.372752225477329, 1.6215963790450416`, 0.}, 
      RotationMatrix :> {{0.22379048930244588`, -0.9746372745271805, 0.}, {
       0.9746372745271805, 0.22379048930244588`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012911538132742338`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0010872047247133423`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.139889674011027`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3437631203317326, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22379048930244588`, -0.9746372745271805, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.372752225477329, 1.6215963790450416`, 0.}, 
      Optica`Optica`RayEnd :> {7.412708949979767, 1.3649542899157536`, 0.}, 
      RotationMatrix :> {{0.1538371526891288, -0.9880962151797265, 0.}, {
       0.9880962151797265, 0.1538371526891288, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01283864572793367, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25973390565270693`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.487933107585654`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42798323464862476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1538371526891288, -0.9880962151797265, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.385537894137745, 1.917924882028194, 0.}, 
      Optica`Optica`RayEnd :> {4.339896425545627, 1.9082524771412326`, 0.}, 
      RotationMatrix :> {{-0.9782737812243631, -0.2073171699811325, 0.}, {
       0.2073171699811325, -0.9782737812243631, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010852536857487473`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04665510766832144, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.0014492852546, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09640920155447227, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9782737812243631, -0.2073171699811325, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.339896425545627, 1.9082524771412326`, 0.}, 
      Optica`Optica`RayEnd :> {4.1432445512089, 1.8362821881632283`, 0.}, 
      RotationMatrix :> {{-0.9390851245691655, -0.3436846356951585, 0.}, {
       0.3436846356951585, -0.9390851245691655, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010605829287655058`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20940793245654563`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.31137302529029, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2568774382126144, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9390851245691655, -0.3436846356951585, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.613683131266335, 3.285649020901551, 0.}, 
      Optica`Optica`RayEnd :> {3.553902918326969, 3.314373845341771, 0.}, 
      RotationMatrix :> {{-0.9013446241806102, 0.4331026073123016, 
       0.}, {-0.4331026073123016, -0.9013446241806102, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03193054195584809, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0663233699249173, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.44614721018006, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1483482087506938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9013446241806102, 0.4331026073123016, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.553902918326969, 3.314373845341771, 0.}, 
      Optica`Optica`RayEnd :> {3.357456586428072, 3.437434345337315, 0.}, 
      RotationMatrix :> {{-0.8474519892797346, 0.5308720428368965, 
       0.}, {-0.5308720428368965, -0.8474519892797346, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03152819925925279, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23180821377959193`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.789223366573857`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11358488651662255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8474519892797346, 0.5308720428368965, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8437336950449588`, -0.5645446446200453, 0.},
       Optica`Optica`RayEnd :> {3.823958396045145, -0.5832133566231358, 0.}, 
      RotationMatrix :> {{-0.7271592329585688, -0.686468826621504, 0.}, {
       0.686468826621504, -0.7271592329585688, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012323993430661468`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.027195280075527493`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.71705559975903, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13957125768279116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7271592329585688, -0.686468826621504, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.823958396045145, -0.5832133566231358, 0.}, 
      Optica`Optica`RayEnd :> {3.6415973214998734`, -0.7773224395460558, 0.}, 
      RotationMatrix :> {{-0.6847077299146068, -0.7288177581502693, 0.}, {
       0.7288177581502693, -0.6847077299146068, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01226749733389535, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26633418402916864`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.111230192122196`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14923485715234588`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6847077299146068, -0.7288177581502693, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3044227199070897`, 2.8599001531862447`, 0.},
       Optica`Optica`RayEnd :> {2.2541150612332057`, 3.0764472252778026`, 0.},
       RotationMatrix :> {{-0.22629105081664275`, 0.9740597313924337, 
       0.}, {-0.9740597313924337, -0.22629105081664275`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008703473005665709, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22231395582075883`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.762230531212634`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28850243532644365`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22629105081664275`, 0.9740597313924337, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2541150612332057`, 3.0764472252778026`, 0.},
       Optica`Optica`RayEnd :> {2.1945212760539454`, 3.3748669079486944`, 0.},
       RotationMatrix :> {{-0.19583127438790868`, 0.9806376048120978, 
       0.}, {-0.9806376048120978, -0.19583127438790868`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008677599357854674, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3043118897404233, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.21261212802846, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4232208494565384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.19583127438790868`, 0.9806376048120978, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1626895965014343`, 2.9042839244054353`, 0.},
       Optica`Optica`RayEnd :> {2.1397724922646493`, 2.907287161873985, 0.}, 
      RotationMatrix :> {{-0.991522268748585, 0.12993687150173883`, 
       0.}, {-0.12993687150173883`, -0.991522268748585, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20072222975103354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023113050467045204`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.7151109530056, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24223287895171272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.991522268748585, 0.12993687150173883`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1397724922646493`, 2.907287161873985, 0.}, 
      Optica`Optica`RayEnd :> {1.9002821581533915`, 2.948691825759078, 0.}, 
      RotationMatrix :> {{-0.9853820079345198, 0.17035932154987707`, 
       0.}, {-0.17035932154987707`, -0.9853820079345198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20004600485478619`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24304313675592526`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.074814795404368`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09887230540803715, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9853820079345198, 0.17035932154987707`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0713890407219795`, 2.787141251001066, 0.}, 
      Optica`Optica`RayEnd :> {1.9981921232715614`, 2.649539852330109, 0.}, 
      RotationMatrix :> {{-0.46963639850118194`, -0.8828599284160763, 0.}, {
       0.8828599284160763, -0.46963639850118194`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008021717772985479, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15585869767339552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.11279975522905, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16896694098583442`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 107, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46963639850118194`, -0.8828599284160763, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7875435276326748`, 0.5557776983030938, 0.}, 
      Optica`Optica`RayEnd :> {2.7013439460896578`, 0.41510805924679106`, 0.},
       RotationMatrix :> {{-0.5224858554935209, -0.8526479524453239, 0.}, {
       0.8526479524453239, -0.5224858554935209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012481489648239759`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16497974181826602`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.46532623145039, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3281409675753054, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5224858554935209, -0.8526479524453239, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7013439460896578`, 0.41510805924679106`, 
       0.}, Optica`Optica`RayEnd :> {2.5751762563305114`, 0.164338020188098, 
       0.}, RotationMatrix :> {{-0.4494426675801423, -0.8933091785929692, 
       0.}, {0.8933091785929692, -0.4494426675801423, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012391837481959015`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2807203206550224, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.880792306019824`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2157847976320557, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4494426675801423, -0.8933091785929692, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.63197961151276, 3.0213397653388454`, 0.}, 
      Optica`Optica`RayEnd :> {7.843513348210977, 3.0109054965819593`, 0.}, 
      RotationMatrix :> {{0.9987856521124829, -0.0492668360486221, 0.}, {
       0.0492668360486221, 0.9987856521124829, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011438092667277355`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21179092456005216`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.675078348465483`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08832995699317445, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9987856521124829, -0.0492668360486221, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.843513348210977, 3.0109054965819593`, 0.}, 
      Optica`Optica`RayEnd :> {8.145218465973057, 3.002605801682305, 0.}, 
      RotationMatrix :> {{0.9996218339839488, -0.027498891297038884`, 0.}, {
       0.027498891297038884`, 0.9996218339839488, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011407129365692659`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30181925554751854`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.121770846675812`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36372589932130606`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 108, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9996218339839488, -0.027498891297038884`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.852640212802115, -1.7759387147053527`, 0.}, 
      Optica`Optica`RayEnd :> {7.094971761813688, -1.7987569508849908`, 0.}, 
      RotationMatrix :> {{0.9955960949306272, -0.09374655065060256, 0.}, {
       0.09374655065060256, 0.9955960949306272, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008050599930654703, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24340347480818406`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.85481160545441, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.009806139451817283, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9955960949306272, -0.09374655065060256, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.094971761813688, -1.7987569508849908`, 0.}, 
      Optica`Optica`RayEnd :> {7.3847323755227645`, -1.8228940275480667`, 0.},
       RotationMatrix :> {{0.9965485018075169, -0.08301255052818128, 0.}, {
       0.08301255052818128, 0.9965485018075169, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00803028887204484, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29076418577070284`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.28514260039505, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37936707602522246`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9965485018075169, -0.08301255052818128, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.333169237688875, -2.0022077378949565`, 0.}, 
      Optica`Optica`RayEnd :> {5.102642866096751, -2.0338418521312005`, 0.}, 
      RotationMatrix :> {{-0.9907154931541226, -0.13595150467863054`, 0.}, {
       0.13595150467863054`, -0.9907154931541226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019773235680795632`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23268675334651415`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.19893545237823, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36062262664418643`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9907154931541226, -0.13595150467863054`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.102642866096751, -2.0338418521312005`, 0.}, 
      Optica`Optica`RayEnd :> {4.810627423020948, -2.0628701227823787`, 0.}, 
      RotationMatrix :> {{-0.9950954799898472, -0.0989190866505334, 0.}, {
       0.0989190866505334, -0.9950954799898472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019709822162423958`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29345469751182257`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.633248404695728`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21286179894511673`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9950954799898472, -0.0989190866505334, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.965978042793, -3.6638144368616565`, 0.}, 
      Optica`Optica`RayEnd :> {6.904023761744716, -3.8776898950459926`, 0.}, 
      RotationMatrix :> {{-0.27823610529390685`, -0.9605127118944742, 0.}, {
       0.9605127118944742, -0.27823610529390685`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03850346402219204, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2226680142134686, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.076286084534264`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40813554378036243`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.27823610529390685`, -0.9605127118944742, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.904023761744716, -3.8776898950459926`, 0.}, 
      Optica`Optica`RayEnd :> {6.866622737248663, -4.094535006342286, 0.}, 
      RotationMatrix :> {{-0.16996842134717036`, -0.9854495094852653, 0.}, {
       0.9854495094852653, -0.16996842134717036`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03802347580759137, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2200469016515713, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.40195549897859, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.287797226131891, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.16996842134717036`, -0.9854495094852653, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.426423131981197, -2.3289619051770183`, 0.}, 
      Optica`Optica`RayEnd :> {6.399416597563361, -2.340950662209046, 0.}, 
      RotationMatrix :> {{-0.9139891548545009, -0.4057386163632378, 0.}, {
       0.4057386163632378, -0.9139891548545009, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013294879657590014`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0295479812581973, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.838700769789664`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13814184693628806`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9139891548545009, -0.4057386163632378, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.399416597563361, -2.340950662209046, 0.}, 
      Optica`Optica`RayEnd :> {6.2235295923556375`, -2.3817523947534873`, 0.},
       RotationMatrix :> {{-0.9741327857444745, -0.22597636101528254`, 0.}, {
       0.22597636101528254`, -0.9741327857444745, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012590715941711086`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18055752540276424`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.105925907385757`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38256147749764463`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9741327857444745, -0.22597636101528254`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.930958569340212, -0.3847901262935921, 0.}, 
      Optica`Optica`RayEnd :> {7.947664964619279, -0.16217757645068404`, 0.}, 
      RotationMatrix :> {{0.07483651523243859, 0.9971958162707385, 
       0.}, {-0.9971958162707385, 0.07483651523243859, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013366451520295392`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22323855175749027`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.134136540204572`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3920401040970934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.07483651523243859, 0.9971958162707385, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.947664964619279, -0.16217757645068404`, 0.},
       Optica`Optica`RayEnd :> {7.979510040500845, 0.1419831973646408, 0.}, 
      RotationMatrix :> {{0.10412900796387392`, 0.9945637987079858, 
       0.}, {-0.9945637987079858, 0.10412900796387392`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013327488754502318`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3058232907838117, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.586755010564612`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3192611151366776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.10412900796387392`, 0.9945637987079858, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.427593108847438, 0.6724781669937853, 0.}, 
      Optica`Optica`RayEnd :> {5.383963743079979, 0.7060783323082914, 0.}, 
      RotationMatrix :> {{-0.7922805969527562, 0.6101569107141082, 
       0.}, {-0.6101569107141082, -0.7922805969527562, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012991428415227772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05506807302269434, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.027080479588896`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32394417616536214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7922805969527562, 0.6101569107141082, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.383963743079979, 0.7060783323082914, 0.}, 
      Optica`Optica`RayEnd :> {5.14771009037063, 0.8767832613979392, 0.}, 
      RotationMatrix :> {{-0.8105533458047524, 0.5856648133571978, 
       0.}, {-0.5856648133571978, -0.8105533458047524, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012953072608805799`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29147205909659896`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.458459127051864`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3944483257408247, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8105533458047524, 0.5856648133571978, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4805411901108987`, -0.372600169719215, 0.}, 
      Optica`Optica`RayEnd :> {3.4060816265724547`, -0.350241541182473, 0.}, 
      RotationMatrix :> {{-0.9577527612186518, 0.2875928517506091, 
       0.}, {-0.2875928517506091, -0.9577527612186518, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01743049417627911, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07774403432019454, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.804255399366244`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2838067308718287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9577527612186518, 0.2875928517506091, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4060816265724547`, -0.350241541182473, 0.}, 
      Optica`Optica`RayEnd :> {3.1066298187111636`, -0.2555800674312975, 0.}, 
      RotationMatrix :> {{-0.9534932515709246, 0.3014143646356378, 
       0.}, {-0.3014143646356378, -0.9534932515709246, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017385696064913338`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3140576059326377, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.26906065614655, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08397903591990157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9534932515709246, 0.3014143646356378, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.676768144014921, -3.4053014779424857`, 0.}, 
      Optica`Optica`RayEnd :> {4.657676669171288, -3.4357880667505545`, 0.}, 
      RotationMatrix :> {{-0.5307455390278161, -0.8475312223169559, 0.}, {
       0.8475312223169559, -0.5307455390278161, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09111750408755619, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0359710509834968, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.264792553354905`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3961270499818145, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5307455390278161, -0.8475312223169559, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.657676669171288, -3.4357880667505545`, 0.}, 
      Optica`Optica`RayEnd :> {4.510555217834851, -3.622696215050899, 0.}, 
      RotationMatrix :> {{-0.6185102748664343, -0.7857767112129552, 0.}, {
       0.7857767112129552, -0.6185102748664343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09006462351004987, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23786419937519662`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.616831568430197`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2035133583730158, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6185102748664343, -0.7857767112129552, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.568817617378096, 0.30247733245865827`, 0.}, 
      Optica`Optica`RayEnd :> {2.1565119128098553`, 0.41836773618834916`, 0.},
       RotationMatrix :> {{-0.9626938771495936, 0.2705928655724006, 
       0.}, {-0.2705928655724006, -0.9626938771495936, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01042063444718457, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.4282832937392539, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.907316123268764`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32759579642646397`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9626938771495936, 0.2705928655724006, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1565119128098553`, 0.41836773618834916`, 
       0.}, Optica`Optica`RayEnd :> {1.9254498630377734`, 0.4847035724536128, 
       0.}, RotationMatrix :> {{-0.9611736271136957, 0.2759443033314921, 
       0.}, {-0.2759443033314921, -0.9611736271136957, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010394789967959126`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2403957445918873, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.26310182526476, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11222698636021325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9611736271136957, 0.2759443033314921, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9681142684318607`, -2.6598401862157806`, 
       0.}, Optica`Optica`RayEnd :> {2.919631614244007, -2.7259929176539672`, 
       0.}, RotationMatrix :> {{-0.5911309397152238, -0.8065756084282468, 
       0.}, {0.8065756084282468, -0.5911309397152238, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0375003061033261, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08201677653889992, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.689389715386866`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.396521269393742, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5911309397152238, -0.8065756084282468, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.919631614244007, -2.7259929176539672`, 0.}, 
      Optica`Optica`RayEnd :> {2.7454803212975145`, -2.9218814178830406`, 0.},
       RotationMatrix :> {{-0.6644238989482181, -0.7473559275916986, 0.}, {
       0.7473559275916986, -0.6644238989482181, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03716721373871164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26210871285962745`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.077310610419115`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25606288174611513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6644238989482181, -0.7473559275916986, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.12604817160651, -2.498956565176562, 0.}, 
      Optica`Optica`RayEnd :> {8.246993911727618, -2.6048101806406474`, 0.}, 
      RotationMatrix :> {{0.7524962355808932, -0.6585965498213493, 0.}, {
       0.6585965498213493, 0.7524962355808932, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011439289485791308`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16072604008144134`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.901398572545265`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3262713960568977, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7524962355808932, -0.6585965498213493, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.246993911727618, -2.6048101806406474`, 0.}, 
      Optica`Optica`RayEnd :> {8.464967287231055, -2.8252742464879286`, 0.}, 
      RotationMatrix :> {{0.7030784801708138, -0.7111122630926138, 0.}, {
       0.7111122630926138, 0.7030784801708138, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011373621288093732`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3100270903619173, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.360238666280903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37514461666279353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7030784801708138, -0.7111122630926138, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.018810165197388, -3.6757171600667142`, 0.}, 
      Optica`Optica`RayEnd :> {6.9154365070604165`, -3.8703378116629303`, 0.},
       RotationMatrix :> {{-0.4690895300443783, -0.8831506172803955, 0.}, {
       0.8831506172803955, -0.4690895300443783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.12082548914171178`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22037084930715187`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.855099565050317`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43173098350604344`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.4690895300443783, -0.8831506172803955, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9154365070604165`, -3.8703378116629303`, 
       0.}, Optica`Optica`RayEnd :> {6.847230167096772, -4.057055011384567, 
       0.}, RotationMatrix :> {{-0.34311638534040234`, -0.9392928968702658, 
       0.}, {0.9392928968702658, -0.34311638534040234`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11827831057451985`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1987848522476649, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.14930114637686, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16751064668679447`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.34311638534040234`, -0.9392928968702658, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.815550438724145, 3.3888616835434866`, 0.}, 
      Optica`Optica`RayEnd :> {7.770634920213825, 3.578721628612756, 0.}, 
      RotationMatrix :> {{-0.23021734961239082`, 0.9731392356376586, 
       0.}, {-0.9731392356376586, -0.23021734961239082`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035650189283410655`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1951004934508287, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.458029204212814`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26204406558031257`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23021734961239082`, 0.9731392356376586, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.770634920213825, 3.578721628612756, 0.}, 
      Optica`Optica`RayEnd :> {7.705414945740973, 3.888998368063742, 0.}, 
      RotationMatrix :> {{-0.20570409401938303`, 0.9786142374315147, 
       0.}, {-0.9786142374315147, -0.20570409401938303`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03555074778499699, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3170572505314687, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.927273934999388`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41131189964980786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.20570409401938303`, 0.9786142374315147, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.872301017939595, -0.9226557924440155, 0.}, 
      Optica`Optica`RayEnd :> {3.710162616831017, -0.9425001262725878, 0.}, 
      RotationMatrix :> {{-0.9925932909728907, -0.12148480857953395`, 0.}, {
       0.12148480857953395`, -0.9925932909728907, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013758546110687195`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1633482742459984, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.132486981294615`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4123736863427169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9925932909728907, -0.12148480857953395`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.710162616831017, -0.9425001262725878, 0.}, 
      Optica`Optica`RayEnd :> {3.3837451970089263`, -0.9810609906121149, 0.}, 
      RotationMatrix :> {{-0.9930944213508657, -0.1173178174097564, 0.}, {
       0.1173178174097564, -0.9930944213508657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013724514919912245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32868719509880895`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.618944030040854`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07854086547728707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9930944213508657, -0.1173178174097564, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.575543885995159, -2.7837733642724407`, 0.}, 
      Optica`Optica`RayEnd :> {6.541654341085413, -2.88528378636298, 0.}, 
      RotationMatrix :> {{-0.3166712434025284, -0.94853535706472, 0.}, {
       0.94853535706472, -0.3166712434025284, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023894691349671197`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10701806878835497`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.337595204067753`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06357594400929724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.3166712434025284, -0.94853535706472, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.541654341085413, -2.88528378636298, 0.}, 
      Optica`Optica`RayEnd :> {6.43912162825665, -3.185392938272045, 0.}, 
      RotationMatrix :> {{-0.3233031654339461, -0.9462954418258549, 0.}, {
       0.9462954418258549, -0.3233031654339461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023835213525979424`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3171410731198405, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.806963992285116`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35374247413301174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.3233031654339461, -0.9462954418258549, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.072749319436245, -3.105403635144691, 0.}, 
      Optica`Optica`RayEnd :> {7.08799960753779, -3.150314265218908, 0.}, 
      RotationMatrix :> {{0.3215374596607615, -0.9468968592380606, 0.}, {
       0.9468968592380606, 0.3215374596607615, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2088966120190522, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047429273458943884`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.67107701688922, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.309447231398791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3215374596607615, -0.9468968592380606, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.08799960753779, -3.150314265218908, 0.}, 
      Optica`Optica`RayEnd :> {7.194421264377078, -3.4109465853670002`, 0.}, 
      RotationMatrix :> {{0.37802219224761435`, -0.9257965338930078, 0.}, {
       0.9257965338930078, 0.37802219224761435`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2079332617048073, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28152224663460734`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.08772994190844, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3032863692117086, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.37802219224761435`, -0.9257965338930078, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.410905318833086, -2.699039979861575, 0.}, 
      Optica`Optica`RayEnd :> {7.588084346100509, -2.811015656833259, 0.}, 
      RotationMatrix :> {{0.8453313323148948, -0.5342423968637495, 0.}, {
       0.5342423968637495, 0.8453313323148948, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018272192334172897`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20959713723402162`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.855179092567184`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13831160977245785`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8453313323148948, -0.5342423968637495, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.588084346100509, -2.811015656833259, 0.}, 
      Optica`Optica`RayEnd :> {7.757347622260808, -2.895465567414296, 0.}, 
      RotationMatrix :> {{0.8948111421221451, -0.4464448677429961, 0.}, {
       0.4464448677429961, 0.8948111421221451, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018087030809893354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18916089462059216`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.13513721660566, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07899637174040669, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8948111421221451, -0.4464448677429961, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1268187889837655`, -1.8870016953381006`, 
       0.}, Optica`Optica`RayEnd :> {7.128881658595486, -1.9138761945120275`, 
       0.}, RotationMatrix :> {{0.07653423074927396, -0.9970669543835137, 
       0.}, {0.9970669543835137, 0.07653423074927396, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023590879297095364`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.026953555180798672`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.810783649433194`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16242483784326145`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.07653423074927396, -0.9970669543835137, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.128881658595486, -1.9138761945120275`, 0.}, 
      Optica`Optica`RayEnd :> {7.120352531365677, -2.119608947377167, 0.}, 
      RotationMatrix :> {{-0.041421732818142265`, -0.9991417517301243, 0.}, {
       0.9991417517301243, -0.041421732818142265`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.023253661275712302`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20590947431522152`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.115529671419722`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12272584329561054`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.041421732818142265`, -0.9991417517301243, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.14175033611594, 2.3651174583367935`, 0.}, 
      Optica`Optica`RayEnd :> {5.1076434555438315`, 2.4144414593341925`, 0.}, 
      RotationMatrix :> {{-0.568753292639561, 0.8225081714558568, 
       0.}, {-0.8225081714558568, -0.568753292639561, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008548579474683583, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.059967794496307916`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.858004521313596`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04173354572395346, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.568753292639561, 0.8225081714558568, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1076434555438315`, 2.4144414593341925`, 0.},
       Optica`Optica`RayEnd :> {4.9558269679507205`, 2.6415458060438706`, 0.},
       RotationMatrix :> {{-0.5557479167780192, 0.8313508603453124, 
       0.}, {-0.8313508603453124, -0.5557479167780192, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008526442329211152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27317509073767876`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.26230365560536, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36974287516935567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5557479167780192, 0.8313508603453124, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.653980257328887, -0.3616574428833441, 0.}, 
      Optica`Optica`RayEnd :> {5.594967418142435, -0.41055009918854746`, 0.}, 
      RotationMatrix :> {{-0.7700452553709346, -0.6379892669008717, 0.}, {
       0.6379892669008717, -0.7700452553709346, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17045277011011184`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07663554677448846, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.513518384788814`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06279200931718391, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7700452553709346, -0.6379892669008717, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.594967418142435, -0.41055009918854746`, 0.},
       Optica`Optica`RayEnd :> {5.3552372974225495`, -0.6182436607527533, 0.},
       RotationMatrix :> {{-0.7558022645744128, -0.6547999212463215, 0.}, {
       0.6547999212463215, -0.7558022645744128, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16999037541435172`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31718629588239666`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.982954102694762`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24258373136558842`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7558022645744128, -0.6547999212463215, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.583398214968567, -1.132330017951795, 0.}, 
      Optica`Optica`RayEnd :> {7.618430132596749, -1.2291221078227457`, 0.}, 
      RotationMatrix :> {{0.3403251821117306, -0.9403078062106136, 0.}, {
       0.9403078062106136, 0.3403251821117306, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010318848722259188`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10293660143162836`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.123641827409177`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04314379023835174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3403251821117306, -0.9403078062106136, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.618430132596749, -1.2291221078227457`, 0.}, 
      Optica`Optica`RayEnd :> {7.71366100941622, -1.3953709118801847`, 0.}, 
      RotationMatrix :> {{0.4970497708881461, -0.8677220322545931, 0.}, {
       0.8677220322545931, 0.4970497708881461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009908168301184886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1915922356212119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.40719833612857, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4117658974756776, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4970497708881461, -0.8677220322545931, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.666072835015382, 3.5295693043040495`, 0.}, 
      Optica`Optica`RayEnd :> {7.709587383961219, 3.592447385020252, 0.}, 
      RotationMatrix :> {{0.5690647214197703, 0.8222927354874529, 
       0.}, {-0.8222927354874529, 0.5690647214197703, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0088306303676398, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07646678366789703, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.42788767624562, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4031507270939057, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5690647214197703, 0.8222927354874529, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.709587383961219, 3.592447385020252, 0.}, 
      Optica`Optica`RayEnd :> {7.88750394744357, 3.8598451511704264`, 0.}, 
      RotationMatrix :> {{0.5539485254413076, 0.83255091805931, 
       0.}, {-0.83255091805931, 0.5539485254413076, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00880737111655251, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32117887368797005`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.90323240930382, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11706642771861589`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5539485254413076, 0.83255091805931, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.332726271625041, 3.072085061703826, 0.}, 
      Optica`Optica`RayEnd :> {6.27728416674348, 2.933684843818274, 0.}, 
      RotationMatrix :> {{-0.3718648646289101, -0.9282868750847019, 0.}, {
       0.9282868750847019, -0.3718648646289101, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008389837579523699, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14909207659854462`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.306020507676497`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06598906172033718, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3718648646289101, -0.9282868750847019, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.27728416674348, 2.933684843818274, 0.}, 
      Optica`Optica`RayEnd :> {6.152706677785381, 2.623570492538123, 0.}, 
      RotationMatrix :> {{-0.372761911264312, -0.9279270216512588, 0.}, {
       0.9279270216512588, -0.372761911264312, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008369155533173411, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33420122923923223`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.800638326950562`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3905206819431717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.372761911264312, -0.9279270216512588, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.111084384355568, 3.220486449041145, 0.}, 
      Optica`Optica`RayEnd :> {5.954758455371051, 3.344437558261244, 0.}, 
      RotationMatrix :> {{-0.7835746033926111, 0.6212977071566503, 
       0.}, {-0.6212977071566503, -0.7835746033926111, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.2280447809400767`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19950356776199543`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.76834119765399, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32667581952402985`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 113, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7835746033926111, 0.6212977071566503, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.954758455371051, 3.344437558261244, 0.}, 
      Optica`Optica`RayEnd :> {5.848099970795353, 3.4606262406768167`, 0.}, 
      RotationMatrix :> {{-0.6762488067293465, 0.7366733003150946, 
       0.}, {-0.7366733003150946, -0.6762488067293465, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1907037301657544`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1577207730562187, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.001767941777192`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05137183529418522, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 113, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6762488067293465, 0.7366733003150946, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.848099970795353, 3.4606262406768167`, 0.}, 
      Optica`Optica`RayEnd :> {5.928757673475447, 3.59616286765204, 0.}, 
      RotationMatrix :> {{0.5113955575867246, 0.8593454390875428, 
       0.}, {-0.8593454390875428, 0.5113955575867246, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0362056246933072, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15772077305621876`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.235194685900396`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3971497990540176, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 113, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5113955575867246, 0.8593454390875428, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.316562790117922, 3.3905650271201493`, 0.}, 
      Optica`Optica`RayEnd :> {6.356524519002311, 3.4185556272910147`, 0.}, 
      RotationMatrix :> {{0.8190644360576276, 0.5737015335395216, 
       0.}, {-0.5737015335395216, 0.8190644360576276, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008277122335031238, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04878948117529679, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.961153613446278`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3266971008560266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8190644360576276, 0.5737015335395216, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.356524519002311, 3.4185556272910147`, 0.}, 
      Optica`Optica`RayEnd :> {6.601745336365228, 3.5938447090001717`, 0.}, 
      RotationMatrix :> {{0.813527310642658, 0.5815267103397079, 
       0.}, {-0.5815267103397079, 0.813527310642658, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008256340871542143, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3014291151076432, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.40726870380559, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24759296463374425`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.813527310642658, 0.5815267103397079, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.604405943891403, 2.1458756573122315`, 0.}, 
      Optica`Optica`RayEnd :> {5.592964444774758, 2.143284465560271, 0.}, 
      RotationMatrix :> {{-0.9753011135250474, -0.22087946476936615`, 0.}, {
       0.22087946476936615`, -0.9753011135250474, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03703325219470707, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.01173124787614827, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.079507660933082`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0343035987609327, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9753011135250474, -0.22087946476936615`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.592964444774758, 2.143284465560271, 0.}, 
      Optica`Optica`RayEnd :> {5.434749207937504, 2.0885718099516564`, 0.}, 
      RotationMatrix :> {{-0.9450860289970411, -0.32682166053461503`, 0.}, {
       0.32682166053461503`, -0.9450860289970411, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03658015217719984, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16740829086761222`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.327271931417147`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2174744355829651, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9450860289970411, -0.32682166053461503`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.455720919383612, 2.812084139995091, 0.}, 
      Optica`Optica`RayEnd :> {6.377552899821237, 2.8113232883593313`, 0.}, 
      RotationMatrix :> {{-0.9999526324539878, -0.009733080105449432, 0.}, {
       0.009733080105449432, -0.9999526324539878, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040929026086553834`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07817172236503182, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.903507826786537`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3768869706456195, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999526324539878, -0.009733080105449432, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.377552899821237, 2.8113232883593313`, 0.}, 
      Optica`Optica`RayEnd :> {6.048061583993393, 2.8023330118719088`, 0.}, 
      RotationMatrix :> {{-0.9996279633349783, -0.027275170370912635`, 0.}, {
       0.027275170370912635`, -0.9996279633349783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04082176782059912, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32961394430042545`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.391336464351166`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06920416447048656, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9996279633349783, -0.027275170370912635`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.337832227099149, 2.9099046679207174`, 0.}, 
      Optica`Optica`RayEnd :> {6.225713861223167, 3.070734819407332, 0.}, 
      RotationMatrix :> {{-0.5718771929138912, 0.8203392445963603, 
       0.}, {-0.8203392445963603, -0.5718771929138912, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1662746012651736, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19605322133009676`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.288187449826243`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3718051419643379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5718771929138912, 0.8203392445963603, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.225713861223167, 3.070734819407332, 0.}, 
      Optica`Optica`RayEnd :> {6.116955393542976, 3.2735007709854105`, 0.}, 
      RotationMatrix :> {{-0.47267335600626365`, 0.8812377082954264, 
       0.}, {-0.8812377082954264, -0.47267335600626365`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.163970710004797, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.230092232401502, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.628723953780465`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13399073815016527`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.47267335600626365`, 0.8812377082954264, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.352145538186897, 3.0624226294134362`, 0.}, 
      Optica`Optica`RayEnd :> {6.360730456802546, 3.0850282812256205`, 0.}, 
      RotationMatrix :> {{0.3550287914666034, 0.9348553670112623, 
       0.}, {-0.9348553670112623, 0.3550287914666034, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028216510626910527`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02418090820236142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.284596964661596`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.001099821546759097, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3550287914666034, 0.9348553670112623, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.360730456802546, 3.0850282812256205`, 0.}, 
      Optica`Optica`RayEnd :> {6.420110121692732, 3.3141384967822844`, 0.}, 
      RotationMatrix :> {{0.2508858287998734, 0.968016684209213, 
       0.}, {-0.968016684209213, 0.2508858287998734, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027877254482644786`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23668002762145296`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.634883405541345`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24382244844843423`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2508858287998734, 0.968016684209213, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.256952250972121, -0.4067665791358533, 0.}, 
      Optica`Optica`RayEnd :> {8.26526151421365, -0.5869975905894367, 0.}, 
      RotationMatrix :> {{0.04605448562006194, -0.9989389292415578, 0.}, {
       0.9989389292415578, 0.04605448562006194, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2545870221486679, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18042245244203597`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.98140910883837, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.281990704625553, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.04605448562006194, -0.9989389292415578, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.26526151421365, -0.5869975905894367, 0.}, 
      Optica`Optica`RayEnd :> {8.282525643195672, -0.9400201055250266, 0.}, 
      RotationMatrix :> {{0.04884538790947418, -0.9988063516417843, 0.}, {
       0.9988063516417843, 0.04884538790947418, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2539585588019182, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.35344440326727017`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.504506825673932`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24035735408571804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.04884538790947418, -0.9988063516417843, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.245025077907684, -0.43724862593718694`, 0.},
       Optica`Optica`RayEnd :> {7.117777238390527, -0.4931210008312532, 0.}, 
      RotationMatrix :> {{-0.9156242450712245, -0.40203512512932194`, 0.}, {
       0.40203512512932194`, -0.9156242450712245, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06630948667702445, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13897386422664898`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.354949035336038`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35674503537998986`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9156242450712245, -0.40203512512932194`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.117777238390528, -0.4931210008312532, 0.}, 
      Optica`Optica`RayEnd :> {6.860004043903626, -0.5846922603434024, 0.}, 
      RotationMatrix :> {{-0.9423086162407691, -0.3347453834758687, 0.}, {
       0.3347453834758687, -0.9423086162407691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06592681237779134, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27355495858167794`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.75981037403692, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40241851796666517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9423086162407691, -0.3347453834758687, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.746337843806928, -0.9425816125023615, 0.}, 
      Optica`Optica`RayEnd :> {6.480883233853334, -1.3957434313766623`, 0.}, 
      RotationMatrix :> {{-0.5054474271491045, -0.8628574032760857, 0.}, {
       0.8628574032760857, -0.5054474271491045, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0236113390691958, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5251873799236603, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.035608337540626`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40303950211288886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5054474271491045, -0.8628574032760857, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.480883233853334, -1.3957434313766623`, 0.}, 
      Optica`Optica`RayEnd :> {6.404594217038392, -1.5717003663107687`, 0.}, 
      RotationMatrix :> {{-0.39778746683151855`, -0.9174775916782723, 0.}, {
       0.9174775916782723, -0.39778746683151855`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02325496386566611, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19178335964831755`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.319447709820135`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.16612616892775015`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39778746683151855`, -0.9174775916782723, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.508878933533153, -2.1061952972400784`, 0.}, 
      Optica`Optica`RayEnd :> {7.435440312755351, -2.388980126571918, 0.}, 
      RotationMatrix :> {{-0.2513599379006648, -0.9678936830140866, 0.}, {
       0.9678936830140866, -0.2513599379006648, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18481405850765223`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2921651771207228, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.084283788573273`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37108033566249166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2513599379006648, -0.9678936830140866, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.435440312755351, -2.388980126571918, 0.}, 
      Optica`Optica`RayEnd :> {7.381736509769126, -2.6609417351921207`, 0.}, 
      RotationMatrix :> {{-0.19372736634367638`, -0.9810554049234641, 0.}, {
       0.9810554049234641, -0.19372736634367638`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18397945415253414`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27721330238369124`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.494559476101138`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38157914659693526`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.19372736634367638`, -0.9810554049234641, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.550720203660656, 2.1343176423314136`, 0.}, 
      Optica`Optica`RayEnd :> {4.428443316827227, 2.3187447737060687`, 0.}, 
      RotationMatrix :> {{-0.5525880344424392, 0.8334545363671858, 
       0.}, {-0.8334545363671858, -0.5525880344424392, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00966828209902613, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22128037382641844`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.931360994822896`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39879975991584665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5525880344424392, 0.8334545363671858, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.428443316827227, 2.3187447737060687`, 0.}, 
      Optica`Optica`RayEnd :> {4.337253499543261, 2.5050236894144997`, 0.}, 
      RotationMatrix :> {{-0.4396775345062212, 0.8981557023426002, 
       0.}, {-0.8981557023426002, -0.4396775345062212, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009492820494557604, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2074015844052116, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.23831533974261, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1288354157689644, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4396775345062212, 0.8981557023426002, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.876393431753907, 1.0266974747121043`, 0.}, 
      Optica`Optica`RayEnd :> {3.6701262197708275`, 1.1029914289804044`, 0.}, 
      RotationMatrix :> {{-0.9378987055543281, 0.346909236140399, 
       0.}, {-0.346909236140399, -0.9378987055543281, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03198798382775079, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21992482851457718`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.118218397044938`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22088967115999542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9378987055543281, 0.346909236140399, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6701262197708275`, 1.1029914289804044`, 0.},
       Optica`Optica`RayEnd :> {3.4621819624918184`, 1.1524391197069026`, 0.},
       RotationMatrix :> {{-0.9728724262760617, 0.2313422620096207, 
       0.}, {-0.2313422620096207, -0.9728724262760617, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031504984949511365`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21374257473302333`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.434557407649812`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.43066057614994935`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9728724262760617, 0.2313422620096207, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.834142400424299, 0.5186169949293943, 0.}, 
      Optica`Optica`RayEnd :> {3.73333375410169, 0.37613382223822867`, 0.}, 
      RotationMatrix :> {{-0.5775711298579703, -0.8163403640360967, 0.}, {
       0.8163403640360967, -0.5775711298579703, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24704685203527538`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1745389288197261, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.320379052087276`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33034045125106426`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5775711298579703, -0.8163403640360967, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.73333375410169, 0.37613382223822867`, 0.}, 
      Optica`Optica`RayEnd :> {3.6118972978118684`, 0.16418018278816915`, 0.},
       RotationMatrix :> {{-0.49712642813402036`, -0.8676781168444379, 0.}, {
       0.8676781168444379, -0.49712642813402036`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24479880758501874`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24427680649696468`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.681908725702783`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.163015439494401, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.49712642813402036`, -0.8676781168444379, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.13623424416586, 0.45570602404111304`, 0.}, 
      Optica`Optica`RayEnd :> {4.117262062815048, 0.16049933262649818`, 0.}, 
      RotationMatrix :> {{-0.06413513787571673, -0.9979412227629751, 0.}, {
       0.9979412227629751, -0.06413513787571673, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024564481846496396`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2958157100648506, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.435721811415387`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03247440536848928, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06413513787571673, -0.9979412227629751, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.117262062815048, 0.16049933262649818`, 0.}, 
      Optica`Optica`RayEnd :> {4.08319075266063, -0.12669712854553145`, 0.}, 
      RotationMatrix :> {{-0.11780803501146538`, -0.9930363874938001, 0.}, {
       0.9930363874938001, -0.11780803501146538`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024463118315835128`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2892104104028339, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.86375321881158, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08516765923709735, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.11780803501146538`, -0.9930363874938001, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.627965300614364, -0.36629352393380893`, 0.},
       Optica`Optica`RayEnd :> {4.616643151682505, -0.43049006424632213`, 0.},
       RotationMatrix :> {{-0.17368636606581844`, -0.984801018603682, 0.}, {
       0.984801018603682, -0.17368636606581844`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009193626010791307, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06518732119462609, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.560669225192512`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1387609688074649, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17368636606581844`, -0.984801018603682, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.616643151682505, -0.43049006424632213`, 0.},
       Optica`Optica`RayEnd :> {4.552047754432303, -0.6922139549788413, 0.}, 
      RotationMatrix :> {{-0.2396172809362806, -0.9708674259015505, 0.}, {
       0.9708674259015505, -0.2396172809362806, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009145360169150624, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26957737354251166`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.959643738035428`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10067183708024866`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2396172809362806, -0.9708674259015505, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.825680949044306, 1.5631240269047626`, 0.}, 
      Optica`Optica`RayEnd :> {2.7959855139893546`, 1.6219647450608035`, 0.}, 
      RotationMatrix :> {{-0.4505493171656737, 0.8927515403523782, 
       0.}, {-0.8927515403523782, -0.4505493171656737, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012632468749458765`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06590939975619171, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.834305311451626`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18907505355612486`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4505493171656737, 0.8927515403523782, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7959855139893546`, 1.6219647450608035`, 0.},
       Optica`Optica`RayEnd :> {2.6709939753795493`, 1.8909537908995016`, 0.},
       RotationMatrix :> {{-0.4213990892193527, 0.9068752988173726, 
       0.}, {-0.9068752988173726, -0.4213990892193527, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012594372275134429`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2966108418538668, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.27328935739535, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3711923770207043, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4213990892193527, 0.9068752988173726, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.648326616778112, 1.086860197629454, 0.}, 
      Optica`Optica`RayEnd :> {2.5204903062092607`, 1.0799653130267683`, 0.}, 
      RotationMatrix :> {{-0.9985486595922276, -0.053856981224022965`, 0.}, {
       0.053856981224022965`, -0.9985486595922276, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25022373994894936`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12802211423633078`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.885757234402007`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02029136354033412, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9985486595922276, -0.053856981224022965`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5204903062092607`, 1.0799653130267683`, 0.},
       Optica`Optica`RayEnd :> {2.3688715306818175`, 1.0498166231520185`, 0.},
       RotationMatrix :> {{-0.9807978536342336, -0.1950271014666418, 0.}, {
       0.1950271014666418, -0.9807978536342336, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24449284781285735`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15458718120725637`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.114546262588746`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3202776824437015, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9807978536342336, -0.1950271014666418, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.78724020649285, 0.5557238620463394, 0.}, 
      Optica`Optica`RayEnd :> {2.756798215815996, 0.4170659713737852, 0.}, 
      RotationMatrix :> {{-0.21444017577005045`, -0.9767371248272019, 0.}, {
       0.9767371248272019, -0.21444017577005045`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01160118005522395, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14196029530165, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.36547827354163, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19558448151508578`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.21444017577005045`, -0.9767371248272019, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.756798215815996, 0.4170659713737852, 0.}, 
      Optica`Optica`RayEnd :> {2.6840645451323115`, 0.07101065378714078, 0.}, 
      RotationMatrix :> {{-0.20568530325815487`, -0.97861818704927, 0.}, {
       0.97861818704927, -0.20568530325815487`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011572121172541583`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3536162746270539, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.88883035998967, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3642840886671952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.20568530325815487`, -0.97861818704927, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0974595866669437`, 1.2948117347041475`, 0.},
       Optica`Optica`RayEnd :> {2.0631151281931768`, 1.361958894730527, 0.}, 
      RotationMatrix :> {{-0.45537174328954216`, 0.8903013958280883, 
       0.}, {-0.8903013958280883, -0.45537174328954216`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00865050814160092, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07542070622491223, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.069092378939775`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09302967904923388, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.45537174328954216`, 0.8903013958280883, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0631151281931768`, 1.361958894730527, 0.}, 
      Optica`Optica`RayEnd :> {1.8999957360474449`, 1.691340859919253, 0.}, 
      RotationMatrix :> {{-0.4437897350829148, 0.8961309452502103, 
       0.}, {-0.8961309452502103, -0.4437897350829148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008628455971146688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.36756008364018544`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.61308130272725, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4173529830790826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4437897350829148, 0.8961309452502103, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.198137492260498, 0.1574141637177774, 0.}, 
      Optica`Optica`RayEnd :> {2.2090268470570162`, -0.13268082458635444`, 
       0.}, RotationMatrix :> {{0.03751078631363271, -0.9992962228038953, 
       0.}, {0.9992962228038953, 0.03751078631363271, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00817540533452656, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2902992943275247, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.940722145874958`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39448520044766305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03751078631363271, -0.9992962228038953, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2090268470570162`, -0.13268082458635444`, 
       0.}, Optica`Optica`RayEnd :> {2.2306487365576024`, -0.434011017903535, 
       0.}, RotationMatrix :> {{0.07157079221217699, -0.9974355225788385, 
       0.}, {0.9974355225788385, 0.07157079221217699, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008150231902771919, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30210493460078564`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.38783744908412, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34658124117431144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.07157079221217699, -0.9974355225788385, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.415501185784918, -3.8244870407543035`, 0.}, 
      Optica`Optica`RayEnd :> {7.422972368351319, -3.8454761566998754`, 0.}, 
      RotationMatrix :> {{0.33534379887241306`, -0.9420958213248893, 0.}, {
       0.9420958213248893, 0.33534379887241306`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00835116514709602, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.022279173169513104`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.51892597010377, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4292041457288197, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33534379887241306`, -0.9420958213248893, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.422972368351319, -3.8454761566998754`, 0.}, 
      Optica`Optica`RayEnd :> {7.5064694967424925`, -4.068756492661345, 0.}, 
      RotationMatrix :> {{0.350266384033954, -0.9366501268967927, 0.}, {
       0.9366501268967927, 0.350266384033954, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008329517840496571, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23838179225066478`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.87173102263475, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15559628120604832`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.350266384033954, -0.9366501268967927, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8860657647081065`, 3.0378135942946987`, 0.},
       Optica`Optica`RayEnd :> {2.616602416028211, 3.0080884991397507`, 0.}, 
      RotationMatrix :> {{-0.9939705816670893, -0.10964708286310039`, 0.}, {
       0.10964708286310039`, -0.9939705816670893, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28979145014342367`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27109791139688566`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.36870436701916, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3847369153164286, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9939705816670893, -0.10964708286310039`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.616602416028211, 3.0080884991397507`, 0.}, 
      Optica`Optica`RayEnd :> {2.301734612303231, 2.9715636864263844`, 0.}, 
      RotationMatrix :> {{-0.9933390932043606, -0.11522780008287037`, 0.}, {
       0.11522780008287037`, -0.9933390932043606, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2890726448865627, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31697917244882046`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.837833542243413`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.030874345442535193`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9933390932043606, -0.11522780008287037`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.03176716932845, 3.687293224962993, 0.}, 
      Optica`Optica`RayEnd :> {4.083036431691981, 3.7183520146823694`, 0.}, 
      RotationMatrix :> {{0.8552975713600854, 0.5181371096780647, 
       0.}, {-0.5181371096780647, 0.8552975713600854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03190267015405101, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.059943187120246946`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.03766561367363, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.013171700001029893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8552975713600854, 0.5181371096780647, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.083036431691981, 3.7183520146823694`, 0.}, 
      Optica`Optica`RayEnd :> {4.315560330733823, 3.842826281431774, 0.}, 
      RotationMatrix :> {{0.8816252968873786, 0.4719500353726452, 
       0.}, {-0.4719500353726452, 0.8816252968873786, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03177263621721155, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2637445861215409, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.428007601133512`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.045208836086587594`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.8816252968873786, 0.4719500353726452, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.642666223636448, 3.6503448995112304`, 0.}, 
      Optica`Optica`RayEnd :> {4.648119115760208, 3.6510884643268637`, 0.}, 
      RotationMatrix :> {{0.9908304449457652, 0.13511117410701498`, 
       0.}, {-0.13511117410701498`, 0.9908304449457652, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.032323755905886736`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.005503355444490935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.74059477948397, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24432435097256217`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9908304449457652, 0.13511117410701498`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.648119115760208, 3.6510884643268637`, 0.}, 
      Optica`Optica`RayEnd :> {4.926853849632756, 3.6996533119034503`, 0.}, 
      RotationMatrix :> {{0.9851584628316913, 0.17164732188734683`, 
       0.}, {-0.17164732188734683`, 0.9851584628316913, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03222052453646206, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2829339079840676, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.15933696330039, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3858978715259379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9851584628316913, 0.17164732188734683`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.622413844330305, 3.520465895530815, 0.}, 
      Optica`Optica`RayEnd :> {6.816371544651145, 3.497741381394294, 0.}, 
      RotationMatrix :> {{0.9932063700555314, -0.1163662600632752, 0.}, {
       0.1163662600632752, 0.9932063700555314, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021862514510374933`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19528439020180163`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.22197361491798, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.053254585519778616`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9932063700555314, -0.1163662600632752, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.816371544651145, 3.497741381394294, 0.}, 
      Optica`Optica`RayEnd :> {7.08493018736672, 3.4665318756219445`, 0.}, 
      RotationMatrix :> {{0.9933151195164045, -0.11543428147699442`, 0.}, {
       0.11543428147699442`, 0.9933151195164045, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021808621140697426`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2703660071602689, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.62211530551518, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3985643131925717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9933151195164045, -0.11543428147699442`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.498313174423297, 1.8306402663680825`, 0.}, 
      Optica`Optica`RayEnd :> {6.628465941339579, 1.7376646769887718`, 0.}, 
      RotationMatrix :> {{0.8137058895356496, -0.5812768061216587, 0.}, {
       0.5812768061216587, 0.8137058895356496, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011228579207082773`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15995062662082427`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.815002588777187`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11098838817738571`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8137058895356496, -0.5812768061216587, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.628465941339579, 1.7376646769887718`, 0.}, 
      Optica`Optica`RayEnd :> {6.8423809303975185`, 1.5972051673966625`, 0.}, 
      RotationMatrix :> {{0.8359084340958439, -0.5488689186020952, 0.}, {
       0.5488689186020952, 0.8359084340958439, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011191586991407477`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2559072026702533, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.19374524872916, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05440102770973036, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8359084340958439, -0.5488689186020952, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.119367256792085, 3.0761878458813996`, 0.}, 
      Optica`Optica`RayEnd :> {7.180006138502992, 3.0910293230434465`, 0.}, 
      RotationMatrix :> {{0.9713300967135802, 0.2377348170091756, 
       0.}, {-0.2377348170091756, 0.9713300967135802, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.15686547415048863`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06242870669412381, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.431412671843734`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3293202615565758, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9713300967135802, 0.2377348170091756, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.180006138502992, 3.0910293230434465`, 0.}, 
      Optica`Optica`RayEnd :> {7.358079660061334, 3.168928479704756, 0.}, 
      RotationMatrix :> {{0.9161724655226419, 0.40078424796661216`, 
       0.}, {-0.40078424796661216`, 0.9161724655226419, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1506862901766112, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1943668122101415, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.719075553914745`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23820122787813414`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9161724655226419, 0.40078424796661216`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.529350429469603, 0.870475889649174, 0.}, 
      Optica`Optica`RayEnd :> {6.612412203942919, 0.8204946137409735, 0.}, 
      RotationMatrix :> {{0.8568359197854291, -0.5155891839104628, 0.}, {
       0.5155891839104628, 0.8568359197854291, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09374461823965194, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0969401171861668, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.80203423551381, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22278126786644295`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8568359197854291, -0.5155891839104628, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.612412203942919, 0.8204946137409735, 0.}, 
      Optica`Optica`RayEnd :> {6.913412393865279, 0.6424620335464204, 0.}, 
      RotationMatrix :> {{0.8607150079816966, -0.5090870996549285, 0.}, {
       0.5090870996549285, 0.8607150079816966, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09351088110400799, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34970947076684494`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.319604252248737`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21331004674402515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8607150079816966, -0.5090870996549285, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.162084544223142, 1.0917722028025019`, 0.}, 
      Optica`Optica`RayEnd :> {5.183607526553527, 0.8975625777593969, 0.}, 
      RotationMatrix :> {{0.11014910600937614`, -0.9939150740608244, 0.}, {
       0.9939150740608244, 0.11014910600937614`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.047905335774023894`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19539861112039028`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.00400075946384, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3951391892720212, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.11014910600937614`, -0.9939150740608244, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.183607526553527, 0.8975625777593969, 0.}, 
      Optica`Optica`RayEnd :> {5.223831140464143, 0.6062246397799318, 0.}, 
      RotationMatrix :> {{0.13676776349662986`, -0.9906031389351281, 0.}, {
       0.9906031389351281, 0.13676776349662986`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04776944736918801, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2941015695676529, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.439271082423964`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29734002501418305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.13676776349662986`, -0.9906031389351281, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7662921383577954`, 1.1468848888748389`, 0.},
       Optica`Optica`RayEnd :> {3.6942946472059317`, 1.0427846718180966`, 0.},
       RotationMatrix :> {{-0.5688259651058152, -0.8224579146810107, 0.}, {
       0.8224579146810107, -0.5688259651058152, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03418872254349396, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.126572089827985, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.75120997363064, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38324162656485505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5688259651058152, -0.8224579146810107, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6942946472059317`, 1.0427846718180966`, 0.},
       Optica`Optica`RayEnd :> {3.5400266537753016`, 0.8584285114380503, 0.}, 
      RotationMatrix :> {{-0.641749053479274, -0.7669146969242763, 0.}, {
       0.7669146969242763, -0.641749053479274, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03390025856023029, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24038678763024046`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.106982419323398`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24852940236472076`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.641749053479274, -0.7669146969242763, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3617301027851787`, 3.5264239061816407`, 0.},
       Optica`Optica`RayEnd :> {2.2362153506393723`, 3.5660250924968926`, 0.},
       RotationMatrix :> {{-0.9536591087137046, 0.3008891895156445, 
       0.}, {-0.3008891895156445, -0.9536591087137046, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02281540760599134, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13161385551604543`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.237162458896, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21114952731151207`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9536591087137046, 0.3008891895156445, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2362153506393723`, 3.5660250924968926`, 0.},
       Optica`Optica`RayEnd :> {2.089830620806531, 3.644610377272796, 0.}, 
      RotationMatrix :> {{-0.8810665135324797, 0.4729923876044093, 
       0.}, {-0.4729923876044093, -0.8810665135324797, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021661359017307216`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16614492502494252`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.483056947932916`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23875108882604285`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8810665135324797, 0.4729923876044093, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.319178571095467, 0.030756680964077566`, 0.},
       Optica`Optica`RayEnd :> {2.1509732346100674`, -0.037460808890576236`, 
       0.}, RotationMatrix :> {{-0.9266891229598846, -0.37582877668938447`, 
       0.}, {0.37582877668938447`, -0.9266891229598846, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0800947152327206, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1815121515057223, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.078543169366583`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4108951723023795, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9266891229598846, -0.37582877668938447`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1509732346100674`, -0.037460808890576236`, 
       0.}, Optica`Optica`RayEnd :> {1.8184609758976726`, -0.1543466785264378,
        0.}, RotationMatrix :> {{-0.943409339866201, -0.3316305436072168, 
       0.}, {0.3316305436072168, -0.943409339866201, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07979802317557987, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3524580949766229, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.600181149931984`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3439944803296771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.943409339866201, -0.3316305436072168, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.915873650154078, 2.085425531623274, 0.}, 
      Optica`Optica`RayEnd :> {3.811957347798449, 2.145449446476206, 0.}, 
      RotationMatrix :> {{-0.8659250417956497, 0.5001737917876161, 
       0.}, {-0.5001737917876161, -0.8659250417956497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036140705767510724`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1200061175504753, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.33533016350623, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22710023953627012`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8659250417956497, 0.5001737917876161, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.811957347798449, 2.145449446476206, 0.}, 
      Optica`Optica`RayEnd :> {3.58339473401461, 2.2758211254393754`, 0.}, 
      RotationMatrix :> {{-0.8686284628196504, 0.4954640184509571, 
       0.}, {-0.4954640184509571, -0.8686284628196504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03605109866124203, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2631304678203876, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.68792499038555, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22242865000929885`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8686284628196504, 0.4954640184509571, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8556411871541107`, 1.0443451746924912`, 0.},
       Optica`Optica`RayEnd :> {2.585297879846851, 0.987296686739908, 0.}, 
      RotationMatrix :> {{-0.9784518272705149, -0.20647523268176735`, 0.}, {
       0.20647523268176735`, -0.9784518272705149, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08677719921981861, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2762970028492953, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.7691954478827, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3961022925593427, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9784518272705149, -0.20647523268176735`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.585297879846851, 0.987296686739908, 0.}, 
      Optica`Optica`RayEnd :> {2.345772548463666, 0.9347785088876049, 0.}, 
      RotationMatrix :> {{-0.976796029176284, -0.21417170071100364`, 0.}, {
       0.21417170071100364`, -0.976796029176284, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08656063162434105, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24521530005109965`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.097783949951175`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14723607616413303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.976796029176284, -0.21417170071100364`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9173878228281183`, -0.09386285124665286, 
       0.}, 
      Optica`Optica`RayEnd :> {3.8483375195141334`, -0.14371255809062766`, 
       0.}, RotationMatrix :> {{-0.8107904381118781, -0.5853365403478142, 
       0.}, {0.5853365403478142, -0.8107904381118781, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020376356029900882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08516418061710875, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.633034882463775`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20938971596118144`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8107904381118781, -0.5853365403478142, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8483375195141334`, -0.14371255809062766`, 
       0.}, Optica`Optica`RayEnd :> {
       3.5719528092812887`, -0.34369219067637297`, 0.}, 
      RotationMatrix :> {{-0.810166279235525, -0.5862001364633628, 0.}, {
       0.5862001364633628, -0.810166279235525, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020326123603821886`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34114566023858967`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.090170067183486`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2976441762551221, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.810166279235525, -0.5862001364633628, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.982587617186125, -3.1717560561794467`, 0.}, 
      Optica`Optica`RayEnd :> {5.969952656087857, -3.3732957056206274`, 0.}, 
      RotationMatrix :> {{-0.06256934765806425, -0.9980406187794381, 0.}, {
       0.9980406187794381, -0.06256934765806425, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008106220552827743, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20193531771047077`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.538355697412342`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37991000911731987`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.06256934765806425, -0.9980406187794381, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.969952656087857, -3.3732957056206274`, 0.}, 
      Optica`Optica`RayEnd :> {5.96350433554662, -3.6571197780856823`, 0.}, 
      RotationMatrix :> {{-0.022713566564969034`, -0.9997420136684754, 0.}, {
       0.9997420136684754, -0.022713566564969034`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008079289286411688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28389731409164704`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.95852372226798, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39428105372533784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.022713566564969034`, -0.9997420136684754, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2264786672156953`, -2.866480413713278, 0.}, 
      Optica`Optica`RayEnd :> {2.181353800596747, -2.892619305560026, 0.}, 
      RotationMatrix :> {{-0.8653101113460568, -0.5012368813268572, 0.}, {
       0.5012368813268572, -0.8653101113460568, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15311042820384177`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05214877998912177, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.466762666494866`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23084267716959267`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8653101113460568, -0.5012368813268572, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.181353800596747, -2.892619305560026, 0.}, 
      Optica`Optica`RayEnd :> {1.8925223693054563`, -3.0614739192830824`, 0.},
       RotationMatrix :> {{-0.863297685624581, -0.5046950623844475, 0.}, {
       0.5046950623844475, -0.863297685624581, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15273183879548274`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33456759597626684`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.961922708539742`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23564555493217942`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.863297685624581, -0.5046950623844475, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.873754933729199, 3.6211107541915326`, 0.}, 
      Optica`Optica`RayEnd :> {2.860348670364729, 3.65708926283423, 0.}, 
      RotationMatrix :> {{-0.3491663192320349, 0.937060767247222, 
       0.}, {-0.937060767247222, -0.3491663192320349, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04080590029251491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.038395064546763974`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.886255729976725`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19189874608025784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3491663192320349, 0.937060767247222, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.860348670364729, 3.65708926283423, 0.}, 
      Optica`Optica`RayEnd :> {2.735202566971461, 3.941086772914109, 0.}, 
      RotationMatrix :> {{-0.4032439061750188, 0.9150925374696879, 
       0.}, {-0.9150925374696879, -0.4032439061750188, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04062403406869375, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3103484057089541, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.345571370425976`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2112549414354954, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4032439061750188, 0.9150925374696879, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.667143186592133, 3.386655018692026, 0.}, 
      Optica`Optica`RayEnd :> {3.6629156674126215`, 3.3977027496627663`, 0.}, 
      RotationMatrix :> {{-0.35738724547931544`, 0.9339562927507402, 
       0.}, {-0.9339562927507402, -0.35738724547931544`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.047044108445915965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.011828959295517078`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.91650201393954, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2653117328698939, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.35738724547931544`, 0.9339562927507402, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6629156674126215`, 3.3977027496627663`, 0.},
       Optica`Optica`RayEnd :> {3.5490640983277992`, 3.6362395798778353`, 0.},
       RotationMatrix :> {{-0.4307432849935779, 0.9024744996025872, 
       0.}, {-0.9024744996025872, -0.4307432849935779, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04673044047412252, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2643142053544015, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.307687037864053`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1626346452830975, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4307432849935779, 0.9024744996025872, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.081675417603904, 0.3567032731689679, 0.}, 
      Optica`Optica`RayEnd :> {8.112777383536885, 0.3310916078713156, 0.}, 
      RotationMatrix :> {{0.7719511649691657, -0.6356818377952499, 0.}, {
       0.6356818377952499, 0.7719511649691657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03160703826305748, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.040290069300205, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.335883207366585`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35867570374320334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7719511649691657, -0.6356818377952499, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.112777383536885, 0.3310916078713156, 0.}, 
      Optica`Optica`RayEnd :> {8.35458679363506, 0.12765032623837, 0.}, 
      RotationMatrix :> {{0.7652037672676134, -0.6437881596918746, 0.}, {
       0.6437881596918746, 0.7652037672676134, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03152737399264827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31600655987571297`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.80357291598264, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21672326563423663`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7652037672676134, -0.6437881596918746, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.173986439691582, 0.09385754040219779, 0.}, 
      Optica`Optica`RayEnd :> {7.274268209074545, -0.1363595633154113, 0.}, 
      RotationMatrix :> {{0.39935357863419385`, -0.9167969891050374, 0.}, {
       0.9167969891050374, 0.39935357863419385`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012437522237085495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25111023100364155`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.86436750307398, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15535145159505648`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.39935357863419385`, -0.9167969891050374, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.274268209074545, -0.1363595633154113, 0.}, 
      Optica`Optica`RayEnd :> {7.361821664728799, -0.379995678727669, 0.}, 
      RotationMatrix :> {{0.33818752863485885`, -0.9410787403165826, 0.}, {
       0.9410787403165826, 0.33818752863485885`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012374114899797433`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25889025537894683`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.24752508103482, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18269331148006157`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.33818752863485885`, -0.9410787403165826, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.60623413005632, 2.1637909267630078`, 0.}, 
      Optica`Optica`RayEnd :> {4.18329341596266, 2.0581945319702597`, 0.}, 
      RotationMatrix :> {{-0.9702173637646916, -0.2422359738963035, 0.}, {
       0.2422359738963035, -0.9702173637646916, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01816443087132368, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4359236701892672, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.129499294292778`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24853913617775875`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9702173637646916, -0.2422359738963035, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.18329341596266, 2.0581945319702597`, 0.}, 
      Optica`Optica`RayEnd :> {3.8735678907445887`, 1.9718076657689771`, 0.}, 
      RotationMatrix :> {{-0.9632350724931865, -0.26865999910489896`, 0.}, {
       0.26865999910489896`, -0.9632350724931865, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01811263836004397, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3215471841327312, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.60538912680922, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00851659129313348, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9632350724931865, -0.26865999910489896`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.101941934037496, 2.654840751506858, 0.}, 
      Optica`Optica`RayEnd :> {6.0951283677385755`, 2.6488139974837615`, 0.}, 
      RotationMatrix :> {{-0.7490310160229084, -0.6625349326908645, 0.}, {
       0.6625349326908645, -0.7490310160229084, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010783883655519206`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.009096507558656772, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.296920739336805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12195104992226961`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7490310160229084, -0.6625349326908645, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.0951283677385755`, 2.6488139974837615`, 0.},
       Optica`Optica`RayEnd :> {5.888508547977647, 2.4429143369798125`, 0.}, 
      RotationMatrix :> {{-0.708340139240514, -0.7058712681082352, 0.}, {
       0.7058712681082352, -0.708340139240514, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010734899908417542`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29169576636228384`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.728630473552986`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13515731918315965`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.708340139240514, -0.7058712681082352, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4872954362059225`, 2.3272620760423, 0.}, 
      Optica`Optica`RayEnd :> {7.527369175267768, 2.2124021505044738`, 0.}, 
      RotationMatrix :> {{0.3294184954469545, -0.944184015357951, 0.}, {
       0.944184015357951, 0.3294184954469545, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010139194142948596`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12164993652670725`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.312233074427077`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1595243117333467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.3294184954469545, -0.944184015357951, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.527369175267768, 2.2124021505044738`, 0.}, 
      Optica`Optica`RayEnd :> {7.613073684194516, 1.9149759269957787`, 0.}, 
      RotationMatrix :> {{0.2768876861157384, -0.9609022891415501, 0.}, {
       0.9609022891415501, 0.2768876861157384, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010096473093018712`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3095280621866445, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.77033460646331, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11709329342760322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2768876861157384, -0.9609022891415501, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.412708949979767, 1.3649542899157536`, 0.}, 
      Optica`Optica`RayEnd :> {7.4275612104463455`, 1.1868517104206138`, 0.}, 
      RotationMatrix :> {{0.08310315215522004, -0.9965409505393468, 0.}, {
       0.9965409505393468, 0.08310315215522004, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012766164838981913`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17872078352499937`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 17.752439867202654`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41662552361977245`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.08310315215522004, -0.9965409505393468, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4275612104463455`, 1.1868517104206138`, 0.},
       Optica`Optica`RayEnd :> {7.4349281815717845`, 0.8897875450281161, 0.}, 
      RotationMatrix :> {{0.024791636529180268`, -0.9996926401440612, 0.}, {
       0.9996926401440612, 0.024791636529180268`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012709240607369532`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2971554990638811, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.150628235948254`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4298163411073512, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.024791636529180268`, -0.9996926401440612, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1432445512089, 1.8362821881632283`, 0.}, 
      Optica`Optica`RayEnd :> {3.920732809479422, 1.7167830393253625`, 0.}, 
      RotationMatrix :> {{-0.8809909597118113, -0.47313309851040924`, 0.}, {
       0.47313309851040924`, -0.8809909597118113, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01036473004938714, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2525698354524159, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.649816604796527`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30287915534211807`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.8809909597118113, -0.47313309851040924`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.920732809479422, 1.7167830393253625`, 0.}, 
      Optica`Optica`RayEnd :> {3.7061559660456895`, 1.6302363202035928`, 0.}, 
      RotationMatrix :> {{-0.9274057934900721, -0.37405680611512543`, 0.}, {
       0.37405680611512543`, -0.9274057934900721, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010239825751505265`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23137319708368756`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.992248936480383`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4011555675664575, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9274057934900721, -0.37405680611512543`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.357456586428072, 3.437434345337315, 0.}, 
      Optica`Optica`RayEnd :> {3.1387202755849977`, 3.6112018223763473`, 0.}, 
      RotationMatrix :> {{-0.7829973241199374, 0.6220250721803879, 
       0.}, {-0.6220250721803879, -0.7829973241199374, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.031130926305780807`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2793576735258023, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.16356264909843, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25993269525961166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7829973241199374, 0.6220250721803879, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1387202755849977`, 3.6112018223763473`, 0.},
       Optica`Optica`RayEnd :> {2.9882413674549433`, 3.6907620563599965`, 0.},
       RotationMatrix :> {{-0.8840430358851412, 0.46740550991936547`, 
       0.}, {-0.46740550991936547`, -0.8840430358851412, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.029610080232268826`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1702167225144062, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.415483398419752`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29099900246449706`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8840430358851412, 0.46740550991936547`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6415973214998734`, -0.7773224395460558, 0.},
       Optica`Optica`RayEnd :> {3.617055429827024, -0.8068031282257101, 0.}, 
      RotationMatrix :> {{-0.6397943176989501, -0.7685461801610449, 0.}, {
       0.7685461801610449, -0.6397943176989501, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012211260228580977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.038359033511137494`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.162631297027122`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.039003946123868545`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6397943176989501, -0.7685461801610449, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.617055429827024, -0.8068031282257101, 0.}, 
      Optica`Optica`RayEnd :> {3.417849472132508, -1.058102453305081, 0.}, 
      RotationMatrix :> {{-0.6212024913802895, -0.7836500907311373, 0.}, {
       0.7836500907311373, -0.6212024913802895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012177567440452109`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3206779761167526, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.637234701679915`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3127434357970288, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6212024913802895, -0.7836500907311373, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1945212760539454`, 3.3748669079486944`, 0.},
       Optica`Optica`RayEnd :> {2.160334222458122, 3.5789906596311543`, 0.}, 
      RotationMatrix :> {{-0.16518133278877967`, 0.9862632140043159, 
       0.}, {-0.9862632140043159, -0.16518133278877967`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008651802627114628, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2069668104660415, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.489947654052955`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40661537070879544`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.16518133278877967`, 0.9862632140043159, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.160334222458122, 3.5789906596311543`, 0.}, 
      Optica`Optica`RayEnd :> {2.133292155381548, 3.839095338540685, 0.}, 
      RotationMatrix :> {{-0.10340872469098916`, 0.9946389473863287, 
       0.}, {-0.9946389473863287, -0.10340872469098916`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008610412978161293, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26150662971023114`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.876977466024098`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4030479034907626, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.10340872469098916`, 0.9946389473863287, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5751762563305114`, 0.164338020188098, 0.}, 
      Optica`Optica`RayEnd :> {2.565815094168653, 0.1410710166466319, 0.}, 
      RotationMatrix :> {{-0.37325848548829177`, -0.9277273861490705, 0.}, {
       0.9277273861490705, -0.37325848548829177`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012302829270137653`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.02507956958999104, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.914398929270412`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02230159788342379, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.37325848548829177`, -0.9277273861490705, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.565815094168653, 0.14107101664663185`, 0.}, 
      Optica`Optica`RayEnd :> {2.4346059552727373`, -0.17662184558167104`, 
       0.}, RotationMatrix :> {{-0.3817307629595219, -0.9242735658939625, 
       0.}, {0.9242735658939625, -0.3817307629595219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012271991089420805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34372167932881276`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.423107014677054`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3682746097830654, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 112, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3817307629595219, -0.9242735658939625, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3847323755227645`, -1.8228940275480667`, 
       0.}, Optica`Optica`RayEnd :> {7.429132867141638, -1.8261112150576801`, 
       0.}, RotationMatrix :> {{0.997385183655039, -0.07226891050378742, 
       0.}, {0.07226891050378742, 0.997385183655039, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008010029056709446, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04451689512386983, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.344795239861035`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.387698295495279, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 115, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.997385183655039, -0.07226891050378742, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.810627423020948, -2.0628701227823787`, 0.}, 
      Optica`Optica`RayEnd :> {4.655261269437338, -2.072482187679916, 0.}, 
      RotationMatrix :> {{-0.9980917027042592, -0.06174911329657099, 0.}, {
       0.06174911329657099, -0.9980917027042592, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019646612013615936`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15566320525724975`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.84183709974044, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3254701126351182, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9980917027042592, -0.06174911329657099, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.655261269437338, -2.072482187679916, 0.}, 
      Optica`Optica`RayEnd :> {4.34509924734631, -2.079337547647544, 0.}, 
      RotationMatrix :> {{-0.9997558289291749, -0.02209711569726721, 0.}, {
       0.02209711569726721, -0.9997558289291749, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019581525776108916`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31023777318031504`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.30098900404731, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18665436597648663`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9997558289291749, -0.02209711569726721, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.866622737248663, -4.094535006342286, 0.}, 
      Optica`Optica`RayEnd :> {6.859571591560801, -4.212627155441221, 0.}, 
      RotationMatrix :> {{-0.05960269220454964, -0.9982221792176174, 0.}, {
       0.9982221792176174, -0.05960269220454964, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03754947117633854, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11830246968815375`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.560480808360715`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32790379044579476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.05960269220454964, -0.9982221792176174, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.859571591560801, -4.212627155441221, 0.}, 
      Optica`Optica`RayEnd :> {6.816528145569681, -4.383112257242901, 0.}, 
      RotationMatrix :> {{-0.24479468348539785`, -0.9695749393096355, 0.}, {
       0.9695749393096355, -0.24479468348539785`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0356307897580996, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17583488897007823`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.82071644403643, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10942513187173403`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.24479468348539785`, -0.9695749393096355, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.2235295923556375`, -2.3817523947534873`, 
       0.}, Optica`Optica`RayEnd :> {
       5.8106301849454995`, -2.3974929692183786`, 0.}, 
      RotationMatrix :> {{-0.999274145473604, -0.03809438525554418, 0.}, {
       0.03809438525554418, -0.999274145473604, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011923848279014368`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.41319933001413267`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.659613009604694`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.046774507340203504`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.999274145473604, -0.03809438525554418, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8106301849454995`, -2.3974929692183786`, 
       0.}, Optica`Optica`RayEnd :> {5.604807374485697, -2.3781584461875953`, 
       0.}, RotationMatrix :> {{-0.9956168409963081, 0.0935259639059213, 
       0.}, {-0.0935259639059213, -0.9956168409963081, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011700911716802006`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20672893625808533`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.965571835266662`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34669598060675005`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9956168409963081, 0.0935259639059213, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.979510040500845, 0.14198319736464082`, 0.}, 
      Optica`Optica`RayEnd :> {8.006806903401426, 0.34488466422178027`, 0.}, 
      RotationMatrix :> {{0.1333314314310333, 0.9910715056909623, 
       0.}, {-0.9910715056909623, 0.1333314314310333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013288639563887815`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20472939206912127`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.861092395937234`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28082683796415703`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.1333314314310333, 0.9910715056909623, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.006806903401426, 0.34488466422178027`, 0.}, 
      Optica`Optica`RayEnd :> {8.049286457408408, 0.6750501916120701, 0.}, 
      RotationMatrix :> {{0.12760951205765939`, 0.9918244867074041, 
       0.}, {-0.9918244867074041, 0.12760951205765939`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0132556663911243, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3328870498916118, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.35376522977682, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1669633468142008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.12760951205765939`, 0.9918244867074041, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.14771009037063, 0.8767832613979392, 0.}, 
      Optica`Optica`RayEnd :> {5.128144313032029, 0.8900298355245744, 0.}, 
      RotationMatrix :> {{-0.8280692354580034, 0.5606258478593344, 
       0.}, {-0.5606258478593344, -0.8280692354580034, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01291483004381035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.023628190132893977`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.490120901829943`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1554194817855335, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8280692354580034, 0.5606258478593344, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.128144313032029, 0.8900298355245744, 0.}, 
      Optica`Optica`RayEnd :> {4.857304483961946, 1.0785491778117529`, 0.}, 
      RotationMatrix :> {{-0.8207502869363063, 0.5712871138875536, 
       0.}, {-0.5712871138875536, -0.8207502869363063, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01288191299428509, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3299905383902721, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.978506898647545`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2331150071327467, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8207502869363063, 0.5712871138875536, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1066298187111636`, -0.2555800674312975, 0.},
       Optica`Optica`RayEnd :> {2.913926441095321, -0.19158357221137529`, 0.},
       RotationMatrix :> {{-0.9490342924542482, 0.31517282837494764`, 
       0.}, {-0.31517282837494764`, -0.9490342924542482, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017341013089169174`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20305207003374137`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.541150429991763`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3070473401524301, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9490342924542482, 0.31517282837494764`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.913926441095321, -0.19158357221137529`, 0.},
       Optica`Optica`RayEnd :> {2.6677729820998963`, -0.13071392041402335`, 
       0.}, RotationMatrix :> {{-0.9707598462244589, 0.2400527462002147, 
       0.}, {-0.2400527462002147, -0.9707598462244589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017229021097724437`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2535678210762226, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.91643080518457, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3824221342801126, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9707598462244589, 0.2400527462002147, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.510555217834851, -3.622696215050899, 0.}, 
      Optica`Optica`RayEnd :> {4.346861212778436, -3.790094402998322, 0.}, 
      RotationMatrix :> {{-0.6991520803106008, -0.7149729845227435, 0.}, {
       0.7149729845227435, -0.6991520803106008, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08902390917350449, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23413218621003476`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.930568697951642`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4116638537516605, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6991520803106008, -0.7149729845227435, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.346861212778436, -3.790094402998322, 0.}, 
      Optica`Optica`RayEnd :> {4.199850853875885, -3.9113342055346747`, 0.}, 
      RotationMatrix :> {{-0.7714859543560042, -0.6362463534130514, 0.}, {
       0.6362463534130514, -0.7714859543560042, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08800349095817998, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1905548092904256, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.212589815701474`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2966696842364763, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7714859543560042, -0.6362463534130514, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7454803212975145`, -2.9218814178830406`, 
       0.}, Optica`Optica`RayEnd :> {2.4385228322540007`, -3.207733694584439, 
       0.}, RotationMatrix :> {{-0.7318175523500778, -0.6815006016668959, 
       0.}, {0.6815006016668959, -0.7318175523500778, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.036837080030569444`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.4194453768672051, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.63936741542117, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43152753205807376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7318175523500778, -0.6815006016668959, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4385228322540007`, -3.207733694584439, 0.}, 
      Optica`Optica`RayEnd :> {2.2504504448487164`, -3.355483321000886, 0.}, 
      RotationMatrix :> {{-0.7863620796138583, -0.6177658777768225, 0.}, {
       0.6177658777768225, -0.7863620796138583, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03657096042967973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23916767133231648`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.993335568992997`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34753191926910004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7863620796138583, -0.6177658777768225, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.847230167096772, -4.057055011384567, 0.}, 
      Optica`Optica`RayEnd :> {6.825875960104849, -4.156169652824735, 0.}, 
      RotationMatrix :> {{-0.2106167591096555, -0.9775687089827214, 0.}, {
       0.9775687089827214, -0.2106167591096555, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11578483026834266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10138892594394595`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.285162307141746`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14917807690267273`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.2106167591096555, -0.9775687089827214, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.825875960104849, -4.156169652824735, 0.}, 
      Optica`Optica`RayEnd :> {6.750818439690522, -4.419688470805187, 0.}, 
      RotationMatrix :> {{-0.273932923319292, -0.9617487995946479, 0.}, {
       0.9617487995946479, -0.273932923319292, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11520049002439489`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27399963284749385`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.690681763756036`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12466585939320929`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.273932923319292, -0.9617487995946479, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3837451970089263`, -0.9810609906121149, 0.},
       Optica`Optica`RayEnd :> {3.1151139283275167`, -1.0116527439306593`, 
       0.}, RotationMatrix :> {{-0.9935780584231843, -0.11314875969278287`, 
       0.}, {0.11314875969278287`, -0.9935780584231843, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01369056790387031, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2703675533130526, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.981236551480343`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3993756024923282, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9935780584231843, -0.11314875969278287`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1151139283275167`, -1.0116527439306593`, 
       0.}, Optica`Optica`RayEnd :> {2.833124009085632, -1.0373182512021093`, 
       0.}, RotationMatrix :> {{-0.9958836290091447, -0.09064103635537263, 
       0.}, {0.09064103635537263, -0.9958836290091447, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013653239158579933`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2831554922962741, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.400306680078828`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1494367615048074, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9958836290091447, -0.09064103635537263, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.43912162825665, -3.185392938272045, 0.}, 
      Optica`Optica`RayEnd :> {6.4054814356495156`, -3.2816487654920232`, 0.},
       RotationMatrix :> {{-0.3299192457363408, -0.9440091584792827, 0.}, {
       0.9440091584792827, -0.3299192457363408, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02377588375239048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10196492942402993`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.943596997713318`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3846709356054306, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3299192457363408, -0.9440091584792827, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.4054814356495156`, -3.2816487654920232`, 
       0.}, Optica`Optica`RayEnd :> {6.323627665433101, -3.3923747599303007`, 
       0.}, RotationMatrix :> {{-0.5944512590188872, -0.8041316438561906, 
       0.}, {0.8041316438561906, -0.5944512590188872, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017845064802731653`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1376963526858541, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.147387599688383`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028275587434804066`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.5944512590188872, -0.8041316438561906, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.194421264377078, -3.4109465853670002`, 0.}, 
      Optica`Optica`RayEnd :> {7.321252999872217, -3.674877994366107, 0.}, 
      RotationMatrix :> {{0.4331325311233923, -0.9013302449616584, 0.}, {
       0.9013302449616584, 0.4331325311233923, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.206974353989315, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29282431214802346`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.480114520186792`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1658925130781099, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4331325311233923, -0.9013302449616584, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.321252999872217, -3.674877994366107, 0.}, 
      Optica`Optica`RayEnd :> {7.396788952294392, -3.863917628126922, 0.}, 
      RotationMatrix :> {{0.371052293978078, -0.9286119723186889, 0.}, {
       0.9286119723186889, 0.371052293978078, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2058791164333152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20357225557709954`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.7814014584409, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20483338923583563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.371052293978078, -0.9286119723186889, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.757347622260808, -2.895465567414296, 0.}, 
      Optica`Optica`RayEnd :> {7.85372094736996, -2.9319571685943555`, 0.}, 
      RotationMatrix :> {{0.9352026614542621, -0.3541129509194261, 0.}, {
       0.3541129509194261, 0.9352026614542621, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01790374562258787, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10305073871292172`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.273225206480976`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28248924125063846`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9352026614542621, -0.3541129509194261, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.85372094736996, -2.9319571685943555`, 0.}, 
      Optica`Optica`RayEnd :> {8.166895214856064, -3.0588244373516718`, 0.}, 
      RotationMatrix :> {{0.9268374086576752, -0.37546293813467735`, 0.}, {
       0.37546293813467735`, 0.9268374086576752, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01785479870312892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3378955840158289, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.773310670824404`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3846715748511858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9268374086576752, -0.37546293813467735`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.120352531365677, -2.119608947377167, 0.}, 
      Optica`Optica`RayEnd :> {7.118421919627566, -2.1316120902231095`, 0.}, 
      RotationMatrix :> {{-0.15880119226528078`, -0.987310579977306, 0.}, {
       0.987310579977306, -0.15880119226528078`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022921263591566918`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01215741337059176, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.131820605336316`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3584328759875169, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.15880119226528078`, -0.987310579977306, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.118421919627566, -2.1316120902231095`, 0.}, 
      Optica`Optica`RayEnd :> {7.109466376042483, -2.3475363475123796`, 0.}, 
      RotationMatrix :> {{-0.04143976652157272, -0.9991410039382012, 0.}, {
       0.9991410039382012, -0.04143976652157272, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022593734368124205`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21610989483785112`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.451663249696335`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3283343831540146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.04143976652157272, -0.9991410039382012, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.9558269679507205`, 2.6415458060438706`, 0.},
       Optica`Optica`RayEnd :> {4.9018847525001386`, 2.7250518604226603`, 0.},
       RotationMatrix :> {{-0.5426050861458167, 0.8399879287755808, 
       0.}, {-0.8399879287755808, -0.5426050861458167, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008504362509427871, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09941339811931968, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.39551760908525, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3365020494431064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.5426050861458167, 0.8399879287755808, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.9018847525001386`, 2.7250518604226603`, 0.},
       Optica`Optica`RayEnd :> {4.745581720203257, 2.93105649072293, 0.}, 
      RotationMatrix :> {{-0.6044445481357582, 0.7966472169216173, 
       0.}, {-0.7966472169216173, -0.6044445481357582, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008452235239997557, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25858953113061456`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.77823011515856, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2655397176408497, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6044445481357582, 0.7966472169216173, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3552372974225495`, -0.6182436607527533, 0.},
       Optica`Optica`RayEnd :> {5.313269548490573, -0.656253555064122, 0.}, 
      RotationMatrix :> {{-0.7411923613406239, -0.6712926958416198, 0.}, {
       0.6712926958416198, -0.7411923613406239, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16952923507693698`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.056621939351976056`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.05882750142641, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12353055223992801`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7411923613406239, -0.6712926958416198, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.313269548490573, -0.656253555064122, 0.}, 
      Optica`Optica`RayEnd :> {5.0950691582980365`, -0.8562053790945715, 0.}, 
      RotationMatrix :> {{-0.7372638654789411, -0.6756049086996403, 0.}, {
       0.6756049086996403, -0.7372638654789411, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1691085201095186, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29595969694078084`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.496847852898767`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31673065781625476`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7372638654789411, -0.6756049086996403, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.71366100941622, -1.3953709118801847`, 0.}, 
      Optica`Optica`RayEnd :> {7.846069552065707, -1.5547823287806197`, 0.}, 
      RotationMatrix :> {{0.638946723154656, -0.7692509895800766, 0.}, {
       0.7692509895800766, 0.638946723154656, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009513832572507326, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2072293946445952, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.684885724952327`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.030400776388372124`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.638946723154656, -0.7692509895800766, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.846069552065707, -1.5547823287806197`, 0.}, 
      Optica`Optica`RayEnd :> {7.994065167912832, -1.694889300567602, 0.}, 
      RotationMatrix :> {{0.7261961568709083, -0.6874875575208055, 0.}, {
       0.6874875575208055, 0.7261961568709083, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009373462859084827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.203795647287394, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.98650328293767, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25263240093561307`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7261961568709083, -0.6874875575208055, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.152706677785381, 2.623570492538123, 0.}, 
      Optica`Optica`RayEnd :> {6.151437642763765, 2.620420253012436, 0.}, 
      RotationMatrix :> {{-0.3736586096702163, -0.92756630136035, 0.}, {
       0.92756630136035, -0.3736586096702163, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008348524470770927, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.003396241887040037, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.805189291079195`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06643676951656123, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3736586096702163, -0.92756630136035, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.151437642763765, 2.6204202530124365`, 0.}, 
      Optica`Optica`RayEnd :> {6.022441816341458, 2.3231662784791007`, 0.}, 
      RotationMatrix :> {{-0.3980900499464742, -0.9173463425193411, 0.}, {
       0.9173463425193411, -0.3980900499464742, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008324924162037084, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3240368013208358, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.284763757034032`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3165687988328613, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.3980900499464742, -0.9173463425193411, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.954758455371051, 3.344437558261244, 0.}, 
      Optica`Optica`RayEnd :> {5.920544336604041, 3.3340937605348855`, 0.}, 
      RotationMatrix :> {{-0.9572114708667486, -0.2893893571662825, 0.}, {
       0.2893893571662825, -0.9572114708667486, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037341050774322045`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03574353192406814, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 17.81623753043224, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2944749349077164, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9572114708667486, -0.2893893571662825, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.920544336604041, 3.3340937605348855`, 0.}, 
      Optica`Optica`RayEnd :> {5.6701500886058795`, 3.255165769425571, 0.}, 
      RotationMatrix :> {{-0.9537399007267549, -0.30063300178409974`, 0.}, {
       0.30063300178409974`, -0.9537399007267549, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037246420574836535`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2625393441202988, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.20479575973028, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09603641027115631, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9537399007267549, -0.30063300178409974`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.848099970795353, 3.4606262406768167`, 0.}, 
      Optica`Optica`RayEnd :> {5.763727798657249, 3.5880340962695576`, 0.}, 
      RotationMatrix :> {{-0.5521315127176641, 0.8337570345514949, 
       0.}, {-0.8337570345514949, -0.5521315127176641, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1544981054724472`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15281173089145536`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.206535661171742`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29350846887258425`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5521315127176641, 0.8337570345514949, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.763727798657249, 3.5880340962695576`, 0.}, 
      Optica`Optica`RayEnd :> {5.624661889022492, 3.837040565238847, 0.}, 
      RotationMatrix :> {{-0.4875948647352788, 0.8730700131626237, 
       0.}, {-0.8730700131626237, -0.4875948647352788, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1474144156040729`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2852079045382443, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.628643359888343`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21674423622453948`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.4875948647352788, 0.8730700131626237, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.601745336365228, 3.5938447090001717`, 0.}, 
      Optica`Optica`RayEnd :> {6.624242981949835, 3.610254629137234, 0.}, 
      RotationMatrix :> {{0.8079154276406527, 0.5892984488187795, 
       0.}, {-0.5892984488187795, 0.8079154276406527, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008235611584305526, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.027846535435406484`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.444583061289038`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4098168330640591, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8079154276406527, 0.5892984488187795, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.624242981949835, 3.610254629137234, 0.}, 
      Optica`Optica`RayEnd :> {6.882779322650426, 3.811935048904515, 0.}, 
      RotationMatrix :> {{0.7884696577494501, 0.61507365315746, 
       0.}, {-0.61507365315746, 0.7884696577494501, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008210805481025828, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32789637262458154`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.92986969277342, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31556536173977406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7884696577494501, 0.61507365315746, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.434749207937504, 2.0885718099516564`, 0.}, 
      Optica`Optica`RayEnd :> {5.164801340599267, 1.9604416019457573`, 0.}, 
      RotationMatrix :> {{-0.9034007186940066, -0.4287973197947387, 0.}, {
       0.4287973197947387, -0.9034007186940066, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03613259581610135, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29881298714095006`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.72768133418602, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42475087657213983`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9034007186940066, -0.4287973197947387, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.164801340599267, 1.9604416019457573`, 0.}, 
      Optica`Optica`RayEnd :> {4.946889611226584, 1.869578185063331, 0.}, 
      RotationMatrix :> {{-0.9229763465958096, -0.3848566793296579, 0.}, {
       0.3848566793296579, -0.9229763465958096, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03599695695836152, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23609676475069027`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.07710454601704, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3663437208438175, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9229763465958096, -0.3848566793296579, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.048061583993393, 2.8023330118719088`, 0.}, 
      Optica`Optica`RayEnd :> {5.8591954719604376`, 2.793861627005079, 0.}, 
      RotationMatrix :> {{-0.9989955783992226, -0.04480886451140724, 0.}, {
       0.04480886451140724, -0.9989955783992226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040714790634765664`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18905600396709665`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.644671509667077`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43185728692092806`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9989955783992226, -0.04480886451140724, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8591954719604376`, 2.793861627005079, 0.}, 
      Optica`Optica`RayEnd :> {5.542744171328283, 2.780874315517512, 0.}, 
      RotationMatrix :> {{-0.9991589020922901, -0.04100595529588886, 0.}, {
       0.04100595529588886, -0.9991589020922901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04061414788246977, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3167176912195738, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.113413692672047`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.038677117416907394`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9991589020922901, -0.04100595529588886, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.116955393542976, 3.2735007709854105`, 0.}, 
      Optica`Optica`RayEnd :> {6.07412909135062, 3.3820288297901584`, 0.}, 
      RotationMatrix :> {{-0.3670647837153119, 0.9301953797756847, 
       0.}, {-0.9301953797756847, -0.3670647837153119, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16169874132850273`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11667232622776416`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.78506487092567, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13575788167523348`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3670647837153119, 0.9301953797756847, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.07412909135062, 3.3820288297901584`, 0.}, 
      Optica`Optica`RayEnd :> {5.974551438823336, 3.606204375382554, 0.}, 
      RotationMatrix :> {{-0.40594808017870554`, 0.9138961408164618, 
       0.}, {-0.9138961408164618, -0.40594808017870554`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1611439538202129, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24529652285446835`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.148103724750282`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26604385072503045`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.40594808017870554`, 0.9138961408164618, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.420110121692732, 3.3141384967822844`, 0.}, 
      Optica`Optica`RayEnd :> {6.428544256025292, 3.3722030476344838`, 0.}, 
      RotationMatrix :> {{0.14374592711972045`, 0.9896146262240119, 
       0.}, {-0.9896146262240119, 0.14374592711972045`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027542077323656298`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.058673901247550696`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.713506433213063`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36166095170921575`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.14374592711972045`, 0.9896146262240119, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.428544256025292, 3.3722030476344838`, 0.}, 
      Optica`Optica`RayEnd :> {6.475677707174433, 3.668722634526091, 0.}, 
      RotationMatrix :> {{0.15698472216016346`, 0.9876010312916319, 
       0.}, {-0.9876010312916319, 0.15698472216016346`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.027471709648714253`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30024228154541766`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.15786500990028, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23677962853672294`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.15698472216016346`, 0.9876010312916319, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.282525643195672, -0.9400201055250266, 0.}, 
      Optica`Optica`RayEnd :> {8.289914658878898, -1.0829276038966589`, 0.}, 
      RotationMatrix :> {{0.0516359088769905, -0.9986659766480712, 0.}, {
       0.9986659766480712, 0.0516359088769905, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25333164685466586`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1430983949721486, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.69625867493661, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15246406641523658`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0516359088769905, -0.9986659766480712, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.289914658878898, -1.0829276038966589`, 0.}, 
      Optica`Optica`RayEnd :> {8.297399842444705, -1.3703794401746636`, 0.}, 
      RotationMatrix :> {{0.02603095952395477, -0.9996611371591181, 0.}, {
       0.9996611371591181, 0.02603095952395477, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2526215490268054, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2875492760425778, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.121831603479627`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1274746000844721, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.02603095952395477, -0.9996611371591181, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.860004043903626, -0.5846922603434024, 0.}, 
      Optica`Optica`RayEnd :> {6.690008009051376, -0.6315445677566753, 0.}, 
      RotationMatrix :> {{-0.9640553232453094, -0.26570158773026104`, 0.}, {
       0.26570158773026104`, -0.9640553232453094, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06554634650493328, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1763343147984393, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.996098355866827`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23443674854003382`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9640553232453094, -0.26570158773026104`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.690008009051376, -0.6315445677566753, 0.}, 
      Optica`Optica`RayEnd :> {6.443488422529625, -0.6741042190569693, 0.}, 
      RotationMatrix :> {{-0.9854224271073452, -0.1701253659918721, 0.}, {
       0.1701253659918721, -0.9854224271073452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06491907621816267, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2501664055337123, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.36634463605672, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3920039755703967, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9854224271073452, -0.1701253659918721, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.404594217038392, -1.5717003663107687`, 0.}, 
      Optica`Optica`RayEnd :> {6.259408443254719, -2.061249027219967, 0.}, 
      RotationMatrix :> {{-0.2843301392285424, -0.9587264322664087, 0.}, {
       0.9587264322664087, -0.2843301392285424, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022903967572892772`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5106239323681893, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.00368377919351, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30190410272754625`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2843301392285424, -0.9587264322664087, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.259408443254719, -2.061249027219967, 0.}, 
      Optica`Optica`RayEnd :> {6.183785132830618, -2.3608905041613863`, 0.}, 
      RotationMatrix :> {{-0.2447062895083108, -0.9695972524069331, 0.}, {
       0.9695972524069331, -0.2447062895083108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.022826583892989208`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3090370524437728, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.46105861681029, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40719917782648263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2447062895083108, -0.9695972524069331, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.381736509769126, -2.6609417351921207`, 0.}, 
      Optica`Optica`RayEnd :> {7.380574323379593, -2.669444910492241, 0.}, 
      RotationMatrix :> {{-0.13541776719137386`, -0.990788589119244, 0.}, {
       0.990788589119244, -0.13541776719137386`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18314861879873123`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008582229744570586, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.50605966395886, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.054433685649638255`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.13541776719137386`, -0.990788589119244, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.380574323379593, -2.669444910492241, 0.}, 
      Optica`Optica`RayEnd :> {7.329947657622755, -2.9378162837687634`, 0.}, 
      RotationMatrix :> {{-0.18537447331988607`, -0.9826679523833949, 0.}, {
       0.9826679523833949, -0.18537447331988607`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18243289297965154`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27310483935657565`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.910254826206593`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13038623708287855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.18537447331988607`, -0.9826679523833949, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.337253499543261, 2.5050236894144997`, 0.}, 
      Optica`Optica`RayEnd :> {4.292422481352895, 2.6380683363991775`, 0.}, 
      RotationMatrix :> {{-0.3193210859054464, 0.9476465818522037, 
       0.}, {-0.9476465818522037, -0.3193210859054464, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009320543196703987, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14039479435955748`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.426444364184416`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.186863801493845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3193210859054464, 0.9476465818522037, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.292422481352895, 2.6380683363991775`, 0.}, 
      Optica`Optica`RayEnd :> {4.1955955310933275`, 2.9430773810869217`, 0.}, 
      RotationMatrix :> {{-0.3025753911695591, 0.9531254548371831, 
       0.}, {-0.9531254548371831, -0.3025753911695591, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009296105364908028, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3200093367980051, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.900058182645463`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42014331123749876`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.3025753911695591, 0.9531254548371831, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4621819624918184`, 1.1524391197069026`, 0.},
       Optica`Optica`RayEnd :> {3.3656486830671053`, 1.1633589103542972`, 0.},
       RotationMatrix :> {{-0.993662750169364, 0.11240257526344834`, 
       0.}, {-0.11240257526344834`, -0.993662750169364, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03102927905721432, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09714893650613302, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.564736982568032`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05250296593163904, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.993662750169364, 0.11240257526344834`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3656486830671053`, 1.1633589103542972`, 0.},
       Optica`Optica`RayEnd :> {3.1615855378483713`, 1.207032031787801, 0.}, 
      RotationMatrix :> {{-0.9778560797788836, 0.20927849206135068`, 
       0.}, {-0.20927849206135068`, -0.9778560797788836, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03073100693773136, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20868423220815616`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.873589646236102`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24858045863710684`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9778560797788836, 0.20927849206135068`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6118972978118684`, 0.16418018278816915`, 
       0.}, Optica`Optica`RayEnd :> {3.5755001570220437`, 0.08372018670784769,
        0.}, RotationMatrix :> {{-0.4121544383350768, -0.9111139988830688, 
       0.}, {0.9111139988830688, -0.4121544383350768, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24257121959396685`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08830947189809074, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.800243418046225`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17490384175741275`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4121544383350768, -0.9111139988830688, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5755001570220437`, 0.08372018670784769, 0.},
       Optica`Optica`RayEnd :> {3.4410452598506835`, -0.18049458499323162`, 
       0.}, RotationMatrix :> {{-0.4535371941517372, -0.8912373497116066, 
       0.}, {0.8912373497116066, -0.4535371941517372, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24169118025090436`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29645836968858613`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.23900180518533, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27572215856844484`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4535371941517372, -0.8912373497116066, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.08319075266063, -0.12669712854553145`, 0.}, 
      Optica`Optica`RayEnd :> {4.043580714792697, -0.35473242622201256`, 0.}, 
      RotationMatrix :> {{-0.17113871897334665`, -0.9852469430899855, 0.}, {
       0.9852469430899855, -0.17113871897334665`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024362173054340373`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23144989109157166`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.17389607287429, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04372800066416959, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17113871897334665`, -0.9852469430899855, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.043580714792697, -0.35473242622201256`, 0.},
       Optica`Optica`RayEnd :> {3.9852894961017116`, -0.6460686592447719, 0.},
       RotationMatrix :> {{-0.1961937153598228, -0.9805651564548417, 0.}, {
       0.9805651564548417, -0.1961937153598228, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02429397479168017, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2971105296827628, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.61361965680478, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2320052385474224, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1961937153598228, -0.9805651564548417, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.552047754432303, -0.6922139549788413, 0.}, 
      Optica`Optica`RayEnd :> {4.51316159899305, -0.8138720656466969, 0.}, 
      RotationMatrix :> {{-0.30446008641579947`, -0.9525250945669006, 0.}, {
       0.9525250945669006, -0.30446008641579947`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009097347719530306, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12772168561414302`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.13079079675838, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24913865691997217`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.30446008641579947`, -0.9525250945669006, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.51316159899305, -0.8138720656466969, 0.}, 
      Optica`Optica`RayEnd :> {4.43125834980598, -1.0992574212415742`, 0.}, 
      RotationMatrix :> {{-0.27585618264631917`, -0.9611989213975428, 0.}, {
       0.9611989213975428, -0.27585618264631917`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00907068872064511, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2969056136475255, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.570211104956716`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4244296644080807, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.27585618264631917`, -0.9611989213975428, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6709939753795493`, 1.8909537908995016`, 0.},
       Optica`Optica`RayEnd :> {2.4586418271341675`, 2.389602901024031, 0.}, 
      RotationMatrix :> {{-0.3918067224619082, 0.9200475488982383, 
       0.}, {-0.9200475488982383, -0.3918067224619082, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012556390690574295`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5419818907421298, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.999545090989802`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3612034305076296, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.3918067224619082, 0.9200475488982383, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4586418271341675`, 2.389602901024031, 0.}, 
      Optica`Optica`RayEnd :> {2.3767600525366226`, 2.6307316791079334`, 0.}, 
      RotationMatrix :> {{-0.32154363381967604`, 0.9468947626584683, 
       0.}, {-0.9468947626584683, -0.32154363381967604`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01247986905247673, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25465214044158146`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.376430258843342`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2955410813216125, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.32154363381967604`, 0.9468947626584683, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3688715306818175`, 1.0498166231520185`, 0.},
       Optica`Optica`RayEnd :> {2.1586051450993393`, 0.9757481031880711, 0.}, 
      RotationMatrix :> {{-0.9431916837700561, -0.33224907474213605`, 0.}, {
       0.33224907474213605`, -0.9431916837700561, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23889321070749203`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22293070348332242`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.413273405256398`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39106535582575297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9431916837700561, -0.33224907474213605`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1586051450993393`, 0.9757481031880711, 0.}, 
      Optica`Optica`RayEnd :> {1.8654612149900247`, 0.8885482619526972, 0.}, 
      RotationMatrix :> {{-0.9584926323213071, -0.2851172982927738, 0.}, {
       0.2851172982927738, -0.9584926323213071, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23797549081717562`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3058384803640791, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.865914356195233`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.332456445176114, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9584926323213071, -0.2851172982927738, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6840645451323115`, 0.07101065378714078, 0.},
       Optica`Optica`RayEnd :> {2.636307215419951, -0.16676976387992273`, 0.},
       RotationMatrix :> {{-0.1969139376258959, -0.9804207776096261, 0.}, {
       0.9804207776096261, -0.1969139376258959, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011543135077166946`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24252894583364326`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.21381914740675, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2673897909783519, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1969139376258959, -0.9804207776096261, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.636307215419951, -0.16676976387992273`, 0.},
       Optica`Optica`RayEnd :> {2.6361714884051755`, -0.33417672375082363`, 
       0.}, RotationMatrix :> {{-0.000810760617549533, -0.999999671333556, 
       0.}, {0.999999671333556, -0.000810760617549533, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010851675001839178`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16740701489196907`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.461581529446864`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2667043537664936, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.000810760617549533, -0.999999671333556, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2306487365576024`, -0.434011017903535, 0.}, 
      Optica`Optica`RayEnd :> {2.2415014762410768`, -0.5362599279497503, 0.}, 
      RotationMatrix :> {{0.10554752218691077`, -0.994414260034621, 0.}, {
       0.994414260034621, 0.10554752218691077`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008125135984197411, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10282325400548396`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.52562060945147, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1880458124487504, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10554752218691077`, -0.994414260034621, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2415014762410768`, -0.5362599279497503, 0.},
       Optica`Optica`RayEnd :> {2.2680396580060287`, -0.8580522163487847, 0.},
       RotationMatrix :> {{0.082190883944062, -0.9966166056194794, 0.}, {
       0.9966166056194794, 0.082190883944062, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008102817684153265, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3228847347963, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.003490016949993`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10960622008288345`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.082190883944062, -0.9966166056194794, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.5064694967424925`, -4.068756492661345, 0.}, 
      Optica`Optica`RayEnd :> {7.578285539175333, -4.251879845857825, 0.}, 
      RotationMatrix :> {{0.36510058327889333`, -0.9309680789852094, 0.}, {
       0.9309680789852094, 0.36510058327889333`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008307926646532274, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19670207532366912`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.135311803568467`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09630785352300217, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.36510058327889333`, -0.9309680789852094, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.578285539175333, -4.251879845857825, 0.}, 
      Optica`Optica`RayEnd :> {7.671016338206515, -4.418310300182402, 0.}, 
      RotationMatrix :> {{0.4867232275226071, -0.8735562373367702, 0.}, {
       0.8735562373367702, 0.4867232275226071, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00814390780893489, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19052059525323364`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.41728228454325, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3866084871337704, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4867232275226071, -0.8735562373367702, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.301734612303231, 2.9715636864263844`, 0.}, 
      Optica`Optica`RayEnd :> {2.15678870259673, 2.953924326936628, 0.}, 
      RotationMatrix :> {{-0.9926762716654618, -0.12080488265114837`, 0.}, {
       0.12080488265114837`, -0.9926762716654618, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2883556225704925, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14601528599380956`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.033494025475118`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38820002512029717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9926762716654618, -0.12080488265114837`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.15678870259673, 2.953924326936628, 0.}, 
      Optica`Optica`RayEnd :> {1.905450895359237, 2.9302119632853034`, 0.}, 
      RotationMatrix :> {{-0.995579039798007, -0.09392750137674251, 0.}, {
       0.09392750137674251, -0.995579039798007, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.28753592812209033`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25245389586394545`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.407125791353756`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1697552126022934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.995579039798007, -0.09392750137674251, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.926853849632756, 3.6996533119034503`, 0.}, 
      Optica`Optica`RayEnd :> {5.06111150636273, 3.728195983954255, 0.}, 
      RotationMatrix :> {{0.9781397085355926, 0.20794881722651154`, 
       0.}, {-0.20794881722651154`, 0.9781397085355926, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03211762285383692, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13725816011597783`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.3432628978558, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09500645166121784, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9781397085355926, 0.20794881722651154`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.06111150636273, 3.728195983954255, 0.}, 
      Optica`Optica`RayEnd :> {5.403187952588996, 3.800301315581602, 0.}, 
      RotationMatrix :> {{0.9784982959218707, 0.20625490267626237`, 
       0.}, {-0.20625490267626237`, 0.9784982959218707, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03203841564892293, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.34959329786464916`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.86066097869548, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3665540732785064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9784982959218707, 0.20625490267626237`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.08493018736672, 3.4665318756219445`, 0.}, 
      Optica`Optica`RayEnd :> {7.373505533449265, 3.4332706036957727`, 0.}, 
      RotationMatrix :> {{0.9934229944521727, -0.11450220126127418`, 0.}, {
       0.11450220126127418`, 0.9934229944521727, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02175486062377545, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2904858732826903, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.011366375713987`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15851277062347668`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9934229944521727, -0.11450220126127418`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.373505533449265, 3.4332706036957727`, 0.}, 
      Optica`Optica`RayEnd :> {7.657254405218824, 3.413101570340565, 0.}, 
      RotationMatrix :> {{0.9974833084155922, -0.0709016885009356, 0.}, {
       0.0709016885009356, 0.9974833084155922, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021678417844706352`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2844647818922069, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.432374252914453`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27513330192645297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9974833084155922, -0.0709016885009356, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8423809303975185`, 1.5972051673966625`, 0.},
       Optica`Optica`RayEnd :> {6.845562438732375, 1.5952906131564648`, 0.}, 
      RotationMatrix :> {{0.8568209845663062, -0.515614003307537, 0.}, {
       0.515614003307537, 0.8568209845663062, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011154716645471472`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0037131540802158506`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.19872087519665, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28745428280240115`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8568209845663062, -0.515614003307537, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.845562438732375, 1.5952906131564648`, 0.}, 
      Optica`Optica`RayEnd :> {7.078171501620103, 1.4531793955188055`, 0.}, 
      RotationMatrix :> {{0.8533451043439757, -0.5213464614746782, 0.}, {
       0.5213464614746782, 0.8533451043439757, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011126973395551534`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27258498549253396`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.6021466537256, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26679252274759024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8533451043439757, -0.5213464614746782, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.358079660061334, 3.168928479704756, 0.}, 
      Optica`Optica`RayEnd :> {7.592570358476737, 3.3241435725362685`, 0.}, 
      RotationMatrix :> {{0.8338709518205207, 0.5519594511464933, 
       0.}, {-0.5519594511464933, 0.8338709518205207, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.14475051422345883`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28120741932964405`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.09589349581647, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21046700974563964`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8338709518205207, 0.5519594511464933, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.592570358476737, 3.3241435725362685`, 0.}, 
      Optica`Optica`RayEnd :> {7.76948545282574, 3.4087582852440135`, 0.}, 
      RotationMatrix :> {{0.9021279777585824, 0.43146855244062665`, 
       0.}, {-0.43146855244062665`, 0.9021279777585824, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.14166595628413695`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19610864390722574`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.386134288799163`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1379458335733581, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9021279777585824, 0.43146855244062665`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.913412393865279, 0.6424620335464204, 0.}, 
      Optica`Optica`RayEnd :> {6.966790918559761, 0.6114333462384633, 0.}, 
      RotationMatrix :> {{0.8645447561851359, -0.5025558322741694, 0.}, {
       0.5025558322741694, 0.8645447561851359, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09327772675433729, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06174177139193824, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.402338225913933`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33409621574196025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8645447561851359, -0.5025558322741694, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.966790918559761, 0.6114333462384633, 0.}, 
      Optica`Optica`RayEnd :> {7.159514962471937, 0.47210629384999775`, 0.}, 
      RotationMatrix :> {{0.8104047751287944, -0.5858703785381605, 0.}, {
       0.5858703785381605, 0.8104047751287944, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09235911634911008, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23781207839199622`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.75430010193409, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40274039196553957`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8104047751287944, -0.5858703785381605, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.223831140464143, 0.6062246397799318, 0.}, 
      Optica`Optica`RayEnd :> {5.25788395479941, 0.40047914863717937`, 0.}, 
      RotationMatrix :> {{0.16328801359094808`, -0.9865784432155008, 0.}, {
       0.9865784432155008, 0.16328801359094808`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04763394442576827, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2085444827602125, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.718720689322648`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11128472568575565`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.16328801359094808`, -0.9865784432155008, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.25788395479941, 0.40047914863717937`, 0.}, 
      Optica`Optica`RayEnd :> {5.2919813439335, 0.11115117115553971`, 0.}, 
      RotationMatrix :> {{0.11704033464006319`, -0.9931271620831548, 0.}, {
       0.9931271620831548, 0.11704033464006319`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04745898715223935, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2913302430222062, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.149889448995513`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005084499066106306, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.11704033464006319`, -0.9931271620831548, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5400266537753016`, 0.8584285114380503, 0.}, 
      Optica`Optica`RayEnd :> {3.418791294547206, 0.7379370981728014, 0.}, 
      RotationMatrix :> {{-0.7092796363126475, -0.7049272285223469, 0.}, {
       0.7049272285223469, -0.7092796363126475, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033614228463448755`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17092744951534972`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.336025201673966`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4131063989225416, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7092796363126475, -0.7049272285223469, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.418791294547206, 0.7379370981728014, 0.}, 
      Optica`Optica`RayEnd :> {3.2337022530914274`, 0.5807779500679296, 0.}, 
      RotationMatrix :> {{-0.7622776705350989, -0.6472501471638163, 0.}, {
       0.6472501471638163, -0.7622776705350989, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03339658625640332, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24281052510150344`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.69538477882419, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34493088612662637`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7622776705350989, -0.6472501471638163, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.58339473401461, 2.2758211254393754`, 0.}, 
      Optica`Optica`RayEnd :> {3.4639266872794554`, 2.343108263921816, 0.}, 
      RotationMatrix :> {{-0.8713062675992993, 0.4907396336573778, 
       0.}, {-0.4907396336573778, -0.8713062675992993, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035961713726436834`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1371137235869123, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.89085330129418, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27240695222391803`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.8713062675992993, 0.4907396336573778, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4639266872794554`, 2.343108263921816, 0.}, 
      Optica`Optica`RayEnd :> {3.419021162144573, 2.3521030916458017`, 0.}, 
      RotationMatrix :> {{-0.9805230105928674, 0.1964042405293196, 
       0.}, {-0.1964042405293196, -0.9805230105928674, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02528997250968048, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.045797523005330194`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.952221982121323`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38100426459125786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9805230105928674, 0.1964042405293196, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.345772548463666, 0.9347785088876049, 0.}, 
      Optica`Optica`RayEnd :> {2.1109418660443935`, 0.8813486848297772, 0.}, 
      RotationMatrix :> {{-0.9750796919137752, -0.22185489495915298`, 0.}, {
       0.22185489495915298`, -0.9750796919137752, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0863446045109698, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2408322974693211, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.45421575020577, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12911044878720043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9750796919137752, -0.22185489495915298`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1109418660443935`, 0.8813486848297772, 0.}, 
      Optica`Optica`RayEnd :> {2.001820259253169, 0.8322686305099309, 0.}, 
      RotationMatrix :> {{-0.9119986429370895, -0.41019321700987044`, 0.}, {
       0.41019321700987044`, -0.9119986429370895, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08104188262691892, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11965106268118829`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.61454817419856, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22333767204424324`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9119986429370895, -0.41019321700987044`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5719528092812887`, -0.3436921906763729, 0.},
       Optica`Optica`RayEnd :> {3.540315837718936, -0.3666346889023103, 0.}, 
      RotationMatrix :> {{-0.8095412005186755, -0.587063067023281, 0.}, {
       0.587063067023281, -0.8095412005186755, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020276015012280636`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.039080125313057004`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.148008652646812`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2128213487562865, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8095412005186755, -0.587063067023281, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.540315837718936, -0.3666346889023103, 0.}, 
      Optica`Optica`RayEnd :> {3.381604823976741, -0.45247289711526967`, 0.}, 
      RotationMatrix :> {{-0.8795941161068204, -0.4757249109624818, 0.}, {
       0.4757249109624818, -0.8795941161068204, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019897858517167778`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1804366478082729, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.389793760709896`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2376449881890385, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8795941161068204, -0.4757249109624818, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.96350433554662, -3.6571197780856823`, 0.}, 
      Optica`Optica`RayEnd :> {5.966474220943696, -3.8299795327438115`, 0.}, 
      RotationMatrix :> {{0.017178360398971373`, -0.9998524410801838, 0.}, {
       0.9998524410801838, 0.017178360398971373`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008052447493641963, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.172885265421147, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.190189977932317`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2653737343136274, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.017178360398971373`, -0.9998524410801838, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.966474220943696, -3.8299795327438115`, 0.}, 
      Optica`Optica`RayEnd :> {5.972389363345108, -4.14210818712324, 0.}, 
      RotationMatrix :> {{0.01894757313664845, -0.9998204786221527, 0.}, {
       0.9998204786221527, 0.01894757313664845, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00803258833253827, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31218469820659317`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.652223331278073`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24912743632861215`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.01894757313664845, -0.9998204786221527, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.361821664728799, -0.379995678727669, 0.}, 
      Optica`Optica`RayEnd :> {7.361840882167571, -0.3800627190973369, 0.}, 
      RotationMatrix :> {{0.27555682594912473`, -0.9612847838558786, 0.}, {
       0.9612847838558786, 0.27555682594912473`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012311030817442746`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00006974038369671678, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.247618533148973`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32670199402627537`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.27555682594912473`, -0.9612847838558786, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.361840882167571, -0.3800627190973369, 0.}, 
      Optica`Optica`RayEnd :> {7.449908629578593, -0.6290946221239575, 0.}, 
      RotationMatrix :> {{0.3334062676755047, -0.9427832522243325, 0.}, {
       0.9427832522243325, 0.3334062676755047, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012253810099394923`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26414544640994975`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.638553793835698`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32306166742378556`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3334062676755047, -0.9427832522243325, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8735678907445887`, 1.9718076657689771`, 0.},
       Optica`Optica`RayEnd :> {3.7775506922884885`, 1.9421761779742046`, 0.},
       RotationMatrix :> {{-0.9555332624427406, -0.29488334026447, 0.}, {
       0.29488334026447, -0.9555332624427406, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018060993525520194`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10048545898929809`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.74003964185488, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23140427267455219`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9555332624427406, -0.29488334026447, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7775506922884885`, 1.9421761779742046`, 0.},
       Optica`Optica`RayEnd :> {3.6290617411838237`, 1.8597836212114276`, 0.},
       RotationMatrix :> {{-0.874410412562537, -0.485187005599091, 0.}, {
       0.485187005599091, -0.874410412562537, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016796250386695615`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1698160828957931, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.991367444540657`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24635635303624326`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.874410412562537, -0.485187005599091, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.888508547977647, 2.4429143369798125`, 0.}, 
      Optica`Optica`RayEnd :> {5.767552045297535, 2.3071249030370566`, 0.}, 
      RotationMatrix :> {{-0.6651461404011543, -0.7467132059294563, 0.}, {
       0.7467132059294563, -0.6651461404011543, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010686138660700773`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18184951446484035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.972308822935872`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01371941215994596, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6651461404011543, -0.7467132059294563, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.767552045297535, 2.3071249030370566`, 0.}, 
      Optica`Optica`RayEnd :> {5.615425364229257, 2.1304326170238865`, 0.}, 
      RotationMatrix :> {{-0.6524615402765672, -0.7578218382046853, 0.}, {
       0.7578218382046853, -0.6524615402765672, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010658263821516021`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2331580816300594, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.31738278374836, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32217812862911277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6524615402765672, -0.7578218382046853, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.613073684194516, 1.9149759269957787`, 0.}, 
      Optica`Optica`RayEnd :> {7.628545758690353, 1.8475056952641078`, 0.}, 
      RotationMatrix :> {{0.2235154188146933, -0.9747003937375274, 0.}, {
       0.9747003937375274, 0.2235154188146933, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010053932046359442`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06922150864529095, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.863091428048, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31143274742071214`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2235154188146933, -0.9747003937375274, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.628545758690353, 1.8475056952641078`, 0.}, 
      Optica`Optica`RayEnd :> {7.713787371339179, 1.570713499858081, 0.}, 
      RotationMatrix :> {{0.29432171939134344`, -0.9557064013045649, 0.}, {
       0.9557064013045649, 0.29432171939134344`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009994875061707703, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2896205309791773, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.291729813897184`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36710539145247967`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.29432171939134344`, -0.9557064013045649, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4349281815717845`, 0.8897875450281161, 0.}, 
      Optica`Optica`RayEnd :> {7.4265704102400125`, 0.6412175565394289, 0.}, 
      RotationMatrix :> {{-0.033604422692884536`, -0.9994352118949364, 0.}, {
       0.9994352118949364, -0.033604422692884536`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012652570200471572`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2487104571965166, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.518719712599097`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3333316026936311, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.033604422692884536`, -0.9994352118949364, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.4265704102400125`, 0.6412175565394289, 0.}, 
      Optica`Optica`RayEnd :> {7.405720745714707, 0.28962841116119903`, 0.}, 
      RotationMatrix :> {{-0.059197221765541985`, -0.9982463067476082, 0.}, {
       0.9982463067476082, -0.059197221765541985`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01261710592430744, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3522068080810077, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.990676835427646`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3750412161586659, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.059197221765541985`, -0.9982463067476082, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7061559660456895`, 1.6302363202035928`, 0.},
       Optica`Optica`RayEnd :> {3.5630614227640534`, 1.590029904485815, 0.}, 
      RotationMatrix :> {{-0.9627191639699857, -0.2705028859826277, 0.}, {
       0.2705028859826277, -0.9627191639699857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010116426662495704`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14863581056343989`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.19142092263539, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1323215166263694, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9627191639699857, -0.2705028859826277, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5630614227640534`, 1.590029904485815, 0.}, 
      Optica`Optica`RayEnd :> {3.3243323955771182`, 1.5094446611867771`, 0.}, 
      RotationMatrix :> {{-0.9474752060920884, -0.3198292260578346, 0.}, {
       0.3198292260578346, -0.9474752060920884, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010076230151400516`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2519633502301189, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.564326680975967`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.06395695819730429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9474752060920884, -0.3198292260578346, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9882413674549433`, 3.6907620563599965`, 0.},
       Optica`Optica`RayEnd :> {2.8913015105007416`, 3.7208958175518165`, 0.},
       RotationMatrix :> {{-0.9549274580843691, 0.29683926592774856`, 
       0.}, {-0.29683926592774856`, -0.9549274580843691, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028163532390573003`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10151541474016001`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.551514054171566`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35769053445700855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9549274580843691, 0.29683926592774856`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8913015105007416`, 3.7208958175518165`, 0.},
       Optica`Optica`RayEnd :> {2.553007083039228, 3.824253879775438, 0.}, 
      RotationMatrix :> {{-0.956359217959928, 0.2921935081809215, 
       0.}, {-0.2921935081809215, -0.956359217959928, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02809378635381146, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.353731548887197, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.075036746524617`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16816212982258202`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.956359217959928, 0.2921935081809215, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.417849472132508, -1.058102453305081, 0.}, 
      Optica`Optica`RayEnd :> {3.3495126332599936`, -1.148684791261067, 0.}, 
      RotationMatrix :> {{-0.6022542289365352, -0.7983043553232425, 0.}, {
       0.7983043553232425, -0.6022542289365352, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01214396761602647, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11346842510875207`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.789282391325642`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2198971986316589, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6022542289365352, -0.7983043553232425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3495126332599936`, -1.148684791261067, 0.}, 
      Optica`Optica`RayEnd :> {3.1502362259938024`, -1.3957048186924736`, 0.},
       RotationMatrix :> {{-0.6278797980688219, -0.7783103231854591, 0.}, {
       0.7783103231854591, -0.6278797980688219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012107295987815172`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31737986773759597`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.259004595577284`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3923718369870991, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6278797980688219, -0.7783103231854591, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4346059552727373`, -0.17662184558167104`, 
       0.}, Optica`Optica`RayEnd :> {2.416036833516986, -0.22044205134953043`,
        0.}, RotationMatrix :> {{-0.39017108637467096`, -0.9207423762145461, 
       0.}, {0.9207423762145461, -0.39017108637467096`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012241230207459314`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04759225479337407, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.486880636100175`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3080928216644907, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39017108637467096`, -0.9207423762145461, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.416036833516986, -0.22044205134953043`, 0.},
       Optica`Optica`RayEnd :> {2.3009531280733664`, -0.43534944114653396`, 
       0.}, RotationMatrix :> {{-0.47207716973739045`, -0.8815572277582067, 
       0.}, {0.8815572277582067, -0.47207716973739045`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0121397315140795, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24378155272291438`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.847677334130086`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1569987779615445, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 116, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.47207716973739045`, -0.8815572277582067, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.34509924734631, -2.079337547647544, 0.}, 
      Optica`Optica`RayEnd :> {4.312866981451187, -2.0787705044848455`, 0.}, 
      RotationMatrix :> {{-0.9998452895060842, 0.017589685969188626`, 
       0.}, {-0.017589685969188626`, -0.9998452895060842, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01951665515940765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03223725333650933, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.344186923518233`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026270956288119332`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9998452895060842, 0.017589685969188626`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.312866981451187, -2.0787705044848455`, 0.}, 
      Optica`Optica`RayEnd :> {4.126212024936174, -2.1067733899757095`, 0.}, 
      RotationMatrix :> {{-0.9889327446168814, -0.14836450594573464`, 0.}, {
       0.14836450594573464`, -0.9889327446168814, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01882252703547951, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18874383271364312`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.623527795934425`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35935148224696367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9889327446168814, -0.14836450594573464`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.604807374485697, -2.3781584461875953`, 0.}, 
      Optica`Optica`RayEnd :> {5.603160721611645, -2.3777808238799247`, 0.}, 
      RotationMatrix :> {{-0.9746982364379461, 0.22352482610385216`, 
       0.}, {-0.22352482610385216`, -0.9746982364379461, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011482143331641896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001689397613019067, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.96783562806811, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21433690823740337`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9746982364379461, 0.22352482610385216`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.603160721611645, -2.3777808238799247`, 0.}, 
      Optica`Optica`RayEnd :> {5.3692815675533225`, -2.347872509711066, 0.}, 
      RotationMatrix :> {{-0.9919223728749347, 0.12684638816363125`, 
       0.}, {-0.12684638816363125`, -0.9919223728749347, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011371672798873451`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23578372708789622`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.316795544158197`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3784482749077905, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9919223728749347, 0.12684638816363125`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.049286457408408, 0.6750501916120701, 0.}, 
      Optica`Optica`RayEnd :> {8.058839754670561, 0.7528464829549052, 0.}, 
      RotationMatrix :> {{0.12188334235067892`, 0.9925444326867321, 
       0.}, {-0.9925444326867321, 0.12188334235067892`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01322277503487157, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07838066365678686, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.458795319076913`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06989241287478717, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.12188334235067892`, 0.9925444326867321, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.058839754670561, 0.7528464829549052, 0.}, 
      Optica`Optica`RayEnd :> {8.11598951992452, 0.901805773284278, 0.}, 
      RotationMatrix :> {{0.3582021527121857, 0.9336440530482458, 
       0.}, {-0.9336440530482458, 0.3582021527121857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01162506070492232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15954612450326974`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.69492358334175, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3831066033530075, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3582021527121857, 0.9336440530482458, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.857304483961946, 1.0785491778117529`, 0.}, 
      Optica`Optica`RayEnd :> {4.747626960664649, 1.1570154792815404`, 0.}, 
      RotationMatrix :> {{-0.8132940846717733, 0.5818528437997893, 
       0.}, {-0.5818528437997893, -0.8132940846717733, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012849079843049296`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1348559215717901, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.159213833553743`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21044710198179672`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8132940846717733, 0.5818528437997893, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.747626960664649, 1.1570154792815404`, 0.}, 
      Optica`Optica`RayEnd :> {4.604221962285013, 1.2840482842581151`, 0.}, 
      RotationMatrix :> {{-0.7485442664776367, 0.6630848219673381, 
       0.}, {-0.6630848219673381, -0.7485442664776367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012710497532463748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19157851419321434`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.4427500345597, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01587916643524523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7485442664776367, 0.6630848219673381, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6677729820998963`, -0.13071392041402335`, 
       0.}, Optica`Optica`RayEnd :> {
       2.6187428803404096`, -0.12258995378609708`, 0.}, 
      RotationMatrix :> {{-0.9865491778753382, 0.16346473513725854`, 
       0.}, {-0.16346473513725854`, -0.9865491778753382, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017117752374642584`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.049698588635063885`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.983026913955555`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1721999555104056, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9865491778753382, 0.16346473513725854`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6187428803404096`, -0.12258995378609706`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3194844998904247`, -0.055999695094600184`, 0.}, 
      RotationMatrix :> {{-0.9761259628159862, 0.21720521337335313`, 
       0.}, {-0.21720521337335313`, -0.9761259628159862, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017046098949106227`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3065776260951673, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.436761800576402`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12742723894881894`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9761259628159862, 0.21720521337335313`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.199850853875885, -3.9113342055346747`, 0.}, 
      Optica`Optica`RayEnd :> {4.167172969626897, -3.932868198177771, 0.}, 
      RotationMatrix :> {{-0.8350016885656263, -0.5502473808138962, 0.}, {
       0.5502473808138962, -0.8350016885656263, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08699476907638912, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03913511157698678, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.265030865214637`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.306567259350702, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8350016885656263, -0.5502473808138962, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.167172969626897, -3.932868198177771, 0.}, 
      Optica`Optica`RayEnd :> {3.9464350153265713`, -4.072481409782038, 0.}, 
      RotationMatrix :> {{-0.8451434075116823, -0.5345396343953763, 0.}, {
       0.5345396343953763, -0.8451434075116823, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08676491918242181, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2611840219522444, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.65158321770396, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3374210378795287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8451434075116823, -0.5345396343953763, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2504504448487164`, -3.355483321000886, 0.}, 
      Optica`Optica`RayEnd :> {2.135404990293597, -3.4311843999347778`, 0.}, 
      RotationMatrix :> {{-0.8353728035433183, -0.5496837991974808, 0.}, {
       0.5496837991974808, -0.8353728035433183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03630676333844383, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13771750057835544`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.177877019767994`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3218598943033048, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8353728035433183, -0.5496837991974808, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.135404990293597, -3.4311843999347778`, 0.}, 
      Optica`Optica`RayEnd :> {1.8717760217040529`, -3.596276373248007, 0.}, 
      RotationMatrix :> {{-0.8475300229769619, -0.5307474542121425, 0.}, {
       0.5307474542121425, -0.8475300229769619, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03620787450596532, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31105561035294477`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.638239323090353`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34846804336426, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8475300229769619, -0.5307474542121425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.833124009085632, -1.0373182512021093`, 0.}, 
      Optica`Optica`RayEnd :> {2.6662098907927887`, -1.0487093524605482`, 0.},
       RotationMatrix :> {{-0.9976793935544608, -0.06808691266905283, 0.}, {
       0.06808691266905283, -0.9976793935544608, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013616012193963287`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16730236123066894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.624491844127924`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40809546063626817`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9976793935544608, -0.06808691266905283, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6662098907927887`, -1.0487093524605482`, 
       0.}, Optica`Optica`RayEnd :> {2.312220468657105, -1.0674312255994285`, 
       0.}, RotationMatrix :> {{-0.9986043449149646, -0.05281441391281659, 
       0.}, {0.05281441391281659, -0.9986043449149646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013580844600214552`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3544841597558116, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.149128400566525`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09839761371996662, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9986043449149646, -0.05281441391281659, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.323627665433101, -3.3923747599303007`, 0.}, 
      Optica`Optica`RayEnd :> {6.171777647535761, -3.5039883632184616`, 0.}, 
      RotationMatrix :> {{-0.8057543795997262, -0.5922498457204187, 0.}, {
       0.5922498457204187, -0.8057543795997262, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013393669868598643`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18845695629079176`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.399919921118045`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41106624891518406`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8057543795997262, -0.5922498457204187, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.171777647535761, -3.5039883632184616`, 0.}, 
      Optica`Optica`RayEnd :> {5.947765141123858, -3.6496665162900763`, 0.}, 
      RotationMatrix :> {{-0.8383238539382697, -0.5451725560940188, 0.}, {
       0.5451725560940188, -0.8383238539382697, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013335137780755424`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26721475878270573`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.795397764116448`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42690378629183534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8383238539382697, -0.5451725560940188, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.396788952294392, -3.863917628126922, 0.}, 
      Optica`Optica`RayEnd :> {7.3970953867840885`, -3.8648666770073263`, 0.},
       RotationMatrix :> {{0.30726586618167195`, -0.9516237110747221, 0.}, {
       0.9516237110747221, 0.30726586618167195`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20478967450020755`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0009972942764665176, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.782737832771364`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35630300619569294`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.30726586618167195`, -0.9516237110747221, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.3970953867840885`, -3.8648666770073263`, 
       0.}, Optica`Optica`RayEnd :> {7.474559788528993, -4.071123810438171, 
       0.}, RotationMatrix :> {{0.35159284951882536`, -0.9361530153597925, 
       0.}, {0.9361530153597925, 0.35159284951882536`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.20403468454437404`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22032416714651426`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.108817600148203`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2751173148731689, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35159284951882536`, -0.9361530153597925, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.109466376042483, -2.3475363475123796`, 0.}, 
      Optica`Optica`RayEnd :> {7.112100941858732, -2.3818749918280813`, 0.}, 
      RotationMatrix :> {{0.07649823817592728, -0.9970697164972858, 0.}, {
       0.9970697164972858, 0.07649823817592728, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02227088531389559, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03443956199605927, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.497812262771053`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.265406231437242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.07649823817592728, -0.9970697164972858, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.112100941858732, -2.3818749918280813`, 0.}, 
      Optica`Optica`RayEnd :> {7.094646516432469, -2.548964716506338, 0.}, 
      RotationMatrix :> {{-0.10389606482015926`, -0.9945881598505404, 0.}, {
       0.9945881598505404, -0.10389606482015926`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021259099729042108`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16799890791316674`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.74645064648254, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17210214615451272`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.10389606482015926`, -0.9945881598505404, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.745581720203257, 2.93105649072293, 0.}, 
      Optica`Optica`RayEnd :> {4.685296765772567, 2.999156445129354, 0.}, 
      RotationMatrix :> {{-0.6628371431104071, 0.7487635953445073, 
       0.}, {-0.7487635953445073, -0.6628371431104071, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008400427483313232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09094987367153033, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.900102945878412`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4281091507152007, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.6628371431104071, 0.7487635953445073, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.685296765772567, 2.999156445129354, 0.}, 
      Optica`Optica`RayEnd :> {4.516406202241529, 3.153786736063154, 0.}, 
      RotationMatrix :> {{-0.7375587421667732, 0.675282979093481, 
       0.}, {-0.675282979093481, -0.7375587421667732, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008308138995562058, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2289859151216578, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.239002100258467`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2791790926339829, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.7375587421667732, 0.675282979093481, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0950691582980365`, -0.8562053790945715, 0.},
       Optica`Optica`RayEnd :> {5.0876498459533925`, -0.8630842502231568, 0.},
       RotationMatrix :> {{-0.7333102818111602, -0.6798941318985157, 0.}, {
       0.6798941318985157, -0.7333102818111602, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16868884921620195`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.010117562140707113`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.510405386167314`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07861014300807383, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7333102818111602, -0.6798941318985157, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.0876498459533925`, -0.8630842502231568, 0.},
       Optica`Optica`RayEnd :> {4.897134594666521, -1.0567814332362302`, 0.}, 
      RotationMatrix :> {{-0.7012266887331211, -0.71293837812842, 0.}, {
       0.71293837812842, -0.7012266887331211, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16807545660187906`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2716885343184359, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.912504416958598`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18652144281746566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7012266887331211, -0.71293837812842, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.994065167912832, -1.694889300567602, 0.}, 
      Optica`Optica`RayEnd :> {8.063713541240318, -1.7465703138020194`, 0.}, 
      RotationMatrix :> {{0.8030626394513577, -0.5958946191378292, 0.}, {
       0.5958946191378292, 0.8030626394513577, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009235164199183203, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08672844421584516, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.102719398186903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009925796641217203, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8030626394513577, -0.5958946191378292, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.063713541240318, -1.7465703138020194`, 0.}, 
      Optica`Optica`RayEnd :> {8.277153594740588, -1.8841482342927005`, 0.}, 
      RotationMatrix :> {{0.8405214273201772, -0.5417783035667374, 0.}, {
       0.5417783035667374, 0.8405214273201772, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009188077088564358, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25393767078702134`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.478547150951695`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.038986547176246826`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8405214273201772, -0.5417783035667374, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.022441816341458, 2.3231662784791007`, 0.}, 
      Optica`Optica`RayEnd :> {5.941956888865805, 2.150378709482794, 0.}, 
      RotationMatrix :> {{-0.4222422926194505, -0.9064830093959119, 0.}, {
       0.9064830093959119, -0.4222422926194505, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008301390568634113, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19061313582860587`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.540185359044365`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41865930534237367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.4222422926194505, -0.9064830093959119, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.941956888865805, 2.150378709482794, 0.}, 
      Optica`Optica`RayEnd :> {5.863954869871214, 1.9176321217127803`, 0.}, 
      RotationMatrix :> {{-0.31776660707684423`, -0.9481689635433492, 0.}, {
       0.9481689635433492, -0.31776660707684423`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008195005765858115, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24546952781520026`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 18.903480260210863`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21986088142379073`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.31776660707684423`, -0.9481689635433492, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.6701500886058795`, 3.255165769425571, 0.}, 
      Optica`Optica`RayEnd :> {5.1265156431039856`, 3.076744775513107, 0.}, 
      RotationMatrix :> {{-0.9501362649413275, -0.3118350173462598, 0.}, {
       0.3118350173462598, -0.9501362649413275, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.037152030188491524`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5721647152742501, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.971496478197775`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24000601658690845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9501362649413275, -0.3118350173462598, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1265156431039856`, 3.076744775513107, 0.}, 
      Optica`Optica`RayEnd :> {4.828233618459975, 2.9715138482660324`, 0.}, 
      RotationMatrix :> {{-0.9430350567706494, -0.332693374898835, 0.}, {
       0.332693374898835, -0.9430350567706494, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03705124552272197, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31630003837339227`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.439620534990397`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06570307794150876, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9430350567706494, -0.332693374898835, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.946889611226584, 1.869578185063331, 0.}, 
      Optica`Optica`RayEnd :> {4.81685376611325, 1.822561236102724, 0.}, 
      RotationMatrix :> {{-0.9404162209911077, -0.3400254862459626, 0.}, {
       0.3400254862459626, -0.9404162209911077, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03586182727798118, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13827477898699828`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.262392749859618`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08994369250033289, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9404162209911077, -0.3400254862459626, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.81685376611325, 1.822561236102724, 0.}, 
      Optica`Optica`RayEnd :> {4.56275376786472, 1.7150572909505666`, 0.}, 
      RotationMatrix :> {{-0.9209671213465274, -0.3896402974522657, 0.}, {
       0.3896402974522657, -0.9209671213465274, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03571534524504367, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2759056130874848, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.670733057229096`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03289801894516491, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9209671213465274, -0.3896402974522657, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.542744171328283, 2.780874315517512, 0.}, 
      Optica`Optica`RayEnd :> {5.3812344063793915`, 2.7748615939355155`, 0.}, 
      RotationMatrix :> {{-0.999307749178721, -0.03720245195356709, 0.}, {
       0.03720245195356709, -0.999307749178721, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040513753908650474`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1616216476672258, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.32998670054613, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3191200598589422, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.999307749178721, -0.03720245195356709, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3812344063793915`, 2.7748615939355155`, 0.},
       Optica`Optica`RayEnd :> {5.116889302356681, 2.756812497992865, 0.}, 
      RotationMatrix :> {{-0.9976771396171857, -0.06811993162995192, 0.}, {
       0.06811993162995192, -0.9976771396171857, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04039359241338009, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26496057043478116`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.722128344789606`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10845210097262414`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9976771396171857, -0.06811993162995192, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.974551438823336, 3.606204375382554, 0.}, 
      Optica`Optica`RayEnd :> {5.93698715466518, 3.681988704384638, 0.}, 
      RotationMatrix :> {{-0.444109773104113, 0.895972382070682, 
       0.}, {-0.895972382070682, -0.444109773104113, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.160591069784868, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08458333149392293, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.26144538895214, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27148130606596466`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.444109773104113, 0.895972382070682, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.93698715466518, 3.681988704384638, 0.}, 
      Optica`Optica`RayEnd :> {5.78884187988963, 3.9356753447342863`, 0.}, 
      RotationMatrix :> {{-0.5042808865591344, 0.8635396849312325, 
       0.}, {-0.8635396849312325, -0.5042808865591344, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15973254664361652`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2937753119821585, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.696232850685735`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23227969258019304`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5042808865591344, 0.8635396849312325, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.297399842444705, -1.3703794401746636`, 0.}, 
      Optica`Optica`RayEnd :> {8.297504651474537, -1.6266875117243267`, 0.}, 
      RotationMatrix :> {{0.000408918144616216, -0.9999999163929715, 0.}, {
       0.9999999163929715, 0.000408918144616216, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.25191344162900536`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2563080929788209, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.465284448071248`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03981292037230377, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.000408918144616216, -0.9999999163929715, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.297504651474537, -1.6266875117243267`, 0.}, 
      Optica`Optica`RayEnd :> {8.281273842308778, -1.8821019026795236`, 0.}, 
      RotationMatrix :> {{-0.06341904332383455, -0.9979869863599868, 0.}, {
       0.9979869863599868, -0.06341904332383455, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.250674451114743, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25592958069201266`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.844060227495426`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02359775129189428, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.06341904332383455, -0.9979869863599868, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.443488422529625, -0.6741042190569693, 0.}, 
      Optica`Optica`RayEnd :> {6.362490433178861, -0.6800261468809501, 0.}, 
      RotationMatrix :> {{-0.9973379825359436, -0.07291740938303592, 0.}, {
       0.07291740938303592, -0.9973379825359436, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06429780882909183, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08121418292403663, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.475171641174928`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21376074467518474`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9973379825359436, -0.07291740938303592, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.362490433178861, -0.6800261468809501, 0.}, 
      Optica`Optica`RayEnd :> {6.093639983498253, -0.7145902088797783, 0.}, 
      RotationMatrix :> {{-0.9918369065110022, -0.12751294398093427`, 0.}, {
       0.12751294398093427`, -0.9918369065110022, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06402806781700361, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2710631636267163, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.876345123342468`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17132027927708257`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9918369065110022, -0.12751294398093427`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.183785132830618, -2.3608905041613863`, 0.}, 
      Optica`Optica`RayEnd :> {6.149600281557578, -2.5243795802136213`, 0.}, 
      RotationMatrix :> {{-0.20466932070892938`, -0.9788311750044256, 0.}, {
       0.9788311750044256, -0.20466932070892938`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02274946166271862, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16702479470118595`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.68487184170988, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4087290784535339, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.20466932070892938`, -0.9788311750044256, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.149600281557578, -2.5243795802136213`, 0.}, 
      Optica`Optica`RayEnd :> {6.094872903973718, -2.6425988951424286`, 0.}, 
      RotationMatrix :> {{-0.42009963071948586`, -0.9074779888621821, 0.}, {
       0.9074779888621821, -0.42009963071948586`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0205864070092409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1302723772694845, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.87767496006872, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04487646532755613, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.42009963071948586`, -0.9074779888621821, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.329947657622755, -2.9378162837687634`, 0.}, 
      Optica`Optica`RayEnd :> {7.28916863721412, -3.106593666353948, 0.}, 
      RotationMatrix :> {{-0.2348563210038703, -0.9720300964911149, 0.}, {
       0.9720300964911149, -0.2348563210038703, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18171996414288846`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.173633906187109, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.14292426049732, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02406382493574675, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2348563210038703, -0.9720300964911149, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.28916863721412, -3.106593666353948, 0.}, 
      Optica`Optica`RayEnd :> {7.207895388041592, -3.412112857650837, 0.}, 
      RotationMatrix :> {{-0.2570763065418839, -0.9663911074791524, 0.}, {
       0.9663911074791524, -0.2570763065418839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1812231873625461, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3161444563514672, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.610818055897493`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26903152084021387`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2570763065418839, -0.9663911074791524, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1955955310933275`, 2.9430773810869217`, 0.},
       Optica`Optica`RayEnd :> {4.135076293354458, 3.146048459213462, 0.}, 
      RotationMatrix :> {{-0.2857357660362537, 0.9583084430430915, 
       0.}, {-0.9583084430430915, -0.2857357660362537, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009271731607448755, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21180140861746843`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.18387207019287, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38115934594242784`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2857357660362537, 0.9583084430430915, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.135076293354458, 3.146048459213462, 0.}, 
      Optica`Optica`RayEnd :> {4.097702904223805, 3.381360299048231, 0.}, 
      RotationMatrix :> {{-0.15685885216810086`, 0.9876210308091383, 
       0.}, {-0.9876210308091383, -0.15685885216810086`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009096705829027354, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23826126873987588`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.536498747927887`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2621400917739142, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.15685885216810086`, 0.9876210308091383, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1615855378483713`, 1.207032031787801, 0.}, 
      Optica`Optica`RayEnd :> {2.924273756208271, 1.2827967015776476`, 0.}, 
      RotationMatrix :> {{-0.9526279674156846, 0.30413805368197594`, 
       0.}, {-0.30413805368197594`, -0.9526279674156846, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030435601989512576`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24911275939534525`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.207400743825865`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32036014624921505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9526279674156846, 0.30413805368197594`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.924273756208271, 1.2827967015776476`, 0.}, 
      Optica`Optica`RayEnd :> {2.6408519376863855`, 1.35138276775199, 0.}, 
      RotationMatrix :> {{-0.9719460191479248, 0.235204030285412, 
       0.}, {-0.235204030285412, -0.9719460191479248, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030262615454523963`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2916024274376397, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.63897233643357, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3678225185763918, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9719460191479248, 0.235204030285412, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4410452598506835`, -0.18049458499323162`, 
       0.}, Optica`Optica`RayEnd :> {
       3.4127101159956346`, -0.23037049313153385`, 0.}, 
      RotationMatrix :> {{-0.49396406878211296`, -0.86948231652646, 0.}, {
       0.86948231652646, -0.49396406878211296`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24081433365777574`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.057362763095118535`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.31586790773279, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32746324322922815`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.49396406878211296`, -0.86948231652646, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4127101159956346`, -0.23037049313153385`, 
       0.}, Optica`Optica`RayEnd :> {
       3.2698138327236355`, -0.44057771756705405`, 0.}, 
      RotationMatrix :> {{-0.5621899504673565, -0.8270081375618443, 0.}, {
       0.8270081375618443, -0.5621899504673565, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23919154037313073`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25417793959711876`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.692051258336527`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.23087964933557037`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5621899504673565, -0.8270081375618443, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9852894961017116`, -0.6460686592447719, 0.},
       Optica`Optica`RayEnd :> {3.935730260460921, -0.8646476621391642, 0.}, 
      RotationMatrix :> {{-0.22112125018873496`, -0.9752463241227676, 0.}, {
       0.9752463241227676, -0.22112125018873496`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.024225967439864368`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22412696924646575`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.913949795595045`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41912897044569847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22112125018873496`, -0.9752463241227676, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.935730260460921, -0.8646476621391642, 0.}, 
      Optica`Optica`RayEnd :> {3.8973613008508083`, -1.124342701262884, 0.}, 
      RotationMatrix :> {{-0.14615957433425164`, -0.9892610266408102, 0.}, {
       0.9892610266408102, -0.14615957433425164`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02407531150051946, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2625141718213184, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.302470769890597`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36108852960486226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.14615957433425164`, -0.9892610266408102, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.43125834980598, -1.0992574212415742`, 0.}, 
      Optica`Optica`RayEnd :> {4.411462985290634, -1.1769154495360734`, 0.}, 
      RotationMatrix :> {{-0.24700582383709843`, -0.9690139952500972, 0.}, {
       0.9690139952500972, -0.24700582383709843`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009044107843674506, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08014128658116643, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.677600428975477`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3611290669829394, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.24700582383709843`, -0.9690139952500972, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.411462985290634, -1.1769154495360734`, 0.}, 
      Optica`Optica`RayEnd :> {4.3351822088776855`, -1.3548246086900826`, 0.},
       RotationMatrix :> {{-0.3940676562402403, -0.9190814339901132, 0.}, {
       0.9190814339901132, -0.3940676562402403, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008780237424073651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19357279189247886`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.964088160976345`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.001522321435101948, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3940676562402403, -0.9190814339901132, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3767600525366226`, 2.6307316791079334`, 0.},
       Optica`Optica`RayEnd :> {2.262077448055811, 3.075918410771986, 0.}, 
      RotationMatrix :> {{-0.24946135595581131`, 0.968384754054238, 
       0.}, {-0.968384754054238, -0.24946135595581131`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01240381375548319, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.459720921669031, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.992456293879844`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26761253151999564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.24946135595581131`, 0.968384754054238, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.262077448055811, 3.075918410771986, 0.}, 
      Optica`Optica`RayEnd :> {2.1941208268320462`, 3.3746548047126277`, 0.}, 
      RotationMatrix :> {{-0.22181348773922488`, 0.9750891121620422, 
       0.}, {-0.9750891121620422, -0.22181348773922488`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012368030325712107`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3063683003066874, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.44588137833374, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4239792607723065, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.22181348773922488`, 0.9750891121620422, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6361714884051755`, -0.33417672375082363`, 
       0.}, Optica`Optica`RayEnd :> {2.648156598461509, -0.3943550324390119, 
       0.}, RotationMatrix :> {{0.19532390616220205`, -0.9807387887106018, 
       0.}, {0.9807387887106018, 0.19532390616220205`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010201634959507322`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06136018008149338, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.543804170756065`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05515371701502966, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.19532390616220205`, -0.9807387887106018, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.648156598461509, -0.3943550324390119, 0.}, 
      Optica`Optica`RayEnd :> {2.6728400483340056`, -0.6450395782798753, 0.}, 
      RotationMatrix :> {{0.09799031463795742, -0.9951873684071525, 0.}, {
       0.9951873684071525, 0.09799031463795742, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010103089830228935`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2518968324950674, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.916611482848765`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1510181505997587, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09799031463795742, -0.9951873684071525, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2680396580060287`, -0.8580522163487847, 0.},
       Optica`Optica`RayEnd :> {2.284457958746897, -1.1368441939427059`, 0.}, 
      RotationMatrix :> {{0.058789009246110885`, -0.9982704304905861, 0.}, {
       0.9982704304905861, 0.058789009246110885`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008080560688500561, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27927500312406606`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.37771852113624, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10870934512255903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.058789009246110885`, -0.9982704304905861, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.284457958746897, -1.1368441939427059`, 0.}, 
      Optica`Optica`RayEnd :> {2.291385780639463, -1.436690548982074, 0.}, 
      RotationMatrix :> {{0.02309840825739662, -0.9997331961758467, 0.}, {
       0.9997331961758467, 0.02309840825739662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008055170324611846, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2999263765435943, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.82160955842076, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08605350143966095, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.02309840825739662, -0.9997331961758467, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.403187952588996, 3.800301315581602, 0.}, 
      Optica`Optica`RayEnd :> {5.630284451455838, 3.8477598192669125`, 0.}, 
      RotationMatrix :> {{0.9788539498373788, 0.20456036978789777`, 
       0.}, {-0.20456036978789777`, 0.9788539498373788, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03195940378166947, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2320024339734955, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.171544240219966`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24748292521340567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9788539498373788, 0.20456036978789777`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.630284451455838, 3.8477598192669125`, 0.}, 
      Optica`Optica`RayEnd :> {5.907182003757885, 3.882611126529649, 0.}, 
      RotationMatrix :> {{0.9921720677417031, 0.12487829272196431`, 
       0.}, {-0.12487829272196431`, 0.9921720677417031, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.031742246390203614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2790821887702377, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.584585879599917`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13769323614870027`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9921720677417031, 0.12487829272196431`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.657254405218824, 3.413101570340565, 0.}, 
      Optica`Optica`RayEnd :> {7.709790060700965, 3.4116739007042938`, 0.}, 
      RotationMatrix :> {{0.9996309572496823, -0.027165222400764487`, 0.}, {
       0.027165222400764487`, 0.9996309572496823, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02160224367220629, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.052555050542536855`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.502798020641453`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3105222937858641, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9996309572496823, -0.027165222400764487`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.709790060700965, 3.4116739007042938`, 0.}, 
      Optica`Optica`RayEnd :> {7.841941765830849, 3.367434628351651, 0.}, 
      RotationMatrix :> {{0.9482762923819039, -0.31744617387272006`, 0.}, {
       0.31744617387272006`, 0.9482762923819039, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.016496266149675438`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.139359916715772, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.709050697380796`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1328584613198646, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9482762923819039, -0.31744617387272006`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.078171501620103, 1.4531793955188055`, 0.}, 
      Optica`Optica`RayEnd :> {7.126234424523609, 1.4233713146992655`, 0.}, 
      RotationMatrix :> {{0.8498308723862412, -0.5270554888616937, 0.}, {
       0.5270554888616937, 0.8498308723862412, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011099299146749298`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05655586830889065, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.677931517259516`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41981645286879665`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8498308723862412, -0.5270554888616937, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.126234424523609, 1.4233713146992655`, 0.}, 
      Optica`Optica`RayEnd :> {7.370656595532074, 1.2520823986515497`, 0.}, 
      RotationMatrix :> {{0.8189273909513205, -0.5738971409143468, 0.}, {
       0.5738971409143468, 0.8189273909513205, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01105173183287477, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2984662299847218, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.119661537636905`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39854839999744496`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8189273909513205, -0.5738971409143468, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.76948545282574, 3.4087582852440135`, 0.}, 
      Optica`Optica`RayEnd :> {7.826222303376928, 3.426778123712218, 0.}, 
      RotationMatrix :> {{0.9530848248658594, 0.3027033475375076, 
       0.}, {-0.3027033475375076, 0.9530848248658594, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1386471286652363, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05952969669742953, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.46590408237372, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18272978717372174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9530848248658594, 0.3027033475375076, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.826222303376928, 3.426778123712218, 0.}, 
      Optica`Optica`RayEnd :> {8.135770010216715, 3.527245556395318, 0.}, 
      RotationMatrix :> {{0.9511564472577715, 0.3087092691189774, 
       0.}, {-0.3087092691189774, 0.9511564472577715, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1383026528670347, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32544352480838373`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.947560499090127`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35645969378039755`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9511564472577715, 0.3087092691189774, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.159514962471937, 0.4721062938499978, 0.}, 
      Optica`Optica`RayEnd :> {7.812765773017162, -0.10705713229944788`, 0.}, 
      RotationMatrix :> {{0.7482641125037156, -0.6634009480992817, 0.}, {
       0.6634009480992817, 0.7482641125037156, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.09144955253095094, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8730217040069262, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.92414918530337, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.012056916493254022`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 120, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7482641125037156, -0.6634009480992817, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.812765773017162, -0.10705713229944788`, 0.},
       Optica`Optica`RayEnd :> {7.888113141749456, -0.22169323589710352`, 0.},
       RotationMatrix :> {{0.5492546179126727, -0.8356550512631411, 0.}, {
       0.8356550512631411, 0.5492546179126727, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07698969842798983, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13718112925228712`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.127177256596756`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4083206338810696, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 120, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5492546179126727, -0.8356550512631411, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.888113141749456, -0.22169323589710352`, 0.},
       Optica`Optica`RayEnd :> {7.834918368184336, -0.348140767657468, 0.}, 
      RotationMatrix :> {{-0.3877703431591529, -0.9217560203037634, 0.}, {
       0.9217560203037634, -0.3877703431591529, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012173485554484881`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13718112925228718`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.33020532789014, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0792367368174972, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 120, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3877703431591529, -0.9217560203037634, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.2919813439335, 0.11115117115553974`, 0.}, 
      Optica`Optica`RayEnd :> {5.30137660267463, -0.021712658906653276`, 0.}, 
      RotationMatrix :> {{0.07053730486706028, -0.9975091421245672, 0.}, {
       0.9975091421245672, 0.07053730486706028, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04728467248867965, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13319560137485048`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.328371554837812`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19529437649992146`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.07053730486706028, -0.9975091421245672, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.30137660267463, -0.021712658906653276`, 0.},
       Optica`Optica`RayEnd :> {5.319840476503305, -0.3754533054975368, 0.}, 
      RotationMatrix :> {{0.05212511910524949, -0.9986405619432159, 0.}, {
       0.9986405619432159, 0.05212511910524949, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04715996806817774, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.35422218971614083`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.8526203956177, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1463137933445844, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.05212511910524949, -0.9986405619432159, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2337022530914274`, 0.5807779500679296, 0.}, 
      Optica`Optica`RayEnd :> {3.1850486011279524`, 0.5456290314456834, 0.}, 
      RotationMatrix :> {{-0.8105987978701225, -0.5856019030805065, 0.}, {
       0.5856019030805065, -0.8105987978701225, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033180353218404846`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06002186542999344, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.77581407850038, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4206130330766771, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8105987978701225, -0.5856019030805065, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1850486011279524`, 0.5456290314456834, 0.}, 
      Optica`Optica`RayEnd :> {2.9646265652922676`, 0.4058709806656777, 0.}, 
      RotationMatrix :> {{-0.8445463127652619, -0.5354825166096453, 0.}, {
       0.5354825166096453, -0.8445463127652619, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033026689297777176`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26099461036537636`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.16208610184114, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4239172017107622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8445463127652619, -0.5354825166096453, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4639266872794554`, 2.343108263921816, 0.}, 
      Optica`Optica`RayEnd :> {3.42524535983107, 2.32639715513739, 0.}, 
      RotationMatrix :> {{-0.9179948967023107, -0.39659219562229525`, 0.}, {
       0.39659219562229525`, -0.9179948967023107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01067174121675637, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04213675651938724, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.953215700942874`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20056275077039487`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9179948967023107, -0.39659219562229525`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.42524535983107, 2.32639715513739, 0.}, 
      Optica`Optica`RayEnd :> {3.1344910450342534`, 2.2090378699962967`, 0.}, 
      RotationMatrix :> {{-0.9273090701478099, -0.37429652472552155`, 0.}, {
       0.37429652472552155`, -0.9273090701478099, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010642239483722064`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31354628586828265`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.37336772400637, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06621675941768955, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9273090701478099, -0.37429652472552155`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.419021162144573, 2.3521030916458017`, 0.}, 
      Optica`Optica`RayEnd :> {3.4036866376173576`, 2.350292019126975, 0.}, 
      RotationMatrix :> {{-0.9930978166288, -0.11728907283762441`, 0.}, {
       0.11728907283762441`, -0.9930978166288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0177851009661479, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.015441101843593331`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.97507481284984, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10596803888209858`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9930978166288, -0.11728907283762441`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4036866376173576`, 2.350292019126975, 0.}, 
      Optica`Optica`RayEnd :> {3.1808192602493235`, 2.3452581568970534`, 0.}, 
      RotationMatrix :> {{-0.9997450156546742, -0.022581046778982497`, 0.}, {
       0.022581046778982497`, -0.9997450156546742, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017624845741933917`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2229242195542142, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.273793267052486`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3546398945632902, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9997450156546742, -0.022581046778982497`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.381604823976741, -0.45247289711526967`, 0.},
       Optica`Optica`RayEnd :> {3.1315529398097395`, -0.5477796894646114, 0.},
       RotationMatrix :> {{-0.9344268904857381, -0.35615500324599436`, 0.}, {
       0.35615500324599436`, -0.9344268904857381, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019526754805094863`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26759919552081624`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.785840570080705`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2220702000986015, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.9344268904857381, -0.35615500324599436`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1315529398097395`, -0.5477796894646114, 0.},
       Optica`Optica`RayEnd :> {3.013239309426549, -0.6172267168862021, 0.}, 
      RotationMatrix :> {{-0.8624091952823405, -0.5062117935138076, 0.}, {
       0.5062117935138076, -0.8624091952823405, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0188306493500104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13718966707498562`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.969674723961184`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21560757158673968`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.8624091952823405, -0.5062117935138076, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.972389363345108, -4.14210818712324, 0.}, 
      Optica`Optica`RayEnd :> {5.977006599338496, -4.3649351408674555`, 0.}, 
      RotationMatrix :> {{0.020716726546972965`, -0.9997853855909162, 0.}, {
       0.9997853855909162, 0.020716726546972965`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008012778148628164, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22287478588468754`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.950875544363555`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2718712698955239, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 118, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.020716726546972965`, -0.9997853855909162, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.449908629578593, -0.6290946221239575, 0.}, 
      Optica`Optica`RayEnd :> {7.531812469884396, -0.8224597114203069, 0.}, 
      RotationMatrix :> {{0.3900258188300474, -0.9208039208463171, 0.}, {
       0.9208039208463171, 0.3900258188300474, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01219685533881422, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2099959447594731, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.919948359813393`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2797387303235964, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3900258188300474, -0.9208039208463171, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.531812469884396, -0.8224597114203069, 0.}, 
      Optica`Optica`RayEnd :> {7.640428094261788, -1.1038480785083356`, 0.}, 
      RotationMatrix :> {{0.36010326028797185`, -0.9329124513747111, 0.}, {
       0.9329124513747111, 0.36010326028797185`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012160121274981043`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3016235517849326, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.366351216455094`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07125752057194615, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.36010326028797185`, -0.9329124513747111, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6290617411838237`, 1.8597836212114276`, 0.},
       Optica`Optica`RayEnd :> {3.4058226965187366`, 1.6664153391472372`, 0.},
       RotationMatrix :> {{-0.7558659433172943, -0.6547264128878989, 0.}, {
       0.6547264128878989, -0.7558659433172943, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015620072431449951`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2953421127632108, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.38712587564336, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19596962259890865`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7558659433172943, -0.6547264128878989, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4058226965187366`, 1.6664153391472372`, 0.},
       Optica`Optica`RayEnd :> {3.264465092946304, 1.5995015474563508`, 0.}, 
      RotationMatrix :> {{-0.9038493066549784, -0.4278509446750276, 0.}, {
       0.4278509446750276, -0.9038493066549784, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01288808963587158, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1563951009660865, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.618590625073168`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2680070637549204, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9038493066549784, -0.4278509446750276, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.615425364229257, 2.1304326170238865`, 0.}, 
      Optica`Optica`RayEnd :> {5.614686661186413, 2.1295447813128416`, 0.}, 
      RotationMatrix :> {{-0.639591444819751, -0.7687150211316168, 0.}, {
       0.7687150211316168, -0.639591444819751, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010630461693970548`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0011549607938424065`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.31893043121211, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07444097978982671, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.639591444819751, -0.7687150211316168, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.614686661186413, 2.1295447813128416`, 0.}, 
      Optica`Optica`RayEnd :> {5.4640233858549445`, 1.9477339013071668`, 0.}, 
      RotationMatrix :> {{-0.6380680221594668, -0.769979999154202, 0.}, {
       0.769979999154202, -0.6380680221594668, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01060424037599711, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23612415933581152`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.66839418702911, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37887547461278925`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6380680221594668, -0.769979999154202, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.713787371339179, 1.570713499858081, 0.}, 
      Optica`Optica`RayEnd :> {7.774328954197708, 1.4155775426289767`, 0.}, 
      RotationMatrix :> {{0.36354624558892756`, -0.9315761521841325, 0.}, {
       0.9315761521841325, 0.36354624558892756`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009936164978887019, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16653062325112034`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.514880849053686`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27465772060659976`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.36354624558892756`, -0.9315761521841325, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.774328954197708, 1.4155775426289767`, 0.}, 
      Optica`Optica`RayEnd :> {7.862360376716455, 1.1678882075169161`, 0.}, 
      RotationMatrix :> {{0.33488843327098233`, -0.9422577870526228, 0.}, {
       0.9422577870526228, 0.33488843327098233`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00990682077110572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2628679099451451, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.9039253557725, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05062751713307724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.33488843327098233`, -0.9422577870526228, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.405720745714707, 0.28962841116119903`, 0.}, 
      Optica`Optica`RayEnd :> {7.380816080976115, -0.003170653943217791, 0.}, 
      RotationMatrix :> {{-0.0847511634941402, -0.996402147873231, 0.}, {
       0.996402147873231, -0.0847511634941402, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012581741052048121`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2938563166783423, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.425584184111592`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1518763145766984, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 118, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.0847511634941402, -0.996402147873231, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3243323955771182`, 1.5094446611867771`, 0.},
       Optica`Optica`RayEnd :> {3.1473289708149186`, 1.439324730597311, 0.}, 
      RotationMatrix :> {{-0.9297057851935557, -0.36830307218055175`, 0.}, {
       0.36830307218055175`, -0.9297057851935557, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010036193356730718`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19038649385767697`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.819444582745255`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30623148472941686`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9297057851935557, -0.36830307218055175`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1473289708149186`, 1.439324730597311, 0.}, 
      Optica`Optica`RayEnd :> {2.8900303313193105`, 1.3625771376378866`, 0.}, 
      RotationMatrix :> {{-0.9582781695172926, -0.28583727858098873`, 0.}, {
       0.28583727858098873`, -0.9582781695172926, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009958635797187197, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2685009923843043, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.216826051474026`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4118158007478157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9582781695172926, -0.28583727858098873`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1502362259938024`, -1.3957048186924736`, 
       0.}, Optica`Optica`RayEnd :> {3.140939782144625, -1.4064915027523015`, 
       0.}, RotationMatrix :> {{-0.6528420554462854, -0.7574940598055324, 
       0.}, {0.7574940598055324, -0.6528420554462854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01207073509839684, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.014239958611156626`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.278086140116233`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17776872752267456`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.6528420554462854, -0.7574940598055324, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.140939782144625, -1.4064915027523015`, 0.}, 
      Optica`Optica`RayEnd :> {2.9274205586807724`, -1.6459941452217333`, 0.},
       RotationMatrix :> {{-0.6654564534182777, -0.746436674208848, 0.}, {
       0.746436674208848, -0.6654564534182777, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012039266566667994`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32086130109199373`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.752960865732383`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4211870845758388, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6654564534182777, -0.746436674208848, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3009531280733664`, -0.43534944114653396`, 
       0.}, Optica`Optica`RayEnd :> {2.234991679446133, -0.5354867968672238, 
       0.}, RotationMatrix :> {{-0.5500914100365971, -0.8351044489187853, 
       0.}, {0.8351044489187853, -0.5500914100365971, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012039074401536185`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1199099775487225, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.008356704045376`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20625234357241923`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5500914100365971, -0.8351044489187853, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.234991679446133, -0.5354867968672238, 0.}, 
      Optica`Optica`RayEnd :> {2.0824279862392947`, -0.7938827603812862, 0.}, 
      RotationMatrix :> {{-0.5084209424008613, -0.8611086721942938, 0.}, {
       0.8611086721942938, -0.5084209424008613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011993146577347942`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3000735817183362, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.452465604988515`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.28334919592339247`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 119, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5084209424008613, -0.8611086721942938, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.126212024936174, -2.1067733899757095`, 0.}, 
      Optica`Optica`RayEnd :> {4.074089590001083, -2.1237816255091575`, 0.}, 
      RotationMatrix :> {{-0.9506664412051905, -0.31021495380825514`, 0.}, {
       0.31021495380825514`, -0.9506664412051905, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018153086228537434`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05482725872706014, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.696996322628685`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1280433166103064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9506664412051905, -0.31021495380825514`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.074089590001083, -2.1237816255091575`, 0.}, 
      Optica`Optica`RayEnd :> {3.9177412468353956`, -2.1479226278260843`, 0.},
       RotationMatrix :> {{-0.9882885108884978, -0.15259691755011148`, 0.}, {
       0.15259691755011148`, -0.9882885108884978, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017554742480894805`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15820111378723467`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.93113397103379, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42067559933648413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9882885108884978, -0.15259691755011148`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3692815675533225`, -2.347872509711066, 0.}, 
      Optica`Optica`RayEnd :> {5.3459786044157145`, -2.3471977292237662`, 0.},
       RotationMatrix :> {{-0.9995810137920084, 0.028944720875148905`, 
       0.}, {-0.028944720875148905`, -0.9995810137920084, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011262265111103337`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.023312730850305243`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.348034603497606`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15807765722757314`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.9995810137920084, 0.028944720875148905`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3459786044157145`, -2.3471977292237662`, 
       0.}, Optica`Optica`RayEnd :> {5.071169419359076, -2.318045595221131, 
       0.}, RotationMatrix :> {{-0.9944204192182169, 0.10548947739876847`, 
       0.}, {-0.10548947739876847`, -0.9944204192182169, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01119160099071891, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2763511083900355, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.75703424391486, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24589795856639607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9944204192182169, 0.10548947739876847`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.11598951992452, 0.901805773284278, 0.}, 
      Optica`Optica`RayEnd :> {8.117465107955368, 0.9039147885466935, 0.}, 
      RotationMatrix :> {{0.5732739033397004, 0.8193637969483785, 
       0.}, {-0.8193637969483785, 0.5732739033397004, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010220398973492943`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0025739668634008612`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.69837269893871, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.015043930706857413`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5732739033397004, 0.8193637969483785, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.117465107955368, 0.9039147885466935, 0.}, 
      Optica`Optica`RayEnd :> {8.193310352004639, 1.0700518446392056`, 0.}, 
      RotationMatrix :> {{0.4152926498610976, 0.9096878667825287, 
       0.}, {-0.9096878667825287, 0.4152926498610976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009743557485578981, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1826308365309098, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.968666337004453`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3874703826466261, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4152926498610976, 0.9096878667825287, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.604221962285013, 1.2840482842581151`, 0.}, 
      Optica`Optica`RayEnd :> {4.563582880352831, 1.3283827761195492`, 0.}, 
      RotationMatrix :> {{-0.6757167774312312, 0.7371613369527404, 
       0.}, {-0.7371613369527404, -0.6757167774312312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012573409885857397`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.060142182774673, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.523340559477763`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14341699602760505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6757167774312312, 0.7371613369527404, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.563582880352831, 1.3283827761195492`, 0.}, 
      Optica`Optica`RayEnd :> {4.413118909568857, 1.5107447399974474`, 0.}, 
      RotationMatrix :> {{-0.6364215877137476, 0.7713414047566177, 
       0.}, {-0.7713414047566177, -0.6364215877137476, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01252307649637794, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2364218525718051, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.873244901284036`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2056020096197454, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6364215877137476, 0.7713414047566177, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3194844998904247`, -0.05599969509460018, 
       0.}, Optica`Optica`RayEnd :> {2.151209848715848, -0.008757463641831466,
        0.}, RotationMatrix :> {{-0.9627776082507783, 0.2702947965664726, 
       0.}, {-0.2702947965664726, -0.9627776082507783, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016974745458589298`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1747803955269654, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.670967530582537`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4155360384698536, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9627776082507783, 0.2702947965664726, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.151209848715848, -0.008757463641831466, 0.},
       Optica`Optica`RayEnd :> {1.7936828751715792`, 0.0789026636679371, 0.}, 
      RotationMatrix :> {{-0.9712329432561193, 0.23813141316100145`, 
       0.}, {-0.23813141316100145`, -0.9712329432561193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0169230207771294, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3681166048030011, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.21578010569098, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2600841237612672, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9712329432561193, 0.23813141316100145`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9464350153265713`, -4.072481409782038, 0.}, 
      Optica`Optica`RayEnd :> {3.835722394194781, -4.13964075830178, 0.}, 
      RotationMatrix :> {{-0.8549896746664141, -0.5186450194630421, 0.}, {
       0.5186450194630421, -0.8549896746664141, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08653567657754005, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1294900095430818, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.825099830491688`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10131044451618136`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.8549896746664141, -0.5186450194630421, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.835722394194781, -4.13964075830178, 0.}, 
      Optica`Optica`RayEnd :> {3.6249144125819277`, -4.291219948717063, 0.}, 
      RotationMatrix :> {{-0.8119041005421057, -0.5837908285704002, 0.}, {
       0.5837908285704002, -0.8119041005421057, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0859778359737021, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25964640586504917`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.20937651117196, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0022256067509563993`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8119041005421057, -0.5837908285704002, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.312220468657105, -1.0674312255994285`, 0.}, 
      Optica`Optica`RayEnd :> {2.1483285684874125`, -1.0735863512073813`, 0.},
       RotationMatrix :> {{-0.9992955182516792, -0.03752955105124175, 0.}, {
       0.03752955105124175, -0.9992955182516792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013545767837733614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16400744041805604`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.36889837072672, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3399298229661263, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9992955182516792, -0.03752955105124175, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1483285684874125`, -1.0735863512073813`, 
       0.}, Optica`Optica`RayEnd :> {
       1.7818741487236447`, -1.0752584328605608`, 0.}, 
      RotationMatrix :> {{-0.9999895902989325, -0.00456281642990445, 0.}, {
       0.00456281642990445, -0.9999895902989325, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013504632056860493`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3664582344844425, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.911256557763693`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15193493755212842`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9999895902989325, -0.00456281642990445, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.947765141123858, -3.6496665162900763`, 0.}, 
      Optica`Optica`RayEnd :> {5.887302745128805, -3.684232142683669, 0.}, 
      RotationMatrix :> {{-0.8681461059175205, -0.49630871318187103`, 0.}, {
       0.49630871318187103`, -0.8681461059175205, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01327686148578607, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06964541519327791, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.88872262047544, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24567237732635805`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8681461059175205, -0.49630871318187103`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.887302745128805, -3.684232142683669, 0.}, 
      Optica`Optica`RayEnd :> {5.616473148431152, -3.839546036759751, 0.}, 
      RotationMatrix :> {{-0.8674775466060445, -0.497476337260736, 0.}, {
       0.497476337260736, -0.8674775466060445, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013244126484075079`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3122035812422552, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.35078392071398, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24313229655591895`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.8674775466060445, -0.497476337260736, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.474559788528993, -4.071123810438171, 0.}, 
      Optica`Optica`RayEnd :> {7.579937962894859, -4.3161032824231205`, 0.}, 
      RotationMatrix :> {{0.3951448435018557, -0.9186188288152454, 0.}, {
       0.9186188288152454, 0.3951448435018557, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2032824779800118, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26668239785690256`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.466172013276452`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12141121896530604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3951448435018557, -0.9186188288152454, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.579937962894859, -4.3161032824231205`, 0.}, 
      Optica`Optica`RayEnd :> {7.666259953006467, -4.416423503191367, 0.}, 
      RotationMatrix :> {{0.6522416527857493, -0.7580110991082606, 0.}, {
       0.7580110991082606, 0.6522416527857493, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15014819618983194`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13234663830947194`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.66204503797447, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3973743663672349, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6522416527857493, -0.7580110991082606, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.666259953006467, -4.416423503191367, 0.}, 
      Optica`Optica`RayEnd :> {7.798279980013547, -4.407131294580484, 0.}, 
      RotationMatrix :> {{0.9975321526367094, 0.07021114196458983, 
       0.}, {-0.07021114196458983, 0.9975321526367094, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03924596278987575, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13234663830947208`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.85791806267249, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.005966776588013199, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9975321526367094, 0.07021114196458983, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.798279980013547, -4.407131294580484, 0.}, 
      Optica`Optica`RayEnd :> {7.869698474112256, -4.295708534910429, 0.}, 
      RotationMatrix :> {{0.5396320980341672, 0.8419009435623896, 
       0.}, {-0.8419009435623896, 0.5396320980341672, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01025816915813612, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13234663830947227`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.05379108737051, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4045036046313473, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 125, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5396320980341672, 0.8419009435623896, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.094646516432469, -2.548964716506338, 0.}, 
      Optica`Optica`RayEnd :> {7.017709930673849, -2.8118212473725794`, 0.}, 
      RotationMatrix :> {{-0.2809087314073877, -0.9597344865217103, 0.}, {
       0.9597344865217103, -0.2809087314073877, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02029328043853616, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27388463638405985`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.11345605923718, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.15781397617745008`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.2809087314073877, -0.9597344865217103, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.017709930673849, -2.8118212473725794`, 0.}, 
      Optica`Optica`RayEnd :> {6.929734262581606, -3.1213235621942435`, 0.}, 
      RotationMatrix :> {{-0.2734176384847101, -0.9618954178939846, 0.}, {
       0.9618954178939846, -0.2734176384847101, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02024264715887027, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3217629578684364, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.589665236882464`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3837739641524802, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.2734176384847101, -0.9618954178939846, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.516406202241529, 3.153786736063154, 0.}, 
      Optica`Optica`RayEnd :> {4.4247886751073, 3.2215031330595845`, 0.}, 
      RotationMatrix :> {{-0.8041799413059671, 0.5943859200899115, 
       0.}, {-0.5943859200899115, -0.8041799413059671, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008216864404423688, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11392665052729894`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.39166381196505, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3182232513163667, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8041799413059671, 0.5943859200899115, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.4247886751073, 3.2215031330595845`, 0.}, 
      Optica`Optica`RayEnd :> {4.134348357352752, 3.424274933828437, 0.}, 
      RotationMatrix :> {{-0.8199427405765038, 0.5724455451620631, 
       0.}, {-0.5724455451620631, -0.8199427405765038, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00819351101102162, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3542202441481941, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.915909773304378`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3794608370593763, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8199427405765038, 0.5724455451620631, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.897134594666521, -1.0567814332362302`, 0.}, 
      Optica`Optica`RayEnd :> {4.838260177596472, -1.1224294320918338`, 0.}, 
      RotationMatrix :> {{-0.6676555980982528, -0.7444702830389295, 0.}, {
       0.7444702830389295, -0.6676555980982528, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16746429442840072`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08818081843056016, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.03066671365555, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21217034812265417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6676555980982528, -0.7444702830389295, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.838260177596472, -1.1224294320918338`, 0.}, 
      Optica`Optica`RayEnd :> {4.628548247530289, -1.346088855764899, 0.}, 
      RotationMatrix :> {{-0.6839953224615645, -0.7294863938763354, 0.}, {
       0.7294863938763354, -0.6839953224615645, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1670094770389857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3065984856613794, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.484432472434392`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4276624486339197, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6839953224615645, -0.7294863938763354, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.863954869871214, 1.9176321217127803`, 0.}, 
      Optica`Optica`RayEnd :> {5.828851133311871, 1.7536027718809188`, 0.}, 
      RotationMatrix :> {{-0.20927025635826918`, -0.9778578423287011, 0.}, {
       0.9778578423287011, -0.20927025635826918`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008089984316145455, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16774355405407054`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.128256622643317`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3485991792265264, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 122, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.20927025635826918`, -0.9778578423287011, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.828233618459975, 2.9715138482660324`, 0.}, 
      Optica`Optica`RayEnd :> {4.657936910198665, 2.9071816910221346`, 0.}, 
      RotationMatrix :> {{-0.9354760067422158, -0.35339021040435814`, 0.}, {
       0.35339021040435814`, -0.9354760067422158, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03695073426189968, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18204283918982125`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.683557939504755`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2173178923832607, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9354760067422158, -0.35339021040435814`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.657936910198665, 2.9071816910221346`, 0.}, 
      Optica`Optica`RayEnd :> {4.451625246734025, 2.8573328742422452`, 0.}, 
      RotationMatrix :> {{-0.9720290431632368, -0.234860680504764, 0.}, {
       0.234860680504764, -0.9720290431632368, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.036355405316505024`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21224845586223207`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.99768565418086, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4267540257788779, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9720290431632368, -0.234860680504764, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.56275376786472, 1.7150572909505666`, 0.}, 
      Optica`Optica`RayEnd :> {4.411361324814766, 1.641264663471477, 0.}, 
      RotationMatrix :> {{-0.898902569966389, -0.4381485703592111, 0.}, {
       0.4381485703592111, -0.898902569966389, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03556946153593966, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1684191903641075, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.896414772317, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1615701835074436, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.898902569966389, -0.4381485703592111, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.411361324814766, 1.641264663471477, 0.}, 
      Optica`Optica`RayEnd :> {4.234404632860996, 1.5925539569764573`, 0.}, 
      RotationMatrix :> {{-0.9641390342726762, -0.26539766877602866`, 0.}, {
       0.26539766877602866`, -0.9641390342726762, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03383326130557584, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18353856203660604`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.168051844131178`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3719912655655078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9641390342726762, -0.26539766877602866`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.116889302356681, 2.756812497992865, 0.}, 
      Optica`Optica`RayEnd :> {4.90488330168855, 2.735726286789342, 0.}, 
      RotationMatrix :> {{-0.99509020719508, -0.09897211498422952, 0.}, {
       0.09897211498422952, -0.99509020719508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04027378731028649, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21305204205126782`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.007618081138304`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3616012612033896, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.99509020719508, -0.09897211498422952, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.90488330168855, 2.735726286789342, 0.}, 
      Optica`Optica`RayEnd :> {4.604009722506619, 2.7158150708953386`, 0.}, 
      RotationMatrix :> {{-0.9978174016951613, -0.06603357384176489, 0.}, {
       0.06603357384176489, -0.9978174016951613, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.040151370201531866`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30153170176305266`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.453884999747622`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1812424150488707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9978174016951613, -0.06603357384176489, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.281273842308778, -1.8821019026795236`, 0.}, 
      Optica`Optica`RayEnd :> {8.257770156028219, -2.0656888230253854`, 0.}, 
      RotationMatrix :> {{-0.12698837809342683`, -0.9919042049659835, 0.}, {
       0.9919042049659835, -0.12698837809342683`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2494415543503198, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1850853332678006, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.092074574074278`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20183758213272723`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12698837809342683`, -0.9919042049659835, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.257770156028219, -2.0656888230253854`, 0.}, 
      Optica`Optica`RayEnd :> {8.215440038407017, -2.401181598702991, 0.}, 
      RotationMatrix :> {{-0.12518048485338798`, -0.9921339860179519, 0.}, {
       0.9921339860179519, -0.12518048485338798`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24882635126203284`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3381526894609726, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.592540554476518`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3091389752869406, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12518048485338798`, -0.9921339860179519, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.093639983498253, -0.7145902088797783, 0.}, 
      Optica`Optica`RayEnd :> {5.914514873020996, -0.7476928139270784, 0.}, 
      RotationMatrix :> {{-0.9833494747882516, -0.1817245454903358, 0.}, {
       0.1817245454903358, -0.9833494747882516, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06375945841756175, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1821581391659642, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.12043702982486, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3827905442214018, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9833494747882516, -0.1817245454903358, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.914514873020996, -0.7476928139270784, 0.}, 
      Optica`Optica`RayEnd :> {5.630380699138552, -0.7899309361355071, 0.}, 
      RotationMatrix :> {{-0.989130583555903, -0.1470397520208671, 0.}, {
       0.1470397520208671, -0.989130583555903, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06356053230102765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28725648423587163`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.54557662649395, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22662282740847353`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.989130583555903, -0.1470397520208671, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.094872903973718, -2.6425988951424286`, 0.}, 
      Optica`Optica`RayEnd :> {5.951171420434094, -2.8273803728010924`, 0.}, 
      RotationMatrix :> {{-0.6138941814285392, -0.7893883290296246, 0.}, {
       0.7893883290296246, -0.6138941814285392, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01862901899980518, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2340818464922212, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.191344634368296`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3668629702629064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6138941814285392, -0.7893883290296246, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.951171420434094, -2.8273803728010924`, 0.}, 
      Optica`Optica`RayEnd :> {5.8301339973671515`, -3.0309964858953027`, 0.},
       RotationMatrix :> {{-0.5109767769477629, -0.8595945168625003, 0.}, {
       0.8595945168625003, -0.5109767769477629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018325650740303748`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2368746066894473, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.54191905226868, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09833675776944412, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5109767769477629, -0.8595945168625003, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.207895388041592, -3.412112857650837, 0.}, 
      Optica`Optica`RayEnd :> {7.186656610075415, -3.4851689095687415`, 0.}, 
      RotationMatrix :> {{-0.2791611918085472, -0.9602442548581224, 0.}, {
       0.9602442548581224, -0.2791611918085472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.18072776864525777`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07608069670637979, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.712766189484043`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38126659351057646`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2791611918085472, -0.9602442548581224, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.186656610075415, -3.4851689095687415`, 0.}, 
      Optica`Optica`RayEnd :> {7.104736350691827, -3.6563018927554336`, 0.}, 
      RotationMatrix :> {{-0.4317731081157472, -0.9019822521025934, 0.}, {
       0.9019822521025934, -0.4317731081157472, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17462954874357203`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18972987859546797`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.993566409805336`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012846370735146662`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4317731081157472, -0.9019822521025934, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.097702904223805, 3.381360299048231, 0.}, 
      Optica`Optica`RayEnd :> {4.09629675294918, 3.437049686041319, 0.}, 
      RotationMatrix :> {{-0.02524185152241268, 0.9996813737045017, 
       0.}, {-0.9996813737045017, -0.02524185152241268, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008924984074536874, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.055707136751703815`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.61114631117517, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11525283235822181`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.02524185152241268, 0.9996813737045017, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.09629675294918, 3.437049686041319, 0.}, 
      Optica`Optica`RayEnd :> {4.07115545095173, 3.6707940629447973`, 0.}, 
      RotationMatrix :> {{-0.10694213546302186`, 0.9942652461303311, 
       0.}, {-0.9942652461303311, -0.10694213546302186`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008863020427805972, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.235092574957446, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.95908332211219, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009151109288428938, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10694213546302186`, 0.9942652461303311, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6408519376863855`, 1.35138276775199, 0.}, 
      Optica`Optica`RayEnd :> {2.5958833832665844`, 1.3589087179036896`, 0.}, 
      RotationMatrix :> {{-0.9862827632600667, 0.16506456584042017`, 
       0.}, {-0.16506456584042017`, -0.9862827632600667, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030090612121421702`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04559397780729916, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.700068266695354`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10265984172907322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9862827632600667, 0.16506456584042017`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5958833832665844`, 1.3589087179036896`, 0.},
       Optica`Optica`RayEnd :> {2.3206781979850604`, 1.4260747983155784`, 0.},
       RotationMatrix :> {{-0.9714854947706674, 0.2370989950425576, 
       0.}, {-0.2370989950425576, -0.9714854947706674, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02991307961919179, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2832828557532808, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.11932689321021, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17690899351729944`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9714854947706674, 0.2370989950425576, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2698138327236355`, -0.4405777175670541, 0.},
       Optica`Optica`RayEnd :> {2.937998642286805, -0.8530764190411502, 0.}, 
      RotationMatrix :> {{-0.6267847446279597, -0.7791924562658845, 0.}, {
       0.7791924562658845, -0.6267847446279597, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23757968272510135`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5293925758097158, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.401437309921548`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3429791231981707, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6267847446279597, -0.7791924562658845, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.937998642286805, -0.8530764190411502, 0.}, 
      Optica`Optica`RayEnd :> {2.8297096805049433`, -1.02433477027403, 0.}, 
      RotationMatrix :> {{-0.534436713382981, -0.8452084946262647, 0.}, {
       0.8452084946262647, -0.534436713382981, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2344716387877651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2026226100680719, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.701318772822294`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10461769570048607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.534436713382981, -0.8452084946262647, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8973613008508083`, -1.124342701262884, 0.}, 
      Optica`Optica`RayEnd :> {3.892751312928141, -1.1897116440320903`, 0.}, 
      RotationMatrix :> {{-0.07034788339783582, -0.9975225186939108, 0.}, {
       0.9975225186939108, -0.07034788339783582, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023925592457177423`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0655312953283461, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.390282705630582`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13061622351406893`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.07034788339783582, -0.9975225186939108, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.892751312928141, -1.1897116440320903`, 0.}, 
      Optica`Optica`RayEnd :> {3.860881282240003, -1.4002161107014388`, 0.}, 
      RotationMatrix :> {{-0.149692492782456, -0.9887326016697202, 0.}, {
       0.9887326016697202, -0.149692492782456, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023766055741274536`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2129033333318426, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.70537963896171, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.018103913453952517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.149692492782456, -0.9887326016697202, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.3351822088776855`, -1.3548246086900826`, 
       0.}, Optica`Optica`RayEnd :> {4.21139443529494, -1.5520424102655443`, 
       0.}, RotationMatrix :> {{-0.531624402114722, -0.8469802211835668, 
       0.}, {0.8469802211835668, -0.531624402114722, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008524065674097695, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23284817831976093`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.276104719924824`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31146848537731064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.531624402114722, -0.8469802211835668, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.21139443529494, -1.5520424102655443`, 0.}, 
      Optica`Optica`RayEnd :> {4.07555611396809, -1.8117704305492082`, 0.}, 
      RotationMatrix :> {{-0.46344552409379275`, -0.8861254122286693, 0.}, {
       0.8861254122286693, -0.46344552409379275`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008468562486519738, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29310526106054124`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.709900506294424`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22114233384823362`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46344552409379275`, -0.8861254122286693, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1941208268320462`, 3.3746548047126277`, 0.},
       Optica`Optica`RayEnd :> {2.1530100585787526`, 3.5825554779714337`, 0.},
       RotationMatrix :> {{-0.19398609410323048`, 0.9810042789379522, 
       0.}, {-0.9810042789379522, -0.19398609410323048`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012332350126598257`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21192636742000948`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.729862710676553`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42166499762799825`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.19398609410323048`, 0.9810042789379522, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1530100585787526`, 3.5825554779714337`, 0.},
       Optica`Optica`RayEnd :> {2.1227029962502155`, 3.8305644736481965`, 0.},
       RotationMatrix :> {{-0.12129912815654423`, 0.9926159990189868, 
       0.}, {-0.9926159990189868, -0.12129912815654423`, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012259491984874664`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24985391724682332`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.09964650820185, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3748961098718803, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.12129912815654423`, 0.9926159990189868, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6728400483340056`, -0.6450395782798753, 0.},
       Optica`Optica`RayEnd :> {2.6728293627882644`, -0.6816242794814096, 0.},
       RotationMatrix :> {{-0.0002920768773361643, -0.9999999573455477, 0.}, {
       0.9999999573455477, -0.0002920768773361643, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01000549662116167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03658470276203468, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.96563498454989, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3058762579477174, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.0002920768773361643, -0.9999999573455477, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6728293627882644`, -0.6816242794814096, 0.},
       Optica`Optica`RayEnd :> {2.6958045992808475`, -0.8824309136322641, 0.},
       RotationMatrix :> {{0.11367311546407693`, -0.9935182045743751, 0.}, {
       0.9935182045743751, 0.11367311546407693`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009872945037530766, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2021167133388164, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.26476772029134, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38730962955085735`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.11367311546407693`, -0.9935182045743751, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.291385780639463, -1.436690548982074, 0.}, 
      Optica`Optica`RayEnd :> {2.2897548956541605`, -1.5658933942645108`, 0.},
       RotationMatrix :> {{-0.012621665345882955`, -0.9999203436093775, 0.}, {
       0.9999203436093775, -0.012621665345882955`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00802985974114967, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12921313793462563`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.99475516325316, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19250178139996174`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.012621665345882955`, -0.9999203436093775, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2897548956541605`, -1.5658933942645108`, 
       0.}, Optica`Optica`RayEnd :> {2.282771181374178, -1.8615689193742373`, 
       0.}, RotationMatrix :> {{-0.02361293532375934, -0.9997211757712222, 
       0.}, {0.9997211757712222, -0.02361293532375934, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008009581870598843, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29575798960308214`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.432476987865723`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2140737725895545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.02361293532375934, -0.9997211757712222, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.907182003757885, 3.882611126529649, 0.}, 
      Optica`Optica`RayEnd :> {6.679674476361992, 3.916929071821072, 0.}, 
      RotationMatrix :> {{0.9990146698030343, 0.04438118428268492, 
       0.}, {-0.04438118428268492, 0.9990146698030343, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03152656453729881, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7732543834981032, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.620746753487374`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3502095970290269, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9990146698030343, 0.04438118428268492, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.679674476361992, 3.916929071821072, 0.}, 
      Optica`Optica`RayEnd :> {6.834619754427745, 3.8806501516394767`, 0.}, 
      RotationMatrix :> {{0.9736670759847911, -0.22797461512902334`, 0.}, {
       0.22797461512902334`, 0.9736670759847911, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.025818944992908193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1591357886976278, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.856267720759863`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09383090943251704, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9736670759847911, -0.22797461512902334`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.841941765830849, 3.367434628351651, 0.}, 
      Optica`Optica`RayEnd :> {8.081998778109991, 3.196453475142506, 0.}, 
      RotationMatrix :> {{0.8145161025074987, -0.5801409473188331, 0.}, {
       0.5801409473188331, 0.8145161025074987, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012597154305367621`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2947234702176215, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.10398014747241, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13198686301736623`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8145161025074987, -0.5801409473188331, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.081998778109991, 3.196453475142506, 0.}, 
      Optica`Optica`RayEnd :> {8.27378532912938, 3.089154647252922, 0.}, 
      RotationMatrix :> {{0.8727031149068092, -0.488251239867296, 0.}, {
       0.488251239867296, 0.8727031149068092, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012447299934343995`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21976150622525217`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.42922717668578, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11890559529573949`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8727031149068092, -0.488251239867296, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.370656595532074, 1.2520823986515497`, 0.}, 
      Optica`Optica`RayEnd :> {7.442301448445294, 1.1956261762702811`, 0.}, 
      RotationMatrix :> {{0.7854449716037487, -0.618931495872027, 0.}, {
       0.618931495872027, 0.7854449716037487, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011004368374155358`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0912156236317011, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.241890473303386`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4238507979522624, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7854449716037487, -0.618931495872027, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.442301448445294, 1.1956261762702811`, 0.}, 
      Optica`Optica`RayEnd :> {7.690322061937462, 0.9829898218117369, 0.}, 
      RotationMatrix :> {{0.7591851221426102, -0.65087475778164, 0.}, {
       0.65087475778164, 0.7591851221426102, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01096704909811298, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32669319545171355`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.72539640257192, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32685739275256764`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7591851221426102, -0.65087475778164, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.135770010216715, 3.527245556395318, 0.}, 
      Optica`Optica`RayEnd :> {8.25819076382651, 3.567834013922942, 0.}, 
      RotationMatrix :> {{0.9491902233874245, 0.3147029072406709, 
       0.}, {-0.3147029072406709, 0.9491902233874245, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.13795903293636302`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1289738880504959, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.120385509077792`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32614883586916266`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.9491902233874245, 0.3147029072406709, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.25819076382651, 3.567834013922942, 0.}, 
      Optica`Optica`RayEnd :> {8.495946585525004, 3.6887914096803205`, 0.}, 
      RotationMatrix :> {{0.8912872611747825, 0.4534391007263867, 
       0.}, {-0.4534391007263867, 0.8912872611747825, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1342857484716806, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2667555479084419, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.515183719982286`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2842389815716897, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8912872611747825, 0.4534391007263867, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.812765773017162, -0.10705713229944788`, 0.},
       Optica`Optica`RayEnd :> {7.898297320087702, -0.13106147713959804`, 0.},
       RotationMatrix :> {{0.9628015998079162, -0.2702093251672048, 0.}, {
       0.2702093251672048, 0.9628015998079162, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014459854102961163`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08883610817389934, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.043189570256395`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3668042699636638, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9628015998079162, -0.2702093251672048, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.898297320087702, -0.13106147713959804`, 0.},
       Optica`Optica`RayEnd :> {8.085192016271241, -0.15233612156201284`, 0.},
       RotationMatrix :> {{0.9935834008051853, -0.11310183749347974`, 0.}, {
       0.11310183749347974`, 0.9935834008051853, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013999677330604303`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18810166920268867`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.321580040676373`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.001554021194934196, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9935834008051853, -0.11310183749347974`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.888113141749456, -0.22169323589710355`, 0.},
       Optica`Optica`RayEnd :> {7.9413563276372345`, -0.3837138304238663, 0.},
       RotationMatrix :> {{0.31219482035439217`, -0.9500181020085291, 0.}, {
       0.9500181020085291, 0.31219482035439217`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06481621287350493, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17054474455193916`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.355707214296356`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2785859887355446, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.31219482035439217`, -0.9500181020085291, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.9413563276372345`, -0.3837138304238663, 0.},
       Optica`Optica`RayEnd :> {8.023749465279174, -0.6564234254441896, 0.}, 
      RotationMatrix :> {{0.28921598344717814`, -0.9572638690134924, 0.}, {
       0.9572638690134924, 0.28921598344717814`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06463714399228207, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28488445437866977`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.777336206776788`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0020804093334473033`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.28921598344717814`, -0.9572638690134924, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.834918368184336, -0.34814076765746804`, 0.},
       Optica`Optica`RayEnd :> {7.220197575325882, -1.1366431247685609`, 0.}, 
      RotationMatrix :> {{-0.6148383549377238, -0.7886531539894281, 0.}, {
       0.7886531539894281, -0.6148383549377238, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010248633872102194`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9998087918908676, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.669949109023904`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3597912876602244, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6148383549377238, -0.7886531539894281, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.220197575325882, -1.1366431247685609`, 0.}, 
      Optica`Optica`RayEnd :> {7.110066133937232, -1.3196122735009896`, 0.}, 
      RotationMatrix :> {{-0.515700160526837, -0.856769131349043, 0.}, {
       0.856769131349043, -0.515700160526837, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010095283466440808`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21355712062633594`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.98601364755088, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10302899520380335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.515700160526837, -0.856769131349043, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.319840476503305, -0.3754533054975368, 0.}, 
      Optica`Optica`RayEnd :> {5.329960608744796, -0.6756262338699552, 0.}, 
      RotationMatrix :> {{0.03369519575465825, -0.9994321556679342, 0.}, {
       0.9994321556679342, 0.03369519575465825, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04703559253210442, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3003434767133428, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.25508065441358, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20497303622615626`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.03369519575465825, -0.9994321556679342, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.329960608744796, -0.6756262338699552, 0.}, 
      Optica`Optica`RayEnd :> {5.311374477317961, -0.8702033506379357, 0.}, 
      RotationMatrix :> {{-0.09508782877901711, -0.9954688869161561, 0.}, {
       0.9954688869161561, -0.09508782877901711, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.046203128067370994`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19546278073115575`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.54436556989569, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11492887780492672`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.09508782877901711, -0.9954688869161561, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9646265652922676`, 0.4058709806656777, 0.}, 
      Optica`Optica`RayEnd :> {2.871601740402528, 0.35450208351356993`, 0.}, 
      RotationMatrix :> {{-0.875399083411589, -0.48340091514409506`, 0.}, {
       0.48340091514409506`, -0.875399083411589, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03287373702118617, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10626561833627353`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.304482030411748`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17268939012050002`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.875399083411589, -0.48340091514409506`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.871601740402528, 0.35450208351356993`, 0.}, 
      Optica`Optica`RayEnd :> {2.568609747241561, 0.17993281888803214`, 0.}, 
      RotationMatrix :> {{-0.8664748581881636, -0.4992207128393218, 0.}, {
       0.4992207128393218, -0.8664748581881636, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032787214709693056`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3496835370324953, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.822013665219842`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17184486021544004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8664748581881636, -0.4992207128393218, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1344910450342534`, 2.2090378699962967`, 0.},
       Optica`Optica`RayEnd :> {2.605605904911915, 2.0102812707078206`, 0.}, 
      RotationMatrix :> {{-0.9360818334808005, -0.35178232051543135`, 0.}, {
       0.35178232051543135`, -0.9360818334808005, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01061281930741165, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.5649988293819249, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.20956599149162, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32796742749639435`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9360818334808005, -0.35178232051543135`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.605605904911915, 2.0102812707078206`, 0.}, 
      Optica`Optica`RayEnd :> {2.352085693409248, 1.914169228756334, 0.}, 
      RotationMatrix :> {{-0.9350596388448165, -0.35449043965021126`, 0.}, {
       0.35449043965021126`, -0.9350596388448165, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010586617895193861`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2711273174146073, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.572876596827193`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19146272063299447`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9350596388448165, -0.35449043965021126`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1808192602493235`, 2.3452581568970534`, 0.},
       Optica`Optica`RayEnd :> {3.1380886835098276`, 2.34835699848299, 0.}, 
      RotationMatrix :> {{-0.9973807176024674, 0.0723305202164796, 
       0.}, {-0.0723305202164796, -0.9973807176024674, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017466034520592713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0428427941159851, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.337200602344144`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0517094355627241, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9973807176024674, 0.0723305202164796, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1380886835098276`, 2.34835699848299, 0.}, 
      Optica`Optica`RayEnd :> {2.9377092946462433`, 2.335707755262018, 0.}, 
      RotationMatrix :> {{-0.998013459705856, -0.06300106543501682, 0.}, {
       0.06300106543501682, -0.998013459705856, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01711559636621599, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20077824293335875`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.606243447874846`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4272833743107952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.998013459705856, -0.06300106543501682, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.013239309426549, -0.6172267168862021, 0.}, 
      Optica`Optica`RayEnd :> {2.9142006442519786`, -0.7002105201445175, 0.}, 
      RotationMatrix :> {{-0.7664996704176925, -0.6422447004449072, 0.}, {
       0.6422447004449072, -0.7664996704176925, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01815935922186763, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12920901208033217`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.160904061840075`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2581930716791184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7664996704176925, -0.6422447004449072, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9142006442519786`, -0.7002105201445175, 0.},
       Optica`Optica`RayEnd :> {2.7009504064931456`, -0.886442425745927, 0.}, 
      RotationMatrix :> {{-0.7532100811450123, -0.6577800344047574, 0.}, {
       0.6577800344047574, -0.7532100811450123, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018110736853952092`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28312185816028257`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.540287351774854`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4011573970635167, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7532100811450123, -0.6577800344047574, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.640428094261788, -1.1038480785083356`, 0.}, 
      Optica`Optica`RayEnd :> {7.653211682028765, -1.1404403509867747`, 0.}, 
      RotationMatrix :> {{0.3298054827835016, -0.9440489094988357, 0.}, {
       0.9440489094988357, 0.3298054827835016, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012123497845521093`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03876099226454786, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.418290946089588`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30701026992928165`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3298054827835016, -0.9440489094988357, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.653211682028765, -1.1404403509867747`, 0.}, 
      Optica`Optica`RayEnd :> {7.766147741904659, -1.4105064288629432`, 0.}, 
      RotationMatrix :> {{0.3858042009256227, -0.92258068403156, 0.}, {
       0.92258068403156, 0.3858042009256227, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012067911144361454`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29272895319682385`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.851529796820888`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29903547629841165`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3858042009256227, -0.92258068403156, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.264465092946304, 1.5995015474563508`, 0.}, 
      Optica`Optica`RayEnd :> {3.1433883712892046`, 1.578667178518207, 0.}, 
      RotationMatrix :> {{-0.9855158418705532, -0.16958338781311558`, 0.}, {
       0.16958338781311558`, -0.9855158418705532, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010633936250374093`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.12285619014230179`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.78321791986385, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2834046276482186, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9855158418705532, -0.16958338781311558`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1433883712892046`, 1.578667178518207, 0.}, 
      Optica`Optica`RayEnd :> {2.8156411223846534`, 1.5132813511973178`, 0.}, 
      RotationMatrix :> {{-0.9806747138124245, -0.19564535693166354`, 0.}, {
       0.19564535693166354`, -0.9806747138124245, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01060386785010563, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3342058730467478, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.27784261197304, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.025358560621933583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9806747138124245, -0.19564535693166354`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.4640233858549445`, 1.9477339013071668`, 0.},
       Optica`Optica`RayEnd :> {5.332146241952127, 1.7879499890282105`, 0.}, 
      RotationMatrix :> {{-0.6365420976434009, -0.7712419580959907, 0.}, {
       0.7712419580959907, -0.6365420976434009, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010578083736072108`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2071774111893809, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.946011918022883`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3886535976914831, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6365420976434009, -0.7712419580959907, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.332146241952127, 1.7879499890282105`, 0.}, 
      Optica`Optica`RayEnd :> {5.1875130680893315`, 1.639042991257376, 0.}, 
      RotationMatrix :> {{-0.6967377540287782, -0.7173259385460228, 0.}, {
       0.7173259385460228, -0.6967377540287782, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010506174175654186`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20758624464725173`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.253239560100816`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3031124080926821, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6967377540287782, -0.7173259385460228, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.862360376716455, 1.1678882075169161`, 0.}, 
      Optica`Optica`RayEnd :> {7.880779110920352, 1.1105665064762662`, 0.}, 
      RotationMatrix :> {{0.30591737718627754`, -0.9520580645819181, 0.}, {
       0.9520580645819181, 0.30591737718627754`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009877563224781047, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06020819861005196, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.98460434190997, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20315234547840683`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.30591737718627754`, -0.9520580645819181, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.880779110920352, 1.1105665064762662`, 0.}, 
      Optica`Optica`RayEnd :> {7.977761929985089, 0.8882111978820659, 0.}, 
      RotationMatrix :> {{0.39978878678824076`, -0.9166072910240162, 0.}, {
       0.9166072910240162, 0.39978878678824076`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009778346537379792, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2425851406285336, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.3436303500402, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37676527711457697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.39978878678824076`, -0.9166072910240162, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.380816080976115, -0.003170653943217805, 0.},
       Optica`Optica`RayEnd :> {7.29815300656839, -0.1434792057361047, 0.}, 
      RotationMatrix :> {{-0.507606841033086, -0.8615888201087628, 0.}, {
       0.8615888201087628, -0.507606841033086, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012581741052048123`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16284862166059086`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 19.666600144169266`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07564419902996472, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.507606841033086, -0.8615888201087628, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.29815300656839, -0.1434792057361047, 0.}, 
      Optica`Optica`RayEnd :> {7.14183109987971, -0.3988120264075526, 0.}, 
      RotationMatrix :> {{-0.5221433883431844, -0.852857714985036, 0.}, {
       0.852857714985036, -0.5221433883431844, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012548900588498939`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29938501602923023`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.067776065648435`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3735867639902099, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.5221433883431844, -0.852857714985036, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8900303313193105`, 1.3625771376378866`, 0.},
       Optica`Optica`RayEnd :> {2.8701993775974306`, 1.3585039727833168`, 0.},
       RotationMatrix :> {{-0.9795513602740505, -0.20119426578621982`, 0.}, {
       0.20119426578621982`, -0.9795513602740505, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00988167758590537, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0202449351061407, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.243954264516255`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07891825959789969, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9795513602740505, -0.20119426578621982`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8701993775974306`, 1.3585039727833168`, 0.},
       Optica`Optica`RayEnd :> {2.5939123039010066`, 1.2797169994967676`, 0.},
       RotationMatrix :> {{-0.9616637503119198, -0.27423134637749275`, 0.}, {
       0.27423134637749275`, -0.9616637503119198, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009821481803894826, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28730112121498697`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.669159923914435`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1634954135062128, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9616637503119198, -0.27423134637749275`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9274205586807724`, -1.6459941452217333`, 
       0.}, Optica`Optica`RayEnd :> {2.880748875491625, -1.6966098945074817`, 
       0.}, RotationMatrix :> {{-0.677883599389129, -0.735169249682845, 0.}, {
       0.735169249682845, -0.677883599389129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01200788007372809, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06884911101434685, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.84521867449161, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36692350339243246`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.677883599389129, -0.735169249682845, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.880748875491625, -1.6966098945074817`, 0.}, 
      Optica`Optica`RayEnd :> {2.6744488706177325`, -1.8935461606096162`, 0.},
       RotationMatrix :> {{-0.7233318425115661, -0.6905005761104196, 0.}, {
       0.6905005761104196, -0.7233318425115661, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011948967157664725`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2852079678361369, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.26732646688909, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35632309782163374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7233318425115661, -0.6905005761104196, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0824279862392947`, -0.7938827603812862, 0.},
       Optica`Optica`RayEnd :> {2.0544620146035415`, -0.8470505500838811, 0.},
       RotationMatrix :> {{-0.46552383424891314`, -0.8850353437836197, 0.}, {
       0.8850353437836197, -0.46552383424891314`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011947393963060755`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.060074199382023435`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.532965032160426`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.019030763755236903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46552383424891314`, -0.8850353437836197, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0544620146035415`, -0.8470505500838811, 0.},
       Optica`Optica`RayEnd :> {1.8756163776684474`, -1.1869631499097286`, 
       0.}, RotationMatrix :> {{-0.4656328046451193, -0.8849780173757535, 
       0.}, {0.8849780173757535, -0.4656328046451193, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011917947551899127`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3840915741995471, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.101420561975758`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.422554701070049, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 123, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4656328046451193, -0.8849780173757535, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9177412468353956`, -2.1479226278260843`, 
       0.}, Optica`Optica`RayEnd :> {3.9031775651540577`, -2.147791139500906, 
       0.}, RotationMatrix :> {{-0.9999592455078385, 0.009028140638815546, 
       0.}, {-0.009028140638815546, -0.9999592455078385, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016976120737314512`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.014564275240979084`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.950650099856702`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2402778847021325, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999592455078385, 0.009028140638815546, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9031775651540577`, -2.147791139500906, 0.}, 
      Optica`Optica`RayEnd :> {3.6672522571574695`, -2.159269702104077, 0.}, 
      RotationMatrix :> {{-0.9988185216654466, -0.04859589260474449, 0.}, {
       0.04859589260474449, -0.9988185216654466, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01690142703356013, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23620437835213806`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.300232579817866`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2168878890818213, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9988185216654466, -0.04859589260474449, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.071169419359076, -2.318045595221131, 0.}, 
      Optica`Optica`RayEnd :> {4.914250378235094, -2.2890980576784323`, 0.}, 
      RotationMatrix :> {{-0.9834069330711055, 0.1814133511836486, 
       0.}, {-0.1814133511836486, -0.9834069330711055, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011121380246321502`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15956674276632934`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.97085367922174, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3539632176268873, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9834069330711055, 0.1814133511836486, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.914250378235094, -2.2890980576784323`, 0.}, 
      Optica`Optica`RayEnd :> {4.626555883353152, -2.233817827673968, 0.}, 
      RotationMatrix :> {{-0.982035323206953, 0.1886971753201807, 
       0.}, {-0.1886971753201807, -0.982035323206953, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011093664199602598`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29295737951914097`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.404430600910068`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05937510435279242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.982035323206953, 0.1886971753201807, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.193310352004639, 1.0700518446392056`, 0.}, 
      Optica`Optica`RayEnd :> {8.207500799389074, 1.1265603554403336`, 0.}, 
      RotationMatrix :> {{0.24355835151179914`, 0.9698862456024699, 
       0.}, {-0.9698862456024699, 0.24355835151179914`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009288963446633084, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05826302935766061, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.046738796343718`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43165766588515453`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.24355835151179914`, 0.9698862456024699, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.207500799389074, 1.1265603554403336`, 0.}, 
      Optica`Optica`RayEnd :> {8.300156147257562, 1.4583259666974322`, 0.}, 
      RotationMatrix :> {{0.26898640737317486`, 0.963143972959636, 
       0.}, {-0.963143972959636, 0.26898640737317486`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009262750743684305, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3444610780646004, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.556541191879326`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23844875780145916`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.26898640737317486`, 0.963143972959636, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.413118909568857, 1.5107447399974474`, 0.}, 
      Optica`Optica`RayEnd :> {4.349313759099647, 1.5968430133600238`, 0.}, 
      RotationMatrix :> {{-0.5954001751014709, 0.8034292946421218, 
       0.}, {-0.8034292946421218, -0.5954001751014709, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012472944599581818`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10716347279934299`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.016843954835156`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0665866277763446, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5954001751014709, 0.8034292946421218, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.349313759099647, 1.5968430133600238`, 0.}, 
      Optica`Optica`RayEnd :> {4.162346604277734, 1.862138328747747, 0.}, 
      RotationMatrix :> {{-0.5760658396245705, 0.8174032960648239, 
       0.}, {-0.8174032960648239, -0.5760658396245705, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012438560679173198`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3245586562531845, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.49719076608987, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33455481669739323`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5760658396245705, 0.8174032960648239, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6249144125819277`, -4.291219948717063, 0.}, 
      Optica`Optica`RayEnd :> {3.5146907617059844`, -4.384345781536437, 0.}, 
      RotationMatrix :> {{-0.7638656328061989, -0.6453753133003969, 0.}, {
       0.6453753133003969, -0.7638656328061989, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08542359141431197, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1442971723587258, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.402734722132653`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08537311844803064, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7638656328061989, -0.6453753133003969, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5146907617059844`, -4.384345781536437, 0.}, 
      Optica`Optica`RayEnd :> {3.2909883109441656`, -4.5946589053852165`, 0.},
       RotationMatrix :> {{-0.7285743230550108, -0.6849667552406707, 0.}, {
       0.6849667552406707, -0.7285743230550108, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08507614425715486, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3070413596567665, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.857155934424668`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14313498468183122`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7285743230550108, -0.6849667552406707, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.616473148431152, -3.839546036759751, 0.}, 
      Optica`Optica`RayEnd :> {5.580849709699812, -3.8600389169282856`, 0.}, 
      RotationMatrix :> {{-0.866807416884748, -0.4986430607494606, 0.}, {
       0.4986430607494606, -0.866807416884748, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013211472192729126`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.04109729339807446, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.4058542938674, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05502141007377193, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.866807416884748, -0.4986430607494606, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.580849709699812, -3.8600389169282856`, 0.}, 
      Optica`Optica`RayEnd :> {5.362099643024295, -4.006547355628791, 0.}, 
      RotationMatrix :> {{-0.830864996548899, -0.5564740402838192, 0.}, {
       0.5564740402838192, -0.830864996548899, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013141193910169713`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2632799162127695, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.7955085698623, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.01140318736123791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.830864996548899, -0.5564740402838192, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.579937962894859, -4.3161032824231205`, 0.}, 
      Optica`Optica`RayEnd :> {7.583838827532015, -4.362254507597883, 0.}, 
      RotationMatrix :> {{0.08422321423816159, -0.9964469128776464, 0.}, {
       0.9964469128776464, 0.08422321423816159, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.053134281790179844`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.046315789208962684`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.528235170816462`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04524728368670884, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.08422321423816159, -0.9964469128776464, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.583838827532015, -4.362254507597883, 0.}, 
      Optica`Optica`RayEnd :> {7.592086742145651, -4.625886100022921, 0.}, 
      RotationMatrix :> {{0.031270459561902705`, -0.9995109595991364, 0.}, {
       0.9995109595991364, 0.031270459561902705`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.052918151944205384`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26376058200579416`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.91860083218504, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.014031868827100887`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {0.031270459561902705`, -0.9995109595991364, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.666259953006467, -4.416423503191367, 0.}, 
      Optica`Optica`RayEnd :> {7.813075213571055, -4.507642203723091, 0.}, 
      RotationMatrix :> {{0.849401620577258, -0.527746991427452, 0.}, {
       0.527746991427452, 0.849401620577258, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11090223339995614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17284551501657283`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.893658028096677`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014668424167825656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.849401620577258, -0.527746991427452, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.813075213571055, -4.507642203723091, 0.}, 
      Optica`Optica`RayEnd :> {8.074781152017092, -4.648738151644846, 0.}, 
      RotationMatrix :> {{0.8802219591084146, -0.4745622221620085, 0.}, {
       0.4745622221620085, 0.8802219591084146, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11037993616003676`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2973181204330792, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.333688846337633`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.014459614682136687`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8802219591084146, -0.4745622221620085, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.798279980013547, -4.407131294580484, 0.}, 
      Optica`Optica`RayEnd :> {7.862689890837578, -4.381808975953809, 0.}, 
      RotationMatrix :> {{0.9306608602189673, 0.36588299120960904`, 
       0.}, {-0.36588299120960904`, 0.9306608602189673, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028987793631739634`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06920878869761084, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.950657839527288`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.351813195550991, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9306608602189673, 0.36588299120960904`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.862689890837578, -4.381808975953809, 0.}, 
      Optica`Optica`RayEnd :> {8.051406858091678, -4.344427070346459, 0.}, 
      RotationMatrix :> {{0.9809403562038274, 0.19430907742745201`, 
       0.}, {-0.19430907742745201`, 0.9809403562038274, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02770677081002304, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19238373267098713`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.23538576388035, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06203807834490353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9809403562038274, 0.19430907742745201`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.929734262581606, -3.1213235621942435`, 0.}, 
      Optica`Optica`RayEnd :> {6.9071799002491305`, -3.203089436157028, 0.}, 
      RotationMatrix :> {{-0.26590992557074056`, -0.9639978793975441, 0.}, {
       0.9639978793975441, -0.26590992557074056`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020192140213091986`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0848195579163353, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.703323444490355`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3879035494053713, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.26590992557074056`, -0.9639978793975441, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9071799002491305`, -3.203089436157028, 0.}, 
      Optica`Optica`RayEnd :> {6.8268878473143895`, -3.3719473963555866`, 0.},
       RotationMatrix :> {{-0.42942560920243233`, -0.9031022346119617, 0.}, {
       0.9031022346119617, -0.42942560920243233`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019363456096660202`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.186975464932951, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.98004713259112, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0001399542236404927, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.42942560920243233`, -0.9031022346119617, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.134348357352752, 3.424274933828437, 0.}, 
      Optica`Optica`RayEnd :> {4.103650192613267, 3.4444959002671793`, 0.}, 
      RotationMatrix :> {{-0.8351071080054805, 0.5500873732042233, 
       0.}, {-0.5500873732042233, -0.8351071080054805, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008170223990989801, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03675955388860637, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.96516757551511, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.14944949831076743`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8351071080054805, 0.5500873732042233, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.103650192613267, 3.4444959002671793`, 0.}, 
      Optica`Optica`RayEnd :> {3.862323337613243, 3.6088293415498454`, 0.}, 
      RotationMatrix :> {{-0.8265581445262079, 0.5628513424674335, 
       0.}, {-0.5628513424674335, -0.8265581445262079, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008149113919701217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2919659755314063, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.397277219301593`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21838457361184738`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.8265581445262079, 0.5628513424674335, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.628548247530289, -1.346088855764899, 0.}, 
      Optica`Optica`RayEnd :> {4.614717322515146, -1.3601992666660045`, 0.}, 
      RotationMatrix :> {{-0.6999988607116395, -0.7141439595784637, 0.}, {
       0.7141439595784637, -0.6999988607116395, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1665558948911391, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01975849646538294, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.510908857698006`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.00586320199882984, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6999988607116395, -0.7141439595784637, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.614717322515146, -1.3601992666660045`, 0.}, 
      Optica`Optica`RayEnd :> {4.414914889031484, -1.574690063371122, 0.}, 
      RotationMatrix :> {{-0.6816087460521115, -0.731716828633364, 0.}, {
       0.731716828633364, -0.6816087460521115, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16608988290248408`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29313361168107127`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.94474660298599, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2751612624956993, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6816087460521115, -0.731716828633364, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.451625246734025, 2.8573328742422452`, 0.}, 
      Optica`Optica`RayEnd :> {4.42224035122515, 2.8539994316229933`, 0.}, 
      RotationMatrix :> {{-0.9936270492845508, -0.11271773121419411`, 0.}, {
       0.11271773121419411`, -0.9936270492845508, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03576966796814638, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.029573365107193435`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.0373139634245, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3219477493569971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.9936270492845508, -0.11271773121419411`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.42224035122515, 2.8539994316229933`, 0.}, 
      Optica`Optica`RayEnd :> {4.107906924151698, 2.811140438077034, 0.}, 
      RotationMatrix :> {{-0.9908321325761488, -0.1350987973839866, 0.}, {
       0.1350987973839866, -0.9908321325761488, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03567219812241412, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31724185837230456`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.50683191381551, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03825875669029738, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9908321325761488, -0.1350987973839866, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.234404632860996, 1.5925539569764573`, 0.}, 
      Optica`Optica`RayEnd :> {4.134558778891135, 1.5841778176651693`, 0.}, 
      RotationMatrix :> {{-0.9964996395519825, -0.08359705959403269, 0.}, {
       0.08359705959403269, -0.9964996395519825, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032181807683953075`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10019657810890047`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.302315258797105`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19189723191103558`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9964996395519825, -0.08359705959403269, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.134558778891135, 1.5841778176651693`, 0.}, 
      Optica`Optica`RayEnd :> {3.8776235649819144`, 1.547137372789917, 0.}, 
      RotationMatrix :> {{-0.9897677918521672, -0.14268748442692544`, 0.}, {
       0.14268748442692544`, -0.9897677918521672, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032035557953147414`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2595914072212974, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.686510541484626`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1793819458434333, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9897677918521672, -0.14268748442692544`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.604009722506619, 2.7158150708953386`, 0.}, 
      Optica`Optica`RayEnd :> {4.405039731031097, 2.7092409194679954`, 0.}, 
      RotationMatrix :> {{-0.9994545953506369, -0.03302289860829227, 0.}, {
       0.03302289860829227, -0.9994545953506369, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0400293251945714, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19907856985310834`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.720650283350786`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2233359914106789, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9994545953506369, -0.03302289860829227, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.405039731031097, 2.7092409194679954`, 0.}, 
      Optica`Optica`RayEnd :> {4.128791118712853, 2.7182553933505633`, 0.}, 
      RotationMatrix :> {{-0.9994680094775336, 0.032614383805547924`, 
       0.}, {-0.032614383805547924`, -0.9994680094775336, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03982590242782695, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2763956521856576, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.12971584858556, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2479691546986304, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9994680094775336, 0.032614383805547924`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.215440038407017, -2.401181598702991, 0.}, 
      Optica`Optica`RayEnd :> {8.187344793038829, -2.6271694339600202`, 0.}, 
      RotationMatrix :> {{-0.12337217585412556`, -0.9923604719178498, 0.}, {
       0.9923604719178498, -0.12337217585412556`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24821266546239837`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22772756639558797`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.897695493446605`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.43141987757580913`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12337217585412556`, -0.9923604719178498, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.187344793038829, -2.6271694339600202`, 0.}, 
      Optica`Optica`RayEnd :> {8.170792281269932, -2.938696871178345, 0.}, 
      RotationMatrix :> {{-0.05305855591377279, -0.9985914027490643, 0.}, {
       0.9985914027490643, -0.05305855591377279, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24682851916630746`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3119668728978719, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.359406465335457`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40220867158495044`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05305855591377279, -0.9985914027490643, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.630380699138552, -0.7899309361355071, 0.}, 
      Optica`Optica`RayEnd :> {5.345367726580626, -0.8221047988375817, 0.}, 
      RotationMatrix :> {{-0.9936886757633983, -0.11217315035062214`, 0.}, {
       0.11217315035062214`, -0.9936886757633983, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06336222682338886, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2868232068147148, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.92991972362567, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2953762281667847, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9936886757633983, -0.11217315035062214`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.345367726580626, -0.8221047988375817, 0.}, 
      Optica`Optica`RayEnd :> {5.081982035900316, -0.837429909266994, 0.}, 
      RotationMatrix :> {{-0.9983115358056259, -0.05808680984020139, 0.}, {
       0.05808680984020139, -0.9983115358056259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06309905247534335, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2638311601475806, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.32038984064409, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.25338999816964786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9983115358056259, -0.05808680984020139, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.8301339973671515`, -3.0309964858953027`, 
       0.}, Optica`Optica`RayEnd :> {5.78627592501987, -3.131449517541143, 
       0.}, RotationMatrix :> {{-0.4001285525216335, -0.9164590233376184, 
       0.}, {0.9164590233376184, -0.4001285525216335, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0180272227463565, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10960995427815691`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.688796391001407`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.016742188603198354`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4001285525216335, -0.9164590233376184, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.78627592501987, -3.131449517541143, 0.}, 
      Optica`Optica`RayEnd :> {5.656320172600433, -3.4231682308452736`, 0.}, 
      RotationMatrix :> {{-0.40693057346067935`, -0.9134590896055289, 0.}, {
       0.9134590896055289, -0.40693057346067935`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01798229336808007, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3193560791322432, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.161443388117128`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38270341611072156`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.40693057346067935`, -0.9134590896055289, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.104736350691827, -3.6563018927554336`, 0.}, 
      Optica`Optica`RayEnd :> {6.968545787671244, -3.8511629426954896`, 0.}, 
      RotationMatrix :> {{-0.5728632203601849, -0.8196509810636217, 0.}, {
       0.8196509810636217, -0.5728632203601849, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16873709847124718`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2377366152690919, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.31213347426592, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31744161868268717`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5728632203601849, -0.8196509810636217, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.968545787671244, -3.8511629426954896`, 0.}, 
      Optica`Optica`RayEnd :> {6.848439921609096, -4.060339923633495, 0.}, 
      RotationMatrix :> {{-0.4979385631224341, -0.8672123081204307, 0.}, {
       0.8672123081204307, -0.4979385631224341, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1673942821251315, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2412061948144733, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.66911864259134, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17805309362806498`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4979385631224341, -0.8672123081204307, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3206781979850604`, 1.4260747983155784`, 0.},
       Optica`Optica`RayEnd :> {2.1758216835623503`, 1.4729453427395387`, 0.},
       RotationMatrix :> {{-0.9514345122462747, 0.3078512122871897, 
       0.}, {-0.3078512122871897, -0.9514345122462747, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029736594546280398`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15225064106694364`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.323342752239917`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3203347252448892, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9514345122462747, 0.3078512122871897, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1758216835623503`, 1.4729453427395387`, 0.},
       Optica`Optica`RayEnd :> {1.8240741026616254`, 1.588190619940066, 0.}, 
      RotationMatrix :> {{-0.9502949429359593, 0.3113511224170245, 
       0.}, {-0.3113511224170245, -0.9502949429359593, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029663102732973772`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3701456937295615, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.871158378959667`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1388510399541724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9502949429359593, 0.3113511224170245, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8297096805049433`, -1.02433477027403, 0.}, 
      Optica`Optica`RayEnd :> {2.800016384379107, -1.0857634080385206`, 0.}, 
      RotationMatrix :> {{-0.4352017830402683, -0.9003329428820043, 0.}, {
       0.9003329428820043, -0.4352017830402683, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23140425462825842`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06822880163404325, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.79274536701191, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2385430603092584, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4352017830402683, -0.9003329428820043, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.800016384379107, -1.0857634080385206`, 0.}, 
      Optica`Optica`RayEnd :> {2.690471506059175, -1.3392204971550752`, 0.}, 
      RotationMatrix :> {{-0.3967336079335279, -0.9179337908237418, 0.}, {
       0.9179337908237418, -0.3967336079335279, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23060867096257184`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27611696143041575`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.201398469928925`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35204738587886847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3967336079335279, -0.9179337908237418, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.860881282240003, -1.4002161107014388`, 0.}, 
      Optica`Optica`RayEnd :> {3.792643879086505, -1.6915080459494076`, 0.}, 
      RotationMatrix :> {{-0.22808313740624536`, -0.9736416601763315, 0.}, {
       0.9736416601763315, -0.22808313740624536`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023607582821963784`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2991777644305136, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.106277843298596`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1118689625916523, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22808313740624536`, -0.9736416601763315, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.792643879086505, -1.6915080459494076`, 0.}, 
      Optica`Optica`RayEnd :> {3.7253197317359628`, -1.9226930520229284`, 0.},
       RotationMatrix :> {{-0.2795988123777768, -0.9601169221073733, 0.}, {
       0.9601169221073733, -0.2795988123777768, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023511201945448527`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24078838811224115`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.46264465770471, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16726408989599084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2795988123777768, -0.9601169221073733, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.07555611396809, -1.8117704305492082`, 0.}, 
      Optica`Optica`RayEnd :> {4.035231998209413, -1.9062904564970764`, 0.}, 
      RotationMatrix :> {{-0.39240222582405593`, -0.9197937231620609, 0.}, {
       0.9197937231620609, -0.39240222582405593`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008413420699703935, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10276219935805601`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.84760185343422, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0472410527495915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.39240222582405593`, -0.9197937231620609, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.035231998209413, -1.9062904564970764`, 0.}, 
      Optica`Optica`RayEnd :> {3.9291983209491628`, -2.1531670824734057`, 0.},
       RotationMatrix :> {{-0.3946405111871178, -0.9188356038650057, 0.}, {
       0.9188356038650057, -0.3946405111871178, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008392659555218038, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.268684218306151, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.245254496527323`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3935139420333731, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3946405111871178, -0.9188356038650057, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6958045992808475`, -0.8824309136322641, 0.},
       Optica`Optica`RayEnd :> {2.7450952301165734`, -1.0947326431897753`, 
       0.}, RotationMatrix :> {{0.22615713822353045`, -0.9740908319199715, 
       0.}, {0.9740908319199715, 0.22615713822353045`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00974214948091065, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21794859637376535`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.556818839432186`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38333085627640495`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.22615713822353045`, -0.9740908319199715, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7450952301165734`, -1.0947326431897753`, 
       0.}, Optica`Optica`RayEnd :> {2.81530561668199, -1.3819969648385397`, 
       0.}, RotationMatrix :> {{0.23742188021794114`, -0.9714066351398764, 
       0.}, {0.9714066351398764, 0.23742188021794114`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00971748232989414, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29571995007775514`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.99448436554726, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19203645807285535`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.23742188021794114`, -0.9714066351398764, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.834619754427745, 3.8806501516394767`, 0.}, 
      Optica`Optica`RayEnd :> {7.134549649453645, 3.7150840089529598`, 0.}, 
      RotationMatrix :> {{0.8754695343480123, -0.4832733123486892, 0.}, {
       0.4832733123486892, 0.8754695343480123, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021144641997327355`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.342593183724282, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.3153425869504, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.009874740023431137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8754695343480123, -0.4832733123486892, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.134549649453645, 3.7150840089529598`, 0.}, 
      Optica`Optica`RayEnd :> {7.396143214128973, 3.5870377413582615`, 0.}, 
      RotationMatrix :> {{0.8981728028524918, -0.4396426005474198, 0.}, {
       0.4396426005474198, 0.8981728028524918, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.021063892986337974`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29125081926833685`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.74639379946754, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07795412601090408, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8981728028524918, -0.4396426005474198, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.690322061937462, 0.9829898218117369, 0.}, 
      Optica`Optica`RayEnd :> {7.7545209504678905`, 0.9231714981215575, 0.}, 
      RotationMatrix :> {{0.7316271028101149, -0.6817050553088748, 0.}, {
       0.6817050553088748, 0.7316271028101149, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010929856383479403`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08774810047884439, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.842978857213573`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3327395403348699, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.7316271028101149, -0.6817050553088748, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.7545209504678905`, 0.9231714981215575, 0.}, 
      Optica`Optica`RayEnd :> {7.951636345348979, 0.7137730150913497, 0.}, 
      RotationMatrix :> {{0.6854282558257283, -0.7281401692776593, 0.}, {
       0.7281401692776593, 0.6854282558257283, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010874451028889988`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28757990818984525`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.268597121334544`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3524378508410988, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6854282558257283, -0.7281401692776593, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.085192016271241, -0.15233612156201284`, 0.},
       Optica`Optica`RayEnd :> {8.118623229274593, -0.15076632007160554`, 0.},
       RotationMatrix :> {{0.9988993790932295, 0.04690448216492202, 
       0.}, {-0.04690448216492202, 0.9988993790932295, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013554145426743982`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.033468048637392, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.36642722585048, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24929529848182583`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9988993790932295, 0.04690448216492202, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.118623229274593, -0.15076632007160554`, 0.},
       Optica`Optica`RayEnd :> {8.417195633114394, -0.1544898434743955, 0.}, 
      RotationMatrix :> {{0.9999222450233339, -0.01247012058861402, 0.}, {
       0.01247012058861402, 0.9999222450233339, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013492646147050695`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2985956211353542, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.808348745130804`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.261414514679726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9999222450233339, -0.01247012058861402, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.023749465279174, -0.6564234254441896, 0.}, 
      Optica`Optica`RayEnd :> {8.086800653178619, -0.8848543317206131, 0.}, 
      RotationMatrix :> {{0.26606924853890035`, -0.9639539174576469, 0.}, {
       0.9639539174576469, 0.26606924853890035`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06445856982777903, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2369728491574494, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.09487982464777, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1066906987568117, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.26606924853890035`, -0.9639539174576469, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.086800653178619, -0.8848543317206131, 0.}, 
      Optica`Optica`RayEnd :> {8.140126437614487, -1.1365465124910128`, 0.}, 
      RotationMatrix :> {{0.20726814239280966`, -0.9782841699368507, 0.}, {
       0.9782841699368507, 0.20726814239280966`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06416011546702369, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2572792124262284, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.47565305903859, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10057339137546768`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.20726814239280966`, -0.9782841699368507, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.110066133937232, -1.3196122735009896`, 0.}, 
      Optica`Optica`RayEnd :> {7.060689219099167, -1.4297462813242712`, 0.}, 
      RotationMatrix :> {{-0.40910072957505167`, -0.9124892290110386, 0.}, {
       0.9124892290110386, -0.40910072957505167`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009944227644351244, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.12069622777097924`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.147746592763994`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16563167506477064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.40910072957505167`, -0.9124892290110386, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.060689219099167, -1.4297462813242712`, 0.}, 
      Optica`Optica`RayEnd :> {6.941744632947714, -1.6665184367310864`, 0.}, 
      RotationMatrix :> {{-0.4488990576584635, -0.8935824729891152, 0.}, {
       0.8935824729891152, -0.4488990576584635, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009909143792764185, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2649695608003485, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.53990154274851, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27960128054951533`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4488990576584635, -0.8935824729891152, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.311374477317961, -0.8702033506379357, 0.}, 
      Optica`Optica`RayEnd :> {5.24895411678124, -1.1439807200337655`, 0.}, 
      RotationMatrix :> {{-0.22229232167071553`, -0.9749800632455218, 0.}, {
       0.9749800632455218, -0.22229232167071553`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04538539706399608, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28080304379196963`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.92064164857693, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29602271024202514`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22229232167071553`, -0.9749800632455218, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.24895411678124, -1.1439807200337655`, 0.}, 
      Optica`Optica`RayEnd :> {5.1971633524093805`, -1.411110251959242, 0.}, 
      RotationMatrix :> {{-0.1903345970382811, -0.9817192781901931, 0.}, {
       0.9817192781901931, -0.1903345970382811, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.045248087198569265`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27210378553218545`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.323355251164564`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42516194652017547`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1903345970382811, -0.9817192781901931, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.568609747241561, 0.17993281888803214`, 0.}, 
      Optica`Optica`RayEnd :> {2.527798254498685, 0.1554213130849209, 0.}, 
      RotationMatrix :> {{-0.8572647761548882, -0.5148758137299791, 0.}, {
       0.5148758137299791, -0.8572647761548882, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032700920121332896`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04760663668689241, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.885806558380278`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13851756702950793`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8572647761548882, -0.5148758137299791, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.527798254498685, 0.1554213130849209, 0.}, 
      Optica`Optica`RayEnd :> {2.3141454695633144`, -0.0009303562125356022, 
       0.}, RotationMatrix :> {{-0.806993669737877, -0.5905600875465535, 
       0.}, {0.5905600875465535, -0.806993669737877, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03242944352826545, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26475150047306795`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.27763877908042, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.032177362798731124`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.806993669737877, -0.5905600875465535, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.352085693409248, 1.914169228756334, 0.}, 
      Optica`Optica`RayEnd :> {2.3220548648436976`, 1.9026847111612062`, 0.}, 
      RotationMatrix :> {{-0.9340296095394319, -0.35719558858364264`, 0.}, {
       0.35719558858364264`, -0.9340296095394319, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010560481170217254`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03215190210121743, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.620461411936994`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1358067990469982, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9340296095394319, -0.35719558858364264`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3220548648436976`, 1.9026847111612062`, 0.},
       Optica`Optica`RayEnd :> {2.2076719681319608`, 1.8799915918934478`, 0.},
       RotationMatrix :> {{-0.9808820565873183, -0.19460316303963696`, 0.}, {
       0.19460316303963696`, -0.9808820565873183, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010165196285888195`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11661228375376495`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.776721872167037`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4009776269219245, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9808820565873183, -0.19460316303963696`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9377092946462433`, 2.335707755262018, 0.}, 
      Optica`Optica`RayEnd :> {2.8772032825485674`, 2.323538337846488, 0.}, 
      RotationMatrix :> {{-0.9803675469335719, -0.19717878415146556`, 0.}, {
       0.19717878415146556`, -0.9803675469335719, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01677218939570061, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.061717681584757274`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      18.697585616620287`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.29599569316195024`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 52, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9803675469335719, -0.19717878415146556`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8772032825485674`, 2.323538337846488, 0.}, 
      Optica`Optica`RayEnd :> {2.5359324408170836`, 2.2629931975671616`, 0.}, 
      RotationMatrix :> {{-0.9846247112754738, -0.1746830785900265, 0.}, {
       0.1746830785900265, -0.9846247112754738, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016726350294304044`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3465999155042583, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.162029503395992`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03123080430615239, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9846247112754738, -0.1746830785900265, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7009504064931456`, -0.886442425745927, 0.}, 
      Optica`Optica`RayEnd :> {2.6416685364883628`, -0.9403888692305328, 0.}, 
      RotationMatrix :> {{-0.7396056803492987, -0.6730404427633236, 0.}, {
       0.6730404427633236, -0.7396056803492987, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018062244674257, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08015334600565172, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.65891430386322, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24373297826534568`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7396056803492987, -0.6730404427633236, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6416685364883628`, -0.9403888692305328, 0.},
       Optica`Optica`RayEnd :> {2.3882353982456106`, -1.1810577998572418`, 
       0.}, RotationMatrix :> {{-0.7251316508811504, -0.6886102590655887, 
       0.}, {0.6886102590655887, -0.7251316508811504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01801356295806492, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.349499484589854, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.127243613213626`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4155629061672085, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7251316508811504, -0.6886102590655887, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.766147741904659, -1.4105064288629432`, 0.}, 
      Optica`Optica`RayEnd :> {7.850274393352393, -1.582000064127832, 0.}, 
      RotationMatrix :> {{0.44041528122695717`, -0.8977941746646497, 0.}, {
       0.8977941746646497, 0.44041528122695717`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012012579310351976`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1910166495889174, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.107492107270037`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12162518057489652`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.44041528122695717`, -0.8977941746646497, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.850274393352393, -1.582000064127832, 0.}, 
      Optica`Optica`RayEnd :> {7.942643768053254, -1.6854126608445184`, 0.}, 
      RotationMatrix :> {{0.6661630257371991, -0.745806156545157, 0.}, {
       0.745806156545157, 0.6661630257371991, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009876541128831037, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.13865881343180483`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.31270715114911, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38600780776921695`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6661630257371991, -0.745806156545157, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8156411223846534`, 1.5132813511973178`, 0.},
       Optica`Optica`RayEnd :> {2.6527186743894404`, 1.4762625269830916`, 0.},
       RotationMatrix :> {{-0.9751445021579224, -0.2215698533446656, 0.}, {
       0.2215698533446656, -0.9751445021579224, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010573884470912466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16707518489278017`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.501723359729365`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.41679501707603656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9751445021579224, -0.2215698533446656, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6527186743894404`, 1.4762625269830916`, 0.},
       Optica`Optica`RayEnd :> {2.3269097514349193`, 1.4116366195782286`, 0.},
       RotationMatrix :> {{-0.9808897038733511, -0.19456461352272814`, 0.}, {
       0.19456461352272814`, -0.9808897038733511, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010543648094998134`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3321565326539384, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.993315028057193`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21894454542123407`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9808897038733511, -0.19456461352272814`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1875130680893315`, 1.639042991257376, 0.}, 
      Optica`Optica`RayEnd :> {5.138377464275786, 1.5960238694596374`, 0.}, 
      RotationMatrix :> {{-0.7523833964138529, -0.6587254547994587, 0.}, {
       0.6587254547994587, -0.7523833964138529, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01043475345470932, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06530660305336979, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.34075040819233, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20354449264559077`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7523833964138529, -0.6587254547994587, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.138377464275786, 1.5960238694596374`, 0.}, 
      Optica`Optica`RayEnd :> {4.883148682769548, 1.3764357895408095`, 0.}, 
      RotationMatrix :> {{-0.758051082683954, -0.6521951824735319, 0.}, {
       0.6521951824735319, -0.758051082683954, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010408644686908277`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.33669074200458265`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.839052706359112`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3562380043117331, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.758051082683954, -0.6521951824735319, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.977761929985089, 0.8882111978820659, 0.}, 
      Optica`Optica`RayEnd :> {8.06130159699868, 0.7394461874404072, 0.}, 
      RotationMatrix :> {{0.48963488345671036`, -0.8719275663163383, 0.}, {
       0.8719275663163383, 0.48963488345671036`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009680126447098179, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1706162486296323, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.572256123203907`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11064395426443033`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.48963488345671036`, -0.8719275663163383, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.06130159699868, 0.7394461874404072, 0.}, 
      Optica`Optica`RayEnd :> {8.171750587440552, 0.6191664772526606, 0.}, 
      RotationMatrix :> {{0.6763652411882434, -0.7365663992556055, 0.}, {
       0.7365663992556055, 0.6763652411882434, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008708366501372047, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1632978510957119, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.81393694282556, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36960504867205585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6763652411882434, -0.7365663992556055, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.14183109987971, -0.39881202640755253`, 0.}, 
      Optica`Optica`RayEnd :> {7.1216425990063, -0.4305655282711646, 0.}, 
      RotationMatrix :> {{-0.536529796765824, -0.8438813762504905, 0.}, {
       0.8438813762504905, -0.536529796765824, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012516145844091615`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.037627921124054525`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.123465388912035`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3971612922295429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.536529796765824, -0.8438813762504905, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.1216425990063, -0.4305655282711646, 0.}, 
      Optica`Optica`RayEnd :> {7.048745360448051, -0.5896979328317056, 0.}, 
      RotationMatrix :> {{-0.4164731812998279, -0.9091480018445837, 0.}, {
       0.9091480018445837, -0.4164731812998279, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012258600049010884`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17503465248526612`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.35801182324229, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02936632547856826, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.4164731812998279, -0.9091480018445837, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5939123039010066`, 1.2797169994967676`, 0.},
       Optica`Optica`RayEnd :> {2.412278309774798, 1.2127964730526846`, 0.}, 
      RotationMatrix :> {{-0.9383385264082234, -0.3457178182536197, 0.}, {
       0.3457178182536197, -0.9383385264082234, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009761652713889806, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1935697927926585, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.928543446256597`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4180413905402335, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9383385264082234, -0.3457178182536197, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.412278309774798, 1.2127964730526846`, 0.}, 
      Optica`Optica`RayEnd :> {2.1178173572235908`, 1.1177483207118895`, 0.}, 
      RotationMatrix :> {{-0.9516512383284065, -0.30718059930277064`, 0.}, {
       0.30718059930277064`, -0.9516512383284065, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009728819207225788, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30942107853338513`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.38648664248601, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3149995132765585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9516512383284065, -0.30718059930277064`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6744488706177325`, -1.8935461606096162`, 
       0.}, Optica`Optica`RayEnd :> {2.6340094531314135`, -1.927500485180183, 
       0.}, RotationMatrix :> {{-0.7658427556721351, -0.6430278948727721, 
       0.}, {0.6430278948727721, -0.7658427556721351, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011890343279437995`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.052803812775937015`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.33808357600885, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37160672540304907`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7658427556721351, -0.6430278948727721, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6340094531314135`, -1.927500485180183, 0.}, 
      Optica`Optica`RayEnd :> {2.4018199732914707`, -2.10354895449524, 0.}, 
      RotationMatrix :> {{-0.7968486829628827, -0.6041789275209107, 0.}, {
       0.6041789275209107, -0.7968486829628827, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01184455417907567, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2913846565907647, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.76933286776318, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4224188968800835, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 128, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7968486829628827, -0.6041789275209107, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6672522571574695`, -2.159269702104077, 0.}, 
      Optica`Optica`RayEnd :> {3.4330706213555873`, -2.184247532440832, 0.}, 
      RotationMatrix :> {{-0.994359892035633, -0.10605849853210386`, 0.}, {
       0.10605849853210386`, -0.994359892035633, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01682706197670141, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2355099372747935, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.61581589576609, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4017306263596122, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.994359892035633, -0.10605849853210386`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4330706213555873`, -2.184247532440832, 0.}, 
      Optica`Optica`RayEnd :> {3.134775657365511, -2.2162878220725832`, 0.}, 
      RotationMatrix :> {{-0.9942808321467121, -0.106797129294947, 0.}, {
       0.106797129294947, -0.9942808321467121, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016785584278621882`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30001077597567644`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.05983184421009, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04986257885323179, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9942808321467121, -0.106797129294947, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.626555883353152, -2.233817827673968, 0.}, 
      Optica`Optica`RayEnd :> {4.397673717117399, -2.1880767136477473`, 0.}, 
      RotationMatrix :> {{-0.9806097648319695, 0.19597063330047487`, 
       0.}, {-0.19597063330047487`, -0.9806097648319695, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01106601722517766, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23340800229026099`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.71719732397902, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36804044983023837`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9806097648319695, 0.19597063330047487`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.397673717117399, -2.1880767136477473`, 0.}, 
      Optica`Optica`RayEnd :> {4.099114995086564, -2.141213723451201, 0.}, 
      RotationMatrix :> {{-0.9879041977745489, 0.1550654572089627, 
       0.}, {-0.1550654572089627, -0.9879041977745489, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011028382037576908`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.302214245777473, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.164474407729678`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2533371201106975, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9879041977745489, 0.1550654572089627, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.162346604277734, 1.862138328747747, 0.}, 
      Optica`Optica`RayEnd :> {4.162179615633744, 1.862387703249933, 0.}, 
      RotationMatrix :> {{-0.5564036712744452, 0.8309121220636503, 
       0.}, {-0.8309121220636503, -0.5564036712744452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012404271544239908`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00030012139137712714`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.497592928754315`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1503368196119024, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5564036712744452, 0.8309121220636503, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.162179615633744, 1.862387703249933, 0.}, 
      Optica`Optica`RayEnd :> {3.975437887865956, 2.127856256636735, 0.}, 
      RotationMatrix :> {{-0.5753502347226057, 0.817907150845768, 
       0.}, {-0.817907150845768, -0.5753502347226057, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01237034459444045, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32457052504344847`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.97795730581862, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3980023647750793, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5753502347226057, 0.817907150845768, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.362099643024295, -4.006547355628791, 0.}, 
      Optica`Optica`RayEnd :> {5.279787419090234, -4.070198385837125, 0.}, 
      RotationMatrix :> {{-0.7910704536350394, -0.6117250504807309, 0.}, {
       0.6117250504807309, -0.7910704536350394, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01307128947216959, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10405169799457042`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.934937845175025`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11282077235094279`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7910704536350394, -0.6117250504807309, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.279787419090234, -4.070198385837125, 0.}, 
      Optica`Optica`RayEnd :> {5.092301143738348, -4.23590309475546, 0.}, 
      RotationMatrix :> {{-0.7492910818701899, -0.6622407980710644, 0.}, {
       0.6622407980710644, -0.7492910818701899, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013004965192346592`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2502182127724384, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.305260800078234`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.08597642117311494, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7492910818701899, -0.6622407980710644, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.051406858091678, -4.344427070346459, 0.}, 
      Optica`Optica`RayEnd :> {8.11099580886446, -4.343442291022954, 0.}, 
      RotationMatrix :> {{0.9998634702100566, 0.016523950481114297`, 
       0.}, {-0.016523950481114297`, 0.9998634702100566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.026482358694543965`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05959708755062664, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.31524586119819, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1824253787894285, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9998634702100566, 0.016523950481114297`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.11099580886446, -4.343442291022954, 0.}, 
      Optica`Optica`RayEnd :> {8.470391685845325, -4.324888481466, 0.}, 
      RotationMatrix :> {{0.9986700877718281, 0.05155633607820054, 
       0.}, {-0.05155633607820054, 0.9986700877718281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02639985048466714, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3598744784503624, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.847860089304724`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.35053020556013703`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9986700877718281, 0.05155633607820054, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8268878473143895`, -3.3719473963555866`, 
       0.}, Optica`Optica`RayEnd :> {6.665933962421392, -3.5980869677647735`, 
       0.}, RotationMatrix :> {{-0.5798671474507259, -0.8147110477386182, 
       0.}, {0.8147110477386182, -0.5798671474507259, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018568781122279714`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.27757027726195604`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.35199130412214, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39901850124865956`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5798671474507259, -0.8147110477386182, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.665933962421392, -3.5980869677647735`, 0.}, 
      Optica`Optica`RayEnd :> {6.56398960641994, -3.7938934235005783`, 0.}, 
      RotationMatrix :> {{-0.46179839147252966`, -0.8869849184926333, 0.}, {
       0.8869849184926333, -0.46179839147252966`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0181734531402836, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2207551128023276, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.678708871069585`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10438697688481874`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.46179839147252966`, -0.8869849184926333, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.862323337613243, 3.6088293415498454`, 0.}, 
      Optica`Optica`RayEnd :> {3.829911836817922, 3.63163678705379, 0.}, 
      RotationMatrix :> {{-0.8178141102765452, 0.5754824767380695, 
       0.}, {-0.5754824767380695, -0.8178141102765452, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008128058392218326, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03963186791233141, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.450383922304116`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14144009288249804`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.8178141102765452, 0.5754824767380695, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.829911836817922, 3.63163678705379, 0.}, 
      Optica`Optica`RayEnd :> {3.636771330728353, 3.7921973243101887`, 0.}, 
      RotationMatrix :> {{-0.7689841671891221, 0.6392678238519848, 
       0.}, {-0.6392678238519848, -0.7689841671891221, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008073324742445615, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25116317647417646`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.822105423485898`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.026536694173265707`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.7689841671891221, 0.6392678238519848, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.414914889031484, -1.574690063371122, 0.}, 
      Optica`Optica`RayEnd :> {4.37831481021951, -1.6160413907100193`, 0.}, 
      RotationMatrix :> {{-0.6627776291406686, -0.7488162754045039, 0.}, {
       0.7488162754045039, -0.6627776291406686, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16562517478346214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05522226038230757, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.018744431898284`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17498594960177466`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6627776291406686, -0.7488162754045039, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.37831481021951, -1.6160413907100193`, 0.}, 
      Optica`Optica`RayEnd :> {4.136185292466732, -1.8815145244865437`, 0.}, 
      RotationMatrix :> {{-0.673876163244413, -0.7388443114831356, 0.}, {
       0.7388443114831356, -0.673876163244413, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16519836703602336`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35930862517384876`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.55052119715558, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4133033186003932, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.673876163244413, -0.7388443114831356, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.107906924151698, 2.811140438077034, 0.}, 
      Optica`Optica`RayEnd :> {3.9126355914282813`, 2.7800145138044243`, 0.}, 
      RotationMatrix :> {{-0.9875331560967172, -0.15741113559610403`, 0.}, {
       0.15741113559610403`, -0.9875331560967172, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035574993875200585`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.197736482585798, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.77179880048048, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.40471580825845954`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9875331560967172, -0.15741113559610403`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9126355914282813`, 2.7800145138044243`, 0.},
       Optica`Optica`RayEnd :> {3.652329238880699, 2.7398869964278223`, 0.}, 
      RotationMatrix :> {{-0.9883257831614265, -0.15235532920889672`, 0.}, {
       0.15235532920889672`, -0.9883257831614265, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035486848129557, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2633811208637314, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.1616028593588, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10025965162662258`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9883257831614265, -0.15235532920889672`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8776235649819144`, 1.547137372789917, 0.}, 
      Optica`Optica`RayEnd :> {3.603518065205677, 1.4908146381672884`, 0.}, 
      RotationMatrix :> {{-0.9795351393520778, -0.20127322418668744`, 0.}, {
       0.20127322418668744`, -0.9795351393520778, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031889972851997475`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2798322273129953, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.06148572608404, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.43175809109572505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9795351393520778, -0.20127322418668744`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.603518065205677, 1.4908146381672884`, 0.}, 
      Optica`Optica`RayEnd :> {3.33269357193641, 1.4407580715476331`, 0.}, 
      RotationMatrix :> {{-0.9833444329555789, -0.18175182578249385`, 0.}, {
       0.18175182578249385`, -0.9833444329555789, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0318049566061322, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27541163013987485`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.469094938691054`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18105576122331377`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9833444329555789, -0.18175182578249385`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.128791118712853, 2.7182553933505633`, 0.}, 
      Optica`Optica`RayEnd :> {3.9106446064727507`, 2.739761757931408, 0.}, 
      RotationMatrix :> {{-0.9951754625315937, 0.0981111552017772, 
       0.}, {-0.0981111552017772, -0.9951754625315937, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03962351342375098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21920407049141552`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.423449303044055`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3737664215151575, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9951754625315937, 0.0981111552017772, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9106446064727507`, 2.739761757931408, 0.}, 
      Optica`Optica`RayEnd :> {3.6496634334844873`, 2.7681090417856065`, 0.}, 
      RotationMatrix :> {{-0.9941527406630835, 0.10798299973643326`, 
       0.}, {-0.10798299973643326`, -0.9941527406630835, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0395238984121437, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26251617313270514`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.81197323928046, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0067649465909444, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9941527406630835, 0.10798299973643326`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.170792281269932, -2.938696871178345, 0.}, 
      Optica`Optica`RayEnd :> {8.175387372593446, -3.200941815523302, 0.}, 
      RotationMatrix :> {{0.017519445772076203`, -0.9998465227322832, 0.}, {
       0.9998465227322832, 0.017519445772076203`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.24545209149716662`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2622851991606865, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.710868632210776`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31457578162492267`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.017519445772076203`, -0.9998465227322832, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.175387372593446, -3.200941815523302, 0.}, 
      Optica`Optica`RayEnd :> {8.202925738185447, -3.42230821353291, 0.}, 
      RotationMatrix :> {{0.12345016510612124`, -0.9923507730310237, 0.}, {
       0.9923507730310237, 0.12345016510612124`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2426787829787857, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2230727319670131, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.041016275521955`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4002092316691655, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.12345016510612124`, -0.9923507730310237, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.081982035900316, -0.837429909266994, 0.}, 
      Optica`Optica`RayEnd :> {4.8549634431669375`, -0.8382992390160692, 0.}, 
      RotationMatrix :> {{-0.9999926681856908, -0.003829304749201269, 0.}, {
       0.003829304749201269, -0.9999926681856908, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06283697121920676, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2270202572037485, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.624596985297114`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02952213562160544, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999926681856908, -0.003829304749201269, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.8549634431669375`, -0.8382992390160692, 0.},
       Optica`Optica`RayEnd :> {4.658065848402106, -0.8129543347630941, 0.}, 
      RotationMatrix :> {{-0.991816970261984, 0.1276679188376542, 
       0.}, {-0.1276679188376542, -0.991816970261984, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0616603080326803, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19852210707064438`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.918409703761668`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3342106836415234, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.991816970261984, 0.1276679188376542, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.656320172600433, -3.4231682308452736`, 0.}, 
      Optica`Optica`RayEnd :> {5.638641215965254, -3.462072466565094, 0.}, 
      RotationMatrix :> {{-0.4137101045306021, -0.9104086716465729, 0.}, {
       0.9104086716465729, -0.4137101045306021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017937475967619666`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.042732716560638505`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.218705228308384`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3191199591115568, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4137101045306021, -0.9104086716465729, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.638641215965254, -3.462072466565094, 0.}, 
      Optica`Optica`RayEnd :> {5.513356881400975, -3.6820117133582566`, 0.}, 
      RotationMatrix :> {{-0.4949613841910594, -0.8689149717663228, 0.}, {
       0.8689149717663228, -0.4949613841910594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01778744057656669, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2531194120709786, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.593321958173433`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.16833160372493003`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4949613841910594, -0.8689149717663228, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.848439921609096, -4.060339923633495, 0.}, 
      Optica`Optica`RayEnd :> {6.810830744740259, -4.141818437470286, 0.}, 
      RotationMatrix :> {{-0.41909224926965294`, -0.907943658275172, 0.}, {
       0.907943658275172, -0.41909224926965294`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1660621519633566, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08973961445094174, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.789369725955602`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08627653210725227, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.41909224926965294`, -0.907943658275172, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.810830744740259, -4.141818437470286, 0.}, 
      Optica`Optica`RayEnd :> {6.672843912771113, -4.421741734640321, 0.}, 
      RotationMatrix :> {{-0.4421441891003626, -0.8969439871278374, 0.}, {
       0.8969439871278374, -0.4421441891003626, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1655970462999427, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31208559418118687`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.25125640534376, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3380861043382799, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4421441891003626, -0.8969439871278374, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.690471506059175, -1.3392204971550752`, 0.}, 
      Optica`Optica`RayEnd :> {2.6285767423124753`, -1.5008821935487953`, 0.},
       RotationMatrix :> {{-0.35755544219277335`, -0.9338919133167015, 0.}, {
       0.9338919133167015, -0.35755544219277335`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.22981582256798078`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17310536057602346`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.433359653100798`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4311753415398135, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 132, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.35755544219277335`, -0.9338919133167015, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6285767423124753`, -1.5008821935487953`, 
       0.}, Optica`Optica`RayEnd :> {2.543596105985032, -1.6363224572962705`, 
       0.}, RotationMatrix :> {{-0.5314843849415017, -0.8470680896854471, 
       0.}, {0.8470680896854471, -0.5314843849415017, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2166363620687963, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15989300670949583`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.67000130303085, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04036090406417464, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 132, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5314843849415017, -0.8470680896854471, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.543596105985032, -1.6363224572962705`, 0.}, 
      Optica`Optica`RayEnd :> {2.3849479729325935`, -1.616409057948625, 0.}, 
      RotationMatrix :> {{-0.9922143333052731, 0.12454202818154092`, 
       0.}, {-0.12454202818154092`, -0.9922143333052731, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012423645790219824`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15989300670949577`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.906642952960905`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38481925220459284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 132, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9922143333052731, 0.12454202818154092`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7253197317359628`, -1.9226930520229284`, 
       0.}, Optica`Optica`RayEnd :> {
       3.5646833574010808`, -2.3816995048095375`, 0.}, 
      RotationMatrix :> {{-0.33032132610553233`, -0.9438685403804292, 0.}, {
       0.9438685403804292, -0.33032132610553233`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023415214555781466`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.4863033708079783, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.114291174587404`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.061381228139551006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.33032132610553233`, -0.9438685403804292, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5646833574010808`, -2.3816995048095375`, 
       0.}, Optica`Optica`RayEnd :> {3.461323438055423, -2.6714090529866406`, 
       0.}, 
      RotationMatrix :> {{-0.3360256310452141, -0.9418528416268992, 0.}, {
       0.9418528416268992, -0.3360256310452141, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023357075642886575`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30759534331995664`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.56953228270094, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3616125397677604, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3360256310452141, -0.9418528416268992, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9291983209491628`, -2.1531670824734057`, 
       0.}, Optica`Optica`RayEnd :> {3.9174504507025527`, -2.180336851323488, 
       0.}, RotationMatrix :> {{-0.3968764571551029, -0.9178720377895891, 
       0.}, {0.9178720377895891, -0.3968764571551029, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008371949641395121, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.02960082422328979, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.28491960098653, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.34681844067224304`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.3968764571551029, -0.9178720377895891, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.9174504507025527`, -2.180336851323488, 0.}, 
      Optica`Optica`RayEnd :> {3.822596609712692, -2.3474960651091377`, 0.}, 
      RotationMatrix :> {{-0.4935256014318866, -0.8697312692615425, 0.}, {
       0.8697312692615425, -0.4935256014318866, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008273919058432035, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19219639409719982`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.569370264250384`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13131735326228341`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.4935256014318866, -0.8697312692615425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.81530561668199, -1.3819969648385397`, 0.}, 
      Optica`Optica`RayEnd :> {2.8545555271329692`, -1.5348882764083038`, 0.},
       RotationMatrix :> {{0.24865478409856148`, -0.9685921733861456, 0.}, {
       0.9685921733861456, 0.24865478409856148`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009692877636176246, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1578490057742923, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.206002033284815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07928017248668744, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 130, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.24865478409856148`, -0.9685921733861456, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.396143214128973, 3.5870377413582615`, 0.}, 
      Optica`Optica`RayEnd :> {7.403854419465872, 3.5837227126396174`, 0.}, 
      RotationMatrix :> {{0.9187033218165543, -0.3949483592613441, 0.}, {
       0.3949483592613441, 0.9187033218165543, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02098345234674483, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008393575111551177, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.75764119011702, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32994986980795227`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9187033218165543, -0.3949483592613441, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.403854419465872, 3.5837227126396174`, 0.}, 
      Optica`Optica`RayEnd :> {7.6717827922214505`, 3.458681008403295, 0.}, 
      RotationMatrix :> {{0.9061721701923531, -0.42290897125608523`, 0.}, {
       0.42290897125608523`, 0.9061721701923531, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020921442860254384`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2956704934987196, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.195233520495126`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38997210383718517`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9061721701923531, -0.42290897125608523`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.951636345348979, 0.7137730150913497, 0.}, 
      Optica`Optica`RayEnd :> {7.984278723080915, 0.6741966303886024, 0.}, 
      RotationMatrix :> {{0.6362885423956006, -0.771451159060689, 0.}, {
       0.771451159060689, 0.6362885423956006, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010819326533738205`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05130121879774605, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.337340754523524`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3345473635746008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.6362885423956006, -0.771451159060689, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.984278723080915, 0.6741966303886024, 0.}, 
      Optica`Optica`RayEnd :> {8.165363385013364, 0.43148520809964575`, 0.}, 
      RotationMatrix :> {{0.597992641885775, -0.801501590921983, 0.}, {
       0.801501590921983, 0.597992641885775, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010778340393249044`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30282088649351385`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.785515666533925`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26091659188330296`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.597992641885775, -0.801501590921983, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.140126437614487, -1.1365465124910128`, 0.}, 
      Optica`Optica`RayEnd :> {8.14040047723197, -1.138381443590131, 0.}, 
      RotationMatrix :> {{0.14770782833335064`, -0.9890310396792633, 0.}, {
       0.9890310396792633, 0.14770782833335064`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06386304300173534, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.001855281609476249, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.47813913639529, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30128971150548367`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.14770782833335064`, -0.9890310396792633, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.14040047723197, -1.138381443590131, 0.}, 
      Optica`Optica`RayEnd :> {8.194207568944458, -1.3608744551039436`, 0.}, 
      RotationMatrix :> {{0.23506108747525073`, -0.9719805991659255, 0.}, {
       0.9719805991659255, 0.23506108747525073`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06335220939627735, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2289068441332449, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.81692126571249, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41331792317652055`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.23506108747525073`, -0.9719805991659255, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.941744632947714, -1.6665184367310864`, 0.}, 
      Optica`Optica`RayEnd :> {6.700922205001355, -2.0974585618943045`, 0.}, 
      RotationMatrix :> {{-0.487825905527204, -0.8729409406692773, 0.}, {
       0.8729409406692773, -0.487825905527204, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009874183719180427, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.49366469721630796`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.201412237018364`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38990991801871044`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.487825905527204, -0.8729409406692773, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.700922205001355, -2.0974585618943045`, 0.}, 
      Optica`Optica`RayEnd :> {6.649765790317664, -2.252140099420774, 0.}, 
      RotationMatrix :> {{-0.3139945980701363, -0.9494247692064774, 0.}, {
       0.9494247692064774, -0.3139945980701363, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009348102033914648, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16292132093388667`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.442535792000516`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1264047310586979, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.3139945980701363, -0.9494247692064774, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1971633524093805`, -1.411110251959242, 0.}, 
      Optica`Optica`RayEnd :> {5.171495430089541, -1.571344055739821, 0.}, 
      RotationMatrix :> {{-0.15817383998223894`, -0.9874112802400384, 0.}, {
       0.9874112802400384, -0.15817383998223894`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04511119275308724, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16227665916640766`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.54080597444755, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.42424101386300805`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.15817383998223894`, -0.9874112802400384, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.171495430089541, -1.571344055739821, 0.}, 
      Optica`Optica`RayEnd :> {5.149893895290433, -1.8437437694677532`, 0.}, 
      RotationMatrix :> {{-0.07905269493737342, -0.9968704386343981, 0.}, {
       0.9968704386343981, -0.07905269493737342, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0448112476161388, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27325488164850126`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.945223199287334`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.37723290223886224`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.07905269493737342, -0.9968704386343981, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3141454695633144`, -0.0009303562125356213, 
       0.}, Optica`Optica`RayEnd :> {
       1.9827536820664209`, -0.29313647247103203`, 0.}, 
      RotationMatrix :> {{-0.7500605937701056, -0.6613691145443937, 0.}, {
       0.6613691145443937, -0.7500605937701056, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03216022068036205, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.44182002127479486`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.869677607588645`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2983840483621546, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7500605937701056, -0.6613691145443937, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9827536820664209`, -0.29313647247103203`, 
       0.}, Optica`Optica`RayEnd :> {
       1.8423080769447733`, -0.45235163317290616`, 0.}, 
      RotationMatrix :> {{-0.6615200411272681, -0.7499274866191905, 0.}, {
       0.7499274866191905, -0.6615200411272681, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03162983664470131, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21230740777304338`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.18389257109275, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.004619954255706049, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6615200411272681, -0.7499274866191905, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5359324408170836`, 2.2629931975671616`, 0.},
       Optica`Optica`RayEnd :> {2.373788782868912, 2.2380415331809025`, 0.}, 
      RotationMatrix :> {{-0.988365754822614, -0.15209580761455618`, 0.}, {
       0.15209580761455618`, -0.988365754822614, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016680636473105984`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.16405228242379988`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.404826881383215`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4158746117803885, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.988365754822614, -0.15209580761455618`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.373788782868912, 2.2380415331809025`, 0.}, 
      Optica`Optica`RayEnd :> {2.0947908614681428`, 2.1924778196150227`, 0.}, 
      RotationMatrix :> {{-0.9869255484540614, -0.16117680294834535`, 0.}, {
       0.16117680294834535`, -0.9869255484540614, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016638817946494158`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.282693990279, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.783636828357075`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1279697698519162, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9869255484540614, -0.16117680294834535`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3882353982456106`, -1.1810577998572418`, 
       0.}, Optica`Optica`RayEnd :> {2.3688702250328464`, -1.200246830713806, 
       0.}, RotationMatrix :> {{-0.7103299223039465, -0.703868880885971, 
       0.}, {0.703868880885971, -0.7103299223039465, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01796501244978937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.027262223657921227`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.16759170422735, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22214871249946544`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.7103299223039465, -0.703868880885971, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3688702250328464`, -1.200246830713806, 0.}, 
      Optica`Optica`RayEnd :> {2.1535509058181757`, -1.4225705938373867`, 0.},
       RotationMatrix :> {{-0.695700492713474, -0.7183319736989504, 0.}, {
       0.7183319736989504, -0.695700492713474, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017916861488427804`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30950002403311616`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.582321736431723`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42500275875264265`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.695700492713474, -0.7183319736989504, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.942643768053254, -1.6854126608445184`, 0.}, 
      Optica`Optica`RayEnd :> {8.06431006465274, -1.7631830852736665`, 0.}, 
      RotationMatrix :> {{0.8425731365687525, -0.5385819431922071, 0.}, {
       0.5385819431922071, 0.8425731365687525, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00812032638031625, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14439849945246613`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.506201140415413`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.04575444861265937, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8425731365687525, -0.5385819431922071, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.06431006465274, -1.7631830852736665`, 0.}, 
      Optica`Optica`RayEnd :> {8.282380208947151, -1.8815251178425596`, 0.}, 
      RotationMatrix :> {{0.8789191668820915, -0.47697075181533904`, 0.}, {
       0.47697075181533904`, 0.8789191668820915, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008074222850921381, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24811171779084215`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.87340648274586, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.01941980176643071, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.8789191668820915, -0.47697075181533904`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3269097514349193`, 1.4116366195782286`, 0.},
       Optica`Optica`RayEnd :> {2.0829310118783844`, 1.3702071945206948`, 0.},
       RotationMatrix :> {{-0.9858871828619501, -0.1674110589791687, 0.}, {
       0.1674110589791687, -0.9858871828619501, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010513498181010916`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24747125614138152`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.324926511286645`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.035560380418974906`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9858871828619501, -0.1674110589791687, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0829310118783844`, 1.3702071945206948`, 0.},
       Optica`Optica`RayEnd :> {1.900105784987952, 1.382113841150748, 0.}, 
      RotationMatrix :> {{-0.9978860346450333, 0.06498816707994154, 
       0.}, {-0.06498816707994154, -0.9978860346450333, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009425621503675973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1832125318353281, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.59608105840293, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4175488611738104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9978860346450333, 0.06498816707994154, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.883148682769548, 1.3764357895408095`, 0.}, 
      Optica`Optica`RayEnd :> {4.852140342572451, 1.35022068032724, 0.}, 
      RotationMatrix :> {{-0.7636620916545416, -0.6456161473893051, 0.}, {
       0.6456161473893051, -0.7636620916545416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010382601245783043`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.040604791747505295`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.89346312730077, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.26444763258014237`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7636620916545416, -0.6456161473893051, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.852140342572451, 1.35022068032724, 0.}, 
      Optica`Optica`RayEnd :> {4.651262681609272, 1.1872731524470477`, 0.}, 
      RotationMatrix :> {{-0.7766162477861792, -0.6299739706325288, 0.}, {
       0.6299739706325288, -0.7766162477861792, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010354830967041598`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.25865755646472804`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.276276310868568`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.38317501713076396`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7766162477861792, -0.6299739706325288, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.048745360448051, -0.5896979328317056, 0.}, 
      Optica`Optica`RayEnd :> {6.9629454351588285`, -0.8743022802455626, 0.}, 
      RotationMatrix :> {{-0.28863962745965066`, -0.9574378128421461, 0.}, {
       0.9574378128421461, -0.28863962745965066`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01200635379560934, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2972562223848368, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 20.79795103237185, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2237569462050188, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.28863962745965066`, -0.9574378128421461, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.9629454351588285`, -0.8743022802455626, 0.},
       Optica`Optica`RayEnd :> {6.8750291013448415`, -1.1416594337420962`, 
       0.}, RotationMatrix :> {{-0.31237908590274843`, -0.9499575288877717, 
       0.}, {0.9499575288877717, -0.31237908590274843`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01197293597997323, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28144116485877035`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.175082193282602`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4193846252669216, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.31237908590274843`, -0.9499575288877717, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1178173572235908`, 1.1177483207118895`, 0.},
       Optica`Optica`RayEnd :> {2.1143800737692033`, 1.1167916407522147`, 0.},
       RotationMatrix :> {{-0.963381977053935, -0.268132740051733, 0.}, {
       0.268132740051733, -0.963381977053935, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009696096136692976, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.003567934148922588, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.391267674245565`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14316027945465815`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.963381977053935, -0.268132740051733, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1143800737692033`, 1.1167916407522147`, 0.},
       Optica`Optica`RayEnd :> {1.8238439393769457`, 1.0202765181166027`, 0.},
       RotationMatrix :> {{-0.9490064249519753, -0.31525672934906523`, 0.}, {
       0.31525672934906523`, -0.9490064249519753, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009659018158444893, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3061477001137905, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.844366270413975`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05755156170174229, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9490064249519753, -0.31525672934906523`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4018199732914707`, -2.10354895449524, 0.}, 
      Optica`Optica`RayEnd :> {2.391765974104575, -2.1104128801252755`, 0.}, 
      RotationMatrix :> {{-0.825885908095186, -0.5638372697949192, 0.}, {
       0.5638372697949192, -0.825885908095186, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01179894141018357, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.012173593335771922`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.785645482833115`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1020456318355062, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.825885908095186, -0.5638372697949192, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.391765974104575, -2.1104128801252755`, 0.}, 
      Optica`Optica`RayEnd :> {2.122311827895533, -2.3037455073972075`, 0.}, 
      RotationMatrix :> {{-0.8124974516427856, -0.5829647425650867, 0.}, {
       0.5829647425650867, -0.8124974516427856, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011766564565803052`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3316369124164435, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.27646811320945, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19612829419679306`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 131, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8124974516427856, -0.5829647425650867, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.134775657365511, -2.2162878220725832`, 0.}, 
      Optica`Optica`RayEnd :> {2.86782894591727, -2.2451615561793226`, 0.}, 
      RotationMatrix :> {{-0.9942012235878901, -0.10753570112451996`, 0.}, {
       0.10753570112451996`, -0.9942012235878901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016744208820579295`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26850370439585525`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.41962680810054, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3755364668984076, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9942012235878901, -0.10753570112451996`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.86782894591727, -2.2451615561793226`, 0.}, 
      Optica`Optica`RayEnd :> {2.5579443007284106`, -2.269403900700476, 0.}, 
      RotationMatrix :> {{-0.9969539902020313, -0.07799193176379218, 0.}, {
       0.07799193176379218, -0.9969539902020313, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016695259721568153`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31083144080306246`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.87965734048907, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17316412362353056`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9969539902020313, -0.07799193176379218, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.099114995086564, -2.141213723451201, 0.}, 
      Optica`Optica`RayEnd :> {4.059116012474011, -2.136628299514328, 0.}, 
      RotationMatrix :> {{-0.9934930712372961, 0.11389256957099658`, 
       0.}, {-0.11389256957099658`, -0.9934930712372961, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01099087484610312, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04026095779685643, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.218424091177464`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.05589329301408762, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9934930712372961, 0.11389256957099658`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.059116012474011, -2.136628299514328, 0.}, 
      Optica`Optica`RayEnd :> {3.862287847875723, -2.0944986984044083`, 0.}, 
      RotationMatrix :> {{-0.9778511044089916, 0.2093017381822591, 
       0.}, {-0.2093017381822591, -0.9778511044089916, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010888310461735268`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20128643687246117`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.516328017748705`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.24559490504689538`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9778511044089916, 0.2093017381822591, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.975437887865956, 2.127856256636735, 0.}, 
      Optica`Optica`RayEnd :> {3.4230846793690546`, 2.8759319963892263`, 0.}, 
      RotationMatrix :> {{-0.5939929548241129, 0.8044702415996, 
       0.}, {-0.8044702415996, -0.5939929548241129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012336510438314416`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9298985855151403, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.22402141040891, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4285906356773369, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5939929548241129, 0.8044702415996, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4230846793690546`, 2.8759319963892263`, 0.},
       Optica`Optica`RayEnd :> {3.339779505009526, 3.0434863985286267`, 0.}, 
      RotationMatrix :> {{-0.4451943962583011, 0.8954339448224008, 
       0.}, {-0.8954339448224008, -0.4451943962583011, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011830980142825758`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.18712089608422516`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.500960336613563`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07068294469976966, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4451943962583011, 0.8954339448224008, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.092301143738348, -4.23590309475546, 0.}, 
      Optica`Optica`RayEnd :> {4.988579227331983, -4.340452516713437, 0.}, 
      RotationMatrix :> {{-0.7042917390846323, -0.7099106607574958, 0.}, {
       0.7099106607574958, -0.7042917390846323, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01293897744474587, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14727123811103168`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.502604259147017`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21083446490440322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.7042917390846323, -0.7099106607574958, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.988579227331983, -4.340452516713437, 0.}, 
      Optica`Optica`RayEnd :> {4.815103198866747, -4.5442523639535395`, 0.}, 
      RotationMatrix :> {{-0.6481822262186572, -0.7614852602737794, 0.}, {
       0.7614852602737794, -0.6481822262186572, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012858589134751576`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26763465804555414`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.898703553054435`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12308191127509838`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.6481822262186572, -0.7614852602737794, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.56398960641994, -3.7938934235005783`, 0.}, 
      Optica`Optica`RayEnd :> {6.543285241504151, -3.852149876543363, 0.}, 
      RotationMatrix :> {{-0.33487984955666356`, -0.9422608377518963, 0.}, {
       0.9422608377518963, -0.33487984955666356`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017786541661897512`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06182624885671428, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.76155604453758, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11715162046821276`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.33487984955666356`, -0.9422608377518963, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.543285241504151, -3.852149876543363, 0.}, 
      Optica`Optica`RayEnd :> {6.434314923225942, -4.16383908087726, 0.}, 
      RotationMatrix :> {{-0.3300242010952542, -0.9439724713631422, 0.}, {
       0.9439724713631422, -0.3300242010952542, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017742468331167927`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3301888707451417, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.250235573240392`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39449402543567225`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3300242010952542, -0.9439724713631422, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.136185292466732, -1.8815145244865437`, 0.}, 
      Optica`Optica`RayEnd :> {4.080829143176823, -1.940417865237979, 0.}, 
      RotationMatrix :> {{-0.6848246807054148, -0.7287078678707444, 0.}, {
       0.7287078678707444, -0.6848246807054148, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16477265915068884`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08083258511198563, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.65883686120564, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1631793505138157, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6848246807054148, -0.7287078678707444, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.080829143176823, -1.940417865237979, 0.}, 
      Optica`Optica`RayEnd :> {3.895683725659957, -2.133657255674023, 0.}, 
      RotationMatrix :> {{-0.6918229055488854, -0.7220672180329872, 0.}, {
       0.7220672180329872, -0.6918229055488854, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.164358864692161, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2676196697621247, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.054913972453583`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.39129728218922616`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6918229055488854, -0.7220672180329872, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.652329238880699, 2.7398869964278223`, 0.}, 
      Optica`Optica`RayEnd :> {3.4438157125500233`, 2.7088351887185578`, 0.}, 
      RotationMatrix :> {{-0.9890925265314038, -0.14729553272154133`, 0.}, {
       0.14729553272154133`, -0.9890925265314038, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035398920786550436`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21081296313288356`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.444092229956865`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.31898619180598564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9890925265314038, -0.14729553272154133`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4438157125500233`, 2.7088351887185578`, 0.},
       Optica`Optica`RayEnd :> {3.1602250446055833`, 2.681392119152333, 0.}, 
      RotationMatrix :> {{-0.9953504135274077, -0.09632006172556537, 0.}, {
       0.09632006172556537, -0.9953504135274077, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.035258889720509196`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2849154067655703, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.86576703196991, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2606077007497996, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.9953504135274077, -0.09632006172556537, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.33269357193641, 1.4407580715476331`, 0.}, 
      Optica`Optica`RayEnd :> {3.1302201679194464`, 1.4074849028546426`, 0.}, 
      RotationMatrix :> {{-0.9867647197165962, -0.16215852713510473`, 0.}, {
       0.16215852713510473`, -0.9867647197165962, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03172016700712219, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2051891397932377, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.744048386013993`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21706847572576465`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9867647197165962, -0.16215852713510473`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1302201679194464`, 1.4074849028546426`, 0.},
       Optica`Optica`RayEnd :> {2.861739231903491, 1.3869725520795433`, 0.}, 
      RotationMatrix :> {{-0.9970941195721402, -0.07617950324501703, 0.}, {
       0.07617950324501703, -0.9970941195721402, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03147833208649081, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26926338321116783`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.142558193166522`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34104770822414, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9970941195721402, -0.07617950324501703, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6496634334844873`, 2.7681090417856065`, 0.},
       Optica`Optica`RayEnd :> {3.451260765305006, 2.791653704045864, 0.}, 
      RotationMatrix :> {{-0.9930320954708353, 0.11784420802398632`, 
       0.}, {-0.11784420802398632`, -0.9930320954708353, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03942453383644382, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.19979481940652752`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.079698297285205`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38254217885790043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9930320954708353, 0.11784420802398632`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.451260765305006, 2.791653704045864, 0.}, 
      Optica`Optica`RayEnd :> {3.1468993997360766`, 2.818992318919108, 0.}, 
      RotationMatrix :> {{-0.9959901726476268, 0.08946270725475133, 
       0.}, {-0.08946270725475133, -0.9959901726476268, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03931069464505399, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.305586715539421, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.53196663628355, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17388433961855992`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9959901726476268, 0.08946270725475133, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.202925738185447, -3.42230821353291, 0.}, 
      Optica`Optica`RayEnd :> {8.248112007121396, -3.615283735849963, 0.}, 
      RotationMatrix :> {{0.22798867476342632`, -0.9736637839519429, 0.}, {
       0.9736637839519429, 0.22798867476342632`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2399368094557239, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1981952348415348, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.306597890209613`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3401705036698207, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.22798867476342632`, -0.9736637839519429, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.248112007121396, -3.615283735849963, 0.}, 
      Optica`Optica`RayEnd :> {8.319354478030785, -3.9202359941616067`, 0.}, 
      RotationMatrix :> {{0.2274929035332037, -0.9737797383608018, 0.}, {
       0.9737797383608018, 0.2274929035332037, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23934541463425085`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3131634868733054, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.770079850782103`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14260389608535012`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2274929035332037, -0.9737797383608018, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.658065848402106, -0.8129543347630941, 0.}, 
      Optica`Optica`RayEnd :> {4.424263155239173, -0.7507918497619795, 0.}, 
      RotationMatrix :> {{-0.9664249544818883, 0.2569490364929967, 
       0.}, {-0.2569490364929967, -0.9664249544818883, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.060505678630209135`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2419253477247767, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.24258966971287, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38785581526486035`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9664249544818883, 0.2569490364929967, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.424263155239173, -0.7507918497619795, 0.}, 
      Optica`Optica`RayEnd :> {4.144075751525485, -0.6886994227943991, 0.}, 
      RotationMatrix :> {{-0.9763133992007695, 0.2163611484094079, 
       0.}, {-0.2163611484094079, -0.9763133992007695, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06029923664829346, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28698510533918226`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.66732762561486, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28047263152388563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9763133992007695, 0.2163611484094079, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.513356881400975, -3.6820117133582566`, 0.}, 
      Optica`Optica`RayEnd :> {5.4472361063926655`, -3.7768066801453966`, 0.},
       RotationMatrix :> {{-0.5720928539698839, -0.8201888602246389, 0.}, {
       0.8201888602246389, -0.5720928539698839, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0176386601345717, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11557699864538108`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.748195136358245`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4135417002402155, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5720928539698839, -0.8201888602246389, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.4472361063926655`, -3.7768066801453966`, 
       0.}, Optica`Optica`RayEnd :> {5.301047359768452, -3.944042993187486, 
       0.}, RotationMatrix :> {{-0.6581398398652373, -0.7528957106944886, 
       0.}, {0.7528957106944886, -0.6581398398652373, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017426836973892735`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2221241410551099, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.076938865119807`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22322410715189533`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6581398398652373, -0.7528957106944886, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.672843912771113, -4.421741734640321, 0.}, 
      Optica`Optica`RayEnd :> {6.659903152929509, -4.446385810830566, 0.}, 
      RotationMatrix :> {{-0.4649076808289837, -0.8853591634507518, 0.}, {
       0.8853591634507518, -0.4649076808289837, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1651332433010769, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.027835117325936905`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.288555462560517`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25258178708782797`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.4649076808289837, -0.8853591634507518, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.659903152929509, -4.446385810830566, 0.}, 
      Optica`Optica`RayEnd :> {6.515057093215638, -4.686380860885859, 0.}, 
      RotationMatrix :> {{-0.5167210881268564, -0.8561537928929573, 0.}, {
       0.8561537928929573, -0.5167210881268564, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1643827321877667, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2803176859666132, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.703425637791103`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2640925970457204, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5167210881268564, -0.8561537928929573, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6285767423124753`, -1.5008821935487953`, 
       0.}, Optica`Optica`RayEnd :> {
       2.6594651458304117`, -1.5781593961122107`, 0.}, 
      RotationMatrix :> {{0.3711578269647809, -0.9285697967750087, 0.}, {
       0.9285697967750087, 0.3711578269647809, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01317946049918434, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.08322174900778041, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.544876796771224`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3879718618886211, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.3711578269647809, -0.9285697967750087, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6594651458304117`, -1.5781593961122107`, 
       0.}, Optica`Optica`RayEnd :> {
       2.7823370711004873`, -1.8868877195185065`, 0.}, 
      RotationMatrix :> {{0.36978313989817785`, -0.9291180923042258, 0.}, {
       0.9291180923042258, 0.36978313989817785`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013146963147281995`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33228103721524266`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.036652731849784`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.0651435684725811, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36978313989817785`, -0.9291180923042258, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.543596105985032, -1.6363224572962705`, 0.}, 
      Optica`Optica`RayEnd :> {2.3965708830209524`, -1.7925522233475382`, 0.},
       RotationMatrix :> {{-0.6853287169555758, -0.7282338564747064, 0.}, {
       0.7282338564747064, -0.6853287169555758, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.20421271627857635`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2145324124417358, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.957474735702778`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23336005019393563`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 136, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6853287169555758, -0.7282338564747064, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3965708830209524`, -1.7925522233475382`, 
       0.}, Optica`Optica`RayEnd :> {2.279009699303809, -1.8618269030697097`, 
       0.}, RotationMatrix :> {{-0.8615463032551068, -0.5076790003018232, 
       0.}, {0.5076790003018232, -0.8615463032551068, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.16286185078610396`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13645370338538068`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.159426216713143`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22546132842593195`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 136, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8615463032551068, -0.5076790003018232, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.279009699303809, -1.8618269030697097`, 0.}, 
      Optica`Optica`RayEnd :> {2.154464827177917, -1.8060757775677903`, 0.}, 
      RotationMatrix :> {{-0.9127262143567072, 0.40857172886296633`, 
       0.}, {-0.40857172886296633`, -0.9127262143567072, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.032977762641009926`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13645370338538082`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.36137769772351, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3117529405569035, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 136, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9127262143567072, 0.40857172886296633`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3849479729325935`, -1.616409057948625, 0.}, 
      Optica`Optica`RayEnd :> {2.382855125444696, -1.6157165107911804`, 0.}, 
      RotationMatrix :> {{-0.9493708260912564, 0.3141576587747061, 
       0.}, {-0.3141576587747061, -0.9493708260912564, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011711175486311043`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0022044573420419017`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.909596925799242`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1623829480131843, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9493708260912564, 0.3141576587747061, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.382855125444696, -1.6157165107911804`, 0.}, 
      Optica`Optica`RayEnd :> {2.1992812968316877`, -1.582953166762202, 0.}, 
      RotationMatrix :> {{-0.984443994283654, 0.17569866851756227`, 
       0.}, {-0.17569866851756227`, -0.984443994283654, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011440152111491957`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18647462900780762`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.185579376730796`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42728723027937565`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.984443994283654, 0.17569866851756227`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.461323438055423, -2.6714090529866406`, 0.}, 
      Optica`Optica`RayEnd :> {3.4057873386829636`, -2.8241461926857054`, 0.},
       RotationMatrix :> {{-0.34171763672899647`, -0.9398026690472573, 0.}, {
       0.9398026690472573, -0.34171763672899647`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023299081086268443`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16252043618252865`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.78730966718553, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4304496302895123, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.34171763672899647`, -0.9398026690472573, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4057873386829636`, -2.8241461926857054`, 
       0.}, Optica`Optica`RayEnd :> {3.351553571969628, -3.045170916975937, 
       0.}, RotationMatrix :> {{-0.23830506324731468`, -0.9711903504620978, 
       0.}, {0.9711903504620978, -0.23830506324731468`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.023025736618500225`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2275812606509804, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.12412993294898, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26380898474347886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.23830506324731468`, -0.9711903504620978, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.822596609712692, -2.3474960651091377`, 0.}, 
      Optica`Optica`RayEnd :> {3.623646102364506, -2.623732783245161, 0.}, 
      RotationMatrix :> {{-0.5844209327295468, -0.8114506598601826, 0.}, {
       0.8114506598601826, -0.5844209327295468, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008177036355665052, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34042330828053113`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.025537497346296`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3908889370174853, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 134, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5844209327295468, -0.8114506598601826, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.6717827922214505`, 3.458681008403295, 0.}, 
      Optica`Optica`RayEnd :> {7.772022016348352, 3.40810360023285, 0.}, 
      RotationMatrix :> {{0.8927902809511328, -0.4504725454888417, 0.}, {
       0.4504725454888417, 0.8927902809511328, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02085961662179916, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11227633887334788`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.345683814585414`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.12975110389017422`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8927902809511328, -0.4504725454888417, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.772022016348352, 3.40810360023285, 0.}, 
      Optica`Optica`RayEnd :> {7.877126940960202, 3.311600672087688, 0.}, 
      RotationMatrix :> {{0.7366067054286716, -0.676321344863163, 0.}, {
       0.676321344863163, 0.7366067054286716, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017031190648950163`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14268798238903302`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.55686202852118, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3224235725671773, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7366067054286716, -0.676321344863163, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.165363385013364, 0.43148520809964575`, 0.}, 
      Optica`Optica`RayEnd :> {8.203554124833435, 0.37473041028837395`, 0.}, 
      RotationMatrix :> {{0.5582797353501222, -0.8296527810460206, 0.}, {
       0.8296527810460206, 0.5582797353501222, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010737509517850274`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06840789196140058, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.877182241762203`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3022016096355585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5582797353501222, -0.8296527810460206, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.203554124833435, 0.37473041028837395`, 0.}, 
      Optica`Optica`RayEnd :> {8.353958111122084, 0.12673605509693064`, 0.}, 
      RotationMatrix :> {{0.5185648892495708, -0.8550382772938174, 0.}, {
       0.8550382772938174, 0.5185648892495708, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010697809466999778`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2900388927339503, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.30643980300845, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.21356975136960685`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5185648892495708, -0.8550382772938174, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.194207568944458, -1.3608744551039436`, 0.}, 
      Optica`Optica`RayEnd :> {8.280785062159566, -1.6167105668714303`, 0.}, 
      RotationMatrix :> {{0.3205523550143233, -0.9472307995915095, 0.}, {
       0.9472307995915095, 0.3205523550143233, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0628454618938329, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27008846405523895`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.17883980754651, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02543726630305887, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.3205523550143233, -0.9472307995915095, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.280785062159566, -1.6167105668714303`, 0.}, 
      Optica`Optica`RayEnd :> {8.333292854791026, -1.8375753072924508`, 0.}, 
      RotationMatrix :> {{0.23129098680451382`, -0.9728846177337749, 0.}, {
       0.9728846177337749, 0.23129098680451382`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06230220432101657, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22702048772803082`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.514830129383995`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2020123482247178, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.23129098680451382`, -0.9728846177337749, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.649765790317664, -2.252140099420774, 0.}, 
      Optica`Optica`RayEnd :> {6.642168701414975, -2.310614675154861, 0.}, 
      RotationMatrix :> {{-0.12883841620830871`, -0.9916656001439871, 0.}, {
       0.9916656001439871, -0.12883841620830871`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008850049191077075, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.05896602214052459, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.521550261668818`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03424378098979723, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12883841620830871`, -0.9916656001439871, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.642168701414975, -2.310614675154861, 0.}, 
      Optica`Optica`RayEnd :> {6.586852865388811, -2.621865656387353, 0.}, 
      RotationMatrix :> {{-0.17497914647724647`, -0.9845721397125219, 0.}, {
       0.9845721397125219, -0.17497914647724647`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0088175565671167, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31612816235423036`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.989419941953077`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13972822580602381`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17497914647724647`, -0.9845721397125219, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.149893895290433, -1.8437437694677532`, 0.}, 
      Optica`Optica`RayEnd :> {5.150028337380061, -2.0794393420918182`, 0.}, 
      RotationMatrix :> {{0.0005704055713013356, -0.9999998373187281, 0.}, {
       0.9999998373187281, 0.0005704055713013356, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04451329681983375, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2356956109673265, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.26105531798355, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4043240801965882, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0005704055713013356, -0.9999998373187281, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.150028337380061, -2.0794393420918182`, 0.}, 
      Optica`Optica`RayEnd :> {5.1633437138595895`, -2.3949405336234557`, 0.},
       RotationMatrix :> {{0.042166350533941195`, -0.9991106039286377, 0.}, {
       0.9991106039286377, 0.042166350533941195`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.0443617892119538, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31578204684350686`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.728412747311943`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3781022144627382, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.042166350533941195`, -0.9991106039286377, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0947908614681428`, 2.1924778196150227`, 0.},
       Optica`Optica`RayEnd :> {2.0375417428426617`, 2.1825871052305135`, 0.},
       RotationMatrix :> {{-0.9854019087116255, -0.17024417260947586`, 0.}, {
       0.17024417260947586`, -0.9854019087116255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01659710425935718, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.05809722725251487, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      19.869620724690797`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18880781882410905`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 134, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9854019087116255, -0.17024417260947586`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1535509058181757`, -1.4225705938373867`, 
       0.}, Optica`Optica`RayEnd :> {
       2.1410113125605466`, -1.4360627430792223`, 0.}, 
      RotationMatrix :> {{-0.6807766417952255, -0.7324910675127824, 0.}, {
       0.7324910675127824, -0.6807766417952255, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017868839584314972`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01841954098860086, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.60958265709485, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32708244658063856`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.6807766417952255, -0.7324910675127824, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1410113125605466`, -1.4360627430792223`, 
       0.}, 
      Optica`Optica`RayEnd :> {1.9679775262061567`, -1.6446457138116022`, 0.},
       RotationMatrix :> {{-0.6384725989650006, -0.7696445545645584, 0.}, {
       0.7696445545645584, -0.6384725989650006, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017792015423060425`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2710120788815166, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.972738842796083`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.311255134240129, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.6384725989650006, -0.7696445545645584, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.651262681609272, 1.1872731524470477`, 0.}, 
      Optica`Optica`RayEnd :> {4.613254550733855, 1.1577011222800127`, 0.}, 
      RotationMatrix :> {{-0.7892500591477856, -0.6140719372640434, 0.}, {
       0.6140719372640434, -0.7892500591477856, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010327134965291359`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.048157273395021565`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.340807057217898`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.03845596100026522, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7892500591477856, -0.6140719372640434, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.613254550733855, 1.1577011222800127`, 0.}, 
      Optica`Optica`RayEnd :> {4.34950135708816, 0.9394537482734076, 0.}, 
      RotationMatrix :> {{-0.7704389849288813, -0.6375137414219033, 0.}, {
       0.6375137414219033, -0.7704389849288813, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010296816236058009`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3423414427425963, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      20.84747239247694, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2003698861575139, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7704389849288813, -0.6375137414219033, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.8750291013448415`, -1.1416594337420962`, 
       0.}, Optica`Optica`RayEnd :> {6.862194451580757, -1.177646071358585, 
       0.}, RotationMatrix :> {{-0.33592502033686317`, -0.941888730536509, 
       0.}, {0.941888730536509, -0.33592502033686317`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01193961117762166, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.03820688840388859, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.231628388120356`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04933892515845827, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.33592502033686317`, -0.941888730536509, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.862194451580757, -1.177646071358585, 0.}, 
      Optica`Optica`RayEnd :> {6.778138158256813, -1.4378788033585193`, 0.}, 
      RotationMatrix :> {{-0.30736791280579484`, -0.95159075561788, 0.}, {
       0.95159075561788, -0.30736791280579484`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011904517772118586`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27347126951749506`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.598079889273798`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2510446223408792, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.30736791280579484`, -0.95159075561788, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.122311827895533, -2.3037455073972075`, 0.}, 
      Optica`Optica`RayEnd :> {2.0846919533166233`, -2.3320911188318774`, 0.},
       RotationMatrix :> {{-0.7986660939076652, -0.6017744348526872, 0.}, {
       0.6017744348526872, -0.7986660939076652, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011734276564990412`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.047103382584886264`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.339586645873197`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.03274193705592992, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7986660939076652, -0.6017744348526872, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0846919533166233`, -2.3320911188318774`, 
       0.}, Optica`Optica`RayEnd :> {
       1.8478535170951083`, -2.5287092081334865`, 0.}, 
      RotationMatrix :> {{-0.7694138746498892, -0.6387505690770405, 0.}, {
       0.6387505690770405, -0.7694138746498892, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011690882294326037`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30781669531146005`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.79515535493416, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13481957093004907`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 135, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7694138746498892, -0.6387505690770405, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5579443007284106`, -2.269403900700476, 0.}, 
      Optica`Optica`RayEnd :> {2.4442099759061167`, -2.2749127608980144`, 0.},
       RotationMatrix :> {{-0.9988290265277764, -0.0483794973679425, 0.}, {
       0.0483794973679425, -0.9988290265277764, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016646453717660506`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.11386766083247292`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.032240006004585`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.36651954902145994`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9988290265277764, -0.0483794973679425, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4442099759061167`, -2.2749127608980144`, 
       0.}, Optica`Optica`RayEnd :> {
       2.1147820855425192`, -2.2821698249394347`, 0.}, 
      RotationMatrix :> {{-0.9997574433691664, -0.0220239512337851, 0.}, {
       0.0220239512337851, -0.9997574433691664, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01659944827306273, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.329507814668957, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.51991157171464, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13262814255316738`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9997574433691664, -0.0220239512337851, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.862287847875723, -2.0944986984044083`, 0.}, 
      Optica`Optica`RayEnd :> {3.6469436431969653`, -2.026091854644832, 0.}, 
      RotationMatrix :> {{-0.9530685955856618, 0.30275444193004636`, 
       0.}, {-0.30275444193004636`, -0.9530685955856618, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010786703185249007`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2259482745273216, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.819098705615318`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34438581385447914`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9530685955856618, 0.30275444193004636`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6469436431969653`, -2.026091854644832, 0.}, 
      Optica`Optica`RayEnd :> {3.3899699046641167`, -1.9450005602570204`, 0.},
       RotationMatrix :> {{-0.9536447796235121, 0.3009346013618617, 
       0.}, {-0.3009346013618617, -0.9536447796235121, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010760097970568731`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26946484060270204`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.217906669707318`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.15915244888850624`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9536447796235121, 0.3009346013618617, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.339779505009526, 3.0434863985286267`, 0.}, 
      Optica`Optica`RayEnd :> {3.315343322038069, 3.126349591829431, 0.}, 
      RotationMatrix :> {{-0.2828550692321101, 0.9591626607670347, 
       0.}, {-0.9591626607670347, -0.2828550692321101, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011346165663283178`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08639117919221267, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.61672451673113, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.07444285114375451, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2828550692321101, 0.9591626607670347, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.315343322038069, 3.126349591829431, 0.}, 
      Optica`Optica`RayEnd :> {3.2238502271956717`, 3.427387713933632, 0.}, 
      RotationMatrix :> {{-0.29079157899537156`, 0.9567864221368205, 
       0.}, {-0.9567864221368205, -0.29079157899537156`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011317811409310014`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.31463460929125986`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.082383738482193`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33697756283287356`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.29079157899537156`, 0.9567864221368205, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.434314923225942, -4.16383908087726, 0.}, 
      Optica`Optica`RayEnd :> {6.400555111761498, -4.262022410720735, 0.}, 
      RotationMatrix :> {{-0.3251598046785386, -0.9456590830851327, 0.}, {
       0.9456590830851327, -0.3251598046785386, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017698504209891105`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10382529137578883`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.389361463683947`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38161610478602764`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.3251598046785386, -0.9456590830851327, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.400555111761498, -4.262022410720735, 0.}, 
      Optica`Optica`RayEnd :> {6.302464808170437, -4.450050301458311, 0.}, 
      RotationMatrix :> {{-0.46252447767493904`, -0.8866065122429025, 0.}, {
       0.8866065122429025, -0.46252447767493904`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017234324784482932`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.21207591884466342`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.70323382357405, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04662216399193647, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.46252447767493904`, -0.8866065122429025, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.895683725659957, -2.133657255674023, 0.}, 
      Optica`Optica`RayEnd :> {3.894363137934695, -2.1350092208711593`, 0.}, 
      RotationMatrix :> {{-0.6987567400953506, -0.71535936295775, 0.}, {
       0.71535936295775, -0.6987567400953506, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16394610939786583`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.0018899105360783582`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.057446452571927`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.18809517395724568`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6987567400953506, -0.71535936295775, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.894363137934695, -2.1350092208711593`, 0.}, 
      Optica`Optica`RayEnd :> {3.7055343143627244`, -2.3234015063995175`, 0.},
       RotationMatrix :> {{-0.7079246044418692, -0.7062880109599925, 0.}, {
       0.7062880109599925, -0.7079246044418692, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16352832101342266`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.266735782860442, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.45221541120538, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3938188304188384, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7079246044418692, -0.7062880109599925, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1602250446055833`, 2.681392119152333, 0.}, 
      Optica`Optica`RayEnd :> {3.088276325440507, 2.678144610161838, 0.}, 
      RotationMatrix :> {{-0.998982904757788, -0.04509053117552031, 0.}, {
       0.04509053117552031, -0.998982904757788, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03511941258941911, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0720219723705088, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.962276474946393`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.09748017951884567, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.998982904757788, -0.04509053117552031, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.088276325440507, 2.678144610161838, 0.}, 
      Optica`Optica`RayEnd :> {2.892263836527015, 2.630179466514019, 0.}, 
      RotationMatrix :> {{-0.971340705165378, -0.23769146911242856`, 0.}, {
       0.23769146911242856`, -0.971340705165378, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033099505557120684`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20179581466229138`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.260934280646584`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3457045177109833, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.971340705165378, -0.23769146911242856`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.861739231903491, 1.3869725520795433`, 0.}, 
      Optica`Optica`RayEnd :> {2.8189310068960913`, 1.3874165313898386`, 0.}, 
      RotationMatrix :> {{-0.9999462218333148, 0.01037079752372673, 
       0.}, {-0.01037079752372673, -0.9999462218333148, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03123834091809515, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04281052727907167, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.19992429972048, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0888867398736892, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9999462218333148, 0.01037079752372673, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8189310068960913`, 1.3874165313898386`, 0.},
       Optica`Optica`RayEnd :> {2.6407767730931617`, 1.3513135172147952`, 0.},
       RotationMatrix :> {{-0.9800779699446736, -0.1986131235067979, 0.}, {
       0.1986131235067979, -0.9800779699446736, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02894387027297956, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18177557221593965`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.46895214660007, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36762507756467794`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9800779699446736, -0.1986131235067979, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1468993997360766`, 2.818992318919108, 0.}, 
      Optica`Optica`RayEnd :> {2.859142571987567, 2.8365806538130016`, 0.}, 
      RotationMatrix :> {{-0.9981372550591646, 0.061008360598814426`, 
       0.}, {-0.061008360598814426`, -0.9981372550591646, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.039197184166783514`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2882938456509696, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.918280389455848`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22467546869450405`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9981372550591646, 0.061008360598814426`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.859142571987567, 2.8365806538130016`, 0.}, 
      Optica`Optica`RayEnd :> {2.597929550289893, 2.8344956544945057`, 0.}, 
      RotationMatrix :> {{-0.9999681454524371, -0.007981734173263554, 0.}, {
       0.007981734173263554, -0.9999681454524371, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.038985020101843765`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26122134278536235`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.304887976778186`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.267790356669105, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999681454524371, -0.007981734173263554, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.319354478030785, -3.9202359941616067`, 0.}, 
      Optica`Optica`RayEnd :> {8.361110025060112, -4.099381638041829, 0.}, 
      RotationMatrix :> {{0.2269970733289634, -0.9738954403323205, 0.}, {
       0.9738954403323205, 0.2269970733289634, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23875547747921777`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18394751270125392`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.016569517801784`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06264881235381055, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.2269970733289634, -0.9738954403323205, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.361110025060112, -4.099381638041829, 0.}, 
      Optica`Optica`RayEnd :> {8.412962572471049, -4.416584131883879, 0.}, 
      RotationMatrix :> {{0.16132701403067795`, -0.9869010054427672, 0.}, {
       0.9869010054427672, 0.16132701403067795`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2375123194526273, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3214126767453624, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.492260279384922`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0985712945849953, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.16132701403067795`, -0.9869010054427672, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.144075751525485, -0.6886994227943991, 0.}, 
      Optica`Optica`RayEnd :> {3.915434832123526, -0.647965335292557, 0.}, 
      RotationMatrix :> {{-0.9844980227824383, 0.1753956759372037, 
       0.}, {-0.1753956759372037, -0.9844980227824383, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06009349903484142, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23224111588945884`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.978530720906736`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22539897547357585`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9844980227824383, 0.1753956759372037, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.915434832123526, -0.647965335292557, 0.}, 
      Optica`Optica`RayEnd :> {3.6767553638289288`, -0.6263039518208819, 0.}, 
      RotationMatrix :> {{-0.9959070207752182, 0.0903836598651991, 
       0.}, {-0.0903836598651991, -0.9959070207752182, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.059642794307125366`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23966039330539884`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.333228102998728`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3446610244045872, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9959070207752182, 0.0903836598651991, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.301047359768452, -3.944042993187486, 0.}, 
      Optica`Optica`RayEnd :> {5.1473790497722725`, -4.085249162367698, 0.}, 
      RotationMatrix :> {{-0.7363336038731153, -0.6766186694196585, 0.}, {
       0.6766186694196585, -0.7363336038731153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017217557603448272`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20869387080513993`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.356588651998695`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2558976975409137, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7363336038731153, -0.6766186694196585, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1473790497722725`, -4.085249162367698, 0.}, 
      Optica`Optica`RayEnd :> {5.017777290759835, -4.160408289752661, 0.}, 
      RotationMatrix :> {{-0.8650598459819387, -0.5016686783821602, 0.}, {
       0.5016686783821602, -0.8650598459819387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015802974506275023`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14981825779385888`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.578319673533606`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25423952806002786`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8650598459819387, -0.5016686783821602, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7823370711004873`, -1.8868877195185065`, 
       0.}, Optica`Optica`RayEnd :> {
       2.9520001666773728`, -2.3150268609912428`, 0.}, 
      RotationMatrix :> {{0.36840764286121225`, -0.92966435270018, 0.}, {
       0.92966435270018, 0.36840764286121225`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013114545925964711`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.46053087894487915`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.653764109635922`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.30441110445137776`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.36840764286121225`, -0.92966435270018, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9520001666773728`, -2.3150268609912428`, 
       0.}, Optica`Optica`RayEnd :> {3.068991289281188, -2.631997311602204, 
       0.}, RotationMatrix :> {{0.3462591627699445, -0.938138898137081, 0.}, {
       0.938138898137081, 0.3462591627699445, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013078439761677923`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3378715574424948, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.153814014650816`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.026280987487486418`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3462591627699445, -0.938138898137081, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3965708830209524`, -1.7925522233475382`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3818224814643028`, -1.8307828693178243`, 0.}, 
      RotationMatrix :> {{-0.35992082704753525`, -0.9329828499267376, 0.}, {
       0.9329828499267376, -0.35992082704753525`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.041350865492472015`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04097679391779631, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.012383639552624`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4042996845207713, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.35992082704753525`, -0.9329828499267376, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3818224814643028`, -1.8307828693178243`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3331305227023598`, -2.0340983190730886`, 0.}, 
      RotationMatrix :> {{-0.23290369898026037`, -0.9724998030854873, 0.}, {
       0.9724998030854873, -0.23290369898026037`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04055729127874689, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2090647721574827, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.321799502345698`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22717516063093962`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23290369898026037`, -0.9724998030854873, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.279009699303809, -1.8618269030697097`, 0.}, 
      Optica`Optica`RayEnd :> {2.183786388996578, -1.8860639242246482`, 0.}, 
      RotationMatrix :> {{-0.96910116291655, -0.24666360905855095`, 0.}, {
       0.24666360905855095`, -0.96910116291655, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.12988408814509395`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.09825941186640645, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.291093828614127`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3073665552375398, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.96910116291655, -0.24666360905855095`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.183786388996578, -1.8860639242246482`, 0.}, 
      Optica`Optica`RayEnd :> {1.8575330775666872`, -1.973609833425109, 0.}, 
      RotationMatrix :> {{-0.9658320687088942, -0.25916869998805264`, 0.}, {
       0.25916869998805264`, -0.9658320687088942, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.12955305318067176`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3377950701782144, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.791030532477883`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06936197201849507, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9658320687088942, -0.25916869998805264`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.154464827177917, -1.8060757775677903`, 0.}, 
      Optica`Optica`RayEnd :> {1.9635584338880692`, -1.6439212922441218`, 0.},
       RotationMatrix :> {{-0.7621677022213734, 0.6473796364503529, 
       0.}, {-0.6473796364503529, -0.7621677022213734, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026300122521132445`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2504781988707239, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.69701848421028, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3221932989061409, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7621677022213734, 0.6473796364503529, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9635584338880692`, -1.6439212922441218`, 
       0.}, Optica`Optica`RayEnd :> {1.8331971455187728`, -1.49581634012526, 
       0.}, RotationMatrix :> {{-0.6607105264665941, 0.750640793066987, 
       0.}, {-0.750640793066987, -0.6607105264665941, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025668947877907827`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.19730469418499183`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.989029431604067`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.02466778996199919, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6607105264665941, 0.750640793066987, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1992812968316877`, -1.582953166762202, 0.}, 
      Optica`Optica`RayEnd :> {2.1201065284469833`, -1.5802870100530664`, 0.},
       RotationMatrix :> {{-0.9994335017358673, 0.03365524636637604, 
       0.}, {-0.03365524636637604, -0.9994335017358673, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011175400837179281`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.07921964617674888, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.29173370260764, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20624701533807063`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9994335017358673, 0.03365524636637604, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1201065284469833`, -1.5802870100530664`, 
       0.}, Optica`Optica`RayEnd :> {1.847484571749867, -1.5541627057341192`, 
       0.}, RotationMatrix :> {{-0.9954400576972172, 0.095389158355445, 
       0.}, {-0.095389158355445, -0.9954400576972172, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01112239553128573, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27387079170571166`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.697062474332093`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20886186452494604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9954400576972172, 0.095389158355445, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.351553571969628, -3.045170916975937, 0.}, 
      Optica`Optica`RayEnd :> {3.337120111113439, -3.153467306216698, 0.}, 
      RotationMatrix :> {{-0.13210924226424997`, -0.9912351628692179, 0.}, {
       0.9912351628692179, -0.13210924226424997`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022755599023903672`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1092539826041754, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.270530269638574`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.06037172695640039, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.13210924226424997`, -0.9912351628692179, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.337120111113439, -3.153467306216698, 0.}, 
      Optica`Optica`RayEnd :> {3.289440215654356, -3.451588365206402, 0.}, 
      RotationMatrix :> {{-0.1579276081998558, -0.9874506927276279, 0.}, {
       0.9874506927276279, -0.1579276081998558, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022691519711564332`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.30190981806515, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.717356800374997`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21216503632256417`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1579276081998558, -0.9874506927276279, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.877126940960202, 3.311600672087688, 0.}, 
      Optica`Optica`RayEnd :> {7.954147366881353, 3.186700566472998, 0.}, 
      RotationMatrix :> {{0.5248822554874233, -0.8511748456541901, 0.}, {
       0.8511748456541901, 0.5248822554874233, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013905406804924856`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14673848299487172`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.75349159573431, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3563647437883759, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5248822554874233, -0.8511748456541901, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.954147366881353, 3.186700566472998, 0.}, 
      Optica`Optica`RayEnd :> {8.103699191777398, 2.928621355054173, 0.}, 
      RotationMatrix :> {{0.5013815972835944, -0.865226267461495, 0.}, {
       0.865226267461495, 0.5013815972835944, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013865737655638305`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29827944564837217`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.194945175293903`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1270939158697711, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5013815972835944, -0.865226267461495, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.333292854791026, -1.8375753072924508`, 0.}, 
      Optica`Optica`RayEnd :> {8.37502059150578, -2.132620862057291, 0.}, 
      RotationMatrix :> {{0.14003456956141336`, -0.990146615066551, 0.}, {
       0.990146615066551, 0.14003456956141336`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.06176364285165033, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29798168299046196`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.914125584591215`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19735291791723064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.14003456956141336`, -0.990146615066551, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.37502059150578, -2.132620862057291, 0.}, 
      Optica`Optica`RayEnd :> {8.372609199076223, -2.338139090646819, 0.}, 
      RotationMatrix :> {{-0.011732421384996111`, -0.9999311727756285, 0.}, {
       0.9999311727756285, -0.011732421384996111`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.060065185511272545`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20553237481240444`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.218313499313574`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.18651949143956026`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.011732421384996111`, -0.9999311727756285, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.586852865388811, -2.621865656387353, 0.}, 
      Optica`Optica`RayEnd :> {6.5283406794940015`, -2.8804016821273737`, 0.},
       RotationMatrix :> {{-0.22073854746207827`, -0.9753330168021235, 0.}, {
       0.9753330168021235, -0.22073854746207827`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008785183238607578, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2650746168602971, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.344619928545875`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10753046428719956`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22073854746207827`, -0.9753330168021235, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.5283406794940015`, -2.8804016821273737`, 
       0.}, Optica`Optica`RayEnd :> {6.455915662084558, -3.1889427043325047`, 
       0.}, RotationMatrix :> {{-0.22852245879850389`, -0.9735386411564184, 
       0.}, {0.9735386411564184, -0.22852245879850389`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008763250208185996, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31692735055552645`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.813672407368053`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3135691014168087, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.22852245879850389`, -0.9735386411564184, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1633437138595895`, -2.3949405336234557`, 
       0.}, Optica`Optica`RayEnd :> {5.177189268849019, -2.5598001098368637`, 
       0.}, RotationMatrix :> {{0.08368930497990114, -0.9964918967216841, 
       0.}, {0.9964918967216841, 0.08368930497990114, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04421079728268869, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.16543995666775854`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.95010228924674, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3843611479973078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.08368930497990114, -0.9964918967216841, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.177189268849019, -2.5598001098368637`, 0.}, 
      Optica`Optica`RayEnd :> {5.2141051080821414`, -2.8945932194192343`, 0.},
       RotationMatrix :> {{0.10960036910836281`, -0.9939757336531456, 0.}, {
       0.9939757336531456, 0.10960036910836281`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04408637587737085, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3368222163250501, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.448599169407814`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3054508624972299, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10960036910836281`, -0.9939757336531456, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.34950135708816, 0.9394537482734076, 0.}, 
      Optica`Optica`RayEnd :> {4.308246115973363, 0.9031733340704978, 0.}, 
      RotationMatrix :> {{-0.7509319156266083, -0.6603796317977644, 0.}, {
       0.6603796317977644, -0.7509319156266083, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010266586517508204`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.054938723812760284`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.92109028238604, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11604499127122281`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7509319156266083, -0.6603796317977644, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.308246115973363, 0.9031733340704978, 0.}, 
      Optica`Optica`RayEnd :> {4.102079489920942, 0.6993790946992785, 0.}, 
      RotationMatrix :> {{-0.7111868021504437, -0.7030030813922683, 0.}, {
       0.7030030813922683, -0.7111868021504437, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010220902427665947`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28989096174032863`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.350128905761725`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13712003892418087`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7111868021504437, -0.7030030813922683, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.778138158256813, -1.4378788033585193`, 0.}, 
      Optica`Optica`RayEnd :> {6.730084543669796, -1.6035765617551552`, 0.}, 
      RotationMatrix :> {{-0.2785312118392544, -0.9604271778908356, 0.}, {
       0.9604271778908356, -0.2785312118392544, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011869527514623546`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17252506198389714`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 21.853416981009964`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20333841615165604`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.2785312118392544, -0.9604271778908356, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.730084543669796, -1.6035765617551552`, 0.}, 
      Optica`Optica`RayEnd :> {6.648066431511518, -1.8677482212282193`, 0.}, 
      RotationMatrix :> {{-0.29651068447973256`, -0.9550295356633527, 0.}, {
       0.9550295356633527, -0.29651068447973256`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011838149682084834`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27661098385776445`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.22407569937937, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4262860742157448, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 139, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.29651068447973256`, -0.9550295356633527, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3899699046641167`, -1.9450005602570204`, 
       0.}, Optica`Optica`RayEnd :> {2.876920695888101, -1.784177655015215, 
       0.}, RotationMatrix :> {{-0.9542174887631342, 0.29911366424584757`, 
       0.}, {-0.29911366424584757`, -0.9542174887631342, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010733558377184975`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.5376648560917016, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.9383775768702, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3358828831152488, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9542174887631342, 0.29911366424584757`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.876920695888101, -1.784177655015215, 0.}, 
      Optica`Optica`RayEnd :> {2.5598910142943008`, -1.6845745240638166`, 0.},
       RotationMatrix :> {{-0.9540236393986129, 0.29973137217953183`, 
       0.}, {-0.29973137217953183`, -0.9540236393986129, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01070710151021494, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3323079937449416, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.430193407612713`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14690699849298997`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9540236393986129, 0.29973137217953183`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2238502271956717`, 3.427387713933632, 0.}, 
      Optica`Optica`RayEnd :> {3.164101554416602, 3.6182791304508584`, 0.}, 
      RotationMatrix :> {{-0.2987081303666714, 0.954344514760182, 
       0.}, {-0.954344514760182, -0.2987081303666714, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011289528013082296`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.20002359060574224`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.350415349893886`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.37047461732073084`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.2987081303666714, 0.954344514760182, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.164101554416602, 3.6182791304508584`, 0.}, 
      Optica`Optica`RayEnd :> {3.101985669129406, 3.8742308283456834`, 0.}, 
      RotationMatrix :> {{-0.23584024230793124`, 0.9717918399061272, 
       0.}, {-0.9717918399061272, -0.23584024230793124`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01123257182359135, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26338119686161293`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.740219521249074`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35296883354377284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.23584024230793124`, 0.9717918399061272, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7055343143627244`, -2.3234015063995175`, 
       0.}, Optica`Optica`RayEnd :> {
       3.6126373039872774`, -2.4137232822676298`, 0.}, 
      RotationMatrix :> {{-0.7169747132016795, -0.6970991756051422, 0.}, {
       0.6970991756051422, -0.7169747132016795, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1631115972906224, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.129568042868083, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.62583658864861, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12537396385956945`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7169747132016795, -0.6970991756051422, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6126373039872774`, -2.4137232822676298`, 
       0.}, Optica`Optica`RayEnd :> {3.3922309432078155`, -2.628930241020917, 
       0.}, RotationMatrix :> {{-0.7154957159105708, -0.6986171201120248, 
       0.}, {0.6986171201120248, -0.7154957159105708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1627092163903207, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3080470726494336, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.081746256169772`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3419814261914499, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7154957159105708, -0.6986171201120248, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.892263836527015, 2.630179466514019, 0.}, 
      Optica`Optica`RayEnd :> {2.656542139953466, 2.52067965515237, 0.}, 
      RotationMatrix :> {{-0.9069243114135148, -0.42129359521255505`, 0.}, {
       0.42129359521255505`, -0.9069243114135148, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03119577428399096, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.25991330655383726`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.609218111428724`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4008332693291291, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9069243114135148, -0.42129359521255505`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.656542139953466, 2.52067965515237, 0.}, 
      Optica`Optica`RayEnd :> {2.4021847771895124`, 2.4197950374793806`, 0.}, 
      RotationMatrix :> {{-0.929554399966777, -0.3686849841021509, 0.}, {
       0.3686849841021509, -0.929554399966777, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031059387794138946`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27363364938409707`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.014195912517188`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3829074197571266, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.929554399966777, -0.3686849841021509, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6407767730931617`, 1.3513135172147952`, 0.},
       Optica`Optica`RayEnd :> {2.4100475676243165`, 1.2509610945770788`, 0.},
       RotationMatrix :> {{-0.9170186358477059, -0.39884435749802405`, 0.}, {
       0.39884435749802405`, -0.9170186358477059, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02681792956212341, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2516079787795755, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.806106838164702`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3832376986861457, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9170186358477059, -0.39884435749802405`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4100475676243165`, 1.2509610945770788`, 0.},
       Optica`Optica`RayEnd :> {2.109843693225373, 1.128427125877418, 0.}, 
      RotationMatrix :> {{-0.9258457283244296, -0.3779016900510049, 0.}, {
       0.3779016900510049, -0.9258457283244296, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02674474298628302, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32424826859896466`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.28599427569117, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2828143945358699, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9258457283244296, -0.3779016900510049, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.597929550289893, 2.8344956544945057`, 0.}, 
      Optica`Optica`RayEnd :> {2.4952292852444606`, 2.826571044663803, 0.}, 
      RotationMatrix :> {{-0.9970362022321602, -0.07693381206251287, 0.}, {
       0.07693381206251287, -0.9970362022321602, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.038774004425274476`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.10300555267251818`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.442915417359362`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1481150903699008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 143, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9970362022321602, -0.07693381206251287, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4952292852444606`, 2.826571044663803, 0.}, 
      Optica`Optica`RayEnd :> {2.358105900150826, 2.859797487829117, 0.}, 
      RotationMatrix :> {{-0.9718753993693595, 0.23549566471730887`, 
       0.}, {-0.23549566471730887`, -0.9718753993693595, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02733474697376804, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14109152797016236`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.651730878755203`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3829640709725676, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 143, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9718753993693595, 0.23549566471730887`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.358105900150826, 2.859797487829117, 0.}, 
      Optica`Optica`RayEnd :> {2.301619792494541, 2.9890883958884147`, 0.}, 
      RotationMatrix :> {{-0.40035081105812487`, 0.916361952552102, 
       0.}, {-0.916361952552102, -0.40035081105812487`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008064403268104786, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.14109152797016253`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.860546340151043`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.02433259746077865, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 143, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.40035081105812487`, 0.916361952552102, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6767553638289288`, -0.6263039518208819, 0.},
       Optica`Optica`RayEnd :> {3.660707579059717, -0.6262284193186336, 0.}, 
      RotationMatrix :> {{-0.9999889235561261, 0.004706672397659012, 
       0.}, {-0.004706672397659012, -0.9999889235561261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05919546989100458, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.016047962523568098`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.35473237278031, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2078987184334114, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9999889235561261, 0.004706672397659012, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.660707579059717, -0.6262284193186336, 0.}, 
      Optica`Optica`RayEnd :> {3.380318304137456, -0.6066002737367311, 0.}, 
      RotationMatrix :> {{-0.9975587449981131, 0.06983230110620889, 
       0.}, {-0.06983230110620889, -0.9975587449981131, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05889722832488268, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28107545177481347`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.770724041407032`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2302683458526706, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9975587449981131, 0.06983230110620889, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.017777290759835, -4.160408289752661, 0.}, 
      Optica`Optica`RayEnd :> {4.871824473011491, -4.206822074429016, 0.}, 
      RotationMatrix :> {{-0.9529743424530014, -0.3030509901423664, 0.}, {
       0.3030509901423664, -0.9529743424530014, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01450461261683035, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15315503392531513`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.78354741899353, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25727314448545374`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9529743424530014, -0.3030509901423664, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.871824473011491, -4.206822074429016, 0.}, 
      Optica`Optica`RayEnd :> {4.566101814353904, -4.310487669884657, 0.}, 
      RotationMatrix :> {{-0.9470368706970829, -0.3211248441654363, 0.}, {
       0.3211248441654363, -0.9470368706970829, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01446619739916272, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3228202281422833, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.261321356644107`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.07329239622279791, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9470368706970829, -0.3211248441654363, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.068991289281188, -2.631997311602204, 0.}, 
      Optica`Optica`RayEnd :> {3.084678752134776, -2.677816872230564, 0.}, 
      RotationMatrix :> {{0.32391595584313015`, -0.9460858595023132, 0.}, {
       0.9460858595023132, 0.32391595584313015`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01304243300267034, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.0484306579240738, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.218711096269075`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19587083624711668`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.32391595584313015`, -0.9460858595023132, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.084678752134776, -2.677816872230564, 0.}, 
      Optica`Optica`RayEnd :> {3.186830152915206, -2.9007350279240947`, 0.}, 
      RotationMatrix :> {{0.4165892585133147, -0.9090948188672763, 0.}, {
       0.9090948188672763, 0.4165892585133147, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012912891969377635`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2452089166796535, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.581620292954963`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3698050106433552, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4165892585133147, -0.9090948188672763, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3331305227023598`, -2.0340983190730886`, 
       0.}, Optica`Optica`RayEnd :> {2.328960687100035, -2.0748605967363356`, 
       0.}, RotationMatrix :> {{-0.1017653538384013, -0.9948084301804766, 
       0.}, {0.9948084301804766, -0.1017653538384013, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03977894673494984, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04097500224827391, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.376706005358386`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.11035195056578107`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1017653538384013, -0.9948084301804766, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.328960687100035, -2.0748605967363356`, 0.}, 
      Optica`Optica`RayEnd :> {2.2886130596423895`, -2.406696796436617, 0.}, 
      RotationMatrix :> {{-0.12070005302031814`, -0.9926890234111041, 0.}, {
       0.9926890234111041, -0.12070005302031814`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039673570314835725`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.33428011378630634`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.87144057376212, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22399964319505006`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.12070005302031814`, -0.9926890234111041, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.289440215654356, -3.451588365206402, 0.}, 
      Optica`Optica`RayEnd :> {3.265160825292077, -3.581552939267163, 0.}, 
      RotationMatrix :> {{-0.18363843961083287`, -0.9829938573039497, 0.}, {
       0.9829938573039497, -0.18363843961083287`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022627620845288635`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1322130073296835, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.894522230196774`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.305445772460198, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.18363843961083287`, -0.9829938573039497, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.265160825292077, -3.581552939267163, 0.}, 
      Optica`Optica`RayEnd :> {3.21414977933437, -3.9108801651768457`, 0.}, 
      RotationMatrix :> {{-0.1530693478926099, -0.9882154495532492, 0.}, {
       0.9882154495532492, -0.1530693478926099, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022560469168505248`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3332544801425277, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.387738860807715`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41089149980361284`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.1530693478926099, -0.9882154495532492, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.103699191777398, 2.928621355054173, 0.}, 
      Optica`Optica`RayEnd :> {8.12458174917919, 2.890196586484368, 0.}, 
      RotationMatrix :> {{0.47750504156855533`, -0.8786290088977322, 0.}, {
       0.8786290088977322, 0.47750504156855533`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013826181673943847`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.043732642765813026`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.253546916600094`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.39003397800900946`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.47750504156855533`, -0.8786290088977322, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.12458174917919, 2.890196586484368, 0.}, 
      Optica`Optica`RayEnd :> {8.301227485802736, 2.5779427149896432`, 0.}, 
      RotationMatrix :> {{0.4923834329050153, -0.8703783975953627, 0.}, {
       0.8703783975953627, 0.4923834329050153, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013790079556213985`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35875645852126364`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.784506475211565`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.08457571681466568, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.4923834329050153, -0.8703783975953627, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.372609199076223, -2.338139090646819, 0.}, 
      Optica`Optica`RayEnd :> {8.328067160359495, -2.6073615446193075`, 0.}, 
      RotationMatrix :> {{-0.16322805366038834`, -0.986588365276137, 0.}, {
       0.986588365276137, -0.16322805366038834`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05841343456973877, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.27288225104614466`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.583975715715408`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13497604690833437`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.16322805366038834`, -0.986588365276137, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.328067160359495, -2.6073615446193075`, 0.}, 
      Optica`Optica`RayEnd :> {8.264249979302264, -2.9744161410151913`, 0.}, 
      RotationMatrix :> {{-0.1712932341752863, -0.9852200911094787, 0.}, {
       0.9852200911094787, -0.1712932341752863, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05826750875932775, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.37256101424254884`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.13536601679438, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.28955133564836777`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.1712932341752863, -0.9852200911094787, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.455915662084558, -3.1889427043325047`, 0.}, 
      Optica`Optica`RayEnd :> {6.424566515033717, -3.317857071873617, 0.}, 
      RotationMatrix :> {{-0.23629178833175138`, -0.9716821449254804, 0.}, {
       0.9716821449254804, -0.23629178833175138`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008741371935623231, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.13267133518337795`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.991451996513778`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3972348894053909, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.23629178833175138`, -0.9716821449254804, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.424566515033717, -3.317857071873617, 0.}, 
      Optica`Optica`RayEnd :> {6.380694900367936, -3.572269944766505, 0.}, 
      RotationMatrix :> {{-0.16993447502413372`, -0.9854553638791924, 0.}, {
       0.9854553638791924, -0.16993447502413372`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008695149140509732, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2581678300389024, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 27.373540384971353`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3705592255481858, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.16993447502413372`, -0.9854553638791924, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.2141051080821414`, -2.8945932194192343`, 
       0.}, Optica`Optica`RayEnd :> {5.240643944512358, -3.0887371814349898`, 
       0.}, RotationMatrix :> {{0.13543715549712124`, -0.9907859389953246, 
       0.}, {0.9907859389953246, 0.13543715549712124`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04396230462828299, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1959494522223649, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.711171435385783`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.27898507614818496`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.13543715549712124`, -0.9907859389953246, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.240643944512358, -3.0887371814349898`, 0.}, 
      Optica`Optica`RayEnd :> {5.2846673386373135`, -3.42689019718041, 0.}, 
      RotationMatrix :> {{0.129098352732004, -0.9916317942270113, 0.}, {
       0.9916317942270113, 0.129098352732004, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04385305370694658, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.34100662939010995`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.215861246883147`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.163448557301287, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.129098352732004, -0.9916317942270113, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.102079489920942, 0.6993790946992785, 0.}, 
      Optica`Optica`RayEnd :> {4.087892909975138, 0.6836188491282627, 0.}, 
      RotationMatrix :> {{-0.6690261907054842, -0.7432388284731278, 0.}, {
       0.7432388284731278, -0.6690261907054842, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010175421622144257`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.021204819994930763`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.378543364554933`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.028145826892071166`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6690261907054842, -0.7432388284731278, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.087892909975138, 0.6836188491282627, 0.}, 
      Optica`Optica`RayEnd :> {3.8723596812644248`, 0.43704591406790944`, 0.},
       RotationMatrix :> {{-0.6581273596950976, -0.7529066199873382, 0.}, {
       0.7529066199873382, -0.6581273596950976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010149253843155022`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.32749470985458945`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.863235535139726`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.32745323880141125`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6581273596950976, -0.7529066199873382, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.648066431511518, -1.8677482212282193`, 0.}, 
      Optica`Optica`RayEnd :> {6.633457387841712, -1.9118605919964782`, 0.}, 
      RotationMatrix :> {{-0.3143856679475469, -0.949295344868589, 0.}, {
       0.949295344868589, -0.3143856679475469, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011806854798793563`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04646854217363228, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.292849141796346`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.33181785878964004`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.3143856679475469, -0.949295344868589, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.633457387841712, -1.9118605919964782`, 0.}, 
      Optica`Optica`RayEnd :> {6.609319392222294, -2.0588667500189346`, 0.}, 
      RotationMatrix :> {{-0.16202751152721648`, -0.986786241041238, 0.}, {
       0.986786241041238, -0.16202751152721648`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011452211919860853`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14897467344836315`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.492475204217154`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19479143262417853`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 142, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.16202751152721648`, -0.986786241041238, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.5598910142943008`, -1.6845745240638166`, 
       0.}, Optica`Optica`RayEnd :> {2.3957522094877737`, -1.632889265754243, 
       0.}, RotationMatrix :> {{-0.9538293901638837, 0.3003489544839359, 
       0.}, {-0.3003489544839359, -0.9538293901638837, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010680709856083492`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.17208402938635126`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.660786006990424`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2288131024585845, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9538293901638837, 0.3003489544839359, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3957522094877737`, -1.632889265754243, 0.}, 
      Optica`Optica`RayEnd :> {2.1864040273262773`, -1.5908839168081363`, 0.},
       RotationMatrix :> {{-0.9804582556205477, 0.19672724515306075`, 
       0.}, {-0.19672724515306075`, -0.9804582556205477, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010558094981586623`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21352075007925375`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.97679671710772, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4118516622828556, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9804582556205477, 0.19672724515306075`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3922309432078155`, -2.628930241020917, 0.}, 
      Optica`Optica`RayEnd :> {3.373086493082613, -2.647702492049789, 0.}, 
      RotationMatrix :> {{-0.7140135049070866, -0.700131926718313, 0.}, {
       0.700131926718313, -0.7140135049070866, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16230782812568448`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.026812448215098674`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.117674936778005`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21142851788629013`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7140135049070866, -0.700131926718313, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.373086493082613, -2.647702492049789, 0.}, 
      Optica`Optica`RayEnd :> {3.135354215431099, -2.873588876929993, 0.}, 
      RotationMatrix :> {{-0.7249374250541053, -0.6888147281787192, 0.}, {
       0.6888147281787192, -0.7249374250541053, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16188751415535485`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3279348940134673, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.603018579917936`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3944766914057619, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7249374250541053, -0.6888147281787192, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4021847771895124`, 2.4197950374793806`, 0.},
       Optica`Optica`RayEnd :> {2.2508515589624474`, 2.369591616676134, 0.}, 
      RotationMatrix :> {{-0.9491357482032488, -0.31486716482138527`, 0.}, {
       0.31486716482138527`, -0.9491357482032488, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.030923597579745426`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.15944317608260428`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.227849768467877`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1905520832921078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9491357482032488, -0.31486716482138527`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2508515589624474`, 2.369591616676134, 0.}, 
      Optica`Optica`RayEnd :> {2.105089716554118, 2.2924074478347602`, 0.}, 
      RotationMatrix :> {{-0.8837474617035851, -0.4679641267580973, 0.}, {
       0.4679641267580973, -0.8837474617035851, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02982057945656011, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1649360804130023, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.47195516747912, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.22386116739633322`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.8837474617035851, -0.4679641267580973, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.109843693225373, 1.128427125877418, 0.}, 
      Optica`Optica`RayEnd :> {2.1045353568776313`, 1.1263999011482146`, 0.}, 
      RotationMatrix :> {{-0.9341946095562911, -0.35676383151318475`, 0.}, {
       0.35676383151318475`, -0.9341946095562911, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026671756137825423`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.005682259663500699, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.29360850364026, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10369441329357676`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9341946095562911, -0.35676383151318475`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1045353568776313`, 1.1263999011482146`, 0.},
       Optica`Optica`RayEnd :> {1.8227355325169223`, 1.0030155268912893`, 0.},
       RotationMatrix :> {{-0.916041566865407, -0.40108334267926066`, 0.}, {
       0.40108334267926066`, -0.916041566865407, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026571964416807037`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.307627769911137, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.748897603108745`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.006446924165629196, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.916041566865407, -0.40108334267926066`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4952292852444606`, 2.826571044663803, 0.}, 
      Optica`Optica`RayEnd :> {2.3308064325818236`, 2.763043043820169, 0.}, 
      RotationMatrix :> {{-0.9327962470514981, -0.3604041640806048, 0.}, {
       0.3604041640806048, -0.9327962470514981, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011439257451506436`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17626877593297094`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.679115577109542`, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3971581953433545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9327962470514981, -0.3604041640806048, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3308064325818236`, 2.763043043820169, 0.}, 
      Optica`Optica`RayEnd :> {2.107523011322846, 2.6895580339560903`, 0.}, 
      RotationMatrix :> {{-0.9498796689340522, -0.3126157618318924, 0.}, {
       0.3126157618318924, -0.9498796689340522, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011394453687226162`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.23506495460582394`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.02701170992616, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34634323383505045`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9498796689340522, -0.3126157618318924, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.358105900150826, 2.859797487829117, 0.}, 
      Optica`Optica`RayEnd :> {2.158132977113625, 2.9830817346584992`, 0.}, 
      RotationMatrix :> {{-0.8512324607952291, 0.5247888124650698, 
       0.}, {-0.5247888124650698, -0.8512324607952291, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019270343705663242`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.234921636858614, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.966525872145745`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4155482248119766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8512324607952291, 0.5247888124650698, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.158132977113625, 2.9830817346584992`, 0.}, 
      Optica`Optica`RayEnd :> {1.9620053601186829`, 3.0868466436547135`, 0.}, 
      RotationMatrix :> {{-0.8839134167504348, 0.4676505871786879, 
       0.}, {-0.4676505871786879, -0.8839134167504348, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019172075462033394`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.22188555267774224`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.294916490108804`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4310458771126887, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.8839134167504348, 0.4676505871786879, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.380318304137456, -0.6066002737367311, 0.}, 
      Optica`Optica`RayEnd :> {3.1133430358425915`, -0.5703185624998235, 0.}, 
      RotationMatrix :> {{-0.9908916817859126, 0.13466133434466035`, 
       0.}, {-0.13466133434466035`, -0.9908916817859126, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.058600489374280605`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26942931624341304`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.131759325173206`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.13580298269157542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9908916817859126, 0.13466133434466035`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1133430358425915`, -0.5703185624998235, 0.},
       Optica`Optica`RayEnd :> {2.8546878672361986`, -0.5169710757238604, 0.},
       RotationMatrix :> {{-0.9793859712975209, 0.20199781985360638`, 
       0.}, {-0.20199781985360638`, -0.9793859712975209, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05828746212156104, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.26409931956011007`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.522626318122168`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17863413450846669`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9793859712975209, 0.20199781985360638`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.566101814353904, -4.310487669884657, 0.}, 
      Optica`Optica`RayEnd :> {4.446348884020257, -4.35365092609602, 0.}, 
      RotationMatrix :> {{-0.9407566494687157, -0.3390824774009932, 0.}, {
       0.3390824774009932, -0.9407566494687157, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.014427883923540014`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1272942693535844, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.43189567757791, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.29373616873318303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9407566494687157, -0.3390824774009932, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.446348884020257, -4.35365092609602, 0.}, 
      Optica`Optica`RayEnd :> {4.30456992408814, -4.450885268302151, 0.}, 
      RotationMatrix :> {{-0.8246895553515204, -0.5655856586708248, 0.}, {
       0.5655856586708248, -0.8246895553515204, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012398625647326524`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.17191797690669802`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.686334283399823`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.227709535693151, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8246895553515204, -0.5655856586708248, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.186830152915206, -2.9007350279240947`, 0.}, 
      Optica`Optica`RayEnd :> {3.333988727489665, -3.1521740169841297`, 0.}, 
      RotationMatrix :> {{0.5051147160302896, -0.8630522137447069, 0.}, {
       0.8630522137447069, 0.5051147160302896, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012784637573271645`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.29133693773759456`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.97201178952334, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0711664972415661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.5051147160302896, -0.8630522137447069, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.333988727489665, -3.1521740169841297`, 0.}, 
      Optica`Optica`RayEnd :> {3.4218536151488363`, -3.351156547170038, 0.}, 
      RotationMatrix :> {{0.40394218808204363`, -0.9147845148927097, 0.}, {
       0.9147845148927097, 0.40394218808204363`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012617007760862888`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2175184723248689, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.293939128564144`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3178157890922402, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.40394218808204363`, -0.9147845148927097, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2886130596423895`, -2.406696796436617, 0.}, 
      Optica`Optica`RayEnd :> {2.269709177066505, -2.5407943245044953`, 0.}, 
      RotationMatrix :> {{-0.13959093630651123`, -0.990209255915673, 0.}, {
       0.990209255915673, -0.13959093630651123`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039568473042130674`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1354234241568209, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.05290796213226, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23343057465157566`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.13959093630651123`, -0.990209255915673, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.269709177066505, -2.5407943245044953`, 0.}, 
      Optica`Optica`RayEnd :> {2.2269974575965636`, -2.866598855823816, 0.}, 
      RotationMatrix :> {{-0.1299839425231335, -0.9915160990554525, 0.}, {
       0.9915160990554525, -0.1299839425231335, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03946908602100868, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3285922756369681, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.53922453007497, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3395161382300277, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.1299839425231335, -0.9915160990554525, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.21414977933437, -3.9108801651768457`, 0.}, 
      Optica`Optica`RayEnd :> {3.1878751517765105`, -4.124011085105019, 0.}, 
      RotationMatrix :> {{-0.12235304411782627`, -0.9924866410159386, 0.}, {
       0.9924866410159386, -0.12235304411782627`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.022493516776822393`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2147443714809166, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.675496318592145`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.36426300282533325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.12235304411782627`, -0.9924866410159386, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1878751517765105`, -4.124011085105019, 0.}, 
      Optica`Optica`RayEnd :> {3.1843017802244207`, -4.353766402763522, 0.}, 
      RotationMatrix :> {{-0.015551063097101706`, -0.9998790749068357, 0.}, {
       0.9998790749068357, -0.015551063097101706`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02223493310608651, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22978310420178552`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.01557531281079, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3534353471174926, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.015551063097101706`, -0.9998790749068357, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.264249979302264, -2.9744161410151913`, 0.}, 
      Optica`Optica`RayEnd :> {8.230821166008036, -3.1577858296872368`, 0.}, 
      RotationMatrix :> {{-0.17934695186498578`, -0.983785886693206, 0.}, {
       0.983785886693206, -0.17934695186498578`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05812194749420158, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18639186753166906`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.385131119286815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.40852249447837696`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.17934695186498578`, -0.983785886693206, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.230821166008036, -3.1577858296872368`, 0.}, 
      Optica`Optica`RayEnd :> {8.200425868156623, -3.420396074804406, 0.}, 
      RotationMatrix :> {{-0.11497543220541802`, -0.9933683355076184, 0.}, {
       0.9933683355076184, -0.11497543220541802`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.057829600887681694`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26436341458676854`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.776388972875232`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3940349969218724, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.11497543220541802`, -0.9933683355076184, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.380694900367936, -3.572269944766505, 0.}, 
      Optica`Optica`RayEnd :> {6.3661669333633055`, -3.7128484852223758`, 0.},
       RotationMatrix :> {{-0.10279665359211453`, -0.9947023916781653, 0.}, {
       0.9947023916781653, -0.10279665359211453`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008649170763183722, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.14132723680165338`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.56291888228557, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3661220064830449, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 145, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.10279665359211453`, -0.9947023916781653, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.2846673386373135`, -3.42689019718041, 0.}, 
      Optica`Optica`RayEnd :> {5.3101931958713955`, -3.633260269225098, 0.}, 
      RotationMatrix :> {{0.12275427037461739`, -0.99243709579237, 0.}, {
       0.99243709579237, 0.12275427037461739`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.043744074285567106`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20794272293894903`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.49450449562134, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1965277845791934, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.12275427037461739`, -0.99243709579237, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3101931958713955`, -3.633260269225098, 0.}, 
      Optica`Optica`RayEnd :> {5.340524913380642, -3.9364533047015757`, 0.}, 
      RotationMatrix :> {{0.09954405628844856, -0.9950331556574589, 0.}, {
       0.9950331556574589, 0.09954405628844856, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.043624030622833515`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3047064650585892, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.94547006390805, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.10155539072880723`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09954405628844856, -0.9950331556574589, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8723596812644248`, 0.43704591406790944`, 
       0.}, Optica`Optica`RayEnd :> {3.8163508583297476`, 
       0.37105506085661005`, 0.}, 
      RotationMatrix :> {{-0.6470888406852433, -0.7624146065367756, 0.}, {
       0.7624146065367756, -0.6470888406852433, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010123153358935738`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.08655507468706429, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.979219335220392`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.10093644845148952`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6470888406852433, -0.7624146065367756, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.8163508583297476`, 0.37105506085661005`, 
       0.}, Optica`Optica`RayEnd :> {3.6277582609737444`, 
       0.13098454742641094`, 0.}, 
      RotationMatrix :> {{-0.6177522146048281, -0.7863728132068332, 0.}, {
       0.7863728132068332, -0.6177522146048281, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01009043382390742, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3052884196888622, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.431046196359908`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.26532326576512094`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6177522146048281, -0.7863728132068332, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.609319392222294, -2.0588667500189346`, 0.}, 
      Optica`Optica`RayEnd :> {6.607990499786304, -2.292803609693519, 0.}, 
      RotationMatrix :> {{-0.005680468642256964, -0.9999838660078486, 0.}, {
       0.9999838660078486, -0.005680468642256964, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011108221460536992`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.23394063407093807`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 22.83870734264214, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0771565547721506, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.005680468642256964, -0.9999838660078486, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.607990499786304, -2.292803609693519, 0.}, 
      Optica`Optica`RayEnd :> {6.6188993657553175`, -2.610571620417632, 0.}, 
      RotationMatrix :> {{0.03430944302380988, -0.9994112577509794, 0.}, {
       0.9994112577509794, 0.03430944302380988, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011071264259578377`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31795520438623126`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.26476731651969, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.04309638006352617, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 146, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.03430944302380988, -0.9994112577509794, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1864040273262773`, -1.5908839168081363`, 
       0.}, Optica`Optica`RayEnd :> {2.116943046812807, -1.584546922441695, 
       0.}, RotationMatrix :> {{-0.9958642516112337, 0.09085368656690357, 
       0.}, {-0.09085368656690357, -0.9958642516112337, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010436887729583996`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06974944667517449, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.070260975652456`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.19087410217177264`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534883*^-15}, 
      Optica`Optica`RayTilt :> {-0.9958642516112337, 0.09085368656690357, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.116943046812807, -1.584546922441695, 0.}, 
      Optica`Optica`RayEnd :> {1.8429277720194244`, -1.5431834720036013`, 0.},
       RotationMatrix :> {{-0.9887976731170539, 0.14926205692773845`, 
       0.}, {-0.14926205692773845`, -0.9887976731170539, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010389989784159245`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2771196598082454, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.480398072168658`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1742014400871985, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534885*^-15}, 
      Optica`Optica`RayTilt :> {-0.9887976731170539, 0.14926205692773845`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.135354215431099, -2.873588876929993, 0.}, 
      Optica`Optica`RayEnd :> {3.1291590347370537`, -2.8792926509807226`, 0.},
       RotationMatrix :> {{-0.7356819876975914, -0.6773271092886511, 0.}, {
       0.6773271092886511, -0.7356819876975914, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16146828863427443`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.008421003636957336, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.61430272479146, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.13591413334877106`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7356819876975914, -0.6773271092886511, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1291590347370537`, -2.8792926509807226`, 
       0.}, Optica`Optica`RayEnd :> {2.8747270856212968`, -3.114781565921408, 
       0.}, RotationMatrix :> {{-0.7338990247585169, -0.6792585821750781, 
       0.}, {0.6792585821750781, -0.7338990247585169, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16106976677838786`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3466852258040206, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.127396858981413`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.33029283566787515`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7338990247585169, -0.6792585821750781, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.107523011322846, 2.6895580339560903`, 0.}, 
      Optica`Optica`RayEnd :> {1.9715389495919409`, 2.652334402765798, 0.}, 
      RotationMatrix :> {{-0.964516604780188, -0.26402219433846386`, 0.}, {
       0.26402219433846386`, -0.964516604780188, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011349825404379212`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1409867503130187, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.215933955345605`, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.23687442400320097`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.964516604780188, -0.26402219433846386`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9715389495919409`, 2.652334402765798, 0.}, 
      Optica`Optica`RayEnd :> {1.8126837753289176`, 2.5667455556332626`, 0.}, 
      RotationMatrix :> {{-0.8803520608786449, -0.4743208290879935, 0.}, {
       0.4743208290879935, -0.8803520608786449, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010277417254604973`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.1804450529762787, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.4829926337505, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.2623469712000231, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8803520608786449, -0.4743208290879935, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8546878672361986`, -0.5169710757238604, 0.},
       Optica`Optica`RayEnd :> {2.7081137701951414`, -0.4761334728962817, 0.},
       RotationMatrix :> {{-0.9633098742439864, 0.2683916656381741, 
       0.}, {-0.2683916656381741, -0.9633098742439864, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05797610697195857, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.15215674723161066`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.726516359412525`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.32915924502203975`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9633098742439864, 0.2683916656381741, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.7081137701951414`, -0.4761334728962817, 0.},
       Optica`Optica`RayEnd :> {2.4233374609525127`, -0.41594306614899723`, 
       0.}, RotationMatrix :> {{-0.9783849825150366, 0.20679174545675139`, 
       0.}, {-0.20679174545675139`, -0.9783849825150366, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.057693255181950016`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.29106774361006926`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.157296619955428`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3390609504968023, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9783849825150366, 0.20679174545675139`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4218536151488363`, -3.351156547170038, 0.}, 
      Optica`Optica`RayEnd :> {3.4253620668364504`, -3.362413453139368, 0.}, 
      RotationMatrix :> {{0.2975539136047475, -0.9547050164833627, 0.}, {
       0.9547050164833627, 0.2975539136047475, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01245157587967019, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.011790978129343245`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.309739039257465`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3217593679504726, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2975539136047475, -0.9547050164833627, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.4253620668364504`, -3.362413453139368, 0.}, 
      Optica`Optica`RayEnd :> {3.5187321549010875`, -3.6092674409253935`, 0.},
       RotationMatrix :> {{0.353778993597178, -0.93532904567824, 0.}, {
       0.93532904567824, 0.353778993597178, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012394992483478704`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.26392208060535866`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.700343718553395`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.311312180060994, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.353778993597178, -0.93532904567824, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2269974575965636`, -2.866598855823816, 0.}, 
      Optica`Optica`RayEnd :> {2.2005832540538934`, -3.084454745644393, 0.}, 
      RotationMatrix :> {{-0.12036472996723699`, -0.9927297375317782, 0.}, {
       0.9927297375317782, -0.12036472996723699`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.039369948637520094`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.21945135879804625`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.833289350864355`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41016041892601884`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.12036472996723699`, -0.9927297375317782, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2005832540538934`, -3.084454745644393, 0.}, 
      Optica`Optica`RayEnd :> {2.19117527744928, -3.3256825326061277`, 0.}, 
      RotationMatrix :> {{-0.03897075858165612, -0.9992403514548286, 0.}, {
       0.9992403514548286, -0.03897075858165612, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03909782909135094, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.24141117460931505`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.190577889286143`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3866439949557562, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.03897075858165612, -0.9992403514548286, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.200425868156623, -3.420396074804406, 0.}, 
      Optica`Optica`RayEnd :> {8.189281402749307, -3.642485901268315, 0.}, 
      RotationMatrix :> {{-0.05011693227824933, -0.9987433569736603, 0.}, {
       0.9987433569736603, -0.05011693227824933, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.057538724750442846`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2223692652503579, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.074363788310713`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4005769259794034, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05011693227824933, -0.9987433569736603, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.189281402749307, -3.642485901268315, 0.}, 
      Optica`Optica`RayEnd :> {8.195899279209828, -3.8980626220087173`, 0.}, 
      RotationMatrix :> {{0.02588521730014453, -0.9996649216239025, 0.}, {
       0.9996649216239025, 0.02588521730014453, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05718265653137244, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2556623876780946, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 27.452744122074293`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4155261532803731, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.02588521730014453, -0.9996649216239025, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.340524913380642, -3.9364533047015757`, 0.}, 
      Optica`Optica`RayEnd :> {5.354799821483549, -4.123047464971758, 0.}, 
      RotationMatrix :> {{0.0762795455419229, -0.9970864711407513, 0.}, {
       0.9970864711407513, 0.0762795455419229, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.043504316387141154`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18713939630201026`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.196236854952744`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.19835686822707274`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.0762795455419229, -0.9970864711407513, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.354799821483549, -4.123047464971758, 0.}, 
      Optica`Optica`RayEnd :> {5.3435873933583835`, -4.311607522435026, 0.}, 
      RotationMatrix :> {{-0.05935858144977356, -0.9982367248344799, 0.}, {
       0.9982367248344799, -0.05935858144977356, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04262623936684563, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.18889312802485206`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.475798684429524`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.1425673901415661, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.05935858144977356, -0.9982367248344799, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6277582609737444`, 0.1309845474264109, 0.}, 
      Optica`Optica`RayEnd :> {3.5846098472847885`, 0.0715563325483261, 0.}, 
      RotationMatrix :> {{-0.5875293406282709, -0.8092028632555052, 0.}, {
       0.8092028632555052, -0.5875293406282709, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01005782004327544, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07344044068133798, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.5294563868729, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.21812045673242605`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5875293406282709, -0.8092028632555052, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5846098472847885`, 0.0715563325483261, 0.}, 
      Optica`Optica`RayEnd :> {3.3955428969268873`, -0.17104557766406175`, 
       0.}, RotationMatrix :> {{-0.61470318507497, -0.7887585145395806, 0.}, {
       0.7887585145395806, -0.61470318507497, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01002689046088073, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30757437890100103`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      22.984666467646385`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38300220241527305`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.61470318507497, -0.7887585145395806, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.6188993657553175`, -2.610571620417632, 0.}, 
      Optica`Optica`RayEnd :> {6.621906511845788, -2.650963131536688, 0.}, 
      RotationMatrix :> {{0.07424447601816592, -0.9972400702843758, 0.}, {
       0.9972400702843758, 0.07424447601816592, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011034430015720277`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04050329737305689, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.324712196631815`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.35411333357890334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.07424447601816592, -0.9972400702843758, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.621906511845788, -2.650963131536688, 0.}, 
      Optica`Optica`RayEnd :> {6.617583509206603, -2.8749985982825743`, 0.}, 
      RotationMatrix :> {{-0.01929247238127947, -0.9998138829349272, 0.}, {
       0.9998138829349272, -0.01929247238127947, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010937699242241987`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22407717133136384`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.62497560621584, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.34023206852003335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 149, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.01929247238127947, -0.9998138829349272, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.8747270856212968`, -3.114781565921408, 0.}, 
      Optica`Optica`RayEnd :> {2.838082340362363, -3.148877303266252, 0.}, 
      RotationMatrix :> {{-0.7321109909116376, -0.6811853616941423, 0.}, {
       0.6811853616941423, -0.7321109909116376, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16067222851916274`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.050053537938698406`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.19446859981927, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.05308530712476637, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 66, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7321109909116376, -0.6811853616941423, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.838082340362363, -3.148877303266252, 0.}, 
      Optica`Optica`RayEnd :> {2.6159504524003254`, -3.3632753449875312`, 0.},
       RotationMatrix :> {{-0.7195214290559875, -0.6944702391962013, 0.}, {
       0.6944702391962013, -0.7195214290559875, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1602489253146359, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30872171278272376`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.651376734737703`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2800639917920772, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7195214290559875, -0.6944702391962013, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.4233374609525127`, -0.41594306614899723`, 
       0.}, Optica`Optica`RayEnd :> {
       2.3635825394116026`, -0.40722552239788085`, 0.}, 
      RotationMatrix :> {{-0.9895252132034068, 0.1443601483607946, 
       0.}, {-0.1443601483607946, -0.9895252132034068, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05741178335929856, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.060387467386975056`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.238215826253974`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0580364575598141, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9895252132034068, 0.1443601483607946, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3635825394116026`, -0.40722552239788085`, 
       0.}, Optica`Optica`RayEnd :> {2.1264231119612176`, -0.3502980429841255,
        0.}, RotationMatrix :> {{-0.9723787256901998, 0.23340868412529453`, 
       0.}, {-0.23340868412529453`, -0.9723787256901998, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.056936823920177744`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.24389614991015712`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.599182128121008`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22183916443517607`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9723787256901998, 0.23340868412529453`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5187321549010875`, -3.6092674409253935`, 
       0.}, Optica`Optica`RayEnd :> {3.66216580349884, -3.929519671680314, 
       0.}, RotationMatrix :> {{0.40875286771613195`, -0.9126451079876765, 
       0.}, {0.9126451079876765, 0.40875286771613195`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012338666217850892`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.35090554691193826`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.17055715141539, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.12646324090103922`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.40875286771613195`, -0.9126451079876765, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.66216580349884, -3.929519671680314, 0.}, 
      Optica`Optica`RayEnd :> {3.70053918451893, -4.096874564738043, 0.}, 
      RotationMatrix :> {{0.2234935662269396, -0.9747054046506379, 0.}, {
       0.9747054046506379, 0.2234935662269396, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01161965895953892, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1716979225304628, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.424670076760474`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3245871373119852, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2234935662269396, -0.9747054046506379, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.19117527744928, -3.3256825326061277`, 0.}, 
      Optica`Optica`RayEnd :> {2.2006771023350336`, -3.5480932227332427`, 0.},
       RotationMatrix :> {{0.04268304514085796, -0.9990886635616995, 0.}, {
       0.9990886635616995, 0.04268304514085796, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03882759039720142, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.22261356598145401`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.48888006770129, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2868811053978894, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.04268304514085796, -0.9990886635616995, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2006771023350336`, -3.5480932227332427`, 
       0.}, Optica`Optica`RayEnd :> {
       2.2155922311191225`, -3.8656354417860164`, 0.}, 
      RotationMatrix :> {{0.04691880937993223, -0.9988987062392106, 0.}, {
       0.9988987062392106, 0.04691880937993223, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03873154493018055, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.31789231187244127`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.959360689272504`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.24723282588573392`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.04691880937993223, -0.9988987062392106, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.195899279209828, -3.8980626220087173`, 0.}, 
      Optica`Optica`RayEnd :> {8.216390756546161, -4.098432075737106, 0.}, 
      RotationMatrix :> {{0.10173782342183363`, -0.994811246058963, 0.}, {
       0.994811246058963, 0.10173782342183363`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05682879177748452, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20141454423858904`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.722639611354, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3942748534064837, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.10173782342183363`, -0.994811246058963, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.216390756546161, -4.098432075737106, 0.}, 
      Optica`Optica`RayEnd :> {8.2637206997027, -4.46240798472222, 0.}, 
      RotationMatrix :> {{0.1289502609140301, -0.9916510627283179, 0.}, {
       0.9916510627283179, 0.1289502609140301, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.05666664760788331, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.36704030547167527`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 28.265859263452082`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.30252411739668295`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.1289502609140301, -0.9916510627283179, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.3955428969268873`, -0.17104557766406175`, 
       0.}, Optica`Optica`RayEnd :> {3.386058930047751, -0.1823967932116381, 
       0.}, RotationMatrix :> {{-0.6411661933871448, -0.7674020539830716, 
       0.}, {0.7674020539830716, -0.6411661933871448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009996055992443423, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.01479174506852015, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.0044874060382, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17900719592525277`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6411661933871448, -0.7674020539830716, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.386058930047751, -0.1823967932116381, 0.}, 
      Optica`Optica`RayEnd :> {3.1814876357625916`, -0.4182253843986803, 0.}, 
      RotationMatrix :> {{-0.6552716467816868, -0.7553933206773905, 0.}, {
       0.7553933206773905, -0.6552716467816868, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009969678396836617, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3121931114979483, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.466533211055165`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4290225989925714, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6552716467816868, -0.7553933206773905, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.617583509206603, -2.8749985982825743`, 0.}, 
      Optica`Optica`RayEnd :> {6.610183188278267, -2.940267322267495, 0.}, 
      RotationMatrix :> {{-0.11266050003604926`, -0.9936335399590868, 0.}, {
       0.9936335399590868, -0.11266050003604926`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010841816436671809`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.06568691711796264, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.722192243550428`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.20963158119651631`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.11266050003604926`, -0.9936335399590868, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.610183188278267, -2.940267322267495, 0.}, 
      Optica`Optica`RayEnd :> {6.612659338632755, -3.1199280820686464`, 0.}, 
      RotationMatrix :> {{0.01378105722069417, -0.9999050367219273, 0.}, {
       0.9999050367219273, 0.01378105722069417, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010658158601366319`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1796778225961824, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.962960525829313`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.22206210369223883`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 152, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.01378105722069417, -0.9999050367219273, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6159504524003254`, -3.3632753449875312`, 
       0.}, Optica`Optica`RayEnd :> {2.610911570792706, -3.368320156404455, 
       0.}, RotationMatrix :> {{-0.7066908382871107, -0.7075224795588196, 
       0.}, {0.7075224795588196, -0.7066908382871107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15982673733459185`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.007130248949926514, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.660931268330604`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.012636102533284711`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 68, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7066908382871107, -0.7075224795588196, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.610911570792706, -3.368320156404455, 0.}, 
      Optica`Optica`RayEnd :> {2.3994172582498967`, -3.5898937933800235`, 0.},
       RotationMatrix :> {{-0.6904624301354393, -0.7233682551587837, 0.}, {
       0.7233682551587837, -0.6904624301354393, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15939074054648214`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.30630821216633514`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.11426742233678, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2804256705620147, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6904624301354393, -0.7233682551587837, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1264231119612176`, -0.3502980429841255, 0.},
       Optica`Optica`RayEnd :> {2.1230759113004076`, -0.3491653743978561, 0.},
       RotationMatrix :> {{-0.9472357419411566, 0.32053775002202933`, 
       0.}, {-0.32053775002202933`, -0.9472357419411566, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05646579375229029, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.00353365114153173, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.60391722065066, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.172413112160577, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9472357419411566, 0.32053775002202933`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1230759113004076`, -0.3491653743978561, 0.},
       Optica`Optica`RayEnd :> {1.9247809079917395`, -0.31161928865510713`, 
       0.}, RotationMatrix :> {{-0.9825423462748508, 0.1860390759402695, 
       0.}, {-0.1860390759402695, -0.9825423462748508, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.05524930315696491, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2018182769022334, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.902608270465965`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.42735517669316475`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9825423462748508, 0.1860390759402695, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.70053918451893, -4.096874564738043, 0.}, 
      Optica`Optica`RayEnd :> {3.702257626811304, -4.154703283557864, 0.}, 
      RotationMatrix :> {{0.029702958992410794`, -0.9995587697714899, 0.}, {
       0.9995587697714899, 0.029702958992410794`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010942550187528316`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.057854245861943134`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.502194766215478`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4277373432728242, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.029702958992410794`, -0.9995587697714899, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.702257626811304, -4.154703283557864, 0.}, 
      Optica`Optica`RayEnd :> {3.7259065841173045`, -4.4409374302681215`, 0.},
       RotationMatrix :> {{0.08234046090002008, -0.9966042587199653, 0.}, {
       0.9966042587199653, 0.08234046090002008, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010898277795699938`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.28720943564689916`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.92726473097289, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3926129050315694, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.08234046090002008, -0.9966042587199653, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2155922311191225`, -3.8656354417860164`, 
       0.}, Optica`Optica`RayEnd :> {2.228243500126284, -4.112630251758305, 
       0.}, RotationMatrix :> {{0.05115373012285755, -0.9986907909330681, 
       0.}, {0.9986907909330681, 0.05115373012285755, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03863573704503487, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2473186017280919, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.29076761558815, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.17792486185203377`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.05115373012285755, -0.9986907909330681, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.228243500126284, -4.112630251758305, 0.}, 
      Optica`Optica`RayEnd :> {2.2382741906794665`, -4.436492633377812, 0.}, 
      RotationMatrix :> {{0.030957232185027946`, -0.9995207100282824, 0.}, {
       0.9995207100282824, 0.030957232185027946`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03853247656745058, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.32401768004421155`, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 26.77031378205358, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.14866682894303845`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.030957232185027946`, -0.9995207100282824, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1814876357625916`, -0.4182253843986803, 0.},
       Optica`Optica`RayEnd :> {3.157010076547749, -0.4454088774003837, 0.}, 
      RotationMatrix :> {{-0.6691522283175975, -0.7431253564087237, 0.}, {
       0.7431253564087237, -0.6691522283175975, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009943370406437158, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.03657995621771289, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.5155503523869, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.4060314464392026, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6691522283175975, -0.7431253564087237, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.157010076547749, -0.4454088774003837, 0.}, 
      Optica`Optica`RayEnd :> {2.9759563094528474`, -0.6156758306537146, 0.}, 
      RotationMatrix :> {{-0.7284742212831304, -0.6850732142814631, 0.}, {
       0.6850732142814631, -0.7284742212831304, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00987278893074765, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.2485383309460066, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      23.88338708218699, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.31614512115921656`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7284742212831304, -0.6850732142814631, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.612659338632755, -3.1199280820686464`, 0.}, 
      Optica`Optica`RayEnd :> {6.613883624297096, -3.128586745291935, 0.}, 
      RotationMatrix :> {{0.14000174824234501`, -0.9901512563689883, 0.}, {
       0.9901512563689883, 0.14000174824234501`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010477611886846358`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.008744788402371181, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 23.975902812664824`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.3052607049325559, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 69, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.14000174824234501`, -0.9901512563689883, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.613883624297096, -3.128586745291935, 0.}, 
      Optica`Optica`RayEnd :> {6.620701540397806, -3.3381284650382446`, 0.}, 
      RotationMatrix :> {{0.03252006329007291, -0.9994710828651365, 0.}, {
       0.9994710828651365, 0.03252006329007291, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010355146338043755`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.20965260860336837`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.256837308193337`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3303573046106641, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 155, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.03252006329007291, -0.9994710828651365, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3994172582498967`, -3.5898937933800235`, 
       0.}, Optica`Optica`RayEnd :> {2.357224672434786, -3.6361538172685215`, 
       0.}, RotationMatrix :> {{-0.6738788137001575, -0.7388418940788807, 
       0.}, {0.7388418940788807, -0.6738788137001575, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1589559331288271, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.06261153334594119, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.19816687702034, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.27763954744520747`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 70, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.6738788137001575, -0.7388418940788807, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.357224672434786, -3.6361538172685215`, 0.}, 
      Optica`Optica`RayEnd :> {2.1468082288758534`, -3.850481151304229, 0.}, 
      RotationMatrix :> {{-0.7005662954026965, -0.7135873217383709, 0.}, {
       0.7135873217383709, -0.7005662954026965, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.158449817778772, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3003519366257575, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.642687743226464`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.41064915223056064`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7005662954026965, -0.7135873217383709, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.9759563094528474`, -0.6156758306537146, 0.},
       Optica`Optica`RayEnd :> {2.898480630675166, -0.6772683293156354, 0.}, 
      RotationMatrix :> {{-0.7827776460270708, -0.6223014999823773, 0.}, {
       0.6223014999823773, -0.7827776460270708, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009802708466737973, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.09897533376291887, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.0160140294293, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.17159938694065677`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7827776460270708, -0.6223014999823773, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.898480630675166, -0.6772683293156354, 0.}, 
      Optica`Optica`RayEnd :> {2.672209777524318, -0.858033741578869, 0.}, 
      RotationMatrix :> {{-0.781291855813466, -0.6241658722163116, 0.}, {
       0.6241658722163116, -0.781291855813466, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009778520280707782, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.28961117598654496`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.444638569889385`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3030904231795021, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.781291855813466, -0.6241658722163116, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.620701540397806, -3.3381284650382446`, 0.}, 
      Optica`Optica`RayEnd :> {6.617152559466575, -3.3851007019041273`, 0.}, 
      RotationMatrix :> {{-0.07534012826467568, -0.9971578937525698, 0.}, {
       0.9971578937525698, -0.07534012826467568, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010234112204224405`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.04710611745659842, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.326554362029103`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.25826422386070913`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {-0.07534012826467568, -0.9971578937525698, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.617152559466575, -3.3851007019041273`, 0.}, 
      Optica`Optica`RayEnd :> {6.630213745123582, -3.5013041336861583`, 0.}, 
      RotationMatrix :> {{0.11169596403364497`, -0.9937424272006272, 0.}, {
       0.9937424272006272, 0.11169596403364497`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009714020314729989, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.11693516207149965`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.483247479204913`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.3468634411272914, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 158, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.11169596403364497`, -0.9937424272006272, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1468082288758534`, -3.850481151304229, 0.}, 
      Optica`Optica`RayEnd :> {2.132850973422473, -3.8636901345735404`, 0.}, 
      RotationMatrix :> {{-0.7263080020252727, -0.6873693957356961, 0.}, {
       0.6873693957356961, -0.7263080020252727, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15794531389890568`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.019216717170210514`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.668438144234546`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.09268786602930476, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7263080020252727, -0.6873693957356961, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.132850973422473, -3.8636901345735404`, 0.}, 
      Optica`Optica`RayEnd :> {1.892191514199834, -4.095942514368096, 0.}, 
      RotationMatrix :> {{-0.7195635130637594, -0.6944266344743268, 0.}, {
       0.6944266344743268, -0.7195635130637594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1575484884853253, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3344520043796531, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.163427110716434`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.312254300389684, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7195635130637594, -0.6944266344743268, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.672209777524318, -0.858033741578869, 0.}, 
      Optica`Optica`RayEnd :> {2.6138631964053385`, -0.9048745229806487, 0.}, 
      RotationMatrix :> {{-0.7798016251616744, -0.6260266970307338, 0.}, {
       0.6260266970307338, -0.7798016251616744, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00975439177903375, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.07482233844650261, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.5449005034077, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.126952719383921, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7798016251616744, -0.6260266970307338, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.6138631964053385`, -0.9048745229806487, 0.},
       Optica`Optica`RayEnd :> {2.3384123243514687`, -1.1309549887150265`, 
       0.}, RotationMatrix :> {{-0.7729777313692627, -0.6344331539313078, 
       0.}, {0.6344331539313078, -0.7729777313692627, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00972977672635962, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.35635033310200576`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.07229899639867, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2757111782404823, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 74, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7729777313692627, -0.6344331539313078, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.630213745123582, -3.5013041336861583`, 0.}, 
      Optica`Optica`RayEnd :> {6.660778854575984, -3.600368690908474, 0.}, 
      RotationMatrix :> {{0.29482334931060206`, -0.9555517739511962, 0.}, {
       0.9555517739511962, 0.29482334931060206`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009220359205758574, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.1036726213302759, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 24.636682958773722`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.4086059073685644, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.29482334931060206`, -0.9555517739511962, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.660778854575984, -3.600368690908474, 0.}, 
      Optica`Optica`RayEnd :> {6.757251316699107, -3.9294027223609964`, 0.}, 
      RotationMatrix :> {{0.28135490724177614`, -0.959603780823612, 0.}, {
       0.959603780823612, 0.28135490724177614`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009196715279504124, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.3428853012335131, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.09614926242663, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.1883100385791175, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 161, 
      Optica`Optica`IntersectionNumber :> 74, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.28135490724177614`, -0.959603780823612, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3384123243514687`, -1.1309549887150265`, 
       0.}, Optica`Optica`RayEnd :> {2.315348086617261, -1.1503070340854382`, 
       0.}, RotationMatrix :> {{-0.766063218271388, -0.642765233667536, 0.}, {
       0.642765233667536, -0.766063218271388, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009705223789379826, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.030107486150100924`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.112643027839805`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.0030064386410880847`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 75, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.766063218271388, -0.642765233667536, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.315348086617261, -1.1503070340854382`, 0.}, 
      Optica`Optica`RayEnd :> {2.0918985495275626`, -1.3514712695253897`, 0.},
       RotationMatrix :> {{-0.743195484555467, -0.669074339469362, 0.}, {
       0.669074339469362, -0.743195484555467, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009675060194578883, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.300660514942918, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      25.557620589955324`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.20054877422355855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 76, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.743195484555467, -0.669074339469362, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.757251316699107, -3.9294027223609964`, 0.}, 
      Optica`Optica`RayEnd :> {6.818098322848967, -4.148287247464208, 0.}, 
      RotationMatrix :> {{0.2678308081947124, -0.9634659610913954, 0.}, {
       0.9634659610913954, 0.2678308081947124, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.009173131983777866, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.2271844921799449, Optica`Optica`RefractiveIndex :> 1.48, 
      Optica`Optica`OpticalLength :> 25.432382310852947`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.11593954711943455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 75, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.2678308081947124, -0.9634659610913954, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.818098322848967, -4.148287247464208, 0.}, 
      Optica`Optica`RayEnd :> {6.866441308379045, -4.240348940993934, 0.}, 
      RotationMatrix :> {{0.4649137839635013, -0.8853559586294869, 0.}, {
       0.8853559586294869, 0.4649137839635013, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008477358699008812, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.10398268925894594`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.571719114459935`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 1, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.38957594090948744`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 164, 
      Optica`Optica`IntersectionNumber :> 76, 
      Optica`Optica`Polarization :> {0., 1., -116.97237085078373`}, 
      Optica`Optica`RayTilt :> {0.4649137839635013, -0.8853559586294869, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0918985495275626`, -1.3514712695253897`, 
       0.}, Optica`Optica`RayEnd :> {2.083749471856234, -1.3593388178846615`, 
       0.}, RotationMatrix :> {{-0.7194246923018226, -0.6945704515068478, 
       0.}, {0.6945704515068478, -0.7194246923018226, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009644990347482377, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.011327214312390366`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.572799057133928`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {0.049425584288464094`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 167, 
      Optica`Optica`IntersectionNumber :> 77, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.7194246923018226, -0.6945704515068478, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.083749471856234, -1.3593388178846615`, 0.}, 
      Optica`Optica`RayEnd :> {1.8626583431103891`, -1.5802739192837725`, 0.},
       RotationMatrix :> {{-0.7073563331557031, -0.7068571411144662, 0.}, {
       0.7068571411144662, -0.7073563331557031, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009619770402865472, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.3125597642697271, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      26.035387508253123`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 1, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 76359, 
      Optica`Optica`SurfaceCoordinates :> {-0.2912925483439838, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 167, 
      Optica`Optica`IntersectionNumber :> 78, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7073563331557031, -0.7068571411144662, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7667114977152143`, 0., 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, 0.2310098625111181, 0.}, 
      RotationMatrix :> {{-0.975145483966289, 0.22156553229271028`, 
       0.}, {-0.22156553229271028`, -0.975145483966289, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.25210800679539547`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0426254486457347`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      6.4445115081236715`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.6310098625111181, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 2, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.975145483966289, 0.22156553229271028`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7737198649463215`, -0.07722951543100699, 
       0.}, Optica`Optica`RayEnd :> {0.75, -0.2645718457173044, 0.}, 
      RotationMatrix :> {{-0.9836643929276236, -0.18001211649866722`, 0.}, {
       0.18001211649866722`, -0.9836643929276236, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2508384402129281, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.0407206688650008`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 7.579050002408071, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.13542815428269564`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 4, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9836643929276236, -0.18001211649866722`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7672930323709903`, 0.004669646611714488, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, 
       0.011079305361220593`, 0.}, 
      RotationMatrix :> {{-0.999980151177387, 0.006300575469771955, 
       0.}, {-0.006300575469771955, -0.999980151177387, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24399111906604629`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0173132248407322`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      7.983874433669025, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.4110793053612206, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 6, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.999980151177387, 0.006300575469771955, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7661119968940817`, -0.006264234149068747, 
       0.}, Optica`Optica`RayEnd :> {0.75, -0.008397797803824991, 0.}, 
      RotationMatrix :> {{-0.999997795568443, -0.002099728138219784, 0.}, {
       0.002099728138219784, -0.999997795568443, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24281264740012035`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0161142368483709`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.005136127759545, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.39160220219617503`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.999997795568443, -0.002099728138219784, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3675489352810515`, 0.11310424430511475`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, 0.35379247403818237`,
        0.}, RotationMatrix :> {{-0.9891100652716592, 0.14717771155407428`, 
       0.}, {-0.14717771155407428`, -0.9891100652716592, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24931985845250892`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.635357875806058, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      9.58874427924843, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.7537924740381824, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 8, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9891100652716592, 0.14717771155407428`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.850524420653777, -0.5013247962187429, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, -0.928706845010267, 0.}, 
      RotationMatrix :> {{-0.9321761494491662, -0.36200500880253805`, 0.}, {
       0.36200500880253805`, -0.9321761494491662, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24086346391192495`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1805970591546344`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.789590919019641`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.528706845010267, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 14, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9321761494491662, -0.36200500880253805`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9375366706374482`, 0.3992115048105958, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, 0.5757269206438212, 0.}, 
      RotationMatrix :> {{-0.9891328248659392, 0.14702467402693642`, 
       0.}, {-0.14702467402693642`, -0.9891328248659392, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.23369156789924644`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2005836231331206`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      11.788791002973728`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.9757269206438213, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9891328248659392, 0.14702467402693642`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.842422203976989, -0.4570800530492261, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -0.8587765005445434, 0.}, 
      RotationMatrix :> {{-0.9385588966995021, -0.34511910614484, 0.}, {
       0.34511910614484, -0.9385588966995021, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.24520328198809632`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1639356973958228`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      10.983935067694727`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.4587765005445434, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 16, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9385588966995021, -0.34511910614484, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1679364592479047`, 0.7873630095557195, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.6218552987430191, 0.}, 
      RotationMatrix :> {{-0.9932565429570509, -0.1159372238455268, 0.}, {
       0.1159372238455268, -0.9932565429570509, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06057624519092128, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.427563170161988, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      13.725666916272605`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0218552987430192`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9932565429570509, -0.1159372238455268, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1968282486405424`, -1.5843271908251064`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.088120711125074, 0.}, 
      RotationMatrix :> {{-0.9443855698933966, -0.3288402277354823, 0.}, {
       0.3288402277354823, -0.9443855698933966, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07670595478336543, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.5320312960773654`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 13.470105752895062`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.6881207111250738`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 23, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.9443855698933966, -0.3288402277354823, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9265945208348418`, -0.5911279665573725, 0.},
       Optica`Optica`RayEnd :> {0.75, -2.921154990973647, 0.}, 
      RotationMatrix :> {{-0.45075946980629783`, -0.8926454505457054, 0.}, {
       0.8926454505457054, -0.45075946980629783`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013440267656036283`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.6102491453822436`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.182395620976248`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.5211549909736477`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 27, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.45075946980629783`, -0.8926454505457054, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8849683746156314`, 0.8698811764446064, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.9551550171248132, 0.}, 
      RotationMatrix :> {{-0.9971893926572495, 0.07492206064882145, 
       0.}, {-0.07492206064882145, -0.9971893926572495, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19755853436454543`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1381673160313475`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.046373725498299`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.3551550171248132`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9971893926572495, 0.07492206064882145, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.981736479233178, 2.1791356728325355`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 2.966776391674025, 0.}, 
      RotationMatrix :> {{-0.8424795984752177, 0.5387282488908818, 
       0.}, {-0.5387282488908818, -0.8424795984752177, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.22777152927111408`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4620371596682773`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.078710769148675`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.366776391674025, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8424795984752177, 0.5387282488908818, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0330784063531713`, -2.120040053223454, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, -3.832482196669296, 0.}, 
      RotationMatrix :> {{-0.5996251101343456, -0.8002810301990005, 0.}, {
       0.8002810301990005, -0.5996251101343456, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01238178954365232, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.1398009934335445`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.63521417428526, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.432482196669296, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5996251101343456, -0.8002810301990005, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.871705955361084, -2.579383011099843, 0.}, 
      Optica`Optica`RayEnd :> {1.574703078245685, -5.4, 0.}, 
      RotationMatrix :> {{-0.10471820070317472`, -0.9945019348606058, 0.}, {
       0.9945019348606058, -0.10471820070317472`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.21212186112314835`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      2.836210659857095, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.729315957594864`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {3.675296921754315, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 28, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.10471820070317472`, -0.9945019348606058, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8907195989671668`, 1.684804414747426, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, 4.016141094002052, 0.}, 
      RotationMatrix :> {{-0.4395070795338904, 0.8982391257563824, 
       0.}, {-0.8982391257563824, -0.4395070795338904, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015042604907991313`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.595452160126594, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.630217251128226`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.416141094002052, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4395070795338904, 0.8982391257563824, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8604948557158172`, -0.18781759303254186`, 
       0.}, Optica`Optica`RayEnd :> {0.7500000000000002, -4.038364933774184, 
       0.}, RotationMatrix :> {{-0.2771053739138759, -0.9608395348589956, 
       0.}, {0.9608395348589956, -0.2771053739138759, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01321490144109207, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 4.007482208053308, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.044097261235233`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.638364933774184, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.2771053739138759, -0.9608395348589956, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0670908527082337`, -0.6339946714700225, 0.},
       Optica`Optica`RayEnd :> {0.7500000000000002, -1.147294791143008, 0.}, 
      RotationMatrix :> {{-0.9317420102358133, -0.3631209527990987, 0.}, {
       0.3631209527990987, -0.9317420102358133, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008710703712198769, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.413578907293117, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.498469541383368`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.747294791143008, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 29, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9317420102358133, -0.3631209527990987, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.82287096155126, 1.0079416589077277`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.4930922703543543`, 0.}, 
      RotationMatrix :> {{-0.9111703512953842, 0.4120298422690347, 
       0.}, {-0.4120298422690347, -0.9111703512953842, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21194901949479275`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1774647408423577`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      15.545396600791276`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.8930922703543542`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 30, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9111703512953842, 0.4120298422690347, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.382099314299674, 0.22347529134967298`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.05704594163051452, 0.}, 
      RotationMatrix :> {{0.979613099988907, -0.20089344023666536`, 0.}, {
       0.20089344023666536`, 0.979613099988907, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07180781634103656, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3963683067486694`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.089647249471223`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.34295405836948556`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.979613099988907, -0.20089344023666536`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8528470577585507`, -1.17291256256883, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, -1.6019322081523129`, 0.}, 
      RotationMatrix :> {{-0.931966220804767, -0.36254511895608243`, 0.}, {
       0.36254511895608243`, -0.931966220804767, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.21674958435278577`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1833551829874536`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.56020189987696, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.201932208152313, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.931966220804767, -0.36254511895608243`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.410142819605809, 3.6812770041790377`, 0.}, 
      Optica`Optica`RayEnd :> {6.398097770588954, 4.6, 0.}, 
      RotationMatrix :> {{0.7322994206804064, 0.6809827886746782, 
       0.}, {-0.6809827886746782, 0.7322994206804064, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008724005044455016, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3491133859770106`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.28097047630116, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.1480977705889548`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7322994206804064, 0.6809827886746782, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1531498249152365`, 3.3914826324245704`, 0.},
       Optica`Optica`RayEnd :> {4.096020104562012, 4.6, 0.}, 
      RotationMatrix :> {{0.615123761317455, 0.7884305665451249, 
       0.}, {-0.7884305665451249, 0.615123761317455, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.01863151469667742, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.5328139456478838`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 16.53669590932355, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.1539798954379883`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.615123761317455, 0.7884305665451249, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.841612151678042, -2.4839424729838475`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -3.7999334201003583`, 0.}, 
      RotationMatrix :> {{-0.6384407234914246, -0.7696709963274867, 0.}, {
       0.7696709963274867, -0.6384407234914246, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2503182207593463, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7098097153144776`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.308345555528728`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.3999334201003584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6384407234914246, -0.7696709963274867, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.34571974139002, 2.320663474652185, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.798201103792634, 0.}, 
      RotationMatrix :> {{0.9467558246219879, 0.32195249423531436`, 
       0.}, {-0.32195249423531436`, 0.9467558246219879, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010397071340990218`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4832549450336556`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.845029707383027`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.198201103792634, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 31, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.9467558246219879, 0.32195249423531436`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.371022184652178, -0.3716808198235361, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.4126332128078969, 0.}, 
      RotationMatrix :> {{0.999559316428755, -0.02968455727276835, 0.}, {
       0.02968455727276835, 0.999559316428755, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.5475511541848186`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.379585776134488, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      16.638569464513736`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.012633212807896886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 32, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.999559316428755, -0.02968455727276835, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0921927069666446`, 0.3256054024297014, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.10026814533756578`, 0.}, 
      RotationMatrix :> {{-0.9861980021971971, -0.16557022818809206`, 0.}, {
       0.16557022818809206`, -0.9861980021971971, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.06269067518534704, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3609769072501767`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.04120231669908, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.5002681453375658, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9861980021971971, -0.16557022818809206`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.18705552402088, 0.7293805768078586, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.26803405995480933`, 0.}, 
      RotationMatrix :> {{-0.952137402486927, -0.3056703564061254, 0.}, {
       0.3056703564061254, -0.952137402486927, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010374915291683382`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5092942681039265`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.778959066371865`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.6680340599548094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 33, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.952137402486927, -0.3056703564061254, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.074965366139089, -0.7819802989291605, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, -1.0556499518973506`, 0.}, 
      RotationMatrix :> {{-0.9793279857390603, -0.20227875901407544`, 0.}, {
       0.20227875901407544`, -0.9793279857390603, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009154747018122682, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.352933220977229, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.5110647065028, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.6556499518973503, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9793279857390603, -0.20227875901407544`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.279619357017198, 2.3844659508650694`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 3.4820796197269925`, 0.}, 
      RotationMatrix :> {{0.8013509015041572, 0.5981945608733614, 
       0.}, {-0.5981945608733614, 0.8013509015041572, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      70.51767649597501, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8348773804619884`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.193593049782393`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.8820796197269924`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.8013509015041572, 0.5981945608733614, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.353376858084014, 1.4486758481567938`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 1.475934126222417, 0.}, 
      RotationMatrix :> {{0.9998095923828223, 0.019513558857732094`, 
       0.}, {-0.019513558857732094`, 0.9998095923828223, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0875835243348965, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3968891202448335`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.66985961631749, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-1.875934126222417, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9998095923828223, 0.019513558857732094`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.471556087494077, 1.3036155224815655`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.1488836651565428`, 0.}, 
      RotationMatrix :> {{0.462247415586626, -0.8867509948026473, 0.}, {
       0.8867509948026473, 0.462247415586626, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.1653661208978088`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.765713488919095, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.78100183499799, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.7488836651565429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.462247415586626, -0.8867509948026473, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.18182694304322, 0.5465277883779298, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.3682938018806834, 0.}, 
      RotationMatrix :> {{0.8637659614480736, -0.5038932067846161, 0.}, {
       0.5038932067846161, 0.8637659614480736, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08025236492921935, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8155068930104539`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.997602950225513`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.03170619811931663, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8637659614480736, -0.5038932067846161, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.40513098295746, -1.2478631540215561`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.0051899138897755`, 0.}, 
      RotationMatrix :> {{0.9841070903929416, 0.17757599679669042`, 
       0.}, {-0.17757599679669042`, 0.9841070903929416, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010862216620351466`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3665880778336341`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.623015065322136`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.6051899138897753, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9841070903929416, 0.17757599679669042`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8631456608056345`, -1.9991716919118454`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.54891212154094, 0.}, 
      RotationMatrix :> {{-0.8966177027608964, -0.442805482233195, 0.}, {
       0.442805482233195, -0.8966177027608964, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16858614175314884`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2414941812748035`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.546817502901217`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.14891212154094, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8966177027608964, -0.442805482233195, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0003485458539485`, 3.6568472194308046`, 0.},
       Optica`Optica`RayEnd :> {1.8899101609401012`, 4.6, 0.}, 
      RotationMatrix :> {{-0.11630030972161609`, 0.9932140947241214, 
       0.}, {-0.9932140947241214, -0.11630030972161609`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013624201370336193`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9495966535102065, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      17.69253859306236, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.3600898390598988`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 34, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.11630030972161609`, 0.9932140947241214, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.347403889598631, 0.3164039243675053, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.3150971450631865`, 0.}, 
      RotationMatrix :> {{0.5744269500724504, 0.8185558496709079, 
       0.}, {-0.8185558496709079, 0.5744269500724504, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09730877095902937, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.441731033379378, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.889567265264755`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-2.7150971450631864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {0.5744269500724504, 0.8185558496709079, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.33682100981092, -2.372116296911316, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -3.3637609551454264`, 0.}, 
      RotationMatrix :> {{0.8185730054687448, -0.5744025023603798, 0.}, {
       0.5744025023603798, 0.8185730054687448, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      5.069397672552881, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.726393346406337, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.215547721415845`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.9637609551454265`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.8185730054687448, -0.5744025023603798, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.311903601845028, -1.6379705011059962`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 1.2905317992727268`, 0.}, 
      RotationMatrix :> {{0.44078877583012166`, 0.897610859505489, 
       0.}, {-0.897610859505489, 0.44078877583012166`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.042739110560332604`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.2625522177751844`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.538205844867377`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-1.6905317992727267`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.44078877583012166`, 0.897610859505489, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.336491908698271, -1.3533739219868754`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -5.137849265650147, 0.}, 
      RotationMatrix :> {{0.34989261716047115`, -0.9367898144496426, 0.}, {
       0.9367898144496426, 0.34989261716047115`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035978520662323245`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 4.039834000422627, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.32334829270187, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {4.737849265650146, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 35, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.34989261716047115`, -0.9367898144496426, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.468165047516123, 1.3220799330813995`, 0.}, 
      Optica`Optica`RayEnd :> {9.547044756836728, 4.6, 0.}, 
      RotationMatrix :> {{0.3126367973598252, 0.9498727456541696, 
       0.}, {-0.9498727456541696, 0.3126367973598252, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11722278060440564`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.4509044310573644`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.776044930720317`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {4.297044756836728, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.3126367973598252, 0.9498727456541696, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.454284569695465, -0.7830988991393053, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.9427746248001707`, 0.}, 
      RotationMatrix :> {{0.5144694780422894, -0.8575086915961223, 0.}, {
       0.8575086915961223, 0.5144694780422894, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2847796251139698, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.51854674690347, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.914811541821898`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.542774624800171, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 36, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5144694780422894, -0.8575086915961223, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.192257270270463, 1.011642970905468, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 1.6024250208275874`, 0.}, 
      RotationMatrix :> {{0.9350146191117992, 0.3546091680247656, 
       0.}, {-0.3546091680247656, 0.9350146191117992, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08034998488806841, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6660089563190854`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.216500101997912`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-2.0024250208275873`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9350146191117992, 0.3546091680247656, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.822712616640818, -1.146059333803818, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -1.338546865179533, 0.}, 
      RotationMatrix :> {{-0.9842792840960521, -0.1766190558783587, 0.}, {
       0.1766190558783587, -0.9842792840960521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013809689753066571`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.089845772407962, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.635109667202105`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9385468651795329, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9842792840960521, -0.1766190558783587, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.11164321715692, -2.5383145838870496`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.2312511425493917`, 0.}, 
      RotationMatrix :> {{0.9828861427390129, 0.1842140885264334, 
       0.}, {-0.1842140885264334, 0.9828861427390129, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08938541161846728, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.666883590684739, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.530901943719563`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {1.8312511425493918`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 37, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9828861427390129, 0.1842140885264334, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.45538678793015, -0.7653751126454883, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.3727948734462406, 0.}, 
      RotationMatrix :> {{0.7510269268530875, 0.6602715768088212, 
       0.}, {-0.6602715768088212, 0.7510269268530875, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013134417381011775`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7237906735174837`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.80110313134888, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.7727948734462406, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7510269268530875, 0.6602715768088212, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.367052651840087, 0.14943348693084343`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.4050411595395943, 0.}, 
      RotationMatrix :> {{0.9833447978616546, 0.1817498514949073, 
       0.}, {-0.1817498514949073, 0.9833447978616546, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.020847260454136658`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4063707370672207`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.87972972768948, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.8050411595395943, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9833447978616546, 0.1817498514949073, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.295863451371103, 3.872524143458744, 0.}, 
      Optica`Optica`RayEnd :> {7.453531826332829, 4.6, 0.}, 
      RotationMatrix :> {{0.21181571721944217`, 0.9773096243969014, 
       0.}, {-0.9773096243969014, 0.21181571721944217`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.17658619051611493`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7443657960394909, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.202089699293495`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.2035318263328287`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.21181571721944217`, 0.9773096243969014, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.825246023854241, 3.9303156676656474`, 0.}, 
      Optica`Optica`RayEnd :> {6.28487639933107, 4.6, 0.}, 
      RotationMatrix :> {{0.56587856022159, 0.8244886021538074, 
       0.}, {-0.8244886021538074, 0.56587856022159, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.00942103932641719, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8122420741595927, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.673082360293456`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.0348763993310697`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.56587856022159, 0.8244886021538074, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.43413732121714, -0.8473346537407715, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.949015893495694, 0.}, 
      RotationMatrix :> {{0.7667494230058054, -0.6419465104821925, 0.}, {
       0.6419465104821925, 0.7667494230058054, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009086340261723959, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7161573772360004`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.628107972991387`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {1.5490158934956941`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.7667494230058054, -0.6419465104821925, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.942088537623861, 3.6182506337634655`, 0.}, 
      Optica`Optica`RayEnd :> {7.184896479020065, 4.6, 0.}, 
      RotationMatrix :> {{0.24008784749924422`, 0.9707511655842491, 
       0.}, {-0.9707511655842491, 0.24008784749924422`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      3.7198225580499793`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0113295775912512`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      17.478426209328894`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.9348964790200647`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 40, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.24008784749924422`, 0.9707511655842491, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.469682112473555, 1.3151141464055818`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.8473077115705722, 0.}, 
      RotationMatrix :> {{0.9392654024444569, -0.34319164292105236`, 0.}, {
       0.34319164292105236`, 0.9392654024444569, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.17255297843795475`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3631055548244315`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.56677081649764, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-1.2473077115705722`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9392654024444569, -0.34319164292105236`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.114318319292503, -4.651750633423436, 0.}, 
      Optica`Optica`RayEnd :> {7.424573157315425, -5.4, 0.}, 
      RotationMatrix :> {{0.3830203958736288, -0.923739885652237, 0.}, {
       0.923739885652237, 0.3830203958736288, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017394438873931734`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8100217152020427, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.106025262609908`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-2.1745731573154248`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 38, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.3830203958736288, -0.923739885652237, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8170903467914052`, 1.5473035894966969`, 0.},
       Optica`Optica`RayEnd :> {0.7499999999999998, 0.8961459321822772, 0.}, 
      RotationMatrix :> {{-0.853620897039725, -0.5208947726144848, 0.}, {
       0.5208947726144848, -0.853620897039725, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008453759448249396, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2500752388934857`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.00987785894462, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.2961459321822772`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.853620897039725, -0.5208947726144848, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.779063316539821, -0.9682283827490923, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -0.9106411150436824, 0.}, 
      RotationMatrix :> {{-0.998437859165306, 0.05587344078720141, 
       0.}, {-0.05587344078720141, -0.998437859165306, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01299763426657872, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0306733735038034`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.948103974035543`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.5106411150436824, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {-0.998437859165306, 0.05587344078720141, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.397117182488653, -0.1252058009954891, 0.}, 
      Optica`Optica`RayEnd :> {9.582253220006294, 4.6, 0.}, 
      RotationMatrix :> {{0.2432763892390465, 0.9699570085518285, 
       0.}, {-0.9699570085518285, 0.2432763892390465, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02090861580665654, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 4.871562099489694, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.17934956702325, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {4.332253220006295, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.2432763892390465, 0.9699570085518285, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8258596958523285`, 1.0332433360189008`, 0.},
       Optica`Optica`RayEnd :> {0.75, 1.6060528093408535`, 0.}, 
      RotationMatrix :> {{-0.88268738076641, 0.46996062370770425`, 
       0.}, {-0.46996062370770425`, -0.88268738076641, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10706041730862778`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.218845674352105, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.105935181631743`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.0060528093408534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.88268738076641, 0.46996062370770425`, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.996997111901896, 3.6103894700818837`, 0.}, 
      Optica`Optica`RayEnd :> {7.002175056042999, 4.6, 0.}, 
      RotationMatrix :> {{0.005232233396563521, 0.999986311773158, 
       0.}, {-0.999986311773158, 0.005232233396563521, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015718216196931555`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9896240761169579, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.888435179989987`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.7521750560429985`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 39, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.005232233396563521, 0.999986311773158, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.576370351743306, 3.840641917987641, 0.}, 
      Optica`Optica`RayEnd :> {6.703907454306172, 4.6, 0.}, 
      RotationMatrix :> {{0.1656339403839987, 0.9861873036055926, 
       0.}, {-0.9861873036055926, 0.1656339403839987, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07710030357132663, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.769993772213528, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.104241775163672`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.453907454306172, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.1656339403839987, 0.9861873036055926, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.5651883069599, 3.6848540105536114`, 0.}, 
      Optica`Optica`RayEnd :> {4.214078151596347, 4.6, 0.}, 
      RotationMatrix :> {{-0.3582065771888677, 0.9336423555401903, 
       0.}, {-0.9336423555401903, -0.3582065771888677, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.41562285305397206`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9801890242189144, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.033110112721673`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.0359218484036534`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.3582065771888677, 0.9336423555401903, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.1726285273595956`, 3.9255726373682482`, 0.},
       Optica`Optica`RayEnd :> {5.063450928584296, 4.6, 0.}, 
      RotationMatrix :> {{-0.15980160351837713`, 0.9871491516042318, 
       0.}, {-0.9871491516042318, -0.15980160351837713`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.015482629958930077`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.6832071541931921, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.069448958282116`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-0.18654907141570376`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.15980160351837713`, 0.9871491516042318, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.557058154927904, 3.6857111952687807`, 0.}, 
      Optica`Optica`RayEnd :> {4.299288985045942, 4.6, 0.}, 
      RotationMatrix :> {{-0.27135566847152126`, 0.962479143248503, 
       0.}, {-0.962479143248503, -0.27135566847152126`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.014867180537842278`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9499310308640709, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.238980201547975`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-0.9507110149540575, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.27135566847152126`, 0.962479143248503, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.000414990405947, -4.159206389957394, 0.}, 
      Optica`Optica`RayEnd :> {5.598862526758939, -5.4, 0.}, 
      RotationMatrix :> {{0.43442155136600263`, -0.9007096733735876, 0.}, {
       0.9007096733735876, 0.43442155136600263`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.02287202886569785, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3775733143791409`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.028446222305977`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.34886252675893925`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.43442155136600263`, -0.9007096733735876, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.021738605429321, 3.6895005923389186`, 0.}, 
      Optica`Optica`RayEnd :> {4.2565580051618515`, 4.6, 0.}, 
      RotationMatrix :> {{0.24973025720164188`, 0.9683154437671654, 
       0.}, {-0.9683154437671654, 0.24973025720164188`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00842876023869091, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9402921470702206, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.071058417516316`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-0.9934419948381489, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.24973025720164188`, 0.9683154437671654, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.11741073100309, 3.1862318942371473`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 4.48138308290737, 0.}, 
      RotationMatrix :> {{-0.726029702546548, 0.6876633413380207, 
       0.}, {-0.6876633413380207, -0.726029702546548, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.3528603025861492, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.883408800228006, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.49883832773273, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.88138308290737, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.726029702546548, 0.6876633413380207, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.28456357642351, 1.882574819793523, 0.}, 
      Optica`Optica`RayEnd :> {9.095478664054873, 4.6, 0.}, 
      RotationMatrix :> {{0.28595244117731566`, 0.9582438110338791, 
       0.}, {-0.9582438110338791, 0.28595244117731566`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.018253914323597284`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.8358390097761865`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.844835979181813`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {3.8454786640548724`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.28595244117731566`, 0.9582438110338791, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.893635248830319, 3.7624543145467406`, 0.}, 
      Optica`Optica`RayEnd :> {6.92910395054671, 4.6, 0.}, 
      RotationMatrix :> {{0.042310456043945954`, 0.9991045117050336, 
       0.}, {-0.9991045117050336, 0.042310456043945954`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008202692387136062, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8382963700403432, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.070291250097718`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.6791039505467102`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348775`*^-15}, 
      Optica`Optica`RayTilt :> {0.042310456043945954`, 0.9991045117050336, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.057522303906609, 3.7785231599775653`, 0.}, 
      Optica`Optica`RayEnd :> {2.151173025599504, 4.6, 0.}, 
      RotationMatrix :> {{-0.7409471642748673, 0.6715633251995166, 
       0.}, {-0.6715633251995166, -0.7409471642748673, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009085943876305364, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.22323064586408, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.741607696273213`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.098826974400496, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 41, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534872*^-15}, 
      Optica`Optica`RayTilt :> {-0.7409471642748673, 0.6715633251995166, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.393442965850957, -2.303851857405552, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -4.986211477490428, 0.}, 
      RotationMatrix :> {{0.45130148886885263`, -0.8923715404161858, 0.}, {
       0.8923715404161858, 0.45130148886885263`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.27038197838035677`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.0058775953722936`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.797888374835335`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {4.586211477490427, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.45130148886885263`, -0.8923715404161858, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.202642609176679, 0.8816321711879552, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.4042047935943578, 0.}, 
      RotationMatrix :> {{-0.9500064324375548, -0.31223032896768516`, 0.}, {
       0.31223032896768516`, -0.9500064324375548, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.26727178874055074`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5290871299149464`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.57403365939973, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.8042047935943578, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9500064324375548, -0.31223032896768516`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.377435097169095, 3.658150991890274, 0.}, 
      Optica`Optica`RayEnd :> {7.039248119545805, 4.6, 0.}, 
      RotationMatrix :> {{0.5749299186667751, 0.8182026574277393, 
       0.}, {-0.8182026574277393, 0.5749299186667751, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.191341619086145, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1511194684587125`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.203157797533336`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.7892481195458043`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.5749299186667751, 0.8182026574277393, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.345897813530606, 3.806407466702233, 0.}, 
      Optica`Optica`RayEnd :> {5.975765862474676, 4.6, 0.}, 
      RotationMatrix :> {{-0.42268736976126314`, 0.906275558229562, 
       0.}, {-0.906275558229562, -0.42268736976126314`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.018028563397250823`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8756636169776822, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.058376013270625`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.7257658624746754, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.42268736976126314`, 0.906275558229562, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8591223699710941`, -0.379751604104828, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.11183972014175736`, 0.}, 
      RotationMatrix :> {{-0.9142246602818619, 0.4052076881458607, 
       0.}, {-0.4052076881458607, -0.9142246602818619, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00825072265202851, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2131836059083587`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.83401049062392, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.5118397201417574, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9142246602818619, 0.4052076881458607, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.370476193877607, 3.3020565011722733`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 3.3939851403745727`, 0.}, 
      RotationMatrix :> {{0.9977870591667533, 0.06649048472797858, 
       0.}, {-0.06649048472797858, 0.9977870591667533, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07691633247592052, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.382583381342333, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.50647594737257, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.7939851403745726`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9977870591667533, 0.06649048472797858, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.6634007260393116`, 3.889464890278438, 0.}, 
      Optica`Optica`RayEnd :> {3.997703916991005, 4.6, 0.}, 
      RotationMatrix :> {{-0.9198104942403901, 0.39236291196448214`, 
       0.}, {-0.39236291196448214`, -0.9198104942403901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07364704065544961, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8109130298887195`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.078764752899158`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.252296083008995, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9198104942403901, 0.39236291196448214`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1664863383255795`, 1.7124017880902116`, 0.},
       Optica`Optica`RayEnd :> {0.75, 2.59384875361945, 0.}, 
      RotationMatrix :> {{-0.8490357155232069, 0.5283354557153952, 
       0.}, {-0.5283354557153952, -0.8490357155232069, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07771978843336844, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6683471760109496`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.62910010262892, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.99384875361945, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8490357155232069, 0.5283354557153952, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1688661246212564`, 3.9136726985842807`, 0.},
       Optica`Optica`RayEnd :> {2.8078833745951814`, 4.6, 0.}, 
      RotationMatrix :> {{-0.46550189324159574`, 0.8850468842883354, 
       0.}, {-0.8850468842883354, -0.46550189324159574`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00869048902662272, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7754699932846989, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.696100387395152`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.4421166254048186`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.46550189324159574`, 0.8850468842883354, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.057599674808473, -3.732319033051137, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -4.456095867831128, 0.}, 
      RotationMatrix :> {{-0.874913899547312, -0.4842785029081051, 0.}, {
       0.4842785029081051, -0.874913899547312, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011845081965868559`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4945466925202993`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.43873973762424, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-4.056095867831128, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 42, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348815`*^-15}, 
      Optica`Optica`RayTilt :> {-0.874913899547312, -0.4842785029081051, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.939751687198152, 2.8785860260273344`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 2.251784413451983, 0.}, 
      RotationMatrix :> {{-0.8847291983448784, -0.46610540180953586`, 0.}, {
       0.46610540180953586`, -0.8847291983448784, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01005472558477097, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3447636739285866`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.048484726104583`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.651784413451983, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.8847291983448784, -0.46610540180953586`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.3669117145038703`, 3.764223584864702, 0.}, 
      Optica`Optica`RayEnd :> {2.54043304516074, 4.6, 0.}, 
      RotationMatrix :> {{0.20328193609478504`, 0.979120245147426, 
       0.}, {-0.979120245147426, 0.20328193609478504`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009108008077500871, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8535993605253817, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.018090147021052`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.70956695483926, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.20328193609478504`, 0.979120245147426, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7735416284485892`, -1.0338422441077806`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, -1.3049203825930151`,
        0.}, 
      RotationMatrix :> {{-0.9666723603923588, -0.2560166940913534, 0.}, {
       0.2560166940913534, -0.9666723603923588, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0188568828218138, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0588299307876645`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.051504725746312`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9049203825930149, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9666723603923588, -0.2560166940913534, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.957214733053927, 3.6183783225821378`, 0.}, 
      Optica`Optica`RayEnd :> {7.189188771260336, 4.6, 0.}, 
      RotationMatrix :> {{0.22998260812079407`, 0.9731947389715775, 
       0.}, {-0.9731947389715775, 0.22998260812079407`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008049888409401629, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0086590464465408`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.106460896376255`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.9391887712603362`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.22998260812079407`, 0.9731947389715775, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.988617948777935, -4.710701163914752, 0.}, 
      Optica`Optica`RayEnd :> {6.246975915126126, -5.4, 0.}, 
      RotationMatrix :> {{0.35096968455132455`, -0.9363868220591011, 0.}, {
       0.9363868220591011, 0.35096968455132455`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.015479012753830191`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7361261605214493, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.18131934692715, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.9969759151261259, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.35096968455132455`, -0.9363868220591011, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.249413289851313, 3.865881414191816, 0.}, 
      Optica`Optica`RayEnd :> {7.096338363960726, 4.6, 0.}, 
      RotationMatrix :> {{-0.20412493642972812`, 0.978944845396082, 
       0.}, {-0.978944845396082, -0.20412493642972812`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.034133503291260255`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.7499080150027845, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 18.67727130724369, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.8463383639607263`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 43, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.20412493642972812`, 0.978944845396082, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1854391618308204`, 3.917440606065164, 0.}, 
      Optica`Optica`RayEnd :> {2.7269243355216988`, 4.6, 0.}, 
      RotationMatrix :> {{-0.5576227362433976, 0.8300945030684311, 
       0.}, {-0.8300945030684311, -0.5576227362433976, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      1.2859832372995041`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8222670929776859, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.31408787671773, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.5230756644783012`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.5576227362433976, 0.8300945030684311, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.6447050878359932`, 3.7340071536615724`, 0.},
       Optica`Optica`RayEnd :> {3.1539235737992732`, 4.6, 0.}, 
      RotationMatrix :> {{-0.4930522926730219, 0.8699996762584892, 
       0.}, {-0.8699996762584892, -0.4930522926730219, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.030368714105124362`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9953944466539414, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.10397316311101, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.0960764262007268`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.4930522926730219, 0.8699996762584892, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.666413661944249, 3.8758765752816933`, 0.}, 
      Optica`Optica`RayEnd :> {4.004056392175901, 4.6, 0.}, 
      RotationMatrix :> {{0.4225960881950098, 0.9063181264005895, 
       0.}, {-0.9063181264005895, 0.4225960881950098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.09322966793809642, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7989726825768528, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.05317865407839, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.2459436078240995`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.4225960881950098, 0.9063181264005895, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7945631340613906`, 3.9404978394038013`, 0.},
       Optica`Optica`RayEnd :> {7.3663440076069335`, 4.6, 0.}, 
      RotationMatrix :> {{0.9833774387332423, 0.18157316153674163`, 
       0.}, {-0.18157316153674163`, 0.9833774387332423, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019165915001405957`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.632156619483364, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.062055784363793`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.1163440076069335`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9833774387332423, 0.18157316153674163`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.0875717529220807`, 3.857537429702332, 0.}, 
      Optica`Optica`RayEnd :> {1.3952982896641766`, 4.6, 0.}, 
      RotationMatrix :> {{-0.9157409550606517, 0.40176921637253993`, 
       0.}, {-0.40176921637253993`, -0.9157409550606517, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02295444258858553, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8479827225220258`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.939900331725898`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.8547017103358234`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.9157409550606517, 0.40176921637253993`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.866738553866757, 1.6632737373389903`, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, 1.6226898414554505`, 0.}, 
      RotationMatrix :> {{-0.9993403029601367, -0.036317473474098895`, 0.}, {
       0.036317473474098895`, -0.9993403029601367, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1455889529665632, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1174757493106962`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.67625625329184, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.0226898414554504`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9993403029601367, -0.036317473474098895`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9255244467780555`, 0.4850253643387584, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.6350326116805584, 0.}, 
      RotationMatrix :> {{-0.9919561067366975, 0.1265823143562024, 
       0.}, {-0.1265823143562024, -0.9919561067366975, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012103611224886438`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1850569181384991`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.224720928320146`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0350326116805584`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9919561067366975, 0.1265823143562024, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.1545226228344525`, 3.848702210669975, 0.}, 
      Optica`Optica`RayEnd :> {3.5800354857925454`, 4.6, 0.}, 
      RotationMatrix :> {{-0.6074269547623992, 0.7943755375312592, 
       0.}, {-0.7943755375312592, -0.6074269547623992, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1755309911382409, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9457715574486204, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.606438037945566`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.6699645142074548`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 45, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6074269547623992, 0.7943755375312592, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9002821581533915`, 2.948691825759078, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 3.196372152840666, 0.}, 
      RotationMatrix :> {{-0.9775945064147752, 0.21049698579232112`, 
       0.}, {-0.21049698579232112`, -0.9775945064147752, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.19937205813226602`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1766454809284173`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.651519739848446`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.596372152840666, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9775945064147752, 0.21049698579232112`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.145218465973057, 3.002605801682305, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.9934296759182932`, 0.}, 
      RotationMatrix :> {{0.9999836526924761, -0.005717897149549355, 0.}, {
       0.005717897149549355, 0.9999836526924761, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011376249882806836`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6048077683130477`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.272213256215295`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-3.393429675918293, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.9999836526924761, -0.005717897149549355, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9254498630377734`, 0.4847035724536128, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.8292542812134315, 0.}, 
      RotationMatrix :> {{-0.9596236296707696, 0.2812872008774978, 
       0.}, {-0.2812872008774978, -0.9596236296707696, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010369009586280703`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.2249071684917245`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 21.90447743104367, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.2292542812134315`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9596236296707696, 0.2812872008774978, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.464967287231055, -2.8252742464879286`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -4.327625127895923, 0.}, 
      RotationMatrix :> {{0.6500047063355107, -0.7599301821494437, 0.}, {
       0.7599301821494437, 0.6500047063355107, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011308330064175354`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.9769590900556566`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.009363846955484`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {3.927625127895922, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6500047063355107, -0.7599301821494437, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.705414945740973, 3.888998368063742, 0.}, 
      Optica`Optica`RayEnd :> {7.5745167285675254`, 4.6, 0.}, 
      RotationMatrix :> {{-0.18106106478520534`, 0.9834718556312874, 
       0.}, {-0.9834718556312874, -0.18106106478520534`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.035451583665520314`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7229506648971342, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.896027825961546`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.3245167285675254`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.18106106478520534`, 0.9834718556312874, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.88750394744357, 3.8598451511704264`, 0.}, 
      Optica`Optica`RayEnd :> {8.360700078604824, 4.6, 0.}, 
      RotationMatrix :> {{0.5386474603928759, 0.8425312536709271, 
       0.}, {-0.8425312536709271, 0.5386474603928759, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008784173128675054, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8784894870127392, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.08040832190089, 
      Optica`Optica`PhaseShift :> 1.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {3.110700078604823, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 44, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5386474603928759, 0.8425312536709271, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.928757673475447, 3.59616286765204, 0.}, 
      Optica`Optica`RayEnd :> {6.764964971778461, 4.6, 0.}, 
      RotationMatrix :> {{0.6400381925960525, 0.7683430952500172, 
       0.}, {-0.7683430952500172, 0.6400381925960525, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03510472341432141, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3064959372366225`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.98589924179747, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.5149649717784612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.6400381925960525, 0.7683430952500172, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8999957360474449`, 1.691340859919253, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 4.09124363753976, 0.}, 
      RotationMatrix :> {{-0.4321331140344915, 0.9018098312587041, 
       0.}, {-0.9018098312587041, -0.4321331140344915, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00860646001683766, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.6612071574678153`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.17909889373412, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.49124363753976, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.4321331140344915, 0.9018098312587041, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.315560330733823, 3.842826281431774, 0.}, 
      Optica`Optica`RayEnd :> {5.930886695834191, 4.6, 0.}, 
      RotationMatrix :> {{0.905461201115119, 0.4244290438638308, 
       0.}, {-0.4244290438638308, 0.905461201115119, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.03164313229320953, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7839818681474326`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.818543304451072`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.6808866958341915, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {0.905461201115119, 0.4244290438638308, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.089830620806531, 3.644610377272796, 0.}, 
      Optica`Optica`RayEnd :> {0.9077638619197765, 4.6, 0.}, 
      RotationMatrix :> {{-0.7777342163645173, 0.6285932617327911, 
       0.}, {-0.6285932617327911, -0.7777342163645173, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.020565684496185017`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.5198852435890893`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.519703174342297`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-4.3422361380802235`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7777342163645173, 0.6285932617327911, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8184609758976726`, -0.1543466785264378, 0.},
       Optica`Optica`RayEnd :> {0.75, -0.47408743664388747`, 0.}, 
      RotationMatrix :> {{-0.9580228770546458, -0.2866917631184025, 0.}, {
       0.2866917631184025, -0.9580228770546458, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.07950243014446738, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1152770998356096`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.0946524637117, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.07408743664388745, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9580228770546458, -0.2866917631184025, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8925223693054563`, -3.0614739192830824`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -3.735555503708284, 0.}, 
      RotationMatrix :> {{-0.861271439479639, -0.5081451638426461, 0.}, {
       0.5081451638426461, -0.861271439479639, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.1523541855084696, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3265531828104533`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.739503973505748`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.3355555037082842`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.861271439479639, -0.5081451638426461, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.735202566971461, 3.941086772914109, 0.}, 
      Optica`Optica`RayEnd :> {2.3976433451061703`, 4.6, 0.}, 
      RotationMatrix :> {{-0.45594764575522445`, 0.8900065979138962, 
       0.}, {-0.8900065979138962, -0.45594764575522445`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.04044297839734489, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7403464520716251, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.337635616201954`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.8523566548938297`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534875*^-15}, 
      Optica`Optica`RayTilt :> {-0.45594764575522445`, 0.8900065979138962, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.5490640983277992`, 3.6362395798778353`, 0.},
       Optica`Optica`RayEnd :> {2.9906241608010675`, 4.6, 0.}, 
      RotationMatrix :> {{-0.5013545370502013, 0.8652419477690487, 
       0.}, {-0.8652419477690487, -0.5013545370502013, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.046418863892723754`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1138623394382765`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      18.800262572711343`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.2593758391989325`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 46, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5013545370502013, 0.8652419477690487, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.35458679363506, 0.12765032623837, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -1.0717124374373639`, 0.}, 
      RotationMatrix :> {{0.7583712484287423, -0.6518228667027796, 0.}, {
       0.6518228667027796, 0.7583712484287423, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0314479105128328, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.8400133302206207`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.269190778478272`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {0.671712437437364, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7583712484287423, -0.6518228667027796, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.133292155381548, 3.839095338540685, 0.}, 
      Optica`Optica`RayEnd :> {2.101890100273397, 4.6, 0.}, 
      RotationMatrix :> {{-0.041234269459624814`, 0.9991495058409087, 
       0.}, {-0.9991495058409087, -0.041234269459624814`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008569221334538671, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.761552357291033, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      19.897457624794082`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.148109899726603, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {-0.041234269459624814`, 0.9991495058409087, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.816528145569681, -4.383112257242901, 0.}, 
      Optica`Optica`RayEnd :> {6.344021416112138, -5.4, 0.}, 
      RotationMatrix :> {{-0.42139028400520867`, -0.9068793902973035, 0.}, {
       0.9068793902973035, -0.42139028400520867`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.033810148026422675`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1213042810728457`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.323264180674045`, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-1.0940214161121378`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 
       0.9999999999999999, -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.42139028400520867`, -0.9068793902973035, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.750818439690522, -4.419688470805187, 0.}, 
      Optica`Optica`RayEnd :> {6.401005318061502, -5.4, 0.}, 
      RotationMatrix :> {{-0.3360823507281261, -0.9418326037725897, 0.}, {
       0.9418326037725897, -0.3360823507281261, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.11461909881547977`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0408553762824657`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.08542796797454, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-1.1510053180615025`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 47, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.3360823507281261, -0.9418326037725897, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.166895214856064, -3.0588244373516718`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -3.742805141543442, 0.}, 
      RotationMatrix :> {{0.9179848252998901, -0.3966155071591744, 0.}, {
       0.3966155071591744, 0.9179848252998901, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017805985599295766`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7245435235018853`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.08419899231693, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {3.342805141543442, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9179848252998901, -0.3966155071591744, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.624661889022492, 3.837040565238847, 0.}, 
      Optica`Optica`RayEnd :> {5.271286518202127, 4.6, 0.}, 
      RotationMatrix :> {{-0.42027381153405563`, 0.9073973348752109, 
       0.}, {-0.9073973348752109, -0.42027381153405563`, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 1.1403741893515447`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.8408217717171032, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 19.755344533989263`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.02128651820212696, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.42027381153405563`, 0.9073973348752109, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.882779322650426, 3.811935048904515, 0.}, 
      Optica`Optica`RayEnd :> {7.828399084772261, 4.6, 0.}, 
      RotationMatrix :> {{0.7682019089296646, 0.6402076437506958, 
       0.}, {-0.6402076437506958, 0.7682019089296646, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008186074095058088, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.2309521118469575`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 20.579345522648342`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {2.5783990847722613`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.7682019089296646, 0.6402076437506958, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.475677707174433, 3.668722634526091, 0.}, 
      Optica`Optica`RayEnd :> {6.636523485148712, 4.6, 0.}, 
      RotationMatrix :> {{0.17019536665964527`, 0.9854103394868493, 
       0.}, {-0.9854103394868493, 0.17019536665964527`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02740152175722202, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.9450655510260518, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.42425284827519, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {1.3865234851487116`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 49, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.17019536665964527`, 0.9854103394868493, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8654612149900247`, 0.8885482619526972, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, 0.6160840059493612, 0.}, 
      RotationMatrix :> {{-0.9714399798064066, -0.23728540965202038`, 0.}, {
       0.23728540965202038`, -0.9714399798064066, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.2370612963924621, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1482554127660243`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.404576609301706`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0160840059493612`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9714399798064066, -0.23728540965202038`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.905450895359237, 2.9302119632853034`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 2.8526439560842514`, 0.}, 
      RotationMatrix :> {{-0.9977542191683024, -0.0669814760351756, 0.}, {
       0.0669814760351756, -0.9977542191683024, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.2867185637790726, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.158051625501905, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.958914969526308`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.2526439560842513`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 48, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9977542191683024, -0.0669814760351756, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.001820259253169, 0.8322686305099309, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -0.06447361069971824, 0.}, 
      RotationMatrix :> {{-0.8129387529261658, -0.5823491942046884, 0.}, {
       0.5823491942046884, -0.8129387529261658, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.07606481930067648, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.5398703220227266`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.893556250792194`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.33552638930028167`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.8129387529261658, -0.5823491942046884, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.553007083039228, 3.824253879775438, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 4.365551956770799, 0.}, 
      RotationMatrix :> {{-0.9577683761967657, 0.2875408450245114, 
       0.}, {-0.2875408450245114, -0.9577683761967657, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.028024213040754323`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.882508472663138, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.597598099893222`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.7655519567708, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9577683761967657, 0.2875408450245114, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8717760217040529`, -3.596276373248007, 0.}, 
      Optica`Optica`RayEnd :> {0.7499999999999998, -4.264103608630234, 0.}, 
      RotationMatrix :> {{-0.8592580674914431, -0.5115423476613354, 0.}, {
       0.5115423476613354, -0.8592580674914431, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0361092550172754, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.305517008387267, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.387632114329293`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.8641036086302334`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8592580674914431, -0.5115423476613354, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.277153594740588, -1.8841482342927005`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.7016737323025786`, 0.}, 
      RotationMatrix :> {{0.874339297927636, -0.48531514719757984`, 0.}, {
       0.48531514719757984`, 0.874339297927636, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00914123005986919, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6845249993341957`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      21.735810650059516`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.301673732302579, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 51, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.874339297927636, -0.48531514719757984`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.78884187988963, 3.9356753447342863`, 0.}, 
      Optica`Optica`RayEnd :> {5.337352751897541, 4.6, 0.}, 
      RotationMatrix :> {{-0.5620957764477629, 0.8270721480618153, 
       0.}, {-0.8270721480618153, -0.5620957764477629, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15887861318462476`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8032245515974761, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.772553749826354`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {0.08735275189754038, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 50, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.5620957764477629, 0.8270721480618153, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7936828751715794`, 0.0789026636679371, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.2982847768764263, 0.}, 
      RotationMatrix :> {{-0.9786141180114314, 0.20570466214626254`, 
       0.}, {-0.20570466214626254`, -0.9786141180114314, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01687145370879416, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0664907198481555`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.644877670287507`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.6982847768764263, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9786141180114314, 0.20570466214626254`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.7818741487236447`, -1.0752584328605608`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -1.0459322082683495`, 0.}, 
      RotationMatrix :> {{-0.9995963863369215, 0.02840887928391188, 
       0.}, {-0.02840887928391188, -0.9995963863369215, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013463621197105787`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0322907953929354`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.294526223590225`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.6459322082683495, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9995963863369215, 0.02840887928391188, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.07115545095173, 3.6707940629447973`, 0.}, 
      Optica`Optica`RayEnd :> {3.893366391537607, 4.6, 0.}, 
      RotationMatrix :> {{-0.1879254503639339, 0.9821832950653925, 
       0.}, {-0.9821832950653925, -0.1879254503639339, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.008801486977194652, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9460616381113839, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 22.226805917181444`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-1.3566336084623927`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1879254503639339, 0.9821832950653925, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1227029962502155`, 3.8305644736481965`, 0.},
       Optica`Optica`RayEnd :> {2.085762264531462, 4.6, 0.}, 
      RotationMatrix :> {{-0.047954935991112, 0.9988495002321858, 
       0.}, {-0.9988495002321858, -0.047954935991112, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012187064280882806`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.7703217813824254, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.1318776952543, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 4, Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-3.164237735468538, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.047954935991112, 0.9988495002321858, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.27378532912938, 3.089154647252922, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 2.462813743293564, 0.}, 
      RotationMatrix :> {{0.9205665322819643, -0.39058579037435337`, 0.}, {
       0.39058579037435337`, 0.9205665322819643, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.012299228214542272`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.6035936774838813`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.578042704514182`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-2.862813743293564, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9205665322819643, -0.39058579037435337`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.495946585525004, 3.6887914096803205`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 4.586149244763882, 0.}, 
      RotationMatrix :> {{0.8132407751058668, 0.5819273508825722, 
       0.}, {-0.5819273508825722, 0.8132407751058668, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.13071026853977363`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.542044438575702, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.581523267673727`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-4.986149244763882, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.8132407751058668, 0.5819273508825722, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8756163776684474`, -1.1869631499097286`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -3.3256616220227384`, 0.}, 
      RotationMatrix :> {{-0.46574176798432343`, -0.884920677549596, 0.}, {
       0.884920677549596, -0.46574176798432343`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.01188857371649193, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.4168250628239436`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.339966146159842`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.9256616220227385`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 56, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.46574176798432343`, -0.884920677549596, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.300156147257562, 1.4583259666974322`, 0.}, 
      Optica`Optica`RayEnd :> {9.267337733411882, 4.6, 0.}, 
      RotationMatrix :> {{0.29422831273390193`, 0.9557351620536731, 
       0.}, {-0.9557351620536731, 0.29422831273390193`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00923661201086145, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 3.2871805475397307`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.961363125582565`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {4.017337733411881, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.29422831273390193`, 0.9557351620536731, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.2909883109441656`, -4.5946589053852165`, 
       0.}, Optica`Optica`RayEnd :> {2.520638746641396, -5.4, 0.}, 
      RotationMatrix :> {{-0.69123356373659, -0.7226314139061585, 0.}, {
       0.7226314139061585, -0.69123356373659, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.08473011028721002, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1144562485341472`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.350527307460425`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {2.729361253358604, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.69123356373659, -0.7226314139061585, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {7.592086742145651, -4.625886100022921, 0.}, 
      Optica`Optica`RayEnd :> {7.575230077813286, -5.4, 0.}, 
      RotationMatrix :> {{-0.021770270881506345`, -0.9997629995682702, 0.}, {
       0.9997629995682702, -0.021770270881506345`, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0527029012314148, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7742974087972513, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      20.956159359973356`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-2.3252300778132864`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348736`*^-15}, 
      Optica`Optica`RayTilt :> {-0.021770270881506345`, -0.9997629995682702, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.074781152017092, -4.648738151644846, 0.}, 
      Optica`Optica`RayEnd :> {9.700038947201104, -5.4, 0.}, 
      RotationMatrix :> {{0.9077163675690939, -0.41958431339501784`, 0.}, {
       0.41958431339501784`, 0.9077163675690939, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.10986009869390606`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.7904907890297566`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.732946503637507`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-4.450038947201104, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 54, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9077163675690939, -0.41958431339501784`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8240741026616254`, 1.588190619940066, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.9444793858073828`, 0.}, 
      RotationMatrix :> {{-0.9491424990400867, 0.3148468143652372, 
       0.}, {-0.3148468143652372, -0.9491424990400867, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.029589792549295744`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1316257608819407`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 23.387536898541466`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.3444793858073827`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9491424990400867, 0.3148468143652372, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.417195633114394, -0.1544898434743955, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -0.2504338269290702, 0.}, 
      RotationMatrix :> {{0.9974189954409365, -0.07180074883726505, 0.}, {
       0.07180074883726505, 0.9974189954409365, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.013431425908291657`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.3362532425968106`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 24.59892809021053, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.14956617307092987`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 58, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 180.}, 
      Optica`Optica`RayTilt :> {0.9974189954409365, -0.07180074883726505, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2076719681319608`, 1.8799915918934478`, 0.},
       Optica`Optica`RayEnd :> {0.75, 1.841438773858871, 0.}, 
      RotationMatrix :> {{-0.9996504294114436, -0.02643896702814083, 0.}, {
       0.02643896702814083, -0.9996504294114436, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009784707142137649, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4581817055689978`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.934830796409155`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.241438773858871, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 53, 
      Optica`Optica`Polarization :> {0., 1., -138.3679760955136}, 
      Optica`Optica`RayTilt :> {-0.9996504294114436, -0.02643896702814083, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.470391685845325, -4.324888481466, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -4.2137530955699525`, 0.}, 
      RotationMatrix :> {{0.9962496471841168, 0.0865253748071732, 
       0.}, {-0.0865253748071732, 0.9962496471841168, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.02631759933666217, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2844253624294537`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.568990074960194`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {3.813753095569952, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9962496471841168, 0.0865253748071732, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.636771330728353, 3.7921973243101887`, 0.}, 
      Optica`Optica`RayEnd :> {2.8101711478294145`, 4.6, 0.}, 
      RotationMatrix :> {{-0.7151920201403896, 0.6989280179871947, 
       0.}, {-0.6989280179871947, -0.7151920201403896, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008018959664387442, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1557737777005397`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.37084228560462, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.4398288521705855`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 55, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534881*^-15}, 
      Optica`Optica`RayTilt :> {-0.7151920201403896, 0.6989280179871947, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8423080769447733`, -0.45235163317290616`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.0574530586425595`, 0.}, 
      RotationMatrix :> {{-0.5626055214573742, -0.8267254848047656, 0.}, {
       0.8267254848047656, -0.5626055214573742, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.031108199664232762`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.9415168093538366`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.78552509562689, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.6574530586425593`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5626055214573742, -0.8267254848047656, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.282380208947151, -1.8815251178425596`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.5469065420650225`, 0.}, 
      RotationMatrix :> {{0.9107677917053949, -0.412918914064345, 0.}, {
       0.412918914064345, 0.9107677917053949, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.00802838107645152, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6114094112888635`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.03269509387294, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.1469065420650226`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.9107677917053949, -0.412918914064345, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.900105784987952, 1.382113841150748, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.7357057001386909`, 0.}, 
      RotationMatrix :> {{-0.9558459920649098, 0.2938680647049751, 
       0.}, {-0.2938680647049751, -0.9558459920649098, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.008450312084613576, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2032333603276224`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.208413761241946`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.1357057001386903`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.9558459920649098, 0.2938680647049751, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8238439393769457`, 1.0202765181166027`, 0.},
       Optica`Optica`RayEnd :> {0.75, 0.6037719390541022, 0.}, 
      RotationMatrix :> {{-0.9323273240591677, -0.36161548751770894`, 0.}, {
       0.36161548751770894`, -0.9323273240591677, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009622081966793348, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1517885528675078`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.387762931256436`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.0037719390541022`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9323273240591677, -0.36161548751770894`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.815103198866747, -4.5442523639535395`, 0.}, 
      Optica`Optica`RayEnd :> {4.192520843571415, -5.4, 0.}, 
      RotationMatrix :> {{-0.5883079304897461, -0.808636988346979, 0.}, {
       0.808636988346979, -0.5883079304897461, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.012778700267654632`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.0582593282008852`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      22.31677105284362, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.057479156428585, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5883079304897461, -0.808636988346979, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.515057093215638, -4.686380860885859, 0.}, 
      Optica`Optica`RayEnd :> {6.024217223762429, -5.4, 0.}, 
      RotationMatrix :> {{-0.5667065517676011, -0.8239197073645432, 0.}, {
       0.8239197073645432, -0.5667065517676011, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.16363563205894352`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.8661270421565483, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.864035874280876`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.774217223762429, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.5667065517676011, -0.8239197073645432, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.353958111122084, 0.12673605509693064`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, -2.440694887693634, 0.}, 
      RotationMatrix :> {{0.4776979514650126, -0.8785241414816836, 0.}, {
       0.8785241414816836, 0.4776979514650126, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010658256200097168`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      2.922436415304919, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.22250459951704, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 1, Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {2.040694887693634, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.4776979514650126, -0.8785241414816836, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.0375417428426617`, 2.1825871052305135`, 0.},
       Optica`Optica`RayEnd :> {0.75, 2.7947799446624715`, 0.}, 
      RotationMatrix :> {{-0.9031114742877898, 0.4294061771909371, 
       0.}, {-0.4294061771909371, -0.9031114742877898, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0165971042593572, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.4256731084698488`, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      21.979616925226175`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {3.1947799446624714`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 57, 
      Optica`Optica`Polarization :> {0., 1., 132.56507968104114`}, 
      Optica`Optica`RayTilt :> {-0.9031114742877898, 0.4294061771909371, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9679775262061567`, -1.6446457138116022`, 
       0.}, Optica`Optica`RayEnd :> {0.7500000000000002, -3.293554580072368, 
       0.}, RotationMatrix :> {{-0.5941445892873589, -0.8043582578805016, 
       0.}, {0.8043582578805016, -0.5941445892873589, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.017715521554756614`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.049968220138213, 
      Optica`Optica`RefractiveIndex :> 1.48, Optica`Optica`OpticalLength :> 
      24.00669180860064, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.893554580072368, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 60, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 
       167.35910683550452`}, 
      Optica`Optica`RayTilt :> {-0.5941445892873589, -0.8043582578805016, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8478535170951083`, -2.5287092081334865`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -3.531199278342574, 0.}, 
      RotationMatrix :> {{-0.7384513046439465, -0.6743068075213625, 0.}, {
       0.6743068075213625, -0.7384513046439465, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011647648499061757`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.486697240821385, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.787329657634814`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-3.131199278342574, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 61, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.7384513046439465, -0.6743068075213625, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.1147820855425192`, -2.2821698249394347`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.2762371811996505`, 0.}, 
      RotationMatrix :> {{-0.9999905521331975, 0.0043469120468401685`, 
       0.}, {-0.0043469120468401685`, -0.9999905521331975, 0.}, {0., 0., 1.}},
       Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.0165525755601482, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3647949799437027`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      24.348736844839202`, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.8762371811996505`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.9999905521331975, 0.0043469120468401685`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {6.302464808170437, -4.450050301458311, 0.}, 
      Optica`Optica`RayEnd :> {5.609114506107334, -5.4, 0.}, 
      RotationMatrix :> {{-0.5895488334184869, -0.8077327361292846, 0.}, {
       0.8077327361292846, -0.5895488334184869, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.016782319412679363`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1760693309199262`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      23.27916672700675, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-0.35911450610733364`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 59, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534876*^-15}, 
      Optica`Optica`RayTilt :> {-0.5895488334184869, -0.8077327361292846, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.412962572471049, -4.416584131883879, 0.}, 
      Optica`Optica`RayEnd :> {8.506745675151512, -5.4, 0.}, 
      RotationMatrix :> {{0.09493393522580915, -0.9954835749235349, 0.}, {
       0.9954835749235349, 0.09493393522580915, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.23627563433252427`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9878775430239106, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.81601618703696, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-3.256745675151512, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.09493393522580915, -0.9954835749235349, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8575330775666872`, -1.973609833425109, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -2.286202570382883, 0.}, 
      RotationMatrix :> {{-0.9624016184658515, -0.2716304930863047, 0.}, {
       0.2716304930863047, -0.9624016184658515, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.1292228619235062, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1508013456296833`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.33310433562166, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-1.886202570382883, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 62, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {-0.9624016184658515, -0.2716304930863047, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8331971455187728`, -1.49581634012526, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 0.1688199539809353, 0.}, 
      RotationMatrix :> {{-0.5454072201317828, 0.8381712022183297, 
       0.}, {-0.8381712022183297, -0.5454072201317828, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.025052920747016295`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.9860337478793317`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 26.650314653762372`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.5688199539809353, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.5454072201317828, 0.8381712022183297, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.847484571749867, -1.5541627057341192`, 0.}, 
      Optica`Optica`RayEnd :> {0.7500000000000002, -1.379969662677608, 0.}, 
      RotationMatrix :> {{-0.9876370411800853, 0.156758013795294, 
       0.}, {-0.156758013795294, -0.9876370411800853, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.011069641631359073`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1112225706303287`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.186100718976732`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9799696626776078, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9876370411800853, 0.156758013795294, 0.}], 
     
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.101985669129406, 3.8742308283456834`, 0.}, 
      Optica`Optica`RayEnd :> {2.975288809690501, 4.6, 0.}, 
      RotationMatrix :> {{-0.1719684341037451, 0.9851024604942906, 
       0.}, {-0.9851024604942906, -0.1719684341037451, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.011175902980703164`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 0.7367448572711411, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      25.727457629992404`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 4, 
      Optica`Optica`SurfaceID :> 79833, 
      Optica`Optica`SurfaceCoordinates :> {-2.274711190309499, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.1719684341037451, 0.9851024604942906, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.301227485802736, 2.5779427149896432`, 0.}, 
      Optica`Optica`RayEnd :> {9.75, 0.11567783808227661`, 0.}, 
      RotationMatrix :> {{0.5071193092161076, -0.8618758647393353, 0.}, {
       0.8618758647393353, 0.5071193092161076, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.013754071706224509`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 2.856867186612831, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      29.612708505272757`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 1, 
      Optica`Optica`SurfaceID :> 79830, 
      Optica`Optica`SurfaceCoordinates :> {-0.5156778380822766, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.5071193092161076, -0.8618758647393353, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.105089716554118, 2.2924074478347602`, 0.}, 
      Optica`Optica`RayEnd :> {0.75, 1.2544260083243568`, 0.}, 
      RotationMatrix :> {{-0.7938667260631909, -0.6080917868625663, 0.}, {
       0.6080917868625663, -0.7938667260631909, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.028756905040941163`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.7069486250847763`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.75926632509272, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {1.6544260083243567`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -7.0167092985348704`*^-15}, 
      Optica`Optica`RayTilt :> {-0.7938667260631909, -0.6080917868625663, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8227355325169223`, 1.0030155268912893`, 0.},
       Optica`Optica`RayEnd :> {0.7500000000000002, 0.4707323179671955, 0.}, 
      RotationMatrix :> {{-0.8957873519719338, -0.44448286811429527`, 0.}, {
       0.44448286811429527`, -0.8957873519719338, 0.}, {0., 0., 
       0.9999999999999999}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.026472546064063754`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.197533689391198, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.35359274689295, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.8707323179671955, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.8957873519719338, -0.44448286811429527`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9620053601186829`, 3.0868466436547135`, 0.},
       Optica`Optica`RayEnd :> {0.75, 3.629250892615372, 0.}, 
      RotationMatrix :> {{-0.9127645334982357, 0.4084861152937114, 
       0.}, {-0.4084861152937114, -0.9127645334982357, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.019074308332854527`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.3278401117028338`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.0742222397906, Optica`Optica`PhaseShift :> 1., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {4.029250892615372, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 63, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534879*^-15}, 
      Optica`Optica`RayTilt :> {-0.9127645334982357, 0.4084861152937114, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {4.30456992408814, -4.450885268302151, 0.}, 
      Optica`Optica`RayEnd :> {3.481404355630144, -5.4, 0.}, 
      RotationMatrix :> {{-0.6552029796613175, -0.7554528810210009, 0.}, {
       0.7554528810210009, -0.6552029796613175, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.010654779228694138`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.2563519916888963`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      27.369845952262946`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 2, 
      Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.768595644369856, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.6552029796613175, -0.7554528810210009, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.1843017802244207`, -4.353766402763522, 0.}, 
      Optica`Optica`RayEnd :> {3.280360365742378, -5.4, 0.}, 
      RotationMatrix :> {{0.0914291534977151, -0.9958115835290785, 0.}, {
       0.9958115835290785, 0.0914291534977151, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.021979322092558224`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.0506340903654763`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.42342499390053, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.969639634257622, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 67, 
      Optica`Optica`Polarization :> {0., 0.9999999999999999, 0.}, 
      Optica`Optica`RayTilt :> {0.0914291534977151, -0.9958115835290785, 0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8429277720194244`, -1.5431834720036013`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, -1.3117594152727874`,
        0.}, RotationMatrix :> {{-0.9783083969292055, 0.20715376052055529`, 
       0.}, {-0.20715376052055529`, -0.9783083969292055, 0.}, {0., 0., 
       0.9999999999999996}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010343302573710479`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1171607802304422`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 25.97739351767745, 
      Optica`Optica`PhaseShift :> 1., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 3, Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-0.9117594152727874, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 65, 
      Optica`Optica`Polarization :> {0., 1., -7.016709298534885*^-15}, 
      Optica`Optica`RayTilt :> {-0.9783083969292055, 0.20715376052055529`, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8126837753289176`, 2.5667455556332626`, 0.},
       Optica`Optica`RayEnd :> {0.75, 1.632450992619971, 0.}, 
      RotationMatrix :> {{-0.7510173691395673, -0.6602824480861822, 0.}, {
       0.6602824480861822, -0.7510173691395673, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009306337468812365, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.414992274474853, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      26.3790822815468, Optica`Optica`PhaseShift :> 1.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {2.032450992619971, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 64, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7510173691395673, -0.6602824480861822, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {5.3435873933583835`, -4.311607522435026, 0.}, 
      Optica`Optica`RayEnd :> {5.1284600887553955`, -5.4, 0.}, 
      RotationMatrix :> {{-0.19390456844249668`, -0.9810203964939402, 0.}, {
       0.9810203964939402, -0.19390456844249668`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.04176588516850442, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      1.1094493870410536`, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 27.962460863064535`, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {0.12153991124460461`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 72, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.19390456844249668`, -0.9810203964939402, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {8.2637206997027, -4.46240798472222, 0.}, 
      Optica`Optica`RayEnd :> {8.41186209041113, -5.4, 0.}, 
      RotationMatrix :> {{0.15606592078241882`, -0.9877466417914741, 0.}, {
       0.9877466417914741, 0.15606592078241882`, 0.}, {0., 0., 
       0.9999999999999998}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.056504966068771215`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9492231870080277, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 29.53781833404284, 
      Optica`Optica`PhaseShift :> 0., Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {-3.1618620904111303`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {0.15606592078241882`, -0.9877466417914741, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.9247809079917395`, -0.31161928865510713`, 
       0.}, Optica`Optica`RayEnd :> {0.7499999999999998, -0.2552318476916251, 
       0.}, RotationMatrix :> {{-0.9988500700112948, 0.04794306663564521, 
       0.}, {-0.04794306663564521, -0.9988500700112948, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.054059020452650715`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.1761333790350081`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      28.478626998372874`, Optica`Optica`PhaseShift :> 0., 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {0.1447681523083749, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 73, 
      Optica`Optica`Polarization :> {0., 1., 0.}, 
      Optica`Optica`RayTilt :> {-0.9988500700112948, 0.04794306663564521, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {3.7259065841173045`, -4.4409374302681215`, 
       0.}, Optica`Optica`RayEnd :> {3.856328888908827, -5.4, 0.}, 
      RotationMatrix :> {{0.13474910278754154`, -0.9908797501704997, 0.}, {
       0.9908797501704997, 0.13474910278754154`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.010854184525250454`, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9678899680479428, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 28.224237288157134`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {1.393671111091173, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.13474910278754154`, -0.9908797501704997, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {2.2382741906794665`, -4.436492633377812, 0.}, 
      Optica`Optica`RayEnd :> {2.2486306484639114`, -5.4, 0.}, 
      RotationMatrix :> {{0.010748085515444279`, -0.9999422376606322, 0.}, {
       0.9999422376606322, 0.010748085515444279`, 0.}, {0., 0., 
       0.9999999999999997}}, Optica`Optica`WaveLength :> 0.532, 
      Optica`Optica`Intensity :> 0.03842949207078567, 
      Optica`Optica`IntensityScale :> 1., Optica`Optica`RayLength :> 
      0.9635630242765988, Optica`Optica`RefractiveIndex :> 1.34, 
      Optica`Optica`OpticalLength :> 28.061488234584225`, 
      Optica`Optica`PhaseShift :> 0.5, Optica`Optica`ComponentNumber :> 2, 
      Optica`Optica`SurfaceNumber :> 2, Optica`Optica`SurfaceID :> 79831, 
      Optica`Optica`SurfaceCoordinates :> {3.0013693515360886`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 71, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {0.010748085515444279`, -0.9999422376606322, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.892191514199834, -4.095942514368096, 0.}, 
      Optica`Optica`RayEnd :> {0.75, -5.219973146163546, 0.}, 
      RotationMatrix :> {{-0.7127504549162951, -0.7014176993893252, 0.}, {
       0.7014176993893252, -0.7127504549162951, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.15715266006497608`, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.6025125011445578`, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      27.31079386225014, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-4.819973146163545, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 74, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.7127504549162951, -0.7014176993893252, 
       0.}], 
     Optica`Optica`Private`HeldRay[
     Optica`Optica`RayStart :> {1.8626583431103891`, -1.5802739192837725`, 
       0.}, Optica`Optica`RayEnd :> {0.75, -2.7311201728047454`, 0.}, 
      RotationMatrix :> {{-0.6950781664382594, -0.7189341712151578, 0.}, {
       0.7189341712151578, -0.6950781664382594, 0.}, {0., 0., 1.}}, 
      Optica`Optica`WaveLength :> 0.532, Optica`Optica`Intensity :> 
      0.009594616403945098, Optica`Optica`IntensityScale :> 1., 
      Optica`Optica`RayLength :> 1.600767218472572, 
      Optica`Optica`RefractiveIndex :> 1.34, Optica`Optica`OpticalLength :> 
      28.180415581006372`, Optica`Optica`PhaseShift :> 0.5, 
      Optica`Optica`ComponentNumber :> 2, Optica`Optica`SurfaceNumber :> 3, 
      Optica`Optica`SurfaceID :> 79832, 
      Optica`Optica`SurfaceCoordinates :> {-2.3311201728047455`, 0.}, 
      Optica`Optica`SourceID :> 79735, Optica`Optica`WaveFrontID :> 1, 
      Optica`Optica`RaySourceNumber :> {{1, 1}, {0, 0}}, 
      Optica`Optica`RaySlot :> 1, Optica`Optica`GenerationNumber :> 168, 
      Optica`Optica`IntersectionNumber :> 79, 
      Optica`Optica`Polarization :> {0., 1., 180.}, 
      Optica`Optica`RayTilt :> {-0.6950781664382594, -0.7189341712151578, 
       0.}]], 
    Optica`Optica`Private`HeldList[
     Optica`Optica`Private`HeldList[], 
     Optica`Optica`Private`HeldList[
      Optica`Optica`Private`HeldSource[{}, Optica`Optica`ComponentNumber :> 1,
        Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`SingleRay[{
           Optica`Optica`Ray[]}, 1, Optica`Optica`IntrinsicMedium -> 1.34, 
          Optica`Optica`SourceTransformation -> {{-2., 0, 0}, {{1., 0, 0}, {
             0, 1., 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{-2, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-2., 0, 0}, {{1., 0, 0}, {
          0, 1., 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-2, 0, 0}, {{1, 0, 
         0}, {0, 1, 0}, {0, 0, 1}}}, Optica`Optica`SourceLevel :> {1, 1}, 
       Optica`Optica`NumberOfRays :> 1, Optica`Optica`BirthPoint :> {0, 0, 0},
        Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 79735, Optica`Optica`SourceFraction :> 
       1, Optica`Optica`SourceOffset :> 0, Optica`Optica`GridSpacing :> (#& ),
        Optica`Optica`PowerOutput :> Optica`Optica`PowerOutput, 
       Optica`Optica`SymbolicValues -> {}, Optica`Optica`IntrinsicMedium :> 
       1.34]]], 
    Optica`Optica`Private`HeldList[
     Optica`Optica`HeldComponent[
     Optica`Optica`ComponentID :> 76509, Optica`Optica`ComponentDescription :> 
      Optica`Optica`ComponentDescription[
        Optica`Optica`RemoveSurface[
         Optica`Optica`RodLens[
         1, 1, {Optica`Optica`FresnelReflections -> True, 
           Optica`Optica`ComponentMedium -> 1.48}, 
          Optica`Optica`ComponentLabel -> "", 
          Optica`Optica`SymbolicComponentTransformation -> {{0, 0, 0}, {{1, 0,
             0}, {0, 1, 0}, {0, 0, 1}}}, 
          Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
            0.}, {0., 1., 0.}, {0., 0., 1.}}}], {1, 5}, 
         Optica`Optica`ComponentLabel -> ""]], 
      Optica`Optica`TranslationVector :> {0., 0., 0.}, 
      RotationMatrix :> {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}, 
      Optica`Optica`Labels :> {"L"}, 
      Optica`Optica`LabelPositions :> {{
        0., -0.5 - 1. Optica`Optica`Offy, -0.5 - 1. Optica`Optica`Offz}}, 
      EdgeStyle :> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CrossStyle :> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CatalogInformation :> {{}}, 
      Optica`Optica`Surfaces :> {{
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76512, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> -1., 
         Optica`Optica`ComponentMedium -> 1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, 1.}, {0, 1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {0, 0, 0.5}, 
         Optica`Optica`SurfaceCenter -> {-0.00001, 0.00001, 0.5}, 
         Optica`Optica`SurfaceBoundary -> 1., 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           0}}, {{7., {3, 0, 5}}, {0.25, {3, 0, 4}}}, {1, 0, 6, 0, 
           0}, {{40, 56, 3, 0, 0, 3, 0, 2}, {40, 56, 3, 0, 1, 3, 0, 3}, {13, 
            2, 3, 2}, {27, 4, 5, 2, 4, 0}, {1}}, 
           
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            Optica`Optica`SCx^2 + Optica`Optica`SCy^2 <= 0.25], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {0, 0, 
           Rational[1, 2]}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, 1}, {0, 1, 0}, {-1, 
          0, 0}}, Optica`Optica`SymbolicComponentTransformation -> {{0, 0, 
            Rational[1, 2]}, {{0, 0, 1}, {0, 1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> 1, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {1, {2, 0, 1}}, {
            7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {2, {2, 0, 2}}, {
            0.25, {3, 0, 14}}, {False, {1, 0, 3}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}}, {5, 4,
            15, 0, 5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27,
             8, 9, 7, 8, 0}, {2, 0, 37}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 
            7, 8}, {19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {
            13, 1, 11, 8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13,
             2, 12, 11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 
            269, 3, 0, 10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 
            9}, {38, 0, 0, 2, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 11}, {38, 0, 0, 
            3, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 12}, {13, 11, 12, 11}, {27, 4, 
            9, 11, 14, 2}, {5, 2, 4}, {3, 2}, {5, 3, 4}, {2, 4, 7}, {38, 0, 0,
             1, 0, 11}, {38, 0, 0, 2, 0, 8}, {38, 0, 0, 3, 0, 10}, {34, 11, 8,
             10, 3, 1}, {42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$474}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 0.25], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$474 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$474), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$474, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$474}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76359, 
         Optica`Optica`SurfaceContinuation -> True, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`CylindricalShape, 
         Optica`Optica`SurfaceValue -> Rational[1, 2], 
         Optica`Optica`SurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`ActiveRegion -> 1., Optica`Optica`ComponentMedium -> 
         1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, -
             Optica`Optica`SCx (Rational[1, 4] - Optica`Optica`SCx^2)^
              Rational[-1, 2], 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {-0.5, 0, 0}, 
         Optica`Optica`SurfaceCenter -> {-0.5, 0.00001, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {0.8660254037844386, 1.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{7., {3, 0, 3}}, {0.5, {3, 0, 6}}, {
            False, {1, 0, 4}}, {-0.4330127018922193, {3, 0, 4}}, {-0.5, {3, 0,
              5}}, {0.4330127018922193, {3, 0, 2}}}, {6, 0, 7, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 0.4330127018922193, 
             Optica`Optica`SCx >= -0.4330127018922193, 
             Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {
           Rational[-1, 2], 0, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}, Optica`Optica`SymbolicComponentTransformation -> {{
            Rational[-1, 2], 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> Rational[1, 2], 
         Optica`Optica`SymbolicSurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {
          Rational[1, 2] 3^Rational[1, 2], 1}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           6}}, {{{{-1., 0., 0.}}, {3, 2, 0}}, {1, {2, 0, 3}}, {
            1., {3, 0, 6}}, {1.*^-7, {3, 0, 22}}, {7., {3, 0, 14}}, {
            1.*^-10, {3, 0, 12}}, {2, {2, 0, 0}}, {0.25, {3, 0, 21}}, {
            5, {2, 0, 4}}, {0.5, {3, 0, 9}}, {False, {1, 0, 2}}, {
            0., {3, 0, 13}}, {-0.4330127018922193, {3, 0, 19}}, {
            3, {2, 0, 2}}, {-0.5, {3, 0, 20}}, {{-1., 0., 0.}, {3, 1, 2}}, {
            0.4330127018922193, {3, 0, 18}}}, {8, 5, 33, 4, 
           8}, {{7, 6, 10}, {7, 6, 24}, {7, 6, 26}, {7, 6, 11}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 3}, {7, 6, 25}, {7, 6, 23}, {7, 
            6, 16}, {40, 56, 3, 0, 3, 3, 0, 30}, {40, 56, 3, 0, 4, 3, 0, 
            28}, {13, 30, 28, 30}, {7, 30, 11}, {40, 56, 3, 0, 0, 3, 0, 30}, {
            40, 56, 3, 0, 1, 3, 0, 28}, {10, 0, 31}, {16, 31, 0, 9, 31}, {19, 
            31, 32}, {13, 30, 28, 32, 30}, {7, 30, 10}, {16, 0, 3, 30}, {16, 
            1, 4, 28}, {16, 9, 3, 32}, {19, 32, 31}, {13, 30, 28, 31, 30}, {7,
             30, 24}, {40, 56, 3, 0, 24, 3, 0, 30}, {16, 10, 11, 28}, {19, 28,
             31}, {13, 30, 31, 30}, {7, 30, 26}, {41, 269, 3, 0, 11, 3, 0, 12,
             3, 0, 30}, {27, 8, 14, 30, 13, 0}, {2, 0, 5}, {41, 269, 3, 0, 26,
             3, 0, 12, 3, 0, 30}, {27, 6, 14, 30, 13, 4}, {5, 4, 3}, {3, 2}, {
            5, 2, 3}, {2, 3, 177}, {10, 0, 30}, {40, 60, 3, 0, 30, 3, 0, 
            31}, {41, 263, 3, 0, 26, 3, 0, 31, 3, 0, 30}, {7, 30, 26}, {13, 
            24, 26, 30}, {7, 30, 15}, {40, 60, 3, 0, 11, 3, 0, 30}, {7, 30, 
            17}, {16, 15, 17, 30}, {19, 30, 31}, {16, 1, 11, 30}, {16, 15, 4, 
            28}, {19, 28, 32}, {13, 30, 32, 30}, {16, 30, 17, 30}, {16, 2, 11,
             32}, {16, 15, 5, 28}, {19, 28, 29}, {13, 32, 29, 32}, {16, 32, 
            17, 32}, {34, 31, 30, 32, 3, 4}, {33, 4, 1}, {24, 1, 2, 0}, {32, 
            0, 0}, {2, 0, 3}, {49}, {3, 1}, {37, 4, 3, 3, 31}, {7, 31, 25}, {
            37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 3, 31}, {7, 31, 16}, {
            41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27, 6, 14, 31, 13, 0}, {
            2, 0, 43}, {27, 4, 14, 23, 18, 4}, {2, 4, 14}, {27, 6, 14, 23, 19,
             1}, {2, 1, 9}, {27, 6, 14, 16, 20, 5}, {2, 5, 4}, {27, 4, 14, 16,
             9, 6}, {5, 6, 7}, {3, 2}, {5, 2, 7}, {5, 7, 5}, {3, 2}, {5, 2, 
            5}, {5, 5, 1}, {3, 2}, {5, 2, 1}, {2, 1, 23}, {16, 25, 4, 31}, {
            19, 23, 30}, {13, 1, 31, 30, 32}, {40, 38, 3, 0, 32, 3, 0, 31}, {
            16, 25, 3, 32}, {40, 56, 3, 0, 23, 3, 0, 30}, {19, 30, 29}, {13, 
            21, 29, 30}, {40, 57, 3, 0, 30, 4, 0, 0}, {11, 20, 13, 1}, {11, 0,
             13, 2}, {11, 32, 13, 3}, {14, 1, 2, 3, 0, 1}, {40, 38, 4, 0, 1, 
            3, 0, 32}, {16, 25, 5, 30}, {19, 16, 29}, {13, 2, 30, 29, 28}, {
            40, 38, 3, 0, 28, 3, 0, 30}, {13, 31, 32, 30, 31}, {27, 3, 14, 31,
             22, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {5, 5, 1}, {3, 2}, {5, 2, 
            1}, {2, 1, 4}, {34, 25, 23, 16, 3, 4}, {
            42, "CopyTensor", 3, 1, 4, 3, 1, 6}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 6}, {19, 24, 31}, {7, 31, 7}, {
            13, 7, 26, 31}, {7, 31, 27}, {40, 60, 3, 0, 11, 3, 0, 31}, {7, 31,
             8}, {16, 27, 8, 31}, {16, 1, 11, 32}, {16, 27, 4, 30}, {13, 32, 
            30, 32}, {16, 32, 8, 32}, {16, 2, 11, 30}, {16, 27, 5, 28}, {13, 
            30, 28, 30}, {16, 30, 8, 30}, {34, 31, 32, 30, 3, 4}, {33, 4, 
            1}, {24, 1, 2, 1}, {32, 1, 1}, {2, 1, 3}, {49}, {3, 1}, {37, 4, 3,
             3, 31}, {7, 31, 25}, {37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 
            3, 31}, {7, 31, 16}, {41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27,
             6, 14, 31, 13, 1}, {2, 1, 43}, {27, 4, 14, 23, 18, 0}, {2, 0, 
            14}, {27, 6, 14, 23, 19, 5}, {2, 5, 9}, {27, 6, 14, 16, 20, 4}, {
            2, 4, 4}, {27, 4, 14, 16, 9, 7}, {5, 7, 6}, {3, 2}, {5, 2, 6}, {5,
             6, 4}, {3, 2}, {5, 2, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 
            23}, {16, 25, 4, 31}, {19, 23, 32}, {13, 1, 31, 32, 30}, {40, 38, 
            3, 0, 30, 3, 0, 31}, {16, 25, 3, 30}, {40, 56, 3, 0, 23, 3, 0, 
            32}, {19, 32, 28}, {13, 21, 28, 32}, {40, 57, 3, 0, 32, 4, 0, 
            1}, {11, 20, 13, 0}, {11, 0, 13, 2}, {11, 30, 13, 3}, {14, 0, 2, 
            3, 1, 0}, {40, 38, 4, 0, 0, 3, 0, 30}, {16, 25, 5, 32}, {19, 16, 
            28}, {13, 2, 32, 28, 29}, {40, 38, 3, 0, 29, 3, 0, 32}, {13, 31, 
            30, 32, 31}, {27, 3, 14, 31, 22, 0}, {5, 0, 4}, {3, 2}, {5, 2, 
            4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 4}, {34, 25, 23, 16, 3, 
            4}, {42, "CopyTensor", 3, 1, 4, 3, 1, 7}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 7}, {34, 6, 7, 0, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 3}, {38, 3, 0, 3, 1, 4}, {38, 3, 
            0, 0, 1, 6}, {
            42, "CompareTensor", 2, 0, 4, 3, 0, 14, 3, 1, 4, 3, 1, 6, 1, 0, 
             1}, {2, 1, 5}, {38, 3, 0, 3, 1, 4}, {34, 4, 0, 6}, {
            42, "CopyTensor", 3, 2, 6, 3, 2, 4}, {3, 2}, {
            42, "CopyTensor", 3, 2, 3, 3, 2, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 6}, {3, 2}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 6}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            
            Block[{Compile`$512, Compile`$513, Compile`$526, Compile`$527, 
              Compile`$528}, 
             
             Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
               Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
               Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
               Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
              Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
              Optica`Optica`TempVar4 = 1.; 
              Optica`Optica`TempVar = {{-1., 0., 0.}}; 
              Optica`Optica`RayL = 1.; Optica`Optica`SCx = 1.; 
              Optica`Optica`SCy = 1.; 
              Optica`Optica`TempVar4 = 
               Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
              Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
              Optica`Optica`TempVar1 = 
               Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 
                Optica`Optica`RSx Rational[1, 2]; 
              Optica`Optica`TempVar2 = 
               Optica`Optica`RSx Optica`Optica`RTx + 
                Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
                Optica`Optica`RTx; 
              Optica`Optica`TempVar3 = 
               Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                Optica`Optica`TempVar4; 
              Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
                And[N[
                   Chop[Optica`Optica`TempVar4]] != 0., N[
                   Chop[Optica`Optica`TempVar3]] >= 0.], 
                Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
                Optica`Optica`TempVar = {{
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$512 = 
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3; 
                    Compile`$513 = 
                    Optica`Optica`TempVar4^(-1); {-(Compile`$512 
                    Compile`$513), (Optica`Optica`RSy Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTy) 
                    Compile`$513, (Optica`Optica`RSz Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTz) Compile`$513}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$526 = -Optica`Optica`TempVar2; 
                    Compile`$527 = Compile`$526 + Optica`Optica`TempVar3; 
                    Compile`$528 = Optica`Optica`TempVar4^(-1); {
                    Compile`$527 
                    Compile`$528, (Optica`Optica`RSy Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTy) 
                    Compile`$528, (Optica`Optica`RSz Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTz) Compile`$528}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
                If[Part[Optica`Optica`TempVar, 1] == 
                  Part[Optica`Optica`TempVar, 2], {
                   Part[Optica`Optica`TempVar, 1]}, 
                  Optica`Optica`TempVar], {{-1., 0., 0.}}]]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SymbolicSurfaceIntersectionFunction -> 
         Optica`Optica`SurfaceIntersectionFunction[{
           Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
           
           Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
             Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
             Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
             Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
            Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
            Optica`Optica`TempVar4 = 1.; 
            Optica`Optica`TempVar = {{-1., 0., 0.}}; Optica`Optica`RayL = 1.; 
            Optica`Optica`SCx = 1.; Optica`Optica`SCy = 1.; 
            Optica`Optica`TempVar4 = 
             Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
            Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
            Optica`Optica`TempVar1 = 
             Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 Optica`Optica`RSx 
              Rational[1, 2]; 
            Optica`Optica`TempVar2 = 
             Optica`Optica`RSx Optica`Optica`RTx + 
              Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
              Optica`Optica`RTx; 
            Optica`Optica`TempVar3 = 
             Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
              Optica`Optica`TempVar4; 
            Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
              And[N[
                 Chop[Optica`Optica`TempVar4]] != 0., N[
                 Chop[Optica`Optica`TempVar3]] >= 0.], 
              Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
              Optica`Optica`TempVar = {{
                  
                 Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {-((Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/Optica`Optica`TempVar4), (
                    Optica`Optica`RSy Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTz)/Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {(-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSy 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTz)/
                    Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
              If[Part[Optica`Optica`TempVar, 1] == 
                Part[Optica`Optica`TempVar, 2], {
                 Part[Optica`Optica`TempVar, 1]}, 
                Optica`Optica`TempVar], {{-1., 0., 0.}}]]], 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76359, 
         Optica`Optica`SurfaceContinuation -> True, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`CylindricalShape, 
         Optica`Optica`SurfaceValue -> Rational[1, 2], 
         Optica`Optica`SurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`ActiveRegion -> 1., Optica`Optica`ComponentMedium -> 
         1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, -
             Optica`Optica`SCx (Rational[1, 4] - Optica`Optica`SCx^2)^
              Rational[-1, 2], 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{-0.5, 0.8660254037844386, 
            0}, {-0.8660254037844386, -0.5, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {0.25, -0.4330127018922193, 0}, 
         Optica`Optica`SurfaceCenter -> {
          0.24999133974596216`, -0.4330177018922193, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {0.8660254037844386, 1.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{7., {3, 0, 3}}, {0.5, {3, 0, 6}}, {
            False, {1, 0, 4}}, {-0.4330127018922193, {3, 0, 4}}, {-0.5, {3, 0,
              5}}, {0.4330127018922193, {3, 0, 2}}}, {6, 0, 7, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 0.4330127018922193, 
             Optica`Optica`SCx >= -0.4330127018922193, 
             Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {
           Rational[1, 4], Rational[-1, 4] 3^Rational[1, 2], 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{
            Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {
           Rational[-1, 2] 3^Rational[1, 2], 
            Rational[-1, 2], 0}, {0, 0, 1}}, 
         Optica`Optica`SymbolicComponentTransformation -> {{
            Rational[1, 4], Rational[-1, 4] 3^Rational[1, 2], 0}, {{
             Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {
            Rational[-1, 2] 3^Rational[1, 2], 
             Rational[-1, 2], 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> Rational[1, 2], 
         Optica`Optica`SymbolicSurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {
          Rational[1, 2] 3^Rational[1, 2], 1}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           6}}, {{{{-1., 0., 0.}}, {3, 2, 0}}, {1, {2, 0, 3}}, {
            1., {3, 0, 6}}, {1.*^-7, {3, 0, 22}}, {7., {3, 0, 14}}, {
            1.*^-10, {3, 0, 12}}, {2, {2, 0, 0}}, {0.25, {3, 0, 21}}, {
            5, {2, 0, 4}}, {0.5, {3, 0, 9}}, {False, {1, 0, 2}}, {
            0., {3, 0, 13}}, {-0.4330127018922193, {3, 0, 19}}, {
            3, {2, 0, 2}}, {-0.5, {3, 0, 20}}, {{-1., 0., 0.}, {3, 1, 2}}, {
            0.4330127018922193, {3, 0, 18}}}, {8, 5, 33, 4, 
           8}, {{7, 6, 10}, {7, 6, 24}, {7, 6, 26}, {7, 6, 11}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 3}, {7, 6, 25}, {7, 6, 23}, {7, 
            6, 16}, {40, 56, 3, 0, 3, 3, 0, 30}, {40, 56, 3, 0, 4, 3, 0, 
            28}, {13, 30, 28, 30}, {7, 30, 11}, {40, 56, 3, 0, 0, 3, 0, 30}, {
            40, 56, 3, 0, 1, 3, 0, 28}, {10, 0, 31}, {16, 31, 0, 9, 31}, {19, 
            31, 32}, {13, 30, 28, 32, 30}, {7, 30, 10}, {16, 0, 3, 30}, {16, 
            1, 4, 28}, {16, 9, 3, 32}, {19, 32, 31}, {13, 30, 28, 31, 30}, {7,
             30, 24}, {40, 56, 3, 0, 24, 3, 0, 30}, {16, 10, 11, 28}, {19, 28,
             31}, {13, 30, 31, 30}, {7, 30, 26}, {41, 269, 3, 0, 11, 3, 0, 12,
             3, 0, 30}, {27, 8, 14, 30, 13, 0}, {2, 0, 5}, {41, 269, 3, 0, 26,
             3, 0, 12, 3, 0, 30}, {27, 6, 14, 30, 13, 4}, {5, 4, 3}, {3, 2}, {
            5, 2, 3}, {2, 3, 177}, {10, 0, 30}, {40, 60, 3, 0, 30, 3, 0, 
            31}, {41, 263, 3, 0, 26, 3, 0, 31, 3, 0, 30}, {7, 30, 26}, {13, 
            24, 26, 30}, {7, 30, 15}, {40, 60, 3, 0, 11, 3, 0, 30}, {7, 30, 
            17}, {16, 15, 17, 30}, {19, 30, 31}, {16, 1, 11, 30}, {16, 15, 4, 
            28}, {19, 28, 32}, {13, 30, 32, 30}, {16, 30, 17, 30}, {16, 2, 11,
             32}, {16, 15, 5, 28}, {19, 28, 29}, {13, 32, 29, 32}, {16, 32, 
            17, 32}, {34, 31, 30, 32, 3, 4}, {33, 4, 1}, {24, 1, 2, 0}, {32, 
            0, 0}, {2, 0, 3}, {49}, {3, 1}, {37, 4, 3, 3, 31}, {7, 31, 25}, {
            37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 3, 31}, {7, 31, 16}, {
            41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27, 6, 14, 31, 13, 0}, {
            2, 0, 43}, {27, 4, 14, 23, 18, 4}, {2, 4, 14}, {27, 6, 14, 23, 19,
             1}, {2, 1, 9}, {27, 6, 14, 16, 20, 5}, {2, 5, 4}, {27, 4, 14, 16,
             9, 6}, {5, 6, 7}, {3, 2}, {5, 2, 7}, {5, 7, 5}, {3, 2}, {5, 2, 
            5}, {5, 5, 1}, {3, 2}, {5, 2, 1}, {2, 1, 23}, {16, 25, 4, 31}, {
            19, 23, 30}, {13, 1, 31, 30, 32}, {40, 38, 3, 0, 32, 3, 0, 31}, {
            16, 25, 3, 32}, {40, 56, 3, 0, 23, 3, 0, 30}, {19, 30, 29}, {13, 
            21, 29, 30}, {40, 57, 3, 0, 30, 4, 0, 0}, {11, 20, 13, 1}, {11, 0,
             13, 2}, {11, 32, 13, 3}, {14, 1, 2, 3, 0, 1}, {40, 38, 4, 0, 1, 
            3, 0, 32}, {16, 25, 5, 30}, {19, 16, 29}, {13, 2, 30, 29, 28}, {
            40, 38, 3, 0, 28, 3, 0, 30}, {13, 31, 32, 30, 31}, {27, 3, 14, 31,
             22, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {5, 5, 1}, {3, 2}, {5, 2, 
            1}, {2, 1, 4}, {34, 25, 23, 16, 3, 4}, {
            42, "CopyTensor", 3, 1, 4, 3, 1, 6}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 6}, {19, 24, 31}, {7, 31, 7}, {
            13, 7, 26, 31}, {7, 31, 27}, {40, 60, 3, 0, 11, 3, 0, 31}, {7, 31,
             8}, {16, 27, 8, 31}, {16, 1, 11, 32}, {16, 27, 4, 30}, {13, 32, 
            30, 32}, {16, 32, 8, 32}, {16, 2, 11, 30}, {16, 27, 5, 28}, {13, 
            30, 28, 30}, {16, 30, 8, 30}, {34, 31, 32, 30, 3, 4}, {33, 4, 
            1}, {24, 1, 2, 1}, {32, 1, 1}, {2, 1, 3}, {49}, {3, 1}, {37, 4, 3,
             3, 31}, {7, 31, 25}, {37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 
            3, 31}, {7, 31, 16}, {41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27,
             6, 14, 31, 13, 1}, {2, 1, 43}, {27, 4, 14, 23, 18, 0}, {2, 0, 
            14}, {27, 6, 14, 23, 19, 5}, {2, 5, 9}, {27, 6, 14, 16, 20, 4}, {
            2, 4, 4}, {27, 4, 14, 16, 9, 7}, {5, 7, 6}, {3, 2}, {5, 2, 6}, {5,
             6, 4}, {3, 2}, {5, 2, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 
            23}, {16, 25, 4, 31}, {19, 23, 32}, {13, 1, 31, 32, 30}, {40, 38, 
            3, 0, 30, 3, 0, 31}, {16, 25, 3, 30}, {40, 56, 3, 0, 23, 3, 0, 
            32}, {19, 32, 28}, {13, 21, 28, 32}, {40, 57, 3, 0, 32, 4, 0, 
            1}, {11, 20, 13, 0}, {11, 0, 13, 2}, {11, 30, 13, 3}, {14, 0, 2, 
            3, 1, 0}, {40, 38, 4, 0, 0, 3, 0, 30}, {16, 25, 5, 32}, {19, 16, 
            28}, {13, 2, 32, 28, 29}, {40, 38, 3, 0, 29, 3, 0, 32}, {13, 31, 
            30, 32, 31}, {27, 3, 14, 31, 22, 0}, {5, 0, 4}, {3, 2}, {5, 2, 
            4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 4}, {34, 25, 23, 16, 3, 
            4}, {42, "CopyTensor", 3, 1, 4, 3, 1, 7}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 7}, {34, 6, 7, 0, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 3}, {38, 3, 0, 3, 1, 4}, {38, 3, 
            0, 0, 1, 6}, {
            42, "CompareTensor", 2, 0, 4, 3, 0, 14, 3, 1, 4, 3, 1, 6, 1, 0, 
             1}, {2, 1, 5}, {38, 3, 0, 3, 1, 4}, {34, 4, 0, 6}, {
            42, "CopyTensor", 3, 2, 6, 3, 2, 4}, {3, 2}, {
            42, "CopyTensor", 3, 2, 3, 3, 2, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 6}, {3, 2}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 6}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            
            Block[{Compile`$512, Compile`$513, Compile`$526, Compile`$527, 
              Compile`$528}, 
             
             Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
               Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
               Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
               Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
              Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
              Optica`Optica`TempVar4 = 1.; 
              Optica`Optica`TempVar = {{-1., 0., 0.}}; 
              Optica`Optica`RayL = 1.; Optica`Optica`SCx = 1.; 
              Optica`Optica`SCy = 1.; 
              Optica`Optica`TempVar4 = 
               Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
              Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
              Optica`Optica`TempVar1 = 
               Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 
                Optica`Optica`RSx Rational[1, 2]; 
              Optica`Optica`TempVar2 = 
               Optica`Optica`RSx Optica`Optica`RTx + 
                Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
                Optica`Optica`RTx; 
              Optica`Optica`TempVar3 = 
               Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                Optica`Optica`TempVar4; 
              Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
                And[N[
                   Chop[Optica`Optica`TempVar4]] != 0., N[
                   Chop[Optica`Optica`TempVar3]] >= 0.], 
                Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
                Optica`Optica`TempVar = {{
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$512 = 
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3; 
                    Compile`$513 = 
                    Optica`Optica`TempVar4^(-1); {-(Compile`$512 
                    Compile`$513), (Optica`Optica`RSy Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTy) 
                    Compile`$513, (Optica`Optica`RSz Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTz) Compile`$513}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$526 = -Optica`Optica`TempVar2; 
                    Compile`$527 = Compile`$526 + Optica`Optica`TempVar3; 
                    Compile`$528 = Optica`Optica`TempVar4^(-1); {
                    Compile`$527 
                    Compile`$528, (Optica`Optica`RSy Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTy) 
                    Compile`$528, (Optica`Optica`RSz Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTz) Compile`$528}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
                If[Part[Optica`Optica`TempVar, 1] == 
                  Part[Optica`Optica`TempVar, 2], {
                   Part[Optica`Optica`TempVar, 1]}, 
                  Optica`Optica`TempVar], {{-1., 0., 0.}}]]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SymbolicSurfaceIntersectionFunction -> 
         Optica`Optica`SurfaceIntersectionFunction[{
           Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
           
           Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
             Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
             Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
             Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
            Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
            Optica`Optica`TempVar4 = 1.; 
            Optica`Optica`TempVar = {{-1., 0., 0.}}; Optica`Optica`RayL = 1.; 
            Optica`Optica`SCx = 1.; Optica`Optica`SCy = 1.; 
            Optica`Optica`TempVar4 = 
             Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
            Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
            Optica`Optica`TempVar1 = 
             Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 Optica`Optica`RSx 
              Rational[1, 2]; 
            Optica`Optica`TempVar2 = 
             Optica`Optica`RSx Optica`Optica`RTx + 
              Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
              Optica`Optica`RTx; 
            Optica`Optica`TempVar3 = 
             Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
              Optica`Optica`TempVar4; 
            Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
              And[N[
                 Chop[Optica`Optica`TempVar4]] != 0., N[
                 Chop[Optica`Optica`TempVar3]] >= 0.], 
              Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
              Optica`Optica`TempVar = {{
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {-((Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/Optica`Optica`TempVar4), (
                    Optica`Optica`RSy Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTz)/Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {(-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSy 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTz)/
                    Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
              If[Part[Optica`Optica`TempVar, 1] == 
                Part[Optica`Optica`TempVar, 2], {
                 Part[Optica`Optica`TempVar, 1]}, 
                Optica`Optica`TempVar], {{-1., 0., 0.}}]]], 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76359, 
         Optica`Optica`SurfaceContinuation -> True, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`CylindricalShape, 
         Optica`Optica`SurfaceValue -> Rational[1, 2], 
         Optica`Optica`SurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`ActiveRegion -> 1., Optica`Optica`ComponentMedium -> 
         1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, -
             Optica`Optica`SCx (Rational[1, 4] - Optica`Optica`SCx^2)^
              Rational[-1, 2], 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{-0.5, -0.8660254037844386, 0}, {
           0.8660254037844386, -0.5, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {0.25, 0.4330127018922193, 0}, 
         Optica`Optica`SurfaceCenter -> {0.25000866025403784`, 
          0.4330077018922193, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {0.8660254037844386, 1.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{7., {3, 0, 3}}, {0.5, {3, 0, 6}}, {
            False, {1, 0, 4}}, {-0.4330127018922193, {3, 0, 4}}, {-0.5, {3, 0,
              5}}, {0.4330127018922193, {3, 0, 2}}}, {6, 0, 7, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 0.4330127018922193, 
             Optica`Optica`SCx >= -0.4330127018922193, 
             Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {
           Rational[1, 4], Rational[1, 4] 3^Rational[1, 2], 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{
            Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {
           Rational[1, 2] 3^Rational[1, 2], 
            Rational[-1, 2], 0}, {0, 0, 1}}, 
         Optica`Optica`SymbolicComponentTransformation -> {{
            Rational[1, 4], Rational[1, 4] 3^Rational[1, 2], 0}, {{
             Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {
            Rational[1, 2] 3^Rational[1, 2], 
             Rational[-1, 2], 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> Rational[1, 2], 
         Optica`Optica`SymbolicSurfaceFunction -> ({
          Rational[1, 2] - (Rational[1, 4] - #^2)^Rational[1, 2], #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{
           1, -((1 #)/(Rational[1, 4] - #^2)^(1/2)), 
            0}, {(1 #)/(Rational[1, 4] - #^2)^(1/2), 1, 0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {
          Rational[1, 2] 3^Rational[1, 2], 1}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           6}}, {{{{-1., 0., 0.}}, {3, 2, 0}}, {1, {2, 0, 3}}, {
            1., {3, 0, 6}}, {1.*^-7, {3, 0, 22}}, {7., {3, 0, 14}}, {
            1.*^-10, {3, 0, 12}}, {2, {2, 0, 0}}, {0.25, {3, 0, 21}}, {
            5, {2, 0, 4}}, {0.5, {3, 0, 9}}, {False, {1, 0, 2}}, {
            0., {3, 0, 13}}, {-0.4330127018922193, {3, 0, 19}}, {
            3, {2, 0, 2}}, {-0.5, {3, 0, 20}}, {{-1., 0., 0.}, {3, 1, 2}}, {
            0.4330127018922193, {3, 0, 18}}}, {8, 5, 33, 4, 
           8}, {{7, 6, 10}, {7, 6, 24}, {7, 6, 26}, {7, 6, 11}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 3}, {7, 6, 25}, {7, 6, 23}, {7, 
            6, 16}, {40, 56, 3, 0, 3, 3, 0, 30}, {40, 56, 3, 0, 4, 3, 0, 
            28}, {13, 30, 28, 30}, {7, 30, 11}, {40, 56, 3, 0, 0, 3, 0, 30}, {
            40, 56, 3, 0, 1, 3, 0, 28}, {10, 0, 31}, {16, 31, 0, 9, 31}, {19, 
            31, 32}, {13, 30, 28, 32, 30}, {7, 30, 10}, {16, 0, 3, 30}, {16, 
            1, 4, 28}, {16, 9, 3, 32}, {19, 32, 31}, {13, 30, 28, 31, 30}, {7,
             30, 24}, {40, 56, 3, 0, 24, 3, 0, 30}, {16, 10, 11, 28}, {19, 28,
             31}, {13, 30, 31, 30}, {7, 30, 26}, {41, 269, 3, 0, 11, 3, 0, 12,
             3, 0, 30}, {27, 8, 14, 30, 13, 0}, {2, 0, 5}, {41, 269, 3, 0, 26,
             3, 0, 12, 3, 0, 30}, {27, 6, 14, 30, 13, 4}, {5, 4, 3}, {3, 2}, {
            5, 2, 3}, {2, 3, 177}, {10, 0, 30}, {40, 60, 3, 0, 30, 3, 0, 
            31}, {41, 263, 3, 0, 26, 3, 0, 31, 3, 0, 30}, {7, 30, 26}, {13, 
            24, 26, 30}, {7, 30, 15}, {40, 60, 3, 0, 11, 3, 0, 30}, {7, 30, 
            17}, {16, 15, 17, 30}, {19, 30, 31}, {16, 1, 11, 30}, {16, 15, 4, 
            28}, {19, 28, 32}, {13, 30, 32, 30}, {16, 30, 17, 30}, {16, 2, 11,
             32}, {16, 15, 5, 28}, {19, 28, 29}, {13, 32, 29, 32}, {16, 32, 
            17, 32}, {34, 31, 30, 32, 3, 4}, {33, 4, 1}, {24, 1, 2, 0}, {32, 
            0, 0}, {2, 0, 3}, {49}, {3, 1}, {37, 4, 3, 3, 31}, {7, 31, 25}, {
            37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 3, 31}, {7, 31, 16}, {
            41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27, 6, 14, 31, 13, 0}, {
            2, 0, 43}, {27, 4, 14, 23, 18, 4}, {2, 4, 14}, {27, 6, 14, 23, 19,
             1}, {2, 1, 9}, {27, 6, 14, 16, 20, 5}, {2, 5, 4}, {27, 4, 14, 16,
             9, 6}, {5, 6, 7}, {3, 2}, {5, 2, 7}, {5, 7, 5}, {3, 2}, {5, 2, 
            5}, {5, 5, 1}, {3, 2}, {5, 2, 1}, {2, 1, 23}, {16, 25, 4, 31}, {
            19, 23, 30}, {13, 1, 31, 30, 32}, {40, 38, 3, 0, 32, 3, 0, 31}, {
            16, 25, 3, 32}, {40, 56, 3, 0, 23, 3, 0, 30}, {19, 30, 29}, {13, 
            21, 29, 30}, {40, 57, 3, 0, 30, 4, 0, 0}, {11, 20, 13, 1}, {11, 0,
             13, 2}, {11, 32, 13, 3}, {14, 1, 2, 3, 0, 1}, {40, 38, 4, 0, 1, 
            3, 0, 32}, {16, 25, 5, 30}, {19, 16, 29}, {13, 2, 30, 29, 28}, {
            40, 38, 3, 0, 28, 3, 0, 30}, {13, 31, 32, 30, 31}, {27, 3, 14, 31,
             22, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {5, 5, 1}, {3, 2}, {5, 2, 
            1}, {2, 1, 4}, {34, 25, 23, 16, 3, 4}, {
            42, "CopyTensor", 3, 1, 4, 3, 1, 6}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 6}, {19, 24, 31}, {7, 31, 7}, {
            13, 7, 26, 31}, {7, 31, 27}, {40, 60, 3, 0, 11, 3, 0, 31}, {7, 31,
             8}, {16, 27, 8, 31}, {16, 1, 11, 32}, {16, 27, 4, 30}, {13, 32, 
            30, 32}, {16, 32, 8, 32}, {16, 2, 11, 30}, {16, 27, 5, 28}, {13, 
            30, 28, 30}, {16, 30, 8, 30}, {34, 31, 32, 30, 3, 4}, {33, 4, 
            1}, {24, 1, 2, 1}, {32, 1, 1}, {2, 1, 3}, {49}, {3, 1}, {37, 4, 3,
             3, 31}, {7, 31, 25}, {37, 4, 0, 3, 31}, {7, 31, 23}, {37, 4, 2, 
            3, 31}, {7, 31, 16}, {41, 269, 3, 0, 25, 3, 0, 12, 3, 0, 31}, {27,
             6, 14, 31, 13, 1}, {2, 1, 43}, {27, 4, 14, 23, 18, 0}, {2, 0, 
            14}, {27, 6, 14, 23, 19, 5}, {2, 5, 9}, {27, 6, 14, 16, 20, 4}, {
            2, 4, 4}, {27, 4, 14, 16, 9, 7}, {5, 7, 6}, {3, 2}, {5, 2, 6}, {5,
             6, 4}, {3, 2}, {5, 2, 4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 
            23}, {16, 25, 4, 31}, {19, 23, 32}, {13, 1, 31, 32, 30}, {40, 38, 
            3, 0, 30, 3, 0, 31}, {16, 25, 3, 30}, {40, 56, 3, 0, 23, 3, 0, 
            32}, {19, 32, 28}, {13, 21, 28, 32}, {40, 57, 3, 0, 32, 4, 0, 
            1}, {11, 20, 13, 0}, {11, 0, 13, 2}, {11, 30, 13, 3}, {14, 0, 2, 
            3, 1, 0}, {40, 38, 4, 0, 0, 3, 0, 30}, {16, 25, 5, 32}, {19, 16, 
            28}, {13, 2, 32, 28, 29}, {40, 38, 3, 0, 29, 3, 0, 32}, {13, 31, 
            30, 32, 31}, {27, 3, 14, 31, 22, 0}, {5, 0, 4}, {3, 2}, {5, 2, 
            4}, {5, 4, 5}, {3, 2}, {5, 2, 5}, {2, 5, 4}, {34, 25, 23, 16, 3, 
            4}, {42, "CopyTensor", 3, 1, 4, 3, 1, 7}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 7}, {34, 6, 7, 0, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 3}, {38, 3, 0, 3, 1, 4}, {38, 3, 
            0, 0, 1, 6}, {
            42, "CompareTensor", 2, 0, 4, 3, 0, 14, 3, 1, 4, 3, 1, 6, 1, 0, 
             1}, {2, 1, 5}, {38, 3, 0, 3, 1, 4}, {34, 4, 0, 6}, {
            42, "CopyTensor", 3, 2, 6, 3, 2, 4}, {3, 2}, {
            42, "CopyTensor", 3, 2, 3, 3, 2, 4}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 6}, {3, 2}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 6}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            
            Block[{Compile`$512, Compile`$513, Compile`$526, Compile`$527, 
              Compile`$528}, 
             
             Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
               Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
               Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
               Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
              Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
              Optica`Optica`TempVar4 = 1.; 
              Optica`Optica`TempVar = {{-1., 0., 0.}}; 
              Optica`Optica`RayL = 1.; Optica`Optica`SCx = 1.; 
              Optica`Optica`SCy = 1.; 
              Optica`Optica`TempVar4 = 
               Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
              Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
              Optica`Optica`TempVar1 = 
               Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 
                Optica`Optica`RSx Rational[1, 2]; 
              Optica`Optica`TempVar2 = 
               Optica`Optica`RSx Optica`Optica`RTx + 
                Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
                Optica`Optica`RTx; 
              Optica`Optica`TempVar3 = 
               Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
                Optica`Optica`TempVar4; 
              Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
                And[N[
                   Chop[Optica`Optica`TempVar4]] != 0., N[
                   Chop[Optica`Optica`TempVar3]] >= 0.], 
                Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
                Optica`Optica`TempVar = {{
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$512 = 
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3; 
                    Compile`$513 = 
                    Optica`Optica`TempVar4^(-1); {-(Compile`$512 
                    Compile`$513), (Optica`Optica`RSy Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTy) 
                    Compile`$513, (Optica`Optica`RSz Optica`Optica`TempVar4 - 
                    Compile`$512 Optica`Optica`RTz) Compile`$513}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = (
                    Compile`$526 = -Optica`Optica`TempVar2; 
                    Compile`$527 = Compile`$526 + Optica`Optica`TempVar3; 
                    Compile`$528 = Optica`Optica`TempVar4^(-1); {
                    Compile`$527 
                    Compile`$528, (Optica`Optica`RSy Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTy) 
                    Compile`$528, (Optica`Optica`RSz Optica`Optica`TempVar4 + 
                    Compile`$527 Optica`Optica`RTz) Compile`$528}); If[
                    And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                    Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
                If[Part[Optica`Optica`TempVar, 1] == 
                  Part[Optica`Optica`TempVar, 2], {
                   Part[Optica`Optica`TempVar, 1]}, 
                  Optica`Optica`TempVar], {{-1., 0., 0.}}]]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SymbolicSurfaceIntersectionFunction -> 
         Optica`Optica`SurfaceIntersectionFunction[{
           Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
           
           Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
             Optica`Optica`TempVar2, Optica`Optica`TempVar3, 
             Optica`Optica`TempVar4, Optica`Optica`RayL, Optica`Optica`SCx, 
             Optica`Optica`SCy}, Optica`Optica`TempVar1 = 1.; 
            Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
            Optica`Optica`TempVar4 = 1.; 
            Optica`Optica`TempVar = {{-1., 0., 0.}}; Optica`Optica`RayL = 1.; 
            Optica`Optica`SCx = 1.; Optica`Optica`SCy = 1.; 
            Optica`Optica`TempVar4 = 
             Optica`Optica`RTx^2 + Optica`Optica`RTy^2; 
            Optica`Optica`TempVar4 = Re[Optica`Optica`TempVar4]; 
            Optica`Optica`TempVar1 = 
             Optica`Optica`RSx^2 + Optica`Optica`RSy^2 - 2 Optica`Optica`RSx 
              Rational[1, 2]; 
            Optica`Optica`TempVar2 = 
             Optica`Optica`RSx Optica`Optica`RTx + 
              Optica`Optica`RSy Optica`Optica`RTy - Rational[1, 2] 
              Optica`Optica`RTx; 
            Optica`Optica`TempVar3 = 
             Optica`Optica`TempVar2^2 - Optica`Optica`TempVar1 
              Optica`Optica`TempVar4; 
            Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; If[
              And[N[
                 Chop[Optica`Optica`TempVar4]] != 0., N[
                 Chop[Optica`Optica`TempVar3]] >= 0.], 
              Optica`Optica`TempVar3 = Optica`Optica`TempVar3^(1/2); 
              Optica`Optica`TempVar = {{
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {-((Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/Optica`Optica`TempVar4), (
                    Optica`Optica`RSy Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz Optica`Optica`TempVar4 - (
                    Optica`Optica`TempVar2 + Optica`Optica`TempVar3) 
                    Optica`Optica`RTz)/Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[
                    Optica`Optica`RSz + Optica`Optica`RayL Optica`Optica`RTz - 
                    Optica`Optica`SCy] < 1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy} = {(-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSy 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTy)/
                    Optica`Optica`TempVar4, (
                    Optica`Optica`RSz 
                    Optica`Optica`TempVar4 + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) Optica`Optica`RTz)/
                    Optica`Optica`TempVar4}; If[
                   And[N[
                    Chop[Optica`Optica`RayL]] >= 0., 
                    And[
                    Optica`Optica`SCx <= 0.4330127018922193, 
                    Optica`Optica`SCx >= -0.4330127018922193, 
                    Optica`Optica`SCy >= -0.5, Optica`Optica`SCy <= 0.5], 
                    Abs[Optica`Optica`RSy + 
                    Optica`Optica`RayL Optica`Optica`RTy - Optica`Optica`SCx] + 
                    Abs[Rational[-1, 2] + Optica`Optica`RSx + 
                    Optica`Optica`RayL 
                    Optica`Optica`RTx + (Rational[1, 4] - 
                    Optica`Optica`SCx^2)^Rational[1, 2]] + 
                    Abs[Optica`Optica`RSz + 
                    Optica`Optica`RayL Optica`Optica`RTz - Optica`Optica`SCy] < 
                    1.*^-7], {
                   Optica`Optica`RayL, Optica`Optica`SCx, 
                    Optica`Optica`SCy}, {-1., 0., 0.}]}; 
              If[Part[Optica`Optica`TempVar, 1] == 
                Part[Optica`Optica`TempVar, 2], {
                 Part[Optica`Optica`TempVar, 1]}, 
                Optica`Optica`TempVar], {{-1., 0., 0.}}]]], 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}, {
        Optica`Optica`ComponentID -> 76509, Optica`Optica`SurfaceID -> 76513, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> -1., 
         Optica`Optica`ComponentMedium -> 1.48, Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, -1.}, {0, -1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {0, 0, -0.5}, 
         Optica`Optica`SurfaceCenter -> {-0.00001, -0.00001, -0.5}, 
         Optica`Optica`SurfaceBoundary -> 1., 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           0}}, {{7., {3, 0, 5}}, {0.25, {3, 0, 4}}}, {1, 0, 6, 0, 
           0}, {{40, 56, 3, 0, 0, 3, 0, 2}, {40, 56, 3, 0, 1, 3, 0, 3}, {13, 
            2, 3, 2}, {27, 4, 5, 2, 4, 0}, {1}}, 
           
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            Optica`Optica`SCx^2 + Optica`Optica`SCy^2 <= 0.25], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {0, 0, 
           Rational[-1, 2]}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, -1}, {0, -1, 0}, {-1,
           0, 0}}, Optica`Optica`SymbolicComponentTransformation -> {{0, 0, 
            Rational[-1, 2]}, {{0, 0, -1}, {0, -1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> 1, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {1, {2, 0, 1}}, {
            7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {2, {2, 0, 2}}, {
            0.25, {3, 0, 14}}, {False, {1, 0, 3}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}}, {5, 4,
            15, 0, 5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27,
             8, 9, 7, 8, 0}, {2, 0, 37}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 
            7, 8}, {19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {
            13, 1, 11, 8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13,
             2, 12, 11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 
            269, 3, 0, 10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 
            9}, {38, 0, 0, 2, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 11}, {38, 0, 0, 
            3, 0, 8}, {40, 56, 3, 0, 8, 3, 0, 12}, {13, 11, 12, 11}, {27, 4, 
            9, 11, 14, 2}, {5, 2, 4}, {3, 2}, {5, 3, 4}, {2, 4, 7}, {38, 0, 0,
             1, 0, 11}, {38, 0, 0, 2, 0, 8}, {38, 0, 0, 3, 0, 10}, {34, 11, 8,
             10, 3, 1}, {42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$474}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 0.25], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$474 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$474), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$474, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$474}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
         Optica`Optica`ComponentTransformation -> {{0., 0., 0.}, {{1., 0., 
           0.}, {0., 1., 0.}, {0., 0., 1.}}}}}, 
      Optica`Optica`Deflections :> {{{
         Optica`Optica`DeflectionID -> 76450, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76450, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76457, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76457, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76464, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76464, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76471, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76471, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76478, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Refraction, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Refraction, {
            True, Optica`Optica`NoCoating, {
             Optica`Optica`IntrinsicMedium, 1.48}}, {
            True, {{Optica`Optica`IntrinsicMedium}, {
              Optica`Optica`IndicesAA1S48AA3, 1.48, {
               Optica`Optica`Temperature, Optica`Optica`Tension, {
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {1, 0, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 1, 0}], 
                 Dot[
                  Transpose[Optica`Optica`SurfaceNormalMatrix], {0, 0, 
                  1}]}}& }}, Optica`Optica`NoCoating, False, False, 76478, 
             Optica`Optica`OriginalRay}}, 
          Optica`Optica`SymbolicDeflectionFunction -> {
           Optica`Optica`Refraction, {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`Intensity -> {Optica`Optica`IntrinsicMedium, 1.48}, 
            Optica`Optica`FresnelReflections -> True, Optica`Optica`Theory -> 
            Optica`Optica`NoCoating}}}, {{
         Optica`Optica`DeflectionID -> 76488, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Resonate, Optica`Optica`ComponentLabel -> 
          Optica`Optica`RodLens, Options -> {}, 
          AddTo -> {Optica`Optica`CreatedRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {
           Optica`Optica`CreatedRay, Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Resonate, False, {
            Optica`Optica`CreatedRay, Optica`Optica`OriginalRay}}}}}, 
      Optica`Optica`EntranceCoordinates :> {{-0.5, 0.00001, 0.00001}, {
       0.24999133974596216`, -0.4330177018922193, 0.00001}, {
       0.25000866025403784`, 0.4330077018922193, 0.00001}}, 
      Optica`Optica`ConfinedPaths :> {{{
         Optica`Optica`SurfaceNumber -> 2, 
          Optica`Optica`DeflectionNumber -> {2, 6}}}, {{
         Optica`Optica`SurfaceNumber -> 3, 
          Optica`Optica`DeflectionNumber -> {3, 6}}}, {{
         Optica`Optica`SurfaceNumber -> 4, 
          Optica`Optica`DeflectionNumber -> {4, 6}}}}, 
      Optica`Optica`RenderedSurfaces :> {{
        Optica`Optica`SurfaceNumber -> 2, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Mesh}, {Optica`Optica`SurfaceNumber -> 3, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Mesh}, {Optica`Optica`SurfaceNumber -> 4, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Mesh}}, Optica`Optica`RenderedPolygons :> {{{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {-0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {0.4330127018922193, 0.}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {-0.4330127018922193, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., -0.5}, 
           Optica`Optica`FinishPoint -> {0., 0.5}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., 0.5}, 
           Optica`Optica`FinishPoint -> {0., -0.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {-0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {0.4330127018922193, 0.}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {-0.4330127018922193, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., -0.5}, 
           Optica`Optica`FinishPoint -> {0., 0.5}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., 0.5}, 
           Optica`Optica`FinishPoint -> {0., -0.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {-0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {0.4330127018922193, 0.}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0.4330127018922193, 0.}, 
           Optica`Optica`FinishPoint -> {-0.4330127018922193, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Trace}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., -0.5}, 
           Optica`Optica`FinishPoint -> {0., 0.5}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., 0.5}, 
           Optica`Optica`FinishPoint -> {0., -0.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> Trace}}},
       Optica`Optica`SymbolicValues :> {}, 
      Options :> {
       Optica`Optica`ComponentLabel -> Optica`Optica`RemoveSurface, 
        CompoundExpression -> True, Optica`Optica`GraphicDesign -> Automatic, 
        PlotPoints -> 10, Optica`Optica`WaveFrontID -> False}], 
     Optica`Optica`HeldComponent[
     Optica`Optica`ComponentID :> 79824, Optica`Optica`ComponentDescription :> 
      Optica`Optica`ComponentDescription[
        Optica`Optica`ClearBoundary[{0, -5, -5}, {9, 5, 5}, 
         Optica`Optica`ComponentLabel -> "", 
         Optica`Optica`SymbolicComponentTransformation -> {{0.75, -0.4, 0}, {{
           1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
         Optica`Optica`ComponentTransformation -> {{
           0.75, -0.4, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}]], 
      Optica`Optica`TranslationVector :> {0.75, -0.4, 0}, 
      RotationMatrix :> {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}, 
      Optica`Optica`Labels :> {""}, 
      Optica`Optica`LabelPositions :> {{0.75, -0.4, 0}}, 
      EdgeStyle :> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CrossStyle :> {
       Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}, 
      Optica`Optica`CatalogInformation :> {{}, {}, {}, {}, {}, {}}, 
      Optica`Optica`Surfaces :> {{
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79830, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{-1., 0, 0}, {0, -1., 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {9.75, -0.4, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           9.75, -0.4, 0}, {{-1., 0, 0}, {0, -1., 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {9.75, -0.40001000000000003`, 
          0.00001}, Optica`Optica`SurfaceBoundary -> {10., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}}, {6, 0, 5, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 4, 2}, {2, 2, 4}, {27, 4, 3, 1, 2, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {9.75, -0.4, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{-1, 0, 0}, {0, -1, 0}, {0, 
          0, 1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           9.75, -0.4, 0}, {{-1, 0, 0}, {0, -1, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {10, 10}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {False, {1, 0, 6}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}}, {8,
            4, 16, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 15, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 14, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 10}, {38, 0, 0, 3, 0, 
            11}, {34, 8, 10, 11, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$484}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$484 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$484), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$484, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$484}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79831, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 1., 0}, {-1., 0, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {5.25, -5.4, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           5.25, -5.4, 0}, {{0, 1., 0}, {-1., 0, 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {5.24999, -5.4, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {9., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 6}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 4}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 5}}, {4.5, {3, 0, 2}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 4.5, Optica`Optica`SCx >= -4.5, 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, -5.4, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 1, 0}, {-1, 0, 0}, {0, 
          0, 1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           5.25, -5.4, 0}, {{0, 1, 0}, {-1, 0, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {9, 10},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 17}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 15}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 16}}, {
            4.5, {3, 0, 14}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$489}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 4.5, Part[#, 2] >= -4.5, Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$489 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$489), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$489, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$489}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79832, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {0.75, -0.4, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           0.75, -0.4, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {0.75, -0.39999, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {10., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}}, {6, 0, 5, 0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 4, 2}, {2, 2, 4}, {27, 4, 3, 1, 2, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {0.75, -0.4, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           0.75, -0.4, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), 
         Optica`Optica`SymbolicSurfaceBoundary -> {10, 10}, 
         Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {False, {1, 0, 6}}, {0., {3, 0, 13}}, {
            0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}}, {8,
            4, 16, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 15, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 14, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 10}, {38, 0, 0, 3, 0, 
            11}, {34, 8, 10, 11, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$484}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$484 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$484), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$484, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$484}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79833, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, -1., 0}, {1., 0, 0}, {0, 0, 1.}}, 
         Optica`Optica`TranslationVector -> {5.25, 4.6, 0}, 
         Optica`Optica`ComponentTransformation -> {{
           5.25, 4.6, 0}, {{0, -1., 0}, {1., 0, 0}, {0, 0, 1.}}}, 
         Optica`Optica`SurfaceCenter -> {5.25001, 4.6, 0.00001}, 
         Optica`Optica`SurfaceBoundary -> {9., 10.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 6}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 4}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 5}}, {4.5, {3, 0, 2}}}, {6, 0, 7, 
           0, 
           0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 1, 
            9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3, 
            5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 4.5, Optica`Optica`SCx >= -4.5, 
             Optica`Optica`SCy >= -5., Optica`Optica`SCy <= 5.]], Evaluate], 
         Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False, 
         Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, 4.6, 0}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, -1, 0}, {1, 0, 0}, {0, 
          0, 1}}, Optica`Optica`SymbolicComponentTransformation -> {{
           5.25, 4.6, 0}, {{0, -1, 0}, {1, 0, 0}, {0, 0, 1}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {9, 10},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 17}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 15}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 16}}, {
            4.5, {3, 0, 14}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$489}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 4.5, Part[#, 2] >= -4.5, Part[#, 3] >= -5., 
                  Part[#, 3] <= 5.]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$489 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$489), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$489, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$489}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79834, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, 1.}, {0, 1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {5.25, -0.4, -5.}, 
         Optica`Optica`ComponentTransformation -> {{
           5.25, -0.4, -5.}, {{0, 0, 1.}, {0, 1., 0}, {-1., 0, 0}}}, 
         Optica`Optica`SurfaceCenter -> {5.24999, -0.39999, -5.}, 
         Optica`Optica`SurfaceBoundary -> {10., 9.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 5}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}, {4.5, {3, 0, 6}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -4.5, Optica`Optica`SCy <= 4.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, -0.4, -5}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, 1}, {0, 1, 0}, {-1, 
          0, 0}}, Optica`Optica`SymbolicComponentTransformation -> {{
           5.25, -0.4, -5}, {{0, 0, 1}, {0, 1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {10, 9},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 16}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}, {
            4.5, {3, 0, 17}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$488}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -4.5, 
                  Part[#, 3] <= 4.5]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$488 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$488), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$488, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$488}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}, {
        Optica`Optica`ComponentID -> 79824, Optica`Optica`SurfaceID -> 79835, 
         Optica`Optica`SurfaceContinuation -> False, 
         Optica`Optica`ActiveComponent -> True, 
         Optica`Optica`SurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SurfaceLabel -> Optica`Optica`PlanarShape, 
         Optica`Optica`SurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 0}, {0, 0,
           1}}& ), Optica`Optica`ActiveRegion -> 0., 
         Optica`Optica`ComponentMedium -> Automatic, 
         Optica`Optica`JacobianMatrix -> 
         Function[{
           Optica`Optica`RayL, Optica`Optica`SCx, Optica`Optica`SCy, 
            Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, {{
            Optica`Optica`RTx, 0, 0}, {Optica`Optica`RTy, -1, 0}, {
            Optica`Optica`RTz, 0, -1}}], 
         Optica`Optica`SurfaceRayIntersections -> Automatic, 
         RotationMatrix -> {{0, 0, -1.}, {0, -1., 0}, {-1., 0, 0}}, 
         Optica`Optica`TranslationVector -> {5.25, -0.4, 5.}, 
         Optica`Optica`ComponentTransformation -> {{5.25, -0.4, 
           5.}, {{0, 0, -1.}, {0, -1., 0}, {-1., 0, 0}}}, 
         Optica`Optica`SurfaceCenter -> {5.24999, -0.40001000000000003`, 5.}, 
         Optica`Optica`SurfaceBoundary -> {10., 9.}, 
         Optica`Optica`InsideSurfaceBoundaryQ -> 
         Optica`Optica`InsideSurfaceBoundaryQ[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {1, 0, 
           1}}, {{5., {3, 0, 2}}, {7., {3, 0, 3}}, {-4.5, {3, 0, 5}}, {
            False, {1, 0, 4}}, {-5., {3, 0, 4}}, {4.5, {3, 0, 6}}}, {6, 0, 7, 
           0, 0}, {{27, 4, 3, 0, 2, 0}, {2, 0, 14}, {27, 6, 3, 0, 4, 1}, {2, 
            1, 9}, {27, 6, 3, 1, 5, 2}, {2, 2, 4}, {27, 4, 3, 1, 6, 3}, {5, 3,
             5}, {3, 2}, {5, 4, 5}, {5, 5, 2}, {3, 2}, {5, 4, 2}, {5, 2, 1}, {
            3, 2}, {5, 4, 1}, {1}}, 
           Function[{Optica`Optica`SCx, Optica`Optica`SCy}, 
            And[
            Optica`Optica`SCx <= 5., Optica`Optica`SCx >= -5., 
             Optica`Optica`SCy >= -4.5, Optica`Optica`SCy <= 4.5]], Evaluate],
          Optica`Optica`OffAxis -> {0, 0}, Optica`Optica`CheckLimits -> False,
          Optica`Optica`SymbolicValues -> {}, 
         Optica`Optica`SymbolicRanges -> {}, 
         Optica`Optica`SymbolicTranslationVector -> {5.25, -0.4, 5}, 
         Optica`Optica`SymbolicRotationMatrix -> {{0, 0, -1}, {0, -1, 0}, {-1,
           0, 0}}, 
         Optica`Optica`SymbolicComponentTransformation -> {{5.25, -0.4, 5}, {{
           0, 0, -1}, {0, -1, 0}, {-1, 0, 0}}}, 
         Optica`Optica`SymbolicSurfaceApproximation -> Automatic, 
         Optica`Optica`SymbolicSurfaceValue -> DirectedInfinity[1], 
         Optica`Optica`SymbolicSurfaceFunction -> ({0, #, #2}& ), 
         Optica`Optica`SymbolicSurfaceNormalFunction -> ({{1, 0, 0}, {0, 1, 
          0}, {0, 0, 1}}& ), Optica`Optica`SymbolicSurfaceBoundary -> {10, 9},
          Optica`Optica`SurpressMissedRays -> False, 
         Optica`Optica`SymbolicOffAxis -> {0, 0}, 
         Optica`Optica`SymbolicRefractiveModels -> {}, 
         Optica`Optica`SurfaceIntersectionFunction -> 
         Optica`Optica`CompiledSurfaceIntersectionFunction[{8, 9., 5468}, {
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real], 
            Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {3, 0, 
           4}, {3, 0, 5}, {3, 2, 
           1}}, {{{{-1., 0., 0.}}, {3, 2, 4}}, {5., {3, 0, 14}}, {
            1, {2, 0, 1}}, {7., {3, 0, 9}}, {1.*^-10, {3, 0, 6}}, {
            2, {2, 0, 2}}, {-4.5, {3, 0, 16}}, {False, {1, 0, 6}}, {
            0., {3, 0, 13}}, {0, {2, 0, 0}}, {
            3, {2, 0, 3}}, {{-1., 0., 0.}, {3, 1, 2}}, {-5., {3, 0, 15}}, {
            4.5, {3, 0, 17}}}, {8, 4, 18, 0, 
           5}, {{41, 269, 3, 0, 3, 3, 0, 6, 3, 0, 7}, {10, 0, 8}, {27, 8, 9, 
            7, 8, 0}, {2, 0, 51}, {40, 60, 3, 0, 3, 3, 0, 7}, {16, 0, 7, 8}, {
            19, 8, 10}, {16, 0, 4, 8}, {16, 8, 7, 8}, {19, 8, 11}, {13, 1, 11,
             8}, {16, 0, 5, 11}, {16, 11, 7, 11}, {19, 11, 12}, {13, 2, 12, 
            11}, {34, 10, 8, 11, 3, 0}, {38, 0, 0, 1, 0, 10}, {41, 269, 3, 0, 
            10, 3, 0, 6, 3, 0, 8}, {27, 6, 9, 8, 13, 1}, {2, 1, 23}, {38, 0, 
            0, 2, 0, 8}, {27, 4, 9, 8, 14, 2}, {2, 2, 17}, {38, 0, 0, 2, 0, 
            8}, {27, 6, 9, 8, 15, 3}, {2, 3, 11}, {38, 0, 0, 3, 0, 8}, {27, 6,
             9, 8, 16, 4}, {2, 4, 5}, {38, 0, 0, 3, 0, 8}, {27, 4, 9, 8, 17, 
            5}, {5, 5, 7}, {3, 2}, {5, 6, 7}, {5, 7, 4}, {3, 2}, {5, 6, 4}, {
            5, 4, 3}, {3, 2}, {5, 6, 3}, {5, 3, 2}, {3, 2}, {5, 6, 2}, {2, 2, 
            7}, {38, 0, 0, 1, 0, 8}, {38, 0, 0, 2, 0, 12}, {38, 0, 0, 3, 0, 
            10}, {34, 8, 12, 10, 3, 1}, {
            42, "CopyTensor", 3, 1, 1, 3, 1, 3}, {3, 2}, {
            42, "CopyTensor", 3, 1, 2, 3, 1, 3}, {34, 3, 0, 0}, {
            42, "CopyTensor", 3, 2, 0, 3, 2, 1}, {3, 2}, {
            42, "CopyTensor", 3, 2, 4, 3, 2, 1}, {1}}, 
           
           Function[{
            Optica`Optica`RSx, Optica`Optica`RSy, Optica`Optica`RSz, 
             Optica`Optica`RTx, Optica`Optica`RTy, Optica`Optica`RTz}, 
            Block[{Compile`$488}, 
             If[Chop[Optica`Optica`RTx] != 0, {
               (If[
                And[N[
                   Chop[
                    Part[#, 1]]] >= 0., 
                 And[
                 Part[#, 2] <= 5., Part[#, 2] >= -5., Part[#, 3] >= -4.5, 
                  Part[#, 3] <= 4.5]], {
                 Part[#, 1], 
                 Part[#, 2], 
                 Part[#, 3]}, {-1., 0., 0.}]& )[
               Compile`$488 = 
                 Optica`Optica`RTx^(-1); {-(Optica`Optica`RSx Compile`$488), 
                  Optica`Optica`RSy - (Optica`Optica`RSx Optica`Optica`RTy) 
                  Compile`$488, 
                  Optica`Optica`RSz - (Optica`Optica`RSx Optica`Optica`RTz) 
                  Compile`$488}]}, {{-1., 0., 0.}}]]], Evaluate], 
         Optica`Optica`BoundaryChecked -> True, 
         Optica`Optica`SurfaceStyle -> {
          Optica`Optica`FillStyle -> {}, Optica`Optica`LineStyle -> {}}}}, 
      Optica`Optica`Deflections :> {{{
         Optica`Optica`DeflectionID -> 79758, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Transmission, Optica`Optica`ComponentLabel -> 
          Optica`Optica`ClearBoundary, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Transmission, 100, {
            AddTo, 100, False, 79758, False, Optica`Optica`OriginalRay}}}}, {{
         Optica`Optica`DeflectionID -> 79816, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Transmission, Optica`Optica`ComponentLabel -> 
          Optica`Optica`ClearBoundary, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Transmission, 100, {
            AddTo, 100, False, 79816, False, Optica`Optica`OriginalRay}}}}, {{
         Optica`Optica`DeflectionID -> 79787, Optica`Optica`DeflectionLabel -> 
          Optica`Optica`Transmission, Optica`Optica`ComponentLabel -> 
          Optica`Optica`ClearBoundary, Options -> {}, 
          AddTo -> {Optica`Optica`NewRay}, 
          Optica`Optica`ReplaceFor -> {Optica`Optica`ReplaceFor}, 
          Optica`Optica`TakeFrom -> {Optica`Optica`OriginalRay}, 
          Optica`Optica`DeflectionFunction -> {
           Optica`Optica`Transmission, 100, {
            AddTo, 100, False, 79787, False, Optica`Optica`OriginalRay}}}}}, 
      Optica`Optica`EntranceCoordinates :> {{9.75, -0.40001000000000003`, 
       0.00001}, {5.24999, -5.4, 0.00001}, {0.75, -0.39999, 0.00001}, {
       5.25001, 4.6, 0.00001}, {5.24999, -0.39999, -5.}, {
       5.24999, -0.40001000000000003`, 5.}}, 
      Optica`Optica`ConfinedPaths :> {{{
         Optica`Optica`SurfaceNumber -> 1, 
          Optica`Optica`DeflectionNumber -> {1}}}, {{
         Optica`Optica`SurfaceNumber -> 2, 
          Optica`Optica`DeflectionNumber -> {2}}}, {{
         Optica`Optica`SurfaceNumber -> 3, 
          Optica`Optica`DeflectionNumber -> {1}}}, {{
         Optica`Optica`SurfaceNumber -> 4, 
          Optica`Optica`DeflectionNumber -> {2}}}, {{
         Optica`Optica`SurfaceNumber -> 5, 
          Optica`Optica`DeflectionNumber -> {3}}}, {{
         Optica`Optica`SurfaceNumber -> 6, 
          Optica`Optica`DeflectionNumber -> {3}}}}, 
      Optica`Optica`RenderedSurfaces :> {{
        Optica`Optica`SurfaceNumber -> 1, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 2, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 3, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 4, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 5, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}, {
        Optica`Optica`SurfaceNumber -> 6, 
         Optica`Optica`PlotFactor -> {1., 1.}, 
         Optica`Optica`FillOffset -> {0., 0.}, Optica`Optica`RenderType -> 
         Trace}}, 
      Optica`Optica`RenderedPolygons :> {{{{
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 1, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {-4.5, 0.}, 
           Optica`Optica`FinishPoint -> {4.5, 0.}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {4.5, 0.}, 
           Optica`Optica`FinishPoint -> {-4.5, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 2, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 3, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {-4.5, 0.}, 
           Optica`Optica`FinishPoint -> {4.5, 0.}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {4.5, 0.}, 
           Optica`Optica`FinishPoint -> {-4.5, 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., -5.}, 
           Optica`Optica`FinishPoint -> {0., 5.}}, {
          Optica`Optica`SurfaceNumber -> 4, 
           Optica`Optica`StartPoint -> {0., 5.}, 
           Optica`Optica`FinishPoint -> {0., -5.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {0., -4.5}, 
           Optica`Optica`FinishPoint -> {0., 4.5}}, {
          Optica`Optica`SurfaceNumber -> 5, 
           Optica`Optica`StartPoint -> {0., 4.5}, 
           Optica`Optica`FinishPoint -> {0., -4.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {-5., 0.}, 
           Optica`Optica`FinishPoint -> {5., 0.}}, {
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {5., 0.}, 
           Optica`Optica`FinishPoint -> {-5., 0.}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> 
          Empty}}, {{{
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {0., -4.5}, 
           Optica`Optica`FinishPoint -> {0., 4.5}}, {
          Optica`Optica`SurfaceNumber -> 6, 
           Optica`Optica`StartPoint -> {0., 4.5}, 
           Optica`Optica`FinishPoint -> {0., -4.5}}}, {
         Optica`Optica`PlotFactor -> 1., Optica`Optica`RenderType -> Empty}}},
       Optica`Optica`SymbolicValues :> {}, 
      Options :> {
       Optica`Optica`ComponentLabel -> Optica`Optica`ClearBoundary, 
        Optica`Optica`GraphicDesign -> Automatic, Optica`Optica`WaveFrontID -> 
        False}, Optica`Optica`SymbolicTranslationVector :> {0.75, -0.4, 0}, 
      Optica`Optica`SymbolicRotationMatrix :> {{1, 0, 0}, {0, 1, 0}, {0, 0, 
       1}}, Optica`Optica`SymbolicComponentTransformation :> {{
        0.75, -0.4, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}]], 
    Optica`Optica`HeldGraphicalOutput[]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727879840362*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880335246*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880337188*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880339098*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880341003*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880342865*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880344617*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880346409*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880349368*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278803512287`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.614727880352998*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.61472788035555*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[279]:="],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.25000000000000006`, 
       0.4330127018922193}, {-0.25000000000000006`, 
       0.4330127018922193}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.2165063509461097}, \
{-0.25000000000000006`, -0.4330127018922193}, {-0.25000000000000006`, \
-0.4330127018922193}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5,
        0.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {-0.24999999999999992`, \
-0.43301270189221935`}, {-0.24999999999999992`, -0.43301270189221935`}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {
       0.41284695471649935`, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.24999999999999992`, 0.43301270189221935`}, {
       0.03784695471649935, 0.4985655503729547}, {0.25, 0.4330127018922193}, {
       0.41284695471649935`, 0.282059199426845}, {0.5, 
       5.551115123125783*^-17}, {0.5, 5.551115123125783*^-17}, {
       0.4128469547164993, 0.282059199426845}, {0.25, 0.4330127018922193}, {
       0.03784695471649929, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}}]}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}], 
      LineBox[{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}], 
      LineBox[{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}], 
      LineBox[{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}], 
      LineBox[{{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}], 
      LineBox[{{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}], 
      LineBox[{{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}], 
      LineBox[{{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}], 
      LineBox[{{-0.5, 0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}], 
      LineBox[{{-0.5, 0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}], 
      LineBox[{{-0.5, 0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}], 
      LineBox[{{-0.5, 0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}], 
      LineBox[{{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 0.2165063509461097}}], 
      LineBox[{{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 0.2165063509461097}}], 
      LineBox[{{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 0.2165063509461097}}], 
      LineBox[{{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 0.2165063509461097}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}], 
      LineBox[{{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}], 
      LineBox[{{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}], 
      LineBox[{{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}], 
      LineBox[{{0.4128469547164993, -0.282059199426845}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}], 
      LineBox[{{0.4128469547164993, -0.282059199426845}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}], 
      LineBox[{{0.4128469547164993, -0.282059199426845}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}], 
      LineBox[{{0.4128469547164993, -0.282059199426845}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}], 
      LineBox[{{0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}], 
      LineBox[{{0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}], 
      LineBox[{{0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}], 
      LineBox[{{0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}], 
      LineBox[{{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}], 
      LineBox[{{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}], 
      LineBox[{{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}], 
      LineBox[{{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-0.24999999999999992`, 0.43301270189221935`}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 0.43301270189221935`}}],
       LineBox[{{-0.24999999999999992`, 0.43301270189221935`}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 0.43301270189221935`}}],
       LineBox[{{-0.24999999999999992`, 0.43301270189221935`}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 0.43301270189221935`}}],
       LineBox[{{-0.24999999999999992`, 0.43301270189221935`}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 0.43301270189221935`}}],
       LineBox[{{0.03784695471649935, 0.4985655503729547}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.03784695471649935, 
       0.4985655503729547}, {0.03784695471649935, 0.4985655503729547}}], 
      LineBox[{{0.03784695471649935, 0.4985655503729547}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.03784695471649935, 
       0.4985655503729547}, {0.03784695471649935, 0.4985655503729547}}], 
      LineBox[{{0.03784695471649935, 0.4985655503729547}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.03784695471649935, 
       0.4985655503729547}, {0.03784695471649935, 0.4985655503729547}}], 
      LineBox[{{0.03784695471649935, 0.4985655503729547}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.03784695471649935, 
       0.4985655503729547}, {0.03784695471649935, 0.4985655503729547}}], 
      LineBox[{{0.25, 0.4330127018922193}, {0.4128469547164993, 
       0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}], 
      LineBox[{{0.25, 0.4330127018922193}, {0.4128469547164993, 
       0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}], 
      LineBox[{{0.25, 0.4330127018922193}, {0.4128469547164993, 
       0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}], 
      LineBox[{{0.25, 0.4330127018922193}, {0.4128469547164993, 
       0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}], 
      LineBox[{{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}], 
      LineBox[{{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}], 
      LineBox[{{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}], 
      LineBox[{{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, 4.6}, {9.75, -5.4}, {9.75, -5.4}, {9.75, 4.6}, {9.75, 
       4.6}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, -5.4}, {0.75, -5.4}, {0.75, -5.4}, {9.75, -5.4}, {
       9.75, -5.4}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.75, -5.4}, {0.75, 4.6}, {0.75, 4.6}, {0.75, -5.4}, {
       0.75, -5.4}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0.75, 4.6}, {9.75, 4.6}, {9.75, 4.6}, {0.75, 4.6}, {0.75, 
       4.6}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, -5.4}, {9.75, 4.6}, {0.75, 4.6}, {0.75, -5.4}, {
       9.75, -5.4}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{9.75, 4.6}, {9.75, -5.4}, {0.75, -5.4}, {0.75, 4.6}, {9.75, 
       4.6}}]}}, 
    {Hue[0.], AbsoluteThickness[0.5], 
     LineBox[{{-1.9999999999999996`, 0.}, {1.7667114977152143`, 0.}}]}, 
    {Hue[0.00018731330880911168`], AbsoluteThickness[0.5], 
     LineBox[{{1.7667114977152143`, 0.}, {
      2.150842225822762, -0.004073940169013586}}]}, 
    {Hue[0.44416168842418224`], AbsoluteThickness[0.5], 
     LineBox[{{2.150842225822762, -0.004073940169013586}, {
      1.7737198649463215`, -0.07722951543100699}}]}, 
    {Hue[0.00037462661761830104`], AbsoluteThickness[0.5], 
     LineBox[{{2.150842225822762, -0.004073940169013586}, {
      2.313846576425795, -0.007531849809321051}}]}, 
    {Hue[0.0005577510705393474], AbsoluteThickness[0.5], 
     LineBox[{{2.313846576425795, -0.007531849809321051}, {
      2.6587982155668994`, -0.015008885084780993`}}]}, 
    {Hue[0.44620830579458787`], AbsoluteThickness[0.5], 
     LineBox[{{2.6587982155668994`, -0.015008885084780993`}, {
      2.3137939589293546`, -0.010581436087871}}]}, 
    {Hue[0.4460251813416669], AbsoluteThickness[0.5], 
     LineBox[{{2.313846576425795, -0.007531849809321053}, {
      2.1506905823677744`, -0.002476657692228986}}]}, 
    {Hue[0.44621398824123293`], AbsoluteThickness[0.5], 
     LineBox[{{2.1506905823677744`, -0.0024766576922289896`}, {
      1.7672930323709903`, 0.004669646611714488}}]}, 
    {Hue[0.0007408755234604714], AbsoluteThickness[0.5], 
     LineBox[{{2.6587982155668994`, -0.015008885084780998`}, {
      2.88220483912467, -0.019954574845912905`}}]}, 
    {Hue[0.000930141336837087], AbsoluteThickness[0.5], 
     LineBox[{{2.88220483912467, -0.01995457484591291}, {
      3.203448398313732, -0.03118806463673083}}]}, 
    {Hue[0.4441360010476784], AbsoluteThickness[0.5], 
     LineBox[{{3.203448398313732, -0.03118806463673083}, {
      2.8890066728387804`, -0.09789651158066667}}]}, 
    {Hue[0.44639143024750894`], AbsoluteThickness[0.5], 
     LineBox[{{2.3137939589293546`, -0.010581436087871}, {
      2.1511871633859885`, -0.008419595868123391}}]}, 
    {Hue[0.446576751450214], AbsoluteThickness[0.5], 
     LineBox[{{2.1511871633859885`, -0.008419595868123391}, {
      1.7661119968940817`, -0.006264234149068746}}]}, 
    {Hue[0.443946735234302], AbsoluteThickness[0.5], 
     LineBox[{{2.88220483912467, -0.019954574845912905`}, {
      2.6470204120697653`, 0.05068334347140578}}]}, 
    {Hue[0.4443731709832407], AbsoluteThickness[0.5], 
     LineBox[{{2.6470204120697653`, 0.05068334347140578}, {
      2.3675489352810515`, 0.11310424430511475`}}]}, 
    {Hue[0.0011194071502139357`], AbsoluteThickness[0.5], 
     LineBox[{{3.203448398313732, -0.03118806463673083}, {
      3.289988407633029, -0.03532566548370465}}]}, 
    {Hue[0.001309964452896728], AbsoluteThickness[0.5], 
     LineBox[{{3.289988407633029, -0.03532566548370465}, {
      3.6101936044655933`, -0.046115682956667625`}}]}, 
    {Hue[0.4440118373077287], AbsoluteThickness[0.5], 
     LineBox[{{3.6101936044655933`, -0.046115682956667625`}, {
      3.304262492718633, 0.049036549917380684`}}]}, 
    {Hue[0.4443252668610551], AbsoluteThickness[0.5], 
     LineBox[{{2.8890066728387804`, -0.09789651158066667}, {
      2.8351104353765613`, -0.10861037831299702`}}]}, 
    {Hue[0.4454222170462231], AbsoluteThickness[0.5], 
     LineBox[{{2.8351104353765613`, -0.10861037831299702`}, {
      2.631370047670223, -0.17513360904866818`}}]}, 
    {Hue[0.443821280005045], AbsoluteThickness[0.5], 
     LineBox[{{3.289988407633029, -0.03532566548370465}, {
      3.203619614090072, -0.057219436555797455`}}]}, 
    {Hue[0.44404284690324547`], AbsoluteThickness[0.5], 
     LineBox[{{3.2036196140900715`, -0.057219436555797455`}, {
      2.9006298519039526`, -0.1239716558766005}}]}, 
    {Hue[0.0015005217555795203`], AbsoluteThickness[0.5], 
     LineBox[{{3.6101936044655933`, -0.046115682956667625`}, {
      3.884424114220212, -0.05148960539899354}}]}, 
    {Hue[0.0018012930087541678`], AbsoluteThickness[0.5], 
     LineBox[{{3.884424114220212, -0.05148960539899354}, {
      4.174745282155764, -0.04187068499412144}}]}, 
    {Hue[0.4106912351060023], AbsoluteThickness[0.5], 
     LineBox[{{4.174745282155764, -0.04187068499412144}, {3.9920227327644295`,
       0.18394201200307905`}}]}, 
    {Hue[0.44420239461041156`], AbsoluteThickness[0.5], 
     LineBox[{{3.304262492718633, 0.049036549917380684`}, {
      2.8975987417994986`, 0.16926171893825742`}}]}, 
    {Hue[0.4443910648557939], AbsoluteThickness[0.5], 
     LineBox[{{2.8975987417994986`, 0.16926171893825742`}, {2.560781759415158,
       0.27331809425780756`}}]}, 
    {Hue[0.44651916723139123`], AbsoluteThickness[0.5], 
     LineBox[{{2.631370047670223, -0.17513360904866818`}, {
      2.4272549118351114`, -0.2699744584069052}}]}, 
    {Hue[0.4467558052995659], AbsoluteThickness[0.5], 
     LineBox[{{2.4272549118351114`, -0.2699744584069052}, {
      2.1508630265649438`, -0.38625248209328467`}}]}, 
    {Hue[0.44426441380144593`], AbsoluteThickness[0.5], 
     LineBox[{{2.9006298519039526`, -0.1239716558766005}, {
      2.868778330669892, -0.1299466247306531}}]}, 
    {Hue[0.4447267343477784], AbsoluteThickness[0.5], 
     LineBox[{{2.868778330669892, -0.12994662473065313`}, {
      2.621793917817546, -0.19608559386754335`}}]}, 
    {Hue[0.410390463852827], AbsoluteThickness[0.5], 
     LineBox[{{3.884424114220212, -0.051489605398993554`}, {
      3.8360941866799445`, -0.12834485163359455`}}]}, 
    {Hue[0.41060164433916274`], AbsoluteThickness[0.5], 
     LineBox[{{3.8360941866799445`, -0.12834485163359455`}, {
      3.6527301356231905`, -0.40317480552400664`}}]}, 
    {Hue[0.002102064261928893], AbsoluteThickness[0.5], 
     LineBox[{{4.174745282155764, -0.04187068499412144}, {
      4.400554302185327, -0.022440938596222378`}}]}, 
    {Hue[0.0023145987830216707`], AbsoluteThickness[0.5], 
     LineBox[{{4.400554302185327, -0.022440938596222378`}, {4.6946057131986, 
      0.011066496590403974`}}]}, 
    {Hue[0.4369278549270888], AbsoluteThickness[0.5], 
     LineBox[{{4.6946057131986, 0.011066496590403974`}, {4.422212158743575, 
      0.12678482713072758`}}]}, 
    {Hue[0.41099200635917693`], AbsoluteThickness[0.5], 
     LineBox[{{3.9920227327644295`, 0.18394201200307905`}, {
      3.9208762860103477`, 0.26296014394196404`}}]}, 
    {Hue[0.41379215857332213`], AbsoluteThickness[0.5], 
     LineBox[{{3.9208762860103477`, 0.26296014394196404`}, {3.774007014814893,
       0.3790719956019406}}]}, 
    {Hue[0.658369912170755], AbsoluteThickness[0.5], 
     LineBox[{{3.774007014814893, 0.3790719956019406}, {3.615497598354153, 
      0.27943610944304614`}}]}, 
    {Hue[0.44457973510117615`], AbsoluteThickness[0.5], 
     LineBox[{{2.560781759415158, 0.27331809425780756`}, {2.289831266060674, 
      0.36065725145027167`}}]}, 
    {Hue[0.4466751879410683], AbsoluteThickness[0.5], 
     LineBox[{{2.289831266060674, 0.36065725145027167`}, {2.1456962410064944`,
       0.3837580623745752}}]}, 
    {Hue[0.4469924433677406], AbsoluteThickness[0.5], 
     LineBox[{{2.1508630265649438`, -0.38625248209328467`}, {
      2.1468470929130756`, -0.38777088348810573`}}]}, 
    {Hue[0.4471763015411806], AbsoluteThickness[0.5], 
     LineBox[{{2.1468470929130756`, -0.38777088348810573`}, {
      1.850524420653777, -0.5013247962187429}}]}, 
    {Hue[0.4451890548941107], AbsoluteThickness[0.5], 
     LineBox[{{2.621793917817546, -0.19608559386754337`}, {
      2.4268272613564683`, -0.26458365317247373`}}]}, 
    {Hue[0.4453927816282814], AbsoluteThickness[0.5], 
     LineBox[{{2.4268272613564683`, -0.26458365317247373`}, {
      2.131967869541339, -0.36053596551370937`}}]}, 
    {Hue[0.41081282482549847`], AbsoluteThickness[0.5], 
     LineBox[{{3.6527301356231905`, -0.40317480552400664`}, {
      3.6440775948960247`, -0.4154141300939811}}]}, 
    {Hue[0.41100701524506145`], AbsoluteThickness[0.5], 
     LineBox[{{3.6440775948960247`, -0.4154141300939811}, {
      3.4519109865691275`, -0.6775846688198423}}]}, 
    {Hue[0.43671532040599603`], AbsoluteThickness[0.5], 
     LineBox[{{4.400554302185327, -0.02244093859622237}, {
      4.332719604913328, -0.07468346298845327}}]}, 
    {Hue[0.43702421859330515`], AbsoluteThickness[0.5], 
     LineBox[{{4.332719604913328, -0.07468346298845327}, {
      4.092110418388803, -0.2817319083055005}}]}, 
    {Hue[0.002527133304114448], AbsoluteThickness[0.5], 
     LineBox[{{4.6946057131986, 0.011066496590403974`}, {4.8241048464905125`, 
      0.02945966646765053}}]}, 
    {Hue[0.002719731037430806], AbsoluteThickness[0.5], 
     LineBox[{{4.8241048464905125`, 0.02945966646765053}, {5.136587594956282, 
      0.06878987295939466}}]}, 
    {Hue[0.44463228110133113`], AbsoluteThickness[0.5], 
     LineBox[{{5.136587594956282, 0.06878987295939468}, {
      4.849864850132244, -0.06152666793996342}}]}, 
    {Hue[0.43714038944818157`], AbsoluteThickness[0.5], 
     LineBox[{{4.422212158743575, 0.12678482713072758`}, {4.399096479845423, 
      0.13585950227795887`}}]}, 
    {Hue[0.4374526644217262], AbsoluteThickness[0.5], 
     LineBox[{{4.399096479845423, 0.13585950227795887`}, {4.1360406816166115`,
       0.2561933497483976}}]}, 
    {Hue[0.6555697599566096], AbsoluteThickness[0.5], 
     LineBox[{{3.9208762860103477`, 0.26296014394196404`}, {
      3.9412780345169445`, 0.3897730672871572}}]}, 
    {Hue[0.6557648067506895], AbsoluteThickness[0.5], 
     LineBox[{{3.9412780345169445`, 0.3897730672871572}, {3.9987729664076967`,
       0.7106424299902512}}]}, 
    {Hue[0.4165923107874674], AbsoluteThickness[0.5], 
     LineBox[{{3.774007014814893, 0.3790719956019406}, {3.618102085979958, 
      0.46427768108364853`}}]}, 
    {Hue[0.41680609380451705`], AbsoluteThickness[0.5], 
     LineBox[{{3.618102085979958, 0.46427768108364853`}, {3.3555961043193907`,
       0.5982774551320276}}]}, 
    {Hue[0.6611700643849002], AbsoluteThickness[0.5], 
     LineBox[{{3.615497598354153, 0.27943610944304614`}, {3.4620287086386394`,
       0.14210240451730616`}}]}, 
    {Hue[0.6617574650025836], AbsoluteThickness[0.5], 
     LineBox[{{3.4620287086386394`, 0.14210240451730616`}, {
      3.290651511409753, -0.04093297677543393}}]}, 
    {Hue[0.4487706407809604], AbsoluteThickness[0.5], 
     LineBox[{{2.1456962410064944`, 0.3837580623745752}, {2.137773631112005, 
      0.3838057059622634}}]}, 
    {Hue[0.4491869394125376], AbsoluteThickness[0.5], 
     LineBox[{{2.137773631112005, 0.3838057059622634}, {1.9375366706374482`, 
      0.3992115048105958}}]}, 
    {Hue[0.4455965083624522], AbsoluteThickness[0.5], 
     LineBox[{{2.131967869541339, -0.36053596551370937`}, {
      2.1317647742058625`, -0.3605968720764497}}]}, 
    {Hue[0.4458157802673633], AbsoluteThickness[0.5], 
     LineBox[{{2.1317647742058625`, -0.3605968720764497}, {
      1.842422203976989, -0.4570800530492261}}]}, 
    {Hue[0.41120120566462454`], AbsoluteThickness[0.5], 
     LineBox[{{3.4519109865691275`, -0.6775846688198423}, {
      3.3743027929427307`, -0.7797432585536458}}]}, 
    {Hue[0.4120798150257461], AbsoluteThickness[0.5], 
     LineBox[{{3.3743027929427307`, -0.7797432585536458}, {
      3.2171263394543335`, -0.945791594974529}}]}, 
    {Hue[0.4373331167806145], AbsoluteThickness[0.5], 
     LineBox[{{4.092110418388803, -0.2817319083055005}, {
      4.023924522203216, -0.3471739477614017}}]}, 
    {Hue[0.4376298878414501], AbsoluteThickness[0.5], 
     LineBox[{{4.023924522203216, -0.3471739477614017}, {
      3.8359760786024566`, -0.547303048019383}}]}, 
    {Hue[0.4444396833680149], AbsoluteThickness[0.5], 
     LineBox[{{4.8241048464905125`, 0.02945966646765053}, {4.69466225720908, 
      0.05463155987304365}}]}, 
    {Hue[0.444664368253119], AbsoluteThickness[0.5], 
     LineBox[{{4.69466225720908, 0.05463155987304365}, {4.40607822076775, 
      0.1010441468157273}}]}, 
    {Hue[0.002912328770747163], AbsoluteThickness[0.5], 
     LineBox[{{5.136587594956282, 0.06878987295939468}, {5.438567307187545, 
      0.1019347427665358}}]}, 
    {Hue[0.0032818618603324134`], AbsoluteThickness[0.5], 
     LineBox[{{5.438567307187545, 0.1019347427665358}, {5.639921896520204, 
      0.11098310414783293`}}]}, 
    {Hue[0.39692804322930464`], AbsoluteThickness[0.5], 
     LineBox[{{5.639921896520204, 0.11098310414783293`}, {
      5.554250872733547, -0.07146146050772646}}]}, 
    {Hue[0.44482487883464744`], AbsoluteThickness[0.5], 
     LineBox[{{4.849864850132244, -0.06152666793996342}, {
      4.788657960453038, -0.08818067542507846}}]}, 
    {Hue[0.4453528924941151], AbsoluteThickness[0.5], 
     LineBox[{{4.788657960453038, -0.08818067542507849}, {
      4.563160363805937, -0.2095253732610226}}]}, 
    {Hue[0.4377649393952707], AbsoluteThickness[0.5], 
     LineBox[{{4.1360406816166115`, 0.2561933497483976}, {3.6179271192659637`,
       0.5285467804054872}}]}, 
    {Hue[0.43823508508890296`], AbsoluteThickness[0.5], 
     LineBox[{{3.6179271192659637`, 0.5285467804054872}, {3.3901148833251633`,
       0.6267205401047594}}]}, 
    {Hue[0.6559598535447694], AbsoluteThickness[0.5], 
     LineBox[{{3.9987729664076967`, 0.7106424299902512}, {4.032900255712351, 
      0.8833460304798999}}]}, 
    {Hue[0.6561551445294105], AbsoluteThickness[0.5], 
     LineBox[{{4.032900255712351, 0.8833460304798999}, {4.087894069184557, 
      1.190572550681726}}]}, 
    {Hue[0.4170198768215668], AbsoluteThickness[0.5], 
     LineBox[{{3.3555961043193907`, 0.5982774551320276}, {3.3506237843433677`,
       0.6006414315659845}}]}, 
    {Hue[0.41734553637105776`], AbsoluteThickness[0.5], 
     LineBox[{{3.3506237843433677`, 0.6006414315659845}, {3.1189077061664916`,
       0.7275798313596082}}]}, 
    {Hue[0.6623448656202671], AbsoluteThickness[0.5], 
     LineBox[{{3.290651511409753, -0.04093297677543392}, {
      3.221579882986132, -0.12916230350309768`}}]}, 
    {Hue[0.6633990566292138], AbsoluteThickness[0.5], 
     LineBox[{{3.221579882986132, -0.12916230350309768`}, {
      3.1079744812692307`, -0.31578149969126973`}}]}, 
    {Hue[0.4129584243868677], AbsoluteThickness[0.5], 
     LineBox[{{3.2171263394543335`, -0.945791594974529}, {
      3.109609326425071, -1.037191798066271}}]}, 
    {Hue[0.41446612494485136`], AbsoluteThickness[0.5], 
     LineBox[{{3.109609326425071, -1.037191798066271}, {
      2.9525382644923193`, -1.1376453192431852`}}]}, 
    {Hue[0.43792665890228577`], AbsoluteThickness[0.5], 
     LineBox[{{3.8359760786024566`, -0.547303048019383}, {
      3.8081445731435055`, -0.5802043795349205}}]}, 
    {Hue[0.43826250825385793`], AbsoluteThickness[0.5], 
     LineBox[{{3.8081445731435055`, -0.5802043795349205}, {
      3.6479267674466245`, -0.7940552712029678}}]}, 
    {Hue[0.44488905313822297`], AbsoluteThickness[0.5], 
     LineBox[{{4.40607822076775, 0.10104414681572732`}, {4.34698126031897, 
      0.10858164471908821`}}]}, 
    {Hue[0.4480141834323506], AbsoluteThickness[0.5], 
     LineBox[{{4.34698126031897, 0.10858164471908821`}, {4.170700334701458, 
      0.1634694739701575}}]}, 
    {Hue[0.6846054576085268], AbsoluteThickness[0.5], 
     LineBox[{{4.170700334701458, 0.1634694739701575}, {4.158904414755697, 
      0.3477206471254315}}]}, 
    {Hue[0.39655851013971954`], AbsoluteThickness[0.5], 
     LineBox[{{5.438567307187545, 0.1019347427665358}, {5.369947045855445, 
      0.2389135007740329}}]}, 
    {Hue[0.39840111420359364`], AbsoluteThickness[0.5], 
     LineBox[{{5.369947045855445, 0.2389135007740329}, {5.256652686999513, 
      0.4008534369572916}}]}, 
    {Hue[0.6735569914789945], AbsoluteThickness[0.5], 
     LineBox[{{5.256652686999513, 0.4008534369572916}, {5.072982639363519, 
      0.3278776308226116}}]}, 
    {Hue[0.0036513949499175856`], AbsoluteThickness[0.5], 
     LineBox[{{5.639921896520204, 0.11098310414783293`}, {5.656117764920519, 
      0.11066713884056856`}}]}, 
    {Hue[0.00818012431114885], AbsoluteThickness[0.5], 
     LineBox[{{5.656117764920519, 0.11066713884056857`}, {5.780139413390965, 
      0.1328722918237478}}]}, 
    {Hue[0.21793962528991054`], AbsoluteThickness[0.5], 
     LineBox[{{5.780139413390965, 0.1328722918237478}, {5.813078531240988, 
      0.25448418525360783`}}]}, 
    {Hue[0.4276991262686724], AbsoluteThickness[0.5], 
     LineBox[{{5.813078531240988, 0.25448418525360783`}, {5.717216724786908, 
      0.33624574206176727`}}]}, 
    {Hue[0.6374586272474345], AbsoluteThickness[0.5], 
     LineBox[{{5.717216724786908, 0.33624574206176727`}, {5.602324795163315, 
      0.28453227557864835`}}]}, 
    {Hue[0.3972975763188899], AbsoluteThickness[0.5], 
     LineBox[{{5.554250872733547, -0.07146146050772645}, {
      5.446013302160968, -0.26798629236588783`}}]}, 
    {Hue[0.43194884986309323`], AbsoluteThickness[0.5], 
     LineBox[{{5.446013302160968, -0.26798629236588783`}, {
      5.3289129465642615`, -0.373110817031439}}]}, 
    {Hue[0.5051086320622069], AbsoluteThickness[0.5], 
     LineBox[{{5.3289129465642615`, -0.373110817031439}, {
      5.173926973483606, -0.3458526601738012}}]}, 
    {Hue[0.578268414261322], AbsoluteThickness[0.5], 
     LineBox[{{5.173926973483606, -0.3458526601738012}, {
      5.099721637990405, -0.2070822485170844}}]}, 
    {Hue[0.6514281964604373], AbsoluteThickness[0.5], 
     LineBox[{{5.099721637990405, -0.2070822485170844}, {
      5.163112851191095, -0.06305026229187857}}]}, 
    {Hue[0.4458809061535828], AbsoluteThickness[0.5], 
     LineBox[{{4.563160363805937, -0.2095253732610226}, {
      4.435873312302021, -0.29231063265284085`}}]}, 
    {Hue[0.4467324454670144], AbsoluteThickness[0.5], 
     LineBox[{{4.435873312302021, -0.29231063265284085`}, {
      4.2072759558879405`, -0.40840447476237973`}}]}, 
    {Hue[0.43870523078253526`], AbsoluteThickness[0.5], 
     LineBox[{{3.3901148833251633`, 0.6267205401047594}, {3.3831584032670334`,
       0.629101891221183}}]}, 
    {Hue[0.4389435449891139], AbsoluteThickness[0.5], 
     LineBox[{{3.3831584032670334`, 0.629101891221183}, {3.118958057251666, 
      0.730693687402561}}]}, 
    {Hue[0.6563504355140515], AbsoluteThickness[0.5], 
     LineBox[{{4.087894069184557, 1.190572550681726}, {4.096974615643519, 
      1.2471439068332988`}}]}, 
    {Hue[0.6634332118783636], AbsoluteThickness[0.5], 
     LineBox[{{4.096974615643519, 1.2471439068332988`}, {4.1566020874311045`, 
      1.3948686334667941`}}]}, 
    {Hue[0.41767119592054863`], AbsoluteThickness[0.5], 
     LineBox[{{3.1189077061664916`, 0.7275798313596082}, {2.962953264961906, 
      0.8250378530382365}}]}, 
    {Hue[0.43190606607026294`], AbsoluteThickness[0.5], 
     LineBox[{{2.962953264961906, 0.8250378530382365}, {2.8527497331871134`, 
      0.9455596562108208}}]}, 
    {Hue[0.5614327383385213], AbsoluteThickness[0.5], 
     LineBox[{{2.8527497331871134`, 0.9455596562108208}, {2.88965565168125, 
      1.1046454086706592`}}]}, 
    {Hue[0.6909594106067789], AbsoluteThickness[0.5], 
     LineBox[{{2.88965565168125, 1.1046454086706592`}, {3.0416663960619714`, 
      1.164336756858046}}]}, 
    {Hue[0.6644532476381607], AbsoluteThickness[0.5], 
     LineBox[{{3.1079744812692307`, -0.31578149969126973`}, {
      3.0979082551464243`, -0.3377617363851812}}]}, 
    {Hue[0.6646560775405909], AbsoluteThickness[0.5], 
     LineBox[{{3.0979082551464243`, -0.3377617363851812}, {
      2.964069326973405, -0.6132710566160591}}]}, 
    {Hue[0.41597382550283507`], AbsoluteThickness[0.5], 
     LineBox[{{2.9525382644923193`, -1.1376453192431852`}, {
      2.9202939341265974`, -1.15256709084685}}]}, 
    {Hue[0.4161645521951827], AbsoluteThickness[0.5], 
     LineBox[{{2.9202939341265974`, -1.15256709084685}, {
      2.6545398615910583`, -1.280178969740208}}]}, 
    {Hue[0.43859835760543003`], AbsoluteThickness[0.5], 
     LineBox[{{3.6479267674466245`, -0.7940552712029678}, {
      3.63352257300137, -0.8158563100177105}}]}, 
    {Hue[0.4387816661764597], AbsoluteThickness[0.5], 
     LineBox[{{3.63352257300137, -0.8158563100177105}, {
      3.4528534018009265`, -1.0906598151282794`}}]}, 
    {Hue[0.6814803273143996], AbsoluteThickness[0.5], 
     LineBox[{{4.34698126031897, 0.10858164471908821`}, {
      4.172131662576525, -0.04731871164326101}}]}, 
    {Hue[0.685758255603942], AbsoluteThickness[0.5], 
     LineBox[{{4.172131662576525, -0.04731871164326101}, {
      4.0215053031803265`, -0.13656884224374358`}}]}, 
    {Hue[0.45113931372647814`], AbsoluteThickness[0.5], 
     LineBox[{{4.170700334701458, 0.1634694739701575}, {3.9039351419317736`, 
      0.3012815070009306}}]}, 
    {Hue[0.45276456625578565`], AbsoluteThickness[0.5], 
     LineBox[{{3.9039351419317736`, 0.3012815070009306}, {3.7095927179649006`,
       0.3694555953323202}}]}, 
    {Hue[0.6877305879026544], AbsoluteThickness[0.5], 
     LineBox[{{4.158904414755697, 0.34772064712543155`}, {4.186709549300818, 
      0.5970566748280117}}]}, 
    {Hue[0.6879616800417122], AbsoluteThickness[0.5], 
     LineBox[{{4.186709549300818, 0.5970566748280117}, {4.232349480833086, 
      0.9075335520499724}}]}, 
    {Hue[0.6717143874151205], AbsoluteThickness[0.5], 
     LineBox[{{5.369947045855445, 0.2389135007740329}, {5.4363474180854485`, 
      0.33981791682190754`}}]}, 
    {Hue[0.6719219590415206], AbsoluteThickness[0.5], 
     LineBox[{{5.4363474180854485`, 0.33981791682190754`}, {5.618099162223654,
       0.631822219651038}}]}, 
    {Hue[0.4002437182674677], AbsoluteThickness[0.5], 
     LineBox[{{5.256652686999513, 0.4008534369572916}, {5.169280136629371, 
      0.4934251559499546}}]}, 
    {Hue[0.40052632119553055`], AbsoluteThickness[0.5], 
     LineBox[{{5.169280136629371, 0.4934251559499546}, {4.9705929431190015`, 
      0.6843149737851442}}]}, 
    {Hue[0.6753995955428685], AbsoluteThickness[0.5], 
     LineBox[{{5.072982639363519, 0.3278776308226116}, {4.8388393340441525`, 
      0.1924932213145497}}]}, 
    {Hue[0.6792002845508751], AbsoluteThickness[0.5], 
     LineBox[{{4.8388393340441525`, 0.1924932213145497}, {4.698679316809952, 
      0.14323389961481361`}}]}, 
    {Hue[0.21341089592867818`], AbsoluteThickness[0.5], 
     LineBox[{{5.656117764920519, 0.11066713884056856`}, {
      6.050783306785948, -0.26091767258249676`}}]}, 
    {Hue[0.21381945399631314`], AbsoluteThickness[0.5], 
     LineBox[{{6.050783306785948, -0.26091767258249676`}, {
      6.266462557308947, -0.4372999424005015}}]}, 
    {Hue[0.6000353977298363], AbsoluteThickness[0.5], 
     LineBox[{{6.266462557308947, -0.4372999424005015}, {
      6.340928797522072, -0.1688171249226691}}]}, 
    {Hue[0.012708853672380038`], AbsoluteThickness[0.5], 
     LineBox[{{5.780139413390965, 0.1328722918237478}, {6.078954373256245, 
      0.25009272336775246`}}]}, 
    {Hue[0.012895177921819333`], AbsoluteThickness[0.5], 
     LineBox[{{6.078954373256245, 0.2500927233677525}, {6.385877384362597, 
      0.3672198357910872}}]}, 
    {Hue[0.4572619178187765], AbsoluteThickness[0.5], 
     LineBox[{{6.385877384362597, 0.3672198357910872}, {6.10438412011554, 
      0.19786211558100952`}}]}, 
    {Hue[0.22246835465114173`], AbsoluteThickness[0.5], 
     LineBox[{{5.813078531240988, 0.25448418525360783`}, {5.826683256183537, 
      0.45472933508594915`}}]}, 
    {Hue[0.22364101062358127`], AbsoluteThickness[0.5], 
     LineBox[{{5.826683256183537, 0.45472933508594915`}, {5.865410312505054, 
      0.6554846140465254}}]}, 
    {Hue[0.5319969869084632], AbsoluteThickness[0.5], 
     LineBox[{{5.865410312505054, 0.6554846140465254}, {6.068810334202852, 
      0.6347265289902424}}]}, 
    {Hue[0.4322278556299034], AbsoluteThickness[0.5], 
     LineBox[{{5.717216724786908, 0.33624574206176727`}, {5.623040498948695, 
      0.3888634059114886}}]}, 
    {Hue[0.43242907484189264`], AbsoluteThickness[0.5], 
     LineBox[{{5.623040498948695, 0.3888634059114886}, {5.324433384014403, 
      0.5643586341087806}}]}, 
    {Hue[0.6419873566086657], AbsoluteThickness[0.5], 
     LineBox[{{5.602324795163315, 0.28453227557864835`}, {
      5.11645815730649, -0.0620488094172342}}]}, 
    {Hue[0.646454972473871], AbsoluteThickness[0.5], 
     LineBox[{{5.11645815730649, -0.0620488094172342}, {
      4.960778241183477, -0.13227393548212463`}}]}, 
    {Hue[0.4704573585179997], AbsoluteThickness[0.5], 
     LineBox[{{5.446013302160968, -0.26798629236588783`}, {
      5.408512329344934, -0.4038070907651124}}]}, 
    {Hue[0.4712208106595636], AbsoluteThickness[0.5], 
     LineBox[{{5.408512329344934, -0.4038070907651124}, {
      5.368665699292367, -0.6386508757579388}}]}, 
    {Hue[0.46660012340729434`], AbsoluteThickness[0.5], 
     LineBox[{{5.3289129465642615`, -0.373110817031439}, {
      5.142156563325427, -0.4511357329145888}}]}, 
    {Hue[0.4667838246518385], AbsoluteThickness[0.5], 
     LineBox[{{5.142156563325427, -0.4511357329145888}, {
      4.862033541413417, -0.5694760611249675}}]}, 
    {Hue[0.5397599056064071], AbsoluteThickness[0.5], 
     LineBox[{{5.173926973483606, -0.3458526601738012}, {
      4.873260489996408, -0.17770917402864797`}}]}, 
    {Hue[0.5406122374348107], AbsoluteThickness[0.5], 
     LineBox[{{4.873260489996408, -0.17770917402864797`}, {
      4.6598052417380575`, -0.08667403832027229}}]}, 
    {Hue[0.6129196878055221], AbsoluteThickness[0.5], 
     LineBox[{{5.099721637990405, -0.2070822485170844}, {
      5.082806838587439, -0.09899688104197428}}]}, 
    {Hue[0.6132233546079778], AbsoluteThickness[0.5], 
     LineBox[{{5.082806838587439, -0.0989968810419743}, {5.023892590390386, 
      0.17942858185625338`}}]}, 
    {Hue[0.6860794700046379], AbsoluteThickness[0.5], 
     LineBox[{{5.163112851191095, -0.0630502622918786}, {5.5353880389761905`, 
      0.33622452132097363`}}]}, 
    {Hue[0.6875232404616601], AbsoluteThickness[0.5], 
     LineBox[{{5.5353880389761905`, 0.33622452132097363`}, {5.668226346046645,
       0.5234462570138415}}]}, 
    {Hue[0.447583984780446], AbsoluteThickness[0.5], 
     LineBox[{{4.2072759558879405`, -0.40840447476237973`}, {
      4.122525323515495, -0.44061256833959456`}}]}, 
    {Hue[0.4477671433629541], AbsoluteThickness[0.5], 
     LineBox[{{4.122525323515495, -0.44061256833959456`}, {
      3.836599226409276, -0.5489259410795577}}]}, 
    {Hue[0.4391818591956926], AbsoluteThickness[0.5], 
     LineBox[{{3.118958057251666, 0.730693687402561}, {2.874401641472924, 
      0.8353535702065428}}]}, 
    {Hue[0.44351597401038756`], AbsoluteThickness[0.5], 
     LineBox[{{2.874401641472924, 0.8353535702065428}, {2.700765721031118, 
      0.872423121498889}}]}, 
    {Hue[0.6564385234910702], AbsoluteThickness[0.5], 
     LineBox[{{2.700765721031118, 0.872423121498889}, {2.594207019314376, 
      0.7304061239629206}}]}, 
    {Hue[0.6705159882426757], AbsoluteThickness[0.5], 
     LineBox[{{4.1566020874311045`, 1.3948686334667941`}, {4.288513573205669, 
      1.5843620745615243`}}]}, 
    {Hue[0.6708995662372941], AbsoluteThickness[0.5], 
     LineBox[{{4.288513573205669, 1.5843620745615243`}, {4.434230233882032, 
      1.8265236218852379`}}]}, 
    {Hue[0.5471978681888069], AbsoluteThickness[0.5], 
     LineBox[{{2.962953264961906, 0.8250378530382365}, {2.872577200713656, 
      0.8371273671687086}}]}, 
    {Hue[0.5483088097555177], AbsoluteThickness[0.5], 
     LineBox[{{2.872577200713656, 0.8371273671687086}, {2.647719817861916, 
      0.8400449151302908}}]}, 
    {Hue[0.4461409362199773], AbsoluteThickness[0.5], 
     LineBox[{{2.8527497331871134`, 0.9455596562108208}, {2.799054144884693, 
      1.0514884273813996`}}]}, 
    {Hue[0.44634481005331705`], AbsoluteThickness[0.5], 
     LineBox[{{2.799054144884693, 1.0514884273813996`}, {2.651432219296955, 
      1.3603774696099153`}}]}, 
    {Hue[0.5756676084882357], AbsoluteThickness[0.5], 
     LineBox[{{2.88965565168125, 1.1046454086706592`}, {2.8897054905365716`, 
      1.104736744939623}}]}, 
    {Hue[0.5874546005510799], AbsoluteThickness[0.5], 
     LineBox[{{2.8897054905365716`, 1.104736744939623}, {2.9294255861950274`, 
      1.2662841266646672`}}]}, 
    {Hue[0.6648589074430211], AbsoluteThickness[0.5], 
     LineBox[{{2.964069326973405, -0.6132710566160591}, {
      2.9168138999373223`, -0.7051666635248719}}]}, 
    {Hue[0.6652492107745259], AbsoluteThickness[0.5], 
     LineBox[{{2.9168138999373223`, -0.7051666635248719}, {
      2.7903414601329137`, -0.9150460813852921}}]}, 
    {Hue[0.41635527888753043`], AbsoluteThickness[0.5], 
     LineBox[{{2.6545398615910583`, -1.280178969740208}, {
      2.503822008840952, -1.3552129096803736`}}]}, 
    {Hue[0.4175006761992627], AbsoluteThickness[0.5], 
     LineBox[{{2.503822008840952, -1.3552129096803736`}, {
      2.335531677235352, -1.4663065767668944`}}]}, 
    {Hue[0.4389649747474893], AbsoluteThickness[0.5], 
     LineBox[{{3.4528534018009265`, -1.0906598151282794`}, {
      3.3747794230132278`, -1.2100033118374303`}}]}, 
    {Hue[0.4396149382320487], AbsoluteThickness[0.5], 
     LineBox[{{3.3747794230132278`, -1.2100033118374303`}, {
      3.2175576221075644`, -1.407368696474002}}]}, 
    {Hue[0.6900361838934844], AbsoluteThickness[0.5], 
     LineBox[{{4.0215053031803265`, -0.1365688422437436}, {
      3.8714170205849907`, -0.1899383071354556}}]}, 
    {Hue[0.6902196116159037], AbsoluteThickness[0.5], 
     LineBox[{{3.8714170205849907`, -0.1899383071354556}, {
      3.5497612598705612`, -0.30326694863810244`}}]}, 
    {Hue[0.454389818785093], AbsoluteThickness[0.5], 
     LineBox[{{3.7095927179649006`, 0.3694555953323202}, {3.5830711532181354`,
       0.39482902294536726`}}]}, 
    {Hue[0.4546982609368363], AbsoluteThickness[0.5], 
     LineBox[{{3.5830711532181354`, 0.39482902294536726`}, {
      3.3199501454438773`, 0.46261288869489703`}}]}, 
    {Hue[0.68819277218077], AbsoluteThickness[0.5], 
     LineBox[{{4.232349480833086, 0.9075335520499725}, {4.269784719445412, 
      1.1122674644837052`}}]}, 
    {Hue[0.6884047452003055], AbsoluteThickness[0.5], 
     LineBox[{{4.269784719445412, 1.1122674644837052`}, {4.316627609022407, 
      1.4150762881589727`}}]}, 
    {Hue[0.6721295306679208], AbsoluteThickness[0.5], 
     LineBox[{{5.618099162223654, 0.631822219651038}, {5.645647895609862, 
      0.6786811532817432}}]}, 
    {Hue[0.6723720779498005], AbsoluteThickness[0.5], 
     LineBox[{{5.645647895609862, 0.6786811532817432}, {5.799127858721389, 
      0.9180940447729026}}]}, 
    {Hue[0.40080892412359337`], AbsoluteThickness[0.5], 
     LineBox[{{4.9705929431190015`, 0.6843149737851442}, {4.899941011965765, 
      0.7458439041177413}}]}, 
    {Hue[0.40171713087032], AbsoluteThickness[0.5], 
     LineBox[{{4.899941011965765, 0.7458439041177413}, {4.71671549254766, 
      0.8729662902272273}}]}, 
    {Hue[0.6830009735588818], AbsoluteThickness[0.5], 
     LineBox[{{4.698679316809952, 0.14323389961481361`}, {4.655763772139483, 
      0.1366737163587785}}]}, 
    {Hue[0.6833570073304843], AbsoluteThickness[0.5], 
     LineBox[{{4.655763772139483, 0.1366737163587785}, {4.397708205712049, 
      0.08057332563951655}}]}, 
    {Hue[0.5996268396622014], AbsoluteThickness[0.5], 
     LineBox[{{6.050783306785948, -0.26091767258249676`}, {
      5.883599341133357, -0.36116449926156435`}}]}, 
    {Hue[0.602009627663375], AbsoluteThickness[0.5], 
     LineBox[{{5.883599341133357, -0.36116449926156435`}, {
      5.734567675388738, -0.42073563195442343`}}]}, 
    {Hue[0.21422801206394804`], AbsoluteThickness[0.5], 
     LineBox[{{6.266462557308947, -0.4372999424005015}, {
      6.381514964835767, -0.5186948359539496}}]}, 
    {Hue[0.21450618355118772`], AbsoluteThickness[0.5], 
     LineBox[{{6.381514964835767, -0.5186948359539496}, {
      6.639330255385841, -0.6831522198358223}}]}, 
    {Hue[0.6291811623036083], AbsoluteThickness[0.5], 
     LineBox[{{6.639330255385841, -0.6831522198358223}, {
      6.593103752960103, -0.3808641690826178}}]}, 
    {Hue[0.6004439557974712], AbsoluteThickness[0.5], 
     LineBox[{{6.340928797522072, -0.1688171249226691}, {
      6.364726631954419, -0.05188299846126178}}]}, 
    {Hue[0.6010858585245522], AbsoluteThickness[0.5], 
     LineBox[{{6.364726631954419, -0.05188299846126178}, {6.435475922970339, 
      0.18220880631998992`}}]}, 
    {Hue[0.4570755935693357], AbsoluteThickness[0.5], 
     LineBox[{{6.078954373256245, 0.2500927233677525}, {5.8171415788764795`, 
      0.20293311017655968`}}]}, 
    {Hue[0.45729684462058934`], AbsoluteThickness[0.5], 
     LineBox[{{5.8171415788764795`, 0.2029331101765597}, {5.593901268418461, 
      0.16989544610745042`}}]}, 
    {Hue[0.013081502171258707`], AbsoluteThickness[0.5], 
     LineBox[{{6.385877384362597, 0.3672198357910872}, {6.46397806998668, 
      0.3961971742504616}}]}, 
    {Hue[0.016678766256371158`], AbsoluteThickness[0.5], 
     LineBox[{{6.46397806998668, 0.3961971742504616}, {6.5901068238903555`, 
      0.47152052588080945`}}]}, 
    {Hue[0.24306384018427], AbsoluteThickness[0.5], 
     LineBox[{{6.5901068238903555`, 0.4715205258808095}, {6.569286664841523, 
      0.616946076728329}}]}, 
    {Hue[0.4694489141121686], AbsoluteThickness[0.5], 
     LineBox[{{6.569286664841523, 0.616946076728329}, {6.427090072857617, 
      0.65385405811834}}]}, 
    {Hue[0.6958339880400677], AbsoluteThickness[0.5], 
     LineBox[{{6.427090072857617, 0.65385405811834}, {6.338170829330356, 
      0.5369120297766741}}]}, 
    {Hue[0.4574482420682158], AbsoluteThickness[0.5], 
     LineBox[{{6.10438412011554, 0.19786211558100952`}, {6.081452134150184, 
      0.18435347933583313`}}]}, 
    {Hue[0.45792884473398543`], AbsoluteThickness[0.5], 
     LineBox[{{6.081452134150184, 0.18435347933583313`}, {5.850888149584709, 
      0.023020528021387685`}}]}, 
    {Hue[0.5308243309360224], AbsoluteThickness[0.5], 
     LineBox[{{5.826683256183537, 0.45472933508594915`}, {5.668343071788032, 
      0.5220777142812463}}]}, 
    {Hue[0.5311075804382953], AbsoluteThickness[0.5], 
     LineBox[{{5.668343071788032, 0.5220777142812463}, {5.367192815857526, 
      0.6330714094465906}}]}, 
    {Hue[0.22481366659602073`], AbsoluteThickness[0.5], 
     LineBox[{{5.865410312505054, 0.6554846140465254}, {5.865531100028655, 
      0.6558574549179828}}]}, 
    {Hue[0.2264825544867541], AbsoluteThickness[0.5], 
     LineBox[{{5.865531100028655, 0.6558574549179828}, {5.898362925789411, 
      0.8443488925545409}}]}, 
    {Hue[0.5088998834787345], AbsoluteThickness[0.5], 
     LineBox[{{5.898362925789411, 0.8443488925545409}, {5.720389387508421, 
      0.9145797299183803}}]}, 
    {Hue[0.5331696428809027], AbsoluteThickness[0.5], 
     LineBox[{{6.068810334202852, 0.6347265289902424}, {6.345098640148805, 
      0.5716557199086093}}]}, 
    {Hue[0.5333565633029127], AbsoluteThickness[0.5], 
     LineBox[{{6.345098640148805, 0.5716557199086093}, {6.601759200889874, 
      0.5103319550200578}}]}, 
    {Hue[0.43263029405388176`], AbsoluteThickness[0.5], 
     LineBox[{{5.324433384014403, 0.5643586341087806}, {5.25685805736425, 
      0.6060839947188786}}]}, 
    {Hue[0.43362020279483504`], AbsoluteThickness[0.5], 
     LineBox[{{5.25685805736425, 0.6060839947188786}, {5.090506017080307, 
      0.737171203163886}}]}, 
    {Hue[0.6509225883390762], AbsoluteThickness[0.5], 
     LineBox[{{4.960778241183477, -0.13227393548212468`}, {
      4.862506407101621, -0.15506615480032948`}}]}, 
    {Hue[0.6511369506714446], AbsoluteThickness[0.5], 
     LineBox[{{4.862506407101621, -0.15506615480032948`}, {
      4.561073218499606, -0.23407451704225998`}}]}, 
    {Hue[0.4719842628011275], AbsoluteThickness[0.5], 
     LineBox[{{5.368665699292367, -0.6386508757579388}, {
      5.346770984931949, -0.966173849270861}}]}, 
    {Hue[0.4778761861353045], AbsoluteThickness[0.5], 
     LineBox[{{5.346770984931949, -0.966173849270861}, {
      5.3706584693009765`, -1.1285576357412543`}}]}, 
    {Hue[0.6687828882342224], AbsoluteThickness[0.5], 
     LineBox[{{5.370658469300976, -1.1285576357412543`}, {
      5.525299534917696, -1.1835598797215485`}}]}, 
    {Hue[0.4669675258963826], AbsoluteThickness[0.5], 
     LineBox[{{4.862033541413417, -0.5694760611249675}, {
      4.843546772902948, -0.577372549175145}}]}, 
    {Hue[0.46740339125080593`], AbsoluteThickness[0.5], 
     LineBox[{{4.843546772902948, -0.577372549175145}, {
      4.62020904994084, -0.6927533534632233}}]}, 
    {Hue[0.5414645692632142], AbsoluteThickness[0.5], 
     LineBox[{{4.6598052417380575`, -0.08667403832027229}, {
      4.644180013893946, -0.08190306712637067}}]}, 
    {Hue[0.5417907577597303], AbsoluteThickness[0.5], 
     LineBox[{{4.644180013893946, -0.08190306712637067}, {4.3916852340172055`,
       0.011356320668955006`}}]}, 
    {Hue[0.6135270214104337], AbsoluteThickness[0.5], 
     LineBox[{{5.023892590390386, 0.17942858185625332`}, {4.963593281354314, 
      0.40446042622468326`}}]}, 
    {Hue[0.6139777448929925], AbsoluteThickness[0.5], 
     LineBox[{{4.963593281354314, 0.40446042622468326`}, {4.917328532690551, 
      0.6491059597694256}}]}, 
    {Hue[0.6889670109186823], AbsoluteThickness[0.5], 
     LineBox[{{5.668226346046645, 0.5234462570138415}, {5.7218301323823555`, 
      0.6254710583343828}}]}, 
    {Hue[0.689162018088169], AbsoluteThickness[0.5], 
     LineBox[{{5.7218301323823555`, 0.6254710583343828}, {5.856008136082876, 
      0.892256352907218}}]}, 
    {Hue[0.447950301945462], AbsoluteThickness[0.5], 
     LineBox[{{3.836599226409276, -0.5489259410795577}, {
      3.669827641570253, -0.6118987683239112}}]}, 
    {Hue[0.4488048186562987], AbsoluteThickness[0.5], 
     LineBox[{{3.669827641570253, -0.6118987683239112}, {
      3.440801978911579, -0.6713898163737759}}]}, 
    {Hue[0.6521044086763746], AbsoluteThickness[0.5], 
     LineBox[{{2.874401641472924, 0.8353535702065428}, {2.7800941570748763`, 
      1.048199041125198}}]}, 
    {Hue[0.6523204224744242], AbsoluteThickness[0.5], 
     LineBox[{{2.7800941570748763`, 1.048199041125198}, {2.6522622387944037`, 
      1.3610242766510867`}}]}, 
    {Hue[0.4478500888250823], AbsoluteThickness[0.5], 
     LineBox[{{2.700765721031118, 0.872423121498889}, {2.540332325001979, 
      0.8750370702415957}}]}, 
    {Hue[0.4487119969885089], AbsoluteThickness[0.5], 
     LineBox[{{2.540332325001979, 0.8750370702415957}, {2.3652191267041047`, 
      0.8967965807865681}}]}, 
    {Hue[0.660772638305765], AbsoluteThickness[0.5], 
     LineBox[{{2.594207019314376, 0.7304061239629206}, {2.5653768335927825`, 
      0.67067236065996}}]}, 
    {Hue[0.6609602242501947], AbsoluteThickness[0.5], 
     LineBox[{{2.5653768335927825`, 0.67067236065996}, {2.423048150401369, 
      0.3838397198217184}}]}, 
    {Hue[0.6712831442319124], AbsoluteThickness[0.5], 
     LineBox[{{4.434230233882032, 1.8265236218852379`}, {4.442488502570082, 
      1.842571367732075}}]}, 
    {Hue[0.671474074264443], AbsoluteThickness[0.5], 
     LineBox[{{4.442488502570082, 1.842571367732075}, {4.592996513027466, 
      2.1249490237982482`}}]}, 
    {Hue[0.5494197513222284], AbsoluteThickness[0.5], 
     LineBox[{{2.647719817861916, 0.8400449151302908}, {2.4122339635400483`, 
      0.8147439907309327}}]}, 
    {Hue[0.549603648288553], AbsoluteThickness[0.5], 
     LineBox[{{2.4122339635400483`, 0.8147439907309327}, {2.1679364592479047`,
       0.7873630095557195}}]}, 
    {Hue[0.4465486838866569], AbsoluteThickness[0.5], 
     LineBox[{{2.651432219296955, 1.3603774696099153`}, {2.6317869098812796`, 
      1.4040762764764532`}}]}, 
    {Hue[0.44695485883003283`], AbsoluteThickness[0.5], 
     LineBox[{{2.6317869098812796`, 1.4040762764764532`}, {2.495720909980971, 
      1.6579704444939585`}}]}, 
    {Hue[0.5992415926139238], AbsoluteThickness[0.5], 
     LineBox[{{2.9294255861950274`, 1.2662841266646672`}, {
      2.9280989752410815`, 1.3428405400690842`}}]}, 
    {Hue[0.5994775978150687], AbsoluteThickness[0.5], 
     LineBox[{{2.9280989752410815`, 1.3428405400690842`}, {
      2.9343541138804152`, 1.6684119244566258`}}]}, 
    {Hue[0.6656395141060306], AbsoluteThickness[0.5], 
     LineBox[{{2.7903414601329137`, -0.9150460813852921}, {
      2.4842168326986034`, -1.3533368486914512`}}]}, 
    {Hue[0.665986013368467], AbsoluteThickness[0.5], 
     LineBox[{{2.4842168326986034`, -1.3533368486914512`}, {
      2.3495590308742202`, -1.5735559140602946`}}]}, 
    {Hue[0.418646073510995], AbsoluteThickness[0.5], 
     LineBox[{{2.335531677235352, -1.4663065767668944`}, {
      2.1968282486405424`, -1.5843271908251064`}}]}, 
    {Hue[0.4367296112391562], AbsoluteThickness[0.5], 
     LineBox[{{2.1968282486405424`, -1.5843271908251064`}, {
      2.122821027838444, -1.6979744077857233`}}]}, 
    {Hue[0.5503529923120155], AbsoluteThickness[0.5], 
     LineBox[{{2.122821027838444, -1.6979744077857233`}, {
      2.17184458169658, -1.8244238040708087`}}]}, 
    {Hue[0.6639763733848759], AbsoluteThickness[0.5], 
     LineBox[{{2.17184458169658, -1.8244238040708087`}, {
      2.3031174647941777`, -1.8584853486187098`}}]}, 
    {Hue[0.4402649017166083], AbsoluteThickness[0.5], 
     LineBox[{{3.2175576221075644`, -1.407368696474002}, {
      3.1691153892197756`, -1.4577264201050941`}}]}, 
    {Hue[0.4405479149628941], AbsoluteThickness[0.5], 
     LineBox[{{3.1691153892197756`, -1.4577264201050941`}, {
      2.9545503044322277`, -1.6599496305216164`}}]}, 
    {Hue[0.6904030393383233], AbsoluteThickness[0.5], 
     LineBox[{{3.5497612598705612`, -0.30326694863810244`}, {
      3.404192993676753, -0.35408154355463156`}}]}, 
    {Hue[0.6910639913554336], AbsoluteThickness[0.5], 
     LineBox[{{3.404192993676753, -0.35408154355463156`}, {
      3.1711990803001635`, -0.4115125146935025}}]}, 
    {Hue[0.45500670308857954`], AbsoluteThickness[0.5], 
     LineBox[{{3.3199501454438773`, 0.46261288869489703`}, {
      3.1817374130547575`, 0.5063297872396552}}]}, 
    {Hue[0.45519256669611596`], AbsoluteThickness[0.5], 
     LineBox[{{3.1817374130547575`, 0.5063297872396552}, {2.8956096724243867`,
       0.5941363996724759}}]}, 
    {Hue[0.6886167182198409], AbsoluteThickness[0.5], 
     LineBox[{{4.316627609022407, 1.4150762881589727`}, {4.339192280199492, 
      1.5930613960057278`}}]}, 
    {Hue[0.6888841209514609], AbsoluteThickness[0.5], 
     LineBox[{{4.339192280199492, 1.5930613960057278`}, {4.3638619846663005`, 
      1.897890825549716}}]}, 
    {Hue[0.6726146252316801], AbsoluteThickness[0.5], 
     LineBox[{{5.799127858721389, 0.9180940447729026}, {6.0516089093221535`, 
      1.2803718303013756`}}]}, 
    {Hue[0.6742431395063346], AbsoluteThickness[0.5], 
     LineBox[{{6.0516089093221535`, 1.2803718303013756`}, {6.186980434491088, 
      1.4262010764902882`}}]}, 
    {Hue[0.40262533761704655`], AbsoluteThickness[0.5], 
     LineBox[{{4.71671549254766, 0.8729662902272273}, {4.656340914544981, 
      0.9056846679963191}}]}, 
    {Hue[0.4028146134241972], AbsoluteThickness[0.5], 
     LineBox[{{4.656340914544981, 0.9056846679963191}, {4.3477706183017695`, 
      1.0780641496062522`}}]}, 
    {Hue[0.6837130411020867], AbsoluteThickness[0.5], 
     LineBox[{{4.397708205712049, 0.08057332563951655}, {4.189373374273458, 
      0.021467253382598736`}}]}, 
    {Hue[0.6839294198463485], AbsoluteThickness[0.5], 
     LineBox[{{4.189373374273458, 0.021467253382598736`}, {
      3.886363500432843, -0.05497944326763965}}]}, 
    {Hue[0.6043924156645484], AbsoluteThickness[0.5], 
     LineBox[{{5.734567675388738, -0.42073563195442343`}, {
      5.628213718193005, -0.444562251532586}}]}, 
    {Hue[0.6046409851787445], AbsoluteThickness[0.5], 
     LineBox[{{5.628213718193005, -0.444562251532586}, {
      5.335781837376667, -0.5225924266413898}}]}, 
    {Hue[0.6289029908163692], AbsoluteThickness[0.5], 
     LineBox[{{6.381514964835767, -0.5186948359539496}, {
      5.911232301346223, -0.6804740080385091}}]}, 
    {Hue[0.6290872467365279], AbsoluteThickness[0.5], 
     LineBox[{{5.911232301346223, -0.6804740080385091}, {
      5.624663377518157, -0.777283667465705}}]}, 
    {Hue[0.21478435503842727`], AbsoluteThickness[0.5], 
     LineBox[{{6.639330255385841, -0.6831522198358223}, {
      6.6616951298003775`, -0.6959549043217395}}]}, 
    {Hue[0.21499149791660932`], AbsoluteThickness[0.5], 
     LineBox[{{6.6616951298003775`, -0.6959549043217395}, {
      6.903791814934578, -0.8427133549804139}}]}, 
    {Hue[0.6515088079725282], AbsoluteThickness[0.5], 
     LineBox[{{6.903791814934578, -0.8427133549804139}, {
      6.621496895843233, -0.8213024594383405}}]}, 
    {Hue[0.629459333790848], AbsoluteThickness[0.5], 
     LineBox[{{6.593103752960103, -0.3808641690826178}, {
      6.585937710344732, -0.34544883692820877`}}]}, 
    {Hue[0.6312147724737611], AbsoluteThickness[0.5], 
     LineBox[{{6.585937710344732, -0.34544883692820877`}, {
      6.574334237508879, -0.139023951860052}}]}, 
    {Hue[0.6017277612516331], AbsoluteThickness[0.5], 
     LineBox[{{6.435475922970339, 0.18220880631998992`}, {6.5277167916844, 
      0.4090387728449872}}]}, 
    {Hue[0.602453541150469], AbsoluteThickness[0.5], 
     LineBox[{{6.5277167916844, 0.4090387728449872}, {6.5835171622575075`, 
      0.5978111898525217}}]}, 
    {Hue[0.4575180956718432], AbsoluteThickness[0.5], 
     LineBox[{{5.593901268418461, 0.1698954461074504}, {5.5368369334040395`, 
      0.16326730455128366`}}]}, 
    {Hue[0.5156005851446641], AbsoluteThickness[0.5], 
     LineBox[{{5.5368369334040395`, 0.16326730455128366`}, {5.447483270690153,
       0.11587933936681133`}}]}, 
    {Hue[0.5609350936095716], AbsoluteThickness[0.5], 
     LineBox[{{5.447483270690153, 0.11587933936681133`}, {5.42785836360701, 
      0.016659586763362173`}}]}, 
    {Hue[0.6062696020744827], AbsoluteThickness[0.5], 
     LineBox[{{5.42785836360701, 0.016659586763362176`}, {
      5.492443700937656, -0.06117633352154406}}]}, 
    {Hue[0.6516041105393936], AbsoluteThickness[0.5], 
     LineBox[{{5.492443700937656, -0.06117633352154406}, {
      5.593580874204508, -0.06019222565020976}}]}, 
    {Hue[0.6969386190043046], AbsoluteThickness[0.5], 
     LineBox[{{5.593580874204508, -0.06019222565020976}, {5.656639372597604, 
      0.018885723647427514`}}]}, 
    {Hue[0.23946657609915584`], AbsoluteThickness[0.5], 
     LineBox[{{6.46397806998668, 0.3961971742504616}, {6.612509852193087, 
      0.3238578492146921}}]}, 
    {Hue[0.2396536642148841], AbsoluteThickness[0.5], 
     LineBox[{{6.612509852193087, 0.3238578492146921}, {6.898387262851132, 
      0.1809591662737341}}]}, 
    {Hue[0.6837171918558463], AbsoluteThickness[0.5], 
     LineBox[{{6.898387262851132, 0.1809591662737341}, {6.5900884129714665`, 
      0.26520729191273357`}}]}, 
    {Hue[0.020276030341483762`], AbsoluteThickness[0.5], 
     LineBox[{{6.5901068238903555`, 0.47152052588080956`}, {
      6.7103606959140265`, 0.5772951254941001}}]}, 
    {Hue[0.0205718551467718], AbsoluteThickness[0.5], 
     LineBox[{{6.7103606959140265`, 0.5772951254941001}, {6.935844594623621, 
      0.7973177727561169}}]}, 
    {Hue[0.43068984087178513`], AbsoluteThickness[0.5], 
     LineBox[{{6.935844594623621, 0.7973177727561169}, {6.623695705447773, 
      0.8399326160826954}}]}, 
    {Hue[0.24666110426938262`], AbsoluteThickness[0.5], 
     LineBox[{{6.569286664841523, 0.616946076728329}, {6.4874006132775435`, 
      0.8597499173682634}}]}, 
    {Hue[0.24685827577854072`], AbsoluteThickness[0.5], 
     LineBox[{{6.4874006132775435`, 0.8597499173682634}, {6.385731150277527, 
      1.1815774722078438`}}]}, 
    {Hue[0.6870315004951044], AbsoluteThickness[0.5], 
     LineBox[{{6.385731150277527, 1.1815774722078438`}, {6.595407208774853, 
      0.9171051574870768}}]}, 
    {Hue[0.47304617819728123`], AbsoluteThickness[0.5], 
     LineBox[{{6.427090072857617, 0.65385405811834}, {6.407772164511959, 
      0.6552256069035045}}]}, 
    {Hue[0.4733586027067991], AbsoluteThickness[0.5], 
     LineBox[{{6.407772164511959, 0.6552256069035045}, {6.17426127708289, 
      0.6847681835117939}}]}, 
    {Hue[0.6994312521251803], AbsoluteThickness[0.5], 
     LineBox[{{6.338170829330356, 0.5369120297766741}, {6.29429118719413, 
      0.4498904721833331}}]}, 
    {Hue[0.6996189126873044], AbsoluteThickness[0.5], 
     LineBox[{{6.29429118719413, 0.4498904721833331}, {6.149860507509465, 
      0.15542061427856801`}}]}, 
    {Hue[0.4584094473997551], AbsoluteThickness[0.5], 
     LineBox[{{5.850888149584709, 0.023020528021387654`}, {
      5.152008776889274, -0.5523167722276326}}]}, 
    {Hue[0.4594834274896925], AbsoluteThickness[0.5], 
     LineBox[{{5.152008776889274, -0.5523167722276326}, {
      4.976148157166832, -0.6651470108793203}}]}, 
    {Hue[0.5313908299405682], AbsoluteThickness[0.5], 
     LineBox[{{5.367192815857526, 0.6330714094465906}, {5.339669363981522, 
      0.6417085268261644}}]}, 
    {Hue[0.53172093311823], AbsoluteThickness[0.5], 
     LineBox[{{5.339669363981522, 0.6417085268261644}, {5.090655489293798, 
      0.7360701536815027}}]}, 
    {Hue[0.5072309955879984], AbsoluteThickness[0.5], 
     LineBox[{{5.865531100028655, 0.6558574549179828}, {5.866032082750782, 
      0.6559443778978106}}]}, 
    {Hue[0.5097857700712862], AbsoluteThickness[0.5], 
     LineBox[{{5.866032082750782, 0.6559443778978106}, {6.043512798331155, 
      0.6573804419320666}}]}, 
    {Hue[0.22815144237748752`], AbsoluteThickness[0.5], 
     LineBox[{{5.898362925789411, 0.8443488925545409}, {5.899262128321833, 
      0.8727879726536775}}]}, 
    {Hue[0.22961914525809987`], AbsoluteThickness[0.5], 
     LineBox[{{5.899262128321833, 0.8727879726536775}, {5.934985647022961, 
      1.0862925640458698`}}]}, 
    {Hue[0.5214685507819192], AbsoluteThickness[0.5], 
     LineBox[{{5.934985647022961, 1.0862925640458698`}, {6.151457852592751, 
      1.0858869168008731`}}]}, 
    {Hue[0.5105687713694679], AbsoluteThickness[0.5], 
     LineBox[{{5.720389387508421, 0.9145797299183803}, {5.666533260694018, 
      0.9274747733141636}}]}, 
    {Hue[0.5107560476733822], AbsoluteThickness[0.5], 
     LineBox[{{5.666533260694018, 0.9274747733141636}, {5.343756785437981, 
      1.0083714905520778`}}]}, 
    {Hue[0.5335434837249226], AbsoluteThickness[0.5], 
     LineBox[{{6.601759200889874, 0.5103319550200578}, {6.839475126009467, 
      0.4509905851077668}}]}, 
    {Hue[0.5337518350082154], AbsoluteThickness[0.5], 
     LineBox[{{6.839475126009467, 0.4509905851077668}, {7.143881683462895, 
      0.3832461284525548}}]}, 
    {Hue[0.43461011153578827`], AbsoluteThickness[0.5], 
     LineBox[{{5.090506017080307, 0.737171203163886}, {4.991659151421143, 
      0.8352725985202283}}]}, 
    {Hue[0.43543078413390474`], AbsoluteThickness[0.5], 
     LineBox[{{4.991659151421143, 0.8352725985202283}, {4.839439865992445, 
      1.0218694340316077`}}]}, 
    {Hue[0.651351313003813], AbsoluteThickness[0.5], 
     LineBox[{{4.561073218499606, -0.23407451704225998`}, {
      4.44134789660697, -0.2691230503460128}}]}, 
    {Hue[0.6516180653992973], AbsoluteThickness[0.5], 
     LineBox[{{4.44134789660697, -0.2691230503460128}, {
      4.122856680468086, -0.3469255217782274}}]}, 
    {Hue[0.6628909649000444], AbsoluteThickness[0.5], 
     LineBox[{{5.346770984931949, -0.966173849270861}, {
      5.040126630241996, -1.3128848690005974`}}]}, 
    {Hue[0.6633531544806814], AbsoluteThickness[0.5], 
     LineBox[{{5.040126630241996, -1.3128848690005974`}, {
      4.899821121356265, -1.4982348238119843`}}]}, 
    {Hue[0.48376810946948157`], AbsoluteThickness[0.5], 
     LineBox[{{5.370658469300976, -1.1285576357412543`}, {
      5.461859781943019, -1.371691218610847}}]}, 
    {Hue[0.4839590555805361], AbsoluteThickness[0.5], 
     LineBox[{{5.461859781943019, -1.371691218610847}, {
      5.5760497386044126`, -1.6632283365645302`}}]}, 
    {Hue[0.6746748115683995], AbsoluteThickness[0.5], 
     LineBox[{{5.525299534917696, -1.1835598797215485`}, {
      5.600761982400861, -1.1933424117791065`}}]}, 
    {Hue[0.674859613232596], AbsoluteThickness[0.5], 
     LineBox[{{5.600761982400861, -1.1933424117791065`}, {
      5.916170905633331, -1.2320732494795885`}}]}, 
    {Hue[0.46783925660522935`], AbsoluteThickness[0.5], 
     LineBox[{{4.62020904994084, -0.6927533534632233}, {
      4.421059584571563, -0.814860172281644}}]}, 
    {Hue[0.46850681978059366`], AbsoluteThickness[0.5], 
     LineBox[{{4.421059584571563, -0.814860172281644}, {
      4.211636102543155, -0.9174096462932262}}]}, 
    {Hue[0.5421169462562463], AbsoluteThickness[0.5], 
     LineBox[{{4.3916852340172055`, 0.011356320668955004`}, {
      4.165796928560684, 0.1098764015693789}}]}, 
    {Hue[0.5433168831386145], AbsoluteThickness[0.5], 
     LineBox[{{4.165796928560684, 0.1098764015693789}, {3.956690241253088, 
      0.17168039885872202`}}]}, 
    {Hue[0.6144284683755513], AbsoluteThickness[0.5], 
     LineBox[{{4.917328532690551, 0.6491059597694256}, {4.891472330682532, 
      0.879007572435998}}]}, 
    {Hue[0.6152269787107987], AbsoluteThickness[0.5], 
     LineBox[{{4.891472330682532, 0.879007572435998}, {4.8894263217254865`, 
      1.1211417280571658`}}]}, 
    {Hue[0.6893570252576557], AbsoluteThickness[0.5], 
     LineBox[{{5.856008136082876, 0.892256352907218}, {5.877142979456383, 
      0.9362061847735541}}]}, 
    {Hue[0.6907407539336129], AbsoluteThickness[0.5], 
     LineBox[{{5.877142979456383, 0.9362061847735541}, {5.996981320663829, 
      1.1193631448066796`}}]}, 
    {Hue[0.44965933536713537`], AbsoluteThickness[0.5], 
     LineBox[{{3.440801978911579, -0.6713898163737759}, {
      3.3397884269225475`, -0.6863708108810382}}]}, 
    {Hue[0.44996535831483236`], AbsoluteThickness[0.5], 
     LineBox[{{3.3397884269225475`, -0.6863708108810382}, {
      3.060092723143652, -0.7433532091214999}}]}, 
    {Hue[0.6525364362724737], AbsoluteThickness[0.5], 
     LineBox[{{2.652262238794404, 1.3610242766510867`}, {2.634322296068684, 
      1.4088634427580893`}}]}, 
    {Hue[0.6530691830020815], AbsoluteThickness[0.5], 
     LineBox[{{2.634322296068684, 1.4088634427580893`}, {2.5179669445967625`, 
      1.6546179606098674`}}]}, 
    {Hue[0.44957390515193546`], AbsoluteThickness[0.5], 
     LineBox[{{2.3652191267041047`, 0.8967965807865681}, {2.3584371703534224`,
       0.8983914028520312}}]}, 
    {Hue[0.454595445721452], AbsoluteThickness[0.5], 
     LineBox[{{2.3584371703534224`, 0.8983914028520312}, {2.22879531666272, 
      0.9020263899058154}}]}, 
    {Hue[0.6569336628349186], AbsoluteThickness[0.5], 
     LineBox[{{2.22879531666272, 0.9020263899058154}, {2.167926937343688, 
      0.7875044978575388}}]}, 
    {Hue[0.6611478101946244], AbsoluteThickness[0.5], 
     LineBox[{{2.423048150401369, 0.3838397198217184}, {
      2.070299296037435, -0.3079337586645584}}]}, 
    {Hue[0.66133107044785], AbsoluteThickness[0.5], 
     LineBox[{{2.070299296037435, -0.3079337586645584}, {
      1.9265945208348418`, -0.5911279665573725}}]}, 
    {Hue[0.6716650042969736], AbsoluteThickness[0.5], 
     LineBox[{{4.592996513027466, 2.1249490237982482`}, {4.611110226660915, 
      2.157782503145335}}]}, 
    {Hue[0.6718976446598106], AbsoluteThickness[0.5], 
     LineBox[{{4.611110226660915, 2.157782503145335}, {4.764975851525028, 
      2.414726189496874}}]}, 
    {Hue[0.44736103377340874`], AbsoluteThickness[0.5], 
     LineBox[{{2.495720909980971, 1.6579704444939585`}, {2.4243203082646443`, 
      1.7714919169140946`}}]}, 
    {Hue[0.44889938400760737`], AbsoluteThickness[0.5], 
     LineBox[{{2.4243203082646443`, 1.7714919169140946`}, {2.312530256982746, 
      1.9047407108645917`}}]}, 
    {Hue[0.5997136030162136], AbsoluteThickness[0.5], 
     LineBox[{{2.9343541138804152`, 1.6684119244566258`}, {2.944238569475594, 
      1.8455352239882736`}}]}, 
    {Hue[0.5999303265158445], AbsoluteThickness[0.5], 
     LineBox[{{2.944238569475594, 1.8455352239882736`}, {2.9696703051931497`, 
      2.143299400268076}}]}, 
    {Hue[0.6663325126309031], AbsoluteThickness[0.5], 
     LineBox[{{2.3495590308742202`, -1.5735559140602946`}, {
      2.344019420635874, -1.5839933710191287`}}]}, 
    {Hue[0.6665158816640899], AbsoluteThickness[0.5], 
     LineBox[{{2.344019420635874, -1.5839933710191287`}, {
      2.203960725449316, -1.846230942491997}}]}, 
    {Hue[0.4548131489673168], AbsoluteThickness[0.5], 
     LineBox[{{2.122821027838444, -1.6979744077857233`}, {
      2.0942813412035988`, -1.7940861426641752`}}]}, 
    {Hue[0.4550014307631401], AbsoluteThickness[0.5], 
     LineBox[{{2.0942813412035988`, -1.7940861426641752`}, {
      1.9941947604424164`, -2.117172517617665}}]}, 
    {Hue[0.5684365300401758], AbsoluteThickness[0.5], 
     LineBox[{{2.17184458169658, -1.8244238040708087`}, {
      2.3314998299859577`, -2.030808955936765}}]}, 
    {Hue[0.5830586720865872], AbsoluteThickness[0.5], 
     LineBox[{{2.3314998299859577`, -2.030808955936765}, {
      2.4515426952274284`, -2.1199870179428464`}}]}, 
    {Hue[0.6820599111130357], AbsoluteThickness[0.5], 
     LineBox[{{2.3031174647941777`, -1.8584853486187098`}, {
      2.3538526555372528`, -1.856724289753587}}]}, 
    {Hue[0.6825897157024172], AbsoluteThickness[0.5], 
     LineBox[{{2.3538526555372528`, -1.856724289753587}, {
      2.6087330171752736`, -1.8690807179268634`}}]}, 
    {Hue[0.44083092820917996`], AbsoluteThickness[0.5], 
     LineBox[{{2.9545503044322277`, -1.6599496305216161`}, {
      2.8843245852369903`, -1.7199217785169294`}}]}, 
    {Hue[0.4412170222729683], AbsoluteThickness[0.5], 
     LineBox[{{2.8843245852369903`, -1.7199217785169294`}, {
      2.6583334482814975`, -1.8881915848497568`}}]}, 
    {Hue[0.691724943372544], AbsoluteThickness[0.5], 
     LineBox[{{3.1711990803001635`, -0.4115125146935025}, {
      3.1507501855607156`, -0.41455067932681255`}}]}, 
    {Hue[0.6919160516020043], AbsoluteThickness[0.5], 
     LineBox[{{3.1507501855607156`, -0.41455067932681255`}, {
      2.844387562893518, -0.4646491925784466}}]}, 
    {Hue[0.45537843030365227`], AbsoluteThickness[0.5], 
     LineBox[{{2.8956096724243867`, 0.5941363996724759}, {2.874159596136431, 
      0.6005179289230769}}]}, 
    {Hue[0.4556734018166436], AbsoluteThickness[0.5], 
     LineBox[{{2.874159596136431, 0.6005179289230769}, {2.5947838776974526`, 
      0.699565467163501}}]}, 
    {Hue[0.6891515236830807], AbsoluteThickness[0.5], 
     LineBox[{{4.3638619846663005`, 1.897890825549716}, {4.3728757462880425`, 
      2.152400317364623}}]}, 
    {Hue[0.6904756138725233], AbsoluteThickness[0.5], 
     LineBox[{{4.3728757462880425`, 2.152400317364623}, {4.352532376797479, 
      2.369357454152633}}]}, 
    {Hue[0.6758716537809891], AbsoluteThickness[0.5], 
     LineBox[{{6.186980434491088, 1.4262010764902882`}, {6.350438183835544, 
      1.5591974553303574`}}]}, 
    {Hue[0.6775883160569206], AbsoluteThickness[0.5], 
     LineBox[{{6.350438183835544, 1.5591974553303574`}, {6.52218963097219, 
      1.6623099573089042`}}]}, 
    {Hue[0.40300388923134794`], AbsoluteThickness[0.5], 
     LineBox[{{4.3477706183017695`, 1.0780641496062522`}, {4.284510727295245, 
      1.1144763410521983`}}]}, 
    {Hue[0.4037845371435921], AbsoluteThickness[0.5], 
     LineBox[{{4.284510727295245, 1.1144763410521983`}, {4.096591811836374, 
      1.2499734969440517`}}]}, 
    {Hue[0.68414579859061], AbsoluteThickness[0.5], 
     LineBox[{{3.886363500432843, -0.05497944326763965}, {
      3.766450187298416, -0.08152062867129992}}]}, 
    {Hue[0.6856713018798677], AbsoluteThickness[0.5], 
     LineBox[{{3.766450187298416, -0.08152062867129992}, {
      3.560933992060265, -0.15747189595957234`}}]}, 
    {Hue[0.6048895546929407], AbsoluteThickness[0.5], 
     LineBox[{{5.335781837376667, -0.5225924266413898}, {
      5.1406776893927555`, -0.5831849702109122}}]}, 
    {Hue[0.6054578274622964], AbsoluteThickness[0.5], 
     LineBox[{{5.1406776893927555`, -0.5831849702109122}, {
      4.908455139197296, -0.6337664010897093}}]}, 
    {Hue[0.6292715026566866], AbsoluteThickness[0.5], 
     LineBox[{{5.624663377518157, -0.777283667465705}, {
      5.285262011497718, -0.8898514129071506}}]}, 
    {Hue[0.6433212864500458], AbsoluteThickness[0.5], 
     LineBox[{{5.285262011497718, -0.8898514129071506}, {
      5.147244857449752, -0.8967049223682861}}]}, 
    {Hue[0.6513016650943462], AbsoluteThickness[0.5], 
     LineBox[{{6.6616951298003775`, -0.6959549043217395}, {
      6.649809728695999, -0.6757401709390647}}]}, 
    {Hue[0.6514898268197185], AbsoluteThickness[0.5], 
     LineBox[{{6.649809728695999, -0.6757401709390647}, {
      6.477344047574457, -0.3900611068834905}}]}, 
    {Hue[0.21519864079479148`], AbsoluteThickness[0.5], 
     LineBox[{{6.903791814934578, -0.8427133549804139}, {
      6.952683447459978, -0.8740524240884584}}]}, 
    {Hue[0.21658764587894747`], AbsoluteThickness[0.5], 
     LineBox[{{6.952683447459978, -0.8740524240884584}, {
      7.098021325764257, -0.9968067045346964}}]}, 
    {Hue[0.5124873323687597], AbsoluteThickness[0.5], 
     LineBox[{{7.098021325764257, -0.9968067045346964}, {
      6.997752704567444, -1.1584789527443164`}}]}, 
    {Hue[0.6517159508507103], AbsoluteThickness[0.5], 
     LineBox[{{6.621496895843233, -0.8213024594383405}, {
      6.386503912598267, -0.79754594807913}}]}, 
    {Hue[0.6519025293919913], AbsoluteThickness[0.5], 
     LineBox[{{6.386503912598267, -0.79754594807913}, {
      6.084428116973464, -0.7640639246493693}}]}, 
    {Hue[0.6329702111566743], AbsoluteThickness[0.5], 
     LineBox[{{6.574334237508879, -0.139023951860052}, {
      6.577263296573113, -0.10557389463469018`}}]}, 
    {Hue[0.6333253520191596], AbsoluteThickness[0.5], 
     LineBox[{{6.577263296573113, -0.10557389463469018`}, {6.584222943013781, 
      0.1716058667428289}}]}, 
    {Hue[0.603179321049305], AbsoluteThickness[0.5], 
     LineBox[{{6.5835171622575075`, 0.5978111898525217}, {6.601474680697096, 
      0.6918967745999689}}]}, 
    {Hue[0.6054869127729013], AbsoluteThickness[0.5], 
     LineBox[{{6.601474680697096, 0.6918967745999689}, {6.672516915681058, 
      0.8885179867466502}}]}, 
    {Hue[0.502852604136745], AbsoluteThickness[0.5], 
     LineBox[{{5.5368369334040395`, 0.16326730455128366`}, {5.348854642305988,
       0.16858535696493876`}}]}, 
    {Hue[0.5031425049380172], AbsoluteThickness[0.5], 
     LineBox[{{5.348854642305988, 0.16858535696493876`}, {5.062238178947538, 
      0.1912066990993062}}]}, 
    {Hue[0.5736830746174781], AbsoluteThickness[0.5], 
     LineBox[{{5.447483270690153, 0.11587933936681133`}, {
      5.325030926814644, -0.026245639924664915`}}]}, 
    {Hue[0.5739521600795816], AbsoluteThickness[0.5], 
     LineBox[{{5.325030926814644, -0.026245639924664915`}, {
      5.1212892282563045`, -0.285848443696126}}]}, 
    {Hue[0.6190175830823816], AbsoluteThickness[0.5], 
     LineBox[{{5.42785836360701, 0.01665958676336221}, {
      5.4982581522663425`, -0.377555216146243}}]}, 
    {Hue[0.6192124454528327], AbsoluteThickness[0.5], 
     LineBox[{{5.4982581522663425`, -0.377555216146243}, {
      5.548883626199007, -0.6931337635867161}}]}, 
    {Hue[0.6643520915472927], AbsoluteThickness[0.5], 
     LineBox[{{5.492443700937656, -0.061176333521544085`}, {
      5.6973141732691275`, -0.1747465325449184}}]}, 
    {Hue[0.6646499090948801], AbsoluteThickness[0.5], 
     LineBox[{{5.6973141732691275`, -0.1747465325449184}, {
      5.903281161164852, -0.3033895933541004}}]}, 
    {Hue[0.6835301037401167], AbsoluteThickness[0.5], 
     LineBox[{{6.612509852193087, 0.3238578492146921}, {6.5127792552332116`, 
      0.4029728818525733}}]}, 
    {Hue[0.6838724488414242], AbsoluteThickness[0.5], 
     LineBox[{{6.5127792552332116`, 0.4029728818525733}, {6.34098319847574, 
      0.5569745163120173}}]}, 
    {Hue[0.23984075233061233`], AbsoluteThickness[0.5], 
     LineBox[{{6.898387262851132, 0.1809591662737341}, {6.97435174451669, 
      0.14200277352684282`}}]}, 
    {Hue[0.24015006254830684`], AbsoluteThickness[0.5], 
     LineBox[{{6.97435174451669, 0.14200277352684282`}, {7.1533879505423, 
      0.03752729228343482}}]}, 
    {Hue[0.6469669210474227], AbsoluteThickness[0.5], 
     LineBox[{{7.1533879505423, 0.03752729228343482}, {
      6.964087541651995, -0.04693834832296653}}]}, 
    {Hue[0.6839042799715747], AbsoluteThickness[0.5], 
     LineBox[{{6.5900884129714665`, 0.26520729191273357`}, {6.400758126154542,
       0.3190506142465829}}]}, 
    {Hue[0.6841595271998806], AbsoluteThickness[0.5], 
     LineBox[{{6.400758126154542, 0.3190506142465829}, {6.103008723708266, 
      0.39029214819013164`}}]}, 
    {Hue[0.4303940160664945], AbsoluteThickness[0.5], 
     LineBox[{{6.7103606959140265`, 0.5772951254941001}, {6.739719792815295, 
      0.3986426170525476}}]}, 
    {Hue[0.4305811127131329], AbsoluteThickness[0.5], 
     LineBox[{{6.739719792815295, 0.3986426170525476}, {6.788286169112373, 
      0.08275477138089243}}]}, 
    {Hue[0.020867679952059834`], AbsoluteThickness[0.5], 
     LineBox[{{6.935844594623621, 0.7973177727561169}, {6.9767342513768655`, 
      0.8415684967397441}}]}, 
    {Hue[0.021160637516731938`], AbsoluteThickness[0.5], 
     LineBox[{{6.9767342513768655`, 0.8415684967397441}, {7.156710522321821, 
      1.057504153542214}}]}, 
    {Hue[0.43199992167484896`], AbsoluteThickness[0.5], 
     LineBox[{{7.156710522321821, 1.057504153542214}, {6.875687281178761, 
      1.0642572209501147`}}]}, 
    {Hue[0.4309856656770731], AbsoluteThickness[0.5], 
     LineBox[{{6.623695705447773, 0.8399326160826954}, {6.188869344374059, 
      0.8765301252217953}}]}, 
    {Hue[0.43124282278482756`], AbsoluteThickness[0.5], 
     LineBox[{{6.188869344374059, 0.8765301252217953}, {5.881209576075601, 
      0.9157210836573269}}]}, 
    {Hue[0.6868343289859437], AbsoluteThickness[0.5], 
     LineBox[{{6.4874006132775435`, 0.8597499173682634}, {6.471949617710071, 
      0.6611436641888342}}]}, 
    {Hue[0.6870189182751039], AbsoluteThickness[0.5], 
     LineBox[{{6.471949617710071, 0.6611436641888342}, {6.453084848827884, 
      0.3971828149358141}}]}, 
    {Hue[0.24705544728769882`], AbsoluteThickness[0.5], 
     LineBox[{{6.385731150277527, 1.1815774722078438`}, {6.364102736692175, 
      1.2549358388771608`}}]}, 
    {Hue[0.25102900522992627`], AbsoluteThickness[0.5], 
     LineBox[{{6.364102736692175, 1.2549358388771608`}, {6.285753978708785, 
      1.4070605913421486`}}]}, 
    {Hue[0.47021808200199605`], AbsoluteThickness[0.5], 
     LineBox[{{6.285753978708785, 1.4070605913421486`}, {6.114937969488056, 
      1.3969433197743022`}}]}, 
    {Hue[0.6894071587740664], AbsoluteThickness[0.5], 
     LineBox[{{6.114937969488056, 1.3969433197743022`}, {6.055094413422918, 
      1.2366335665228163`}}]}, 
    {Hue[0.6872286720042626], AbsoluteThickness[0.5], 
     LineBox[{{6.595407208774853, 0.9171051574870768}, {6.639117835616823, 
      0.8597328288639436}}]}, 
    {Hue[0.6874237426478679], AbsoluteThickness[0.5], 
     LineBox[{{6.639117835616823, 0.8597328288639436}, {6.853458526119032, 
      0.5885561136172155}}]}, 
    {Hue[0.473671027216317], AbsoluteThickness[0.5], 
     LineBox[{{6.17426127708289, 0.6847681835117939}, {5.9129569581717885`, 
      0.7325369742730579}}]}, 
    {Hue[0.4738558191221794], AbsoluteThickness[0.5], 
     LineBox[{{5.9129569581717885`, 0.7325369742730579}, {5.615981264787904, 
      0.7888893143257181}}]}, 
    {Hue[0.6998065732494285], AbsoluteThickness[0.5], 
     LineBox[{{6.149860507509465, 0.15542061427856801`}, {6.145120821954897, 
      0.14548131807801748`}}]}, 
    {Hue[0.4605574075796298], AbsoluteThickness[0.5], 
     LineBox[{{4.976148157166832, -0.6651470108793203}, {
      4.922093988224713, -0.6914005885171679}}]}, 
    {Hue[0.4607787506817087], AbsoluteThickness[0.5], 
     LineBox[{{4.922093988224713, -0.6914005885171679}, {
      4.655926041426688, -0.8105216709669426}}]}, 
    {Hue[0.5320510362958917], AbsoluteThickness[0.5], 
     LineBox[{{5.090655489293798, 0.7360701536815027}, {4.813642807021752, 
      0.8598979484814954}}]}, 
    {Hue[0.6421980210464688], AbsoluteThickness[0.5], 
     LineBox[{{4.813642807021752, 0.8598979484814954}, {4.679967194926414, 
      0.8613803822979871}}]}, 
    {Hue[0.661270279623519], AbsoluteThickness[0.5], 
     LineBox[{{4.679967194926414, 0.8613803822979871}, {4.593536982293348, 
      0.7593941811564283}}]}, 
    {Hue[0.6803425382005658], AbsoluteThickness[0.5], 
     LineBox[{{4.593536982293348, 0.7593941811564283}, {4.616922886965641, 
      0.6277717425612483}}]}, 
    {Hue[0.6994147967776196], AbsoluteThickness[0.5], 
     LineBox[{{4.616922886965641, 0.6277717425612483}, {4.733194800845937, 
      0.5618004691030476}}]}, 
    {Hue[0.512340544554574], AbsoluteThickness[0.5], 
     LineBox[{{6.043512798331155, 0.6573804419320666}, {6.210986383001262, 
      0.6311070841589409}}]}, 
    {Hue[0.5138227116969069], AbsoluteThickness[0.5], 
     LineBox[{{6.210986383001262, 0.6311070841589409}, {6.382123401893994, 
      0.6275245760517915}}]}, 
    {Hue[0.5200008479013034], AbsoluteThickness[0.5], 
     LineBox[{{5.899262128321833, 0.8727879726536775}, {5.841682554284794, 
      0.9015937670123577}}]}, 
    {Hue[0.5907044735988266], AbsoluteThickness[0.5], 
     LineBox[{{5.841682554284794, 0.9015937670123577}, {5.712539000534084, 
      0.9118442775173976}}]}, 
    {Hue[0.626857068240255], AbsoluteThickness[0.5], 
     LineBox[{{5.712539000534084, 0.9118442775173976}, {5.622717590410879, 
      0.8184888024532366}}]}, 
    {Hue[0.6630096628816858], AbsoluteThickness[0.5], 
     LineBox[{{5.622717590410879, 0.8184888024532366}, {5.637941798653708, 
      0.6898367370817262}}]}, 
    {Hue[0.6991622575231233], AbsoluteThickness[0.5], 
     LineBox[{{5.637941798653708, 0.6898367370817262}, {5.747071877350697, 
      0.620024443289261}}]}, 
    {Hue[0.23108684813871214`], AbsoluteThickness[0.5], 
     LineBox[{{5.934985647022961, 1.0862925640458698`}, {6.02114616024396, 
      1.3648656312182066`}}]}, 
    {Hue[0.23130476716915407`], AbsoluteThickness[0.5], 
     LineBox[{{6.02114616024396, 1.3648656312182066`}, {6.10158126102411, 
      1.6554902335190946`}}]}, 
    {Hue[0.6640641650607872], AbsoluteThickness[0.5], 
     LineBox[{{6.10158126102411, 1.6554902335190946`}, {5.8798616310272624`, 
      1.4511061084650112`}}]}, 
    {Hue[0.5229362536625315], AbsoluteThickness[0.5], 
     LineBox[{{6.151457852592751, 1.0858869168008731`}, {6.298381427932044, 
      1.0657737383879953`}}]}, 
    {Hue[0.5231211887559973], AbsoluteThickness[0.5], 
     LineBox[{{6.298381427932044, 1.0657737383879953`}, {6.637302678486836, 
      1.0169603213082352`}}]}, 
    {Hue[0.5109433239772967], AbsoluteThickness[0.5], 
     LineBox[{{5.343756785437981, 1.0083714905520778`}, {5.161225427054131, 
      1.0561727505257825`}}]}, 
    {Hue[0.5113009647059183], AbsoluteThickness[0.5], 
     LineBox[{{5.161225427054131, 1.0561727505257825`}, {4.879946877019573, 
      1.1112905707736813`}}]}, 
    {Hue[0.5339601862915083], AbsoluteThickness[0.5], 
     LineBox[{{7.143881683462895, 0.3832461284525548}, {7.32151291507871, 
      0.3484715981465151}}]}, 
    {Hue[0.5347906931964654], AbsoluteThickness[0.5], 
     LineBox[{{7.32151291507871, 0.3484715981465151}, {7.5841933507179515`, 
      0.3253409192139103}}]}, 
    {Hue[0.43625145673202104`], AbsoluteThickness[0.5], 
     LineBox[{{4.839439865992445, 1.0218694340316077`}, {4.750805233635593, 
      1.157338521753208}}]}, 
    {Hue[0.4365258676073417], AbsoluteThickness[0.5], 
     LineBox[{{4.750805233635593, 1.157338521753208}, {4.628638705595014, 
      1.3647266179686772`}}]}, 
    {Hue[0.6518848177947815], AbsoluteThickness[0.5], 
     LineBox[{{4.122856680468086, -0.3469255217782274}, {
      4.05452514831685, -0.36037909558971937`}}]}, 
    {Hue[0.652686958301315], AbsoluteThickness[0.5], 
     LineBox[{{4.05452514831685, -0.36037909558971937`}, {
      3.8418719011631226`, -0.4257345527276301}}]}, 
    {Hue[0.6638153440613184], AbsoluteThickness[0.5], 
     LineBox[{{4.899821121356265, -1.4982348238119843`}, {
      4.8447250389984315`, -1.5838618799218238`}}]}, 
    {Hue[0.6640000957840371], AbsoluteThickness[0.5], 
     LineBox[{{4.8447250389984315`, -1.5838618799218238`}, {
      4.6801569042007625`, -1.8359346973849022`}}]}, 
    {Hue[0.4841500016915905], AbsoluteThickness[0.5], 
     LineBox[{{5.5760497386044126`, -1.6632283365645302`}, {
      5.6059430288850525`, -1.7364162622695076`}}]}, 
    {Hue[0.48897560554999225`], AbsoluteThickness[0.5], 
     LineBox[{{5.6059430288850525`, -1.7364162622695076`}, {
      5.698922125620347, -1.8758034494156233`}}]}, 
    {Hue[0.6941703684292847], AbsoluteThickness[0.5], 
     LineBox[{{5.698922125620347, -1.8758034494156233`}, {
      5.864952223193942, -1.8532666557235384`}}]}, 
    {Hue[0.6750444148967928], AbsoluteThickness[0.5], 
     LineBox[{{5.916170905633331, -1.2320732494795885`}, {
      6.120371921029847, -1.2557540571998236`}}]}, 
    {Hue[0.6752484686821175], AbsoluteThickness[0.5], 
     LineBox[{{6.120371921029847, -1.2557540571998236`}, {
      6.446986340259031, -1.2858947444894115`}}]}, 
    {Hue[0.46917438295595804`], AbsoluteThickness[0.5], 
     LineBox[{{4.211636102543155, -0.9174096462932262}, {
      4.1540997221684615`, -0.9391112416421967}}]}, 
    {Hue[0.4693597677403792], AbsoluteThickness[0.5], 
     LineBox[{{4.1540997221684615`, -0.9391112416421967}, {
      3.854644651235509, -1.0547381333962738`}}]}, 
    {Hue[0.5445168200209827], AbsoluteThickness[0.5], 
     LineBox[{{3.956690241253088, 0.17168039885872202`}, {3.9225528304364947`,
       0.177311715770142}}]}, 
    {Hue[0.5447023032475823], AbsoluteThickness[0.5], 
     LineBox[{{3.9225528304364947`, 0.177311715770142}, {3.6037690263909803`, 
      0.23251298497403247`}}]}, 
    {Hue[0.6160254890460461], AbsoluteThickness[0.5], 
     LineBox[{{4.8894263217254865`, 1.1211417280571658`}, {4.911625254895543, 
      1.3538738076488344`}}]}, 
    {Hue[0.6163005009610897], AbsoluteThickness[0.5], 
     LineBox[{{4.911625254895543, 1.3538738076488344`}, {4.955364090593181, 
      1.6592345551760308`}}]}, 
    {Hue[0.6921244826095702], AbsoluteThickness[0.5], 
     LineBox[{{5.996981320663829, 1.1193631448066796`}, {6.067545715787124, 
      1.2013709460128568`}}]}, 
    {Hue[0.6923711407814184], AbsoluteThickness[0.5], 
     LineBox[{{6.067545715787124, 1.2013709460128568`}, {6.267562956917228, 
      1.4159252596804341`}}]}, 
    {Hue[0.45027138126252936`], AbsoluteThickness[0.5], 
     LineBox[{{3.060092723143652, -0.7433532091214999}, {
      2.9321073113160727`, -0.7766782465086752}}]}, 
    {Hue[0.4504871662735736], AbsoluteThickness[0.5], 
     LineBox[{{2.9321073113160727`, -0.7766782465086752}, {
      2.660008727854707, -0.8391463939340966}}]}, 
    {Hue[0.6536019297316893], AbsoluteThickness[0.5], 
     LineBox[{{2.5179669445967625`, 1.6546179606098674`}, {
      2.4031273095709067`, 1.8526055614273562`}}]}, 
    {Hue[0.656106724107899], AbsoluteThickness[0.5], 
     LineBox[{{2.4031273095709067`, 1.8526055614273562`}, {
      2.3465003261523547`, 2.0016919364102153`}}]}, 
    {Hue[0.6519121222654014], AbsoluteThickness[0.5], 
     LineBox[{{2.3584371703534224`, 0.8983914028520312}, {2.2418943733926846`,
       1.0564346421307682`}}]}, 
    {Hue[0.6523388347738539], AbsoluteThickness[0.5], 
     LineBox[{{2.2418943733926846`, 1.0564346421307682`}, {2.094867808752803, 
      1.28922010582574}}]}, 
    {Hue[0.4596169862909685], AbsoluteThickness[0.5], 
     LineBox[{{2.22879531666272, 0.9020263899058154}, {2.1107622699206594`, 
      0.8811695801798028}}]}, 
    {Hue[0.4608421283660734], AbsoluteThickness[0.5], 
     LineBox[{{2.1107622699206594`, 0.8811695801798028}, {1.8849683746156314`,
       0.8698811764446064}}]}, 
    {Hue[0.6619552034044351], AbsoluteThickness[0.5], 
     LineBox[{{2.167926937343688, 0.7875044978575387}, {2.1018694891400234`, 
      0.5625338826359672}}]}, 
    {Hue[0.6621565143675792], AbsoluteThickness[0.5], 
     LineBox[{{2.1018694891400234`, 0.5625338826359672}, {2.030548797235382, 
      0.33793803114345605`}}]}, 
    {Hue[0.6721302850226476], AbsoluteThickness[0.5], 
     LineBox[{{4.764975851525028, 2.414726189496874}, {5.040372770179408, 
      2.839708033129257}}]}, 
    {Hue[0.6730773838794724], AbsoluteThickness[0.5], 
     LineBox[{{5.040372770179408, 2.839708033129257}, {5.14196656423911, 
      3.043244514731989}}]}, 
    {Hue[0.45043773424180583`], AbsoluteThickness[0.5], 
     LineBox[{{2.312530256982746, 1.9047407108645917`}, {2.160245365407655, 
      2.042717078838258}}]}, 
    {Hue[0.4509725045953448], AbsoluteThickness[0.5], 
     LineBox[{{2.160245365407655, 2.042717078838258}, {1.981736479233178, 
      2.1791356728325355`}}]}, 
    {Hue[0.6001470500154757], AbsoluteThickness[0.5], 
     LineBox[{{2.9696703051931497`, 2.143299400268076}, {2.989624174191954, 
      2.316567486165755}}]}, 
    {Hue[0.6003329193369128], AbsoluteThickness[0.5], 
     LineBox[{{2.989624174191954, 2.316567486165755}, {3.0356327260310234`, 
      2.687957121083041}}]}, 
    {Hue[0.6666992506972766], AbsoluteThickness[0.5], 
     LineBox[{{2.203960725449316, -1.846230942491997}, {
      2.183252305621113, -1.8847619765155457`}}]}, 
    {Hue[0.6671502566074627], AbsoluteThickness[0.5], 
     LineBox[{{2.183252305621113, -1.8847619765155457`}, {
      2.0330784063531713`, -2.120040053223454}}]}, 
    {Hue[0.45518971255896346`], AbsoluteThickness[0.5], 
     LineBox[{{1.9941947604424164`, -2.117172517617665}, {
      1.9225117896096935`, -2.339296137369611}}]}, 
    {Hue[0.45598953384784496`], AbsoluteThickness[0.5], 
     LineBox[{{1.9225117896096935`, -2.339296137369611}, {
      1.871705955361084, -2.579383011099843}}]}, 
    {Hue[0.6961587260964055], AbsoluteThickness[0.5], 
     LineBox[{{2.3314998299859577`, -2.030808955936765}, {
      2.343528762848731, -2.080123389095915}}]}, 
    {Hue[0.696550592566659], AbsoluteThickness[0.5], 
     LineBox[{{2.343528762848731, -2.080123389095915}, {
      2.392586079497609, -2.3630622067704063`}}]}, 
    {Hue[0.5976808141329985], AbsoluteThickness[0.5], 
     LineBox[{{2.4515426952274284`, -2.1199870179428464`}, {
      2.556943566838984, -2.160322154999426}}]}, 
    {Hue[0.5978642334136873], AbsoluteThickness[0.5], 
     LineBox[{{2.556943566838984, -2.160322154999426}, {
      2.8588435170927085`, -2.274866792392901}}]}, 
    {Hue[0.6831195202917987], AbsoluteThickness[0.5], 
     LineBox[{{2.6087330171752736`, -1.8690807179268634`}, {
      2.626161706169526, -1.8713873058769472`}}]}, 
    {Hue[0.6857201056285085], AbsoluteThickness[0.5], 
     LineBox[{{2.626161706169526, -1.8713873058769472`}, {
      2.8201946499746575`, -1.8649612329970076`}}]}, 
    {Hue[0.4416031163367566], AbsoluteThickness[0.5], 
     LineBox[{{2.6583334482814975`, -1.8881915848497568`}, {
      2.628396231651677, -1.9075178484490787`}}]}, 
    {Hue[0.4418056360222993], AbsoluteThickness[0.5], 
     LineBox[{{2.628396231651677, -1.9075178484490787`}, {
      2.3601829633056144`, -2.072207955493204}}]}, 
    {Hue[0.6921071598314648], AbsoluteThickness[0.5], 
     LineBox[{{2.844387562893518, -0.4646491925784466}, {
      2.711766618665485, -0.4883288901651158}}]}, 
    {Hue[0.6922922434144831], AbsoluteThickness[0.5], 
     LineBox[{{2.711766618665485, -0.4883288901651158}, {
      2.37955614645619, -0.5501416006647808}}]}, 
    {Hue[0.455968373329635], AbsoluteThickness[0.5], 
     LineBox[{{2.5947838776974526`, 0.699565467163501}, {2.411995464801956, 
      0.7751817178667965}}]}, 
    {Hue[0.4561691638310632], AbsoluteThickness[0.5], 
     LineBox[{{2.411995464801956, 0.7751817178667965}, {2.187360460058735, 
      0.8624833169471092}}]}, 
    {Hue[0.6917997040619661], AbsoluteThickness[0.5], 
     LineBox[{{4.352532376797479, 2.369357454152633}, {4.345611921107683, 
      2.399961550671878}}]}, 
    {Hue[0.6793049783328521], AbsoluteThickness[0.5], 
     LineBox[{{6.52218963097219, 1.6623099573089042`}, {6.625069808407641, 
      1.7056084372372071`}}]}, 
    {Hue[0.6795459703524722], AbsoluteThickness[0.5], 
     LineBox[{{6.625069808407641, 1.7056084372372071`}, {6.865402790228393, 
      1.7961382788338658`}}]}, 
    {Hue[0.4045651850558362], AbsoluteThickness[0.5], 
     LineBox[{{4.096591811836374, 1.2499734969440517`}, {3.9862592797803313`, 
      1.3481438736691491`}}]}, 
    {Hue[0.4064126384403651], AbsoluteThickness[0.5], 
     LineBox[{{3.9862592797803313`, 1.3481438736691491`}, {
      3.8677830330422824`, 1.489527299309895}}]}, 
    {Hue[0.6813758955795126], AbsoluteThickness[0.5], 
     LineBox[{{3.8677830330422824`, 1.489527299309895}, {3.9779876884070617`, 
      1.6374489948889326`}}]}, 
    {Hue[0.6871968051691252], AbsoluteThickness[0.5], 
     LineBox[{{3.560933992060265, -0.15747189595957234`}, {
      3.4144325205014994`, -0.2356454770595336}}]}, 
    {Hue[0.6873926467757164], AbsoluteThickness[0.5], 
     LineBox[{{3.4144325205014994`, -0.2356454770595336}, {
      3.136273110507371, -0.3775728539432791}}]}, 
    {Hue[0.6060261002316522], AbsoluteThickness[0.5], 
     LineBox[{{4.908455139197296, -0.6337664010897093}, {
      4.902628181296575, -0.6345152162075803}}]}, 
    {Hue[0.6062725664379818], AbsoluteThickness[0.5], 
     LineBox[{{4.902628181296575, -0.6345152162075803}, {
      4.621919019136533, -0.6819973016660933}}]}, 
    {Hue[0.6573710702434051], AbsoluteThickness[0.5], 
     LineBox[{{5.147244857449752, -0.8967049223682861}, {
      5.137138975144561, -0.8944342626544151}}]}, 
    {Hue[0.6590420738063201], AbsoluteThickness[0.5], 
     LineBox[{{5.137138975144561, -0.8944342626544151}, {
      4.950544740297555, -0.8794548318219492}}]}, 
    {Hue[0.6516779885450906], AbsoluteThickness[0.5], 
     LineBox[{{6.477344047574457, -0.3900611068834905}, {
      6.37136217824953, -0.2190326212415336}}]}, 
    {Hue[0.6693853104653815], AbsoluteThickness[0.5], 
     LineBox[{{6.37136217824953, -0.2190326212415336}, {
      6.258025463924768, -0.11781453791912785`}}]}, 
    {Hue[0.5110983272846032], AbsoluteThickness[0.5], 
     LineBox[{{6.952683447459978, -0.8740524240884584}, {
      7.052469467204013, -0.8069688713511451}}]}, 
    {Hue[0.5113284344108889], AbsoluteThickness[0.5], 
     LineBox[{{7.052469467204013, -0.8069688713511451}, {
      7.353433065589417, -0.6194021000598979}}]}, 
    {Hue[0.2179766509631035], AbsoluteThickness[0.5], 
     LineBox[{{7.098021325764257, -0.9968067045346964}, {
      7.224219046840725, -1.1355461267955338`}}]}, 
    {Hue[0.2182608110149377], AbsoluteThickness[0.5], 
     LineBox[{{7.224219046840725, -1.1355461267955338`}, {
      7.404873413023072, -1.354943595196123}}]}, 
    {Hue[0.6313582232535427], AbsoluteThickness[0.5], 
     LineBox[{{7.404873413023072, -1.354943595196123}, {
      7.120685522106613, -1.3520295228243422`}}]}, 
    {Hue[0.5138763374529157], AbsoluteThickness[0.5], 
     LineBox[{{6.997752704567444, -1.1584789527443164`}, {
      6.91710714484928, -1.2568947932735157`}}]}, 
    {Hue[0.5142577624083197], AbsoluteThickness[0.5], 
     LineBox[{{6.91710714484928, -1.2568947932735157`}, {
      6.750245482442702, -1.435074784336653}}]}, 
    {Hue[0.6520891079332723], AbsoluteThickness[0.5], 
     LineBox[{{6.084428116973464, -0.7640639246493693}, {
      5.9151743398878, -0.7436509199874607}}]}, 
    {Hue[0.6522724884454496], AbsoluteThickness[0.5], 
     LineBox[{{5.9151743398878, -0.7436509199874607}, {
      5.614645344029233, -0.7065919626854019}}]}, 
    {Hue[0.6336804928816449], AbsoluteThickness[0.5], 
     LineBox[{{6.584222943013781, 0.1716058667428289}, {6.574033746401171, 
      0.4458597481085579}}]}, 
    {Hue[0.6344821065842434], AbsoluteThickness[0.5], 
     LineBox[{{6.574033746401171, 0.44585974810855794`}, {6.5469469278676025`,
       0.6368635855234813}}]}, 
    {Hue[0.6077945044964977], AbsoluteThickness[0.5], 
     LineBox[{{6.672516915681058, 0.8885179867466502}, {6.804524202477089, 
      1.1273984324969137`}}]}, 
    {Hue[0.6092424406848651], AbsoluteThickness[0.5], 
     LineBox[{{6.804524202477089, 1.1273984324969137`}, {6.881204474904297, 
      1.3242995202150794`}}]}, 
    {Hue[0.5034324057392894], AbsoluteThickness[0.5], 
     LineBox[{{5.062238178947538, 0.1912066990993062}, {4.854268663032112, 
      0.21823571056275384`}}]}, 
    {Hue[0.5036482521502704], AbsoluteThickness[0.5], 
     LineBox[{{4.854268663032112, 0.21823571056275384`}, {4.5969460739394234`,
       0.25932011660617466`}}]}, 
    {Hue[0.5742212455416851], AbsoluteThickness[0.5], 
     LineBox[{{5.1212892282563045`, -0.28584844369612605`}, {
      5.058741770078805, -0.37352533270738797`}}]}, 
    {Hue[0.5744272845880432], AbsoluteThickness[0.5], 
     LineBox[{{5.058741770078805, -0.37352533270738797`}, {
      4.892604669438865, -0.6189034417401148}}]}, 
    {Hue[0.6194073078232838], AbsoluteThickness[0.5], 
     LineBox[{{5.548883626199007, -0.6931337635867161}, {
      5.577185086091668, -0.8919322091923785}}]}, 
    {Hue[0.6198700830680356], AbsoluteThickness[0.5], 
     LineBox[{{5.577185086091668, -0.8919322091923785}, {
      5.594092515281308, -1.1510887972667576`}}]}, 
    {Hue[0.6649477266424675], AbsoluteThickness[0.5], 
     LineBox[{{5.903281161164852, -0.3033895933541004}, {
      5.971531298262972, -0.3511333900671929}}]}, 
    {Hue[0.6671171799318479], AbsoluteThickness[0.5], 
     LineBox[{{5.971531298262972, -0.3511333900671929}, {
      6.089186185011931, -0.46412778297490015`}}]}, 
    {Hue[0.6842147939427317], AbsoluteThickness[0.5], 
     LineBox[{{6.34098319847574, 0.5569745163120173}, {6.300445387111725, 
      0.5979718692414645}}]}, 
    {Hue[0.6847926762148346], AbsoluteThickness[0.5], 
     LineBox[{{6.300445387111725, 0.5979718692414645}, {6.16874912920781, 
      0.7568037859242456}}]}, 
    {Hue[0.6466576108297265], AbsoluteThickness[0.5], 
     LineBox[{{6.97435174451669, 0.14200277352684282`}, {6.96810564813093, 
      0.297035070841694}}]}, 
    {Hue[0.6468610508705334], AbsoluteThickness[0.5], 
     LineBox[{{6.96810564813093, 0.29703507084169406`}, {6.962721548274071, 
      0.6105183577215063}}]}, 
    {Hue[0.24045937276600132`], AbsoluteThickness[0.5], 
     LineBox[{{7.1533879505423, 0.03752729228343482}, {
      7.39375033838211, -0.12084842573426254`}}]}, 
    {Hue[0.24303947853622598`], AbsoluteThickness[0.5], 
     LineBox[{{7.39375033838211, -0.12084842573426254`}, {
      7.5496058187056825`, -0.19014294206542603`}}]}, 
    {Hue[0.4935810732162699], AbsoluteThickness[0.5], 
     LineBox[{{7.5496058187056825`, -0.19014294206542603`}, {
      7.664545060342192, -0.06412059693375714}}]}, 
    {Hue[0.6472762312651172], AbsoluteThickness[0.5], 
     LineBox[{{6.964087541651995, -0.04693834832296653}, {
      6.8111748949094295`, -0.1054241267005212}}]}, 
    {Hue[0.6475909112570513], AbsoluteThickness[0.5], 
     LineBox[{{6.8111748949094295`, -0.1054241267005212}, {
      6.543886199459315, -0.22501170017298794`}}]}, 
    {Hue[0.6844147744281865], AbsoluteThickness[0.5], 
     LineBox[{{6.103008723708266, 0.39029214819013164`}, {6.033355543856384, 
      0.40387788023287086`}}]}, 
    {Hue[0.6851605993660171], AbsoluteThickness[0.5], 
     LineBox[{{6.033355543856384, 0.40387788023287086`}, {5.819217854866354, 
      0.46843169438588755`}}]}, 
    {Hue[0.4307682093597711], AbsoluteThickness[0.5], 
     LineBox[{{6.788286169112373, 0.08275477138089243}, {
      6.8157708955746745`, -0.10919306060865114`}}]}, 
    {Hue[0.4315329325933868], AbsoluteThickness[0.5], 
     LineBox[{{6.8157708955746745`, -0.10919306060865114`}, {
      6.8256738210161805`, -0.3516744978920914}}]}, 
    {Hue[0.43170696411017495`], AbsoluteThickness[0.5], 
     LineBox[{{6.9767342513768655`, 0.8415684967397441}, {7.037289686503661, 
      0.6105007043935301}}]}, 
    {Hue[0.431994266808329], AbsoluteThickness[0.5], 
     LineBox[{{7.037289686503661, 0.6105007043935301}, {7.0967852982839235`, 
      0.326322821662418}}]}, 
    {Hue[0.02145359508140412], AbsoluteThickness[0.5], 
     LineBox[{{7.156710522321821, 1.057504153542214}, {7.192065638887377, 
      1.1046249733468794`}}]}, 
    {Hue[0.02179809267099122], AbsoluteThickness[0.5], 
     LineBox[{{7.192065638887377, 1.1046249733468794`}, {7.353649000460349, 
      1.3495682650002878`}}]}, 
    {Hue[0.4206374938303151], AbsoluteThickness[0.5], 
     LineBox[{{7.353649000460349, 1.3495682650002878`}, {7.060538310049242, 
      1.3634434958074577`}}]}, 
    {Hue[0.43229287923952125`], AbsoluteThickness[0.5], 
     LineBox[{{6.875687281178761, 1.0642572209501147`}, {6.635547121943515, 
      1.057748727360387}}]}, 
    {Hue[0.4324821767513969], AbsoluteThickness[0.5], 
     LineBox[{{6.635547121943515, 1.057748727360387}, {6.295198604732274, 
      1.0441447323620774`}}]}, 
    {Hue[0.43149997989258204`], AbsoluteThickness[0.5], 
     LineBox[{{5.881209576075601, 0.9157210836573269}, {5.673185502654298, 
      0.9513089607076581}}]}, 
    {Hue[0.43168336991064926`], AbsoluteThickness[0.5], 
     LineBox[{{5.673185502654298, 0.9513089607076581}, {5.34378759472657, 
      1.0085816823173743`}}]}, 
    {Hue[0.687203507564264], AbsoluteThickness[0.5], 
     LineBox[{{6.453084848827884, 0.3971828149358141}, {6.439182291361847, 
      0.18377233116537578`}}]}, 
    {Hue[0.6874711509753885], AbsoluteThickness[0.5], 
     LineBox[{{6.439182291361847, 0.18377233116537578`}, {
      6.433388240338392, -0.11117953659543571`}}]}, 
    {Hue[0.4662445240597662], AbsoluteThickness[0.5], 
     LineBox[{{6.364102736692175, 1.2549358388771608`}, {6.422826032225031, 
      1.365065552474647}}]}, 
    {Hue[0.46642773110889557`], AbsoluteThickness[0.5], 
     LineBox[{{6.422826032225031, 1.365065552474647}, {6.57323765724591, 
      1.646089620359747}}]}, 
    {Hue[0.2550025631721537], AbsoluteThickness[0.5], 
     LineBox[{{6.285753978708785, 1.4070605913421486`}, {6.174197682692963, 
      1.5494748272910812`}}]}, 
    {Hue[0.25724293460841274`], AbsoluteThickness[0.5], 
     LineBox[{{6.174197682692963, 1.5494748272910812`}, {6.036656461720002, 
      1.6775537955970146`}}]}, 
    {Hue[0.518092510260707], AbsoluteThickness[0.5], 
     LineBox[{{6.036656461720002, 1.6775537955970146`}, {5.875024991266699, 
      1.5816524017169022`}}]}, 
    {Hue[0.4741916399442235], AbsoluteThickness[0.5], 
     LineBox[{{6.114937969488056, 1.3969433197743022`}, {5.995683381404745, 
      1.3667402332319012`}}]}, 
    {Hue[0.6933807167162939], AbsoluteThickness[0.5], 
     LineBox[{{6.055094413422918, 1.2366335665228163`}, {6.036231460668536, 
      1.1256743437386747`}}]}, 
    {Hue[0.693578971325023], AbsoluteThickness[0.5], 
     LineBox[{{6.036231460668536, 1.1256743437386747`}, {5.987631729229609, 
      0.8005725958373693}}]}, 
    {Hue[0.687618813291473], AbsoluteThickness[0.5], 
     LineBox[{{6.853458526119032, 0.5885561136172155}, {6.87794882615238, 
      0.5586810616236928}}]}, 
    {Hue[0.6878126508526254], AbsoluteThickness[0.5], 
     LineBox[{{6.87794882615238, 0.5586810616236928}, {7.082999887296782, 
      0.31698239836342923`}}]}, 
    {Hue[0.47404061102804185`], AbsoluteThickness[0.5], 
     LineBox[{{5.615981264787904, 0.7888893143257181}, {5.369808577478939, 
      0.8373156111747763}}]}, 
    {Hue[0.4745916321993091], AbsoluteThickness[0.5], 
     LineBox[{{5.369808577478939, 0.8373156111747763}, {5.132603163998297, 
      0.8633038107538517}}]}, 
    {Hue[0.46100009378378753`], AbsoluteThickness[0.5], 
     LineBox[{{4.655926041426688, -0.8105216709669426}, {
      4.593039866070804, -0.836333126310018}}]}, 
    {Hue[0.4613955245545706], AbsoluteThickness[0.5], 
     LineBox[{{4.593039866070804, -0.836333126310018}, {
      4.359421295530483, -0.9513629506393492}}]}, 
    {Hue[0.5511232948729266], AbsoluteThickness[0.5], 
     LineBox[{{4.813642807021752, 0.8598979484814954}, {4.672920885593271, 
      0.9332801431723884}}]}, 
    {Hue[0.5513067140678853], AbsoluteThickness[0.5], 
     LineBox[{{4.672920885593271, 0.9332801431723884}, {4.356816966072465, 
      1.0969723235612296`}}]}, 
    {Hue[0.5153048788392396], AbsoluteThickness[0.5], 
     LineBox[{{6.382123401893994, 0.6275245760517915}, {6.382254773277838, 
      0.6275395844991265}}]}, 
    {Hue[0.5164977887184177], AbsoluteThickness[0.5], 
     LineBox[{{6.382254773277838, 0.6275395844991265}, {6.560609031189221, 
      0.6257838054686258}}]}, 
    {Hue[0.5561534425427141], AbsoluteThickness[0.5], 
     LineBox[{{5.841682554284794, 0.9015937670123577}, {5.674320094655733, 
      1.010871541214962}}]}, 
    {Hue[0.5566824806615975], AbsoluteThickness[0.5], 
     LineBox[{{5.674320094655733, 1.010871541214962}, {5.441039746564652, 
      1.1369156045927298`}}]}, 
    {Hue[0.6614080992963218], AbsoluteThickness[0.5], 
     LineBox[{{5.712539000534084, 0.9118442775173976}, {5.64849501488751, 
      0.8916496320041639}}]}, 
    {Hue[0.6623178762881873], AbsoluteThickness[0.5], 
     LineBox[{{5.64849501488751, 0.8916496320041639}, {5.415740315443308, 
      0.8455727215350262}}]}, 
    {Hue[0.6975606939377462], AbsoluteThickness[0.5], 
     LineBox[{{5.622717590410879, 0.8184888024532366}, {5.563056991588514, 
      0.6697420551766223}}]}, 
    {Hue[0.6977441454607114], AbsoluteThickness[0.5], 
     LineBox[{{5.563056991588514, 0.6697420551766223}, {5.43041916475558, 
      0.3419012486380427}}]}, 
    {Hue[0.6638462460303419], AbsoluteThickness[0.5], 
     LineBox[{{6.02114616024396, 1.3648656312182066`}, {6.051328059475833, 
      1.2725527638858225`}}]}, 
    {Hue[0.6698101880246311], AbsoluteThickness[0.5], 
     LineBox[{{6.051328059475833, 1.2725527638858225`}, {6.132844253351959, 
      1.133288049183445}}]}, 
    {Hue[0.23152268619959596`], AbsoluteThickness[0.5], 
     LineBox[{{6.10158126102411, 1.6554902335190946`}, {6.111402240816899, 
      1.6956126639955889`}}]}, 
    {Hue[0.23489531971594912`], AbsoluteThickness[0.5], 
     LineBox[{{6.111402240816899, 1.6956126639955889`}, {6.184072372672007, 
      1.8586024464312514`}}]}, 
    {Hue[0.4659536811412635], AbsoluteThickness[0.5], 
     LineBox[{{6.184072372672007, 1.8586024464312514`}, {6.36240697690967, 
      1.8520156282570719`}}]}, 
    {Hue[0.6970120425665783], AbsoluteThickness[0.5], 
     LineBox[{{6.36240697690967, 1.8520156282570719`}, {6.4228553982991645`, 
      1.6841090899871713`}}]}, 
    {Hue[0.6642820840912291], AbsoluteThickness[0.5], 
     LineBox[{{5.8798616310272624`, 1.4511061084650112`}, {5.833820172339405, 
      1.4060403563564783`}}]}, 
    {Hue[0.6645159118133441], AbsoluteThickness[0.5], 
     LineBox[{{5.833820172339405, 1.4060403563564783`}, {5.599442986112421, 
      1.1595858165884754`}}]}, 
    {Hue[0.5233061238494632], AbsoluteThickness[0.5], 
     LineBox[{{6.637302678486836, 1.0169603213082352`}, {6.858767059798419, 
      0.9834814317062208}}]}, 
    {Hue[0.5235047361640097], AbsoluteThickness[0.5], 
     LineBox[{{6.858767059798419, 0.9834814317062208}, {7.162702661414744, 
      0.9438053337150264}}]}, 
    {Hue[0.51165860543454], AbsoluteThickness[0.5], 
     LineBox[{{4.879946877019573, 1.1112905707736813`}, {4.630680122811341, 
      1.1441015350696153`}}]}, 
    {Hue[0.5129665744590227], AbsoluteThickness[0.5], 
     LineBox[{{4.630680122811341, 1.1441015350696153`}, {4.395280740220098, 
      1.1447153361225655`}}]}, 
    {Hue[0.5356212001014224], AbsoluteThickness[0.5], 
     LineBox[{{7.5841933507179515`, 0.3253409192139103}, {7.626714297149007, 
      0.32609206755954295`}}]}, 
    {Hue[0.5361897967969521], AbsoluteThickness[0.5], 
     LineBox[{{7.626714297149007, 0.32609206755954295`}, {7.891581672955386, 
      0.3077814576649613}}]}, 
    {Hue[0.4368002784826621], AbsoluteThickness[0.5], 
     LineBox[{{4.628638705595014, 1.3647266179686772`}, {4.628289473465782, 
      1.3653888162929944`}}]}, 
    {Hue[0.43702154437393864`], AbsoluteThickness[0.5], 
     LineBox[{{4.628289473465782, 1.3653888162929944`}, {4.503571201537513, 
      1.5849363906658709`}}]}, 
    {Hue[0.6534890988078484], AbsoluteThickness[0.5], 
     LineBox[{{3.8418719011631226`, -0.4257345527276301}, {
      3.6865263052883464`, -0.4917694976009767}}]}, 
    {Hue[0.6536812806603628], AbsoluteThickness[0.5], 
     LineBox[{{3.6865263052883464`, -0.4917694976009767}, {
      3.3847302367062975`, -0.6145580846091381}}]}, 
    {Hue[0.6641848475067557], AbsoluteThickness[0.5], 
     LineBox[{{4.6801569042007625`, -1.8359346973849022`}, {
      4.628435784582611, -1.9140209948334994`}}]}, 
    {Hue[0.6644037808374835], AbsoluteThickness[0.5], 
     LineBox[{{4.628435784582611, -1.9140209948334994`}, {
      4.444584970458577, -2.17407961338191}}]}, 
    {Hue[0.6893447645708811], AbsoluteThickness[0.5], 
     LineBox[{{5.6059430288850525`, -1.7364162622695076`}, {
      5.580392820833384, -1.8113373396360717`}}]}, 
    {Hue[0.6895389187137553], AbsoluteThickness[0.5], 
     LineBox[{{5.580392820833384, -1.8113373396360717`}, {
      5.466710937071036, -2.126897206581193}}]}, 
    {Hue[0.49380120940839406`], AbsoluteThickness[0.5], 
     LineBox[{{5.698922125620347, -1.8758034494156233`}, {
      6.1387084261467875`, -2.3126263188259486`}}]}, 
    {Hue[0.5053831467041116], AbsoluteThickness[0.5], 
     LineBox[{{6.1387084261467875`, -2.3126263188259486`}, {
      6.275115027170251, -2.3916007283932794`}}]}, 
    {Hue[0.6489264403389688], AbsoluteThickness[0.5], 
     LineBox[{{6.275115027170251, -2.39160072839328}, {
      6.415962670666085, -2.3208500429481655`}}]}, 
    {Hue[0.6989959722876865], AbsoluteThickness[0.5], 
     LineBox[{{5.864952223193942, -1.8532666557235384`}, {
      6.087955228348104, -1.7755293071353104`}}]}, 
    {Hue[0.6992880147854827], AbsoluteThickness[0.5], 
     LineBox[{{6.087955228348104, -1.7755293071353104`}, {
      6.29649179032783, -1.714548594238228}}]}, 
    {Hue[0.6754525224674424], AbsoluteThickness[0.5], 
     LineBox[{{6.446986340259031, -1.2858947444894115`}, {
      6.634975538592947, -1.2988093106254066`}}]}, 
    {Hue[0.6756389939861543], AbsoluteThickness[0.5], 
     LineBox[{{6.634975538592947, -1.2988093106254066`}, {
      6.920460688392599, -1.3157020578048386`}}]}, 
    {Hue[0.4695451525248005], AbsoluteThickness[0.5], 
     LineBox[{{3.854644651235509, -1.0547381333962738`}, {
      3.3777554314599088`, -1.2431677270440258`}}]}, 
    {Hue[0.4697866965170728], AbsoluteThickness[0.5], 
     LineBox[{{3.3777554314599088`, -1.2431677270440258`}, {
      3.08320727731976, -1.3467014046111412`}}]}, 
    {Hue[0.5448877864741819], AbsoluteThickness[0.5], 
     LineBox[{{3.6037690263909803`, 0.23251298497403247`}, {
      3.4006273323013927`, 0.2693601613068275}}]}, 
    {Hue[0.5450867008149403], AbsoluteThickness[0.5], 
     LineBox[{{3.4006273323013927`, 0.2693601613068275}, {3.0823029265595387`,
       0.3204098587077727}}]}, 
    {Hue[0.6165755128761331], AbsoluteThickness[0.5], 
     LineBox[{{4.955364090593181, 1.6592345551760308`}, {4.990563917608184, 
      1.8428149348015401`}}]}, 
    {Hue[0.6167675336741454], AbsoluteThickness[0.5], 
     LineBox[{{4.990563917608184, 1.8428149348015401`}, {5.042768365054769, 
      2.0940943312606244`}}]}, 
    {Hue[0.6926177989532666], AbsoluteThickness[0.5], 
     LineBox[{{6.267562956917228, 1.4159252596804341`}, {6.3414793017053155`, 
      1.4891410751493424`}}]}, 
    {Hue[0.6930690552772687], AbsoluteThickness[0.5], 
     LineBox[{{6.3414793017053155`, 1.4891410751493424`}, {6.540441563317021, 
      1.658662282854143}}]}, 
    {Hue[0.45070295128461785`], AbsoluteThickness[0.5], 
     LineBox[{{2.660008727854707, -0.8391463939340966}, {
      2.54432612307239, -0.8621886350649688}}]}, 
    {Hue[0.45260156743695085`], AbsoluteThickness[0.5], 
     LineBox[{{2.54432612307239, -0.8621886350649688}, {
      2.3362231553334047`, -0.9367987626976133}}]}, 
    {Hue[0.6586115184841087], AbsoluteThickness[0.5], 
     LineBox[{{2.3465003261523547`, 2.0016919364102153`}, {2.322593379298374, 
      2.1193979559844265`}}]}, 
    {Hue[0.6588987088821932], AbsoluteThickness[0.5], 
     LineBox[{{2.322593379298374, 2.1193979559844265`}, {2.258971730969517, 
      2.3682680267369927`}}]}, 
    {Hue[0.6527655472823064], AbsoluteThickness[0.5], 
     LineBox[{{2.0948678087528037`, 1.28922010582574}, {2.057027867898407, 
      1.3599474591186946`}}]}, 
    {Hue[0.6529610301954017], AbsoluteThickness[0.5], 
     LineBox[{{2.057027867898407, 1.3599474591186946`}, {1.8907195989671668`, 
      1.684804414747426}}]}, 
    {Hue[0.6623578253307232], AbsoluteThickness[0.5], 
     LineBox[{{2.030548797235382, 0.3379380311434561}, {1.9734752681722851`, 
      0.17096375846217324`}}]}, 
    {Hue[0.6625634883862379], AbsoluteThickness[0.5], 
     LineBox[{{1.9734752681722851`, 0.1709637584621732}, {
      1.8604948557158172`, -0.18781759303254186`}}]}, 
    {Hue[0.6740244827362972], AbsoluteThickness[0.5], 
     LineBox[{{5.14196656423911, 3.043244514731989}, {5.170744503251183, 
      3.121852289530835}}]}, 
    {Hue[0.6742106457143904], AbsoluteThickness[0.5], 
     LineBox[{{5.170744503251183, 3.121852289530835}, {5.261063463459581, 
      3.37564683895124}}]}, 
    {Hue[0.6005187886583497], AbsoluteThickness[0.5], 
     LineBox[{{3.0356327260310234`, 2.687957121083041}, {3.0616699245015138`, 
      2.8842848435931794`}}]}, 
    {Hue[0.6007231345342906], AbsoluteThickness[0.5], 
     LineBox[{{3.0616699245015138`, 2.8842848435931794`}, {
      3.0949401737714983`, 3.1903948146437107`}}]}, 
    {Hue[0.6969424590369124], AbsoluteThickness[0.5], 
     LineBox[{{2.392586079497609, -2.3630622067704063`}, {
      2.394983681095318, -2.386009537355096}}]}, 
    {Hue[0.6977093205230835], AbsoluteThickness[0.5], 
     LineBox[{{2.394983681095318, -2.386009537355096}, {
      2.4434141231202973`, -2.618182018279854}}]}, 
    {Hue[0.5980476526943763], AbsoluteThickness[0.5], 
     LineBox[{{2.8588435170927085`, -2.274866792392901}, {
      2.9627488659543375`, -2.3139506941956443`}}]}, 
    {Hue[0.6011568098591419], AbsoluteThickness[0.5], 
     LineBox[{{2.9627488659543375`, -2.3139506941956443`}, {
      3.131828495403569, -2.4140370798315542`}}]}, 
    {Hue[0.6883206909652182], AbsoluteThickness[0.5], 
     LineBox[{{2.8201946499746575`, -1.8649612329970076`}, {
      3.108523759879753, -1.8071764067739187`}}]}, 
    {Hue[0.6885339555602754], AbsoluteThickness[0.5], 
     LineBox[{{3.108523759879753, -1.8071764067739187`}, {
      3.4145530314090804`, -1.7368927213868033`}}]}, 
    {Hue[0.44200815570784197`], AbsoluteThickness[0.5], 
     LineBox[{{2.3601829633056144`, -2.072207955493204}, {
      2.3453218671299387`, -2.0808772665983004`}}]}, 
    {Hue[0.44240756658728897`], AbsoluteThickness[0.5], 
     LineBox[{{2.3453218671299387`, -2.0808772665983004`}, {
      2.108755056526315, -2.2415706126908783`}}]}, 
    {Hue[0.6924773269975015], AbsoluteThickness[0.5], 
     LineBox[{{2.37955614645619, -0.5501416006647808}, {
      2.3117054913161614`, -0.563277382484079}}]}, 
    {Hue[0.693087311966868], AbsoluteThickness[0.5], 
     LineBox[{{2.3117054913161614`, -0.563277382484079}, {
      2.0670908527082337`, -0.6339946714700225}}]}, 
    {Hue[0.45636995433249145`], AbsoluteThickness[0.5], 
     LineBox[{{2.187360460058735, 0.8624833169471092}, {2.117252386810888, 
      0.8880033394673086}}]}, 
    {Hue[0.4566098990596159], AbsoluteThickness[0.5], 
     LineBox[{{2.117252386810888, 0.8880033394673086}, {1.82287096155126, 
      1.0079416589077277`}}]}, 
    {Hue[0.6797869623720922], AbsoluteThickness[0.5], 
     LineBox[{{6.865402790228393, 1.7961382788338658`}, {7.3413858183556036`, 
      1.955001466937924}}]}, 
    {Hue[0.6799833727627268], AbsoluteThickness[0.5], 
     LineBox[{{7.3413858183556036`, 1.955001466937924}, {7.6650107297416685`, 
      2.069805418458244}}]}, 
    {Hue[0.6795284421949843], AbsoluteThickness[0.5], 
     LineBox[{{3.9862592797803313`, 1.3481438736691491`}, {
      3.9406505601097632`, 1.3331172926123287`}}]}, 
    {Hue[0.6797120933097671], AbsoluteThickness[0.5], 
     LineBox[{{3.9406505601097632`, 1.3331172926123287`}, {
      3.6579620877190564`, 1.2411682766713321`}}]}, 
    {Hue[0.408260091824894], AbsoluteThickness[0.5], 
     LineBox[{{3.8677830330422824`, 1.489527299309895}, {3.7888325516111925`, 
      1.6179286271643638`}}]}, 
    {Hue[0.4085221415744308], AbsoluteThickness[0.5], 
     LineBox[{{3.7888325516111925`, 1.6179286271643638`}, {3.64293783700036, 
      1.8804307999132586`}}]}, 
    {Hue[0.6832233489640415], AbsoluteThickness[0.5], 
     LineBox[{{3.9779876884070617`, 1.6374489948889326`}, {4.122485381220374, 
      1.7816297349162387`}}]}, 
    {Hue[0.684495421747059], AbsoluteThickness[0.5], 
     LineBox[{{4.122485381220374, 1.7816297349162387`}, {4.297582025844731, 
      1.9168082156473396`}}]}, 
    {Hue[0.6875884883823077], AbsoluteThickness[0.5], 
     LineBox[{{3.136273110507371, -0.3775728539432791}, {
      3.134336033072358, -0.3785168038398527}}]}, 
    {Hue[0.6877750042315279], AbsoluteThickness[0.5], 
     LineBox[{{3.134336033072358, -0.3785168038398527}, {
      2.8550571286116426`, -0.5179270523033074}}]}, 
    {Hue[0.6065190326443114], AbsoluteThickness[0.5], 
     LineBox[{{4.621919019136533, -0.6819973016660933}, {
      4.417776698132674, -0.7249371646637658}}]}, 
    {Hue[0.6067074159461544], AbsoluteThickness[0.5], 
     LineBox[{{4.417776698132674, -0.7249371646637658}, {
      4.118371926014607, -0.7916360463911913}}]}, 
    {Hue[0.6607130773692351], AbsoluteThickness[0.5], 
     LineBox[{{4.950544740297555, -0.8794548318219492}, {
      4.650177889460393, -0.8977408237269249}}]}, 
    {Hue[0.6609643900024543], AbsoluteThickness[0.5], 
     LineBox[{{4.650177889460393, -0.8977408237269249}, {
      4.364103526572395, -0.9270059505467887}}]}, 
    {Hue[0.6870926323856726], AbsoluteThickness[0.5], 
     LineBox[{{6.258025463924768, -0.11781453791912785`}, {
      6.169782539508914, -0.07606490709734837}}]}, 
    {Hue[0.6872826713059206], AbsoluteThickness[0.5], 
     LineBox[{{6.169782539508914, -0.07606490709734837}, {5.8600330983876, 
      0.07567180311158178}}]}, 
    {Hue[0.5115585415371746], AbsoluteThickness[0.5], 
     LineBox[{{7.353433065589417, -0.6194021000598979}, {
      7.385488297624597, -0.6009307024520898}}]}, 
    {Hue[0.5118057013380158], AbsoluteThickness[0.5], 
     LineBox[{{7.385488297624597, -0.6009307024520898}, {
      7.626023718036561, -0.44921376867471036`}}]}, 
    {Hue[0.6310740632017073], AbsoluteThickness[0.5], 
     LineBox[{{7.224219046840725, -1.1355461267955338`}, {
      7.269024531048093, -0.9459605645839262}}]}, 
    {Hue[0.6313288063151474], AbsoluteThickness[0.5], 
     LineBox[{{7.269024531048093, -0.9459605645839262}, {
      7.334496159081358, -0.6055118865612469}}]}, 
    {Hue[0.21854497106677184`], AbsoluteThickness[0.5], 
     LineBox[{{7.404873413023072, -1.354943595196123}, {
      7.416265530500333, -1.3702567653724946`}}]}, 
    {Hue[0.21874392521282773`], AbsoluteThickness[0.5], 
     LineBox[{{7.416265530500333, -1.3702567653724946`}, {
      7.5948414737607, -1.6208355140056565`}}]}, 
    {Hue[0.6582501633348631], AbsoluteThickness[0.5], 
     LineBox[{{7.5948414737607, -1.6208355140056565`}, {
      7.33511329940802, -1.4558495987725213`}}]}, 
    {Hue[0.6316423833053768], AbsoluteThickness[0.5], 
     LineBox[{{7.120685522106613, -1.3520295228243422`}, {
      6.9146782862872165`, -1.3397586999505606`}}]}, 
    {Hue[0.631850121738159], AbsoluteThickness[0.5], 
     LineBox[{{6.9146782862872165`, -1.3397586999505606`}, {
      6.636570319863082, -1.3161057789349486`}}]}, 
    {Hue[0.5146391873637236], AbsoluteThickness[0.5], 
     LineBox[{{6.750245482442702, -1.435074784336653}, {
      6.676997172033755, -1.5035954304728814`}}]}, 
    {Hue[0.5150024749175884], AbsoluteThickness[0.5], 
     LineBox[{{6.676997172033755, -1.5035954304728814`}, {
      6.489914395050555, -1.6575550106708106`}}]}, 
    {Hue[0.6524558689576269], AbsoluteThickness[0.5], 
     LineBox[{{5.614645344029233, -0.7065919626854019}, {
      5.536595683944297, -0.696756088761932}}]}, 
    {Hue[0.6568512928969095], AbsoluteThickness[0.5], 
     LineBox[{{5.536595683944297, -0.696756088761932}, {
      5.3712579755478105`, -0.6419208330212081}}]}, 
    {Hue[0.6352837202868421], AbsoluteThickness[0.5], 
     LineBox[{{6.5469469278676025`, 0.6368635855234813}, {6.49118398859179, 
      0.8602635747106462}}]}, 
    {Hue[0.6354700933261109], AbsoluteThickness[0.5], 
     LineBox[{{6.49118398859179, 0.8602635747106462}, {6.41150589720002, 
      1.1926671838836118`}}]}, 
    {Hue[0.6106903768732327], AbsoluteThickness[0.5], 
     LineBox[{{6.881204474904297, 1.3242995202150794`}, {6.8980403815701745`, 
      1.3937316749718944`}}]}, 
    {Hue[0.610888976124855], AbsoluteThickness[0.5], 
     LineBox[{{6.8980403815701745`, 1.3937316749718944`}, {6.966496046375656, 
      1.6530371043377268`}}]}, 
    {Hue[0.5038640985612517], AbsoluteThickness[0.5], 
     LineBox[{{4.5969460739394234`, 0.25932011660617466`}, {4.46026753674279, 
      0.28523889220537657`}}]}, 
    {Hue[0.5040843410085806], AbsoluteThickness[0.5], 
     LineBox[{{4.46026753674279, 0.28523889220537657`}, {4.151550991487545, 
      0.3339560449741226}}]}, 
    {Hue[0.5746333236344012], AbsoluteThickness[0.5], 
     LineBox[{{4.892604669438865, -0.6189034417401148}, {
      4.892404349855441, -0.6192154998693977}}]}, 
    {Hue[0.5748629165631314], AbsoluteThickness[0.5], 
     LineBox[{{4.892404349855441, -0.6192154998693977}, {
      4.727886367284384, -0.8570999932866199}}]}, 
    {Hue[0.6203328583127875], AbsoluteThickness[0.5], 
     LineBox[{{5.594092515281308, -1.1510887972667576`}, {
      5.591763735583777, -1.3605670779720842`}}]}, 
    {Hue[0.6205561743681716], AbsoluteThickness[0.5], 
     LineBox[{{5.591763735583777, -1.3605670779720842`}, {
      5.578707936680302, -1.6625646141888275`}}]}, 
    {Hue[0.6692866332212282], AbsoluteThickness[0.5], 
     LineBox[{{6.089186185011931, -0.46412778297490015`}, {
      6.205953928125927, -0.6174656362047188}}]}, 
    {Hue[0.6695516181363869], AbsoluteThickness[0.5], 
     LineBox[{{6.205953928125927, -0.6174656362047188}, {
      6.366015524438264, -0.8484054132965815}}]}, 
    {Hue[0.6853705584869377], AbsoluteThickness[0.5], 
     LineBox[{{6.16874912920781, 0.7568037859242456}, {6.128686699457673, 
      0.8147673432488303}}]}, 
    {Hue[0.6855551741070877], AbsoluteThickness[0.5], 
     LineBox[{{6.128686699457673, 0.8147673432488302}, {5.940507675890693, 
      1.090761132862692}}]}, 
    {Hue[0.6470644909113402], AbsoluteThickness[0.5], 
     LineBox[{{6.962721548274071, 0.6105183577215063}, {6.964111540215825, 
      0.845293925448589}}]}, 
    {Hue[0.6472863464027983], AbsoluteThickness[0.5], 
     LineBox[{{6.964111540215825, 0.845293925448589}, {6.975305451484222, 
      1.144078691628268}}]}, 
    {Hue[0.4910009674460448], AbsoluteThickness[0.5], 
     LineBox[{{7.39375033838211, -0.12084842573426252`}, {
      7.408684917542238, -0.34354261569780986`}}]}, 
    {Hue[0.49124665635674075`], AbsoluteThickness[0.5], 
     LineBox[{{7.408684917542238, -0.34354261569780986`}, {
      7.438952443142733, -0.6266931228462788}}]}, 
    {Hue[0.24561958430645062`], AbsoluteThickness[0.5], 
     LineBox[{{7.5496058187056825`, -0.19014294206542603`}, {
      7.600626168023581, -0.20339427849454242`}}]}, 
    {Hue[0.24580311625959758`], AbsoluteThickness[0.5], 
     LineBox[{{7.600626168023581, -0.20339427849454242`}, {
      7.882934929861941, -0.2757101473357457}}]}, 
    {Hue[0.6912889320915607], AbsoluteThickness[0.5], 
     LineBox[{{7.882934929861941, -0.2757101473357457}, {
      7.605830110964485, -0.1854840910062472}}]}, 
    {Hue[0.4961611789864946], AbsoluteThickness[0.5], 
     LineBox[{{7.664545060342192, -0.06412059693375713}, {7.733352346359235, 
      0.0420126293025313}}]}, 
    {Hue[0.4964357609481843], AbsoluteThickness[0.5], 
     LineBox[{{7.733352346359235, 0.0420126293025313}, {7.8898389876045965`, 
      0.310250823629456}}]}, 
    {Hue[0.6479055912489853], AbsoluteThickness[0.5], 
     LineBox[{{6.543886199459315, -0.22501170017298794`}, {
      6.379552487833043, -0.3097494748182285}}]}, 
    {Hue[0.6483315414332649], AbsoluteThickness[0.5], 
     LineBox[{{6.379552487833043, -0.3097494748182285}, {
      6.125657458194816, -0.41832732762270464`}}]}, 
    {Hue[0.6859064243038477], AbsoluteThickness[0.5], 
     LineBox[{{5.819217854866354, 0.46843169438588755`}, {5.667336484476603, 
      0.5313895380341801}}]}, 
    {Hue[0.6862149595371609], AbsoluteThickness[0.5], 
     LineBox[{{5.667336484476603, 0.5313895380341801}, {5.370259476906691, 
      0.6360526074102332}}]}, 
    {Hue[0.43229765582700275`], AbsoluteThickness[0.5], 
     LineBox[{{6.8256738210161805`, -0.3516744978920914}, {
      6.825576837079949, -0.35327326938085934`}}]}, 
    {Hue[0.43369642727169105`], AbsoluteThickness[0.5], 
     LineBox[{{6.825576837079949, -0.35327326938085934`}, {
      6.840886796903556, -0.5681950703666385}}]}, 
    {Hue[0.43228156950648305`], AbsoluteThickness[0.5], 
     LineBox[{{7.0967852982839235`, 0.326322821662418}, {7.1057991123948865`, 
      0.2691809260645134}}]}, 
    {Hue[0.43304163868364953`], AbsoluteThickness[0.5], 
     LineBox[{{7.1057991123948865`, 0.2691809260645134}, {7.149448457539012, 
      0.10347078033821686`}}]}, 
    {Hue[0.4202929962407255], AbsoluteThickness[0.5], 
     LineBox[{{7.192065638887377, 1.1046249733468794`}, {7.277988308189711, 
      0.951860803297774}}]}, 
    {Hue[0.4206967151141117], AbsoluteThickness[0.5], 
     LineBox[{{7.277988308189711, 0.951860803297774}, {7.390408105692144, 
      0.7150344162751484}}]}, 
    {Hue[0.022142590260578243`], AbsoluteThickness[0.5], 
     LineBox[{{7.353649000460349, 1.3495682650002878`}, {7.3775247299827535`, 
      1.391018043860573}}]}, 
    {Hue[0.022347619321018752`], AbsoluteThickness[0.5], 
     LineBox[{{7.3775247299827535`, 1.391018043860573}, {7.543884862887944, 
      1.6644691373106297`}}]}, 
    {Hue[0.45962499955061215`], AbsoluteThickness[0.5], 
     LineBox[{{7.543884862887944, 1.6644691373106297`}, {7.512885661753796, 
      1.345893802643445}}]}, 
    {Hue[0.4209819914199023], AbsoluteThickness[0.5], 
     LineBox[{{7.060538310049242, 1.3634434958074577`}, {6.863122473350959, 
      1.3608280192880524`}}]}, 
    {Hue[0.4213216722712571], AbsoluteThickness[0.5], 
     LineBox[{{6.863122473350959, 1.3608280192880524`}, {6.57982954868064, 
      1.3401081333321252`}}]}, 
    {Hue[0.4326714742632726], AbsoluteThickness[0.5], 
     LineBox[{{6.295198604732274, 1.0441447323620774`}, {6.189895363322487, 
      1.0385792570356913`}}]}, 
    {Hue[0.43293666590826463`], AbsoluteThickness[0.5], 
     LineBox[{{6.189895363322487, 1.0385792570356913`}, {5.883323261180942, 
      1.0085602719018325`}}]}, 
    {Hue[0.4318667599287165], AbsoluteThickness[0.5], 
     LineBox[{{5.34378759472657, 1.0085816823173743`}, {5.166006433166219, 
      1.0399900566600764`}}]}, 
    {Hue[0.43211726235946574`], AbsoluteThickness[0.5], 
     LineBox[{{5.166006433166219, 1.0399900566600764`}, {4.858833762293857, 
      1.081384031628743}}]}, 
    {Hue[0.6877387943865129], AbsoluteThickness[0.5], 
     LineBox[{{6.433388240338392, -0.11117953659543567`}, {
      6.441161199556236, -0.41274450725640877`}}]}, 
    {Hue[0.6881628286718862], AbsoluteThickness[0.5], 
     LineBox[{{6.441161199556236, -0.41274450725640877`}, {
      6.468322005052908, -0.690413361520776}}]}, 
    {Hue[0.466610938158025], AbsoluteThickness[0.5], 
     LineBox[{{6.57323765724591, 1.646089620359747}, {6.8197075233683275`, 
      2.104862101175398}}]}, 
    {Hue[0.46708189321787313`], AbsoluteThickness[0.5], 
     LineBox[{{6.8197075233683275`, 2.104862101175398}, {6.902671251455068, 
      2.2927415826140214`}}]}, 
    {Hue[0.5158521388244445], AbsoluteThickness[0.5], 
     LineBox[{{6.174197682692963, 1.5494748272910812`}, {6.186069607961884, 
      1.5868232171547578`}}]}, 
    {Hue[0.5160546378136784], AbsoluteThickness[0.5], 
     LineBox[{{6.186069607961884, 1.5868232171547578`}, {6.287150018382918, 
      1.8816042394023436`}}]}, 
    {Hue[0.25948330604467174`], AbsoluteThickness[0.5], 
     LineBox[{{6.036656461720002, 1.6775537955970146`}, {5.625588209786038, 
      1.954739381579031}}]}, 
    {Hue[0.2596775370878689], AbsoluteThickness[0.5], 
     LineBox[{{5.625588209786038, 1.954739381579031}, {5.434632846005179, 
      2.0883302110018165`}}]}, 
    {Hue[0.5203328816969659], AbsoluteThickness[0.5], 
     LineBox[{{5.875024991266699, 1.5816524017169022`}, {5.386838787639893, 
      1.17707328175869}}]}, 
    {Hue[0.5226642044477693], AbsoluteThickness[0.5], 
     LineBox[{{5.386838787639893, 1.17707328175869}, {5.216418216343868, 
      1.0764549847096392`}}]}, 
    {Hue[0.4778156915000231], AbsoluteThickness[0.5], 
     LineBox[{{5.995683381404745, 1.3667402332319012`}, {5.915766996348002, 
      1.329938586737978}}]}, 
    {Hue[0.47800106042559387`], AbsoluteThickness[0.5], 
     LineBox[{{5.915766996348002, 1.329938586737978}, {5.589348707423781, 
      1.1826893079768626`}}]}, 
    {Hue[0.693777225933752], AbsoluteThickness[0.5], 
     LineBox[{{5.987631729229609, 0.8005725958373693}, {5.972639396864549, 
      0.6844474588014469}}]}, 
    {Hue[0.6939604356032585], AbsoluteThickness[0.5], 
     LineBox[{{5.972639396864549, 0.6844474588014469}, {5.934336026432902, 
      0.3840163419848044}}]}, 
    {Hue[0.6880064884137778], AbsoluteThickness[0.5], 
     LineBox[{{7.082999887296782, 0.31698239836342923`}, {7.114516242080115, 
      0.28107956277846663`}}]}, 
    {Hue[0.6881977531691872], AbsoluteThickness[0.5], 
     LineBox[{{7.114516242080115, 0.28107956277846663`}, {7.269243314924368, 
      0.10997104284251003`}}]}, 
    {Hue[0.4751426533705765], AbsoluteThickness[0.5], 
     LineBox[{{5.132603163998297, 0.8633038107538517}, {5.098684704037478, 
      0.8641184408836207}}]}, 
    {Hue[0.4762704639184416], AbsoluteThickness[0.5], 
     LineBox[{{5.0986847040374785`, 0.8641184408836207}, {4.874911054466808, 
      0.8967438186105634}}]}, 
    {Hue[0.4617909553253535], AbsoluteThickness[0.5], 
     LineBox[{{4.359421295530483, -0.9513629506393492}, {
      4.158007169770423, -1.0681850780699813`}}]}, 
    {Hue[0.46276160376045317`], AbsoluteThickness[0.5], 
     LineBox[{{4.158007169770423, -1.0681850780699813`}, {
      3.9514534114328006`, -1.1585364994661662`}}]}, 
    {Hue[0.5514901332628442], AbsoluteThickness[0.5], 
     LineBox[{{4.356816966072465, 1.0969723235612296`}, {4.309155676079274, 
      1.1214810476127461`}}]}, 
    {Hue[0.552018265505886], AbsoluteThickness[0.5], 
     LineBox[{{4.309155676079274, 1.1214810476127461`}, {4.0960916602283275`, 
      1.2544517791728071`}}]}, 
    {Hue[0.5176906985975959], AbsoluteThickness[0.5], 
     LineBox[{{6.560609031189221, 0.6257838054686258}, {6.650244092232106, 
      0.6137514666967877}}]}, 
    {Hue[0.5188877628483295], AbsoluteThickness[0.5], 
     LineBox[{{6.650244092232106, 0.6137514666967877}, {6.885969195992962, 
      0.6114723626851394}}]}, 
    {Hue[0.5572115187804808], AbsoluteThickness[0.5], 
     LineBox[{{5.441039746564652, 1.1369156045927298`}, {5.380342865732236, 
      1.1634631615150444`}}]}, 
    {Hue[0.5573966875618598], AbsoluteThickness[0.5], 
     LineBox[{{5.380342865732236, 1.1634631615150444`}, {5.0774646795014835`, 
      1.2986243324192273`}}]}, 
    {Hue[0.6632276532800527], AbsoluteThickness[0.5], 
     LineBox[{{5.415740315443308, 0.8455727215350262}, {5.3671627411517635`, 
      0.8414132536242973}}]}, 
    {Hue[0.6635222499739075], AbsoluteThickness[0.5], 
     LineBox[{{5.3671627411517635`, 0.8414132536242973}, {5.096699440575585, 
      0.8041596610668059}}]}, 
    {Hue[0.6979275969836766], AbsoluteThickness[0.5], 
     LineBox[{{5.43041916475558, 0.3419012486380427}, {
      5.2825728163768, -0.02039618674577165}}]}, 
    {Hue[0.6981632997753273], AbsoluteThickness[0.5], 
     LineBox[{{5.2825728163768, -0.02039618674577165}, {
      5.165712099764965, -0.3395329293425942}}]}, 
    {Hue[0.67577413001892], AbsoluteThickness[0.5], 
     LineBox[{{6.132844253351959, 1.133288049183445}, {6.826067983688849, 
      0.37884217744721077`}}]}, 
    {Hue[0.6819135745152601], AbsoluteThickness[0.5], 
     LineBox[{{6.826067983688849, 0.37884217744721077`}, {6.9089651371026575`,
       0.23662464116783447`}}]}, 
    {Hue[0.4625810476249068], AbsoluteThickness[0.5], 
     LineBox[{{6.111402240816899, 1.6956126639955889`}, {6.028279707946844, 
      1.8198766499719492`}}]}, 
    {Hue[0.4629029579707293], AbsoluteThickness[0.5], 
     LineBox[{{6.028279707946844, 1.8198766499719492`}, {5.871677664455433, 
      2.085412051030004}}]}, 
    {Hue[0.23826795323230207`], AbsoluteThickness[0.5], 
     LineBox[{{6.184072372672007, 1.8586024464312514`}, {6.320906309499774, 
      2.0591489993432495`}}]}, 
    {Hue[0.23889692370220977`], AbsoluteThickness[0.5], 
     LineBox[{{6.320906309499774, 2.0591489993432495`}, {6.440837379378749, 
      2.2750571618804605`}}]}, 
    {Hue[0.5932071196333176], AbsoluteThickness[0.5], 
     LineBox[{{6.440837379378749, 2.2750571618804605`}, {6.2077278035136985`, 
      2.356664280519256}}]}, 
    {Hue[0.46932631465761643`], AbsoluteThickness[0.5], 
     LineBox[{{6.36240697690967, 1.8520156282570719`}, {6.6517446872126405`, 
      1.7884474615593178`}}]}, 
    {Hue[0.4695800542169374], AbsoluteThickness[0.5], 
     LineBox[{{6.6517446872126405`, 1.7884474615593178`}, {6.897227864791424, 
      1.7236485654343994`}}]}, 
    {Hue[0.6647497395354591], AbsoluteThickness[0.5], 
     LineBox[{{5.599442986112421, 1.1595858165884754`}, {5.578820183056489, 
      1.1362831538007814`}}]}, 
    {Hue[0.6649645818739215], AbsoluteThickness[0.5], 
     LineBox[{{5.578820183056489, 1.1362831538007814`}, {5.372007422895698, 
      0.8886497691912926}}]}, 
    {Hue[0.5237033484785563], AbsoluteThickness[0.5], 
     LineBox[{{7.162702661414744, 0.9438053337150264}, {7.19531982452479, 
      0.9402167803239351}}]}, 
    {Hue[0.5255744067408665], AbsoluteThickness[0.5], 
     LineBox[{{7.19531982452479, 0.9402167803239352}, {7.3821519417883765`, 
      0.8912266074744308}}]}, 
    {Hue[0.5142745434835054], AbsoluteThickness[0.5], 
     LineBox[{{4.395280740220098, 1.1447153361225655`}, {4.341300350337997, 
      1.1378960908493214`}}]}, 
    {Hue[0.51685335022049], AbsoluteThickness[0.5], 
     LineBox[{{4.341300350337997, 1.1378960908493214`}, {4.156171182713343, 
      1.1450378863667876`}}]}, 
    {Hue[0.5367583934924818], AbsoluteThickness[0.5], 
     LineBox[{{7.891581672955386, 0.3077814576649613}, {8.077006186780842, 
      0.27867406472608236`}}]}, 
    {Hue[0.536962174512035], AbsoluteThickness[0.5], 
     LineBox[{{8.077006186780842, 0.27867406472608236`}, {8.382099314299674, 
      0.22347529134967298`}}]}, 
    {Hue[0.43724281026521516`], AbsoluteThickness[0.5], 
     LineBox[{{4.503571201537513, 1.5849363906658709`}, {4.440374935192335, 
      1.6884978939291888`}}]}, 
    {Hue[0.43764260560472923`], AbsoluteThickness[0.5], 
     LineBox[{{4.440374935192335, 1.6884978939291888`}, {4.278409306365115, 
      1.9170346464985808`}}]}, 
    {Hue[0.6538734625128773], AbsoluteThickness[0.5], 
     LineBox[{{3.3847302367062975`, -0.6145580846091381}, {
      3.2969396556608648`, -0.6486966623067383}}]}, 
    {Hue[0.6542931975767978], AbsoluteThickness[0.5], 
     LineBox[{{3.2969396556608648`, -0.6486966623067383}, {
      3.056035109608411, -0.7627206856098533}}]}, 
    {Hue[0.6646227141682116], AbsoluteThickness[0.5], 
     LineBox[{{4.444584970458577, -2.17407961338191}, {
      4.401395049186998, -2.231397359948631}}]}, 
    {Hue[0.665911328803806], AbsoluteThickness[0.5], 
     LineBox[{{4.401395049186998, -2.231397359948631}, {
      4.250973596039403, -2.385515828997722}}]}, 
    {Hue[0.6897330728566295], AbsoluteThickness[0.5], 
     LineBox[{{5.466710937071036, -2.126897206581193}, {
      5.3881037401442144`, -2.333911060676379}}]}, 
    {Hue[0.6907834775766418], AbsoluteThickness[0.5], 
     LineBox[{{5.3881037401442144`, -2.333911060676379}, {
      5.334963802773455, -2.54581248256604}}]}, 
    {Hue[0.637344503043252], AbsoluteThickness[0.5], 
     LineBox[{{6.1387084261467875`, -2.3126263188259486`}, {
      6.225760321846037, -2.5817075108829264`}}]}, 
    {Hue[0.6375958900393244], AbsoluteThickness[0.5], 
     LineBox[{{6.225760321846037, -2.5817075108829264`}, {
      6.290875589312144, -2.815415160633884}}]}, 
    {Hue[0.5169650839998294], AbsoluteThickness[0.5], 
     LineBox[{{6.275115027170251, -2.39160072839328}, {
      6.376396982301569, -2.4193695636149584`}}]}, 
    {Hue[0.517149643205131], AbsoluteThickness[0.5], 
     LineBox[{{6.376396982301569, -2.4193695636149584`}, {
      6.709709089406296, -2.50852625996953}}]}, 
    {Hue[0.6605083776346864], AbsoluteThickness[0.5], 
     LineBox[{{6.415962670666085, -2.3208500429481655`}, {
      7.324472913554798, -1.5196546351294475`}}]}, 
    {Hue[0.6609542713488418], AbsoluteThickness[0.5], 
     LineBox[{{7.324472913554798, -1.5196546351294475`}, {
      7.529897953148777, -1.3640197673514542`}}]}, 
    {Hue[0.6995800572832791], AbsoluteThickness[0.5], 
     LineBox[{{6.29649179032783, -1.714548594238228}, {
      6.511435683837266, -1.6634132159734705`}}]}, 
    {Hue[0.6758254655048661], AbsoluteThickness[0.5], 
     LineBox[{{6.920460688392599, -1.3157020578048386`}, {
      7.111345118114919, -1.3251806879671508`}}]}, 
    {Hue[0.6760399197534749], AbsoluteThickness[0.5], 
     LineBox[{{7.111345118114919, -1.3251806879671508`}, {
      7.41383491331418, -1.3315744125057838`}}]}, 
    {Hue[0.47002824050934505`], AbsoluteThickness[0.5], 
     LineBox[{{3.08320727731976, -1.3467014046111412`}, {
      3.061437346951778, -1.3534291110795635`}}]}, 
    {Hue[0.47136189676049894`], AbsoluteThickness[0.5], 
     LineBox[{{3.061437346951778, -1.3534291110795635`}, {
      2.866810299806632, -1.442451087010559}}]}, 
    {Hue[0.5452856151556987], AbsoluteThickness[0.5], 
     LineBox[{{3.0823029265595387`, 0.3204098587077727}, {2.875842145644434, 
      0.349209221182765}}]}, 
    {Hue[0.5459209387742295], AbsoluteThickness[0.5], 
     LineBox[{{2.875842145644434, 0.349209221182765}, {2.605303873416047, 
      0.3617660148907954}}]}, 
    {Hue[0.6169595544721576], AbsoluteThickness[0.5], 
     LineBox[{{5.042768365054769, 2.0940943312606244`}, {5.073874337603238, 
      2.2330401138623297`}}]}, 
    {Hue[0.632496368440718], AbsoluteThickness[0.5], 
     LineBox[{{5.073874337603238, 2.2330401138623297`}, {5.1481400246627125`, 
      2.369639803748075}}]}, 
    {Hue[0.6935203116012707], AbsoluteThickness[0.5], 
     LineBox[{{6.540441563317021, 1.658662282854143}, {6.625737115933364, 
      1.7209443206159765`}}]}, 
    {Hue[0.6940364514604499], AbsoluteThickness[0.5], 
     LineBox[{{6.625737115933364, 1.7209443206159765`}, {6.811440419389403, 
      1.8345145594733225`}}]}, 
    {Hue[0.45450018358928385`], AbsoluteThickness[0.5], 
     LineBox[{{2.3362231553334047`, -0.9367987626976133}, {
      2.1561864118925493`, -1.033264979160073}}]}, 
    {Hue[0.454844030186208], AbsoluteThickness[0.5], 
     LineBox[{{2.1561864118925493`, -1.033264979160073}, {
      1.8528470577585507`, -1.17291256256883}}]}, 
    {Hue[0.6591858992802775], AbsoluteThickness[0.5], 
     LineBox[{{2.258971730969517, 2.3682680267369927`}, {2.1707816353633187`, 
      2.6531790411572076`}}]}, 
    {Hue[0.659501738399253], AbsoluteThickness[0.5], 
     LineBox[{{2.1707816353633187`, 2.6531790411572076`}, {2.114866436608288, 
      2.87721879600748}}]}, 
    {Hue[0.6743968086924835], AbsoluteThickness[0.5], 
     LineBox[{{5.261063463459581, 3.37564683895124}, {5.317602229717479, 
      3.5391865573943955`}}]}, 
    {Hue[0.6839904400313929], AbsoluteThickness[0.5], 
     LineBox[{{5.317602229717479, 3.5391865573943955`}, {5.410142819605809, 
      3.6812770041790377`}}]}, 
    {Hue[0.6009274804102315], AbsoluteThickness[0.5], 
     LineBox[{{3.0949401737714983`, 3.1903948146437107`}, {3.100638485469136, 
      3.2575318555276516`}}]}, 
    {Hue[0.6191032349298876], AbsoluteThickness[0.5], 
     LineBox[{{3.100638485469136, 3.2575318555276516`}, {3.1531498249152365`, 
      3.3914826324245704`}}]}, 
    {Hue[0.6984761820092545], AbsoluteThickness[0.5], 
     LineBox[{{2.4434141231202973`, -2.618182018279854}, {
      2.507203505473403, -2.8192627123809926`}}]}, 
    {Hue[0.6988179040757825], AbsoluteThickness[0.5], 
     LineBox[{{2.507203505473403, -2.8192627123809926`}, {
      2.5716690254112136`, -3.0748271865089367`}}]}, 
    {Hue[0.6042659670239073], AbsoluteThickness[0.5], 
     LineBox[{{3.131828495403569, -2.4140370798315542`}, {
      3.5736524678233232`, -2.793166685997226}}]}, 
    {Hue[0.6059761536426187], AbsoluteThickness[0.5], 
     LineBox[{{3.5736524678233232`, -2.793166685997226}, {
      3.7370821451708434`, -2.897242151157988}}]}, 
    {Hue[0.6887472201553326], AbsoluteThickness[0.5], 
     LineBox[{{3.4145530314090804`, -1.7368927213868033`}, {
      3.6175598185970927`, -1.6842546957809021`}}]}, 
    {Hue[0.6921625609911382], AbsoluteThickness[0.5], 
     LineBox[{{3.6175598185970927`, -1.6842546957809021`}, {
      3.767724301347901, -1.6731776431117509`}}]}, 
    {Hue[0.4428069774667359], AbsoluteThickness[0.5], 
     LineBox[{{2.108755056526315, -2.2415706126908783`}, {
      2.0154221800005097`, -2.3147975971414723`}}]}, 
    {Hue[0.4436550173499644], AbsoluteThickness[0.5], 
     LineBox[{{2.0154221800005097`, -2.3147975971414723`}, {
      1.841612151678042, -2.4839424729838475`}}]}, 
    {Hue[0.6801797831533613], AbsoluteThickness[0.5], 
     LineBox[{{7.6650107297416685`, 2.069805418458244}, {8.063843397574225, 
      2.219770844068518}}]}, 
    {Hue[0.6803724396863419], AbsoluteThickness[0.5], 
     LineBox[{{8.063843397574225, 2.219770844068518}, {8.34571974139002, 
      2.320663474652185}}]}, 
    {Hue[0.6798957444245498], AbsoluteThickness[0.5], 
     LineBox[{{3.6579620877190564`, 1.2411682766713321`}, {
      3.1701167073340666`, 1.0845330539530924`}}]}, 
    {Hue[0.6801026395025315], AbsoluteThickness[0.5], 
     LineBox[{{3.1701167073340666`, 1.0845330539530924`}, {2.847931087938611, 
      0.9721552211046295}}]}, 
    {Hue[0.40878419132396754`], AbsoluteThickness[0.5], 
     LineBox[{{3.64293783700036, 1.8804307999132586`}, {3.627751011380789, 
      1.9108336284133907`}}]}, 
    {Hue[0.4089928659596083], AbsoluteThickness[0.5], 
     LineBox[{{3.627751011380789, 1.9108336284133907`}, {3.5075177202934777`, 
      2.1367499951643203`}}]}, 
    {Hue[0.6857674945300767], AbsoluteThickness[0.5], 
     LineBox[{{4.297582025844731, 1.9168082156473396`}, {4.376064366816332, 
      1.9628549605429493`}}]}, 
    {Hue[0.6860416431007751], AbsoluteThickness[0.5], 
     LineBox[{{4.376064366816332, 1.9628549605429493`}, {4.637363154484737, 
      2.100095438023548}}]}, 
    {Hue[0.6879615200807481], AbsoluteThickness[0.5], 
     LineBox[{{2.8550571286116426`, -0.5179270523033074}, {
      2.704601447193009, -0.5948348992005054}}]}, 
    {Hue[0.6887652638353374], AbsoluteThickness[0.5], 
     LineBox[{{2.704601447193009, -0.5948348992005054}, {
      2.4748039084685063`, -0.6836136830671304}}]}, 
    {Hue[0.6068957992479974], AbsoluteThickness[0.5], 
     LineBox[{{4.118371926014607, -0.7916360463911913}, {
      3.8896606650171655`, -0.8454441103070542}}]}, 
    {Hue[0.6089685416254056], AbsoluteThickness[0.5], 
     LineBox[{{3.8896606650171655`, -0.8454441103070542}, {
      3.7044712285073365`, -0.8600566613744223}}]}, 
    {Hue[0.6612157026356736], AbsoluteThickness[0.5], 
     LineBox[{{4.364103526572395, -0.9270059505467887}, {
      4.161058715726155, -0.9562585138170068}}]}, 
    {Hue[0.6614105825861252], AbsoluteThickness[0.5], 
     LineBox[{{4.161058715726155, -0.9562585138170068}, {
      3.8477455568113452`, -1.0070624334439158`}}]}, 
    {Hue[0.6874727102261686], AbsoluteThickness[0.5], 
     LineBox[{{5.8600330983876, 0.07567180311158181}, {5.767312050664425, 
      0.12266667029449653`}}]}, 
    {Hue[0.6877646358457361], AbsoluteThickness[0.5], 
     LineBox[{{5.767312050664425, 0.12266667029449653`}, {5.5831585270802275`,
       0.2281089080558495}}]}, 
    {Hue[0.5120528611388571], AbsoluteThickness[0.5], 
     LineBox[{{7.626023718036561, -0.4492137686747103}, {
      7.72673538027961, -0.3799163735965593}}]}, 
    {Hue[0.5128458173827689], AbsoluteThickness[0.5], 
     LineBox[{{7.72673538027961, -0.3799163735965593}, {
      7.888559142148566, -0.24197956494456557`}}]}, 
    {Hue[0.6315835494285875], AbsoluteThickness[0.5], 
     LineBox[{{7.334496159081358, -0.6055118865612469}, {
      7.342652343122805, -0.5507698702134257}}]}, 
    {Hue[0.6326686170895925], AbsoluteThickness[0.5], 
     LineBox[{{7.342652343122805, -0.5507698702134257}, {
      7.397588857222164, -0.3497113918811222}}]}, 
    {Hue[0.6580512091888071], AbsoluteThickness[0.5], 
     LineBox[{{7.416265530500333, -1.3702567653724946`}, {
      7.410231089580755, -1.3423576688021113`}}]}, 
    {Hue[0.6595011953748061], AbsoluteThickness[0.5], 
     LineBox[{{7.410231089580755, -1.3423576688021113`}, {
      7.341191770303148, -1.1511869589989376`}}]}, 
    {Hue[0.21894287935888354`], AbsoluteThickness[0.5], 
     LineBox[{{7.5948414737607, -1.6208355140056565`}, {
      7.666658242611352, -1.7260979029653378`}}]}, 
    {Hue[0.21925322035914221`], AbsoluteThickness[0.5], 
     LineBox[{{7.666658242611352, -1.7260979029653378`}, {
      7.823226157153527, -1.930649643545257}}]}, 
    {Hue[0.6258237149033915], AbsoluteThickness[0.5], 
     LineBox[{{7.823226157153527, -1.930649643545257}, {
      7.898725692883722, -1.6843677998318296`}}]}, 
    {Hue[0.6584491174809188], AbsoluteThickness[0.5], 
     LineBox[{{7.33511329940802, -1.4558495987725213`}, {
      7.307758015701156, -1.4376774421161653`}}]}, 
    {Hue[0.6589179890254183], AbsoluteThickness[0.5], 
     LineBox[{{7.307758015701156, -1.4376774421161653`}, {
      7.106842406878487, -1.2806810371144008`}}]}, 
    {Hue[0.6320578601709411], AbsoluteThickness[0.5], 
     LineBox[{{6.636570319863082, -1.3161057789349486`}, {
      6.443841666585319, -1.2947815133730185`}}]}, 
    {Hue[0.6322646636534465], AbsoluteThickness[0.5], 
     LineBox[{{6.443841666585319, -1.2947815133730185`}, {
      6.119803288382871, -1.2507439383342212`}}]}, 
    {Hue[0.5153657624714532], AbsoluteThickness[0.5], 
     LineBox[{{6.489914395050555, -1.6575550106708106`}, {
      6.32590391948947, -1.7759094604061625`}}]}, 
    {Hue[0.5156393179239455], AbsoluteThickness[0.5], 
     LineBox[{{6.32590391948947, -1.7759094604061625`}, {
      6.141316224293418, -1.8963876196907001`}}]}, 
    {Hue[0.6612467168361921], AbsoluteThickness[0.5], 
     LineBox[{{5.3712579755478105`, -0.6419208330212081}, {
      5.1564270156805865`, -0.520304833930549}}]}, 
    {Hue[0.6615304929891089], AbsoluteThickness[0.5], 
     LineBox[{{5.1564270156805865`, -0.520304833930549}, {
      4.909899322736532, -0.39632633971432635`}}]}, 
    {Hue[0.6356564663653798], AbsoluteThickness[0.5], 
     LineBox[{{6.41150589720002, 1.1926671838836118`}, {6.354979373850421, 
      1.4386060953362028`}}]}, 
    {Hue[0.6515259441340926], AbsoluteThickness[0.5], 
     LineBox[{{6.354979373850421, 1.4386060953362028`}, {6.362812811651092, 
      1.5853767994063988`}}]}, 
    {Hue[0.6110875753764774], AbsoluteThickness[0.5], 
     LineBox[{{6.966496046375656, 1.6530371043377268`}, {7.051610080316026, 
      1.9509057415606017`}}]}, 
    {Hue[0.6123824692836032], AbsoluteThickness[0.5], 
     LineBox[{{7.051610080316026, 1.9509057415606017`}, {7.076721279197129, 
      2.116419354507405}}]}, 
    {Hue[0.5043045834559097], AbsoluteThickness[0.5], 
     LineBox[{{4.151550991487545, 0.3339560449741226}, {3.5911278109148954`, 
      0.404730043300868}}]}, 
    {Hue[0.5046060010708642], AbsoluteThickness[0.5], 
     LineBox[{{3.5911278109148954`, 0.40473004330086804`}, {
      3.3223761266728817`, 0.45320832530609795`}}]}, 
    {Hue[0.5750925094918615], AbsoluteThickness[0.5], 
     LineBox[{{4.727886367284384, -0.8570999932866199}, {
      4.664926309399225, -0.9417618929029387}}]}, 
    {Hue[0.575656873821323], AbsoluteThickness[0.5], 
     LineBox[{{4.664926309399225, -0.9417618929029387}, {
      4.5046753581612275`, -1.1223702829451243`}}]}, 
    {Hue[0.6207794904235556], AbsoluteThickness[0.5], 
     LineBox[{{5.578707936680302, -1.6625646141888275`}, {
      5.567958176702326, -1.8050679294545213`}}]}, 
    {Hue[0.6210091420012356], AbsoluteThickness[0.5], 
     LineBox[{{5.567958176702326, -1.8050679294545213`}, {
      5.532598262384877, -2.126137966057005}}]}, 
    {Hue[0.6698166030515454], AbsoluteThickness[0.5], 
     LineBox[{{6.366015524438264, -0.8484054132965815}, {
      6.390699751889108, -0.8876621830023901}}]}, 
    {Hue[0.6700415994850019], AbsoluteThickness[0.5], 
     LineBox[{{6.390699751889108, -0.8876621830023901}, {
      6.558502686551672, -1.1361041517412096`}}]}, 
    {Hue[0.6857397897272376], AbsoluteThickness[0.5], 
     LineBox[{{5.940507675890693, 1.090761132862692}, {5.906650267057244, 
      1.1411021167992952`}}]}, 
    {Hue[0.6859776157474415], AbsoluteThickness[0.5], 
     LineBox[{{5.906650267057244, 1.1411021167992952`}, {5.7072547024128575`, 
      1.4150411308714208`}}]}, 
    {Hue[0.6475082018942562], AbsoluteThickness[0.5], 
     LineBox[{{6.975305451484222, 1.144078691628268}, {6.991925785457024, 
      1.3846612093021353`}}]}, 
    {Hue[0.6477305938918645], AbsoluteThickness[0.5], 
     LineBox[{{6.991925785457024, 1.3846612093021353`}, {7.001660413572281, 
      1.6459442831685513`}}]}, 
    {Hue[0.49149234526743685`], AbsoluteThickness[0.5], 
     LineBox[{{7.438952443142733, -0.6266931228462786}, {
      7.470287291566744, -0.8397595192879214}}]}, 
    {Hue[0.4917165943193647], AbsoluteThickness[0.5], 
     LineBox[{{7.470287291566744, -0.8397595192879214}, {
      7.523807089318023, -1.1364673427704632`}}]}, 
    {Hue[0.6911054001384133], AbsoluteThickness[0.5], 
     LineBox[{{7.600626168023581, -0.20339427849454245`}, {
      7.538987903316532, -0.1919606194188685}}]}, 
    {Hue[0.6975441868408543], AbsoluteThickness[0.5], 
     LineBox[{{7.538987903316532, -0.1919606194188685}, {
      7.40231010193742, -0.133882634183127}}]}, 
    {Hue[0.2459866482127445], AbsoluteThickness[0.5], 
     LineBox[{{7.882934929861941, -0.2757101473357457}, {
      8.129580112651137, -0.3380120252934028}}]}, 
    {Hue[0.2468755600458766], AbsoluteThickness[0.5], 
     LineBox[{{8.129580112651137, -0.3380120252934028}, {
      8.371022184652178, -0.3716808198235361}}]}, 
    {Hue[0.575646927862801], AbsoluteThickness[0.5], 
     LineBox[{{8.371022184652178, -0.3716808198235361}, {
      8.400837322111133, -0.12973264472074333`}}]}, 
    {Hue[0.6914724640447076], AbsoluteThickness[0.5], 
     LineBox[{{7.605830110964485, -0.1854840910062472}, {
      7.583808442483033, -0.17839516500404123`}}]}, 
    {Hue[0.6921282214510757], AbsoluteThickness[0.5], 
     LineBox[{{7.583808442483033, -0.17839516500404123`}, {
      7.380663139819714, -0.0912541415179408}}]}, 
    {Hue[0.4967103429098741], AbsoluteThickness[0.5], 
     LineBox[{{7.8898389876045965`, 0.310250823629456}, {7.923392072908012, 
      0.37453662136558347`}}]}, 
    {Hue[0.4968991034221219], AbsoluteThickness[0.5], 
     LineBox[{{7.923392072908012, 0.37453662136558347`}, {8.080195487154919, 
      0.6661707831798577}}]}, 
    {Hue[0.6487574916175445], AbsoluteThickness[0.5], 
     LineBox[{{6.125657458194816, -0.41832732762270464`}, {
      6.080637716367729, -0.43385538527627593`}}]}, 
    {Hue[0.6489417902314301], AbsoluteThickness[0.5], 
     LineBox[{{6.080637716367729, -0.43385538527627593`}, {
      5.825637039936708, -0.5234217821511212}}]}, 
    {Hue[0.686523494770474], AbsoluteThickness[0.5], 
     LineBox[{{5.370259476906691, 0.6360526074102332}, {5.342481872083101, 
      0.6441757256033335}}]}, 
    {Hue[0.686849963009743], AbsoluteThickness[0.5], 
     LineBox[{{5.342481872083101, 0.6441757256033335}, {5.091004786913011, 
      0.7337025154327036}}]}, 
    {Hue[0.4350951987163794], AbsoluteThickness[0.5], 
     LineBox[{{6.840886796903556, -0.5681950703666385}, {
      6.866761886098688, -0.694019397587685}}]}, 
    {Hue[0.4363929080750058], AbsoluteThickness[0.5], 
     LineBox[{{6.866761886098688, -0.694019397587685}, {
      6.881191250877583, -0.8861829153964238}}]}, 
    {Hue[0.43380170786081607`], AbsoluteThickness[0.5], 
     LineBox[{{7.149448457539012, 0.10347078033821677`}, {
      7.238157393487466, -0.13316628934978925`}}]}, 
    {Hue[0.4340246824903644], AbsoluteThickness[0.5], 
     LineBox[{{7.238157393487466, -0.13316628934978925`}, {
      7.331543225782122, -0.40876767013290327`}}]}, 
    {Hue[0.4211004339874979], AbsoluteThickness[0.5], 
     LineBox[{{7.390408105692144, 0.7150344162751484}, {7.419974370971576, 
      0.6397102217070847}}]}, 
    {Hue[0.421289335436788], AbsoluteThickness[0.5], 
     LineBox[{{7.419974370971576, 0.6397102217070847}, {7.548191576253571, 
      0.30072193789939994`}}]}, 
    {Hue[0.45941997049016897`], AbsoluteThickness[0.5], 
     LineBox[{{7.3775247299827535`, 1.391018043860573}, {7.341954503215509, 
      1.3691737677150844`}}]}, 
    {Hue[0.4596040857381762], AbsoluteThickness[0.5], 
     LineBox[{{7.341954503215509, 1.3691737677150844`}, {7.055504511607546, 
      1.1912081890792554`}}]}, 
    {Hue[0.022552648381459026`], AbsoluteThickness[0.5], 
     LineBox[{{7.543884862887944, 1.6644691373106297`}, {7.590368247538926, 
      1.7369085399029403`}}]}, 
    {Hue[0.023960069403974424`], AbsoluteThickness[0.5], 
     LineBox[{{7.590368247538926, 1.7369085399029403`}, {7.738157029364659, 
      1.911472297130765}}]}, 
    {Hue[0.3188915610086631], AbsoluteThickness[0.5], 
     LineBox[{{7.738157029364659, 1.911472297130765}, {7.932904742021405, 
      1.7915249845889867`}}]}, 
    {Hue[0.6138230526133517], AbsoluteThickness[0.5], 
     LineBox[{{7.932904742021405, 1.7915249845889867`}, {7.843510263820795, 
      1.5809955172019488`}}]}, 
    {Hue[0.4598300286110525], AbsoluteThickness[0.5], 
     LineBox[{{7.512885661753796, 1.345893802643445}, {7.496842644551443, 
      1.2139061125156703`}}]}, 
    {Hue[0.460041341883221], AbsoluteThickness[0.5], 
     LineBox[{{7.496842644551443, 1.2139061125156703`}, {7.464985043809726, 
      0.8755865366445774}}]}, 
    {Hue[0.4216613531226118], AbsoluteThickness[0.5], 
     LineBox[{{6.57982954868064, 1.3401081333321252`}, {6.359754642466834, 
      1.3107156326557965`}}]}, 
    {Hue[0.42184968995644057`], AbsoluteThickness[0.5], 
     LineBox[{{6.359754642466834, 1.3107156326557965`}, {6.051399004163451, 
      1.2658168799102762`}}]}, 
    {Hue[0.4332018575532566], AbsoluteThickness[0.5], 
     LineBox[{{5.883323261180942, 1.0085602719018325`}, {5.67637167252377, 
      0.978887154996747}}]}, 
    {Hue[0.433395387184571], AbsoluteThickness[0.5], 
     LineBox[{{5.67637167252377, 0.978887154996747}, {5.348678083172981, 
      0.9374527928655113}}]}, 
    {Hue[0.43236776479021494`], AbsoluteThickness[0.5], 
     LineBox[{{4.858833762293857, 1.081384031628743}, {4.6671547952838885`, 
      1.099269044092898}}]}, 
    {Hue[0.43274194162199997`], AbsoluteThickness[0.5], 
     LineBox[{{4.6671547952838885`, 1.099269044092898}, {4.363292513720586, 
      1.1077631715094527`}}]}, 
    {Hue[0.6885868629572593], AbsoluteThickness[0.5], 
     LineBox[{{6.468322005052908, -0.690413361520776}, {
      6.4922024195277235`, -0.830163736610522}}]}, 
    {Hue[0.6887703744934667], AbsoluteThickness[0.5], 
     LineBox[{{6.4922024195277235`, -0.830163736610522}, {
      6.544058705200856, -1.1397096353662313`}}]}, 
    {Hue[0.4675528482777211], AbsoluteThickness[0.5], 
     LineBox[{{6.902671251455068, 2.2927415826140214`}, {6.918722068695445, 
      2.3383097548097824`}}]}, 
    {Hue[0.4677374316926285], AbsoluteThickness[0.5], 
     LineBox[{{6.918722068695445, 2.3383097548097824`}, {7.023459793219201, 
      2.629803328498619}}]}, 
    {Hue[0.5162571368029123], AbsoluteThickness[0.5], 
     LineBox[{{6.287150018382918, 1.8816042394023436`}, {6.356777134173283, 
      2.0706436486224016`}}]}, 
    {Hue[0.5168611731051305], AbsoluteThickness[0.5], 
     LineBox[{{6.356777134173283, 2.0706436486224016`}, {6.42157587195393, 
      2.311129214326098}}]}, 
    {Hue[0.259871768131066], AbsoluteThickness[0.5], 
     LineBox[{{5.434632846005179, 2.0883302110018165`}, {5.377379804505068, 
      2.129866926644981}}]}, 
    {Hue[0.2600549174168552], AbsoluteThickness[0.5], 
     LineBox[{{5.377379804505068, 2.129866926644981}, {5.105130303168906, 
      2.32777283886906}}]}, 
    {Hue[0.5249955271985723], AbsoluteThickness[0.5], 
     LineBox[{{5.216418216343868, 1.0764549847096392`}, {5.161659475834462, 
      1.054922119649615}}]}, 
    {Hue[0.5251793049739047], AbsoluteThickness[0.5], 
     LineBox[{{5.161659475834462, 1.054922119649615}, {4.851961525503718, 
      0.934645522777102}}]}, 
    {Hue[0.47818642935116445`], AbsoluteThickness[0.5], 
     LineBox[{{5.589348707423781, 1.1826893079768626`}, {5.518103669062487, 
      1.1512149591504777`}}]}, 
    {Hue[0.49842520637683063`], AbsoluteThickness[0.5], 
     LineBox[{{5.518103669062487, 1.1512149591504777`}, {5.461139648466303, 
      1.1443863509174352`}}]}, 
    {Hue[0.6047245010950947], AbsoluteThickness[0.5], 
     LineBox[{{5.461139648466303, 1.1443863509174352`}, {5.409836078855042, 
      1.1187061391187512`}}]}, 
    {Hue[0.6941436452727648], AbsoluteThickness[0.5], 
     LineBox[{{5.934336026432902, 0.3840163419848044}, {5.904292357145209, 
      0.1453567907485327}}]}, 
    {Hue[0.6950476958123927], AbsoluteThickness[0.5], 
     LineBox[{{5.904292357145209, 0.1453567907485327}, {
      5.900457870164396, -0.1016796735186661}}]}, 
    {Hue[0.6883890179245965], AbsoluteThickness[0.5], 
     LineBox[{{7.269243314924368, 0.10997104284251004`}, {
      7.3793113611938725`, -0.008201718506410174}}]}, 
    {Hue[0.6887115661515466], AbsoluteThickness[0.5], 
     LineBox[{{7.3793113611938725`, -0.008201718506410174}, {
      7.5649167357676115`, -0.1860555186724132}}]}, 
    {Hue[0.4773982744663067], AbsoluteThickness[0.5], 
     LineBox[{{4.874911054466808, 0.8967438186105634}, {4.67989996195875, 
      0.9497794729162449}}]}, 
    {Hue[0.4775837677047071], AbsoluteThickness[0.5], 
     LineBox[{{4.67989996195875, 0.9497794729162449}, {4.338030659768891, 
      1.0456952774415846`}}]}, 
    {Hue[0.4637322521955528], AbsoluteThickness[0.5], 
     LineBox[{{3.9514534114328006`, -1.1585364994661662`}, {
      3.88193336815691, -1.17997311673636}}]}, 
    {Hue[0.4640895170572942], AbsoluteThickness[0.5], 
     LineBox[{{3.88193336815691, -1.17997311673636}, {
      3.6682505014656734`, -1.260811247870144}}]}, 
    {Hue[0.5525463977489277], AbsoluteThickness[0.5], 
     LineBox[{{4.0960916602283275`, 1.2544517791728071`}, {3.959387763546078, 
      1.3564299397503847`}}]}, 
    {Hue[0.5633115045391901], AbsoluteThickness[0.5], 
     LineBox[{{3.959387763546078, 1.3564299397503847`}, {3.8700807173829546`, 
      1.4673964527622854`}}]}, 
    {Hue[0.520084827099063], AbsoluteThickness[0.5], 
     LineBox[{{6.885969195992962, 0.6114723626851394}, {7.2096543937444535`, 
      0.6485669109904696}}]}, 
    {Hue[0.5232283031941548], AbsoluteThickness[0.5], 
     LineBox[{{7.2096543937444535`, 0.6485669109904696}, {7.379052243606461, 
      0.6990117450102403}}]}, 
    {Hue[0.5575818563432386], AbsoluteThickness[0.5], 
     LineBox[{{5.0774646795014835`, 1.2986243324192273`}, {5.01246476383433, 
      1.3282117434903686`}}]}, 
    {Hue[0.559763395514296], AbsoluteThickness[0.5], 
     LineBox[{{5.01246476383433, 1.3282117434903686`}, {4.842566133514247, 
      1.440068636143774}}]}, 
    {Hue[0.6638168466677621], AbsoluteThickness[0.5], 
     LineBox[{{5.096699440575585, 0.8041596610668059}, {4.895066441242999, 
      0.7657285500947084}}]}, 
    {Hue[0.6640045934913635], AbsoluteThickness[0.5], 
     LineBox[{{4.895066441242999, 0.7657285500947084}, {4.588794290327433, 
      0.7038109943929166}}]}, 
    {Hue[0.6983990025669778], AbsoluteThickness[0.5], 
     LineBox[{{5.165712099764965, -0.3395329293425942}, {
      5.134211892678214, -0.4363437224036853}}]}, 
    {Hue[0.6988819585056468], AbsoluteThickness[0.5], 
     LineBox[{{5.134211892678214, -0.4363437224036853}, {
      5.0400177056328745`, -0.6635405089458228}}]}, 
    {Hue[0.6880530190115991], AbsoluteThickness[0.5], 
     LineBox[{{6.9089651371026575`, 0.23662464116783447`}, {6.947263191339536,
       0.11802716847812038`}}]}, 
    {Hue[0.6883898514429532], AbsoluteThickness[0.5], 
     LineBox[{{6.947263191339536, 0.11802716847812038`}, {
      7.021149725198444, -0.07154571447836382}}]}, 
    {Hue[0.4632248683165518], AbsoluteThickness[0.5], 
     LineBox[{{5.871677664455433, 2.085412051030004}, {5.821416870401075, 
      2.182867931844339}}]}, 
    {Hue[0.46413776370512555`], AbsoluteThickness[0.5], 
     LineBox[{{5.821416870401075, 2.182867931844339}, {5.728774910946679, 
      2.3223324043258624`}}]}, 
    {Hue[0.5925781491634068], AbsoluteThickness[0.5], 
     LineBox[{{6.320906309499774, 2.0591489993432495`}, {6.3633446608630795`, 
      2.0310033450348413`}}]}, 
    {Hue[0.5928027847207156], AbsoluteThickness[0.5], 
     LineBox[{{6.3633446608630795`, 2.0310033450348413`}, {
      6.6258440355301405`, 1.8689699323790148`}}]}, 
    {Hue[0.23952589417211745`], AbsoluteThickness[0.5], 
     LineBox[{{6.440837379378749, 2.2750571618804605`}, {6.472040952293647, 
      2.3458184217531763`}}]}, 
    {Hue[0.2397911672640363], AbsoluteThickness[0.5], 
     LineBox[{{6.472040952293647, 2.3458184217531763`}, {6.583810886957185, 
      2.633564846050262}}]}, 
    {Hue[0.6579828088082244], AbsoluteThickness[0.5], 
     LineBox[{{6.583810886957185, 2.633564846050262}, {6.299114145669607, 
      2.5142405463846695`}}]}, 
    {Hue[0.5938360901032254], AbsoluteThickness[0.5], 
     LineBox[{{6.2077278035136985`, 2.356664280519256}, {6.164941740114911, 
      2.3673631501433543`}}]}, 
    {Hue[0.5941686134276027], AbsoluteThickness[0.5], 
     LineBox[{{6.164941740114911, 2.3673631501433543`}, {5.8856226064772645`, 
      2.454866553037327}}]}, 
    {Hue[0.4698337937762584], AbsoluteThickness[0.5], 
     LineBox[{{6.897227864791424, 1.7236485654343994`}, {7.0821012120622076`, 
      1.6664828386215798`}}]}, 
    {Hue[0.47020855140666534`], AbsoluteThickness[0.5], 
     LineBox[{{7.0821012120622076`, 1.6664828386215795`}, {7.354603703684484, 
      1.6013214427552687`}}]}, 
    {Hue[0.6651794242123839], AbsoluteThickness[0.5], 
     LineBox[{{5.372007422895698, 0.8886497691912926}, {5.350843936590856, 
      0.8617804958970844}}]}, 
    {Hue[0.665369382928686], AbsoluteThickness[0.5], 
     LineBox[{{5.350843936590856, 0.8617804958970844}, {5.161374580802137, 
      0.6278061110068232}}]}, 
    {Hue[0.5274454650031766], AbsoluteThickness[0.5], 
     LineBox[{{7.3821519417883765`, 0.8912266074744308}, {7.622852413903404, 
      0.7885214531920586}}]}, 
    {Hue[0.5276456687687576], AbsoluteThickness[0.5], 
     LineBox[{{7.622852413903404, 0.7885214531920586}, {7.929742957745927, 
      0.6652030754613594}}]}, 
    {Hue[0.5194321569574744], AbsoluteThickness[0.5], 
     LineBox[{{4.156171182713343, 1.1450378863667876`}, {4.153496893426275, 
      1.1455877333499838`}}]}, 
    {Hue[0.520445844234021], AbsoluteThickness[0.5], 
     LineBox[{{4.153496893426274, 1.1455877333499838`}, {3.934429269750753, 
      1.1647759852781359`}}]}, 
    {Hue[0.4380424009442433], AbsoluteThickness[0.5], 
     LineBox[{{4.278409306365115, 1.9170346464985808`}, {4.201877408545196, 
      2.010677723111943}}]}, 
    {Hue[0.4405381928070084], AbsoluteThickness[0.5], 
     LineBox[{{4.201877408545196, 2.010677723111943}, {4.055325171769849, 
      2.140045002997775}}]}, 
    {Hue[0.6935032872326542], AbsoluteThickness[0.5], 
     LineBox[{{4.055325171769849, 2.140045002997775}, {3.8871266030435763`, 
      2.040432289515257}}]}, 
    {Hue[0.6547129326407184], AbsoluteThickness[0.5], 
     LineBox[{{3.056035109608411, -0.7627206856098533}, {
      2.9121687742877462`, -0.8438138098897752}}]}, 
    {Hue[0.6565420478258817], AbsoluteThickness[0.5], 
     LineBox[{{2.9121687742877462`, -0.8438138098897752}, {
      2.7442304120272185`, -0.9084906570121896}}]}, 
    {Hue[0.6671999434394005], AbsoluteThickness[0.5], 
     LineBox[{{4.250973596039403, -2.385515828997722}, {
      4.141155509164145, -2.4725244263466686`}}]}, 
    {Hue[0.6675632205261678], AbsoluteThickness[0.5], 
     LineBox[{{4.141155509164145, -2.4725244263466686`}, {
      3.9103644313012382`, -2.63264420570771}}]}, 
    {Hue[0.6918338822966542], AbsoluteThickness[0.5], 
     LineBox[{{5.334963802773455, -2.54581248256604}, {
      5.330985085163504, -2.576600492582407}}]}, 
    {Hue[0.6920972780960122], AbsoluteThickness[0.5], 
     LineBox[{{5.330985085163504, -2.576600492582407}, {
      5.275954050371112, -2.8917611585853704`}}]}, 
    {Hue[0.6378472770353968], AbsoluteThickness[0.5], 
     LineBox[{{6.290875589312144, -2.815415160633884}, {
      6.329760945790908, -2.9810678518678104`}}]}, 
    {Hue[0.6394105097339022], AbsoluteThickness[0.5], 
     LineBox[{{6.329760945790908, -2.9810678518678104`}, {
      6.402864922916759, -3.1706687047615048`}}]}, 
    {Hue[0.5173342024104327], AbsoluteThickness[0.5], 
     LineBox[{{6.709709089406296, -2.50852625996953}, {
      6.863121642356406, -2.5485397701708075`}}]}, 
    {Hue[0.5184799739043919], AbsoluteThickness[0.5], 
     LineBox[{{6.863121642356406, -2.5485397701708075`}, {
      7.065516021771263, -2.5757373891090496`}}]}, 
    {Hue[0.6614001650629971], AbsoluteThickness[0.5], 
     LineBox[{{7.529897953148777, -1.3640197673514542`}, {
      7.627798623920488, -1.3007128758044786`}}]}, 
    {Hue[0.6616013961607127], AbsoluteThickness[0.5], 
     LineBox[{{7.627798623920488, -1.3007128758044786`}, {
      7.907913549349928, -1.128131966537967}}]}, 
    {Hue[0.6762543740020837], AbsoluteThickness[0.5], 
     LineBox[{{7.41383491331418, -1.3315744125057838`}, {
      7.641643426389006, -1.3299004596253732`}}]}, 
    {Hue[0.6765659216537168], AbsoluteThickness[0.5], 
     LineBox[{{7.641643426389006, -1.3299004596253732`}, {
      7.9396332096186235`, -1.3113566863266601`}}]}, 
    {Hue[0.47269555301165284`], AbsoluteThickness[0.5], 
     LineBox[{{2.866810299806632, -1.442451087010559}, {
      2.419159283002482, -1.7220162844483655`}}]}, 
    {Hue[0.4730729506279012], AbsoluteThickness[0.5], 
     LineBox[{{2.419159283002482, -1.7220162844483655`}, {
      2.195908819104282, -1.8418698879684676`}}]}, 
    {Hue[0.5465562623927602], AbsoluteThickness[0.5], 
     LineBox[{{2.605303873416047, 0.3617660148907954}, {2.300476159870274, 
      0.3477845166552455}}]}, 
    {Hue[0.5468989186652056], AbsoluteThickness[0.5], 
     LineBox[{{2.300476159870274, 0.3477845166552455}, {2.0921927069666446`, 
      0.3256054024297014}}]}, 
    {Hue[0.6480331824092775], AbsoluteThickness[0.5], 
     LineBox[{{5.1481400246627125`, 2.369639803748075}, {5.367259958218387, 
      2.59304855884162}}]}, 
    {Hue[0.6579214849524203], AbsoluteThickness[0.5], 
     LineBox[{{5.367259958218387, 2.59304855884162}, {5.507286540201194, 
      2.678637279603003}}]}, 
    {Hue[0.694552591319629], AbsoluteThickness[0.5], 
     LineBox[{{6.811440419389403, 1.8345145594733225`}, {6.985714678248692, 
      1.922396766792331}}]}, 
    {Hue[0.6997615016885281], AbsoluteThickness[0.5], 
     LineBox[{{6.985714678248692, 1.922396766792331}, {7.089412134823265, 
      2.004929234284356}}]}, 
    {Hue[0.6598175775182282], AbsoluteThickness[0.5], 
     LineBox[{{2.114866436608288, 2.87721879600748}, {2.0728522647269667`, 
      3.096887373596184}}]}, 
    {Hue[0.6991596261423104], AbsoluteThickness[0.5], 
     LineBox[{{2.5716690254112136`, -3.0748271865089367`}, {
      2.599163998917913, -3.2201451736631674`}}]}, 
    {Hue[0.6076863402613301], AbsoluteThickness[0.5], 
     LineBox[{{3.7370821451708434`, -2.897242151157988}, {
      3.9134400662329862`, -2.9770441415149165`}}]}, 
    {Hue[0.6078705437183707], AbsoluteThickness[0.5], 
     LineBox[{{3.9134400662329862`, -2.9770441415149165`}, {
      4.16312011496545, -3.0916553002213503`}}]}, 
    {Hue[0.6955779018269437], AbsoluteThickness[0.5], 
     LineBox[{{3.767724301347901, -1.6731776431117509`}, {
      4.05889476923608, -1.7042871649611344`}}]}, 
    {Hue[0.6957616661164172], AbsoluteThickness[0.5], 
     LineBox[{{4.05889476923608, -1.7042871649611344`}, {
      4.4193349084766895`, -1.7443209047785018`}}]}, 
    {Hue[0.680309534580513], AbsoluteThickness[0.5], 
     LineBox[{{2.847931087938611, 0.9721552211046295}, {2.413079136039623, 
      0.8082127062037942}}]}, 
    {Hue[0.6805164649459798], AbsoluteThickness[0.5], 
     LineBox[{{2.413079136039623, 0.8082127062037942}, {2.18705552402088, 
      0.7293805768078586}}]}, 
    {Hue[0.4092015405952491], AbsoluteThickness[0.5], 
     LineBox[{{3.5075177202934777`, 2.1367499951643203`}, {3.45669261763965, 
      2.226579398023197}}]}, 
    {Hue[0.41090330868158603`], AbsoluteThickness[0.5], 
     LineBox[{{3.45669261763965, 2.226579398023197}, {3.332308243559459, 
      2.3879252482139632`}}]}, 
    {Hue[0.6918892517510659], AbsoluteThickness[0.5], 
     LineBox[{{3.332308243559459, 2.3879252482139632`}, {3.1486487051213468`, 
      2.299759893171285}}]}, 
    {Hue[0.6863157916714736], AbsoluteThickness[0.5], 
     LineBox[{{4.637363154484737, 2.100095438023548}, {4.669297845975176, 
      2.114999261324612}}]}, 
    {Hue[0.6868323896655905], AbsoluteThickness[0.5], 
     LineBox[{{4.669297845975176, 2.114999261324612}, {4.888010749790684, 
      2.239795602771776}}]}, 
    {Hue[0.6895690075899268], AbsoluteThickness[0.5], 
     LineBox[{{2.4748039084685063`, -0.6836136830671304}, {
      2.3839809742100564`, -0.7082420446104155}}]}, 
    {Hue[0.6897884138998387], AbsoluteThickness[0.5], 
     LineBox[{{2.3839809742100564`, -0.7082420446104155}, {
      2.074965366139089, -0.7819802989291605}}]}, 
    {Hue[0.6110412840028139], AbsoluteThickness[0.5], 
     LineBox[{{3.7044712285073365`, -0.8600566613744223}, {
      3.6789730870763115`, -0.8581771474698388}}]}, 
    {Hue[0.6115194056663645], AbsoluteThickness[0.5], 
     LineBox[{{3.6789730870763115`, -0.8581771474698388}, {
      3.4125453660218863`, -0.8593377419620716}}]}, 
    {Hue[0.6616054625365767], AbsoluteThickness[0.5], 
     LineBox[{{3.8477455568113452`, -1.0070624334439158`}, {
      3.6896996591254667`, -1.035563739061351}}]}, 
    {Hue[0.6620622266583405], AbsoluteThickness[0.5], 
     LineBox[{{3.6896996591254667`, -1.035563739061351}, {
      3.422089061304332, -1.0631783556271799`}}]}, 
    {Hue[0.6880565614653038], AbsoluteThickness[0.5], 
     LineBox[{{5.5831585270802275`, 0.2281089080558495}, {5.169421741661696, 
      0.4938376082481516}}]}, 
    {Hue[0.6882602824784361], AbsoluteThickness[0.5], 
     LineBox[{{5.169421741661696, 0.4938376082481516}, {4.9164044126609205`, 
      0.6481537547206977}}]}, 
    {Hue[0.5136387736266806], AbsoluteThickness[0.5], 
     LineBox[{{7.888559142148566, -0.24197956494456557`}, {
      7.960429604410104, -0.1666218653883848}}]}, 
    {Hue[0.5139148019050045], AbsoluteThickness[0.5], 
     LineBox[{{7.960429604410104, -0.1666218653883848}, {8.150256002333505, 
      0.05231239248044924}}]}, 
    {Hue[0.6337536847505977], AbsoluteThickness[0.5], 
     LineBox[{{7.397588857222164, -0.3497113918811222}, {
      7.4653602179059835`, -0.18272877991268882`}}]}, 
    {Hue[0.633936805325479], AbsoluteThickness[0.5], 
     LineBox[{{7.4653602179059835`, -0.18272877991268882`}, {
      7.574921277472411, 0.08747559165130749}}]}, 
    {Hue[0.6609511815608051], AbsoluteThickness[0.5], 
     LineBox[{{7.341191770303148, -1.1511869589989376`}, {
      7.236059442686831, -0.9493030010524817}}]}, 
    {Hue[0.6612265673385105], AbsoluteThickness[0.5], 
     LineBox[{{7.236059442686831, -0.9493030010524817}, {
      7.093124318394603, -0.6399737634313856}}]}, 
    {Hue[0.6255133739031317], AbsoluteThickness[0.5], 
     LineBox[{{7.666658242611352, -1.7260979029653378`}, {
      7.3802853501272025`, -1.7513157008069478`}}]}, 
    {Hue[0.6257137303833472], AbsoluteThickness[0.5], 
     LineBox[{{7.3802853501272025`, -1.7513157008069478`}, {
      7.095556880334739, -1.782516190304264}}]}, 
    {Hue[0.21956356135940083`], AbsoluteThickness[0.5], 
     LineBox[{{7.823226157153527, -1.930649643545257}, {
      7.863139321655691, -1.9772863051707465`}}]}, 
    {Hue[0.2201914983286907], AbsoluteThickness[0.5], 
     LineBox[{{7.863139321655691, -1.9772863051707465`}, {
      8.022041265246742, -2.1317672179825253`}}]}, 
    {Hue[0.5746232096161243], AbsoluteThickness[0.5], 
     LineBox[{{8.022041265246742, -2.1317672179825253`}, {
      8.147211336256754, -1.948883010289454}}]}, 
    {Hue[0.6261340559036501], AbsoluteThickness[0.5], 
     LineBox[{{7.898725692883722, -1.6843677998318296`}, {
      7.90382085132422, -1.663804587281601}}]}, 
    {Hue[0.6263857767215909], AbsoluteThickness[0.5], 
     LineBox[{{7.90382085132422, -1.663804587281601}, {
      7.981703858840445, -1.3971231822573906`}}]}, 
    {Hue[0.6593868605699178], AbsoluteThickness[0.5], 
     LineBox[{{7.106842406878487, -1.2806810371144008`}, {
      6.978182730931252, -1.1631478453094757`}}]}, 
    {Hue[0.6598152612805176], AbsoluteThickness[0.5], 
     LineBox[{{6.978182730931252, -1.1631478453094757`}, {
      6.81221724320332, -0.9879310810174107}}]}, 
    {Hue[0.6324714671359517], AbsoluteThickness[0.5], 
     LineBox[{{6.119803288382871, -1.2507439383342212`}, {
      5.918159887220145, -1.2182123801542875`}}]}, 
    {Hue[0.6326558409318698], AbsoluteThickness[0.5], 
     LineBox[{{5.918159887220145, -1.2182123801542875`}, {
      5.603984831371815, -1.169398971513567}}]}, 
    {Hue[0.5159128733764378], AbsoluteThickness[0.5], 
     LineBox[{{6.141316224293418, -1.8963876196907001`}, {
      6.137011277797102, -1.8989182429969074`}}]}, 
    {Hue[0.5160973324126866], AbsoluteThickness[0.5], 
     LineBox[{{6.137011277797102, -1.8989182429969074`}, {
      5.930221352069838, -2.022155952212378}}]}, 
    {Hue[0.6618142691420259], AbsoluteThickness[0.5], 
     LineBox[{{4.909899322736532, -0.39632633971432635`}, {
      4.826113860211855, -0.35923044026463574`}}]}, 
    {Hue[0.6620844240225648], AbsoluteThickness[0.5], 
     LineBox[{{4.826113860211855, -0.35923044026463574`}, {
      4.561283549930273, -0.227086100596803}}]}, 
    {Hue[0.6673954219028049], AbsoluteThickness[0.5], 
     LineBox[{{6.362812811651092, 1.5853767994063988`}, {6.367294364003814, 
      1.5983522727364021`}}]}, 
    {Hue[0.6688675619365666], AbsoluteThickness[0.5], 
     LineBox[{{6.367294364003814, 1.5983522727364021`}, {6.407879210301261, 
      1.8004025358513511`}}]}, 
    {Hue[0.6136773631907292], AbsoluteThickness[0.5], 
     LineBox[{{7.076721279197129, 2.116419354507405}, {7.078080013573787, 
      2.1759753661073877`}}]}, 
    {Hue[0.6147202376350033], AbsoluteThickness[0.5], 
     LineBox[{{7.078080013573787, 2.1759753661073877`}, {7.1079055127338115`, 
      2.388170150014077}}]}, 
    {Hue[0.5049074186858187], AbsoluteThickness[0.5], 
     LineBox[{{3.3223761266728817`, 0.45320832530609795`}, {
      3.1763382067299815`, 0.4876034430521933}}]}, 
    {Hue[0.5050949350574642], AbsoluteThickness[0.5], 
     LineBox[{{3.1763382067299815`, 0.4876034430521933}, {2.8863540324988484`,
       0.559232777351813}}]}, 
    {Hue[0.5762212381507845], AbsoluteThickness[0.5], 
     LineBox[{{4.5046753581612275`, -1.1223702829451243`}, {
      4.415850647724226, -1.2065811131300719`}}]}, 
    {Hue[0.5767000682568179], AbsoluteThickness[0.5], 
     LineBox[{{4.415850647724226, -1.2065811131300719`}, {
      4.2133081495809765`, -1.3706139949046245`}}]}, 
    {Hue[0.6212387935789154], AbsoluteThickness[0.5], 
     LineBox[{{5.532598262384877, -2.126137966057005}, {
      5.5055179968266055`, -2.312780313975175}}]}, 
    {Hue[0.6214232737306868], AbsoluteThickness[0.5], 
     LineBox[{{5.5055179968266055`, -2.312780313975175}, {
      5.458210494903547, -2.6254920219548468`}}]}, 
    {Hue[0.6702665959184583], AbsoluteThickness[0.5], 
     LineBox[{{6.558502686551672, -1.1361041517412096`}, {
      6.641624614133751, -1.2508878463061588`}}]}, 
    {Hue[0.6706638554501804], AbsoluteThickness[0.5], 
     LineBox[{{6.641624614133751, -1.2508878463061588`}, {
      6.796596113038852, -1.4367323507430918`}}]}, 
    {Hue[0.6862154417676454], AbsoluteThickness[0.5], 
     LineBox[{{5.7072547024128575`, 1.4150411308714208`}, {5.655358674577875, 
      1.4810432047924222`}}]}, 
    {Hue[0.6864629305685152], AbsoluteThickness[0.5], 
     LineBox[{{5.655358674577875, 1.4810432047924222`}, {5.507576983832616, 
      1.6542440114158796`}}]}, 
    {Hue[0.6479529858894728], AbsoluteThickness[0.5], 
     LineBox[{{7.001660413572281, 1.6459442831685513`}, {7.003201024612557, 
      1.9257747184821181`}}]}, 
    {Hue[0.6481615753217226], AbsoluteThickness[0.5], 
     LineBox[{{7.003201024612557, 1.9257747184821181`}, {6.9982269963100165`, 
      2.1711805332934513`}}]}, 
    {Hue[0.4919408433712925], AbsoluteThickness[0.5], 
     LineBox[{{7.523807089318023, -1.1364673427704632`}, {
      7.578043295185931, -1.389808408822895}}]}, 
    {Hue[0.4928004098284846], AbsoluteThickness[0.5], 
     LineBox[{{7.578043295185931, -1.389808408822895}, {
      7.601329198023765, -1.6135517013908613`}}]}, 
    {Hue[0.5747580160296695], AbsoluteThickness[0.5], 
     LineBox[{{8.129580112651137, -0.3380120252934028}, {
      8.112982644365966, -0.7014769110622621}}]}, 
    {Hue[0.5814059178794988], AbsoluteThickness[0.5], 
     LineBox[{{8.112982644365966, -0.7014769110622621}, {
      8.144168730365307, -0.8780716570571427}}]}, 
    {Hue[0.5765358396959331], AbsoluteThickness[0.5], 
     LineBox[{{8.400837322111133, -0.12973264472074342`}, {8.41846620837065, 
      1.152756908452858}}]}, 
    {Hue[0.5771381486834298], AbsoluteThickness[0.5], 
     LineBox[{{8.41846620837065, 1.152756908452858}, {8.397711101966816, 
      1.425990015523278}}]}, 
    {Hue[0.6927839788574437], AbsoluteThickness[0.5], 
     LineBox[{{7.380663139819714, -0.09125414151794078}, {7.153035130388449, 
      0.03280620533953821}}]}, 
    {Hue[0.6930316895977522], AbsoluteThickness[0.5], 
     LineBox[{{7.153035130388449, 0.03280620533953821}, {6.9578493651101825`, 
      0.12924088828540214`}}]}, 
    {Hue[0.49708786393436966`], AbsoluteThickness[0.5], 
     LineBox[{{8.080195487154919, 0.6661707831798577}, {8.087933797518698, 
      0.6801485323010795}}]}, 
    {Hue[0.4973520261985351], AbsoluteThickness[0.5], 
     LineBox[{{8.087933797518698, 0.6801485323010795}, {8.246315232740649, 
      0.938381580360709}}]}, 
    {Hue[0.6491260888453158], AbsoluteThickness[0.5], 
     LineBox[{{5.825637039936708, -0.5234217821511212}, {
      5.652425320378326, -0.5853602408820765}}]}, 
    {Hue[0.6495160272978657], AbsoluteThickness[0.5], 
     LineBox[{{5.652425320378326, -0.5853602408820765}, {
      5.388581737806026, -0.6601193636767255}}]}, 
    {Hue[0.687176431249012], AbsoluteThickness[0.5], 
     LineBox[{{5.091004786913011, 0.7337025154327036}, {4.850167520404469, 
      0.8353921946611623}}]}, 
    {Hue[0.692941233926949], AbsoluteThickness[0.5], 
     LineBox[{{4.850167520404469, 0.8353921946611623}, {4.690582381629045, 
      0.865765952717761}}]}, 
    {Hue[0.4376906174336321], AbsoluteThickness[0.5], 
     LineBox[{{6.881191250877583, -0.8861829153964238}, {
      6.880779105955508, -0.8939636586819787}}]}, 
    {Hue[0.4380384890739319], AbsoluteThickness[0.5], 
     LineBox[{{6.880779105955508, -0.8939636586819787}, {
      6.882842248520935, -1.1463896616883769`}}]}, 
    {Hue[0.43424765711991287`], AbsoluteThickness[0.5], 
     LineBox[{{7.331543225782122, -0.40876767013290327`}, {
      7.335812371414638, -0.42283003841443123`}}]}, 
    {Hue[0.4351667863866012], AbsoluteThickness[0.5], 
     LineBox[{{7.335812371414638, -0.42283003841443123`}, {
      7.4207183716486735`, -0.620736054269777}}]}, 
    {Hue[0.42147823688607794`], AbsoluteThickness[0.5], 
     LineBox[{{7.548191576253571, 0.30072193789939994`}, {7.581851068272584, 
      0.2082720020311536}}]}, 
    {Hue[0.42719366791909], AbsoluteThickness[0.5], 
     LineBox[{{7.581851068272584, 0.2082720020311536}, {7.675336249011812, 
      0.05918582749291684}}]}, 
    {Hue[0.6202700579100957], AbsoluteThickness[0.5], 
     LineBox[{{7.675336249011812, 0.05918582749291684}, {7.850782598441062, 
      0.07277791814304135}}]}, 
    {Hue[0.4597882009861834], AbsoluteThickness[0.5], 
     LineBox[{{7.055504511607546, 1.1912081890792554`}, {6.983547199606125, 
      1.1459838153379867`}}]}, 
    {Hue[0.4645246867044957], AbsoluteThickness[0.5], 
     LineBox[{{6.983547199606125, 1.1459838153379867`}, {6.863324853607964, 
      1.031608164437147}}]}, 
    {Hue[0.6710585844882619], AbsoluteThickness[0.5], 
     LineBox[{{6.863324853607964, 1.031608164437147}, {6.914027006419358, 
      0.8736066021139147}}]}, 
    {Hue[0.31748413998614466`], AbsoluteThickness[0.5], 
     LineBox[{{7.590368247538926, 1.7369085399029403`}, {7.503845818473073, 
      1.867324869727871}}]}, 
    {Hue[0.3177901017046031], AbsoluteThickness[0.5], 
     LineBox[{{7.503845818473073, 1.867324869727871}, {7.346007987984193, 
      2.1354637918059716`}}]}, 
    {Hue[0.025367490426489822`], AbsoluteThickness[0.5], 
     LineBox[{{7.738157029364659, 1.911472297130765}, {8.066377499692184, 
      2.2089179863153836`}}]}, 
    {Hue[0.025643923959250723`], AbsoluteThickness[0.5], 
     LineBox[{{8.066377499692184, 2.2089179863153836`}, {8.279619357017198, 
      2.3844659508650694`}}]}, 
    {Hue[0.4407831060614114], AbsoluteThickness[0.5], 
     LineBox[{{8.279619357017198, 2.3844659508650694`}, {8.269418053371558, 
      2.1084494459656544`}}]}, 
    {Hue[0.3202989820311785], AbsoluteThickness[0.5], 
     LineBox[{{7.932904742021405, 1.7915249845889867`}, {8.353376858084014, 
      1.4486758481567938`}}]}, 
    {Hue[0.32533513194332486`], AbsoluteThickness[0.5], 
     LineBox[{{8.353376858084014, 1.4486758481567938`}, {8.471556087494077, 
      1.3036155224815655`}}]}, 
    {Hue[0.5274649970776821], AbsoluteThickness[0.5], 
     LineBox[{{8.471556087494077, 1.3036155224815655`}, {8.394212442133696, 
      1.133243022143843}}]}, 
    {Hue[0.6152304736358671], AbsoluteThickness[0.5], 
     LineBox[{{7.843510263820795, 1.5809955172019488`}, {7.742433758337944, 
      1.4098870680789055`}}]}, 
    {Hue[0.6159456033424616], AbsoluteThickness[0.5], 
     LineBox[{{7.742433758337944, 1.4098870680789055`}, {7.6564143033686465`, 
      1.2250070433451765`}}]}, 
    {Hue[0.4602526551553895], AbsoluteThickness[0.5], 
     LineBox[{{7.464985043809726, 0.8755865366445774}, {7.449521888375906, 
      0.6445117044053194}}]}, 
    {Hue[0.4604429862442912], AbsoluteThickness[0.5], 
     LineBox[{{7.449521888375906, 0.6445117044053194}, {7.430375912009466, 
      0.283208622726918}}]}, 
    {Hue[0.42203802679026925`], AbsoluteThickness[0.5], 
     LineBox[{{6.051399004163451, 1.2658168799102762`}, {5.9381947141431874`, 
      1.2479646951500007`}}]}, 
    {Hue[0.42222668843255806`], AbsoluteThickness[0.5], 
     LineBox[{{5.9381947141431874`, 1.2479646951500007`}, {5.585010064392459, 
      1.196668184852395}}]}, 
    {Hue[0.43358891681588546`], AbsoluteThickness[0.5], 
     LineBox[{{5.348678083172981, 0.9374527928655113}, {5.146843271438939, 
      0.915336947551428}}]}, 
    {Hue[0.4340007012995938], AbsoluteThickness[0.5], 
     LineBox[{{5.146843271438939, 0.915336947551428}, {4.869019545342316, 
      0.9045133912008863}}]}, 
    {Hue[0.43311611845378506`], AbsoluteThickness[0.5], 
     LineBox[{{4.363292513720586, 1.1077631715094527`}, {4.180835378956244, 
      1.1009827641266325`}}]}, 
    {Hue[0.4333445839561757], AbsoluteThickness[0.5], 
     LineBox[{{4.180835378956244, 1.1009827641266325`}, {3.8802831926153463`, 
      1.0795703200884155`}}]}, 
    {Hue[0.688953886029674], AbsoluteThickness[0.5], 
     LineBox[{{6.544058705200856, -1.1397096353662313`}, {
      6.585515200998242, -1.3922282078274029`}}]}, 
    {Hue[0.6892516507413502], AbsoluteThickness[0.5], 
     LineBox[{{6.585515200998242, -1.3922282078274029`}, {
      6.613447268885137, -1.6437226269738707`}}]}, 
    {Hue[0.4679220151075357], AbsoluteThickness[0.5], 
     LineBox[{{7.023459793219201, 2.629803328498619}, {7.10368184781019, 
      2.848736495535804}}]}, 
    {Hue[0.46876575414087157`], AbsoluteThickness[0.5], 
     LineBox[{{7.10368184781019, 2.848736495535804}, {7.1516229963101905`, 
      3.04052253545903}}]}, 
    {Hue[0.5174652094073487], AbsoluteThickness[0.5], 
     LineBox[{{6.42157587195393, 2.311129214326098}, {6.428421427838424, 
      2.3501891946211466`}}]}, 
    {Hue[0.5176494256577343], AbsoluteThickness[0.5], 
     LineBox[{{6.428421427838424, 2.3501891946211466`}, {6.488034289750155, 
      2.6797783985379304`}}]}, 
    {Hue[0.2602380667026444], AbsoluteThickness[0.5], 
     LineBox[{{5.105130303168906, 2.32777283886906}, {4.973860009185009, 
      2.4233855638274715`}}]}, 
    {Hue[0.3322808036134718], AbsoluteThickness[0.5], 
     LineBox[{{4.973860009185009, 2.4233855638274715`}, {4.911576044151911, 
      2.523739366932794}}]}, 
    {Hue[0.36760495400987975`], AbsoluteThickness[0.5], 
     LineBox[{{4.911576044151911, 2.523739366932794}, {4.949638783966609, 
      2.6355490531667902`}}]}, 
    {Hue[0.40292910440629226`], AbsoluteThickness[0.5], 
     LineBox[{{4.949638783966609, 2.6355490531667902`}, {5.0602158577717615`, 
      2.677056749400575}}]}, 
    {Hue[0.4382532548027083], AbsoluteThickness[0.5], 
     LineBox[{{5.0602158577717615`, 2.677056749400575}, {5.162450707646214, 
      2.6179110515934285`}}]}, 
    {Hue[0.4735774051991283], AbsoluteThickness[0.5], 
     LineBox[{{5.162450707646214, 2.6179110515934285`}, {5.18158680607505, 
      2.5013606855070525`}}]}, 
    {Hue[0.5089015555955544], AbsoluteThickness[0.5], 
     LineBox[{{5.18158680607505, 2.5013606855070525`}, {5.1036313876707275`, 
      2.412630020912711}}]}, 
    {Hue[0.544225705991988], AbsoluteThickness[0.5], 
     LineBox[{{5.1036313876707275`, 2.412630020912711}, {4.985587288433265, 
      2.416601007334562}}]}, 
    {Hue[0.579549856388428], AbsoluteThickness[0.5], 
     LineBox[{{4.985587288433265, 2.416601007334562}, {4.913771130957169, 
      2.5103699660752623`}}]}, 
    {Hue[0.6148740067848706], AbsoluteThickness[0.5], 
     LineBox[{{4.913771130957169, 2.5103699660752623`}, {4.9406965792129025`, 
      2.6253708283945265`}}]}, 
    {Hue[0.6501981571813187], AbsoluteThickness[0.5], 
     LineBox[{{4.9406965792129025`, 2.6253708283945265`}, {5.046675111958901, 
      2.677512258130888}}]}, 
    {Hue[0.685522307577775], AbsoluteThickness[0.5], 
     LineBox[{{5.046675111958901, 2.677512258130888}, {5.154212732686672, 
      2.6286672151259234`}}]}, 
    {Hue[0.5253630827492372], AbsoluteThickness[0.5], 
     LineBox[{{4.851961525503718, 0.934645522777102}, {4.424351740191631, 
      0.7706489542266817}}]}, 
    {Hue[0.5255613344981609], AbsoluteThickness[0.5], 
     LineBox[{{4.424351740191631, 0.7706489542266817}, {4.1188388464948025`, 
      0.6604338486612473}}]}, 
    {Hue[0.5844857240694302], AbsoluteThickness[0.5], 
     LineBox[{{5.518103669062487, 1.1512149591504777`}, {5.398525796497053, 
      1.2200248889577248`}}]}, 
    {Hue[0.5847455769986512], AbsoluteThickness[0.5], 
     LineBox[{{5.398525796497053, 1.2200248889577248`}, {5.143855725421484, 
      1.3816868608239041`}}]}, 
    {Hue[0.5186639834024973], AbsoluteThickness[0.5], 
     LineBox[{{5.461139648466303, 1.1443863509174352`}, {5.3780326268083885`, 
      1.1592845253399489`}}]}, 
    {Hue[0.5189028552871202], AbsoluteThickness[0.5], 
     LineBox[{{5.3780326268083885`, 1.1592845253399489`}, {5.072201536619233, 
      1.2023600096651306`}}]}, 
    {Hue[0.6249632781207611], AbsoluteThickness[0.5], 
     LineBox[{{5.409836078855042, 1.1187061391187512`}, {5.327993242796761, 
      1.1048759326021627`}}]}, 
    {Hue[0.6959517463520205], AbsoluteThickness[0.5], 
     LineBox[{{5.900457870164396, -0.10167967351866608`}, {
      5.924279037284031, -0.35385045836149054`}}]}, 
    {Hue[0.6961414091004194], AbsoluteThickness[0.5], 
     LineBox[{{5.924279037284031, -0.35385045836149054`}, {
      5.953065952582621, -0.6208304854292546}}]}, 
    {Hue[0.6890341143784967], AbsoluteThickness[0.5], 
     LineBox[{{7.5649167357676115`, -0.1860555186724132}, {
      7.598560623249983, -0.21481323580048364`}}]}, 
    {Hue[0.6893709823557921], AbsoluteThickness[0.5], 
     LineBox[{{7.598560623249983, -0.21481323580048364`}, {
      7.8015864440438545`, -0.3685024860381718}}]}, 
    {Hue[0.4777692609431078], AbsoluteThickness[0.5], 
     LineBox[{{4.338030659768891, 1.0456952774415846`}, {4.184804334084109, 
      1.0900086345508422`}}]}, 
    {Hue[0.4781248255911532], AbsoluteThickness[0.5], 
     LineBox[{{4.184804334084109, 1.0900086345508422`}, {3.9180161944865612`, 
      1.1494482120242693`}}]}, 
    {Hue[0.46444678191903543`], AbsoluteThickness[0.5], 
     LineBox[{{3.6682505014656734`, -1.260811247870144}, {
      3.515237747523003, -1.3299214132440937`}}]}, 
    {Hue[0.4684273732926392], AbsoluteThickness[0.5], 
     LineBox[{{3.515237747523003, -1.3299214132440937`}, {
      3.3631369823812154`, -1.436960415300968}}]}, 
    {Hue[0.6874887040176209], AbsoluteThickness[0.5], 
     LineBox[{{3.3631369823812154`, -1.436960415300968}, {
      3.3994379955641585`, -1.6193726603941647`}}]}, 
    {Hue[0.5740766113294524], AbsoluteThickness[0.5], 
     LineBox[{{3.8700807173829546`, 1.4673964527622854`}, {
      3.8010335980801604`, 1.619771714514598}}]}, 
    {Hue[0.5742796095228011], AbsoluteThickness[0.5], 
     LineBox[{{3.8010335980801604`, 1.619771714514598}, {3.6764578941698423`, 
      1.912287471595425}}]}, 
    {Hue[0.5263717792892463], AbsoluteThickness[0.5], 
     LineBox[{{7.379052243606461, 0.6990117450102403}, {7.634981857793197, 
      0.8273299019140062}}]}, 
    {Hue[0.527268363976714], AbsoluteThickness[0.5], 
     LineBox[{{7.634981857793197, 0.8273299019140062}, {7.8600772293281915`, 
      0.9108912178091552}}]}, 
    {Hue[0.561944934685353], AbsoluteThickness[0.5], 
     LineBox[{{4.842566133514247, 1.440068636143774}, {4.720940674311308, 
      1.5505265746309072`}}]}, 
    {Hue[0.5626070442225681], AbsoluteThickness[0.5], 
     LineBox[{{4.720940674311308, 1.5505265746309072`}, {4.563509470794093, 
      1.7232149979237499`}}]}, 
    {Hue[0.664192340314965], AbsoluteThickness[0.5], 
     LineBox[{{4.588794290327433, 0.7038109943929166}, {4.405729173165847, 
      0.664674750076516}}]}, 
    {Hue[0.6646866149257066], AbsoluteThickness[0.5], 
     LineBox[{{4.405729173165847, 0.664674750076516}, {4.1420754931227135`, 
      0.6299410302479087}}]}, 
    {Hue[0.6993649144443158], AbsoluteThickness[0.5], 
     LineBox[{{5.0400177056328745`, -0.6635405089458228}, {
      4.818081978692056, -1.098864073309862}}]}, 
    {Hue[0.699579005824027], AbsoluteThickness[0.5], 
     LineBox[{{4.818081978692056, -1.098864073309862}, {
      4.6730830867006965`, -1.3644129827131524`}}]}, 
    {Hue[0.6887266838743075], AbsoluteThickness[0.5], 
     LineBox[{{7.021149725198444, -0.07154571447836386}, {
      7.098059280499725, -0.2388328067404872}}]}, 
    {Hue[0.6894456584467059], AbsoluteThickness[0.5], 
     LineBox[{{7.098059280499725, -0.2388328067404872}, {
      7.212311557604752, -0.4341530931148644}}]}, 
    {Hue[0.46505065909369914`], AbsoluteThickness[0.5], 
     LineBox[{{5.728774910946679, 2.3223324043258624`}, {5.6539520195670985`, 
      2.4117933223224775`}}]}, 
    {Hue[0.4652587496868688], AbsoluteThickness[0.5], 
     LineBox[{{5.6539520195670985`, 2.4117933223224775`}, {5.435909779053422, 
      2.6593680888455133`}}]}, 
    {Hue[0.5930274202780242], AbsoluteThickness[0.5], 
     LineBox[{{6.6258440355301405`, 1.8689699323790148`}, {6.697475812834526, 
      1.8279146946195524`}}]}, 
    {Hue[0.5933592644450042], AbsoluteThickness[0.5], 
     LineBox[{{6.697475812834526, 1.8279146946195524`}, {6.8978100437530285`, 
      1.696982269817469}}]}, 
    {Hue[0.6577175357163025], AbsoluteThickness[0.5], 
     LineBox[{{6.472040952293647, 2.3458184217531763`}, {6.577898380087658, 
      2.1413614120070266`}}]}, 
    {Hue[0.6584798671866862], AbsoluteThickness[0.5], 
     LineBox[{{6.577898380087658, 2.1413614120070266`}, {6.665193389335898, 
      1.9205603235213684`}}]}, 
    {Hue[0.24005644035595503`], AbsoluteThickness[0.5], 
     LineBox[{{6.583810886957185, 2.633564846050262}, {6.585555138189024, 
      2.638730032428786}}]}, 
    {Hue[0.2404243094976745], AbsoluteThickness[0.5], 
     LineBox[{{6.585555138189024, 2.638730032428786}, {6.692367912281009, 
      2.8987001271996897`}}]}, 
    {Hue[0.634404547882252], AbsoluteThickness[0.5], 
     LineBox[{{6.692367912281009, 2.8987001271996897`}, {6.872093610858287, 
      2.6826165966951008`}}]}, 
    {Hue[0.6582480819001432], AbsoluteThickness[0.5], 
     LineBox[{{6.299114145669607, 2.5142405463846695`}, {6.215984381681101, 
      2.4749307830443343`}}]}, 
    {Hue[0.6585524986519019], AbsoluteThickness[0.5], 
     LineBox[{{6.215984381681101, 2.4749307830443343`}, {5.939781396097772, 
      2.361951907883309}}]}, 
    {Hue[0.5945011367519799], AbsoluteThickness[0.5], 
     LineBox[{{5.8856226064772645`, 2.454866553037327}, {5.683048452564097, 
      2.531613486608514}}]}, 
    {Hue[0.5947909769902558], AbsoluteThickness[0.5], 
     LineBox[{{5.683048452564097, 2.531613486608514}, {5.391351704172249, 
      2.625593379193287}}]}, 
    {Hue[0.4705833090370725], AbsoluteThickness[0.5], 
     LineBox[{{7.354603703684484, 1.6013214427552687`}, {7.356213552333505, 
      1.6010458639601983`}}]}, 
    {Hue[0.4708403963871997], AbsoluteThickness[0.5], 
     LineBox[{{7.356213552333505, 1.6010458639601983`}, {7.653693099468152, 
      1.5369387176341482`}}]}, 
    {Hue[0.6655593416449881], AbsoluteThickness[0.5], 
     LineBox[{{5.161374580802137, 0.6278061110068232}, {5.155851148044681, 
      0.62117069692608}}]}, 
    {Hue[0.6657844107845858], AbsoluteThickness[0.5], 
     LineBox[{{5.155851148044681, 0.62117069692608}, {4.963243164986898, 
      0.40461823168334243`}}]}, 
    {Hue[0.5278458725343387], AbsoluteThickness[0.5], 
     LineBox[{{7.929742957745927, 0.6652030754613594}, {7.943743831431117, 
      0.6599192684195407}}]}, 
    {Hue[0.5283807428955818], AbsoluteThickness[0.5], 
     LineBox[{{7.943743831431117, 0.6599192684195407}, {8.18182694304322, 
      0.5465277883779298}}]}, 
    {Hue[0.5214595315105676], AbsoluteThickness[0.5], 
     LineBox[{{3.934429269750753, 1.1647759852781359`}, {3.8711843852292245`, 
      1.1630018869658185`}}]}, 
    {Hue[0.5236627917267364], AbsoluteThickness[0.5], 
     LineBox[{{3.8711843852292245`, 1.1630018869658185`}, {3.693844003873882, 
      1.1857485126662142`}}]}, 
    {Hue[0.691007495369889], AbsoluteThickness[0.5], 
     LineBox[{{4.201877408545196, 2.010677723111943}, {4.220711907001162, 
      2.085100957738307}}]}, 
    {Hue[0.6911969250385411], AbsoluteThickness[0.5], 
     LineBox[{{4.220711907001162, 2.085100957738307}, {4.2970211362664825`, 
      2.4039905965296344`}}]}, 
    {Hue[0.44303398466977356`], AbsoluteThickness[0.5], 
     LineBox[{{4.055325171769849, 2.140045002997775}, {3.8070783438029028`, 
      2.2959531760368335`}}]}, 
    {Hue[0.44751609833477957`], AbsoluteThickness[0.5], 
     LineBox[{{3.8070783438029028`, 2.2959531760368335`}, {3.675134321503202, 
      2.346331015390589}}]}, 
    {Hue[0.6580203034226719], AbsoluteThickness[0.5], 
     LineBox[{{3.675134321503202, 2.346331015390589}, {3.573380697926003, 
      2.248385357970332}}]}, 
    {Hue[0.6959990790954194], AbsoluteThickness[0.5], 
     LineBox[{{3.8871266030435763`, 2.040432289515257}, {3.7699581791501924`, 
      1.9423212098599785`}}]}, 
    {Hue[0.6968592280590287], AbsoluteThickness[0.5], 
     LineBox[{{3.7699581791501924`, 1.9423212098599785`}, {3.608033170338925, 
      1.7741434996327017`}}]}, 
    {Hue[0.6583711630110451], AbsoluteThickness[0.5], 
     LineBox[{{2.7442304120272185`, -0.9084906570121896}, {
      2.6368300877082387`, -0.932727835487602}}]}, 
    {Hue[0.6586057814156067], AbsoluteThickness[0.5], 
     LineBox[{{2.6368300877082387`, -0.932727835487602}, {
      2.30918847720457, -1.0191991468394757`}}]}, 
    {Hue[0.6679264976129351], AbsoluteThickness[0.5], 
     LineBox[{{3.9103644313012382`, -2.63264420570771}, {
      3.8531464172669496`, -2.667180887666956}}]}, 
    {Hue[0.6681097437399902], AbsoluteThickness[0.5], 
     LineBox[{{3.8531464172669496`, -2.667180887666956}, {
      3.589108696355187, -2.8258811301481175`}}]}, 
    {Hue[0.6923606738953701], AbsoluteThickness[0.5], 
     LineBox[{{5.275954050371112, -2.8917611585853704`}, {
      5.232309234713183, -3.089513230492525}}]}, 
    {Hue[0.692585630329682], AbsoluteThickness[0.5], 
     LineBox[{{5.232309234713183, -3.089513230492525}, {
      5.172461097552453, -3.4101727141824996`}}]}, 
    {Hue[0.6409737424324078], AbsoluteThickness[0.5], 
     LineBox[{{6.402864922916759, -3.1706687047615048`}, {
      6.477872133810045, -3.3062105155783237`}}]}, 
    {Hue[0.6412500308368768], AbsoluteThickness[0.5], 
     LineBox[{{6.477872133810045, -3.3062105155783237`}, {
      6.601170038740591, -3.55634550583027}}]}, 
    {Hue[0.519625745398351], AbsoluteThickness[0.5], 
     LineBox[{{7.065516021771263, -2.5757373891090496`}, {
      7.330498288687872, -2.5789224955651515`}}]}, 
    {Hue[0.5198330733871872], AbsoluteThickness[0.5], 
     LineBox[{{7.330498288687872, -2.5789224955651515`}, {
      7.638935893568386, -2.5748739356299155`}}]}, 
    {Hue[0.6618026272584283], AbsoluteThickness[0.5], 
     LineBox[{{7.907913549349928, -1.128131966537967}, {
      7.925750905818889, -1.1176724675766507`}}]}, 
    {Hue[0.6619922582895007], AbsoluteThickness[0.5], 
     LineBox[{{7.925750905818889, -1.1176724675766507`}, {
      8.17711503024882, -0.9657857867526604}}]}, 
    {Hue[0.67687746930535], AbsoluteThickness[0.5], 
     LineBox[{{7.9396332096186235`, -1.3113566863266601`}, {
      8.12417255435784, -1.2896757064740478`}}]}, 
    {Hue[0.6770974429150209], AbsoluteThickness[0.5], 
     LineBox[{{8.12417255435784, -1.2896757064740478`}, {
      8.40513098295746, -1.2478631540215561`}}]}, 
    {Hue[0.4734503482441496], AbsoluteThickness[0.5], 
     LineBox[{{2.195908819104282, -1.8418698879684676`}, {
      2.1672204988726462`, -1.8549278598035843`}}]}, 
    {Hue[0.4736428341559922], AbsoluteThickness[0.5], 
     LineBox[{{2.1672204988726462`, -1.8549278598035843`}, {
      1.8631456608056345`, -1.9991716919118454`}}]}, 
    {Hue[0.6678097874955625], AbsoluteThickness[0.5], 
     LineBox[{{5.507286540201194, 2.678637279603003}, {5.573136455120478, 
      2.6991648220460918`}}]}, 
    {Hue[0.6680341883831429], AbsoluteThickness[0.5], 
     LineBox[{{5.573136455120478, 2.6991648220460918`}, {5.859102310574856, 
      2.798613824550409}}]}, 
    {Hue[0.6601343049651187], AbsoluteThickness[0.5], 
     LineBox[{{2.0728522647269667`, 3.096887373596184}, {2.0379501329067837`, 
      3.357334989361348}}]}, 
    {Hue[0.660320002129691], AbsoluteThickness[0.5], 
     LineBox[{{2.0379501329067837`, 3.357334989361348}, {2.0003485458539485`, 
      3.6568472194308046`}}]}, 
    {Hue[0.6080547471754114], AbsoluteThickness[0.5], 
     LineBox[{{4.16312011496545, -3.0916553002213503`}, {
      4.204481116344392, -3.110912839801599}}]}, 
    {Hue[0.6099078101493184], AbsoluteThickness[0.5], 
     LineBox[{{4.204481116344392, -3.110912839801599}, {
      4.346900401770584, -3.2046491384338243`}}]}, 
    {Hue[0.6959454304058906], AbsoluteThickness[0.5], 
     LineBox[{{4.4193349084766895`, -1.7443209047785018`}, {
      4.617159875700941, -1.7671299287408804`}}]}, 
    {Hue[0.6962635048663651], AbsoluteThickness[0.5], 
     LineBox[{{4.617159875700941, -1.7671299287408804`}, {
      4.8834535086676665`, -1.782800960434623}}]}, 
    {Hue[0.6901874836647306], AbsoluteThickness[0.5], 
     LineBox[{{3.45669261763965, 2.226579398023197}, {3.5395831023513624`, 
      2.3579201842494855`}}]}, 
    {Hue[0.6916599998434991], AbsoluteThickness[0.5], 
     LineBox[{{3.5395831023513624`, 2.3579201842494855`}, {
      3.6246736316529993`, 2.5441255502263878`}}]}, 
    {Hue[0.41260507676792313`], AbsoluteThickness[0.5], 
     LineBox[{{3.332308243559459, 2.3879252482139632`}, {3.2156463427626463`, 
      2.5015423567450736`}}]}, 
    {Hue[0.41320616712027786`], AbsoluteThickness[0.5], 
     LineBox[{{3.2156463427626463`, 2.5015423567450736`}, {2.990766656968944, 
      2.68440669863797}}]}, 
    {Hue[0.693591019837403], AbsoluteThickness[0.5], 
     LineBox[{{3.1486487051213468`, 2.299759893171285}, {2.610436075581841, 
      1.9398455583721346`}}]}, 
    {Hue[0.6942038996049005], AbsoluteThickness[0.5], 
     LineBox[{{2.610436075581841, 1.9398455583721346`}, {2.427325078483299, 
      1.8400499517806694`}}]}, 
    {Hue[0.6873489876597073], AbsoluteThickness[0.5], 
     LineBox[{{4.888010749790684, 2.239795602771776}, {5.352094276162099, 
      2.5575525177369407`}}]}, 
    {Hue[0.6882519096958704], AbsoluteThickness[0.5], 
     LineBox[{{5.352094276162099, 2.5575525177369407`}, {5.5648705308709445`, 
      2.67124674879148}}]}, 
    {Hue[0.6119975273299152], AbsoluteThickness[0.5], 
     LineBox[{{3.4125453660218863`, -0.8593377419620716}, {
      3.353904435352324, -0.8641742816307323}}]}, 
    {Hue[0.6123551851061675], AbsoluteThickness[0.5], 
     LineBox[{{3.353904435352324, -0.8641742816307323}, {
      3.0780660610831423`, -0.8695988186114041}}]}, 
    {Hue[0.6625189907801041], AbsoluteThickness[0.5], 
     LineBox[{{3.422089061304332, -1.0631783556271799`}, {
      3.093326910640336, -1.0721338202571287`}}]}, 
    {Hue[0.6628788383336387], AbsoluteThickness[0.5], 
     LineBox[{{3.093326910640336, -1.0721338202571287`}, {
      2.844101538872602, -1.0632252089375354`}}]}, 
    {Hue[0.6884640034915684], AbsoluteThickness[0.5], 
     LineBox[{{4.9164044126609205`, 0.6481537547206977}, {4.891964282972589, 
      0.6622910721049998}}]}, 
    {Hue[0.6886557200696338], AbsoluteThickness[0.5], 
     LineBox[{{4.891964282972589, 0.6622910721049998}, {4.620435270414352, 
      0.8139180346299864}}]}, 
    {Hue[0.5141908301833282], AbsoluteThickness[0.5], 
     LineBox[{{8.150256002333505, 0.05231239248044925}, {8.164078058226643, 
      0.069870449653405}}]}, 
    {Hue[0.5144030781743217], AbsoluteThickness[0.5], 
     LineBox[{{8.164078058226643, 0.069870449653405}, {8.347403889598631, 
      0.3164039243675053}}]}, 
    {Hue[0.6341199259003604], AbsoluteThickness[0.5], 
     LineBox[{{7.574921277472411, 0.0874755916513075}, {7.596749065410667, 
      0.14135927252437472`}}]}, 
    {Hue[0.6346930119895756], AbsoluteThickness[0.5], 
     LineBox[{{7.596749065410667, 0.14135927252437472`}, {7.71725703465744, 
      0.3774451573715266}}]}, 
    {Hue[0.6615019531162158], AbsoluteThickness[0.5], 
     LineBox[{{7.093124318394603, -0.6399737634313856}, {
      7.067044428207292, -0.5757241701134088}}]}, 
    {Hue[0.6617274190184294], AbsoluteThickness[0.5], 
     LineBox[{{7.067044428207292, -0.5757241701134088}, {
      6.939023855942025, -0.28788288655888045`}}]}, 
    {Hue[0.6259140868635626], AbsoluteThickness[0.5], 
     LineBox[{{7.095556880334739, -1.782516190304264}, {
      6.836140707000324, -1.8165518686022184`}}]}, 
    {Hue[0.6263505833498814], AbsoluteThickness[0.5], 
     LineBox[{{6.836140707000324, -1.8165518686022184`}, {
      6.603624631246455, -1.8298685568134114`}}]}, 
    {Hue[0.5739952726468333], AbsoluteThickness[0.5], 
     LineBox[{{7.863139321655691, -1.9772863051707465`}, {
      7.7142040229293976`, -2.10792373154992}}]}, 
    {Hue[0.577434963365626], AbsoluteThickness[0.5], 
     LineBox[{{7.7142040229293976`, -2.10792373154992}, {
      7.608643324015406, -2.241089960054466}}]}, 
    {Hue[0.22081943529798057`], AbsoluteThickness[0.5], 
     LineBox[{{8.022041265246742, -2.1317672179825253`}, {
      8.079759756486173, -2.178409227415667}}]}, 
    {Hue[0.22104765519128958`], AbsoluteThickness[0.5], 
     LineBox[{{8.079759756486173, -2.178409227415667}, {
      8.33682100981092, -2.372116296911316}}]}, 
    {Hue[0.6503849598692252], AbsoluteThickness[0.5], 
     LineBox[{{8.33682100981092, -2.372116296911316}, {
      8.241396205327685, -2.0647126153737987`}}]}, 
    {Hue[0.5752511465854142], AbsoluteThickness[0.5], 
     LineBox[{{8.147211336256754, -1.948883010289454}, {
      8.177544675768603, -1.8944705060288458`}}]}, 
    {Hue[0.5754602909288851], AbsoluteThickness[0.5], 
     LineBox[{{8.177544675768603, -1.8944705060288458`}, {
      8.311903601845028, -1.6379705011059962`}}]}, 
    {Hue[0.6266374975395317], AbsoluteThickness[0.5], 
     LineBox[{{7.981703858840445, -1.3971231822573906`}, {
      8.05729602739823, -1.1730735280725026`}}]}, 
    {Hue[0.6268955292776618], AbsoluteThickness[0.5], 
     LineBox[{{8.05729602739823, -1.1730735280725026`}, {
      8.13369358484671, -0.909805201904108}}]}, 
    {Hue[0.6602436619911174], AbsoluteThickness[0.5], 
     LineBox[{{6.81221724320332, -0.9879310810174107}, {
      6.775781437771898, -0.9434245706739666}}]}, 
    {Hue[0.6606181041967374], AbsoluteThickness[0.5], 
     LineBox[{{6.775781437771898, -0.9434245706739666}, {
      6.631251815124599, -0.7413559237850313}}]}, 
    {Hue[0.6328402147277878], AbsoluteThickness[0.5], 
     LineBox[{{5.603984831371815, -1.169398971513567}, {
      5.574104318307114, -1.1649342600888264`}}]}, 
    {Hue[0.6337535892926707], AbsoluteThickness[0.5], 
     LineBox[{{5.574104318307114, -1.1649342600888264`}, {
      5.35587456765623, -1.1072220852942924`}}]}, 
    {Hue[0.5162817914489355], AbsoluteThickness[0.5], 
     LineBox[{{5.930221352069838, -2.022155952212378}, {
      5.770604205594284, -2.118585400139093}}]}, 
    {Hue[0.5167469321888322], AbsoluteThickness[0.5], 
     LineBox[{{5.770604205594284, -2.118585400139093}, {
      5.56054423222673, -2.2685416838301906`}}]}, 
    {Hue[0.6623545789031038], AbsoluteThickness[0.5], 
     LineBox[{{4.561283549930273, -0.227086100596803}, {
      4.41769083502157, -0.14698272811855934`}}]}, 
    {Hue[0.664283773585477], AbsoluteThickness[0.5], 
     LineBox[{{4.41769083502157, -0.14698272811855936`}, {
      4.212331653106352, -0.06959946598404876}}]}, 
    {Hue[0.6703397019703283], AbsoluteThickness[0.5], 
     LineBox[{{6.407879210301261, 1.8004025358513511`}, {6.412338370545742, 
      1.87009568796768}}]}, 
    {Hue[0.6707658493220177], AbsoluteThickness[0.5], 
     LineBox[{{6.412338370545742, 1.87009568796768}, {6.448658799778517, 
      2.1357213457488884`}}]}, 
    {Hue[0.6157631120792773], AbsoluteThickness[0.5], 
     LineBox[{{7.1079055127338115`, 2.388170150014077}, {7.1101305241034725`, 
      2.3966544690921925`}}]}, 
    {Hue[0.6221301096004125], AbsoluteThickness[0.5], 
     LineBox[{{7.1101305241034725`, 2.3966544690921925`}, {
      7.1162682073205294`, 2.5548130859784597`}}]}, 
    {Hue[0.5052824514291097], AbsoluteThickness[0.5], 
     LineBox[{{2.8863540324988484`, 0.559232777351813}, {2.8356563595576576`, 
      0.5723412860644501}}]}, 
    {Hue[0.5060041375871395], AbsoluteThickness[0.5], 
     LineBox[{{2.8356563595576576`, 0.5723412860644501}, {2.6055738337734273`,
       0.6567341618634729}}]}, 
    {Hue[0.5771788983628513], AbsoluteThickness[0.5], 
     LineBox[{{4.2133081495809765`, -1.3706139949046245`}, {
      4.108618644472275, -1.4426546388240173`}}]}, 
    {Hue[0.577407554975418], AbsoluteThickness[0.5], 
     LineBox[{{4.108618644472275, -1.4426546388240173`}, {
      3.8962224611401854`, -1.5783964706025564`}}]}, 
    {Hue[0.6216077538824583], AbsoluteThickness[0.5], 
     LineBox[{{5.458210494903547, -2.6254920219548468`}, {
      5.407019887660409, -2.9505475865878963`}}]}, 
    {Hue[0.6348630284927477], AbsoluteThickness[0.5], 
     LineBox[{{5.407019887660409, -2.9505475865878963`}, {
      5.421649245250298, -3.0825725534329287`}}]}, 
    {Hue[0.6710611149819025], AbsoluteThickness[0.5], 
     LineBox[{{6.796596113038852, -1.4367323507430918`}, {
      6.821543249800346, -1.4628040299671872`}}]}, 
    {Hue[0.6712976794388542], AbsoluteThickness[0.5], 
     LineBox[{{6.821543249800346, -1.4628040299671872`}, {
      7.016042773262057, -1.6516751997741703`}}]}, 
    {Hue[0.6867104193693847], AbsoluteThickness[0.5], 
     LineBox[{{5.507576983832616, 1.6542440114158796`}, {4.430740033522393, 
      2.8184667495682527`}}]}, 
    {Hue[0.6878515444082649], AbsoluteThickness[0.5], 
     LineBox[{{4.430740033522393, 2.8184667495682527`}, {4.262747380025582, 
      2.9608335378144637`}}]}, 
    {Hue[0.6483701647539724], AbsoluteThickness[0.5], 
     LineBox[{{6.9982269963100165`, 2.1711805332934513`}, {6.991086841474694, 
      2.3261666890661976`}}]}, 
    {Hue[0.6485535135586384], AbsoluteThickness[0.5], 
     LineBox[{{6.991086841474694, 2.3261666890661976`}, {6.976035586645406, 
      2.6360109109681593`}}]}, 
    {Hue[0.49365997628567665`], AbsoluteThickness[0.5], 
     LineBox[{{7.601329198023765, -1.6135517013908613`}, {
      7.600403197491476, -1.8782348697021982`}}]}, 
    {Hue[0.494825148524956], AbsoluteThickness[0.5], 
     LineBox[{{7.600403197491476, -1.8782348697021982`}, {
      7.575596281441464, -2.0742213214166454`}}]}, 
    {Hue[0.5880538197293281], AbsoluteThickness[0.5], 
     LineBox[{{8.144168730365307, -0.8780716570571427}, {
      8.229428519827426, -1.0824469116506141`}}]}, 
    {Hue[0.588250405170094], AbsoluteThickness[0.5], 
     LineBox[{{8.229428519827426, -1.0824469116506141`}, {
      8.336491908698271, -1.3533739219868754`}}]}, 
    {Hue[0.5777404576709264], AbsoluteThickness[0.5], 
     LineBox[{{8.397711101966816, 1.425990015523278}, {8.355766015401802, 
      1.677308046114456}}]}, 
    {Hue[0.5785639353505639], AbsoluteThickness[0.5], 
     LineBox[{{8.355766015401802, 1.677308046114456}, {8.300925599643978, 
      1.8751161064027455`}}]}, 
    {Hue[0.6932794003380606], AbsoluteThickness[0.5], 
     LineBox[{{6.9578493651101825`, 0.12924088828540214`}, {6.888620916030578,
       0.16005448555398563`}}]}, 
    {Hue[0.6934652400544626], AbsoluteThickness[0.5], 
     LineBox[{{6.888620916030578, 0.16005448555398563`}, {6.597317163585998, 
      0.2927098512295937}}]}, 
    {Hue[0.4976161884627007], AbsoluteThickness[0.5], 
     LineBox[{{8.246315232740649, 0.938381580360709}, {8.368445590996329, 
      1.1189421761208362`}}]}, 
    {Hue[0.499207737492153], AbsoluteThickness[0.5], 
     LineBox[{{8.368445590996329, 1.1189421761208362`}, {8.468165047516123, 
      1.3220799330813995`}}]}, 
    {Hue[0.6499059657504158], AbsoluteThickness[0.5], 
     LineBox[{{5.388581737806026, -0.6601193636767255}, {
      5.32799048777566, -0.672957898133279}}]}, 
    {Hue[0.6501676206631687], AbsoluteThickness[0.5], 
     LineBox[{{5.32799048777566, -0.672957898133279}, {
      5.063027041023098, -0.7413790643896072}}]}, 
    {Hue[0.6987060366048861], AbsoluteThickness[0.5], 
     LineBox[{{4.690582381629045, 0.865765952717761}, {4.613324960534719, 
      0.8639604577822312}}]}, 
    {Hue[0.4383863607142317], AbsoluteThickness[0.5], 
     LineBox[{{6.882842248520935, -1.1463896616883769`}, {
      6.886544713685529, -1.1997565696185986`}}]}, 
    {Hue[0.439411509950674], AbsoluteThickness[0.5], 
     LineBox[{{6.886544713685529, -1.1997565696185986`}, {
      6.87725476830333, -1.3985091703707337`}}]}, 
    {Hue[0.4360859156532896], AbsoluteThickness[0.5], 
     LineBox[{{7.4207183716486735`, -0.620736054269777}, {
      7.534987210262611, -0.8222687521754535}}]}, 
    {Hue[0.43636024970325804`], AbsoluteThickness[0.5], 
     LineBox[{{7.534987210262611, -0.8222687521754535}, {
      7.665234411496248, -1.0794506771927341`}}]}, 
    {Hue[0.6145546268770803], AbsoluteThickness[0.5], 
     LineBox[{{7.581851068272584, 0.2082720020311536}, {7.545049759835014, 
      0.09611452520613893}}]}, 
    {Hue[0.6147446165322664], AbsoluteThickness[0.5], 
     LineBox[{{7.545049759835014, 0.09611452520613893}, {
      7.4586303530034055`, -0.17982614486075948`}}]}, 
    {Hue[0.4329090989521019], AbsoluteThickness[0.5], 
     LineBox[{{7.675336249011812, 0.0591858274929169}, {
      8.30451965388601, -0.5884010241932411}}]}, 
    {Hue[0.43392049064675275`], AbsoluteThickness[0.5], 
     LineBox[{{8.30451965388601, -0.5884010241932411}, {
      8.454284569695465, -0.7830988991393053}}]}, 
    {Hue[0.6259854889431075], AbsoluteThickness[0.5], 
     LineBox[{{7.850782598441062, 0.07277791814304138}, {7.87963114875032, 
      0.08133101104005919}}]}, 
    {Hue[0.6270791160602054], AbsoluteThickness[0.5], 
     LineBox[{{7.87963114875032, 0.08133101104005919}, {8.093840169841501, 
      0.11788342776077729`}}]}, 
    {Hue[0.6663220987699465], AbsoluteThickness[0.5], 
     LineBox[{{6.983547199606125, 1.1459838153379867`}, {6.852980997598422, 
      1.167184912738187}}]}, 
    {Hue[0.666631665047182], AbsoluteThickness[0.5], 
     LineBox[{{6.852980997598422, 1.167184912738187}, {6.569808117033248, 
      1.2291413933762683`}}]}, 
    {Hue[0.4692611724228079], AbsoluteThickness[0.5], 
     LineBox[{{6.863324853607964, 1.031608164437147}, {6.783168053508213, 
      0.9171501968809312}}]}, 
    {Hue[0.46957289582654643`], AbsoluteThickness[0.5], 
     LineBox[{{6.783168053508213, 0.9171501968809312}, {6.61876224892598, 
      0.6526344388411479}}]}, 
    {Hue[0.675795070206574], AbsoluteThickness[0.5], 
     LineBox[{{6.914027006419358, 0.8736066021139146}, {7.066867649932133, 
      0.6002952428894279}}]}, 
    {Hue[0.6769039975091455], AbsoluteThickness[0.5], 
     LineBox[{{7.066867649932133, 0.6002952428894279}, {7.150151747661281, 
      0.39767247546671286`}}]}, 
    {Hue[0.3180960634230614], AbsoluteThickness[0.5], 
     LineBox[{{7.346007987984193, 2.1354637918059716`}, {7.327120090947857, 
      2.1718958268236905`}}]}, 
    {Hue[0.3183571686847952], AbsoluteThickness[0.5], 
     LineBox[{{7.327120090947857, 2.1718958268236905`}, {7.184201931052216, 
      2.420319605206351}}]}, 
    {Hue[0.4405066725286487], AbsoluteThickness[0.5], 
     LineBox[{{8.066377499692184, 2.2089179863153836`}, {7.898965312849362, 
      2.243527325900353}}]}, 
    {Hue[0.4406906289139544], AbsoluteThickness[0.5], 
     LineBox[{{7.898965312849362, 2.243527325900353}, {7.585569373781221, 
      2.3098714954677755`}}]}, 
    {Hue[0.44105953959417243`], AbsoluteThickness[0.5], 
     LineBox[{{8.269418053371558, 2.1084494459656544`}, {8.251000233336963, 
      1.8908622107119537`}}]}, 
    {Hue[0.4412430735957805], AbsoluteThickness[0.5], 
     LineBox[{{8.251000233336963, 1.8908622107119537`}, {8.226143229094154, 
      1.6084734436314265`}}]}, 
    {Hue[0.5325011469898283], AbsoluteThickness[0.5], 
     LineBox[{{8.394212442133696, 1.133243022143843}, {8.251696866129556, 
      0.9374730351937544}}]}, 
    {Hue[0.5327659146382409], AbsoluteThickness[0.5], 
     LineBox[{{8.251696866129556, 0.9374730351937544}, {8.084613540559982, 
      0.6849672883762922}}]}, 
    {Hue[0.616660733049056], AbsoluteThickness[0.5], 
     LineBox[{{7.6564143033686465`, 1.2250070433451765`}, {
      7.6385450164797195`, 1.1740699618890027`}}]}, 
    {Hue[0.6168962614644514], AbsoluteThickness[0.5], 
     LineBox[{{7.6385450164797195`, 1.1740699618890027`}, {7.517440732883323, 
      0.8653015214522295}}]}, 
    {Hue[0.46063331733319285`], AbsoluteThickness[0.5], 
     LineBox[{{7.430375912009466, 0.283208622726918}, {7.421668960201598, 
      0.06043892671619491}}]}, 
    {Hue[0.4612309668754856], AbsoluteThickness[0.5], 
     LineBox[{{7.421668960201598, 0.06043892671619491}, {
      7.432955462470727, -0.16461433324118624`}}]}, 
    {Hue[0.4224153500748468], AbsoluteThickness[0.5], 
     LineBox[{{5.585010064392459, 1.196668184852395}, {5.38361273321551, 
      1.1699175830622408`}}]}, 
    {Hue[0.4227607814995631], AbsoluteThickness[0.5], 
     LineBox[{{5.38361273321551, 1.1699175830622408`}, {5.095547716240053, 
      1.1493290099655205`}}]}, 
    {Hue[0.43441248578330216`], AbsoluteThickness[0.5], 
     LineBox[{{4.869019545342315, 0.9045133912008863}, {4.6601133026574955`, 
      0.9110461907966975}}]}, 
    {Hue[0.4347458900911821], AbsoluteThickness[0.5], 
     LineBox[{{4.6601133026574955`, 0.9110461907966975}, {4.349677723758777, 
      0.9390518793580136}}]}, 
    {Hue[0.4335730494585662], AbsoluteThickness[0.5], 
     LineBox[{{3.8802831926153463`, 1.0795703200884155`}, {
      3.6903964674858494`, 1.0595389433095326`}}]}, 
    {Hue[0.43376706803217757`], AbsoluteThickness[0.5], 
     LineBox[{{3.6903964674858494`, 1.0595389433095326`}, {3.3824431749592, 
      1.0217437832545335`}}]}, 
    {Hue[0.6895494154530264], AbsoluteThickness[0.5], 
     LineBox[{{6.613447268885137, -1.6437226269738707`}, {
      6.61359122751234, -1.6461805843378567`}}]}, 
    {Hue[0.6900935315682579], AbsoluteThickness[0.5], 
     LineBox[{{6.61359122751234, -1.6461805843378567`}, {
      6.645263755494122, -1.866185420573217}}]}, 
    {Hue[0.46960949317420725`], AbsoluteThickness[0.5], 
     LineBox[{{7.1516229963101905`, 3.04052253545903}, {7.1594300176847945`, 
      3.096458406591349}}]}, 
    {Hue[0.4698039735962354], AbsoluteThickness[0.5], 
     LineBox[{{7.1594300176847945`, 3.096458406591349}, {7.211612833848461, 
      3.428151601916212}}]}, 
    {Hue[0.5178336419081199], AbsoluteThickness[0.5], 
     LineBox[{{6.488034289750155, 2.6797783985379304`}, {6.512358282793377, 
      2.8102062193222936`}}]}, 
    {Hue[0.5180559286507087], AbsoluteThickness[0.5], 
     LineBox[{{6.512358282793377, 2.8102062193222936`}, {6.560121556279733, 
      3.120599832514311}}]}, 
    {Hue[0.2955622170990449], AbsoluteThickness[0.5], 
     LineBox[{{4.973860009185009, 2.4233855638274715`}, {4.42036330315144, 
      2.7385215816048163`}}]}, 
    {Hue[0.2957517302854211], AbsoluteThickness[0.5], 
     LineBox[{{4.42036330315144, 2.7385215816048163`}, {4.138474141033417, 
      2.894172329501781}}]}, 
    {Hue[0.40432354052428693`], AbsoluteThickness[0.5], 
     LineBox[{{4.911576044151911, 2.523739366932794}, {4.88366247065081, 
      2.686708323647802}}]}, 
    {Hue[0.4050236686307316], AbsoluteThickness[0.5], 
     LineBox[{{4.88366247065081, 2.686708323647802}, {4.821355136964984, 
      2.914793700563985}}]}, 
    {Hue[0.43964769092068773`], AbsoluteThickness[0.5], 
     LineBox[{{4.949638783966609, 2.6355490531667902`}, {5.30327979785749, 
      3.0437173209918855`}}]}, 
    {Hue[0.4441723415524213], AbsoluteThickness[0.5], 
     LineBox[{{5.30327979785749, 3.0437173209918855`}, {5.4372327959670805`, 
      3.147729248239088}}]}, 
    {Hue[0.6539966857134655], AbsoluteThickness[0.5], 
     LineBox[{{5.4372327959670805`, 3.147729248239088}, {5.5885091764360935`, 
      3.0710654143640497`}}]}, 
    {Hue[0.47497184131709425`], AbsoluteThickness[0.5], 
     LineBox[{{5.0602158577717615`, 2.677056749400575}, {5.1235570583401175`, 
      2.675363415373785}}]}, 
    {Hue[0.4752213248197264], AbsoluteThickness[0.5], 
     LineBox[{{5.1235570583401175`, 2.675363415373785}, {5.3812716959614155`, 
      2.6789453650180284`}}]}, 
    {Hue[0.5102959917135038], AbsoluteThickness[0.5], 
     LineBox[{{5.162450707646214, 2.6179110515934285`}, {5.522941060404558, 
      2.1538937358320926`}}]}, 
    {Hue[0.5105919093607364], AbsoluteThickness[0.5], 
     LineBox[{{5.522941060404558, 2.1538937358320926`}, {5.644278954911342, 
      1.9798251660506894`}}]}, 
    {Hue[0.5456201421099136], AbsoluteThickness[0.5], 
     LineBox[{{5.18158680607505, 2.5013606855070525`}, {5.152322539864831, 
      2.372367037486031}}]}, 
    {Hue[0.546236745189898], AbsoluteThickness[0.5], 
     LineBox[{{5.152322539864831, 2.372367037486031}, {5.118213821951841, 
      2.1161797360726418`}}]}, 
    {Hue[0.5809442925063276], AbsoluteThickness[0.5], 
     LineBox[{{5.1036313876707275`, 2.412630020912711}, {4.883622081333916, 
      2.302493471582756}}]}, 
    {Hue[0.5811404074213706], AbsoluteThickness[0.5], 
     LineBox[{{4.883622081333916, 2.302493471582756}, {4.60282190644634, 
      2.1683820226624086`}}]}, 
    {Hue[0.6162684429027511], AbsoluteThickness[0.5], 
     LineBox[{{4.985587288433265, 2.416601007334562}, {4.384889466004231, 
      2.6844616944699413`}}]}, 
    {Hue[0.6165015321392392], AbsoluteThickness[0.5], 
     LineBox[{{4.384889466004231, 2.6844616944699413`}, {4.108774052035784, 
      2.8195567145089377`}}]}, 
    {Hue[0.6515925932991867], AbsoluteThickness[0.5], 
     LineBox[{{4.913771130957169, 2.5103699660752623`}, {4.870247198990103, 
      2.669012116609145}}]}, 
    {Hue[0.6519419030703649], AbsoluteThickness[0.5], 
     LineBox[{{4.870247198990103, 2.669012116609145}, {4.781731117882949, 
      2.928205971915999}}]}, 
    {Hue[0.6869167436956203], AbsoluteThickness[0.5], 
     LineBox[{{4.9406965792129025`, 2.6253708283945265`}, {5.457306936761345, 
      3.355448852941872}}]}, 
    {Hue[0.6871691265751076], AbsoluteThickness[0.5], 
     LineBox[{{5.457306936761345, 3.355448852941872}, {5.634090986696744, 
      3.6286175405357364`}}]}, 
    {Hue[0.5257595862470845], AbsoluteThickness[0.5], 
     LineBox[{{4.1188388464948025`, 0.6604338486612473}, {4.1166751170879525`,
       0.6597018252416424}}]}, 
    {Hue[0.5260209914069233], AbsoluteThickness[0.5], 
     LineBox[{{4.1166751170879525`, 0.6597018252416424}, {3.832018778269499, 
      0.5492703607319532}}]}, 
    {Hue[0.5850054299278722], AbsoluteThickness[0.5], 
     LineBox[{{5.143855725421484, 1.3816868608239041`}, {5.132335989322367, 
      1.3897219659560067`}}]}, 
    {Hue[0.5851909943034346], AbsoluteThickness[0.5], 
     LineBox[{{5.132335989322367, 1.3897219659560067`}, {4.8547025614206625`, 
      1.5800455557922033`}}]}, 
    {Hue[0.519141727171743], AbsoluteThickness[0.5], 
     LineBox[{{5.072201536619233, 1.2023600096651306`}, {4.851498967343398, 
      1.2250555314779823`}}]}, 
    {Hue[0.5194049674380496], AbsoluteThickness[0.5], 
     LineBox[{{4.851498967343398, 1.2250555314779823`}, {4.613741195307599, 
      1.2388990593583549`}}]}, 
    {Hue[0.6249632781207611], AbsoluteThickness[0.5], 
     LineBox[{{5.327993242796761, 1.1048759326021627`}, {5.210763959576821, 
      0.9057866227232705}}]}, 
    {Hue[0.625684645760928], AbsoluteThickness[0.5], 
     LineBox[{{5.210763959576821, 0.9057866227232705}, {5.090100669028041, 
      0.7405292894550553}}]}, 
    {Hue[0.6963310718488184], AbsoluteThickness[0.5], 
     LineBox[{{5.953065952582621, -0.6208304854292546}, {
      5.979795162103256, -0.8413281452657155}}]}, 
    {Hue[0.6965257730615604], AbsoluteThickness[0.5], 
     LineBox[{{5.979795162103256, -0.8413281452657155}, {
      6.021253812479882, -1.1394772355398624`}}]}, 
    {Hue[0.6897078503330876], AbsoluteThickness[0.5], 
     LineBox[{{7.8015864440438545`, -0.3685024860381718}, {
      7.865477093546045, -0.4111577264223858}}]}, 
    {Hue[0.6899389341882193], AbsoluteThickness[0.5], 
     LineBox[{{7.865477093546045, -0.4111577264223858}, {
      8.090697161067123, -0.5731585137979203}}]}, 
    {Hue[0.4784803902391987], AbsoluteThickness[0.5], 
     LineBox[{{3.9180161944865612`, 1.1494482120242693`}, {
      3.8621851503738815`, 1.158281382640382}}]}, 
    {Hue[0.47971960798973196`], AbsoluteThickness[0.5], 
     LineBox[{{3.8621851503738815`, 1.158281382640382}, {3.6713872384178625`, 
      1.2136497580075274`}}]}, 
    {Hue[0.6835081126440143], AbsoluteThickness[0.5], 
     LineBox[{{3.515237747523003, -1.3299214132440937`}, {
      3.3736817974158426`, -1.2779634997862737`}}]}, 
    {Hue[0.6836969026454847], AbsoluteThickness[0.5], 
     LineBox[{{3.3736817974158426`, -1.2779634997862737`}, {
      3.062560437831467, -1.1680963505251802`}}]}, 
    {Hue[0.47240796466624274`], AbsoluteThickness[0.5], 
     LineBox[{{3.3631369823812154`, -1.436960415300968}, {
      3.2347894055906963`, -1.5697014360895865`}}]}, 
    {Hue[0.47326085359725617`], AbsoluteThickness[0.5], 
     LineBox[{{3.2347894055906963`, -1.5697014360895865`}, {
      3.0912834629691233`, -1.7539364159912485`}}]}, 
    {Hue[0.6914692953912244], AbsoluteThickness[0.5], 
     LineBox[{{3.3994379955641585`, -1.6193726603941647`}, {
      3.4950612409166117`, -1.855056788319011}}]}, 
    {Hue[0.6916687540409666], AbsoluteThickness[0.5], 
     LineBox[{{3.4950612409166117`, -1.855056788319011}, {
      3.589344272267322, -2.1020351712178833`}}]}, 
    {Hue[0.5744826077161498], AbsoluteThickness[0.5], 
     LineBox[{{3.6764578941698423`, 1.912287471595425}, {3.659701915750172, 
      1.9542676047755663`}}]}, 
    {Hue[0.5750538794171484], AbsoluteThickness[0.5], 
     LineBox[{{3.659701915750172, 1.9542676047755663`}, {3.5671895390265544`, 
      2.1378958136711663`}}]}, 
    {Hue[0.5281649486641815], AbsoluteThickness[0.5], 
     LineBox[{{7.8600772293281915`, 0.9108912178091552}, {7.917087917971804, 
      0.9252157528523273}}]}, 
    {Hue[0.528495176369025], AbsoluteThickness[0.5], 
     LineBox[{{7.917087917971804, 0.9252157528523273}, {8.192257270270463, 
      1.011642970905468}}]}, 
    {Hue[0.5632691537597833], AbsoluteThickness[0.5], 
     LineBox[{{4.563509470794093, 1.7232149979237499`}, {4.491949144930795, 
      1.8183417237540334`}}]}, 
    {Hue[0.5643287541092599], AbsoluteThickness[0.5], 
     LineBox[{{4.491949144930795, 1.8183417237540334`}, {4.380048048528092, 
      2.0105057011738268`}}]}, 
    {Hue[0.6651808895364482], AbsoluteThickness[0.5], 
     LineBox[{{4.1420754931227135`, 0.6299410302479087}, {4.13941268460613, 
      0.6298041521065122}}]}, 
    {Hue[0.665465001478205], AbsoluteThickness[0.5], 
     LineBox[{{4.13941268460613, 0.6298041521065122}, {3.84117167131676, 
      0.5997028117287332}}]}, 
    {Hue[0.6997930972037383], AbsoluteThickness[0.5], 
     LineBox[{{4.6730830867006965`, -1.3644129827131524`}, {
      4.655793407407262, -1.394049582502252}}]}, 
    {Hue[0.6901646330191046], AbsoluteThickness[0.5], 
     LineBox[{{7.212311557604752, -0.4341530931148644}, {
      7.338588345914811, -0.6082107515768171}}]}, 
    {Hue[0.6953649027985305], AbsoluteThickness[0.5], 
     LineBox[{{7.338588345914811, -0.6082107515768171}, {
      7.418876778563906, -0.7867706051417519}}]}, 
    {Hue[0.46546684028003843`], AbsoluteThickness[0.5], 
     LineBox[{{5.435909779053422, 2.6593680888455133`}, {5.3888323111581675`, 
      2.7101479142359346`}}]}, 
    {Hue[0.4659412130244296], AbsoluteThickness[0.5], 
     LineBox[{{5.3888323111581675`, 2.7101479142359346`}, {5.224191606502897, 
      2.8622039459876105`}}]}, 
    {Hue[0.5936911086119842], AbsoluteThickness[0.5], 
     LineBox[{{6.8978100437530285`, 1.696982269817469}, {6.956747605735684, 
      1.6533453290572493`}}]}, 
    {Hue[0.5947518052164188], AbsoluteThickness[0.5], 
     LineBox[{{6.956747605735684, 1.6533453290572493`}, {7.093661954241497, 
      1.5245104065784694`}}]}, 
    {Hue[0.6592421986570698], AbsoluteThickness[0.5], 
     LineBox[{{6.665193389335898, 1.9205603235213684`}, {6.69219454215379, 
      1.82495236190656}}]}, 
    {Hue[0.659449030130331], AbsoluteThickness[0.5], 
     LineBox[{{6.69219454215379, 1.82495236190656}, {6.7707649418967755`, 
      1.571081812287572}}]}, 
    {Hue[0.6340366787405294], AbsoluteThickness[0.5], 
     LineBox[{{6.585555138189024, 2.638730032428786}, {6.578523583257114, 
      2.6384968249285388`}}]}, 
    {Hue[0.6347025159945722], AbsoluteThickness[0.5], 
     LineBox[{{6.578523583257114, 2.6384968249285388`}, {6.327120076572609, 
      2.606217434266993}}]}, 
    {Hue[0.2407921786393939], AbsoluteThickness[0.5], 
     LineBox[{{6.692367912281009, 2.8987001271996897`}, {6.829041889572819, 
      3.1787664066759094`}}]}, 
    {Hue[0.24230133561386294`], AbsoluteThickness[0.5], 
     LineBox[{{6.829041889572819, 3.1787664066759094`}, {6.883506851961149, 
      3.3440089025840014`}}]}, 
    {Hue[0.5321045863779768], AbsoluteThickness[0.5], 
     LineBox[{{6.883506851961149, 3.3440089025840014`}, {6.730079919853941, 
      3.4260557860474723`}}]}, 
    {Hue[0.6347724170239714], AbsoluteThickness[0.5], 
     LineBox[{{6.872093610858287, 2.6826165966951008`}, {6.91602272532324, 
      2.622319810077522}}]}, 
    {Hue[0.6349702037858147], AbsoluteThickness[0.5], 
     LineBox[{{6.91602272532324, 2.622319810077522}, {7.090703027845902, 
      2.372357661055526}}]}, 
    {Hue[0.6588569154036606], AbsoluteThickness[0.5], 
     LineBox[{{5.939781396097772, 2.361951907883309}, {5.772658749981498, 
      2.303802156351581}}]}, 
    {Hue[0.6592505671079941], AbsoluteThickness[0.5], 
     LineBox[{{5.772658749981498, 2.303802156351581}, {5.589205417729699, 
      2.225663533370224}}]}, 
    {Hue[0.5950808172285319], AbsoluteThickness[0.5], 
     LineBox[{{5.391351704172249, 2.625593379193287}, {5.355124772949332, 
      2.6352776953953128`}}]}, 
    {Hue[0.5953540806212828], AbsoluteThickness[0.5], 
     LineBox[{{5.355124772949332, 2.6352776953953128`}, {5.1144186586145235`, 
      2.7118462900651146`}}]}, 
    {Hue[0.47109748373732696`], AbsoluteThickness[0.5], 
     LineBox[{{7.653693099468152, 1.5369387176341482`}, {7.849169220663623, 
      1.4859892362381888`}}]}, 
    {Hue[0.47128342072598045`], AbsoluteThickness[0.5], 
     LineBox[{{7.849169220663623, 1.4859892362381888`}, {8.113793252067586, 
      1.4194705564399406`}}]}, 
    {Hue[0.6660094799241838], AbsoluteThickness[0.5], 
     LineBox[{{4.963243164986898, 0.40461823168334243`}, {4.864035069368825, 
      0.3001735008972025}}]}, 
    {Hue[0.6663898366013477], AbsoluteThickness[0.5], 
     LineBox[{{4.864035069368825, 0.3001735008972025}, {4.694976960098423, 
      0.14421027926079488`}}]}, 
    {Hue[0.5258660519429049], AbsoluteThickness[0.5], 
     LineBox[{{3.693844003873882, 1.1857485126662142`}, {3.4228500119969545`, 
      1.264608325084982}}]}, 
    {Hue[0.5260625373586233], AbsoluteThickness[0.5], 
     LineBox[{{3.4228500119969545`, 1.264608325084982}, {3.1565195605696372`, 
      1.3367049720306945`}}]}, 
    {Hue[0.6913863547071933], AbsoluteThickness[0.5], 
     LineBox[{{4.2970211362664825`, 2.4039905965296344`}, {4.354927469531008, 
      2.660660901539697}}]}, 
    {Hue[0.6919806968379842], AbsoluteThickness[0.5], 
     LineBox[{{4.354927469531008, 2.660660901539697}, {4.388221823160652, 
      2.9095274470816745`}}]}, 
    {Hue[0.6535381897576666], AbsoluteThickness[0.5], 
     LineBox[{{3.8070783438029028`, 2.2959531760368335`}, {
      3.7064987451471687`, 2.657886923554598}}]}, 
    {Hue[0.6543923986502526], AbsoluteThickness[0.5], 
     LineBox[{{3.7064987451471687`, 2.657886923554598}, {3.675537600714022, 
      2.844785459439058}}]}, 
    {Hue[0.4519982119997856], AbsoluteThickness[0.5], 
     LineBox[{{3.675134321503202, 2.346331015390589}, {3.5557058479751067`, 
      2.3666693537413117`}}]}, 
    {Hue[0.452762681945532], AbsoluteThickness[0.5], 
     LineBox[{{3.5557058479751067`, 2.3666693537413117`}, {
      3.3314682700404803`, 2.4287451418733497`}}]}, 
    {Hue[0.662502417087678], AbsoluteThickness[0.5], 
     LineBox[{{3.573380697926003, 2.248385357970332}, {3.4922244091376218`, 
      2.1318753049699684`}}]}, 
    {Hue[0.6638167312413383], AbsoluteThickness[0.5], 
     LineBox[{{3.4922244091376218`, 2.1318753049699684`}, {
      3.4118601926906513`, 1.9774712451865195`}}]}, 
    {Hue[0.697719377022638], AbsoluteThickness[0.5], 
     LineBox[{{3.608033170338925, 1.7741434996327017`}, {3.494865762782598, 
      1.6280956073710566`}}]}, 
    {Hue[0.6979784738403066], AbsoluteThickness[0.5], 
     LineBox[{{3.494865762782598, 1.6280956073710566`}, {3.345010882115403, 
      1.4163935745926908`}}]}, 
    {Hue[0.6588403998201681], AbsoluteThickness[0.5], 
     LineBox[{{2.30918847720457, -1.0191991468394757`}, {
      2.1501325925922243`, -1.0673780166924594`}}]}, 
    {Hue[0.6591713197564416], AbsoluteThickness[0.5], 
     LineBox[{{2.1501325925922243`, -1.0673780166924594`}, {
      1.822712616640818, -1.1460593338038179`}}]}, 
    {Hue[0.6682929898670454], AbsoluteThickness[0.5], 
     LineBox[{{3.589108696355187, -2.8258811301481175`}, {
      3.5793722792052693`, -2.831708477702094}}]}, 
    {Hue[0.6685432097090372], AbsoluteThickness[0.5], 
     LineBox[{{3.5793722792052693`, -2.831708477702094}, {
      3.3311028726883682`, -2.9944225439346672`}}]}, 
    {Hue[0.6928105867639939], AbsoluteThickness[0.5], 
     LineBox[{{5.172461097552453, -3.4101727141824996`}, {
      5.1639613154432675`, -3.465730359428305}}]}, 
    {Hue[0.699195110948896], AbsoluteThickness[0.5], 
     LineBox[{{5.1639613154432675`, -3.465730359428305}, {
      5.10378493535895, -3.621029082309203}}]}, 
    {Hue[0.641526319241346], AbsoluteThickness[0.5], 
     LineBox[{{6.601170038740591, -3.55634550583027}, {
      6.628715581397982, -3.6196351682442374`}}]}, 
    {Hue[0.6417295093276987], AbsoluteThickness[0.5], 
     LineBox[{{6.628715581397982, -3.6196351682442374`}, {
      6.770942851840212, -3.9269453409866735`}}]}, 
    {Hue[0.5200404013760235], AbsoluteThickness[0.5], 
     LineBox[{{7.638935893568386, -2.5748739356299155`}, {
      7.862015843501545, -2.566332486898788}}]}, 
    {Hue[0.5204790458176228], AbsoluteThickness[0.5], 
     LineBox[{{7.862015843501545, -2.566332486898788}, {
      8.11164321715692, -2.5383145838870496`}}]}, 
    {Hue[0.662181889320573], AbsoluteThickness[0.5], 
     LineBox[{{8.17711503024882, -0.9657857867526604}, {
      8.229584526554289, -0.9331285216554779}}]}, 
    {Hue[0.6627021808642573], AbsoluteThickness[0.5], 
     LineBox[{{8.229584526554289, -0.9331285216554779}, {
      8.45538678793015, -0.7653751126454883}}]}, 
    {Hue[0.6682585892707231], AbsoluteThickness[0.5], 
     LineBox[{{5.859102310574856, 2.798613824550409}, {6.084440878437667, 
      2.8852840868237886`}}]}, 
    {Hue[0.6701722477710985], AbsoluteThickness[0.5], 
     LineBox[{{6.084440878437667, 2.8852840868237886`}, {6.2854634585950215`, 
      2.930051637924093}}]}, 
    {Hue[0.6117608731232254], AbsoluteThickness[0.5], 
     LineBox[{{4.346900401770584, -3.2046491384338243`}, {
      4.4508501385809875`, -3.297385501936052}}]}, 
    {Hue[0.6121099072510913], AbsoluteThickness[0.5], 
     LineBox[{{4.4508501385809875`, -3.297385501936052}, {
      4.653245556053751, -3.501540898488227}}]}, 
    {Hue[0.6965815793268396], AbsoluteThickness[0.5], 
     LineBox[{{4.8834535086676665`, -1.782800960434623}, {
      5.105640936272439, -1.7834163468424353`}}]}, 
    {Hue[0.696832999619019], AbsoluteThickness[0.5], 
     LineBox[{{5.105640936272439, -1.7834163468424353`}, {
      5.421968446816875, -1.7712630858995746`}}]}, 
    {Hue[0.6931325160222679], AbsoluteThickness[0.5], 
     LineBox[{{3.6246736316529993`, 2.5441255502263878`}, {
      3.6704688145865982`, 2.6952186852900835`}}]}, 
    {Hue[0.6936137178461547], AbsoluteThickness[0.5], 
     LineBox[{{3.6704688145865982`, 2.6952186852900835`}, {
      3.7481042170747867`, 2.8938741145769025`}}]}, 
    {Hue[0.4138072574726326], AbsoluteThickness[0.5], 
     LineBox[{{2.990766656968944, 2.68440669863797}, {2.8845911525099703`, 
      2.7559991259945607`}}]}, 
    {Hue[0.4141916724407398], AbsoluteThickness[0.5], 
     LineBox[{{2.8845911525099703`, 2.7559991259945607`}, {2.656496102702559, 
      2.8886382820148584`}}]}, 
    {Hue[0.6948167793723977], AbsoluteThickness[0.5], 
     LineBox[{{2.427325078483299, 1.8400499517806694`}, {2.4097248437291436`, 
      1.8324302484370008`}}]}, 
    {Hue[0.6950010806316999], AbsoluteThickness[0.5], 
     LineBox[{{2.4097248437291436`, 1.8324302484370008`}, {
      2.1617716970949905`, 1.7234169393512568`}}]}, 
    {Hue[0.6891548317320334], AbsoluteThickness[0.5], 
     LineBox[{{5.5648705308709445`, 2.67124674879148}, {5.588892206482666, 
      2.680871821839608}}]}, 
    {Hue[0.6894033339860385], AbsoluteThickness[0.5], 
     LineBox[{{5.588892206482666, 2.680871821839608}, {5.858952183105744, 
      2.80193995526425}}]}, 
    {Hue[0.6127128428824197], AbsoluteThickness[0.5], 
     LineBox[{{3.0780660610831423`, -0.8695988186114041}, {
      3.0428885243697246`, -0.8680864942479819}}]}, 
    {Hue[0.6151119302350475], AbsoluteThickness[0.5], 
     LineBox[{{3.0428885243697246`, -0.8680864942479819}, {
      2.8724930742377612`, -0.8881629628885982}}]}, 
    {Hue[0.6632386858871732], AbsoluteThickness[0.5], 
     LineBox[{{2.844101538872602, -1.0632252089375354`}, {
      2.666467982513889, -1.0456368429455045`}}]}, 
    {Hue[0.6634219858195911], AbsoluteThickness[0.5], 
     LineBox[{{2.666467982513889, -1.0456368429455045`}, {
      2.3099577862941993`, -1.0111371331343069`}}]}, 
    {Hue[0.6888474366476992], AbsoluteThickness[0.5], 
     LineBox[{{4.620435270414352, 0.8139180346299864}, {4.568674019498865, 
      0.8418032120599352}}]}, 
    {Hue[0.6894071649103181], AbsoluteThickness[0.5], 
     LineBox[{{4.568674019498865, 0.8418032120599352}, {4.335307961329535, 
      0.9947123023651957}}]}, 
    {Hue[0.6352660980787908], AbsoluteThickness[0.5], 
     LineBox[{{7.71725703465744, 0.3774451573715266}, {7.859452932420811, 
      0.6047336633735261}}]}, 
    {Hue[0.6366634972835808], AbsoluteThickness[0.5], 
     LineBox[{{7.859452932420811, 0.6047336633735261}, {7.9507690227662335`, 
      0.8052219787546446}}]}, 
    {Hue[0.6619528849206429], AbsoluteThickness[0.5], 
     LineBox[{{6.939023855942025, -0.28788288655888045`}, {6.761532495199798, 
      0.0782594081300623}}]}, 
    {Hue[0.6621884229008781], AbsoluteThickness[0.5], 
     LineBox[{{6.761532495199798, 0.0782594081300623}, {6.639163844367371, 
      0.35600074813492016`}}]}, 
    {Hue[0.6267870798362002], AbsoluteThickness[0.5], 
     LineBox[{{6.603624631246455, -1.8298685568134114`}, {
      6.570468399754491, -1.8293367952577892`}}]}, 
    {Hue[0.6282331490638108], AbsoluteThickness[0.5], 
     LineBox[{{6.570468399754491, -1.8293367952577892`}, {
      6.364338814151551, -1.8536428419150592`}}]}, 
    {Hue[0.5808746540844187], AbsoluteThickness[0.5], 
     LineBox[{{7.608643324015406, -2.241089960054466}, {
      7.5302611664733945`, -2.388115128296302}}]}, 
    {Hue[0.5810709523130212], AbsoluteThickness[0.5], 
     LineBox[{{7.5302611664733945`, -2.388115128296302}, {
      7.388525244576338, -2.6663777250317304`}}]}, 
    {Hue[0.6501567399759164], AbsoluteThickness[0.5], 
     LineBox[{{8.079759756486173, -2.178409227415667}, {
      7.8944045676906915`, -2.180664402454299}}]}, 
    {Hue[0.650439709480264], AbsoluteThickness[0.5], 
     LineBox[{{7.8944045676906915`, -2.180664402454299}, {
      7.618630463181174, -2.1975476124328246`}}]}, 
    {Hue[0.6506131797625343], AbsoluteThickness[0.5], 
     LineBox[{{8.241396205327685, -2.0647126153737987`}, {
      8.182546427716614, -1.895598670219838}}]}, 
    {Hue[0.6509297842598181], AbsoluteThickness[0.5], 
     LineBox[{{8.182546427716614, -1.895598670219838}, {
      8.10977393330874, -1.6417027819848846`}}]}, 
    {Hue[0.6271535610157919], AbsoluteThickness[0.5], 
     LineBox[{{8.13369358484671, -0.909805201904108}, {
      8.142056766957792, -0.8755510463406937}}]}, 
    {Hue[0.6275573621547597], AbsoluteThickness[0.5], 
     LineBox[{{8.142056766957792, -0.8755510463406937}, {
      8.232240954122844, -0.5926830924116476}}]}, 
    {Hue[0.6609925464023574], AbsoluteThickness[0.5], 
     LineBox[{{6.631251815124599, -0.7413559237850313}, {
      6.605605728708971, -0.7000616123378564}}]}, 
    {Hue[0.6611900305824417], AbsoluteThickness[0.5], 
     LineBox[{{6.605605728708971, -0.7000616123378564}, {
      6.436956136237303, -0.4163147868373776}}]}, 
    {Hue[0.6346669638575534], AbsoluteThickness[0.5], 
     LineBox[{{5.35587456765623, -1.1072220852942924`}, {
      5.178150371177928, -1.038544202537983}}]}, 
    {Hue[0.6348546166341116], AbsoluteThickness[0.5], 
     LineBox[{{5.178150371177928, -1.038544202537983}, {
      4.902025869288929, -0.9353251541593269}}]}, 
    {Hue[0.5172120729287287], AbsoluteThickness[0.5], 
     LineBox[{{5.56054423222673, -2.2685416838301906`}, {
      5.507209445819916, -2.3131470319159875`}}]}, 
    {Hue[0.5176289114087563], AbsoluteThickness[0.5], 
     LineBox[{{5.507209445819916, -2.3131470319159875`}, {
      5.317042174504154, -2.496568643107816}}]}, 
    {Hue[0.6662129682678501], AbsoluteThickness[0.5], 
     LineBox[{{4.212331653106352, -0.0695994659840488}, {
      4.165340332262248, -0.05949132258521739}}]}, 
    {Hue[0.6664394662555997], AbsoluteThickness[0.5], 
     LineBox[{{4.165340332262248, -0.05949132258521739}, {3.865264422165415, 
      0.015582195435765321`}}]}, 
    {Hue[0.6711919966737071], AbsoluteThickness[0.5], 
     LineBox[{{6.448658799778517, 2.1357213457488884`}, {6.493406679852289, 
      2.34785971181047}}]}, 
    {Hue[0.6714267863834585], AbsoluteThickness[0.5], 
     LineBox[{{6.493406679852289, 2.34785971181047}, {6.547614972963494, 
      2.660373650005636}}]}, 
    {Hue[0.6284971071215477], AbsoluteThickness[0.5], 
     LineBox[{{7.1162682073205294`, 2.5548130859784597`}, {7.065798112577622, 
      2.833912076653831}}]}, 
    {Hue[0.6286809076738463], AbsoluteThickness[0.5], 
     LineBox[{{7.065798112577622, 2.833912076653831}, {7.015837296923768, 
      3.1035802932107157`}}]}, 
    {Hue[0.5067258237451694], AbsoluteThickness[0.5], 
     LineBox[{{2.6055738337734273`, 0.6567341618634729}, {2.4061119345070474`,
       0.7531081223307664}}]}, 
    {Hue[0.5069120705960809], AbsoluteThickness[0.5], 
     LineBox[{{2.4061119345070474`, 0.7531081223307664}, {2.1844334948319033`,
       0.8577212354772984}}]}, 
    {Hue[0.5776362115879845], AbsoluteThickness[0.5], 
     LineBox[{{3.8962224611401854`, -1.5783964706025564`}, {
      3.750287447374651, -1.6648115713326714`}}]}, 
    {Hue[0.5780589989078315], AbsoluteThickness[0.5], 
     LineBox[{{3.750287447374651, -1.6648115713326714`}, {
      3.566128926377194, -1.7924870565715108`}}]}, 
    {Hue[0.6481183031030368], AbsoluteThickness[0.5], 
     LineBox[{{5.421649245250298, -3.0825725534329287`}, {
      5.532067868258321, -3.3615206858124775`}}]}, 
    {Hue[0.648556428949704], AbsoluteThickness[0.5], 
     LineBox[{{5.532067868258321, -3.3615206858124775`}, {
      5.613537725456426, -3.6216851368345666`}}]}, 
    {Hue[0.671534243895806], AbsoluteThickness[0.5], 
     LineBox[{{7.016042773262057, -1.6516751997741703`}, {
      7.108282798810705, -1.7348892010832604`}}]}, 
    {Hue[0.6717510432019943], AbsoluteThickness[0.5], 
     LineBox[{{7.108282798810705, -1.7348892010832604`}, {
      7.322692665885227, -1.9171446844618552`}}]}, 
    {Hue[0.6889926694471449], AbsoluteThickness[0.5], 
     LineBox[{{4.262747380025582, 2.9608335378144637`}, {3.930376204807889, 
      3.179382975753243}}]}, 
    {Hue[0.6891778026439438], AbsoluteThickness[0.5], 
     LineBox[{{3.930376204807889, 3.179382975753243}, {3.6460075670016345`, 
      3.363384076381549}}]}, 
    {Hue[0.6487368623633046], AbsoluteThickness[0.5], 
     LineBox[{{6.976035586645406, 2.6360109109681593`}, {6.965115949693173, 
      2.849766562718292}}]}, 
    {Hue[0.6490890923597816], AbsoluteThickness[0.5], 
     LineBox[{{6.965115949693173, 2.849766562718292}, {6.967666509375516, 
      3.0871540433788582`}}]}, 
    {Hue[0.49599032076423527`], AbsoluteThickness[0.5], 
     LineBox[{{7.575596281441464, -2.0742213214166454`}, {
      7.497597923677322, -2.381853343242259}}]}, 
    {Hue[0.496182612030918], AbsoluteThickness[0.5], 
     LineBox[{{7.497597923677322, -2.381853343242259}, {
      7.425253906713074, -2.687134026360825}}]}, 
    {Hue[0.5793874130302016], AbsoluteThickness[0.5], 
     LineBox[{{8.300925599643978, 1.8751161064027455`}, {8.213321694087746, 
      2.097332886682772}}]}, 
    {Hue[0.5796230751423264], AbsoluteThickness[0.5], 
     LineBox[{{8.213321694087746, 2.097332886682772}, {8.118134773638745, 
      2.367199620738484}}]}, 
    {Hue[0.6936510797708647], AbsoluteThickness[0.5], 
     LineBox[{{6.597317163585998, 0.2927098512295937}, {6.363415043055312, 
      0.4016498220837778}}]}, 
    {Hue[0.6966964069492755], AbsoluteThickness[0.5], 
     LineBox[{{6.363415043055312, 0.4016498220837778}, {6.182146425329703, 
      0.4503276617857824}}]}, 
    {Hue[0.6504292755759215], AbsoluteThickness[0.5], 
     LineBox[{{5.063027041023098, -0.7413790643896072}, {
      4.900853631799341, -0.7909446785446752}}]}, 
    {Hue[0.6511963522080886], AbsoluteThickness[0.5], 
     LineBox[{{4.900853631799341, -0.7909446785446752}, {
      4.68166825234663, -0.834249674863952}}]}, 
    {Hue[0.4404366591871164], AbsoluteThickness[0.5], 
     LineBox[{{6.87725476830333, -1.3985091703707337`}, {
      6.876882042036348, -1.4007800698946995`}}]}, 
    {Hue[0.4409241299686784], AbsoluteThickness[0.5], 
     LineBox[{{6.876882042036348, -1.4007800698946995`}, {
      6.857503797053943, -1.631596318035911}}]}, 
    {Hue[0.4366345837532266], AbsoluteThickness[0.5], 
     LineBox[{{7.665234411496248, -1.0794506771927341`}, {
      7.68024549226014, -1.1129053057541303`}}]}, 
    {Hue[0.4368413436296256], AbsoluteThickness[0.5], 
     LineBox[{{7.68024549226014, -1.1129053057541303`}, {
      7.821491369572861, -1.4078409622156671`}}]}, 
    {Hue[0.6149346061874527], AbsoluteThickness[0.5], 
     LineBox[{{7.4586303530034055`, -0.17982614486075948`}, {
      7.409973767999245, -0.34290258960178854`}}]}, 
    {Hue[0.615476401286862], AbsoluteThickness[0.5], 
     LineBox[{{7.409973767999245, -0.34290258960178854`}, {
      7.360966391982671, -0.5777872347677663}}]}, 
    {Hue[0.6281727431773033], AbsoluteThickness[0.5], 
     LineBox[{{8.093840169841501, 0.11788342776077729`}, {8.099263833995069, 
      0.11815372593931085`}}]}, 
    {Hue[0.6285567225929385], AbsoluteThickness[0.5], 
     LineBox[{{8.099263833995069, 0.11815372593931085`}, {8.367052651840087, 
      0.14943348693084343`}}]}, 
    {Hue[0.6669412313244174], AbsoluteThickness[0.5], 
     LineBox[{{6.569808117033248, 1.2291413933762683`}, {6.364174656875045, 
      1.2860135822578602`}}]}, 
    {Hue[0.6671758913272675], AbsoluteThickness[0.5], 
     LineBox[{{6.364174656875045, 1.2860135822578602`}, {6.075636979375578, 
      1.354708650666049}}]}, 
    {Hue[0.4698846192302851], AbsoluteThickness[0.5], 
     LineBox[{{6.61876224892598, 0.6526344388411479}, {6.586204528821855, 
      0.5932172930600468}}]}, 
    {Hue[0.4702156968326831], AbsoluteThickness[0.5], 
     LineBox[{{6.586204528821855, 0.5932172930600468}, {6.462835957629652, 
      0.3962580859494457}}]}, 
    {Hue[0.678012924811717], AbsoluteThickness[0.5], 
     LineBox[{{7.150151747661281, 0.39767247546671286`}, {7.1720769430198406`,
       0.31847101385484194`}}]}, 
    {Hue[0.6781960574575586], AbsoluteThickness[0.5], 
     LineBox[{{7.1720769430198406`, 0.31847101385484194`}, {7.234378837136803,
       0.09399011306815416}}]}, 
    {Hue[0.31861827394652903`], AbsoluteThickness[0.5], 
     LineBox[{{7.184201931052216, 2.420319605206351}, {7.133875783682815, 
      2.4995612934954696`}}]}, 
    {Hue[0.3214339645928381], AbsoluteThickness[0.5], 
     LineBox[{{7.133875783682815, 2.4995612934954696`}, {7.013927724321256, 
      2.6322695172548927`}}]}, 
    {Hue[0.5656088021190544], AbsoluteThickness[0.5], 
     LineBox[{{7.013927724321256, 2.6322695172548927`}, {6.848681154583996, 
      2.563767102786102}}]}, 
    {Hue[0.4408745852992599], AbsoluteThickness[0.5], 
     LineBox[{{7.585569373781221, 2.3098714954677755`}, {7.496013510024986, 
      2.3292753428951984`}}]}, 
    {Hue[0.44336508704347505`], AbsoluteThickness[0.5], 
     LineBox[{{7.496013510024986, 2.3292753428951984`}, {7.311736426290701, 
      2.4019540191871216`}}]}, 
    {Hue[0.6964850044933766], AbsoluteThickness[0.5], 
     LineBox[{{7.311736426290701, 2.4019540191871216`}, {7.324263802301104, 
      2.5996489822677544`}}]}, 
    {Hue[0.4414266075973887], AbsoluteThickness[0.5], 
     LineBox[{{8.226143229094154, 1.6084734436314265`}, {8.210443865659897, 
      1.4367162884544131`}}]}, 
    {Hue[0.441781080142795], AbsoluteThickness[0.5], 
     LineBox[{{8.210443865659897, 1.4367162884544131`}, {8.201544877431438, 
      1.1301121692279588`}}]}, 
    {Hue[0.5330306822866534], AbsoluteThickness[0.5], 
     LineBox[{{8.084613540559982, 0.6849672883762922}, {8.074604986041667, 
      0.6682651451625644}}]}, 
    {Hue[0.5332275450094045], AbsoluteThickness[0.5], 
     LineBox[{{8.074604986041667, 0.6682651451625644}, {7.911408050797058, 
      0.38375460538032846`}}]}, 
    {Hue[0.6171317898798465], AbsoluteThickness[0.5], 
     LineBox[{{7.517440732883323, 0.8653015214522295}, {7.419272103491942, 
      0.6395345000659645}}]}, 
    {Hue[0.6175508540709476], AbsoluteThickness[0.5], 
     LineBox[{{7.419272103491942, 0.6395345000659645}, {7.3181519197722915`, 
      0.352797237396545}}]}, 
    {Hue[0.4618286164177783], AbsoluteThickness[0.5], 
     LineBox[{{7.432955462470727, -0.16461433324118624`}, {
      7.455973551255673, -0.3288069164334586}}]}, 
    {Hue[0.4620117331579669], AbsoluteThickness[0.5], 
     LineBox[{{7.455973551255673, -0.3288069164334586}, {
      7.4981801653118625`, -0.6300356770624768}}]}, 
    {Hue[0.42310621292427936`], AbsoluteThickness[0.5], 
     LineBox[{{5.095547716240053, 1.1493290099655205`}, {5.079872856413603, 
      1.1491620785190124`}}]}, 
    {Hue[0.4253977056694178], AbsoluteThickness[0.5], 
     LineBox[{{5.079872856413603, 1.1491620785190124`}, {4.884183329433145, 
      1.1158944386613112`}}]}, 
    {Hue[0.684598511373524], AbsoluteThickness[0.5], 
     LineBox[{{4.884183329433145, 1.1158944386613112`}, {4.859839177235601, 
      0.9188957354033456}}]}, 
    {Hue[0.43507929439906196`], AbsoluteThickness[0.5], 
     LineBox[{{4.349677723758777, 0.9390518793580136}, {4.172850117231622, 
      0.9655380592388819}}]}, 
    {Hue[0.4353096320792507], AbsoluteThickness[0.5], 
     LineBox[{{4.172850117231622, 0.9655380592388819}, {3.8771242751091632`, 
      1.0203648055844956`}}]}, 
    {Hue[0.4339610866057889], AbsoluteThickness[0.5], 
     LineBox[{{3.3824431749592, 1.0217437832545335`}, {3.1976610322841617`, 
      0.995866649072636}}]}, 
    {Hue[0.43414796585183996`], AbsoluteThickness[0.5], 
     LineBox[{{3.1976610322841617`, 0.995866649072636}, {2.851433958250631, 
      0.9509216586411364}}]}, 
    {Hue[0.6906376476834895], AbsoluteThickness[0.5], 
     LineBox[{{6.645263755494122, -1.866185420573217}, {
      6.699133125138902, -2.0989175663572746`}}]}, 
    {Hue[0.6909112831286653], AbsoluteThickness[0.5], 
     LineBox[{{6.699133125138902, -2.0989175663572746`}, {
      6.773314947406275, -2.362531201942003}}]}, 
    {Hue[0.46999845401826346`], AbsoluteThickness[0.5], 
     LineBox[{{7.211612833848461, 3.428151601916212}, {7.235215586903052, 
      3.562892476138304}}]}, 
    {Hue[0.47019672874788815`], AbsoluteThickness[0.5], 
     LineBox[{{7.235215586903052, 3.562892476138304}, {7.295863451371103, 
      3.872524143458744}}]}, 
    {Hue[0.5182782153932977], AbsoluteThickness[0.5], 
     LineBox[{{6.560121556279733, 3.120599832514311}, {6.598423449002021, 
      3.4356287083046526`}}]}, 
    {Hue[0.5210166185371307], AbsoluteThickness[0.5], 
     LineBox[{{6.598423449002021, 3.4356287083046526`}, {6.590262861182729, 
      3.6107477297384736`}}]}, 
    {Hue[0.29594124347179734`], AbsoluteThickness[0.5], 
     LineBox[{{4.138474141033417, 2.894172329501781}, {4.080013278153141, 
      2.925462430168098}}]}, 
    {Hue[0.29613591131558176`], AbsoluteThickness[0.5], 
     LineBox[{{4.080013278153141, 2.925462430168098}, {3.8485975650478776`, 
      3.044158711728051}}]}, 
    {Hue[0.4057237967371762], AbsoluteThickness[0.5], 
     LineBox[{{4.821355136964984, 2.914793700563985}, {4.75847914606916, 
      3.0799802186572953`}}]}, 
    {Hue[0.40600918129484126`], AbsoluteThickness[0.5], 
     LineBox[{{4.75847914606916, 3.0799802186572953`}, {4.667391997490735, 
      3.360284447263403}}]}, 
    {Hue[0.6494720350817275], AbsoluteThickness[0.5], 
     LineBox[{{5.30327979785749, 3.0437173209918855`}, {5.300767807755573, 
      3.1573029335704743`}}]}, 
    {Hue[0.6500488872319171], AbsoluteThickness[0.5], 
     LineBox[{{5.300767807755573, 3.1573029335704743`}, {5.277758717143984, 
      3.366557381576849}}]}, 
    {Hue[0.4486969921841547], AbsoluteThickness[0.5], 
     LineBox[{{5.4372327959670805`, 3.147729248239088}, {5.668793819653014, 
      3.263500829221451}}]}, 
    {Hue[0.44892186782513266`], AbsoluteThickness[0.5], 
     LineBox[{{5.668793819653014, 3.263500829221451}, {5.898000674453068, 
      3.368881404682121}}]}, 
    {Hue[0.6585213363451987], AbsoluteThickness[0.5], 
     LineBox[{{5.5885091764360935`, 3.0710654143640497`}, {5.751131827436362, 
      2.943367950001699}}]}, 
    {Hue[0.6638998935008597], AbsoluteThickness[0.5], 
     LineBox[{{5.751131827436362, 2.943367950001699}, {5.8574455005292645`, 
      2.816628517706533}}]}, 
    {Hue[0.4754708083223587], AbsoluteThickness[0.5], 
     LineBox[{{5.3812716959614155`, 2.6789453650180284`}, {5.58057510902941, 
      2.6898228005408806`}}]}, 
    {Hue[0.4758879707634813], AbsoluteThickness[0.5], 
     LineBox[{{5.58057510902941, 2.6898228005408806`}, {5.8427720735431, 
      2.7228770601336127`}}]}, 
    {Hue[0.510887827007969], AbsoluteThickness[0.5], 
     LineBox[{{5.644278954911342, 1.9798251660506894`}, {5.730922672863257, 
      1.8407078588253922`}}]}, 
    {Hue[0.5113819224139253], AbsoluteThickness[0.5], 
     LineBox[{{5.730922672863257, 1.8407078588253922`}, {5.820946895856471, 
      1.666690518766145}}]}, 
    {Hue[0.5468533482698824], AbsoluteThickness[0.5], 
     LineBox[{{5.118213821951841, 2.1161797360726418`}, {5.116121369485934, 
      2.0659492119851817`}}]}, 
    {Hue[0.5472461282077388], AbsoluteThickness[0.5], 
     LineBox[{{5.116121369485934, 2.0659492119851817`}, {5.092211361633606, 
      1.8481257845740613`}}]}, 
    {Hue[0.5813365223364136], AbsoluteThickness[0.5], 
     LineBox[{{4.60282190644634, 2.1683820226624086`}, {4.528702525048912, 
      2.134656689007143}}]}, 
    {Hue[0.585684062969953], AbsoluteThickness[0.5], 
     LineBox[{{4.528702525048912, 2.1346566890071426`}, {4.387311192534063, 
      2.0334509906640714`}}]}, 
    {Hue[0.6167346213757273], AbsoluteThickness[0.5], 
     LineBox[{{4.108774052035784, 2.8195567145089377`}, {4.033330609019542, 
      2.859855657210858}}]}, 
    {Hue[0.6169961719643599], AbsoluteThickness[0.5], 
     LineBox[{{4.033330609019542, 2.859855657210858}, {3.8238202808915664`, 
      2.9838764681221184`}}]}, 
    {Hue[0.6522912128415429], AbsoluteThickness[0.5], 
     LineBox[{{4.781731117882949, 2.928205971915999}, {4.714349277427727, 
      3.0919392338751}}]}, 
    {Hue[0.6529288734824963], AbsoluteThickness[0.5], 
     LineBox[{{4.714349277427727, 3.0919392338751}, {4.641487887169879, 
      3.3291496725314924`}}]}, 
    {Hue[0.687421509454595], AbsoluteThickness[0.5], 
     LineBox[{{5.634090986696744, 3.6286175405357364`}, {5.647119825236141, 
      3.6507051496787444`}}]}, 
    {Hue[0.6876508277050238], AbsoluteThickness[0.5], 
     LineBox[{{5.647119825236141, 3.6507051496787444`}, {5.825246023854241, 
      3.9303156676656474`}}]}, 
    {Hue[0.5262823965667619], AbsoluteThickness[0.5], 
     LineBox[{{3.832018778269499, 0.5492703607319532}, {3.6155978878735318`, 
      0.4541974514948907}}]}, 
    {Hue[0.5267426908305476], AbsoluteThickness[0.5], 
     LineBox[{{3.6155978878735318`, 0.4541974514948907}, {3.3805055831974253`,
       0.37158406636224844`}}]}, 
    {Hue[0.5853765586789969], AbsoluteThickness[0.5], 
     LineBox[{{4.8547025614206625`, 1.5800455557922033`}, {4.828195341595365, 
      1.5979025979241401`}}]}, 
    {Hue[0.5855722349669432], AbsoluteThickness[0.5], 
     LineBox[{{4.828195341595365, 1.5979025979241401`}, {4.573649858233891, 
      1.7627108399105784`}}]}, 
    {Hue[0.5196682077043561], AbsoluteThickness[0.5], 
     LineBox[{{4.613741195307599, 1.2388990593583549`}, {4.409518578935311, 
      1.2417270050109548`}}]}, 
    {Hue[0.5198626604365165], AbsoluteThickness[0.5], 
     LineBox[{{4.409518578935311, 1.2417270050109548`}, {4.098053619989534, 
      1.2406365255603116`}}]}, 
    {Hue[0.6264060134010948], AbsoluteThickness[0.5], 
     LineBox[{{5.090100669028041, 0.7405292894550553}, {5.047734840827478, 
      0.6931117933551798}}]}, 
    {Hue[0.6268223595192739], AbsoluteThickness[0.5], 
     LineBox[{{5.047734840827478, 0.6931117933551798}, {4.875021438164752, 
      0.5253603907749506}}]}, 
    {Hue[0.6967204742743025], AbsoluteThickness[0.5], 
     LineBox[{{6.021253812479882, -1.1394772355398624`}, {
      6.054017287501334, -1.3481992558309215`}}]}, 
    {Hue[0.6973098382601732], AbsoluteThickness[0.5], 
     LineBox[{{6.054017287501334, -1.3481992558309215`}, {
      6.070713347817326, -1.596189391324968}}]}, 
    {Hue[0.6901700180433511], AbsoluteThickness[0.5], 
     LineBox[{{8.090697161067123, -0.5731585137979203}, {
      8.163270847579373, -0.6293038944579838}}]}, 
    {Hue[0.6903672005960408], AbsoluteThickness[0.5], 
     LineBox[{{8.163270847579373, -0.6293038944579838}, {
      8.43413732121714, -0.8473346537407715}}]}, 
    {Hue[0.4809588257402653], AbsoluteThickness[0.5], 
     LineBox[{{3.6713872384178625`, 1.2136497580075274`}, {
      3.4149910609401246`, 1.324466377966882}}]}, 
    {Hue[0.4815169579619012], AbsoluteThickness[0.5], 
     LineBox[{{3.4149910609401246`, 1.324466377966882}, {3.2065309528116637`, 
      1.3940584934118068`}}]}, 
    {Hue[0.683885692646955], AbsoluteThickness[0.5], 
     LineBox[{{3.062560437831467, -1.1680963505251802`}, {
      2.9761983032071324`, -1.13879043959612}}]}, 
    {Hue[0.6886344735836453], AbsoluteThickness[0.5], 
     LineBox[{{2.9761983032071324`, -1.13879043959612}, {
      2.843136121561057, -1.0614196196331982`}}]}, 
    {Hue[0.4741137425282695], AbsoluteThickness[0.5], 
     LineBox[{{3.0912834629691233`, -1.7539364159912485`}, {
      3.0188197633552356`, -1.8708259074624283`}}]}, 
    {Hue[0.474644168112421], AbsoluteThickness[0.5], 
     LineBox[{{3.0188197633552356`, -1.8708259074624283`}, {
      2.910787109517695, -2.0825841162416596`}}]}, 
    {Hue[0.6918682126907088], AbsoluteThickness[0.5], 
     LineBox[{{3.589344272267322, -2.1020351712178833`}, {
      3.7667858207547886`, -2.597483960778643}}]}, 
    {Hue[0.6922841010473781], AbsoluteThickness[0.5], 
     LineBox[{{3.7667858207547886`, -2.597483960778643}, {
      3.836149343049395, -2.845038464983356}}]}, 
    {Hue[0.5756251511181467], AbsoluteThickness[0.5], 
     LineBox[{{3.5671895390265544`, 2.1378958136711663`}, {
      3.4381985078642834`, 2.3465934659157877`}}]}, 
    {Hue[0.5762104606885123], AbsoluteThickness[0.5], 
     LineBox[{{3.4381985078642834`, 2.3465934659157877`}, {
      3.3278659338480487`, 2.5662557517157665`}}]}, 
    {Hue[0.5653883544587364], AbsoluteThickness[0.5], 
     LineBox[{{4.380048048528092, 2.0105057011738268`}, {4.3348175139279395`, 
      2.1146606225039792`}}]}, 
    {Hue[0.5655865825596527], AbsoluteThickness[0.5], 
     LineBox[{{4.3348175139279395`, 2.1146606225039792`}, {4.199617787190727, 
      2.409714096482288}}]}, 
    {Hue[0.6657491134199618], AbsoluteThickness[0.5], 
     LineBox[{{3.84117167131676, 0.5997028117287332}, {3.605395170373543, 
      0.5641122271604382}}]}, 
    {Hue[0.6659682561303614], AbsoluteThickness[0.5], 
     LineBox[{{3.605395170373543, 0.5641122271604382}, {3.3170462945642005`, 
      0.5115606526621097}}]}, 
    {Hue[0.4664155857688208], AbsoluteThickness[0.5], 
     LineBox[{{5.224191606502897, 2.8622039459876105`}, {5.137604686626926, 
      2.930542326395737}}]}, 
    {Hue[0.4666254629865741], AbsoluteThickness[0.5], 
     LineBox[{{5.137604686626926, 2.930542326395737}, {4.886521337520707, 
      3.1181709029604834`}}]}, 
    {Hue[0.5958125018208535], AbsoluteThickness[0.5], 
     LineBox[{{7.093661954241497, 1.5245104065784694`}, {7.1663719160576385`, 
      1.4378542619639703`}}]}, 
    {Hue[0.5960932334094504], AbsoluteThickness[0.5], 
     LineBox[{{7.1663719160576385`, 1.4378542619639703`}, {7.352014452126943, 
      1.193465846067691}}]}, 
    {Hue[0.6596558616035921], AbsoluteThickness[0.5], 
     LineBox[{{6.7707649418967755`, 1.571081812287572}, {6.829062553610241, 
      1.3980842767110477`}}]}, 
    {Hue[0.6611106918324947], AbsoluteThickness[0.5], 
     LineBox[{{6.829062553610241, 1.3980842767110477`}, {6.869205868538643, 
      1.1908184192383027`}}]}, 
    {Hue[0.6353683532486147], AbsoluteThickness[0.5], 
     LineBox[{{6.327120076572609, 2.606217434266993}, {6.191739739163332, 
      2.5756248385797793`}}]}, 
    {Hue[0.6355917983024083], AbsoluteThickness[0.5], 
     LineBox[{{6.191739739163332, 2.5756248385797793`}, {5.882439085046726, 
      2.4952029161458746`}}]}, 
    {Hue[0.5305954294035036], AbsoluteThickness[0.5], 
     LineBox[{{6.829041889572819, 3.1787664066759094`}, {7.0636939052972245`, 
      3.176395837595149}}]}, 
    {Hue[0.5308935287390245], AbsoluteThickness[0.5], 
     LineBox[{{7.0636939052972245`, 3.176395837595149}, {7.36873589652042, 
      3.1892380843199777`}}]}, 
    {Hue[0.24381049258833173`], AbsoluteThickness[0.5], 
     LineBox[{{6.883506851961149, 3.3440089025840014`}, {6.887209292294565, 
      3.364039245201363}}]}, 
    {Hue[0.24402813711677068`], AbsoluteThickness[0.5], 
     LineBox[{{6.887209292294565, 3.364039245201363}, {6.942088537623861, 
      3.6182506337634655`}}]}, 
    {Hue[0.6768809293480227], AbsoluteThickness[0.5], 
     LineBox[{{6.942088537623861, 3.6182506337634655`}, {7.0291737225527635`, 
      3.3731969004548623`}}]}, 
    {Hue[0.5336137433524455], AbsoluteThickness[0.5], 
     LineBox[{{6.730079919853941, 3.4260557860474723`}, {6.614471715614493, 
      3.468972186371477}}]}, 
    {Hue[0.5337971477984682], AbsoluteThickness[0.5], 
     LineBox[{{6.614471715614493, 3.468972186371477}, {6.3305081301654775`, 
      3.5734870220448216`}}]}, 
    {Hue[0.635167990547658], AbsoluteThickness[0.5], 
     LineBox[{{7.090703027845902, 2.372357661055526}, {7.258892531326898, 
      2.1212958894635108`}}]}, 
    {Hue[0.6596442188123276], AbsoluteThickness[0.5], 
     LineBox[{{5.589205417729699, 2.225663533370224}, {5.358245643211889, 
      2.1082057756821846`}}]}, 
    {Hue[0.6673638104804522], AbsoluteThickness[0.5], 
     LineBox[{{5.358245643211889, 2.1082057756821846`}, {5.195563023826857, 
      2.0683216790920302`}}]}, 
    {Hue[0.5956273440140337], AbsoluteThickness[0.5], 
     LineBox[{{5.1144186586145235`, 2.7118462900651146`}, {4.908658190760104, 
      2.788062173697886}}]}, 
    {Hue[0.5958939671554516], AbsoluteThickness[0.5], 
     LineBox[{{4.908658190760104, 2.788062173697886}, {4.631857465184819, 
      2.876601243636376}}]}, 
    {Hue[0.47146935771463383`], AbsoluteThickness[0.5], 
     LineBox[{{8.113793252067586, 1.4194705564399406`}, {8.169498280706339, 
      1.4059822232091812`}}]}, 
    {Hue[0.4717894272129454], AbsoluteThickness[0.5], 
     LineBox[{{8.169498280706339, 1.4059822232091812`}, {8.469682112473555, 
      1.3151141464055818`}}]}, 
    {Hue[0.6667701932785116], AbsoluteThickness[0.5], 
     LineBox[{{4.694976960098423, 0.14421027926079488`}, {4.66760203244225, 
      0.12211145550534279`}}]}, 
    {Hue[0.6669544278842012], AbsoluteThickness[0.5], 
     LineBox[{{4.66760203244225, 0.12211145550534279`}, {
      4.428739814516301, -0.06855911911277814}}]}, 
    {Hue[0.5262590227743418], AbsoluteThickness[0.5], 
     LineBox[{{3.1565195605696372`, 1.3367049720306945`}, {
      3.0764932009547103`, 1.3567604682757834`}}]}, 
    {Hue[0.5268725923448597], AbsoluteThickness[0.5], 
     LineBox[{{3.0764932009547103`, 1.3567604682757834`}, {
      2.8263520093400993`, 1.444130763380094}}]}, 
    {Hue[0.6925750389687751], AbsoluteThickness[0.5], 
     LineBox[{{4.388221823160652, 2.9095274470816745`}, {4.388688848237903, 
      2.920111326351133}}]}, 
    {Hue[0.6942206165356551], AbsoluteThickness[0.5], 
     LineBox[{{4.388688848237903, 2.920111326351133}, {4.425356686909021, 
      3.1169129380419007`}}]}, 
    {Hue[0.6552466075428386], AbsoluteThickness[0.5], 
     LineBox[{{3.675537600714022, 2.844785459439058}, {3.6666652177736796`, 
      2.9995176613208825`}}]}, 
    {Hue[0.6736727342873569], AbsoluteThickness[0.5], 
     LineBox[{{3.6666652177736796`, 2.9995176613208825`}, {
      3.6155601683525647`, 3.140748752813215}}]}, 
    {Hue[0.45352715189127835`], AbsoluteThickness[0.5], 
     LineBox[{{3.3314682700404803`, 2.4287451418733497`}, {
      3.2138668225961746`, 2.4745554143657085`}}]}, 
    {Hue[0.4537294332611836], AbsoluteThickness[0.5], 
     LineBox[{{3.2138668225961746`, 2.4745554143657085`}, {2.868843846892141, 
      2.60011284487213}}]}, 
    {Hue[0.6651310453949988], AbsoluteThickness[0.5], 
     LineBox[{{3.4118601926906513`, 1.9774712451865195`}, {
      3.3814054766801434`, 1.8943963373611692`}}]}, 
    {Hue[0.6653640423985672], AbsoluteThickness[0.5], 
     LineBox[{{3.3814054766801434`, 1.8943963373611692`}, {3.26131283152225, 
      1.5996640494127237`}}]}, 
    {Hue[0.6982375706579755], AbsoluteThickness[0.5], 
     LineBox[{{3.345010882115403, 1.4163935745926908`}, {3.3381077552641885`, 
      1.405688281109693}}]}, 
    {Hue[0.6984306057326943], AbsoluteThickness[0.5], 
     LineBox[{{3.3381077552641885`, 1.405688281109693}, {3.191782608675725, 
      1.1704668874483517`}}]}, 
    {Hue[0.6687934295510292], AbsoluteThickness[0.5], 
     LineBox[{{3.3311028726883682`, -2.9944225439346672`}, {
      2.9000758278077194`, -3.30278184605173}}]}, 
    {Hue[0.6694310116036395], AbsoluteThickness[0.5], 
     LineBox[{{2.9000758278077194`, -3.30278184605173}, {
      2.69371070634779, -3.4233066182279197`}}]}, 
    {Hue[0.6419326994140514], AbsoluteThickness[0.5], 
     LineBox[{{6.770942851840212, -3.9269453409866735`}, {
      6.968359650415052, -4.329024738210822}}]}, 
    {Hue[0.6421549369204606], AbsoluteThickness[0.5], 
     LineBox[{{6.968359650415052, -4.329024738210822}, {
      7.114318319292503, -4.651750633423436}}]}, 
    {Hue[0.6720859062714739], AbsoluteThickness[0.5], 
     LineBox[{{6.2854634585950215`, 2.930051637924093}, {6.330169129435359, 
      2.933234084288223}}]}, 
    {Hue[0.6722790753170463], AbsoluteThickness[0.5], 
     LineBox[{{6.330169129435359, 2.933234084288223}, {6.65303976200892, 
      2.961530386470526}}]}, 
    {Hue[0.6124589413789572], AbsoluteThickness[0.5], 
     LineBox[{{4.653245556053751, -3.501540898488227}, {
      4.773889911495325, -3.6391532943810976`}}]}, 
    {Hue[0.6169163792292381], AbsoluteThickness[0.5], 
     LineBox[{{4.773889911495325, -3.6391532943810976`}, {
      4.854366695460026, -3.7783913530293813`}}]}, 
    {Hue[0.6970844199111984], AbsoluteThickness[0.5], 
     LineBox[{{5.421968446816875, -1.7712630858995746`}, {
      5.607815702618099, -1.7564436272019612`}}]}, 
    {Hue[0.6972695348235728], AbsoluteThickness[0.5], 
     LineBox[{{5.607815702618099, -1.7564436272019612`}, {
      5.921928558588366, -1.7290781022400192`}}]}, 
    {Hue[0.6940949196700413], AbsoluteThickness[0.5], 
     LineBox[{{3.7481042170747867`, 2.8938741145769025`}, {
      3.8509603849960232`, 3.1063593674367422`}}]}, 
    {Hue[0.6949321122497956], AbsoluteThickness[0.5], 
     LineBox[{{3.8509603849960232`, 3.1063593674367422`}, {3.933775921915895, 
      3.33685800507418}}]}, 
    {Hue[0.414576087408847], AbsoluteThickness[0.5], 
     LineBox[{{2.656496102702559, 2.8886382820148584`}, {2.6041384557393847`, 
      2.9145896264108724`}}]}, 
    {Hue[0.41475942742867755`], AbsoluteThickness[0.5], 
     LineBox[{{2.6041384557393847`, 2.9145896264108724`}, {2.319455317078221, 
      3.0548251894317278`}}]}, 
    {Hue[0.6951853818910017], AbsoluteThickness[0.5], 
     LineBox[{{2.1617716970949905`, 1.7234169393512568`}, {
      2.0981549132147475`, 1.6950179459541808`}}]}, 
    {Hue[0.6955522398064655], AbsoluteThickness[0.5], 
     LineBox[{{2.0981549132147475`, 1.6950179459541808`}, {
      1.8170903467914052`, 1.5473035894966969`}}]}, 
    {Hue[0.6896518362400436], AbsoluteThickness[0.5], 
     LineBox[{{5.858952183105744, 2.80193995526425}, {6.340608338011412, 
      3.0416477975838894`}}]}, 
    {Hue[0.6905766860656359], AbsoluteThickness[0.5], 
     LineBox[{{6.340608338011412, 3.0416477975838894`}, {6.558434112117004, 
      3.121394561388964}}]}, 
    {Hue[0.6175110175876752], AbsoluteThickness[0.5], 
     LineBox[{{2.8724930742377612`, -0.8881629628885982}, {
      2.8708371103867525`, -0.888634715180869}}]}, 
    {Hue[0.6231028857540123], AbsoluteThickness[0.5], 
     LineBox[{{2.8708371103867525`, -0.888634715180869}, {
      2.7207957282082207`, -0.8988499529645195}}]}, 
    {Hue[0.663605285752009], AbsoluteThickness[0.5], 
     LineBox[{{2.3099577862941993`, -1.0111371331343069`}, {
      2.1558050837059786`, -0.9965654936102184}}]}, 
    {Hue[0.6638022949102302], AbsoluteThickness[0.5], 
     LineBox[{{2.1558050837059786`, -0.9965654936102184}, {
      1.779063316539821, -0.9682283827490923}}]}, 
    {Hue[0.6899668931729369], AbsoluteThickness[0.5], 
     LineBox[{{4.335307961329535, 0.9947123023651957}, {4.167880082384757, 
      1.1262556643233088`}}]}, 
    {Hue[0.6953690855647625], AbsoluteThickness[0.5], 
     LineBox[{{4.167880082384757, 1.1262556643233088`}, {4.019750937957919, 
      1.1993746870569428`}}]}, 
    {Hue[0.6380608964883709], AbsoluteThickness[0.5], 
     LineBox[{{7.9507690227662335`, 0.8052219787546446}, {7.976217467467496, 
      0.8887484947175992}}]}, 
    {Hue[0.6382446577348225], AbsoluteThickness[0.5], 
     LineBox[{{7.976217467467496, 0.8887484947175992}, {8.073286747564538, 
      1.2026505553483355`}}]}, 
    {Hue[0.6624239608811133], AbsoluteThickness[0.5], 
     LineBox[{{6.639163844367371, 0.35600074813492016`}, {6.5917685741927246`,
       0.47514305546185914`}}]}, 
    {Hue[0.6630224944182963], AbsoluteThickness[0.5], 
     LineBox[{{6.5917685741927246`, 0.47514305546185914`}, {6.499397579882815,
       0.6579562769550734}}]}, 
    {Hue[0.6296792182914213], AbsoluteThickness[0.5], 
     LineBox[{{6.364338814151551, -1.8536428419150592`}, {
      6.301717809521697, -1.869685007195425}}]}, 
    {Hue[0.6306840952722055], AbsoluteThickness[0.5], 
     LineBox[{{6.301717809521697, -1.869685007195425}, {
      6.135532990828835, -1.892394399522408}}]}, 
    {Hue[0.5812672505416236], AbsoluteThickness[0.5], 
     LineBox[{{7.388525244576338, -2.6663777250317304`}, {
      7.385285491719142, -2.67304322521958}}]}, 
    {Hue[0.5814671739557594], AbsoluteThickness[0.5], 
     LineBox[{{7.385285491719142, -2.67304322521958}, {
      7.249945292601955, -2.9372034400351885`}}]}, 
    {Hue[0.6507226789846113], AbsoluteThickness[0.5], 
     LineBox[{{7.618630463181174, -2.1975476124328246`}, {
      7.383847382218892, -2.223507775755651}}]}, 
    {Hue[0.6509059646706404], AbsoluteThickness[0.5], 
     LineBox[{{7.383847382218892, -2.223507775755651}, {
      7.071484832429513, -2.258721142881024}}]}, 
    {Hue[0.6512463887571017], AbsoluteThickness[0.5], 
     LineBox[{{8.10977393330874, -1.6417027819848846`}, {
      8.10964461137912, -1.6411335578766304`}}]}, 
    {Hue[0.6516610693442125], AbsoluteThickness[0.5], 
     LineBox[{{8.10964461137912, -1.6411335578766304`}, {
      8.037465293458888, -1.4027113492410619`}}]}, 
    {Hue[0.6279611632937273], AbsoluteThickness[0.5], 
     LineBox[{{8.232240954122844, -0.5926830924116476}, {
      8.307891776053028, -0.40206142026351155`}}]}, 
    {Hue[0.6283418968443224], AbsoluteThickness[0.5], 
     LineBox[{{8.307891776053028, -0.40206142026351155`}, {
      8.397117182488653, -0.1252058009954891}}]}, 
    {Hue[0.6613875147625261], AbsoluteThickness[0.5], 
     LineBox[{{6.436956136237303, -0.4163147868373776}, {
      6.378723026894536, -0.3138436879739406}}]}, 
    {Hue[0.6621368851620993], AbsoluteThickness[0.5], 
     LineBox[{{6.378723026894536, -0.3138436879739406}, {
      6.236712677796566, -0.11373154791280835`}}]}, 
    {Hue[0.6350422694106697], AbsoluteThickness[0.5], 
     LineBox[{{4.902025869288929, -0.9353251541593269}, {
      4.425748637850462, -0.7632457802846241}}]}, 
    {Hue[0.6352981549000425], AbsoluteThickness[0.5], 
     LineBox[{{4.425748637850462, -0.7632457802846241}, {
      4.152490345497259, -0.6774240377395112}}]}, 
    {Hue[0.5180457498887839], AbsoluteThickness[0.5], 
     LineBox[{{5.317042174504154, -2.496568643107816}, {
      5.267414443626319, -2.551733145538712}}]}, 
    {Hue[0.5183749559004831], AbsoluteThickness[0.5], 
     LineBox[{{5.267414443626319, -2.551733145538712}, {
      5.077151719566918, -2.7896193673170946`}}]}, 
    {Hue[0.666665964243349], AbsoluteThickness[0.5], 
     LineBox[{{3.865264422165415, 0.01558219543576532}, {3.5553008412191462`, 
      0.10418403203907302`}}]}, 
    {Hue[0.6698491851131112], AbsoluteThickness[0.5], 
     LineBox[{{3.5553008412191462`, 0.10418403203907302`}, {
      3.3735957448722327`, 0.12285257957385658`}}]}, 
    {Hue[0.67166157609321], AbsoluteThickness[0.5], 
     LineBox[{{6.547614972963494, 2.660373650005636}, {6.554837225932531, 
      2.7133042740968643`}}]}, 
    {Hue[0.6801559164001664], AbsoluteThickness[0.5], 
     LineBox[{{6.554837225932531, 2.7133042740968643`}, {6.613477516367497, 
      2.8636309481357225`}}]}, 
    {Hue[0.628864708226145], AbsoluteThickness[0.5], 
     LineBox[{{7.015837296923768, 3.1035802932107157`}, {6.969200230953496, 
      3.3494134145434793`}}]}, 
    {Hue[0.6290486866463277], AbsoluteThickness[0.5], 
     LineBox[{{6.969200230953496, 3.3494134145434793`}, {6.920138022643766, 
      3.6150100035364083`}}]}, 
    {Hue[0.5070983174469925], AbsoluteThickness[0.5], 
     LineBox[{{2.1844334948319033`, 0.8577212354772984}, {2.1176780270552102`,
       0.888479135663443}}]}, 
    {Hue[0.5073133708640748], AbsoluteThickness[0.5], 
     LineBox[{{2.1176780270552102`, 0.888479135663443}, {1.8258596958523285`, 
      1.0332433360189008`}}]}, 
    {Hue[0.5784817862276784], AbsoluteThickness[0.5], 
     LineBox[{{3.566128926377194, -1.7924870565715108`}, {
      3.4861205041345973`, -1.8568951960375732`}}]}, 
    {Hue[0.5813666814604382], AbsoluteThickness[0.5], 
     LineBox[{{3.4861205041345973`, -1.8568951960375732`}, {
      3.383789456511689, -1.9729749954037983`}}]}, 
    {Hue[0.6489945547963714], AbsoluteThickness[0.5], 
     LineBox[{{5.613537725456426, -3.6216851368345666`}, {
      5.625609448203834, -3.6732339857997185`}}]}, 
    {Hue[0.6494995456149084], AbsoluteThickness[0.5], 
     LineBox[{{5.625609448203834, -3.6732339857997185`}, {
      5.7020451715431815`, -3.9112365439015684`}}]}, 
    {Hue[0.6719678425081826], AbsoluteThickness[0.5], 
     LineBox[{{7.322692665885227, -1.9171446844618552`}, {
      7.338693997548402, -1.9299532556065953`}}]}, 
    {Hue[0.6722342546716031], AbsoluteThickness[0.5], 
     LineBox[{{7.338693997548402, -1.9299532556065953`}, {
      7.555889127695717, -2.088286515364006}}]}, 
    {Hue[0.6893629358407425], AbsoluteThickness[0.5], 
     LineBox[{{3.6460075670016345`, 3.363384076381549}, {3.641308145352485, 
      3.366375990633749}}]}, 
    {Hue[0.6895539960180694], AbsoluteThickness[0.5], 
     LineBox[{{3.641308145352485, 3.366375990633749}, {3.3690487587760924`, 
      3.5453326097585736`}}]}, 
    {Hue[0.6494413223562586], AbsoluteThickness[0.5], 
     LineBox[{{6.967666509375516, 3.0871540433788582`}, {6.9869882325984545`, 
      3.3530902027251317`}}]}, 
    {Hue[0.649668860711992], AbsoluteThickness[0.5], 
     LineBox[{{6.9869882325984545`, 3.3530902027251317`}, {6.996997111901896, 
      3.6103894700818837`}}]}, 
    {Hue[0.49637490329760076`], AbsoluteThickness[0.5], 
     LineBox[{{7.425253906713074, -2.687134026360825}, {
      7.419796584842048, -2.7118805555779257`}}]}, 
    {Hue[0.4970207107176502], AbsoluteThickness[0.5], 
     LineBox[{{7.419796584842048, -2.7118805555779257`}, {
      7.34954007318907, -2.9311449148270943`}}]}, 
    {Hue[0.5798587372544511], AbsoluteThickness[0.5], 
     LineBox[{{8.118134773638745, 2.367199620738484}, {8.117789784286584, 
      2.3683044252525343`}}]}, 
    {Hue[0.580172839511414], AbsoluteThickness[0.5], 
     LineBox[{{8.117789784286584, 2.3683044252525343`}, {8.023701590059098, 
      2.6198351822922343`}}]}, 
    {Hue[0.6997417341276861], AbsoluteThickness[0.5], 
     LineBox[{{6.182146425329703, 0.4503276617857824}, {6.0872471334290434`, 
      0.4587794600283177}}]}, 
    {Hue[0.7], AbsoluteThickness[0.5], 
     LineBox[{{6.0872471334290434`, 0.4587794600283177}, {5.809237141424264, 
      0.4956500394430211}}]}, 
    {Hue[0.6519634288402555], AbsoluteThickness[0.5], 
     LineBox[{{4.68166825234663, -0.834249674863952}, {
      4.601379121612772, -0.8417789523378222}}]}, 
    {Hue[0.6527864139944284], AbsoluteThickness[0.5], 
     LineBox[{{4.601379121612772, -0.8417789523378222}, {
      4.382315238116761, -0.8858538580442203}}]}, 
    {Hue[0.4414116007502405], AbsoluteThickness[0.5], 
     LineBox[{{6.857503797053943, -1.631596318035911}, {
      6.855348031303997, -2.0773063315811187`}}]}, 
    {Hue[0.4416623730386507], AbsoluteThickness[0.5], 
     LineBox[{{6.855348031303997, -2.0773063315811187`}, {
      6.842558002495407, -2.3562116887071047`}}]}, 
    {Hue[0.43704810350602485`], AbsoluteThickness[0.5], 
     LineBox[{{7.821491369572861, -1.4078409622156671`}, {
      7.85970811237031, -1.482799807515262}}]}, 
    {Hue[0.437474692369067], AbsoluteThickness[0.5], 
     LineBox[{{7.85970811237031, -1.482799807515262}, {
      7.987758823987346, -1.6947174978191548`}}]}, 
    {Hue[0.6160181963862715], AbsoluteThickness[0.5], 
     LineBox[{{7.360966391982671, -0.5777872347677663}, {
      7.355657786762561, -0.6212897865834256}}]}, 
    {Hue[0.6163723658530607], AbsoluteThickness[0.5], 
     LineBox[{{7.355657786762561, -0.6212897865834256}, {
      7.296808618032822, -0.9383558163661906}}]}, 
    {Hue[0.6674105513301176], AbsoluteThickness[0.5], 
     LineBox[{{6.075636979375578, 1.354708650666049}, {6.024587853821008, 
      1.3649310161556567`}}]}, 
    {Hue[0.6800028446846077], AbsoluteThickness[0.5], 
     LineBox[{{6.024587853821008, 1.3649310161556567`}, {5.892238369604698, 
      1.4306052722726568`}}]}, 
    {Hue[0.4705467744350809], AbsoluteThickness[0.5], 
     LineBox[{{6.462835957629652, 0.3962580859494457}, {6.401800641306805, 
      0.31038149519909297`}}]}, 
    {Hue[0.4713486385109845], AbsoluteThickness[0.5], 
     LineBox[{{6.401800641306805, 0.31038149519909297`}, {6.243269221268635, 
      0.13022919532730273`}}]}, 
    {Hue[0.6783791901034002], AbsoluteThickness[0.5], 
     LineBox[{{7.234378837136803, 0.09399011306815414}, {
      7.300742584987046, -0.14451621421034622`}}]}, 
    {Hue[0.6788028982504964], AbsoluteThickness[0.5], 
     LineBox[{{7.300742584987046, -0.14451621421034622`}, {
      7.35088627346321, -0.39228288094063185`}}]}, 
    {Hue[0.5627931114727422], AbsoluteThickness[0.5], 
     LineBox[{{7.133875783682815, 2.4995612934954696`}, {7.180237032875569, 
      2.637246016100087}}]}, 
    {Hue[0.5629762430300658], AbsoluteThickness[0.5], 
     LineBox[{{7.180237032875569, 2.637246016100087}, {7.267663358684314, 
      2.8974339656723194`}}]}, 
    {Hue[0.32424965523914695`], AbsoluteThickness[0.5], 
     LineBox[{{7.013927724321256, 2.6322695172548927`}, {6.881221144900748, 
      2.7367065227106515`}}]}, 
    {Hue[0.32468043709593175`], AbsoluteThickness[0.5], 
     LineBox[{{6.881221144900748, 2.7367065227106515`}, {6.656119914545259, 
      2.8887936551931834`}}]}, 
    {Hue[0.5684244927653632], AbsoluteThickness[0.5], 
     LineBox[{{6.848681154583996, 2.563767102786102}, {6.592467754632565, 
      2.4023860998368267`}}]}, 
    {Hue[0.5764846629515463], AbsoluteThickness[0.5], 
     LineBox[{{6.592467754632565, 2.4023860998368267`}, {6.435364607407312, 
      2.3487108780900354`}}]}, 
    {Hue[0.6939945027491585], AbsoluteThickness[0.5], 
     LineBox[{{7.496013510024986, 2.3292753428951984`}, {7.340774332740918, 
      2.1929983763609657`}}]}, 
    {Hue[0.698854128738961], AbsoluteThickness[0.5], 
     LineBox[{{7.340774332740918, 2.1929983763609657`}, {7.198132313286852, 
      2.111419819714874}}]}, 
    {Hue[0.4458555887876901], AbsoluteThickness[0.5], 
     LineBox[{{7.311736426290701, 2.4019540191871216`}, {7.132449862213479, 
      2.5089289844678593`}}]}, 
    {Hue[0.4463551270992128], AbsoluteThickness[0.5], 
     LineBox[{{7.132449862213479, 2.5089289844678593`}, {6.90909050153152, 
      2.6189814743779674`}}]}, 
    {Hue[0.6989755062375915], AbsoluteThickness[0.5], 
     LineBox[{{7.324263802301104, 2.5996489822677544`}, {7.351885704301527, 
      2.7200123734695314`}}]}, 
    {Hue[0.4421355526882014], AbsoluteThickness[0.5], 
     LineBox[{{8.201544877431438, 1.1301121692279588`}, {8.20785455614225, 
      0.9396647794255726}}]}, 
    {Hue[0.44231952916364964`], AbsoluteThickness[0.5], 
     LineBox[{{8.20785455614225, 0.9396647794255726}, {8.220310908486281, 
      0.6114199351966487}}]}, 
    {Hue[0.5334244077321554], AbsoluteThickness[0.5], 
     LineBox[{{7.911408050797058, 0.38375460538032846`}, {7.878705842196716, 
      0.3241365905784629}}]}, 
    {Hue[0.5336511639729644], AbsoluteThickness[0.5], 
     LineBox[{{7.878705842196716, 0.3241365905784629}, {7.713475040829654, 
      0.0453881684976358}}]}, 
    {Hue[0.6179699182620485], AbsoluteThickness[0.5], 
     LineBox[{{7.3181519197722915`, 0.352797237396545}, {7.29714803826906, 
      0.27628610566998607`}}]}, 
    {Hue[0.6183916635403894], AbsoluteThickness[0.5], 
     LineBox[{{7.29714803826906, 0.27628610566998607`}, {7.232629346704844, 
      0.09353097316202831}}]}, 
    {Hue[0.46219484989815557`], AbsoluteThickness[0.5], 
     LineBox[{{7.4981801653118625`, -0.6300356770624768}, {
      7.5252117425817255`, -0.8230631277620202}}]}, 
    {Hue[0.46237820802286184`], AbsoluteThickness[0.5], 
     LineBox[{{7.5252117425817255`, -0.8230631277620201}, {
      7.5681643822077485`, -1.1355830966992775`}}]}, 
    {Hue[0.6823070186283825], AbsoluteThickness[0.5], 
     LineBox[{{5.079872856413603, 1.1491620785190124`}, {4.946357056947727, 
      1.3371832328657298`}}]}, 
    {Hue[0.6834723842780629], AbsoluteThickness[0.5], 
     LineBox[{{4.946357056947727, 1.3371832328657298`}, {4.837885967467196, 
      1.5380887190130017`}}]}, 
    {Hue[0.4276891984145562], AbsoluteThickness[0.5], 
     LineBox[{{4.884183329433145, 1.1158944386613112`}, {4.6865304189315635`, 
      1.0490457747668551`}}]}, 
    {Hue[0.42787635920357125`], AbsoluteThickness[0.5], 
     LineBox[{{4.6865304189315635`, 1.0490457747668551`}, {4.349692745732636, 
      0.9390177742939605}}]}, 
    {Hue[0.6868900041186624], AbsoluteThickness[0.5], 
     LineBox[{{4.859839177235601, 0.9188957354033456}, {4.8632038120715215`, 
      0.8222252776510854}}]}, 
    {Hue[0.6877714977615023], AbsoluteThickness[0.5], 
     LineBox[{{4.8632038120715215`, 0.8222252776510854}, {4.846694276822012, 
      0.5984956863594586}}]}, 
    {Hue[0.43553996975943937`], AbsoluteThickness[0.5], 
     LineBox[{{3.8771242751091632`, 1.0203648055844956`}, {3.689696749116665, 
      1.0618743042281937`}}]}, 
    {Hue[0.4358421268876043], AbsoluteThickness[0.5], 
     LineBox[{{3.689696749116665, 1.0618743042281937`}, {3.412383262155191, 
      1.1080402052512859`}}]}, 
    {Hue[0.43433484509789116`], AbsoluteThickness[0.5], 
     LineBox[{{2.851433958250631, 0.9509216586411364}, {2.5742653848532453`, 
      0.9177688138836663}}]}, 
    {Hue[0.4346705487914559], AbsoluteThickness[0.5], 
     LineBox[{{2.5742653848532453`, 0.9177688138836663}, {2.3595970983370855`,
       0.9048842717050697}}]}, 
    {Hue[0.6911849185738413], AbsoluteThickness[0.5], 
     LineBox[{{6.773314947406275, -2.362531201942003}, {
      6.925505318214823, -2.8200025049527064`}}]}, 
    {Hue[0.6913691681057679], AbsoluteThickness[0.5], 
     LineBox[{{6.925505318214823, -2.8200025049527064`}, {
      7.028902406669837, -3.1251692495618935`}}]}, 
    {Hue[0.5237550216809634], AbsoluteThickness[0.5], 
     LineBox[{{6.590262861182729, 3.6107477297384736`}, {6.58082047593546, 
      3.654169993663881}}]}, 
    {Hue[0.527821980788264], AbsoluteThickness[0.5], 
     LineBox[{{6.58082047593546, 3.654169993663881}, {6.576370351743306, 
      3.840641917987641}}]}, 
    {Hue[0.29633057915936617`], AbsoluteThickness[0.5], 
     LineBox[{{3.8485975650478776`, 3.044158711728051}, {3.7427671292921243`, 
      3.096120721976002}}]}, 
    {Hue[0.30919718830135096`], AbsoluteThickness[0.5], 
     LineBox[{{3.7427671292921243`, 3.096120721976002}, {3.622847132670974, 
      3.201489704433622}}]}, 
    {Hue[0.4455596432799015], AbsoluteThickness[0.5], 
     LineBox[{{3.622847132670974, 3.201489704433622}, {3.643384671488563, 
      3.3597983825061997`}}]}, 
    {Hue[0.5819220982584521], AbsoluteThickness[0.5], 
     LineBox[{{3.643384671488563, 3.3597983825061997`}, {3.7862216760573277`, 
      3.4310796435752473`}}]}, 
    {Hue[0.40629456585250623`], AbsoluteThickness[0.5], 
     LineBox[{{4.667391997490735, 3.360284447263403}, {4.649074573465307, 
      3.427865298501506}}]}, 
    {Hue[0.40658613008833144`], AbsoluteThickness[0.5], 
     LineBox[{{4.649074573465307, 3.427865298501506}, {4.5651883069599, 
      3.6848540105536114`}}]}, 
    {Hue[0.6506257393821069], AbsoluteThickness[0.5], 
     LineBox[{{5.277758717143984, 3.366557381576849}, {5.233858861547429, 
      3.5865970474625457`}}]}, 
    {Hue[0.6508213758708886], AbsoluteThickness[0.5], 
     LineBox[{{5.233858861547429, 3.5865970474625457`}, {5.1726285273595956`, 
      3.9255726373682482`}}]}, 
    {Hue[0.44914674346611067`], AbsoluteThickness[0.5], 
     LineBox[{{5.898000674453068, 3.368881404682121}, {5.899134242939919, 
      3.3693583566555887`}}]}, 
    {Hue[0.449449937320805], AbsoluteThickness[0.5], 
     LineBox[{{5.899134242939919, 3.3693583566555887`}, {6.111585282110616, 
      3.472367027206931}}]}, 
    {Hue[0.6692784506565205], AbsoluteThickness[0.5], 
     LineBox[{{5.8574455005292645`, 2.816628517706533}, {5.958198181637355, 
      2.6281149491080376`}}]}, 
    {Hue[0.6694640668400353], AbsoluteThickness[0.5], 
     LineBox[{{5.958198181637355, 2.6281149491080376`}, {6.1176548356263805`, 
      2.335555256105638}}]}, 
    {Hue[0.476305133204604], AbsoluteThickness[0.5], 
     LineBox[{{5.8427720735431, 2.7228770601336127`}, {6.047190372337455, 
      2.7635250484531877`}}]}, 
    {Hue[0.4764917635849486], AbsoluteThickness[0.5], 
     LineBox[{{6.047190372337455, 2.7635250484531877`}, {6.374197998047203, 
      2.8252555391612586`}}]}, 
    {Hue[0.5118760178198815], AbsoluteThickness[0.5], 
     LineBox[{{5.820946895856471, 1.666690518766145}, {5.867096760510475, 
      1.5568645856293863`}}]}, 
    {Hue[0.513017992441701], AbsoluteThickness[0.5], 
     LineBox[{{5.867096760510475, 1.5568645856293863`}, {5.9726659601126935`, 
      1.3721407739913314`}}]}, 
    {Hue[0.5476389081455953], AbsoluteThickness[0.5], 
     LineBox[{{5.092211361633606, 1.8481257845740613`}, {5.088297965282513, 
      1.8262510277303763`}}]}, 
    {Hue[0.5553260811280109], AbsoluteThickness[0.5], 
     LineBox[{{5.088297965282513, 1.8262510277303763`}, {5.095108047103927, 
      1.6972718055676446`}}]}, 
    {Hue[0.5900316036034922], AbsoluteThickness[0.5], 
     LineBox[{{4.387311192534063, 2.0334509906640714`}, {4.277659440999164, 
      1.9169985646153616`}}]}, 
    {Hue[0.59069077963899], AbsoluteThickness[0.5], 
     LineBox[{{4.277659440999164, 1.9169985646153616`}, {4.122848840957539, 
      1.7180552732101344`}}]}, 
    {Hue[0.6172577225529925], AbsoluteThickness[0.5], 
     LineBox[{{3.8238202808915664`, 2.9838764681221184`}, {3.648140038558968, 
      3.098566661548034}}]}, 
    {Hue[0.6193700380209168], AbsoluteThickness[0.5], 
     LineBox[{{3.648140038558968, 3.098566661548034}, {3.4661872280868278`, 
      3.180921472328808}}]}, 
    {Hue[0.6535665341234497], AbsoluteThickness[0.5], 
     LineBox[{{4.641487887169879, 3.3291496725314924`}, {4.624830179117953, 
      3.40901924966295}}]}, 
    {Hue[0.6537967503691205], AbsoluteThickness[0.5], 
     LineBox[{{4.624830179117953, 3.40901924966295}, {4.557058154927904, 
      3.6857111952687807`}}]}, 
    {Hue[0.5272029850943332], AbsoluteThickness[0.5], 
     LineBox[{{3.3805055831974253`, 0.37158406636224844`}, {
      3.3641239810316463`, 0.3671921510397863}}]}, 
    {Hue[0.527456392456611], AbsoluteThickness[0.5], 
     LineBox[{{3.3641239810316463`, 0.3671921510397863}, {3.072694552474338, 
      0.27587203506025676`}}]}, 
    {Hue[0.5857679112548897], AbsoluteThickness[0.5], 
     LineBox[{{4.573649858233891, 1.7627108399105784`}, {4.47360863487234, 
      1.8249231390726355`}}]}, 
    {Hue[0.5200571131686769], AbsoluteThickness[0.5], 
     LineBox[{{4.098053619989534, 1.2406365255603116`}, {3.9358161488169614`, 
      1.2372535926012982`}}]}, 
    {Hue[0.5203214181327978], AbsoluteThickness[0.5], 
     LineBox[{{3.9358161488169614`, 1.2372535926012982`}, {3.667818548636428, 
      1.2196932435683943`}}]}, 
    {Hue[0.6272387056374531], AbsoluteThickness[0.5], 
     LineBox[{{4.875021438164752, 0.5253603907749506}, {4.73748714802897, 
      0.40950604122527534`}}]}, 
    {Hue[0.6283798115121487], AbsoluteThickness[0.5], 
     LineBox[{{4.73748714802897, 0.40950604122527534`}, {4.605132568154086, 
      0.3230387054496063}}]}, 
    {Hue[0.6978992022460438], AbsoluteThickness[0.5], 
     LineBox[{{6.070713347817326, -1.596189391324968}, {
      6.065334003334559, -1.8492591456462795`}}]}, 
    {Hue[0.6980983618028149], AbsoluteThickness[0.5], 
     LineBox[{{6.065334003334559, -1.8492591456462795`}, {
      6.055440525207455, -2.0856520759379458`}}]}, 
    {Hue[0.482075090183537], AbsoluteThickness[0.5], 
     LineBox[{{3.2065309528116637`, 1.3940584934118068`}, {
      3.1330446222023243`, 1.4117656203703455`}}]}, 
    {Hue[0.48229930512259617`], AbsoluteThickness[0.5], 
     LineBox[{{3.1330446222023243`, 1.4117656203703455`}, {
      2.8155000203866543`, 1.49926532461838}}]}, 
    {Hue[0.6933832545203352], AbsoluteThickness[0.5], 
     LineBox[{{2.843136121561057, -1.0614196196331982`}, {
      2.374937088589322, -0.6456031838817202}}]}, 
    {Hue[0.6953692982530784], AbsoluteThickness[0.5], 
     LineBox[{{2.374937088589322, -0.6456031838817202}, {
      2.205090409605016, -0.5352505042925035}}]}, 
    {Hue[0.4751745936965725], AbsoluteThickness[0.5], 
     LineBox[{{2.910787109517695, -2.0825841162416596`}, {
      2.8685673441515807`, -2.1857190069215964`}}]}, 
    {Hue[0.47669999871313934`], AbsoluteThickness[0.5], 
     LineBox[{{2.8685673441515807`, -2.1857190069215964`}, {
      2.7646409666322525`, -2.3652591978116506`}}]}, 
    {Hue[0.6926999894040474], AbsoluteThickness[0.5], 
     LineBox[{{3.836149343049395, -2.845038464983356}, {
      3.9074945903586378`, -3.192587711922769}}]}, 
    {Hue[0.6951560494409114], AbsoluteThickness[0.5], 
     LineBox[{{3.9074945903586378`, -3.192587711922769}, {
      3.9147952493490976`, -3.3708372984770985`}}]}, 
    {Hue[0.576795770258878], AbsoluteThickness[0.5], 
     LineBox[{{3.3278659338480487`, 2.5662557517157665`}, {3.311936366792392, 
      2.6064483382348436`}}]}, 
    {Hue[0.5770055308426942], AbsoluteThickness[0.5], 
     LineBox[{{3.311936366792392, 2.6064483382348436`}, {3.2063272730200887`, 
      2.8948686695957933`}}]}, 
    {Hue[0.5657848106605688], AbsoluteThickness[0.5], 
     LineBox[{{4.199617787190727, 2.409714096482288}, {4.180860665318691, 
      2.4485790599121247`}}]}, 
    {Hue[0.5663277845822872], AbsoluteThickness[0.5], 
     LineBox[{{4.180860665318691, 2.4485790599121247`}, {4.044827874469686, 
      2.678623059659469}}]}, 
    {Hue[0.666187398840761], AbsoluteThickness[0.5], 
     LineBox[{{3.3170462945642005`, 0.5115606526621097}, {3.1737449217559712`,
       0.4809086478989754}}]}, 
    {Hue[0.6665536829110215], AbsoluteThickness[0.5], 
     LineBox[{{3.1737449217559712`, 0.4809086478989754}, {2.918979408019427, 
      0.4432405576931465}}]}, 
    {Hue[0.4668353402043273], AbsoluteThickness[0.5], 
     LineBox[{{4.886521337520707, 3.1181709029604834`}, {4.885546272031111, 
      3.1188602060507615`}}]}, 
    {Hue[0.4670383881446174], AbsoluteThickness[0.5], 
     LineBox[{{4.885546272031111, 3.1188602060507615`}, {4.630191771136144, 
      3.308284194420784}}]}, 
    {Hue[0.5963739649980472], AbsoluteThickness[0.5], 
     LineBox[{{7.352014452126943, 1.193465846067691}, {7.38442038266304, 
      1.146214917856264}}]}, 
    {Hue[0.5965960376712841], AbsoluteThickness[0.5], 
     LineBox[{{7.38442038266304, 1.146214917856264}, {7.583154901338565, 
      0.8752202076403494}}]}, 
    {Hue[0.6625655220613973], AbsoluteThickness[0.5], 
     LineBox[{{6.869205868538643, 1.1908184192383027`}, {6.876421105352835, 
      1.0656697795973613`}}]}, 
    {Hue[0.6642430463401776], AbsoluteThickness[0.5], 
     LineBox[{{6.876421105352835, 1.0656697795973613`}, {6.915310280175682, 
      0.8725376930146247}}]}, 
    {Hue[0.6358152433562018], AbsoluteThickness[0.5], 
     LineBox[{{5.882439085046726, 2.4952029161458746`}, {5.665748465648419, 
      2.431360896350264}}]}, 
    {Hue[0.6363844238191153], AbsoluteThickness[0.5], 
     LineBox[{{5.665748465648419, 2.431360896350264}, {5.405927012198225, 
      2.3787519570622178`}}]}, 
    {Hue[0.5311916280745455], AbsoluteThickness[0.5], 
     LineBox[{{7.36873589652042, 3.1892380843199777`}, {7.586433657280547, 
      3.2098175772256794`}}]}, 
    {Hue[0.5313938140348141], AbsoluteThickness[0.5], 
     LineBox[{{7.586433657280547, 3.2098175772256794`}, {7.8855943003165185`, 
      3.2448708046005024`}}]}, 
    {Hue[0.6766632848195809], AbsoluteThickness[0.5], 
     LineBox[{{6.887209292294565, 3.364039245201363}, {6.878341464867088, 
      3.355366615909915}}]}, 
    {Hue[0.6768795590633847], AbsoluteThickness[0.5], 
     LineBox[{{6.878341464867088, 3.355366615909915}, {6.686899135231831, 
      3.1787974319452377`}}]}, 
    {Hue[0.6770985738764616], AbsoluteThickness[0.5], 
     LineBox[{{7.0291737225527635`, 3.3731969004548623`}, {7.05028264096431, 
      3.3076631218756067`}}]}, 
    {Hue[0.6783263323559267], AbsoluteThickness[0.5], 
     LineBox[{{7.05028264096431, 3.3076631218756067`}, {7.146594245946951, 
      3.101302362746748}}]}, 
    {Hue[0.5339805522444907], AbsoluteThickness[0.5], 
     LineBox[{{6.3305081301654775`, 3.5734870220448216`}, {6.316650533579623, 
      3.5785436319596386`}}]}, 
    {Hue[0.5343804803183261], AbsoluteThickness[0.5], 
     LineBox[{{6.316650533579623, 3.5785436319596386`}, {6.083933215616448, 
      3.682061863205232}}]}, 
    {Hue[0.6353695653785245], AbsoluteThickness[0.5], 
     LineBox[{{7.258892531326898, 2.1212958894635108`}, {7.319072018686604, 
      2.0270369739297505`}}]}, 
    {Hue[0.6492122488037121], AbsoluteThickness[0.5], 
     LineBox[{{7.319072018686604, 2.0270369739297505`}, {7.341081509098933, 
      1.9555372819863597`}}]}, 
    {Hue[0.6750834021485764], AbsoluteThickness[0.5], 
     LineBox[{{5.195563023826857, 2.0683216790920302`}, {5.114170409498007, 
      2.067477533124626}}]}, 
    {Hue[0.6760435737793742], AbsoluteThickness[0.5], 
     LineBox[{{5.114170409498007, 2.067477533124626}, {4.933471172038791, 
      2.0451250526433418`}}]}, 
    {Hue[0.5961605902968696], AbsoluteThickness[0.5], 
     LineBox[{{4.631857465184819, 2.876601243636376}, {4.630982662709606, 
      2.876838106199413}}]}, 
    {Hue[0.5965152832881849], AbsoluteThickness[0.5], 
     LineBox[{{4.630982662709606, 2.876838106199413}, {4.372429286979578, 
      2.9644152224685603`}}]}, 
    {Hue[0.667138662489891], AbsoluteThickness[0.5], 
     LineBox[{{4.428739814516301, -0.06855911911277818}, {
      4.382351075793916, -0.10517391641614338`}}]}, 
    {Hue[0.6673339062988958], AbsoluteThickness[0.5], 
     LineBox[{{4.382351075793916, -0.10517391641614338`}, {
      4.110370663361457, -0.32787980772381814`}}]}, 
    {Hue[0.5274861619153777], AbsoluteThickness[0.5], 
     LineBox[{{2.8263520093400993`, 1.444130763380094}, {2.6487928585431653`, 
      1.524816379995089}}]}, 
    {Hue[0.5278966386178122], AbsoluteThickness[0.5], 
     LineBox[{{2.6487928585431653`, 1.524816379995089}, {2.379458000813778, 
      1.6251160758509406`}}]}, 
    {Hue[0.6958661941025353], AbsoluteThickness[0.5], 
     LineBox[{{4.425356686909021, 3.1169129380419007`}, {4.516830552912185, 
      3.3890059587277985`}}]}, 
    {Hue[0.6960552532889882], AbsoluteThickness[0.5], 
     LineBox[{{4.516830552912185, 3.3890059587277985`}, {4.608146945359943, 
      3.6724081726290074`}}]}, 
    {Hue[0.6920988610318751], AbsoluteThickness[0.5], 
     LineBox[{{3.6155601683525647`, 3.140748752813215}, {3.488082437448585, 
      3.3130000643458306`}}]}, 
    {Hue[0.6927865042890783], AbsoluteThickness[0.5], 
     LineBox[{{3.488082437448585, 3.3130000643458306`}, {3.360907336975386, 
      3.524693212670782}}]}, 
    {Hue[0.4539317146310888], AbsoluteThickness[0.5], 
     LineBox[{{2.868843846892141, 2.60011284487213}, {2.8116934041868635`, 
      2.6194695648763573`}}]}, 
    {Hue[0.45438360044250814`], AbsoluteThickness[0.5], 
     LineBox[{{2.8116934041868635`, 2.6194695648763573`}, {2.577113124496869, 
      2.7190939695865692`}}]}, 
    {Hue[0.6655970394021357], AbsoluteThickness[0.5], 
     LineBox[{{3.26131283152225, 1.5996640494127237`}, {3.0638595987935724`, 
      1.1604254624250783`}}]}, 
    {Hue[0.6657917622523349], AbsoluteThickness[0.5], 
     LineBox[{{3.0638595987935724`, 1.1604254624250783`}, {
      2.9275913020691573`, 0.8424886120484518}}]}, 
    {Hue[0.6986236408074131], AbsoluteThickness[0.5], 
     LineBox[{{3.191782608675725, 1.1704668874483517`}, {3.153448928015458, 
      1.10655298156924}}]}, 
    {Hue[0.6988405278371971], AbsoluteThickness[0.5], 
     LineBox[{{3.153448928015458, 1.10655298156924}, {2.9713169457996758`, 
      0.8222603747779084}}]}, 
    {Hue[0.6700685936562499], AbsoluteThickness[0.5], 
     LineBox[{{2.69371070634779, -3.4233066182279197`}, {
      2.670413320797123, -3.4341668154465013`}}]}, 
    {Hue[0.6702517542364133], AbsoluteThickness[0.5], 
     LineBox[{{2.670413320797123, -3.4341668154465013`}, {
      2.3865127223489795`, -3.5668852488817966`}}]}, 
    {Hue[0.6724722443626188], AbsoluteThickness[0.5], 
     LineBox[{{6.65303976200892, 2.961530386470526}, {6.899423196141074, 
      2.98718877936853}}]}, 
    {Hue[0.6726767825050817], AbsoluteThickness[0.5], 
     LineBox[{{6.899423196141074, 2.98718877936853}, {7.166293012942752, 
      3.0086036193514536`}}]}, 
    {Hue[0.621373817079519], AbsoluteThickness[0.5], 
     LineBox[{{4.854366695460026, -3.7783913530293813`}, {
      4.903634815891672, -3.9230067389810745`}}]}, 
    {Hue[0.6217181419052968], AbsoluteThickness[0.5], 
     LineBox[{{4.903634815891672, -3.9230067389810745`}, {
      5.000414990405947, -4.159206389957394}}]}, 
    {Hue[0.6974546497359472], AbsoluteThickness[0.5], 
     LineBox[{{5.921928558588366, -1.7290781022400192`}, {
      6.121394253571286, -1.7102266949563503`}}]}, 
    {Hue[0.6983105071758604], AbsoluteThickness[0.5], 
     LineBox[{{6.121394253571286, -1.7102266949563503`}, {
      6.294542797162495, -1.712435348389325}}]}, 
    {Hue[0.6957693048295498], AbsoluteThickness[0.5], 
     LineBox[{{3.933775921915895, 3.33685800507418}, {3.9501014524724933`, 
      3.4038499652223475`}}]}, 
    {Hue[0.6959540824532816], AbsoluteThickness[0.5], 
     LineBox[{{3.9501014524724933`, 3.4038499652223475`}, {4.021738605429321, 
      3.6895005923389186`}}]}, 
    {Hue[0.4149427674485081], AbsoluteThickness[0.5], 
     LineBox[{{2.319455317078221, 3.0548251894317278`}, {2.2762663904675184`, 
      3.0759686155040873`}}]}, 
    {Hue[0.4169841444138029], AbsoluteThickness[0.5], 
     LineBox[{{2.2762663904675184`, 3.0759686155040873`}, {2.11741073100309, 
      3.1862318942371473`}}]}, 
    {Hue[0.6846370486126406], AbsoluteThickness[0.5], 
     LineBox[{{2.11741073100309, 3.1862318942371473`}, {2.1829895557969965`, 
      3.368145414678848}}]}, 
    {Hue[0.6915015358912283], AbsoluteThickness[0.5], 
     LineBox[{{6.558434112117004, 3.121394561388964}, {6.726026292771315, 
      3.1624269201018165`}}]}, 
    {Hue[0.6938326281179009], AbsoluteThickness[0.5], 
     LineBox[{{6.726026292771315, 3.1624269201018165`}, {6.874329786784559, 
      3.224916746452884}}]}, 
    {Hue[0.6286947539203495], AbsoluteThickness[0.5], 
     LineBox[{{2.7207957282082207`, -0.8988499529645195}, {
      2.580453695055914, -0.8788474812033391}}]}, 
    {Hue[0.6323476971486623], AbsoluteThickness[0.5], 
     LineBox[{{2.580453695055914, -0.8788474812033391}, {
      2.38258625282617, -0.8872404335930295}}]}, 
    {Hue[0.6384284189812741], AbsoluteThickness[0.5], 
     LineBox[{{8.073286747564538, 1.2026505553483355`}, {8.201736972220186, 
      1.6119815177360024`}}]}, 
    {Hue[0.638613377270406], AbsoluteThickness[0.5], 
     LineBox[{{8.201736972220186, 1.6119815177360024`}, {8.28456357642351, 
      1.882574819793523}}]}, 
    {Hue[0.6636210279554793], AbsoluteThickness[0.5], 
     LineBox[{{6.499397579882815, 0.6579562769550734}, {6.417094863371823, 
      0.7900791931475404}}]}, 
    {Hue[0.6316889722529896], AbsoluteThickness[0.5], 
     LineBox[{{6.135532990828835, -1.892394399522408}, {
      6.132323290557163, -1.8924612836515469`}}]}, 
    {Hue[0.6320896866535736], AbsoluteThickness[0.5], 
     LineBox[{{6.132323290557163, -1.8924612836515469`}, {
      5.930327422316176, -1.9106077982607501`}}]}, 
    {Hue[0.5816670973698951], AbsoluteThickness[0.5], 
     LineBox[{{7.249945292601955, -2.9372034400351885`}, {
      7.163782036569682, -3.096999373830829}}]}, 
    {Hue[0.5823535025088905], AbsoluteThickness[0.5], 
     LineBox[{{7.163782036569682, -3.096999373830829}, {
      7.069476274145186, -3.3210102154751135`}}]}, 
    {Hue[0.6510892503566696], AbsoluteThickness[0.5], 
     LineBox[{{7.071484832429513, -2.258721142881024}, {
      6.931722774464518, -2.2747790926863147`}}]}, 
    {Hue[0.6513997607418688], AbsoluteThickness[0.5], 
     LineBox[{{6.931722774464518, -2.2747790926863147`}, {
      6.6658613148600745`, -2.290693316004209}}]}, 
    {Hue[0.6520757499313232], AbsoluteThickness[0.5], 
     LineBox[{{8.037465293458888, -1.4027113492410619`}, {
      7.931161121804959, -1.1241284316455704`}}]}, 
    {Hue[0.6568003402077828], AbsoluteThickness[0.5], 
     LineBox[{{7.931161121804959, -1.1241284316455704`}, {
      7.905259287943307, -0.9688719174246986}}]}, 
    {Hue[0.6628862555616726], AbsoluteThickness[0.5], 
     LineBox[{{6.236712677796566, -0.11373154791280835`}, {
      6.183012615094738, -0.052204520762133305`}}]}, 
    {Hue[0.6631424215723146], AbsoluteThickness[0.5], 
     LineBox[{{6.183012615094738, -0.052204520762133305`}, {5.960741327726372,
       0.18163303324655297`}}]}, 
    {Hue[0.6355540403894153], AbsoluteThickness[0.5], 
     LineBox[{{4.152490345497259, -0.6774240377395112}, {
      4.017570463917072, -0.6412550494577799}}]}, 
    {Hue[0.6374575969104979], AbsoluteThickness[0.5], 
     LineBox[{{4.017570463917072, -0.6412550494577799}, {
      3.844581130049851, -0.5661312995344663}}]}, 
    {Hue[0.5187041619121823], AbsoluteThickness[0.5], 
     LineBox[{{5.077151719566918, -2.7896193673170946`}, {
      5.04843387188945, -2.830133321013055}}]}, 
    {Hue[0.518915644916951], AbsoluteThickness[0.5], 
     LineBox[{{5.04843387188945, -2.830133321013055}, {
      4.8796782695141685`, -3.08245491405061}}]}, 
    {Hue[0.6730324059828734], AbsoluteThickness[0.5], 
     LineBox[{{3.3735957448722327`, 0.12285257957385659`}, {
      3.3126918097624993`, 0.11835838566538617`}}]}, 
    {Hue[0.676529492262212], AbsoluteThickness[0.5], 
     LineBox[{{3.3126918097624993`, 0.11835838566538617`}, {
      3.1309275385333617`, 0.1380248759012769}}]}, 
    {Hue[0.6886502567071225], AbsoluteThickness[0.5], 
     LineBox[{{6.613477516367497, 2.8636309481357225`}, {6.836228146190559, 
      3.1835285607538286`}}]}, 
    {Hue[0.6939061322612141], AbsoluteThickness[0.5], 
     LineBox[{{6.836228146190559, 3.1835285607538286`}, {6.891693862377186, 
      3.3137983546813343`}}]}, 
    {Hue[0.6292326650665105], AbsoluteThickness[0.5], 
     LineBox[{{6.920138022643766, 3.6150100035364083`}, {6.893635248830319, 
      3.7624543145467406`}}]}, 
    {Hue[0.666524866248729], AbsoluteThickness[0.5], 
     LineBox[{{6.893635248830319, 3.7624543145467406`}, {6.8194450232654305`, 
      3.8923426367631024`}}]}, 
    {Hue[0.5842515766931979], AbsoluteThickness[0.5], 
     LineBox[{{3.383789456511689, -1.9729749954037983`}, {
      3.330907938269609, -2.058829454821125}}]}, 
    {Hue[0.5844539910319425], AbsoluteThickness[0.5], 
     LineBox[{{3.330907938269609, -2.058829454821125}, {
      3.182742657092213, -2.311972613455932}}]}, 
    {Hue[0.6500045364334456], AbsoluteThickness[0.5], 
     LineBox[{{5.7020451715431815`, -3.9112365439015684`}, {
      5.771706365735673, -4.080001974130683}}]}, 
    {Hue[0.6502921469157873], AbsoluteThickness[0.5], 
     LineBox[{{5.771706365735673, -4.080001974130683}, {
      5.875281126091442, -4.37143559027782}}]}, 
    {Hue[0.6725006668350235], AbsoluteThickness[0.5], 
     LineBox[{{7.555889127695717, -2.088286515364006}, {
      7.648601230646284, -2.149668120186087}}]}, 
    {Hue[0.6726926306368441], AbsoluteThickness[0.5], 
     LineBox[{{7.648601230646284, -2.149668120186087}, {
      7.897226245942283, -2.319820684585405}}]}, 
    {Hue[0.6897450561953962], AbsoluteThickness[0.5], 
     LineBox[{{3.3690487587760924`, 3.5453326097585736`}, {
      3.2605448101087156`, 3.61893592385977}}]}, 
    {Hue[0.6901563382817189], AbsoluteThickness[0.5], 
     LineBox[{{3.2605448101087156`, 3.61893592385977}, {3.057522303906609, 
      3.7785231599775653`}}]}, 
    {Hue[0.49766651813769963`], AbsoluteThickness[0.5], 
     LineBox[{{7.34954007318907, -2.9311449148270943`}, {
      7.277103947723624, -3.1009969653937595`}}]}, 
    {Hue[0.4978496670458295], AbsoluteThickness[0.5], 
     LineBox[{{7.277103947723624, -3.1009969653937595`}, {
      7.150433843677726, -3.3987902081105528`}}]}, 
    {Hue[0.5804869417683769], AbsoluteThickness[0.5], 
     LineBox[{{8.023701590059098, 2.6198351822922343`}, {7.889445456338815, 
      2.926024376894937}}]}, 
    {Hue[0.5841524866025745], AbsoluteThickness[0.5], 
     LineBox[{{7.889445456338815, 2.926024376894937}, {7.850770231733905, 
      3.0919020319561095`}}]}, 
    {Hue[0.6536093991486013], AbsoluteThickness[0.5], 
     LineBox[{{4.382315238116761, -0.8858538580442203}, {
      4.378244028380549, -0.8871292544932251}}]}, 
    {Hue[0.6562459042009848], AbsoluteThickness[0.5], 
     LineBox[{{4.378244028380549, -0.8871292544932251}, {
      4.200021876269678, -0.9119070393901738}}]}, 
    {Hue[0.4419131453270608], AbsoluteThickness[0.5], 
     LineBox[{{6.842558002495407, -2.3562116887071047`}, {
      6.838998481869474, -2.3971098311794203`}}]}, 
    {Hue[0.44971523829154175`], AbsoluteThickness[0.5], 
     LineBox[{{6.838998481869474, -2.3971098311794203`}, {
      6.860468037503002, -2.5452454429729006`}}]}, 
    {Hue[0.6207248289382851], AbsoluteThickness[0.5], 
     LineBox[{{6.860468037503002, -2.5452454429729006`}, {
      6.999102128718822, -2.6016873604925377`}}]}, 
    {Hue[0.43790128123210903`], AbsoluteThickness[0.5], 
     LineBox[{{7.987758823987346, -1.6947174978191548`}, {
      8.249651997048355, -2.065005472982989}}]}, 
    {Hue[0.438341460906264], AbsoluteThickness[0.5], 
     LineBox[{{8.249651997048355, -2.065005472982989}, {
      8.393442965850957, -2.303851857405552}}]}, 
    {Hue[0.6167265353198499], AbsoluteThickness[0.5], 
     LineBox[{{7.296808618032822, -0.9383558163661906}, {
      7.2484503078147435`, -1.131275623238627}}]}, 
    {Hue[0.6169534640120845], AbsoluteThickness[0.5], 
     LineBox[{{7.2484503078147435`, -1.131275623238627}, {
      7.185536517567847, -1.4233285737793353`}}]}, 
    {Hue[0.6925951380390971], AbsoluteThickness[0.5], 
     LineBox[{{5.892238369604698, 1.4306052722726568`}, {5.701552488729594, 
      1.5990694274151984`}}]}, 
    {Hue[0.6936597754121393], AbsoluteThickness[0.5], 
     LineBox[{{5.701552488729594, 1.5990694274151984`}, {5.589911053871509, 
      1.723989415994277}}]}, 
    {Hue[0.4721505025868881], AbsoluteThickness[0.5], 
     LineBox[{{6.243269221268635, 0.13022919532730276`}, {6.188201289061612, 
      0.0793996632269098}}]}, 
    {Hue[0.4723953716103102], AbsoluteThickness[0.5], 
     LineBox[{{6.188201289061612, 0.0793996632269098}, {
      5.940248911892806, -0.1320508901896091}}]}, 
    {Hue[0.6792266063975925], AbsoluteThickness[0.5], 
     LineBox[{{7.35088627346321, -0.39228288094063185`}, {
      7.351114219330654, -0.3940541335758071}}]}, 
    {Hue[0.6799903705331355], AbsoluteThickness[0.5], 
     LineBox[{{7.351114219330654, -0.3940541335758071}, {
      7.401924794015256, -0.6117164683421243}}]}, 
    {Hue[0.5631593745873896], AbsoluteThickness[0.5], 
     LineBox[{{7.267663358684314, 2.8974339656723194`}, {7.359469019374845, 
      3.1712319685556047`}}]}, 
    {Hue[0.57757093829388], AbsoluteThickness[0.5], 
     LineBox[{{7.359469019374845, 3.1712319685556047`}, {7.367555068531391, 
      3.3293246155986482`}}]}, 
    {Hue[0.3251112189527165], AbsoluteThickness[0.5], 
     LineBox[{{6.656119914545259, 2.8887936551931834`}, {6.636500606390305, 
      2.9000693577730754`}}]}, 
    {Hue[0.32529567952221483`], AbsoluteThickness[0.5], 
     LineBox[{{6.636500606390305, 2.9000693577730754`}, {6.351578364845772, 
      3.0615498507624155`}}]}, 
    {Hue[0.5845448331377286], AbsoluteThickness[0.5], 
     LineBox[{{6.435364607407312, 2.3487108780900354`}, {6.3900416727379525`, 
      2.3443304094935713`}}]}, 
    {Hue[0.5852037488151737], AbsoluteThickness[0.5], 
     LineBox[{{6.3900416727379525`, 2.3443304094935713`}, {6.149841575224362, 
      2.298041295074627}}]}, 
    {Hue[0.4468546654107355], AbsoluteThickness[0.5], 
     LineBox[{{6.90909050153152, 2.6189814743779674`}, {6.851180149953768, 
      2.6419531208205154`}}]}, 
    {Hue[0.44705759795875666`], AbsoluteThickness[0.5], 
     LineBox[{{6.851180149953768, 2.6419531208205154`}, {6.556008619207015, 
      2.7669057467627027`}}]}, 
    {Hue[0.442503505639098], AbsoluteThickness[0.5], 
     LineBox[{{8.220310908486281, 0.6114199351966487}, {8.230386758025595, 
      0.3758248157132166}}]}, 
    {Hue[0.4426891332165894], AbsoluteThickness[0.5], 
     LineBox[{{8.230386758025595, 0.3758248157132166}, {8.241317660936481, 
      0.05937870694277017}}]}, 
    {Hue[0.5338779202137734], AbsoluteThickness[0.5], 
     LineBox[{{7.713475040829654, 0.0453881684976358}, {
      7.6645860830738215`, -0.031147231682318602`}}]}, 
    {Hue[0.5347809768820458], AbsoluteThickness[0.5], 
     LineBox[{{7.6645860830738215`, -0.031147231682318602`}, {
      7.534634195919815, -0.19247479425545638`}}]}, 
    {Hue[0.6188134088187301], AbsoluteThickness[0.5], 
     LineBox[{{7.232629346704844, 0.0935309731620283}, {
      7.053641669446334, -0.3173519697819334}}]}, 
    {Hue[0.6190114733008494], AbsoluteThickness[0.5], 
     LineBox[{{7.053641669446334, -0.31735196978193336`}, {
      6.918235140502793, -0.6120523874165424}}]}, 
    {Hue[0.46256156614756816`], AbsoluteThickness[0.5], 
     LineBox[{{7.5681643822077485`, -1.1355830966992775`}, {
      7.606344688347924, -1.4187334913977332`}}]}, 
    {Hue[0.46452396114690575`], AbsoluteThickness[0.5], 
     LineBox[{{7.606344688347924, -1.4187334913977334`}, {
      7.603390235694879, -1.6110348748944543`}}]}, 
    {Hue[0.6846377499277434], AbsoluteThickness[0.5], 
     LineBox[{{4.837885967467196, 1.5380887190130017`}, {4.818216791195257, 
      1.5884045492762944`}}]}, 
    {Hue[0.684865251567696], AbsoluteThickness[0.5], 
     LineBox[{{4.818216791195257, 1.5884045492762944`}, {4.701971665894905, 
      1.8586035155755987`}}]}, 
    {Hue[0.4280635199925863], AbsoluteThickness[0.5], 
     LineBox[{{4.349692745732636, 0.9390177742939605}, {4.257659461780888, 
      0.9100120270629408}}]}, 
    {Hue[0.43614059445240044`], AbsoluteThickness[0.5], 
     LineBox[{{4.257659461780888, 0.9100120270629408}, {4.117167632438771, 
      0.8261175470069844}}]}, 
    {Hue[0.6047149285675697], AbsoluteThickness[0.5], 
     LineBox[{{4.117167632438771, 0.8261175470069844}, {4.117643865374875, 
      0.662483775743396}}]}, 
    {Hue[0.6886529914043422], AbsoluteThickness[0.5], 
     LineBox[{{4.846694276822012, 0.5984956863594586}, {4.807577656537465, 
      0.386077457015285}}]}, 
    {Hue[0.688905837334848], AbsoluteThickness[0.5], 
     LineBox[{{4.807577656537465, 0.386077457015285}, {4.751781410101081, 
      0.14079931650843228`}}]}, 
    {Hue[0.43614428401576927`], AbsoluteThickness[0.5], 
     LineBox[{{3.412383262155191, 1.1080402052512859`}, {3.109795497765404, 
      1.1420644005632679`}}]}, 
    {Hue[0.43962123809240594`], AbsoluteThickness[0.5], 
     LineBox[{{3.109795497765404, 1.1420644005632679`}, {2.9148613770099985`, 
      1.1285672376053026`}}]}, 
    {Hue[0.6684708662403186], AbsoluteThickness[0.5], 
     LineBox[{{2.9148613770099985`, 1.1285672376053026`}, {2.853419889646802, 
      0.9430775385026428}}]}, 
    {Hue[0.4350062524850206], AbsoluteThickness[0.5], 
     LineBox[{{2.3595970983370855`, 0.9048842717050697}, {2.3474023378701885`,
       0.9048738988616299}}]}, 
    {Hue[0.437323209078533], AbsoluteThickness[0.5], 
     LineBox[{{2.3474023378701885`, 0.9048738988616299}, {2.202642609176679, 
      0.8816321711879552}}]}, 
    {Hue[0.6957166359521446], AbsoluteThickness[0.5], 
     LineBox[{{2.202642609176679, 0.8816321711879552}, {2.1829116023236583`, 
      0.7363522884607112}}]}, 
    {Hue[0.6915534176376944], AbsoluteThickness[0.5], 
     LineBox[{{7.028902406669837, -3.1251692495618935`}, {
      7.058316122578409, -3.2104291544489056`}}]}, 
    {Hue[0.6929343916329864], AbsoluteThickness[0.5], 
     LineBox[{{7.058316122578409, -3.2104291544489056`}, {
      7.152935114196686, -3.3998557454180136`}}]}, 
    {Hue[0.43269303413791377`], AbsoluteThickness[0.5], 
     LineBox[{{3.7427671292921243`, 3.096120721976002}, {3.6491189382290914`, 
      3.096727167638321}}]}, 
    {Hue[0.432979394960273], AbsoluteThickness[0.5], 
     LineBox[{{3.6491189382290914`, 3.096727167638321}, {3.350901074353575, 
      3.083822610252523}}]}, 
    {Hue[0.32206379744333513`], AbsoluteThickness[0.5], 
     LineBox[{{3.622847132670974, 3.201489704433622}, {3.548730151265034, 
      3.313291298098303}}]}, 
    {Hue[0.3223082015699033], AbsoluteThickness[0.5], 
     LineBox[{{3.548730151265034, 3.313291298098303}, {3.3885589709624035`, 
      3.5767400067352}}]}, 
    {Hue[0.45842625242188567`], AbsoluteThickness[0.5], 
     LineBox[{{3.643384671488563, 3.3597983825061997`}, {3.651399080236819, 
      3.37910346651708}}]}, 
    {Hue[0.4710320858060577], AbsoluteThickness[0.5], 
     LineBox[{{3.651399080236819, 3.37910346651708}, {3.6715545154570086`, 
      3.532753025731774}}]}, 
    {Hue[0.6087872936956217], AbsoluteThickness[0.5], 
     LineBox[{{3.6715545154570086`, 3.532753025731774}, {3.5550668598930115`, 
      3.63495407620088}}]}, 
    {Hue[0.5947887074004361], AbsoluteThickness[0.5], 
     LineBox[{{3.7862216760573277`, 3.4310796435752473`}, {3.881455294618198, 
      3.4502254001223314`}}]}, 
    {Hue[0.5950775213718495], AbsoluteThickness[0.5], 
     LineBox[{{3.881455294618198, 3.4502254001223314`}, {4.139812661650813, 
      3.5158217226159985`}}]}, 
    {Hue[0.4497531311754993], AbsoluteThickness[0.5], 
     LineBox[{{6.111585282110616, 3.472367027206931}, {6.264634592188302, 
      3.5569056035555873`}}]}, 
    {Hue[0.4570965370781884], AbsoluteThickness[0.5], 
     LineBox[{{6.264634592188302, 3.5569056035555873`}, {6.377435097169095, 
      3.658150991890274}}]}, 
    {Hue[0.632376719600673], AbsoluteThickness[0.5], 
     LineBox[{{6.377435097169095, 3.658150991890274}, {6.345897813530606, 
      3.8064074667022325`}}]}, 
    {Hue[0.6696496830235503], AbsoluteThickness[0.5], 
     LineBox[{{6.1176548356263805`, 2.335555256105638}, {6.144325840184996, 
      2.2875612976895767`}}]}, 
    {Hue[0.6700264341315937], AbsoluteThickness[0.5], 
     LineBox[{{6.144325840184996, 2.2875612976895767`}, {6.29350856581124, 
      2.0561842066253853`}}]}, 
    {Hue[0.47667839396529327`], AbsoluteThickness[0.5], 
     LineBox[{{6.374197998047203, 2.8252555391612586`}, {6.406564721915494, 
      2.8310406851140684`}}]}, 
    {Hue[0.4774952290150292], AbsoluteThickness[0.5], 
     LineBox[{{6.406564721915494, 2.8310406851140684`}, {6.635004169707646, 
      2.8971105400953423`}}]}, 
    {Hue[0.5141599670635205], AbsoluteThickness[0.5], 
     LineBox[{{5.9726659601126935`, 1.3721407739913314`}, {6.051377142344828, 
      1.2665536430853388`}}]}, 
    {Hue[0.5153586429954632], AbsoluteThickness[0.5], 
     LineBox[{{6.051377142344828, 1.2665536430853388`}, {6.1972652318558445`, 
      1.114415438426117}}]}, 
    {Hue[0.5630132541104258], AbsoluteThickness[0.5], 
     LineBox[{{5.095108047103927, 1.6972718055676446`}, {5.117654458232004, 
      1.619604436013454}}]}, 
    {Hue[0.5647796787674554], AbsoluteThickness[0.5], 
     LineBox[{{5.117654458232004, 1.619604436013454}, {5.14685598326838, 
      1.4104281174482072`}}]}, 
    {Hue[0.5913499556744878], AbsoluteThickness[0.5], 
     LineBox[{{4.122848840957539, 1.7180552732101344`}, {4.06868495637522, 
      1.6330362242929266`}}]}, 
    {Hue[0.59154815886771], AbsoluteThickness[0.5], 
     LineBox[{{4.06868495637522, 1.6330362242929266`}, {3.9166370419365357`, 
      1.3835162247723365`}}]}, 
    {Hue[0.6214823534888411], AbsoluteThickness[0.5], 
     LineBox[{{3.4661872280868278`, 3.180921472328808}, {3.397482177038022, 
      3.200061181694977}}]}, 
    {Hue[0.6216808766301729], AbsoluteThickness[0.5], 
     LineBox[{{3.397482177038022, 3.200061181694977}, {3.1006670786341908`, 
      3.289236112860523}}]}, 
    {Hue[0.5277097998188888], AbsoluteThickness[0.5], 
     LineBox[{{3.072694552474338, 0.27587203506025676`}, {2.9111937313212852`,
       0.21776340620799062`}}]}, 
    {Hue[0.5279893654489168], AbsoluteThickness[0.5], 
     LineBox[{{2.9111937313212852`, 0.21776340620799062`}, {2.602454551891017,
       0.12321755953209027`}}]}, 
    {Hue[0.5857679112548896], AbsoluteThickness[0.5], 
     LineBox[{{4.47360863487234, 1.8249231390726355`}, {4.428650990937275, 
      1.8365678135129835`}}]}, 
    {Hue[0.5867392336968779], AbsoluteThickness[0.5], 
     LineBox[{{4.428650990937275, 1.8365678135129835`}, {4.237518902676637, 
      1.909981509090571}}]}, 
    {Hue[0.5205857230969185], AbsoluteThickness[0.5], 
     LineBox[{{3.667818548636428, 1.2196932435683943`}, {3.392784632189184, 
      1.1893133403696}}]}, 
    {Hue[0.5215010203279448], AbsoluteThickness[0.5], 
     LineBox[{{3.392784632189184, 1.1893133403696}, {3.2213753721831653`, 
      1.1509229207014182`}}]}, 
    {Hue[0.6295209173868443], AbsoluteThickness[0.5], 
     LineBox[{{4.605132568154086, 0.3230387054496063}, {4.461195578242246, 
      0.2522018687756769}}]}, 
    {Hue[0.6298779142626271], AbsoluteThickness[0.5], 
     LineBox[{{4.461195578242246, 0.2522018687756769}, {4.226784094955743, 
      0.11802907473082361`}}]}, 
    {Hue[0.6982975213595861], AbsoluteThickness[0.5], 
     LineBox[{{6.055440525207455, -2.0856520759379458`}, {
      6.035374206978884, -2.406801521780479}}]}, 
    {Hue[0.6984817099406939], AbsoluteThickness[0.5], 
     LineBox[{{6.035374206978884, -2.406801521780479}, {
      6.017758252410186, -2.666329052544557}}]}, 
    {Hue[0.4825235200616554], AbsoluteThickness[0.5], 
     LineBox[{{2.8155000203866543`, 1.49926532461838}, {2.6393669072293284`, 
      1.554001809947269}}]}, 
    {Hue[0.4829994573716388], AbsoluteThickness[0.5], 
     LineBox[{{2.6393669072293284`, 1.554001809947269}, {2.3678358241441186`, 
      1.6157500856389455`}}]}, 
    {Hue[0.6973553419858214], AbsoluteThickness[0.5], 
     LineBox[{{2.205090409605016, -0.5352505042925035}, {
      2.1486604500619717`, -0.509633451286922}}]}, 
    {Hue[0.6975392002527255], AbsoluteThickness[0.5], 
     LineBox[{{2.1486604500619717`, -0.509633451286922}, {
      1.8591223699710941`, -0.379751604104828}}]}, 
    {Hue[0.47822540372970607`], AbsoluteThickness[0.5], 
     LineBox[{{2.7646409666322525`, -2.3652591978116506`}, {
      2.687346924834199, -2.4646689242798066`}}]}, 
    {Hue[0.4789104535948015], AbsoluteThickness[0.5], 
     LineBox[{{2.687346924834199, -2.4646689242798066`}, {
      2.5207053132081034`, -2.6411097727657418`}}]}, 
    {Hue[0.6976121094777753], AbsoluteThickness[0.5], 
     LineBox[{{3.9147952493490976`, -3.3708372984770985`}, {
      3.9063545629573095`, -3.4404873654517356`}}]}, 
    {Hue[0.5772152914265106], AbsoluteThickness[0.5], 
     LineBox[{{3.2063272730200887`, 2.8948686695957933`}, {
      3.1824858594920125`, 2.9657044306250255`}}]}, 
    {Hue[0.5777604844981806], AbsoluteThickness[0.5], 
     LineBox[{{3.1824858594920125`, 2.9657044306250255`}, {
      3.0835451215110132`, 3.193820375821446}}]}, 
    {Hue[0.5668707585040055], AbsoluteThickness[0.5], 
     LineBox[{{4.044827874469686, 2.678623059659469}, {3.9333640797218736`, 
      2.8352853936772213`}}]}, 
    {Hue[0.5674718704379461], AbsoluteThickness[0.5], 
     LineBox[{{3.9333640797218736`, 2.8352853936772213`}, {3.830651011562688, 
      3.011017350880267}}]}, 
    {Hue[0.6669199669812821], AbsoluteThickness[0.5], 
     LineBox[{{2.918979408019427, 0.4432405576931465}, {2.5876291796852042`, 
      0.4157227093399586}}]}, 
    {Hue[0.6679170725430444], AbsoluteThickness[0.5], 
     LineBox[{{2.5876291796852042`, 0.4157227093399586}, {2.363445515092777, 
      0.42283839082818514`}}]}, 
    {Hue[0.46724143608490737`], AbsoluteThickness[0.5], 
     LineBox[{{4.630191771136144, 3.308284194420784}, {4.528763188868726, 
      3.3871844873446237`}}]}, 
    {Hue[0.4688532865117655], AbsoluteThickness[0.5], 
     LineBox[{{4.528763188868726, 3.3871844873446237`}, {4.395953481947561, 
      3.52396953458935}}]}, 
    {Hue[0.596818110344521], AbsoluteThickness[0.5], 
     LineBox[{{7.583154901338565, 0.8752202076403494}, {7.630096466793213, 
      0.8152795720390332}}]}, 
    {Hue[0.5971488258189732], AbsoluteThickness[0.5], 
     LineBox[{{7.630096466793213, 0.8152795720390332}, {7.825791340319894, 
      0.5933320850040109}}]}, 
    {Hue[0.6659205706189577], AbsoluteThickness[0.5], 
     LineBox[{{6.915310280175682, 0.8725376930146247}, {7.006439621925628, 
      0.6147688300325258}}]}, 
    {Hue[0.6661596681992998], AbsoluteThickness[0.5], 
     LineBox[{{7.006439621925628, 0.6147688300325258}, {7.096466395184083, 
      0.3260823219419739}}]}, 
    {Hue[0.636953604282029], AbsoluteThickness[0.5], 
     LineBox[{{5.405927012198225, 2.3787519570622178`}, {5.334621434201527, 
      2.3706567906970477`}}]}, 
    {Hue[0.6378073197195308], AbsoluteThickness[0.5], 
     LineBox[{{5.334621434201527, 2.3706567906970477`}, {5.098600632748835, 
      2.3179016869850884`}}]}, 
    {Hue[0.5315959999950828], AbsoluteThickness[0.5], 
     LineBox[{{7.8855943003165185`, 3.2448708046005024`}, {8.080559990141701, 
      3.272152460207569}}]}, 
    {Hue[0.5318311071685943], AbsoluteThickness[0.5], 
     LineBox[{{8.080559990141701, 3.272152460207569}, {8.370476193877607, 
      3.3020565011722733`}}]}, 
    {Hue[0.6770958333071886], AbsoluteThickness[0.5], 
     LineBox[{{6.686899135231831, 3.1787974319452377`}, {6.59454673071253, 
      3.0984915207788184`}}]}, 
    {Hue[0.6772875802747533], AbsoluteThickness[0.5], 
     LineBox[{{6.59454673071253, 3.0984915207788184`}, {6.352822588729898, 
      2.881774653529568}}]}, 
    {Hue[0.6795540908353915], AbsoluteThickness[0.5], 
     LineBox[{{7.146594245946951, 3.101302362746748}, {7.277212258579763, 
      2.893757354530947}}]}, 
    {Hue[0.6808021361616182], AbsoluteThickness[0.5], 
     LineBox[{{7.277212258579763, 2.893757354530947}, {7.35450132886719, 
      2.727795098489933}}]}, 
    {Hue[0.5347804083921615], AbsoluteThickness[0.5], 
     LineBox[{{6.083933215616448, 3.682061863205232}, {5.955770445167616, 
      3.749961683916154}}]}, 
    {Hue[0.5350348346919568], AbsoluteThickness[0.5], 
     LineBox[{{5.955770445167616, 3.749961683916154}, {5.6634007260393116`, 
      3.889464890278438}}]}, 
    {Hue[0.6630549322289], AbsoluteThickness[0.5], 
     LineBox[{{7.341081509098933, 1.9555372819863597`}, {7.344366407822268, 
      1.8424170849010477`}}]}, 
    {Hue[0.6637737025969348], AbsoluteThickness[0.5], 
     LineBox[{{7.344366407822268, 1.8424170849010477`}, {7.372508919400013, 
      1.6226560092947893`}}]}, 
    {Hue[0.6770037454101722], AbsoluteThickness[0.5], 
     LineBox[{{4.933471172038791, 2.0451250526433418`}, {4.698023718464621, 
      1.9885595114614367`}}]}, 
    {Hue[0.6771936593159545], AbsoluteThickness[0.5], 
     LineBox[{{4.698023718464621, 1.9885595114614365`}, {4.385537894137745, 
      1.9179248820281938`}}]}, 
    {Hue[0.5968699762795002], AbsoluteThickness[0.5], 
     LineBox[{{4.372429286979578, 2.9644152224685603`}, {3.9123037629453368`, 
      3.1528852667350202`}}]}, 
    {Hue[0.5970870138677276], AbsoluteThickness[0.5], 
     LineBox[{{3.9123037629453368`, 3.1528852667350202`}, {3.613683131266335, 
      3.285649020901551}}]}, 
    {Hue[0.6675291501079006], AbsoluteThickness[0.5], 
     LineBox[{{4.110370663361457, -0.32787980772381814`}, {
      4.064677983430684, -0.3666837619941653}}]}, 
    {Hue[0.667738800339327], AbsoluteThickness[0.5], 
     LineBox[{{4.064677983430684, -0.3666837619941653}, {
      3.8437336950449588`, -0.5645446446200453}}]}, 
    {Hue[0.5283071153202468], AbsoluteThickness[0.5], 
     LineBox[{{2.379458000813778, 1.6251160758509406`}, {2.326056895709007, 
      1.6408456934842706`}}]}, 
    {Hue[0.5298011074587435], AbsoluteThickness[0.5], 
     LineBox[{{2.326056895709007, 1.6408456934842706`}, {2.1664863383255795`, 
      1.7124017880902116`}}]}, 
    {Hue[0.6962443124754412], AbsoluteThickness[0.5], 
     LineBox[{{4.608146945359943, 3.6724081726290074`}, {4.6303386272555365`, 
      3.744375749694504}}]}, 
    {Hue[0.6934741475462814], AbsoluteThickness[0.5], 
     LineBox[{{3.360907336975386, 3.524693212670782}, {3.304799005122269, 
      3.6423960631976082`}}]}, 
    {Hue[0.6936719251943335], AbsoluteThickness[0.5], 
     LineBox[{{3.304799005122269, 3.6423960631976082`}, {3.1688661246212564`, 
      3.9136726985842807`}}]}, 
    {Hue[0.4548354862539275], AbsoluteThickness[0.5], 
     LineBox[{{2.577113124496869, 2.7190939695865692`}, {2.3044227199070897`, 
      2.8599001531862447`}}]}, 
    {Hue[0.45786192635614575`], AbsoluteThickness[0.5], 
     LineBox[{{2.3044227199070897`, 2.8599001531862447`}, {
      2.1626895965014343`, 2.9042839244054353`}}]}, 
    {Hue[0.6967853598890004], AbsoluteThickness[0.5], 
     LineBox[{{2.1626895965014343`, 2.9042839244054353`}, {
      2.0713890407219795`, 2.787141251001066}}]}, 
    {Hue[0.6659864851025342], AbsoluteThickness[0.5], 
     LineBox[{{2.9275913020691573`, 0.8424886120484518}, {2.906504493089363, 
      0.790802834633577}}]}, 
    {Hue[0.666496314522572], AbsoluteThickness[0.5], 
     LineBox[{{2.906504493089363, 0.790802834633577}, {2.7875435276326748`, 
      0.5557776983030938}}]}, 
    {Hue[0.6990574148669811], AbsoluteThickness[0.5], 
     LineBox[{{2.9713169457996758`, 0.8222603747779084}, {2.9206628938257806`,
       0.7481077742418967}}]}, 
    {Hue[0.6996783511416594], AbsoluteThickness[0.5], 
     LineBox[{{2.9206628938257806`, 0.7481077742418967}, {2.7596905406228465`,
       0.5532177507000103}}]}, 
    {Hue[0.6704349148165766], AbsoluteThickness[0.5], 
     LineBox[{{2.3865127223489795`, -3.5668852488817966`}, {
      2.3275229689816683`, -3.594540250413836}}]}, 
    {Hue[0.6706622537777301], AbsoluteThickness[0.5], 
     LineBox[{{2.3275229689816683`, -3.594540250413836}, {
      2.057599674808473, -3.732319033051137}}]}, 
    {Hue[0.6728813206475447], AbsoluteThickness[0.5], 
     LineBox[{{7.166293012942752, 3.0086036193514536`}, {7.375858465854501, 
      3.0204314211510552`}}]}, 
    {Hue[0.6731826927408201], AbsoluteThickness[0.5], 
     LineBox[{{7.375858465854501, 3.0204314211510552`}, {7.63197961151276, 
      3.0213397653388454`}}]}, 
    {Hue[0.6991663646157736], AbsoluteThickness[0.5], 
     LineBox[{{6.294542797162495, -1.712435348389325}, {
      6.574341747354627, -1.7460994912691292`}}]}, 
    {Hue[0.699355734591431], AbsoluteThickness[0.5], 
     LineBox[{{6.574341747354627, -1.7460994912691292`}, {
      6.852640212802115, -1.7759387147053527`}}]}, 
    {Hue[0.6825956716473466], AbsoluteThickness[0.5], 
     LineBox[{{2.2762663904675184`, 3.0759686155040873`}, {2.155549579335169, 
      3.0016635362683948`}}]}, 
    {Hue[0.6828226311146377], AbsoluteThickness[0.5], 
     LineBox[{{2.155549579335169, 3.0016635362683948`}, {1.939751687198152, 
      2.8785860260273344`}}]}, 
    {Hue[0.6866784255779352], AbsoluteThickness[0.5], 
     LineBox[{{2.1829895557969965`, 3.368145414678848}, {2.3023266289224917`, 
      3.587895943765453}}]}, 
    {Hue[0.6885330327446784], AbsoluteThickness[0.5], 
     LineBox[{{2.3023266289224917`, 3.587895943765453}, {2.3669117145038703`, 
      3.764223584864702}}]}, 
    {Hue[0.6961637203445734], AbsoluteThickness[0.5], 
     LineBox[{{6.874329786784559, 3.224916746452884}, {7.066713849244671, 
      3.3448531121491145`}}]}, 
    {Hue[0.6985113577499908], AbsoluteThickness[0.5], 
     LineBox[{{7.066713849244671, 3.3448531121491145`}, {7.253210388579181, 
      3.423351419153272}}]}, 
    {Hue[0.6360006403769756], AbsoluteThickness[0.5], 
     LineBox[{{2.38258625282617, -0.8872404335930295}, {
      2.1419537588121385`, -0.9426588754758249}}]}, 
    {Hue[0.6361937122433774], AbsoluteThickness[0.5], 
     LineBox[{{2.1419537588121385`, -0.9426588754758249}, {
      1.7735416284485892`, -1.0338422441077806`}}]}, 
    {Hue[0.6324904010541575], AbsoluteThickness[0.5], 
     LineBox[{{5.930327422316176, -1.9106077982607501`}, {
      5.66751611441676, -1.9525769503209212`}}]}, 
    {Hue[0.632678027223095], AbsoluteThickness[0.5], 
     LineBox[{{5.66751611441676, -1.9525769503209212`}, {
      5.333169237688875, -2.0022077378949565`}}]}, 
    {Hue[0.5830399076478859], AbsoluteThickness[0.5], 
     LineBox[{{7.069476274145186, -3.3210102154751135`}, {
      7.05875444315332, -3.3553768685733916`}}]}, 
    {Hue[0.5832269265950699], AbsoluteThickness[0.5], 
     LineBox[{{7.05875444315332, -3.3553768685733916`}, {
      6.965978042793, -3.6638144368616565`}}]}, 
    {Hue[0.6517102711270679], AbsoluteThickness[0.5], 
     LineBox[{{6.6658613148600745`, -2.290693316004209}, {
      6.603155983884158, -2.2910182688181258`}}]}, 
    {Hue[0.657015838723914], AbsoluteThickness[0.5], 
     LineBox[{{6.603155983884158, -2.2910182688181258`}, {
      6.426423131981197, -2.3289619051770183`}}]}, 
    {Hue[0.6615249304842421], AbsoluteThickness[0.5], 
     LineBox[{{7.905259287943307, -0.9688719174246986}, {
      7.915357255053708, -0.671240002641347}}]}, 
    {Hue[0.6617239655701824], AbsoluteThickness[0.5], 
     LineBox[{{7.915357255053708, -0.671240002641347}, {
      7.930958569340212, -0.3847901262935921}}]}, 
    {Hue[0.6633985875829566], AbsoluteThickness[0.5], 
     LineBox[{{5.960741327726372, 0.18163303324655294`}, {5.66440582370264, 
      0.4679941414438552}}]}, 
    {Hue[0.6637166650512227], AbsoluteThickness[0.5], 
     LineBox[{{5.66440582370264, 0.4679941414438552}, {5.427593108847438, 
      0.6724781669937853}}]}, 
    {Hue[0.6393611534315805], AbsoluteThickness[0.5], 
     LineBox[{{3.844581130049851, -0.5661312995344663}, {
      3.675606847818308, -0.4607875571318453}}]}, 
    {Hue[0.6407923370871769], AbsoluteThickness[0.5], 
     LineBox[{{3.675606847818308, -0.4607875571318453}, {
      3.4805411901108987`, -0.372600169719215}}]}, 
    {Hue[0.5191271279217194], AbsoluteThickness[0.5], 
     LineBox[{{4.8796782695141685`, -3.08245491405061}, {
      4.8505075852022514`, -3.1287419660385773`}}]}, 
    {Hue[0.5193103202859443], AbsoluteThickness[0.5], 
     LineBox[{{4.8505075852022514`, -3.1287419660385773`}, {
      4.676768144014921, -3.4053014779424857`}}]}, 
    {Hue[0.6800265785415506], AbsoluteThickness[0.5], 
     LineBox[{{3.1309275385333617`, 0.13802487590127688`}, {
      2.9088502337360813`, 0.20410577926362702`}}]}, 
    {Hue[0.6802118461710382], AbsoluteThickness[0.5], 
     LineBox[{{2.9088502337360813`, 0.20410577926362702`}, {2.568817617378096,
       0.3024773324586582}}]}, 
    {Hue[0.6991620078153059], AbsoluteThickness[0.5], 
     LineBox[{{6.891693862377186, 3.3137983546813343`}, {6.900480009785586, 
      3.357864598318122}}]}, 
    {Hue[0.6993568355036917], AbsoluteThickness[0.5], 
     LineBox[{{6.900480009785586, 3.357864598318122}, {6.957214733053927, 
      3.6183783225821378`}}]}, 
    {Hue[0.584656405370687], AbsoluteThickness[0.5], 
     LineBox[{{3.182742657092213, -2.311972613455932}, {
      3.129136823338847, -2.408480019606195}}]}, 
    {Hue[0.5850146504807665], AbsoluteThickness[0.5], 
     LineBox[{{3.129136823338847, -2.408480019606195}, {
      2.9681142684318607`, -2.6598401862157806`}}]}, 
    {Hue[0.650579757398129], AbsoluteThickness[0.5], 
     LineBox[{{5.875281126091442, -4.37143559027782}, {
      5.883357522681043, -4.39835420285686}}]}, 
    {Hue[0.6508070541606356], AbsoluteThickness[0.5], 
     LineBox[{{5.883357522681043, -4.39835420285686}, {
      5.988617948777935, -4.710701163914752}}]}, 
    {Hue[0.6728845944386649], AbsoluteThickness[0.5], 
     LineBox[{{7.897226245942283, -2.319820684585405}, {
      7.91112926995619, -2.329652284028459}}]}, 
    {Hue[0.6731804476326573], AbsoluteThickness[0.5], 
     LineBox[{{7.91112926995619, -2.329652284028459}, {
      8.12604817160651, -2.498956565176562}}]}, 
    {Hue[0.4980328159539593], AbsoluteThickness[0.5], 
     LineBox[{{7.150433843677726, -3.3987902081105528`}, {
      7.147521702715067, -3.405654255286705}}]}, 
    {Hue[0.4982929181127322], AbsoluteThickness[0.5], 
     LineBox[{{7.147521702715067, -3.405654255286705}, {
      7.018810165197388, -3.6757171600667142`}}]}, 
    {Hue[0.5878180314367721], AbsoluteThickness[0.5], 
     LineBox[{{7.850770231733905, 3.0919020319561095`}, {7.84782261656146, 
      3.157509579376103}}]}, 
    {Hue[0.5884726546036159], AbsoluteThickness[0.5], 
     LineBox[{{7.84782261656146, 3.157509579376103}, {7.815550438724145, 
      3.3888616835434866`}}]}, 
    {Hue[0.6588824092533683], AbsoluteThickness[0.5], 
     LineBox[{{4.200021876269678, -0.9119070393901738}, {
      4.136410550081083, -0.9101697603019961}}]}, 
    {Hue[0.6593299874485349], AbsoluteThickness[0.5], 
     LineBox[{{4.136410550081083, -0.9101697603019961}, {
      3.872301017939595, -0.9226557924440155}}]}, 
    {Hue[0.6129227359738013], AbsoluteThickness[0.5], 
     LineBox[{{6.838998481869474, -2.3971098311794203`}, {
      6.66306013011406, -2.6212220089192915`}}]}, 
    {Hue[0.6158696757039838], AbsoluteThickness[0.5], 
     LineBox[{{6.66306013011406, -2.6212220089192915`}, {
      6.575543885995159, -2.7837733642724407`}}]}, 
    {Hue[0.4575173312560225], AbsoluteThickness[0.5], 
     LineBox[{{6.860468037503002, -2.5452454429729006`}, {
      6.964529303640744, -2.809863803943051}}]}, 
    {Hue[0.4577218093110988], AbsoluteThickness[0.5], 
     LineBox[{{6.964529303640744, -2.809863803943051}, {
      7.072749319436245, -3.105403635144691}}]}, 
    {Hue[0.6285269219027658], AbsoluteThickness[0.5], 
     LineBox[{{6.999102128718822, -2.6016873604925377`}, {
      7.261874385091049, -2.6429865621305675`}}]}, 
    {Hue[0.6336254957726021], AbsoluteThickness[0.5], 
     LineBox[{{7.261874385091049, -2.6429865621305675`}, {
      7.410905318833086, -2.699039979861575}}]}, 
    {Hue[0.6171803927043192], AbsoluteThickness[0.5], 
     LineBox[{{7.185536517567847, -1.4233285737793353`}, {
      7.136704245799847, -1.693602331480489}}]}, 
    {Hue[0.6184732740362853], AbsoluteThickness[0.5], 
     LineBox[{{7.136704245799847, -1.693602331480489}, {
      7.1268187889837655`, -1.8870016953381006`}}]}, 
    {Hue[0.6947244127851815], AbsoluteThickness[0.5], 
     LineBox[{{5.589911053871509, 1.723989415994277}, {5.333991827929522, 
      2.0890188684700233`}}]}, 
    {Hue[0.6949079177165698], AbsoluteThickness[0.5], 
     LineBox[{{5.333991827929522, 2.0890188684700233`}, {5.14175033611594, 
      2.3651174583367935`}}]}, 
    {Hue[0.4726402406337323], AbsoluteThickness[0.5], 
     LineBox[{{5.940248911892806, -0.1320508901896091}, {
      5.863056968970465, -0.19280845491380338`}}]}, 
    {Hue[0.4728292289752541], AbsoluteThickness[0.5], 
     LineBox[{{5.863056968970465, -0.19280845491380338`}, {
      5.653980257328887, -0.3616574428833441}}]}, 
    {Hue[0.6807541346686783], AbsoluteThickness[0.5], 
     LineBox[{{7.401924794015256, -0.6117164683421243}, {
      7.478801711368002, -0.8356664099524582}}]}, 
    {Hue[0.6809398128845213], AbsoluteThickness[0.5], 
     LineBox[{{7.478801711368002, -0.8356664099524582}, {
      7.583398214968567, -1.132330017951795}}]}, 
    {Hue[0.691856134876807], AbsoluteThickness[0.5], 
     LineBox[{{7.359469019374845, 3.1712319685556047`}, {7.505099127366551, 
      3.3287697191965226`}}]}, 
    {Hue[0.6922693820517093], AbsoluteThickness[0.5], 
     LineBox[{{7.505099127366551, 3.3287697191965226`}, {7.666072835015382, 
      3.5295693043040495`}}]}, 
    {Hue[0.5919825020003693], AbsoluteThickness[0.5], 
     LineBox[{{7.367555068531391, 3.3293246155986482`}, {7.31726555061554, 
      3.552830485456761}}]}, 
    {Hue[0.5921679260387918], AbsoluteThickness[0.5], 
     LineBox[{{7.31726555061554, 3.552830485456761}, {7.249413289851313, 
      3.865881414191816}}]}, 
    {Hue[0.32548014009171333`], AbsoluteThickness[0.5], 
     LineBox[{{6.351578364845772, 3.0615498507624155`}, {6.332726271625041, 
      3.072085061703826}}]}, 
    {Hue[0.3259819819269226], AbsoluteThickness[0.5], 
     LineBox[{{6.332726271625041, 3.072085061703826}, {6.111084384355568, 
      3.220486449041145}}]}, 
    {Hue[0.6969841629391195], AbsoluteThickness[0.5], 
     LineBox[{{6.111084384355568, 3.220486449041145}, {6.316562790117922, 
      3.3905650271201493`}}]}, 
    {Hue[0.5858626644926189], AbsoluteThickness[0.5], 
     LineBox[{{6.149841575224362, 2.298041295074627}, {5.823748620050392, 
      2.202715441043321}}]}, 
    {Hue[0.5860827820359267], AbsoluteThickness[0.5], 
     LineBox[{{5.823748620050392, 2.202715441043321}, {5.604405943891403, 
      2.1458756573122315`}}]}, 
    {Hue[0.4472605305067779], AbsoluteThickness[0.5], 
     LineBox[{{6.556008619207015, 2.7669057467627027`}, {6.455720919383612, 
      2.812084139995091}}]}, 
    {Hue[0.46106017077541617`], AbsoluteThickness[0.5], 
     LineBox[{{6.455720919383612, 2.812084139995091}, {6.337832227099149, 
      2.9099046679207174`}}]}, 
    {Hue[0.5926802986882784], AbsoluteThickness[0.5], 
     LineBox[{{6.337832227099149, 2.9099046679207174`}, {6.352145538186897, 
      3.0624226294134362`}}]}, 
    {Hue[0.4428747607940808], AbsoluteThickness[0.5], 
     LineBox[{{8.241317660936481, 0.0593787069427702}, {
      8.24463024279155, -0.06646771856770184}}]}, 
    {Hue[0.44306151496844665`], AbsoluteThickness[0.5], 
     LineBox[{{8.24463024279155, -0.06646771856770184}, {
      8.256952250972121, -0.40676657913585323`}}]}, 
    {Hue[0.5356840335503182], AbsoluteThickness[0.5], 
     LineBox[{{7.534634195919815, -0.19247479425545638`}, {
      7.38369793090081, -0.3427039428852845}}]}, 
    {Hue[0.5393805984844966], AbsoluteThickness[0.5], 
     LineBox[{{7.38369793090081, -0.3427039428852845}, {
      7.245025077907684, -0.43724862593718694`}}]}, 
    {Hue[0.6192095377829686], AbsoluteThickness[0.5], 
     LineBox[{{6.918235140502793, -0.6120523874165424}, {
      6.8745919970061, -0.7022677679808029}}]}, 
    {Hue[0.6194556824029659], AbsoluteThickness[0.5], 
     LineBox[{{6.8745919970061, -0.7022677679808029}, {
      6.746337843806928, -0.9425816125023615}}]}, 
    {Hue[0.4664863561462432], AbsoluteThickness[0.5], 
     LineBox[{{7.603390235694879, -1.6110348748944543`}, {
      7.564839912479123, -1.8428960138801187`}}]}, 
    {Hue[0.4667509864640784], AbsoluteThickness[0.5], 
     LineBox[{{7.564839912479123, -1.8428960138801187`}, {
      7.508878933533153, -2.1061952972400784`}}]}, 
    {Hue[0.6850927532076485], AbsoluteThickness[0.5], 
     LineBox[{{4.701971665894905, 1.8586035155755987`}, {4.681822241294973, 
      1.9014125722190873`}}]}, 
    {Hue[0.6855252991262438], AbsoluteThickness[0.5], 
     LineBox[{{4.681822241294973, 1.9014125722190873`}, {4.550720203660656, 
      2.1343176423314136`}}]}, 
    {Hue[0.5966378541077519], AbsoluteThickness[0.5], 
     LineBox[{{4.257659461780888, 0.9100120270629408}, {4.1537787624621005`, 
      0.9380983931909275}}]}, 
    {Hue[0.5969042665886342], AbsoluteThickness[0.5], 
     LineBox[{{4.1537787624621005`, 0.9380983931909275}, {3.876393431753907, 
      1.0266974747121043`}}]}, 
    {Hue[0.44421766891221426`], AbsoluteThickness[0.5], 
     LineBox[{{4.117167632438771, 0.8261175470069844}, {3.998399544867169, 
      0.7106453352719848}}]}, 
    {Hue[0.44484844693828024`], AbsoluteThickness[0.5], 
     LineBox[{{3.998399544867169, 0.7106453352719848}, {3.834142400424299, 
      0.5186169949293943}}]}, 
    {Hue[0.6127920030273835], AbsoluteThickness[0.5], 
     LineBox[{{4.117643865374875, 0.662483775743396}, {4.118875553318521, 
      0.6573601836489971}}]}, 
    {Hue[0.6147785991711971], AbsoluteThickness[0.5], 
     LineBox[{{4.118875553318521, 0.6573601836489971}, {4.13623424416586, 
      0.45570602404111304`}}]}, 
    {Hue[0.6891586832653538], AbsoluteThickness[0.5], 
     LineBox[{{4.751781410101081, 0.14079931650843222`}, {
      4.6926775436207055`, -0.07678088209334444}}]}, 
    {Hue[0.6894260157081151], AbsoluteThickness[0.5], 
     LineBox[{{4.6926775436207055`, -0.07678088209334447}, {
      4.627965300614364, -0.36629352393380893`}}]}, 
    {Hue[0.6649939121636778], AbsoluteThickness[0.5], 
     LineBox[{{3.109795497765404, 1.1420644005632679`}, {2.967594342453163, 
      1.3333641745595262`}}]}, 
    {Hue[0.6655539191687098], AbsoluteThickness[0.5], 
     LineBox[{{2.967594342453163, 1.3333641745595262`}, {2.825680949044306, 
      1.5631240269047626`}}]}, 
    {Hue[0.4430981921690425], AbsoluteThickness[0.5], 
     LineBox[{{2.9148613770099985`, 1.1285672376053026`}, {2.906428365600408, 
      1.1264118496109896`}}]}, 
    {Hue[0.4438146314421651], AbsoluteThickness[0.5], 
     LineBox[{{2.906428365600408, 1.1264118496109896`}, {2.648326616778112, 
      1.086860197629454}}]}, 
    {Hue[0.671947820316955], AbsoluteThickness[0.5], 
     LineBox[{{2.853419889646802, 0.9430775385026428}, {2.841861157799778, 
      0.8603137646950654}}]}, 
    {Hue[0.6721906601865768], AbsoluteThickness[0.5], 
     LineBox[{{2.841861157799778, 0.8603137646950654}, {2.78724020649285, 
      0.5557238620463394}}]}, 
    {Hue[0.6933996793586289], AbsoluteThickness[0.5], 
     LineBox[{{2.3474023378701885`, 0.90487389886163}, {2.2410664177084985`, 
      1.0564604651676346`}}]}, 
    {Hue[0.6938057765522666], AbsoluteThickness[0.5], 
     LineBox[{{2.2410664177084985`, 1.0564604651676346`}, {
      2.0974595866669437`, 1.2948117347041475`}}]}, 
    {Hue[0.6980335925456568], AbsoluteThickness[0.5], 
     LineBox[{{2.1829116023236583`, 0.7363522884607112}, {2.190827813661015, 
      0.3974883048398931}}]}, 
    {Hue[0.6982185743781212], AbsoluteThickness[0.5], 
     LineBox[{{2.190827813661015, 0.39748830483989306`}, {2.198137492260498, 
      0.1574141637177774}}]}, 
    {Hue[0.6943153656282782], AbsoluteThickness[0.5], 
     LineBox[{{7.152935114196686, -3.3998557454180136`}, {
      7.343013019922998, -3.681121789661831}}]}, 
    {Hue[0.6955702607133178], AbsoluteThickness[0.5], 
     LineBox[{{7.343013019922998, -3.681121789661831}, {
      7.415501185784918, -3.8244870407543035`}}]}, 
    {Hue[0.4332657557826322], AbsoluteThickness[0.5], 
     LineBox[{{3.350901074353575, 3.083822610252523}, {3.199044104206012, 
      3.069664227035078}}]}, 
    {Hue[0.4334515316941203], AbsoluteThickness[0.5], 
     LineBox[{{3.199044104206012, 3.069664227035078}, {2.8860657647081065`, 
      3.0378135942946987`}}]}, 
    {Hue[0.3225526056964715], AbsoluteThickness[0.5], 
     LineBox[{{3.3885589709624035`, 3.5767400067352}, {3.3350883661874784`, 
      3.6729827736237035`}}]}, 
    {Hue[0.32280777534759786`], AbsoluteThickness[0.5], 
     LineBox[{{3.3350883661874784`, 3.6729827736237035`}, {
      3.1854391618308204`, 3.917440606065164}}]}, 
    {Hue[0.5961814603114457], AbsoluteThickness[0.5], 
     LineBox[{{3.651399080236819, 3.37910346651708}, {3.847707350386743, 
      3.5520993251997077`}}]}, 
    {Hue[0.596775156431203], AbsoluteThickness[0.5], 
     LineBox[{{3.847707350386743, 3.5520993251997077`}, {4.03176716932845, 
      3.687293224962993}}]}, 
    {Hue[0.4836379191902292], AbsoluteThickness[0.5], 
     LineBox[{{3.6715545154570086`, 3.532753025731774}, {3.6447050878359932`, 
      3.7340071536615724`}}]}, 
    {Hue[0.5007154708822698], AbsoluteThickness[0.5], 
     LineBox[{{3.6447050878359932`, 3.7340071536615724`}, {3.666413661944249, 
      3.8758765752816933`}}]}, 
    {Hue[0.6181029939659323], AbsoluteThickness[0.5], 
     LineBox[{{3.666413661944249, 3.8758765752816933`}, {3.7945631340613906`, 
      3.9404978394038013`}}]}, 
    {Hue[0.621393127079793], AbsoluteThickness[0.5], 
     LineBox[{{3.5550668598930115`, 3.63495407620088}, {3.3616401828882223`, 
      3.7300898723231537`}}]}, 
    {Hue[0.6215943472189847], AbsoluteThickness[0.5], 
     LineBox[{{3.3616401828882223`, 3.7300898723231537`}, {
      3.0875717529220807`, 3.857537429702332}}]}, 
    {Hue[0.5953663353432631], AbsoluteThickness[0.5], 
     LineBox[{{4.139812661650813, 3.5158217226159985`}, {4.409143393975804, 
      3.598808626479347}}]}, 
    {Hue[0.5958810781026362], AbsoluteThickness[0.5], 
     LineBox[{{4.409143393975804, 3.598808626479347}, {4.642666223636448, 
      3.6503448995112304`}}]}, 
    {Hue[0.6250333136979809], AbsoluteThickness[0.5], 
     LineBox[{{6.264634592188302, 3.5569056035555873`}, {6.323640786141722, 
      3.551542038427968}}]}, 
    {Hue[0.6252227451780763], AbsoluteThickness[0.5], 
     LineBox[{{6.323640786141722, 3.551542038427968}, {6.622413844330305, 
      3.520465895530815}}]}, 
    {Hue[0.6704031852396372], AbsoluteThickness[0.5], 
     LineBox[{{6.29350856581124, 2.0561842066253853`}, {6.360070698942792, 
      1.9664371853324578`}}]}, 
    {Hue[0.6726295403769478], AbsoluteThickness[0.5], 
     LineBox[{{6.360070698942792, 1.9664371853324578`}, {6.498313174423297, 
      1.8306402663680825`}}]}, 
    {Hue[0.4783120640647653], AbsoluteThickness[0.5], 
     LineBox[{{6.635004169707646, 2.8971105400953423`}, {6.903575285557843, 
      3.006320190988968}}]}, 
    {Hue[0.47874723864395213`], AbsoluteThickness[0.5], 
     LineBox[{{6.903575285557843, 3.006320190988968}, {7.119367256792085, 
      3.0761878458813996`}}]}, 
    {Hue[0.5165573189274058], AbsoluteThickness[0.5], 
     LineBox[{{6.1972652318558445`, 1.114415438426117}, {6.294695493609805, 
      1.0352192052585532`}}]}, 
    {Hue[0.5169708001102595], AbsoluteThickness[0.5], 
     LineBox[{{6.294695493609805, 1.0352192052585532`}, {6.529350429469603, 
      0.870475889649174}}]}, 
    {Hue[0.566546103424485], AbsoluteThickness[0.5], 
     LineBox[{{5.14685598326838, 1.4104281174482072`}, {5.146718110808978, 
      1.3834846388450577`}}]}, 
    {Hue[0.5668739042038393], AbsoluteThickness[0.5], 
     LineBox[{{5.146718110808978, 1.3834846388450577`}, {5.162084544223142, 
      1.0917722028025019`}}]}, 
    {Hue[0.5917463620609322], AbsoluteThickness[0.5], 
     LineBox[{{3.9166370419365357`, 1.3835162247723365`}, {3.915972049864252, 
      1.3823742354471145`}}]}, 
    {Hue[0.591989882128576], AbsoluteThickness[0.5], 
     LineBox[{{3.9159720498642523`, 1.3823742354471145`}, {
      3.7662921383577954`, 1.1468848888748389`}}]}, 
    {Hue[0.6218793997715047], AbsoluteThickness[0.5], 
     LineBox[{{3.1006670786341908`, 3.289236112860523}, {2.692734014232927, 
      3.4208220106492813`}}]}, 
    {Hue[0.6220628970568295], AbsoluteThickness[0.5], 
     LineBox[{{2.692734014232927, 3.4208220106492813`}, {2.3617301027851787`, 
      3.5264239061816407`}}]}, 
    {Hue[0.5282689310789448], AbsoluteThickness[0.5], 
     LineBox[{{2.602454551891017, 0.12321755953209025`}, {2.5955754033611145`,
       0.12146873893754633`}}]}, 
    {Hue[0.5286652290386409], AbsoluteThickness[0.5], 
     LineBox[{{2.5955754033611145`, 0.1214687389375463}, {2.319178571095467, 
      0.03075668096407757}}]}, 
    {Hue[0.587710556138866], AbsoluteThickness[0.5], 
     LineBox[{{4.237518902676637, 1.909981509090571}, {4.19964115086494, 
      1.929701256250354}}]}, 
    {Hue[0.5879118970931233], AbsoluteThickness[0.5], 
     LineBox[{{4.19964115086494, 1.929701256250354}, {3.915873650154078, 
      2.085425531623274}}]}, 
    {Hue[0.5224163175589711], AbsoluteThickness[0.5], 
     LineBox[{{3.2213753721831653`, 1.1509229207014182`}, {
      3.1376643673154043`, 1.1221886645158219`}}]}, 
    {Hue[0.5227657438925111], AbsoluteThickness[0.5], 
     LineBox[{{3.1376643673154043`, 1.1221886645158219`}, {
      2.8556411871541107`, 1.0443451746924912`}}]}, 
    {Hue[0.6302349111384097], AbsoluteThickness[0.5], 
     LineBox[{{4.226784094955743, 0.11802907473082361`}, {4.177832688135187, 
      0.08579016512972962}}]}, 
    {Hue[0.630435501430179], AbsoluteThickness[0.5], 
     LineBox[{{4.177832688135187, 0.08579016512972962}, {
      3.9173878228281183`, -0.09386285124665285}}]}, 
    {Hue[0.6986658985218018], AbsoluteThickness[0.5], 
     LineBox[{{6.017758252410186, -2.666329052544557}, {
      6.006534413084269, -2.8195029085434435`}}]}, 
    {Hue[0.6988500458231205], AbsoluteThickness[0.5], 
     LineBox[{{6.006534413084269, -2.8195029085434435`}, {
      5.982587617186125, -3.1717560561794467`}}]}, 
    {Hue[0.4834753946816222], AbsoluteThickness[0.5], 
     LineBox[{{2.3678358241441186`, 1.6157500856389455`}, {
      2.1502410153074516`, 1.6477252730810639`}}]}, 
    {Hue[0.4840968047522805], AbsoluteThickness[0.5], 
     LineBox[{{2.1502410153074516`, 1.6477252730810639`}, {1.866738553866757, 
      1.6632737373389903`}}]}, 
    {Hue[0.47959550345989693`], AbsoluteThickness[0.5], 
     LineBox[{{2.5207053132081034`, -2.6411097727657418`}, {
      2.42761242653415, -2.722429377510061}}]}, 
    {Hue[0.48028792284413396`], AbsoluteThickness[0.5], 
     LineBox[{{2.42761242653415, -2.722429377510061}, {
      2.2264786672156953`, -2.866480413713278}}]}, 
    {Hue[0.5783056775698505], AbsoluteThickness[0.5], 
     LineBox[{{3.0835451215110132`, 3.193820375821446}, {2.980971346924826, 
      3.384369921390081}}]}, 
    {Hue[0.5787049509719183], AbsoluteThickness[0.5], 
     LineBox[{{2.980971346924826, 3.384369921390081}, {2.873754933729199, 
      3.6211107541915326`}}]}, 
    {Hue[0.5680729823718866], AbsoluteThickness[0.5], 
     LineBox[{{3.830651011562688, 3.011017350880267}, {3.792604485067973, 
      3.091943737459184}}]}, 
    {Hue[0.5683104307678595], AbsoluteThickness[0.5], 
     LineBox[{{3.792604485067973, 3.091943737459184}, {3.667143186592133, 
      3.386655018692026}}]}, 
    {Hue[0.6689141781048067], AbsoluteThickness[0.5], 
     LineBox[{{2.363445515092777, 0.42283839082818514`}, {2.1629977363500927`,
       0.45237841394074313`}}]}, 
    {Hue[0.6691008001864835], AbsoluteThickness[0.5], 
     LineBox[{{2.1629977363500927`, 0.45237841394074313`}, {
      1.9255244467780555`, 0.4850253643387584}}]}, 
    {Hue[0.4704651369386235], AbsoluteThickness[0.5], 
     LineBox[{{4.395953481947561, 3.52396953458935}, {4.330377895951577, 
      3.613602019872441}}]}, 
    {Hue[0.4706524434792082], AbsoluteThickness[0.5], 
     LineBox[{{4.330377895951577, 3.613602019872441}, {4.1545226228344525`, 
      3.848702210669975}}]}, 
    {Hue[0.5974795412934254], AbsoluteThickness[0.5], 
     LineBox[{{7.825791340319894, 0.5933320850040109}, {7.8593814876447174`, 
      0.5594364396521986}}]}, 
    {Hue[0.5977696175542632], AbsoluteThickness[0.5], 
     LineBox[{{7.8593814876447174`, 0.5594364396521986}, {8.081675417603904, 
      0.3567032731689679}}]}, 
    {Hue[0.666398765779642], AbsoluteThickness[0.5], 
     LineBox[{{7.096466395184083, 0.3260823219419739}, {7.110169719282886, 
      0.2755412943464901}}]}, 
    {Hue[0.6668333834548787], AbsoluteThickness[0.5], 
     LineBox[{{7.110169719282886, 0.2755412943464901}, {7.173986439691582, 
      0.0938575404021978}}]}, 
    {Hue[0.6386610351570324], AbsoluteThickness[0.5], 
     LineBox[{{5.098600632748835, 2.3179016869850884`}, {4.888769269933546, 
      2.2467869132101863`}}]}, 
    {Hue[0.6389120150392072], AbsoluteThickness[0.5], 
     LineBox[{{4.888769269933546, 2.2467869132101863`}, {4.60623413005632, 
      2.1637909267630078`}}]}, 
    {Hue[0.6774793272423182], AbsoluteThickness[0.5], 
     LineBox[{{6.352822588729898, 2.881774653529568}, {6.348498540963568, 
      2.8777780362125003`}}]}, 
    {Hue[0.6776669068039004], AbsoluteThickness[0.5], 
     LineBox[{{6.348498540963568, 2.8777780362125003`}, {6.101941934037496, 
      2.654840751506858}}]}, 
    {Hue[0.6820501814878446], AbsoluteThickness[0.5], 
     LineBox[{{7.35450132886719, 2.727795098489933}, {7.381310718910736, 
      2.6440872337303665`}}]}, 
    {Hue[0.6822394937172962], AbsoluteThickness[0.5], 
     LineBox[{{7.381310718910736, 2.6440872337303665`}, {7.4872954362059225`, 
      2.3272620760423}}]}, 
    {Hue[0.6644924729649695], AbsoluteThickness[0.5], 
     LineBox[{{7.372508919400013, 1.6226560092947893`}, {7.372752225477329, 
      1.6215963790450416`}}]}, 
    {Hue[0.6649125868881777], AbsoluteThickness[0.5], 
     LineBox[{{7.372752225477329, 1.6215963790450416`}, {7.412708949979767, 
      1.3649542899157536`}}]}, 
    {Hue[0.6773835732217371], AbsoluteThickness[0.5], 
     LineBox[{{4.385537894137745, 1.917924882028194}, {4.339896425545627, 
      1.9082524771412326`}}]}, 
    {Hue[0.6790899264214717], AbsoluteThickness[0.5], 
     LineBox[{{4.339896425545627, 1.9082524771412326`}, {4.1432445512089, 
      1.8362821881632283`}}]}, 
    {Hue[0.5973040514559549], AbsoluteThickness[0.5], 
     LineBox[{{3.613683131266335, 3.285649020901551}, {3.553902918326969, 
      3.314373845341771}}]}, 
    {Hue[0.5982450186005109], AbsoluteThickness[0.5], 
     LineBox[{{3.553902918326969, 3.314373845341771}, {3.357456586428072, 
      3.437434345337315}}]}, 
    {Hue[0.6679484505707532], AbsoluteThickness[0.5], 
     LineBox[{{3.8437336950449588`, -0.5645446446200453}, {
      3.823958396045145, -0.5832133566231358}}]}, 
    {Hue[0.6682894065587217], AbsoluteThickness[0.5], 
     LineBox[{{3.823958396045145, -0.5832133566231358}, {
      3.6415973214998734`, -0.7773224395460558}}]}, 
    {Hue[0.6937589197867827], AbsoluteThickness[0.5], 
     LineBox[{{2.3044227199070897`, 2.8599001531862447`}, {
      2.2541150612332057`, 3.0764472252778026`}}]}, 
    {Hue[0.6939798450526311], AbsoluteThickness[0.5], 
     LineBox[{{2.2541150612332057`, 3.0764472252778026`}, {
      2.1945212760539454`, 3.3748669079486944`}}]}, 
    {Hue[0.46088836645836395`], AbsoluteThickness[0.5], 
     LineBox[{{2.1626895965014343`, 2.9042839244054353`}, {
      2.1397724922646493`, 2.907287161873985}}]}, 
    {Hue[0.46113878255833296`], AbsoluteThickness[0.5], 
     LineBox[{{2.1397724922646493`, 2.907287161873985}, {1.9002821581533915`, 
      2.948691825759078}}]}, 
    {Hue[0.6998117999912186], AbsoluteThickness[0.5], 
     LineBox[{{2.0713890407219795`, 2.787141251001066}, {1.9981921232715614`, 
      2.649539852330109}}]}, 
    {Hue[0.6670061439426095], AbsoluteThickness[0.5], 
     LineBox[{{2.7875435276326748`, 0.5557776983030938}, {2.7013439460896578`,
       0.41510805924679106`}}]}, 
    {Hue[0.6675410687732628], AbsoluteThickness[0.5], 
     LineBox[{{2.7013439460896578`, 0.41510805924679106`}, {
      2.5751762563305114`, 0.164338020188098}}]}, 
    {Hue[0.6734840648340955], AbsoluteThickness[0.5], 
     LineBox[{{7.63197961151276, 3.0213397653388454`}, {7.843513348210977, 
      3.0109054965819593`}}]}, 
    {Hue[0.6736852130182318], AbsoluteThickness[0.5], 
     LineBox[{{7.843513348210977, 3.0109054965819593`}, {8.145218465973057, 
      3.002605801682305}}]}, 
    {Hue[0.6995451045670883], AbsoluteThickness[0.5], 
     LineBox[{{6.852640212802115, -1.7759387147053527`}, {
      7.094971761813688, -1.7987569508849908`}}]}, 
    {Hue[0.6997325551142023], AbsoluteThickness[0.5], 
     LineBox[{{7.094971761813688, -1.7987569508849908`}, {
      7.3847323755227645`, -1.8228940275480667`}}]}, 
    {Hue[0.6328656533920325], AbsoluteThickness[0.5], 
     LineBox[{{5.333169237688875, -2.0022077378949565`}, {
      5.102642866096751, -2.0338418521312005`}}]}, 
    {Hue[0.6331040145101817], AbsoluteThickness[0.5], 
     LineBox[{{5.102642866096751, -2.0338418521312005`}, {
      4.810627423020948, -2.0628701227823787`}}]}, 
    {Hue[0.5834139455422539], AbsoluteThickness[0.5], 
     LineBox[{{6.965978042793, -3.6638144368616565`}, {
      6.904023761744716, -3.8776898950459926`}}]}, 
    {Hue[0.5843448088095784], AbsoluteThickness[0.5], 
     LineBox[{{6.904023761744716, -3.8776898950459926`}, {
      6.866622737248663, -4.094535006342286}}]}, 
    {Hue[0.6623214063207599], AbsoluteThickness[0.5], 
     LineBox[{{6.426423131981197, -2.3289619051770183`}, {
      6.399416597563361, -2.340950662209046}}]}, 
    {Hue[0.6663595950466715], AbsoluteThickness[0.5], 
     LineBox[{{6.399416597563361, -2.340950662209046}, {
      6.2235295923556375`, -2.3817523947534873`}}]}, 
    {Hue[0.6619230006561228], AbsoluteThickness[0.5], 
     LineBox[{{7.930958569340212, -0.3847901262935921}, {
      7.947664964619279, -0.16217757645068404`}}]}, 
    {Hue[0.6621396220633472], AbsoluteThickness[0.5], 
     LineBox[{{7.947664964619279, -0.16217757645068404`}, {7.979510040500845, 
      0.1419831973646408}}]}, 
    {Hue[0.6640347425194887], AbsoluteThickness[0.5], 
     LineBox[{{5.427593108847438, 0.6724781669937853}, {5.383963743079979, 
      0.7060783323082914}}]}, 
    {Hue[0.6642541493192062], AbsoluteThickness[0.5], 
     LineBox[{{5.383963743079979, 0.7060783323082914}, {5.14771009037063, 
      0.8767832613979392}}]}, 
    {Hue[0.6422235207427732], AbsoluteThickness[0.5], 
     LineBox[{{3.4805411901108987`, -0.372600169719215}, {
      3.4060816265724547`, -0.350241541182473}}]}, 
    {Hue[0.6424144808583562], AbsoluteThickness[0.5], 
     LineBox[{{3.4060816265724547`, -0.350241541182473}, {
      3.1066298187111636`, -0.2555800674312975}}]}, 
    {Hue[0.5194935126501692], AbsoluteThickness[0.5], 
     LineBox[{{4.676768144014921, -3.4053014779424857`}, {
      4.657676669171288, -3.4357880667505545`}}]}, 
    {Hue[0.5203559600530797], AbsoluteThickness[0.5], 
     LineBox[{{4.657676669171288, -3.4357880667505545`}, {
      4.510555217834851, -3.622696215050899}}]}, 
    {Hue[0.6803971138005258], AbsoluteThickness[0.5], 
     LineBox[{{2.568817617378096, 0.30247733245865827`}, {2.1565119128098553`,
       0.41836773618834916`}}]}, 
    {Hue[0.6805813804372709], AbsoluteThickness[0.5], 
     LineBox[{{2.1565119128098553`, 0.41836773618834916`}, {
      1.9254498630377734`, 0.4847035724536128}}]}, 
    {Hue[0.585372895590846], AbsoluteThickness[0.5], 
     LineBox[{{2.9681142684318607`, -2.6598401862157806`}, {
      2.919631614244007, -2.7259929176539672`}}]}, 
    {Hue[0.5860349593313605], AbsoluteThickness[0.5], 
     LineBox[{{2.919631614244007, -2.7259929176539672`}, {
      2.7454803212975145`, -2.9218814178830406`}}]}, 
    {Hue[0.6734763008266497], AbsoluteThickness[0.5], 
     LineBox[{{8.12604817160651, -2.498956565176562}, {
      8.246993911727618, -2.6048101806406474`}}]}, 
    {Hue[0.6739035090123049], AbsoluteThickness[0.5], 
     LineBox[{{8.246993911727618, -2.6048101806406474`}, {
      8.464967287231055, -2.8252742464879286`}}]}, 
    {Hue[0.498553020271505], AbsoluteThickness[0.5], 
     LineBox[{{7.018810165197388, -3.6757171600667142`}, {
      6.9154365070604165`, -3.8703378116629303`}}]}, 
    {Hue[0.5001340983403967], AbsoluteThickness[0.5], 
     LineBox[{{6.9154365070604165`, -3.8703378116629303`}, {
      6.847230167096772, -4.057055011384567}}]}, 
    {Hue[0.5891272777704595], AbsoluteThickness[0.5], 
     LineBox[{{7.815550438724145, 3.3888616835434866`}, {7.770634920213825, 
      3.578721628612756}}]}, 
    {Hue[0.5893345524267398], AbsoluteThickness[0.5], 
     LineBox[{{7.770634920213825, 3.578721628612756}, {7.705414945740973, 
      3.888998368063742}}]}, 
    {Hue[0.6597775656437015], AbsoluteThickness[0.5], 
     LineBox[{{3.872301017939595, -0.9226557924440155}, {
      3.710162616831017, -0.9425001262725878}}]}, 
    {Hue[0.6599613363295627], AbsoluteThickness[0.5], 
     LineBox[{{3.710162616831017, -0.9425001262725878}, {
      3.3837451970089263`, -0.9810609906121149}}]}, 
    {Hue[0.6188166154341663], AbsoluteThickness[0.5], 
     LineBox[{{6.575543885995159, -2.7837733642724407`}, {
      6.541654341085413, -2.88528378636298}}]}, 
    {Hue[0.6190015545155267], AbsoluteThickness[0.5], 
     LineBox[{{6.541654341085413, -2.88528378636298}, {
      6.43912162825665, -3.185392938272045}}]}, 
    {Hue[0.4579262873661749], AbsoluteThickness[0.5], 
     LineBox[{{7.072749319436245, -3.105403635144691}, {
      7.08799960753779, -3.150314265218908}}]}, 
    {Hue[0.45826928423126023`], AbsoluteThickness[0.5], 
     LineBox[{{7.08799960753779, -3.150314265218908}, {
      7.194421264377078, -3.4109465853670002`}}]}, 
    {Hue[0.6387240696424381], AbsoluteThickness[0.5], 
     LineBox[{{7.410905318833086, -2.699039979861575}, {
      7.588084346100509, -2.811015656833259}}]}, 
    {Hue[0.6394798644033863], AbsoluteThickness[0.5], 
     LineBox[{{7.588084346100509, -2.811015656833259}, {
      7.757347622260808, -2.895465567414296}}]}, 
    {Hue[0.6197661553682514], AbsoluteThickness[0.5], 
     LineBox[{{7.1268187889837655`, -1.8870016953381006`}, {
      7.128881658595486, -1.9138761945120275`}}]}, 
    {Hue[0.6208345292557907], AbsoluteThickness[0.5], 
     LineBox[{{7.128881658595486, -1.9138761945120275`}, {
      7.120352531365677, -2.119608947377167}}]}, 
    {Hue[0.6950914226479582], AbsoluteThickness[0.5], 
     LineBox[{{5.14175033611594, 2.3651174583367935`}, {5.1076434555438315`, 
      2.4144414593341925`}}]}, 
    {Hue[0.6952838312863626], AbsoluteThickness[0.5], 
     LineBox[{{5.1076434555438315`, 2.4144414593341925`}, {
      4.9558269679507205`, 2.6415458060438706`}}]}, 
    {Hue[0.47301821731677596`], AbsoluteThickness[0.5], 
     LineBox[{{5.653980257328887, -0.3616574428833441}, {
      5.594967418142435, -0.41055009918854746`}}]}, 
    {Hue[0.47321979037596107`], AbsoluteThickness[0.5], 
     LineBox[{{5.594967418142435, -0.41055009918854746`}, {
      5.3552372974225495`, -0.6182436607527533}}]}, 
    {Hue[0.6811254911003645], AbsoluteThickness[0.5], 
     LineBox[{{7.583398214968567, -1.132330017951795}, {
      7.618430132596749, -1.2291221078227457`}}]}, 
    {Hue[0.6841391619495543], AbsoluteThickness[0.5], 
     LineBox[{{7.618430132596749, -1.2291221078227457`}, {
      7.71366100941622, -1.3953709118801847`}}]}, 
    {Hue[0.6926826292266117], AbsoluteThickness[0.5], 
     LineBox[{{7.666072835015382, 3.5295693043040495`}, {7.709587383961219, 
      3.592447385020252}}]}, 
    {Hue[0.6928783381260929], AbsoluteThickness[0.5], 
     LineBox[{{7.709587383961219, 3.592447385020252}, {7.88750394744357, 
      3.8598451511704264`}}]}, 
    {Hue[0.6964823211039062], AbsoluteThickness[0.5], 
     LineBox[{{6.332726271625041, 3.072085061703826}, {6.27728416674348, 
      2.933684843818274}}]}, 
    {Hue[0.6966654723070532], AbsoluteThickness[0.5], 
     LineBox[{{6.27728416674348, 2.933684843818274}, {6.152706677785381, 
      2.623570492538123}}]}, 
    {Hue[0.326483823762132], AbsoluteThickness[0.5], 
     LineBox[{{6.111084384355568, 3.220486449041145}, {5.954758455371051, 
      3.344437558261244}}]}, 
    {Hue[0.3287751888780531], AbsoluteThickness[0.5], 
     LineBox[{{5.954758455371051, 3.344437558261244}, {5.848099970795353, 
      3.4606262406768167`}}]}, 
    {Hue[0.587980064212878], AbsoluteThickness[0.5], 
     LineBox[{{5.848099970795353, 3.4606262406768167`}, {5.928757673475447, 
      3.59616286765204}}]}, 
    {Hue[0.6974860047743289], AbsoluteThickness[0.5], 
     LineBox[{{6.316562790117922, 3.3905650271201493`}, {6.356524519002311, 
      3.4185556272910147`}}]}, 
    {Hue[0.6976725467168446], AbsoluteThickness[0.5], 
     LineBox[{{6.356524519002311, 3.4185556272910147`}, {6.601745336365228, 
      3.5938447090001717`}}]}, 
    {Hue[0.5863028995792343], AbsoluteThickness[0.5], 
     LineBox[{{5.604405943891403, 2.1458756573122315`}, {5.592964444774758, 
      2.143284465560271}}]}, 
    {Hue[0.5872163955404703], AbsoluteThickness[0.5], 
     LineBox[{{5.592964444774758, 2.143284465560271}, {5.434749207937504, 
      2.0885718099516564`}}]}, 
    {Hue[0.5788806584196359], AbsoluteThickness[0.5], 
     LineBox[{{6.455720919383612, 2.812084139995091}, {6.377552899821237, 
      2.8113232883593313`}}]}, 
    {Hue[0.5790753750353194], AbsoluteThickness[0.5], 
     LineBox[{{6.377552899821237, 2.8113232883593313`}, {6.048061583993393, 
      2.8023330118719088`}}]}, 
    {Hue[0.47485981104405345`], AbsoluteThickness[0.5], 
     LineBox[{{6.337832227099149, 2.9099046679207174`}, {6.225713861223167, 
      3.070734819407332}}]}, 
    {Hue[0.47589518284742166`], AbsoluteThickness[0.5], 
     LineBox[{{6.225713861223167, 3.070734819407332}, {6.116955393542976, 
      3.2735007709854105`}}]}, 
    {Hue[0.6064799389569157], AbsoluteThickness[0.5], 
     LineBox[{{6.352145538186897, 3.0624226294134362`}, {6.360730456802546, 
      3.0850282812256205`}}]}, 
    {Hue[0.6073775380323692], AbsoluteThickness[0.5], 
     LineBox[{{6.360730456802546, 3.0850282812256205`}, {6.420110121692732, 
      3.3141384967822844`}}]}, 
    {Hue[0.44324826914281246`], AbsoluteThickness[0.5], 
     LineBox[{{8.256952250972121, -0.4067665791358533}, {
      8.26526151421365, -0.5869975905894367}}]}, 
    {Hue[0.44343167544761874`], AbsoluteThickness[0.5], 
     LineBox[{{8.26526151421365, -0.5869975905894367}, {
      8.282525643195672, -0.9400201055250266}}]}, 
    {Hue[0.5430771634186748], AbsoluteThickness[0.5], 
     LineBox[{{7.245025077907684, -0.43724862593718694`}, {
      7.117777238390527, -0.4931210008312532}}]}, 
    {Hue[0.5435066442576468], AbsoluteThickness[0.5], 
     LineBox[{{7.117777238390528, -0.4931210008312532}, {
      6.860004043903626, -0.5846922603434024}}]}, 
    {Hue[0.6197018270229631], AbsoluteThickness[0.5], 
     LineBox[{{6.746337843806928, -0.9425816125023615}, {
      6.480883233853334, -1.3957434313766623`}}]}, 
    {Hue[0.6208303726561667], AbsoluteThickness[0.5], 
     LineBox[{{6.480883233853334, -1.3957434313766623`}, {
      6.404594217038392, -1.5717003663107687`}}]}, 
    {Hue[0.4670156167819136], AbsoluteThickness[0.5], 
     LineBox[{{7.508878933533153, -2.1061952972400784`}, {
      7.435440312755351, -2.388980126571918}}]}, 
    {Hue[0.46735147972246294`], AbsoluteThickness[0.5], 
     LineBox[{{7.435440312755351, -2.388980126571918}, {
      7.381736509769126, -2.6609417351921207`}}]}, 
    {Hue[0.6859578450448391], AbsoluteThickness[0.5], 
     LineBox[{{4.550720203660656, 2.1343176423314136`}, {4.428443316827227, 
      2.3187447737060687`}}]}, 
    {Hue[0.6873169021661307], AbsoluteThickness[0.5], 
     LineBox[{{4.428443316827227, 2.3187447737060687`}, {4.337253499543261, 
      2.5050236894144997`}}]}, 
    {Hue[0.5971706790695166], AbsoluteThickness[0.5], 
     LineBox[{{3.876393431753907, 1.0266974747121043`}, {3.6701262197708275`, 
      1.1029914289804044`}}]}, 
    {Hue[0.5982996761955552], AbsoluteThickness[0.5], 
     LineBox[{{3.6701262197708275`, 1.1029914289804044`}, {
      3.4621819624918184`, 1.1524391197069026`}}]}, 
    {Hue[0.44547922496434617`], AbsoluteThickness[0.5], 
     LineBox[{{3.834142400424299, 0.5186169949293943}, {3.73333375410169, 
      0.37613382223822867`}}]}, 
    {Hue[0.4461575581216349], AbsoluteThickness[0.5], 
     LineBox[{{3.73333375410169, 0.37613382223822867`}, {3.6118972978118684`, 
      0.16418018278816915`}}]}, 
    {Hue[0.6167651953150107], AbsoluteThickness[0.5], 
     LineBox[{{4.13623424416586, 0.45570602404111304`}, {4.117262062815048, 
      0.16049933262649818`}}]}, 
    {Hue[0.6170720308705258], AbsoluteThickness[0.5], 
     LineBox[{{4.117262062815048, 0.16049933262649818`}, {
      4.08319075266063, -0.12669712854553145`}}]}, 
    {Hue[0.6896933481508766], AbsoluteThickness[0.5], 
     LineBox[{{4.627965300614364, -0.36629352393380893`}, {
      4.616643151682505, -0.43049006424632213`}}]}, 
    {Hue[0.6900839457181234], AbsoluteThickness[0.5], 
     LineBox[{{4.616643151682505, -0.43049006424632213`}, {
      4.552047754432303, -0.6922139549788413}}]}, 
    {Hue[0.6661139261737417], AbsoluteThickness[0.5], 
     LineBox[{{2.825680949044306, 1.5631240269047626`}, {2.7959855139893546`, 
      1.6219647450608035`}}]}, 
    {Hue[0.6663380490648066], AbsoluteThickness[0.5], 
     LineBox[{{2.7959855139893546`, 1.6219647450608035`}, {
      2.6709939753795493`, 1.8909537908995016`}}]}, 
    {Hue[0.4445310707152877], AbsoluteThickness[0.5], 
     LineBox[{{2.648326616778112, 1.086860197629454}, {2.5204903062092607`, 
      1.0799653130267683`}}]}, 
    {Hue[0.44625036080783176`], AbsoluteThickness[0.5], 
     LineBox[{{2.5204903062092607`, 1.0799653130267683`}, {
      2.3688715306818175`, 1.0498166231520185`}}]}, 
    {Hue[0.6724335000561986], AbsoluteThickness[0.5], 
     LineBox[{{2.78724020649285, 0.5557238620463394}, {2.756798215815996, 
      0.4170659713737852}}]}, 
    {Hue[0.6726196038399767], AbsoluteThickness[0.5], 
     LineBox[{{2.756798215815996, 0.4170659713737852}, {2.6840645451323115`, 
      0.07101065378714078}}]}, 
    {Hue[0.6942118737459042], AbsoluteThickness[0.5], 
     LineBox[{{2.0974595866669437`, 1.2948117347041475`}, {
      2.0631151281931768`, 1.361958894730527}}]}, 
    {Hue[0.6944012815393918], AbsoluteThickness[0.5], 
     LineBox[{{2.0631151281931768`, 1.361958894730527}, {1.8999957360474449`, 
      1.691340859919253}}]}, 
    {Hue[0.6984035562105855], AbsoluteThickness[0.5], 
     LineBox[{{2.198137492260498, 0.1574141637177774}, {
      2.2090268470570162`, -0.13268082458635444`}}]}, 
    {Hue[0.6986323986652576], AbsoluteThickness[0.5], 
     LineBox[{{2.2090268470570162`, -0.13268082458635444`}, {
      2.2306487365576024`, -0.434011017903535}}]}, 
    {Hue[0.6968251557983574], AbsoluteThickness[0.5], 
     LineBox[{{7.415501185784918, -3.8244870407543035`}, {
      7.422972368351319, -3.8454761566998754`}}]}, 
    {Hue[0.6970177548987189], AbsoluteThickness[0.5], 
     LineBox[{{7.422972368351319, -3.8454761566998754`}, {
      7.5064694967424925`, -4.068756492661345}}]}, 
    {Hue[0.43363730760560837`], AbsoluteThickness[0.5], 
     LineBox[{{2.8860657647081065`, 3.0378135942946987`}, {2.616602416028211, 
      3.0080884991397507`}}]}, 
    {Hue[0.4338215963563692], AbsoluteThickness[0.5], 
     LineBox[{{2.616602416028211, 3.0080884991397507`}, {2.301734612303231, 
      2.9715636864263844`}}]}, 
    {Hue[0.5973688525509602], AbsoluteThickness[0.5], 
     LineBox[{{4.03176716932845, 3.687293224962993}, {4.083036431691981, 
      3.7183520146823694`}}]}, 
    {Hue[0.5976719276408117], AbsoluteThickness[0.5], 
     LineBox[{{4.083036431691981, 3.7183520146823694`}, {4.315560330733823, 
      3.842826281431774}}]}, 
    {Hue[0.5963958208620095], AbsoluteThickness[0.5], 
     LineBox[{{4.642666223636448, 3.6503448995112304`}, {4.648119115760208, 
      3.6510884643268637`}}]}, 
    {Hue[0.5966331867280624], AbsoluteThickness[0.5], 
     LineBox[{{4.648119115760208, 3.6510884643268637`}, {4.926853849632756, 
      3.6996533119034503`}}]}, 
    {Hue[0.6254121766581717], AbsoluteThickness[0.5], 
     LineBox[{{6.622413844330305, 3.520465895530815}, {6.816371544651145, 
      3.497741381394294}}]}, 
    {Hue[0.6255953258658835], AbsoluteThickness[0.5], 
     LineBox[{{6.816371544651145, 3.497741381394294}, {7.08493018736672, 
      3.4665318756219445`}}]}, 
    {Hue[0.6748558955142584], AbsoluteThickness[0.5], 
     LineBox[{{6.498313174423297, 1.8306402663680825`}, {6.628465941339579, 
      1.7376646769887718`}}]}, 
    {Hue[0.675100765683728], AbsoluteThickness[0.5], 
     LineBox[{{6.628465941339579, 1.7376646769887718`}, {6.8423809303975185`, 
      1.5972051673966625`}}]}, 
    {Hue[0.47918241322313887`], AbsoluteThickness[0.5], 
     LineBox[{{7.119367256792085, 3.0761878458813996`}, {7.180006138502992, 
      3.0910293230434465`}}]}, 
    {Hue[0.4821646033028257], AbsoluteThickness[0.5], 
     LineBox[{{7.180006138502992, 3.0910293230434465`}, {7.358079660061334, 
      3.168928479704756}}]}, 
    {Hue[0.5173842812931135], AbsoluteThickness[0.5], 
     LineBox[{{6.529350429469603, 0.870475889649174}, {6.612412203942919, 
      0.8204946137409735}}]}, 
    {Hue[0.5175695309162268], AbsoluteThickness[0.5], 
     LineBox[{{6.612412203942919, 0.8204946137409735}, {6.913412393865279, 
      0.6424620335464204}}]}, 
    {Hue[0.5672017049831937], AbsoluteThickness[0.5], 
     LineBox[{{5.162084544223142, 1.0917722028025019`}, {5.183607526553527, 
      0.8975625777593969}}]}, 
    {Hue[0.5674124945818615], AbsoluteThickness[0.5], 
     LineBox[{{5.183607526553527, 0.8975625777593969}, {5.223831140464143, 
      0.6062246397799318}}]}, 
    {Hue[0.5922334021962197], AbsoluteThickness[0.5], 
     LineBox[{{3.7662921383577954`, 1.1468848888748389`}, {
      3.6942946472059317`, 1.0427846718180966`}}]}, 
    {Hue[0.5928621570201149], AbsoluteThickness[0.5], 
     LineBox[{{3.6942946472059317`, 1.0427846718180966`}, {
      3.5400266537753016`, 0.8584285114380503}}]}, 
    {Hue[0.6222463943421543], AbsoluteThickness[0.5], 
     LineBox[{{2.3617301027851787`, 3.5264239061816407`}, {
      2.2362153506393723`, 3.5660250924968926`}}]}, 
    {Hue[0.6260980934266199], AbsoluteThickness[0.5], 
     LineBox[{{2.2362153506393723`, 3.5660250924968926`}, {2.089830620806531, 
      3.644610377272796}}]}, 
    {Hue[0.529061526998337], AbsoluteThickness[0.5], 
     LineBox[{{2.319178571095467, 0.030756680964077566`}, {
      2.1509732346100674`, -0.037460808890576236`}}]}, 
    {Hue[0.5293369128655928], AbsoluteThickness[0.5], 
     LineBox[{{2.1509732346100674`, -0.037460808890576236`}, {
      1.8184609758976726`, -0.1543466785264378}}]}, 
    {Hue[0.5881132380473807], AbsoluteThickness[0.5], 
     LineBox[{{3.915873650154078, 2.085425531623274}, {3.811957347798449, 
      2.145449446476206}}]}, 
    {Hue[0.5882974504001622], AbsoluteThickness[0.5], 
     LineBox[{{3.811957347798449, 2.145449446476206}, {3.58339473401461, 
      2.2758211254393754`}}]}, 
    {Hue[0.5231151702260509], AbsoluteThickness[0.5], 
     LineBox[{{2.8556411871541107`, 1.0443451746924912`}, {2.585297879846851, 
      0.987296686739908}}]}, 
    {Hue[0.523300593529474], AbsoluteThickness[0.5], 
     LineBox[{{2.585297879846851, 0.987296686739908}, {2.345772548463666, 
      0.9347785088876049}}]}, 
    {Hue[0.6306360917219483], AbsoluteThickness[0.5], 
     LineBox[{{3.9173878228281183`, -0.09386285124665286}, {
      3.8483375195141334`, -0.14371255809062766`}}]}, 
    {Hue[0.6308192503903757], AbsoluteThickness[0.5], 
     LineBox[{{3.8483375195141334`, -0.14371255809062766`}, {
      3.5719528092812887`, -0.34369219067637297`}}]}, 
    {Hue[0.6990341931244392], AbsoluteThickness[0.5], 
     LineBox[{{5.982587617186125, -3.1717560561794467`}, {
      5.969952656087857, -3.3732957056206274`}}]}, 
    {Hue[0.69928113501215], AbsoluteThickness[0.5], 
     LineBox[{{5.969952656087857, -3.3732957056206274`}, {
      5.96350433554662, -3.6571197780856823`}}]}, 
    {Hue[0.480980342228371], AbsoluteThickness[0.5], 
     LineBox[{{2.2264786672156953`, -2.866480413713278}, {
      2.181353800596747, -2.892619305560026}}]}, 
    {Hue[0.4811640532229083], AbsoluteThickness[0.5], 
     LineBox[{{2.181353800596747, -2.892619305560026}, {
      1.8925223693054563`, -3.0614739192830824`}}]}, 
    {Hue[0.579104224373986], AbsoluteThickness[0.5], 
     LineBox[{{2.873754933729199, 3.6211107541915326`}, {2.860348670364729, 
      3.65708926283423}}]}, 
    {Hue[0.5794356855429776], AbsoluteThickness[0.5], 
     LineBox[{{2.860348670364729, 3.65708926283423}, {2.735202566971461, 
      3.941086772914109}}]}, 
    {Hue[0.5685478791638322], AbsoluteThickness[0.5], 
     LineBox[{{3.667143186592133, 3.386655018692026}, {3.6629156674126215`, 
      3.3977027496627663`}}]}, 
    {Hue[0.5690443008925097], AbsoluteThickness[0.5], 
     LineBox[{{3.6629156674126215`, 3.3977027496627663`}, {
      3.5490640983277992`, 3.6362395798778353`}}]}, 
    {Hue[0.5980596938151009], AbsoluteThickness[0.5], 
     LineBox[{{8.081675417603904, 0.3567032731689679}, {8.112777383536885, 
      0.3310916078713156}}]}, 
    {Hue[0.5982469609830429], AbsoluteThickness[0.5], 
     LineBox[{{8.112777383536885, 0.3310916078713156}, {8.35458679363506, 
      0.12765032623837}}]}, 
    {Hue[0.6672680011301155], AbsoluteThickness[0.5], 
     LineBox[{{7.173986439691582, 0.09385754040219779}, {
      7.274268209074545, -0.1363595633154113}}]}, 
    {Hue[0.6676472715837648], AbsoluteThickness[0.5], 
     LineBox[{{7.274268209074545, -0.1363595633154113}, {
      7.361821664728799, -0.379995678727669}}]}, 
    {Hue[0.6391629949213822], AbsoluteThickness[0.5], 
     LineBox[{{4.60623413005632, 2.1637909267630078`}, {4.18329341596266, 
      2.0581945319702597`}}]}, 
    {Hue[0.6393748793499238], AbsoluteThickness[0.5], 
     LineBox[{{4.18329341596266, 2.0581945319702597`}, {3.8735678907445887`, 
      1.9718076657689771`}}]}, 
    {Hue[0.6778544863654826], AbsoluteThickness[0.5], 
     LineBox[{{6.101941934037496, 2.654840751506858}, {6.0951283677385755`, 
      2.6488139974837615`}}]}, 
    {Hue[0.6781923169835764], AbsoluteThickness[0.5], 
     LineBox[{{6.0951283677385755`, 2.6488139974837615`}, {5.888508547977647, 
      2.4429143369798125`}}]}, 
    {Hue[0.6824288059467477], AbsoluteThickness[0.5], 
     LineBox[{{7.4872954362059225`, 2.3272620760423}, {7.527369175267768, 
      2.2124021505044738`}}]}, 
    {Hue[0.6827421265864667], AbsoluteThickness[0.5], 
     LineBox[{{7.527369175267768, 2.2124021505044738`}, {7.613073684194516, 
      1.9149759269957787`}}]}, 
    {Hue[0.6653327008113857], AbsoluteThickness[0.5], 
     LineBox[{{7.412708949979767, 1.3649542899157536`}, {7.4275612104463455`, 
      1.1868517104206138`}}]}, 
    {Hue[0.6656643208504247], AbsoluteThickness[0.5], 
     LineBox[{{7.4275612104463455`, 1.1868517104206138`}, {
      7.4349281815717845`, 0.8897875450281161}}]}, 
    {Hue[0.680796279621206], AbsoluteThickness[0.5], 
     LineBox[{{4.1432445512089, 1.8362821881632283`}, {3.920732809479422, 
      1.7167830393253625`}}]}, 
    {Hue[0.6816959499897781], AbsoluteThickness[0.5], 
     LineBox[{{3.920732809479422, 1.7167830393253625`}, {3.7061559660456895`, 
      1.6302363202035928`}}]}, 
    {Hue[0.5991859857450668], AbsoluteThickness[0.5], 
     LineBox[{{3.357456586428072, 3.437434345337315}, {3.1387202755849977`, 
      3.6112018223763473`}}]}, 
    {Hue[0.602902690188506], AbsoluteThickness[0.5], 
     LineBox[{{3.1387202755849977`, 3.6112018223763473`}, {
      2.9882413674549433`, 3.6907620563599965`}}]}, 
    {Hue[0.6686303625466901], AbsoluteThickness[0.5], 
     LineBox[{{3.6415973214998734`, -0.7773224395460558}, {
      3.617055429827024, -0.8068031282257101}}]}, 
    {Hue[0.668835389176623], AbsoluteThickness[0.5], 
     LineBox[{{3.617055429827024, -0.8068031282257101}, {
      3.417849472132508, -1.058102453305081}}]}, 
    {Hue[0.6942007703184794], AbsoluteThickness[0.5], 
     LineBox[{{2.1945212760539454`, 3.3748669079486944`}, {2.160334222458122, 
      3.5789906596311543`}}]}, 
    {Hue[0.6945566146150711], AbsoluteThickness[0.5], 
     LineBox[{{2.160334222458122, 3.5789906596311543`}, {2.133292155381548, 
      3.839095338540685}}]}, 
    {Hue[0.6680759936039161], AbsoluteThickness[0.5], 
     LineBox[{{2.5751762563305114`, 0.164338020188098}, {2.565815094168653, 
      0.1410710166466319}}]}, 
    {Hue[0.6682622291583254], AbsoluteThickness[0.5], 
     LineBox[{{2.565815094168653, 0.14107101664663185`}, {
      2.4346059552727373`, -0.17662184558167104`}}]}, 
    {Hue[0.6999200056613164], AbsoluteThickness[0.5], 
     LineBox[{{7.3847323755227645`, -1.8228940275480667`}, {
      7.429132867141638, -1.8261112150576801`}}]}, 
    {Hue[0.6333423756283308], AbsoluteThickness[0.5], 
     LineBox[{{4.810627423020948, -2.0628701227823787`}, {
      4.655261269437338, -2.072482187679916}}]}, 
    {Hue[0.6335886140642774], AbsoluteThickness[0.5], 
     LineBox[{{4.655261269437338, -2.072482187679916}, {
      4.34509924734631, -2.079337547647544}}]}, 
    {Hue[0.5852756720769028], AbsoluteThickness[0.5], 
     LineBox[{{6.866622737248663, -4.094535006342286}, {
      6.859571591560801, -4.212627155441221}}]}, 
    {Hue[0.589167668475008], AbsoluteThickness[0.5], 
     LineBox[{{6.859571591560801, -4.212627155441221}, {
      6.816528145569681, -4.383112257242901}}]}, 
    {Hue[0.6703977837725832], AbsoluteThickness[0.5], 
     LineBox[{{6.2235295923556375`, -2.3817523947534873`}, {
      5.8106301849454995`, -2.3974929692183786`}}]}, 
    {Hue[0.6717983084228148], AbsoluteThickness[0.5], 
     LineBox[{{5.8106301849454995`, -2.3974929692183786`}, {
      5.604807374485697, -2.3781584461875953`}}]}, 
    {Hue[0.6623562434705716], AbsoluteThickness[0.5], 
     LineBox[{{7.979510040500845, 0.14198319736464082`}, {8.006806903401426, 
      0.34488466422178027`}}]}, 
    {Hue[0.6625405978919944], AbsoluteThickness[0.5], 
     LineBox[{{8.006806903401426, 0.34488466422178027`}, {8.049286457408408, 
      0.6750501916120701}}]}, 
    {Hue[0.6644735561189237], AbsoluteThickness[0.5], 
     LineBox[{{5.14771009037063, 0.8767832613979392}, {5.128144313032029, 
      0.8900298355245744}}]}, 
    {Hue[0.6646629300654082], AbsoluteThickness[0.5], 
     LineBox[{{5.128144313032029, 0.8900298355245744}, {4.857304483961946, 
      1.0785491778117529`}}]}, 
    {Hue[0.6426054409739392], AbsoluteThickness[0.5], 
     LineBox[{{3.1066298187111636`, -0.2555800674312975}, {
      2.913926441095321, -0.19158357221137529`}}]}, 
    {Hue[0.6430862278989129], AbsoluteThickness[0.5], 
     LineBox[{{2.913926441095321, -0.19158357221137529`}, {
      2.6677729820998963`, -0.13071392041402335`}}]}, 
    {Hue[0.5212184074559905], AbsoluteThickness[0.5], 
     LineBox[{{4.510555217834851, -3.622696215050899}, {
      4.346861212778436, -3.790094402998322}}]}, 
    {Hue[0.5220738808204887], AbsoluteThickness[0.5], 
     LineBox[{{4.346861212778436, -3.790094402998322}, {
      4.199850853875885, -3.9113342055346747`}}]}, 
    {Hue[0.5866970230718751], AbsoluteThickness[0.5], 
     LineBox[{{2.7454803212975145`, -2.9218814178830406`}, {
      2.4385228322540007`, -3.207733694584439}}]}, 
    {Hue[0.5872350439210499], AbsoluteThickness[0.5], 
     LineBox[{{2.4385228322540007`, -3.207733694584439}, {
      2.2504504448487164`, -3.355483321000886}}]}, 
    {Hue[0.5017151764092883], AbsoluteThickness[0.5], 
     LineBox[{{6.847230167096772, -4.057055011384567}, {
      6.825875960104849, -4.156169652824735}}]}, 
    {Hue[0.5020906214003393], AbsoluteThickness[0.5], 
     LineBox[{{6.825875960104849, -4.156169652824735}, {
      6.750818439690522, -4.419688470805187}}]}, 
    {Hue[0.660145107015424], AbsoluteThickness[0.5], 
     LineBox[{{3.3837451970089263`, -0.9810609906121149}, {
      3.1151139283275167`, -1.0116527439306593`}}]}, 
    {Hue[0.6603477113124915], AbsoluteThickness[0.5], 
     LineBox[{{3.1151139283275167`, -1.0116527439306593`}, {
      2.833124009085632, -1.0373182512021093`}}]}, 
    {Hue[0.619186493596887], AbsoluteThickness[0.5], 
     LineBox[{{6.43912162825665, -3.185392938272045}, {
      6.4054814356495156`, -3.2816487654920232`}}]}, 
    {Hue[0.6404792713111888], AbsoluteThickness[0.5], 
     LineBox[{{6.4054814356495156`, -3.2816487654920232`}, {
      6.323627665433101, -3.3923747599303007`}}]}, 
    {Hue[0.45861228109634544`], AbsoluteThickness[0.5], 
     LineBox[{{7.194421264377078, -3.4109465853670002`}, {
      7.321252999872217, -3.674877994366107}}]}, 
    {Hue[0.4590059919410585], AbsoluteThickness[0.5], 
     LineBox[{{7.321252999872217, -3.674877994366107}, {
      7.396788952294392, -3.863917628126922}}]}, 
    {Hue[0.6402356591643346], AbsoluteThickness[0.5], 
     LineBox[{{7.757347622260808, -2.895465567414296}, {
      7.85372094736996, -2.9319571685943555`}}]}, 
    {Hue[0.6404388058658833], AbsoluteThickness[0.5], 
     LineBox[{{7.85372094736996, -2.9319571685943555`}, {
      8.166895214856064, -3.0588244373516718`}}]}, 
    {Hue[0.6219029031433302], AbsoluteThickness[0.5], 
     LineBox[{{7.120352531365677, -2.119608947377167}, {
      7.118421919627566, -2.1316120902231095`}}]}, 
    {Hue[0.6229708926739846], AbsoluteThickness[0.5], 
     LineBox[{{7.118421919627566, -2.1316120902231095`}, {
      7.109466376042483, -2.3475363475123796`}}]}, 
    {Hue[0.695476239924767], AbsoluteThickness[0.5], 
     LineBox[{{4.9558269679507205`, 2.6415458060438706`}, {
      4.9018847525001386`, 2.7250518604226603`}}]}, 
    {Hue[0.6959324780743517], AbsoluteThickness[0.5], 
     LineBox[{{4.9018847525001386`, 2.7250518604226603`}, {4.745581720203257, 
      2.93105649072293}}]}, 
    {Hue[0.4734213634351463], AbsoluteThickness[0.5], 
     LineBox[{{5.3552372974225495`, -0.6182436607527533}, {
      5.313269548490573, -0.656253555064122}}]}, 
    {Hue[0.47360574469604194`], AbsoluteThickness[0.5], 
     LineBox[{{5.313269548490573, -0.656253555064122}, {
      5.0950691582980365`, -0.8562053790945715}}]}, 
    {Hue[0.6871528327987441], AbsoluteThickness[0.5], 
     LineBox[{{7.71366100941622, -1.3953709118801847`}, {
      7.846069552065707, -1.5547823287806197`}}]}, 
    {Hue[0.6882558330382971], AbsoluteThickness[0.5], 
     LineBox[{{7.846069552065707, -1.5547823287806197`}, {
      7.994065167912832, -1.694889300567602}}]}, 
    {Hue[0.6968486235102002], AbsoluteThickness[0.5], 
     LineBox[{{6.152706677785381, 2.623570492538123}, {6.151437642763765, 
      2.620420253012436}}]}, 
    {Hue[0.6970586898698385], AbsoluteThickness[0.5], 
     LineBox[{{6.151437642763765, 2.6204202530124365`}, {6.022441816341458, 
      2.3231662784791007`}}]}, 
    {Hue[0.5856886990969518], AbsoluteThickness[0.5], 
     LineBox[{{5.954758455371051, 3.344437558261244}, {5.920544336604041, 
      3.3340937605348855`}}]}, 
    {Hue[0.5858769894524836], AbsoluteThickness[0.5], 
     LineBox[{{5.920544336604041, 3.3340937605348855`}, {5.6701500886058795`, 
      3.255165769425571}}]}, 
    {Hue[0.33106655399397417`], AbsoluteThickness[0.5], 
     LineBox[{{5.848099970795353, 3.4606262406768167`}, {5.763727798657249, 
      3.5880340962695576`}}]}, 
    {Hue[0.3315232593087311], AbsoluteThickness[0.5], 
     LineBox[{{5.763727798657249, 3.5880340962695576`}, {5.624661889022492, 
      3.837040565238847}}]}, 
    {Hue[0.6978590886593605], AbsoluteThickness[0.5], 
     LineBox[{{6.601745336365228, 3.5938447090001717`}, {6.624242981949835, 
      3.610254629137234}}]}, 
    {Hue[0.6980829357985602], AbsoluteThickness[0.5], 
     LineBox[{{6.624242981949835, 3.610254629137234}, {6.882779322650426, 
      3.811935048904515}}]}, 
    {Hue[0.5881298915017065], AbsoluteThickness[0.5], 
     LineBox[{{5.434749207937504, 2.0885718099516564`}, {5.164801340599267, 
      1.9604416019457573`}}]}, 
    {Hue[0.5884089757768914], AbsoluteThickness[0.5], 
     LineBox[{{5.164801340599267, 1.9604416019457573`}, {4.946889611226584, 
      1.869578185063331}}]}, 
    {Hue[0.579270091651003], AbsoluteThickness[0.5], 
     LineBox[{{6.048061583993393, 2.8023330118719088`}, {5.8591954719604376`, 
      2.793861627005079}}]}, 
    {Hue[0.5794537461592025], AbsoluteThickness[0.5], 
     LineBox[{{5.8591954719604376`, 2.793861627005079}, {5.542744171328283, 
      2.780874315517512}}]}, 
    {Hue[0.4769305546507898], AbsoluteThickness[0.5], 
     LineBox[{{6.116955393542976, 3.2735007709854105`}, {6.07412909135062, 
      3.3820288297901584`}}]}, 
    {Hue[0.477185589840243], AbsoluteThickness[0.5], 
     LineBox[{{6.07412909135062, 3.3820288297901584`}, {5.974551438823336, 
      3.606204375382554}}]}, 
    {Hue[0.6082751371078228], AbsoluteThickness[0.5], 
     LineBox[{{6.420110121692732, 3.3141384967822844`}, {6.428544256025292, 
      3.3722030476344838`}}]}, 
    {Hue[0.6084649675536954], AbsoluteThickness[0.5], 
     LineBox[{{6.428544256025292, 3.3722030476344838`}, {6.475677707174433, 
      3.668722634526091}}]}, 
    {Hue[0.44361508175242503`], AbsoluteThickness[0.5], 
     LineBox[{{8.282525643195672, -0.9400201055250266}, {
      8.289914658878898, -1.0829276038966589`}}]}, 
    {Hue[0.44382337351581413`], AbsoluteThickness[0.5], 
     LineBox[{{8.289914658878898, -1.0829276038966589`}, {
      8.297399842444705, -1.3703794401746636`}}]}, 
    {Hue[0.5439361250966189], AbsoluteThickness[0.5], 
     LineBox[{{6.860004043903626, -0.5846922603434024}, {
      6.690008009051376, -0.6315445677566753}}]}, 
    {Hue[0.5446496787062902], AbsoluteThickness[0.5], 
     LineBox[{{6.690008009051376, -0.6315445677566753}, {
      6.443488422529625, -0.6741042190569693}}]}, 
    {Hue[0.6219589182893702], AbsoluteThickness[0.5], 
     LineBox[{{6.404594217038392, -1.5717003663107687`}, {
      6.259408443254719, -2.061249027219967}}]}, 
    {Hue[0.6222100533366556], AbsoluteThickness[0.5], 
     LineBox[{{6.259408443254719, -2.061249027219967}, {
      6.183785132830618, -2.3608905041613863`}}]}, 
    {Hue[0.4676873426630121], AbsoluteThickness[0.5], 
     LineBox[{{7.381736509769126, -2.6609417351921207`}, {
      7.380574323379593, -2.669444910492241}}]}, 
    {Hue[0.46797789674789475`], AbsoluteThickness[0.5], 
     LineBox[{{7.380574323379593, -2.669444910492241}, {
      7.329947657622755, -2.9378162837687634`}}]}, 
    {Hue[0.6886759592874222], AbsoluteThickness[0.5], 
     LineBox[{{4.337253499543261, 2.5050236894144997`}, {4.292422481352895, 
      2.6380683363991775`}}]}, 
    {Hue[0.6888707756324418], AbsoluteThickness[0.5], 
     LineBox[{{4.292422481352895, 2.6380683363991775`}, {4.1955955310933275`, 
      2.9430773810869217`}}]}, 
    {Hue[0.5994286733215939], AbsoluteThickness[0.5], 
     LineBox[{{3.4621819624918184`, 1.1524391197069026`}, {
      3.3656486830671053`, 1.1633589103542972`}}]}, 
    {Hue[0.6001454282853778], AbsoluteThickness[0.5], 
     LineBox[{{3.3656486830671053`, 1.1633589103542972`}, {
      3.1615855378483713`, 1.207032031787801}}]}, 
    {Hue[0.44683589127892354`], AbsoluteThickness[0.5], 
     LineBox[{{3.6118972978118684`, 0.16418018278816915`}, {
      3.5755001570220437`, 0.08372018670784769}}]}, 
    {Hue[0.4471055942850877], AbsoluteThickness[0.5], 
     LineBox[{{3.5755001570220437`, 0.08372018670784769}, {
      3.4410452598506835`, -0.18049458499323162`}}]}, 
    {Hue[0.6173788664260408], AbsoluteThickness[0.5], 
     LineBox[{{4.08319075266063, -0.12669712854553145`}, {
      4.043580714792697, -0.35473242622201256`}}]}, 
    {Hue[0.6175868839123563], AbsoluteThickness[0.5], 
     LineBox[{{4.043580714792697, -0.35473242622201256`}, {
      3.9852894961017116`, -0.6460686592447719}}]}, 
    {Hue[0.6904745432853702], AbsoluteThickness[0.5], 
     LineBox[{{4.552047754432303, -0.6922139549788413}, {
      4.51316159899305, -0.8138720656466969}}]}, 
    {Hue[0.6906923143261802], AbsoluteThickness[0.5], 
     LineBox[{{4.51316159899305, -0.8138720656466969}, {
      4.43125834980598, -1.0992574212415742`}}]}, 
    {Hue[0.6665621719558716], AbsoluteThickness[0.5], 
     LineBox[{{2.6709939753795493`, 1.8909537908995016`}, {
      2.4586418271341675`, 2.389602901024031}}]}, 
    {Hue[0.6670157793581598], AbsoluteThickness[0.5], 
     LineBox[{{2.4586418271341675`, 2.389602901024031}, {2.3767600525366226`, 
      2.6307316791079334`}}]}, 
    {Hue[0.4479696509003759], AbsoluteThickness[0.5], 
     LineBox[{{2.3688715306818175`, 1.0498166231520185`}, {
      2.1586051450993393`, 0.9757481031880711}}]}, 
    {Hue[0.4482552624939532], AbsoluteThickness[0.5], 
     LineBox[{{2.1586051450993393`, 0.9757481031880711}, {1.8654612149900247`,
       0.8885482619526972}}]}, 
    {Hue[0.6728057076237547], AbsoluteThickness[0.5], 
     LineBox[{{2.6840645451323115`, 0.07101065378714078}, {
      2.636307215419951, -0.16676976387992273`}}]}, 
    {Hue[0.6773894664665591], AbsoluteThickness[0.5], 
     LineBox[{{2.636307215419951, -0.16676976387992273`}, {
      2.6361714884051755`, -0.33417672375082363`}}]}, 
    {Hue[0.6988612411199296], AbsoluteThickness[0.5], 
     LineBox[{{2.2306487365576024`, -0.434011017903535}, {
      2.2415014762410768`, -0.5362599279497503}}]}, 
    {Hue[0.6990653498579257], AbsoluteThickness[0.5], 
     LineBox[{{2.2415014762410768`, -0.5362599279497503}, {
      2.2680396580060287`, -0.8580522163487847}}]}, 
    {Hue[0.6972103539990804], AbsoluteThickness[0.5], 
     LineBox[{{7.5064694967424925`, -4.068756492661345}, {
      7.578285539175333, -4.251879845857825}}]}, 
    {Hue[0.698689999776547], AbsoluteThickness[0.5], 
     LineBox[{{7.578285539175333, -4.251879845857825}, {
      7.671016338206515, -4.418310300182402}}]}, 
    {Hue[0.4340058851071301], AbsoluteThickness[0.5], 
     LineBox[{{2.301734612303231, 2.9715636864263844`}, {2.15678870259673, 
      2.953924326936628}}]}, 
    {Hue[0.43421712481156083`], AbsoluteThickness[0.5], 
     LineBox[{{2.15678870259673, 2.953924326936628}, {1.905450895359237, 
      2.9302119632853034`}}]}, 
    {Hue[0.5968705525941155], AbsoluteThickness[0.5], 
     LineBox[{{4.926853849632756, 3.6996533119034503`}, {5.06111150636273, 
      3.728195983954255}}]}, 
    {Hue[0.5970537803827833], AbsoluteThickness[0.5], 
     LineBox[{{5.06111150636273, 3.728195983954255}, {5.403187952588996, 
      3.800301315581602}}]}, 
    {Hue[0.6257784750735954], AbsoluteThickness[0.5], 
     LineBox[{{7.08493018736672, 3.4665318756219445`}, {7.373505533449265, 
      3.4332706036957727`}}]}, 
    {Hue[0.6260396781419619], AbsoluteThickness[0.5], 
     LineBox[{{7.373505533449265, 3.4332706036957727`}, {7.657254405218824, 
      3.413101570340565}}]}, 
    {Hue[0.6753456358531975], AbsoluteThickness[0.5], 
     LineBox[{{6.8423809303975185`, 1.5972051673966625`}, {6.845562438732375, 
      1.5952906131564648`}}]}, 
    {Hue[0.675530423698295], AbsoluteThickness[0.5], 
     LineBox[{{6.845562438732375, 1.5952906131564648`}, {7.078171501620103, 
      1.4531793955188055`}}]}, 
    {Hue[0.48514679338251226`], AbsoluteThickness[0.5], 
     LineBox[{{7.358079660061334, 3.168928479704756}, {7.592570358476737, 
      3.3241435725362685`}}]}, 
    {Hue[0.48674515744174923`], AbsoluteThickness[0.5], 
     LineBox[{{7.592570358476737, 3.3241435725362685`}, {7.76948545282574, 
      3.4087582852440135`}}]}, 
    {Hue[0.5177547805393402], AbsoluteThickness[0.5], 
     LineBox[{{6.913412393865279, 0.6424620335464204}, {6.966790918559761, 
      0.6114333462384633}}]}, 
    {Hue[0.5184891839783643], AbsoluteThickness[0.5], 
     LineBox[{{6.966790918559761, 0.6114333462384633}, {7.159514962471937, 
      0.47210629384999775`}}]}, 
    {Hue[0.5676232841805292], AbsoluteThickness[0.5], 
     LineBox[{{5.223831140464143, 0.6062246397799318}, {5.25788395479941, 
      0.40047914863717937`}}]}, 
    {Hue[0.5678963379817799], AbsoluteThickness[0.5], 
     LineBox[{{5.25788395479941, 0.40047914863717937`}, {5.2919813439335, 
      0.11115117115553971`}}]}, 
    {Hue[0.5934909118440101], AbsoluteThickness[0.5], 
     LineBox[{{3.5400266537753016`, 0.8584285114380503}, {3.418791294547206, 
      0.7379370981728014}}]}, 
    {Hue[0.5939729303598086], AbsoluteThickness[0.5], 
     LineBox[{{3.418791294547206, 0.7379370981728014}, {3.2337022530914274`, 
      0.5807779500679296}}]}, 
    {Hue[0.5884816627529438], AbsoluteThickness[0.5], 
     LineBox[{{3.58339473401461, 2.2758211254393754`}, {3.4639266872794554`, 
      2.343108263921816}}]}, 
    {Hue[0.6146053507886947], AbsoluteThickness[0.5], 
     LineBox[{{3.4639266872794554`, 2.343108263921816}, {3.419021162144573, 
      2.3521030916458017`}}]}, 
    {Hue[0.5234860168328969], AbsoluteThickness[0.5], 
     LineBox[{{2.345772548463666, 0.9347785088876049}, {2.1109418660443935`, 
      0.8813486848297772}}]}, 
    {Hue[0.528189155391624], AbsoluteThickness[0.5], 
     LineBox[{{2.1109418660443935`, 0.8813486848297772}, {2.001820259253169, 
      0.8322686305099309}}]}, 
    {Hue[0.6310024090588031], AbsoluteThickness[0.5], 
     LineBox[{{3.5719528092812887`, -0.3436921906763729}, {
      3.540315837718936, -0.3666346889023103}}]}, 
    {Hue[0.6323994355909747], AbsoluteThickness[0.5], 
     LineBox[{{3.540315837718936, -0.3666346889023103}, {
      3.381604823976741, -0.45247289711526967`}}]}, 
    {Hue[0.6995280768998606], AbsoluteThickness[0.5], 
     LineBox[{{5.96350433554662, -3.6571197780856823`}, {
      5.966474220943696, -3.8299795327438115`}}]}, 
    {Hue[0.6997113096322752], AbsoluteThickness[0.5], 
     LineBox[{{5.966474220943696, -3.8299795327438115`}, {
      5.972389363345108, -4.14210818712324}}]}, 
    {Hue[0.668026542037414], AbsoluteThickness[0.5], 
     LineBox[{{7.361821664728799, -0.379995678727669}, {
      7.361840882167571, -0.3800627190973369}}]}, 
    {Hue[0.6683722457979282], AbsoluteThickness[0.5], 
     LineBox[{{7.361840882167571, -0.3800627190973369}, {
      7.449908629578593, -0.6290946221239575}}]}, 
    {Hue[0.6395867637784654], AbsoluteThickness[0.5], 
     LineBox[{{3.8735678907445887`, 1.9718076657689771`}, {
      3.7775506922884885`, 1.9421761779742046`}}]}, 
    {Hue[0.6449739743123858], AbsoluteThickness[0.5], 
     LineBox[{{3.7775506922884885`, 1.9421761779742046`}, {
      3.6290617411838237`, 1.8597836212114276`}}]}, 
    {Hue[0.6785301476016701], AbsoluteThickness[0.5], 
     LineBox[{{5.888508547977647, 2.4429143369798125`}, {5.767552045297535, 
      2.3071249030370566`}}]}, 
    {Hue[0.6787239649228346], AbsoluteThickness[0.5], 
     LineBox[{{5.767552045297535, 2.3071249030370566`}, {5.615425364229257, 
      2.1304326170238865`}}]}, 
    {Hue[0.6830554472261857], AbsoluteThickness[0.5], 
     LineBox[{{7.613073684194516, 1.9149759269957787`}, {7.628545758690353, 
      1.8475056952641078`}}]}, 
    {Hue[0.6834926148171161], AbsoluteThickness[0.5], 
     LineBox[{{7.628545758690353, 1.8475056952641078`}, {7.713787371339179, 
      1.570713499858081}}]}, 
    {Hue[0.6659959408894637], AbsoluteThickness[0.5], 
     LineBox[{{7.4349281815717845`, 0.8897875450281161}, {7.4265704102400125`,
       0.6412175565394289}}]}, 
    {Hue[0.6662042247796336], AbsoluteThickness[0.5], 
     LineBox[{{7.4265704102400125`, 0.6412175565394289}, {7.405720745714707, 
      0.28962841116119903`}}]}, 
    {Hue[0.6825956203583499], AbsoluteThickness[0.5], 
     LineBox[{{3.7061559660456895`, 1.6302363202035928`}, {
      3.5630614227640534`, 1.590029904485815}}]}, 
    {Hue[0.6828910536544808], AbsoluteThickness[0.5], 
     LineBox[{{3.5630614227640534`, 1.590029904485815}, {3.3243323955771182`, 
      1.5094446611867771`}}]}, 
    {Hue[0.6066193946319449], AbsoluteThickness[0.5], 
     LineBox[{{2.9882413674549433`, 3.6907620563599965`}, {
      2.8913015105007416`, 3.7208958175518165`}}]}, 
    {Hue[0.6068033890713445], AbsoluteThickness[0.5], 
     LineBox[{{2.8913015105007416`, 3.7208958175518165`}, {2.553007083039228, 
      3.824253879775438}}]}, 
    {Hue[0.6690404158065559], AbsoluteThickness[0.5], 
     LineBox[{{3.417849472132508, -1.058102453305081}, {
      3.3495126332599936`, -1.148684791261067}}]}, 
    {Hue[0.6692648350647847], AbsoluteThickness[0.5], 
     LineBox[{{3.3495126332599936`, -1.148684791261067}, {
      3.1502362259938024`, -1.3957048186924736`}}]}, 
    {Hue[0.6684484647127349], AbsoluteThickness[0.5], 
     LineBox[{{2.4346059552727373`, -0.17662184558167104`}, {
      2.416036833516986, -0.22044205134953043`}}]}, 
    {Hue[0.6690663048220401], AbsoluteThickness[0.5], 
     LineBox[{{2.416036833516986, -0.22044205134953043`}, {
      2.3009531280733664`, -0.43534944114653396`}}]}, 
    {Hue[0.6338348525002239], AbsoluteThickness[0.5], 
     LineBox[{{4.34509924734631, -2.079337547647544}, {
      4.312866981451187, -2.0787705044848455`}}]}, 
    {Hue[0.6365221034564053], AbsoluteThickness[0.5], 
     LineBox[{{4.312866981451187, -2.0787705044848455`}, {
      4.126212024936174, -2.1067733899757095`}}]}, 
    {Hue[0.6731988330730465], AbsoluteThickness[0.5], 
     LineBox[{{5.604807374485697, -2.3781584461875953`}, {
      5.603160721611645, -2.3777808238799247`}}]}, 
    {Hue[0.6739162226673284], AbsoluteThickness[0.5], 
     LineBox[{{5.603160721611645, -2.3777808238799247`}, {
      5.3692815675533225`, -2.347872509711066}}]}, 
    {Hue[0.662724952313417], AbsoluteThickness[0.5], 
     LineBox[{{8.049286457408408, 0.6750501916120701}, {8.058839754670561, 
      0.7528464829549052}}]}, 
    {Hue[0.6722809082061848], AbsoluteThickness[0.5], 
     LineBox[{{8.058839754670561, 0.7528464829549052}, {8.11598951992452, 
      0.901805773284278}}]}, 
    {Hue[0.6648523040118927], AbsoluteThickness[0.5], 
     LineBox[{{4.857304483961946, 1.0785491778117529`}, {4.747626960664649, 
      1.1570154792815404`}}]}, 
    {Hue[0.6656569824349592], AbsoluteThickness[0.5], 
     LineBox[{{4.747626960664649, 1.1570154792815404`}, {4.604221962285013, 
      1.2840482842581151`}}]}, 
    {Hue[0.6435670148238866], AbsoluteThickness[0.5], 
     LineBox[{{2.6677729820998963`, -0.13071392041402335`}, {
      2.6187428803404096`, -0.12258995378609708`}}]}, 
    {Hue[0.6438782830151228], AbsoluteThickness[0.5], 
     LineBox[{{2.6187428803404096`, -0.12258995378609706`}, {
      2.3194844998904247`, -0.055999695094600184`}}]}, 
    {Hue[0.5229293541849869], AbsoluteThickness[0.5], 
     LineBox[{{4.199850853875885, -3.9113342055346747`}, {
      4.167172969626897, -3.932868198177771}}]}, 
    {Hue[0.5231256719057086], AbsoluteThickness[0.5], 
     LineBox[{{4.167172969626897, -3.932868198177771}, {
      3.9464350153265713`, -4.072481409782038}}]}, 
    {Hue[0.5877730647702246], AbsoluteThickness[0.5], 
     LineBox[{{2.2504504448487164`, -3.355483321000886}, {
      2.135404990293597, -3.4311843999347778`}}]}, 
    {Hue[0.5879754532588445], AbsoluteThickness[0.5], 
     LineBox[{{2.135404990293597, -3.4311843999347778`}, {
      1.8717760217040529`, -3.596276373248007}}]}, 
    {Hue[0.6605503156095592], AbsoluteThickness[0.5], 
     LineBox[{{2.833124009085632, -1.0373182512021093`}, {
      2.6662098907927887`, -1.0487093524605482`}}]}, 
    {Hue[0.6607422214323724], AbsoluteThickness[0.5], 
     LineBox[{{2.6662098907927887`, -1.0487093524605482`}, {
      2.312220468657105, -1.0674312255994285`}}]}, 
    {Hue[0.6617720490254894], AbsoluteThickness[0.5], 
     LineBox[{{6.323627665433101, -3.3923747599303007`}, {
      6.171777647535761, -3.5039883632184616`}}]}, 
    {Hue[0.6620970458332027], AbsoluteThickness[0.5], 
     LineBox[{{6.171777647535761, -3.5039883632184616`}, {
      5.947765141123858, -3.6496665162900763`}}]}, 
    {Hue[0.45939970278577147`], AbsoluteThickness[0.5], 
     LineBox[{{7.396788952294392, -3.863917628126922}, {
      7.3970953867840885`, -3.8648666770073263`}}]}, 
    {Hue[0.4596737774394462], AbsoluteThickness[0.5], 
     LineBox[{{7.3970953867840885`, -3.8648666770073263`}, {
      7.474559788528993, -4.071123810438171}}]}, 
    {Hue[0.6240388822046391], AbsoluteThickness[0.5], 
     LineBox[{{7.109466376042483, -2.3475363475123796`}, {
      7.112100941858732, -2.3818749918280813`}}]}, 
    {Hue[0.6274890655070104], AbsoluteThickness[0.5], 
     LineBox[{{7.112100941858732, -2.3818749918280813`}, {
      7.094646516432469, -2.548964716506338}}]}, 
    {Hue[0.6963887162239363], AbsoluteThickness[0.5], 
     LineBox[{{4.745581720203257, 2.93105649072293}, {4.685296765772567, 
      2.999156445129354}}]}, 
    {Hue[0.6972084573540704], AbsoluteThickness[0.5], 
     LineBox[{{4.685296765772567, 2.999156445129354}, {4.516406202241529, 
      3.153786736063154}}]}, 
    {Hue[0.47379012595693765`], AbsoluteThickness[0.5], 
     LineBox[{{5.0950691582980365`, -0.8562053790945715}, {
      5.0876498459533925`, -0.8630842502231568}}]}, 
    {Hue[0.4740604451858342], AbsoluteThickness[0.5], 
     LineBox[{{5.0876498459533925`, -0.8630842502231568}, {
      4.897134594666521, -1.0567814332362302`}}]}, 
    {Hue[0.68935883327785], AbsoluteThickness[0.5], 
     LineBox[{{7.994065167912832, -1.694889300567602}, {
      8.063713541240318, -1.7465703138020194`}}]}, 
    {Hue[0.6897381490649284], AbsoluteThickness[0.5], 
     LineBox[{{8.063713541240318, -1.7465703138020194`}, {
      8.277153594740588, -1.8841482342927005`}}]}, 
    {Hue[0.6972687562294768], AbsoluteThickness[0.5], 
     LineBox[{{6.022441816341458, 2.3231662784791007`}, {5.941956888865805, 
      2.150378709482794}}]}, 
    {Hue[0.6982258632508106], AbsoluteThickness[0.5], 
     LineBox[{{5.941956888865805, 2.150378709482794}, {5.863954869871214, 
      1.9176321217127803`}}]}, 
    {Hue[0.5860652798080154], AbsoluteThickness[0.5], 
     LineBox[{{5.6701500886058795`, 3.255165769425571}, {5.1265156431039856`, 
      3.076744775513107}}]}, 
    {Hue[0.5862668543214522], AbsoluteThickness[0.5], 
     LineBox[{{5.1265156431039856`, 3.076744775513107}, {4.828233618459975, 
      2.9715138482660324`}}]}, 
    {Hue[0.5886880600520764], AbsoluteThickness[0.5], 
     LineBox[{{4.946889611226584, 1.869578185063331}, {4.81685376611325, 
      1.822561236102724}}]}, 
    {Hue[0.5889917807555753], AbsoluteThickness[0.5], 
     LineBox[{{4.81685376611325, 1.822561236102724}, {4.56275376786472, 
      1.7150572909505666`}}]}, 
    {Hue[0.5796374006674022], AbsoluteThickness[0.5], 
     LineBox[{{5.542744171328283, 2.780874315517512}, {5.3812344063793915`, 
      2.7748615939355155`}}]}, 
    {Hue[0.5798578159266284], AbsoluteThickness[0.5], 
     LineBox[{{5.3812344063793915`, 2.7748615939355155`}, {5.116889302356681, 
      2.756812497992865}}]}, 
    {Hue[0.47744062502969625`], AbsoluteThickness[0.5], 
     LineBox[{{5.974551438823336, 3.606204375382554}, {5.93698715466518, 
      3.681988704384638}}]}, 
    {Hue[0.47783839139580153`], AbsoluteThickness[0.5], 
     LineBox[{{5.93698715466518, 3.681988704384638}, {5.78884187988963, 
      3.9356753447342863`}}]}, 
    {Hue[0.44403166527920307`], AbsoluteThickness[0.5], 
     LineBox[{{8.297399842444705, -1.3703794401746636`}, {
      8.297504651474537, -1.6266875117243267`}}]}, 
    {Hue[0.44439753023247036`], AbsoluteThickness[0.5], 
     LineBox[{{8.297504651474537, -1.6266875117243267`}, {
      8.281273842308778, -1.8821019026795236`}}]}, 
    {Hue[0.5453632323159615], AbsoluteThickness[0.5], 
     LineBox[{{6.443488422529625, -0.6741042190569693}, {
      6.362490433178861, -0.6800261468809501}}]}, 
    {Hue[0.5456751911966387], AbsoluteThickness[0.5], 
     LineBox[{{6.362490433178861, -0.6800261468809501}, {
      6.093639983498253, -0.7145902088797783}}]}, 
    {Hue[0.6224611883839409], AbsoluteThickness[0.5], 
     LineBox[{{6.183785132830618, -2.3608905041613863`}, {
      6.149600281557578, -2.5243795802136213`}}]}, 
    {Hue[0.6298750591496384], AbsoluteThickness[0.5], 
     LineBox[{{6.149600281557578, -2.5243795802136213`}, {
      6.094872903973718, -2.6425988951424286`}}]}, 
    {Hue[0.46826845083277724`], AbsoluteThickness[0.5], 
     LineBox[{{7.329947657622755, -2.9378162837687634`}, {
      7.28916863721412, -3.106593666353948}}]}, 
    {Hue[0.4684715868459519], AbsoluteThickness[0.5], 
     LineBox[{{7.28916863721412, -3.106593666353948}, {
      7.207895388041592, -3.412112857650837}}]}, 
    {Hue[0.6890655919774613], AbsoluteThickness[0.5], 
     LineBox[{{4.1955955310933275`, 2.9430773810869217`}, {4.135076293354458, 
      3.146048459213462}}]}, 
    {Hue[0.6904797792349117], AbsoluteThickness[0.5], 
     LineBox[{{4.135076293354458, 3.146048459213462}, {4.097702904223805, 
      3.381360299048231}}]}, 
    {Hue[0.6008621832491617], AbsoluteThickness[0.5], 
     LineBox[{{3.1615855378483713`, 1.207032031787801}, {2.924273756208271, 
      1.2827967015776476`}}]}, 
    {Hue[0.6012851454032405], AbsoluteThickness[0.5], 
     LineBox[{{2.924273756208271, 1.2827967015776476`}, {2.6408519376863855`, 
      1.35138276775199}}]}, 
    {Hue[0.4473752972912517], AbsoluteThickness[0.5], 
     LineBox[{{3.4410452598506835`, -0.18049458499323162`}, {
      3.4127101159956346`, -0.23037049313153385`}}]}, 
    {Hue[0.4478770413923903], AbsoluteThickness[0.5], 
     LineBox[{{3.4127101159956346`, -0.23037049313153385`}, {
      3.2698138327236355`, -0.44057771756705405`}}]}, 
    {Hue[0.6177949013986718], AbsoluteThickness[0.5], 
     LineBox[{{3.9852894961017116`, -0.6460686592447719}, {
      3.935730260460921, -0.8646476621391642}}]}, 
    {Hue[0.6182578076082343], AbsoluteThickness[0.5], 
     LineBox[{{3.935730260460921, -0.8646476621391642}, {
      3.8973613008508083`, -1.124342701262884}}]}, 
    {Hue[0.6909100853669902], AbsoluteThickness[0.5], 
     LineBox[{{4.43125834980598, -1.0992574212415742`}, {
      4.411462985290634, -1.1769154495360734`}}]}, 
    {Hue[0.6931073017147458], AbsoluteThickness[0.5], 
     LineBox[{{4.411462985290634, -1.1769154495360734`}, {
      4.3351822088776855`, -1.3548246086900826`}}]}, 
    {Hue[0.667469386760448], AbsoluteThickness[0.5], 
     LineBox[{{2.3767600525366226`, 2.6307316791079334`}, {2.262077448055811, 
      3.075918410771986}}]}, 
    {Hue[0.667683768553831], AbsoluteThickness[0.5], 
     LineBox[{{2.262077448055811, 3.075918410771986}, {2.1941208268320462`, 
      3.3746548047126277`}}]}, 
    {Hue[0.6819732253093633], AbsoluteThickness[0.5], 
     LineBox[{{2.6361714884051755`, -0.33417672375082363`}, {
      2.648156598461509, -0.3943550324390119}}]}, 
    {Hue[0.682693512077815], AbsoluteThickness[0.5], 
     LineBox[{{2.648156598461509, -0.3943550324390119}, {
      2.6728400483340056`, -0.6450395782798753}}]}, 
    {Hue[0.6992694585959216], AbsoluteThickness[0.5], 
     LineBox[{{2.2680396580060287`, -0.8580522163487847}, {
      2.284457958746897, -1.1368441939427059`}}]}, 
    {Hue[0.6995029896335488], AbsoluteThickness[0.5], 
     LineBox[{{2.284457958746897, -1.1368441939427059`}, {
      2.291385780639463, -1.436690548982074}}]}, 
    {Hue[0.5972370081714514], AbsoluteThickness[0.5], 
     LineBox[{{5.403187952588996, 3.800301315581602}, {5.630284451455838, 
      3.8477598192669125`}}]}, 
    {Hue[0.5977429371861889], AbsoluteThickness[0.5], 
     LineBox[{{5.630284451455838, 3.8477598192669125`}, {5.907182003757885, 
      3.882611126529649}}]}, 
    {Hue[0.6263008812103285], AbsoluteThickness[0.5], 
     LineBox[{{7.657254405218824, 3.413101570340565}, {7.709790060700965, 
      3.4116739007042938`}}]}, 
    {Hue[0.6463112702813866], AbsoluteThickness[0.5], 
     LineBox[{{7.709790060700965, 3.4116739007042938`}, {7.841941765830849, 
      3.367434628351651}}]}, 
    {Hue[0.6757152115433924], AbsoluteThickness[0.5], 
     LineBox[{{7.078171501620103, 1.4531793955188055`}, {7.126234424523609, 
      1.4233713146992655`}}]}, 
    {Hue[0.6760339095312273], AbsoluteThickness[0.5], 
     LineBox[{{7.126234424523609, 1.4233713146992655`}, {7.370656595532074, 
      1.2520823986515497`}}]}, 
    {Hue[0.48834352150098603`], AbsoluteThickness[0.5], 
     LineBox[{{7.76948545282574, 3.4087582852440135`}, {7.826222303376928, 
      3.426778123712218}}]}, 
    {Hue[0.4885281173296894], AbsoluteThickness[0.5], 
     LineBox[{{7.826222303376928, 3.426778123712218}, {8.135770010216715, 
      3.527245556395318}}]}, 
    {Hue[0.5192235874173885], AbsoluteThickness[0.5], 
     LineBox[{{7.159514962471937, 0.4721062938499978}, {
      7.812765773017162, -0.10705713229944788`}}]}, 
    {Hue[0.531995468173748], AbsoluteThickness[0.5], 
     LineBox[{{7.812765773017162, -0.10705713229944788`}, {
      7.888113141749456, -0.22169323589710352`}}]}, 
    {Hue[0.668860266697369], AbsoluteThickness[0.5], 
     LineBox[{{7.888113141749456, -0.22169323589710352`}, {
      7.834918368184336, -0.348140767657468}}]}, 
    {Hue[0.5681693917830306], AbsoluteThickness[0.5], 
     LineBox[{{5.2919813439335, 0.11115117115553974`}, {
      5.30137660267463, -0.021712658906653276`}}]}, 
    {Hue[0.5683653523799694], AbsoluteThickness[0.5], 
     LineBox[{{5.30137660267463, -0.021712658906653276`}, {
      5.319840476503305, -0.3754533054975368}}]}, 
    {Hue[0.5944549488756071], AbsoluteThickness[0.5], 
     LineBox[{{3.2337022530914274`, 0.5807779500679296}, {3.1850486011279524`,
       0.5456290314456834}}]}, 
    {Hue[0.5947994038588943], AbsoluteThickness[0.5], 
     LineBox[{{3.1850486011279524`, 0.5456290314456834}, {2.9646265652922676`,
       0.4058709806656777}}]}, 
    {Hue[0.6786301916583002], AbsoluteThickness[0.5], 
     LineBox[{{3.4639266872794554`, 2.343108263921816}, {3.42524535983107, 
      2.32639715513739}}]}, 
    {Hue[0.6788356137791582], AbsoluteThickness[0.5], 
     LineBox[{{3.42524535983107, 2.32639715513739}, {3.1344910450342534`, 
      2.2090378699962967`}}]}, 
    {Hue[0.6407290388244465], AbsoluteThickness[0.5], 
     LineBox[{{3.419021162144573, 2.3521030916458017`}, {3.4036866376173576`, 
      2.350292019126975}}]}, 
    {Hue[0.641400705588888], AbsoluteThickness[0.5], 
     LineBox[{{3.4036866376173576`, 2.350292019126975}, {3.1808192602493235`, 
      2.3452581568970534`}}]}, 
    {Hue[0.6337964621231462], AbsoluteThickness[0.5], 
     LineBox[{{3.381604823976741, -0.45247289711526967`}, {
      3.1315529398097395`, -0.5477796894646114}}]}, 
    {Hue[0.6364900892926474], AbsoluteThickness[0.5], 
     LineBox[{{3.1315529398097395`, -0.5477796894646114}, {
      3.013239309426549, -0.6172267168862021}}]}, 
    {Hue[0.6998945423646898], AbsoluteThickness[0.5], 
     LineBox[{{5.972389363345108, -4.14210818712324}, {
      5.977006599338496, -4.3649351408674555`}}]}, 
    {Hue[0.6687179495584423], AbsoluteThickness[0.5], 
     LineBox[{{7.449908629578593, -0.6290946221239575}, {
      7.531812469884396, -0.8224597114203069}}]}, 
    {Hue[0.6689417752305883], AbsoluteThickness[0.5], 
     LineBox[{{7.531812469884396, -0.8224597114203069}, {
      7.640428094261788, -1.1038480785083356`}}]}, 
    {Hue[0.6503611848463059], AbsoluteThickness[0.5], 
     LineBox[{{3.6290617411838237`, 1.8597836212114276`}, {
      3.4058226965187366`, 1.6664153391472372`}}]}, 
    {Hue[0.6646273585868414], AbsoluteThickness[0.5], 
     LineBox[{{3.4058226965187366`, 1.6664153391472372`}, {3.264465092946304, 
      1.5995015474563508`}}]}, 
    {Hue[0.6789177822439989], AbsoluteThickness[0.5], 
     LineBox[{{5.615425364229257, 2.1304326170238865`}, {5.614686661186413, 
      2.1295447813128416`}}]}, 
    {Hue[0.6791010442924105], AbsoluteThickness[0.5], 
     LineBox[{{5.614686661186413, 2.1295447813128416`}, {5.4640233858549445`, 
      1.9477339013071668`}}]}, 
    {Hue[0.6839297824080465], AbsoluteThickness[0.5], 
     LineBox[{{7.713787371339179, 1.570713499858081}, {7.774328954197708, 
      1.4155775426289767`}}]}, 
    {Hue[0.6841492546783309], AbsoluteThickness[0.5], 
     LineBox[{{7.774328954197708, 1.4155775426289767`}, {7.862360376716455, 
      1.1678882075169161`}}]}, 
    {Hue[0.6664125086698033], AbsoluteThickness[0.5], 
     LineBox[{{7.405720745714707, 0.28962841116119903`}, {
      7.380816080976115, -0.003170653943217791}}]}, 
    {Hue[0.6831864869506117], AbsoluteThickness[0.5], 
     LineBox[{{3.3243323955771182`, 1.5094446611867771`}, {
      3.1473289708149186`, 1.439324730597311}}]}, 
    {Hue[0.6837621556101091], AbsoluteThickness[0.5], 
     LineBox[{{3.1473289708149186`, 1.439324730597311}, {2.8900303313193105`, 
      1.3625771376378866`}}]}, 
    {Hue[0.6694892543230133], AbsoluteThickness[0.5], 
     LineBox[{{3.1502362259938024`, -1.3957048186924736`}, {
      3.140939782144625, -1.4064915027523015`}}]}, 
    {Hue[0.6696829604942546], AbsoluteThickness[0.5], 
     LineBox[{{3.140939782144625, -1.4064915027523015`}, {
      2.9274205586807724`, -1.6459941452217333`}}]}, 
    {Hue[0.6696841449313454], AbsoluteThickness[0.5], 
     LineBox[{{2.3009531280733664`, -0.43534944114653396`}, {
      2.234991679446133, -0.5354867968672238}}]}, 
    {Hue[0.6699677712070341], AbsoluteThickness[0.5], 
     LineBox[{{2.234991679446133, -0.5354867968672238}, {
      2.0824279862392947`, -0.7938827603812862}}]}, 
    {Hue[0.6392093544125866], AbsoluteThickness[0.5], 
     LineBox[{{4.126212024936174, -2.1067733899757095`}, {
      4.074089590001083, -2.1237816255091575`}}]}, 
    {Hue[0.6416964469142294], AbsoluteThickness[0.5], 
     LineBox[{{4.074089590001083, -2.1237816255091575`}, {
      3.9177412468353956`, -2.1479226278260843`}}]}, 
    {Hue[0.6746336122616103], AbsoluteThickness[0.5], 
     LineBox[{{5.3692815675533225`, -2.347872509711066}, {
      5.3459786044157145`, -2.3471977292237662`}}]}, 
    {Hue[0.675100672862202], AbsoluteThickness[0.5], 
     LineBox[{{5.3459786044157145`, -2.3471977292237662`}, {
      5.071169419359076, -2.318045595221131}}]}, 
    {Hue[0.6818368640989522], AbsoluteThickness[0.5], 
     LineBox[{{8.11598951992452, 0.901805773284278}, {8.117465107955368, 
      0.9039147885466935}}]}, 
    {Hue[0.6853823356091877], AbsoluteThickness[0.5], 
     LineBox[{{8.117465107955368, 0.9039147885466935}, {8.193310352004639, 
      1.0700518446392056`}}]}, 
    {Hue[0.6664616608580258], AbsoluteThickness[0.5], 
     LineBox[{{4.604221962285013, 1.2840482842581151`}, {4.563582880352831, 
      1.3283827761195492`}}]}, 
    {Hue[0.666759312174414], AbsoluteThickness[0.5], 
     LineBox[{{4.563582880352831, 1.3283827761195492`}, {4.413118909568857, 
      1.5107447399974474`}}]}, 
    {Hue[0.6441895512063591], AbsoluteThickness[0.5], 
     LineBox[{{2.3194844998904247`, -0.05599969509460018}, {
      2.151209848715848, -0.008757463641831466}}]}, 
    {Hue[0.6444160109713785], AbsoluteThickness[0.5], 
     LineBox[{{2.151209848715848, -0.008757463641831466}, {
      1.7936828751715792`, 0.0789026636679371}}]}, 
    {Hue[0.5233219896264304], AbsoluteThickness[0.5], 
     LineBox[{{3.9464350153265713`, -4.072481409782038}, {
      3.835722394194781, -4.13964075830178}}]}, 
    {Hue[0.5238018915480553], AbsoluteThickness[0.5], 
     LineBox[{{3.835722394194781, -4.13964075830178}, {
      3.6249144125819277`, -4.291219948717063}}]}, 
    {Hue[0.6609341272551856], AbsoluteThickness[0.5], 
     LineBox[{{2.312220468657105, -1.0674312255994285`}, {
      2.1483285684874125`, -1.0735863512073813`}}]}, 
    {Hue[0.6611598162393211], AbsoluteThickness[0.5], 
     LineBox[{{2.1483285684874125`, -1.0735863512073813`}, {
      1.7818741487236447`, -1.0752584328605608`}}]}, 
    {Hue[0.6624220426409161], AbsoluteThickness[0.5], 
     LineBox[{{5.947765141123858, -3.6496665162900763`}, {
      5.887302745128805, -3.684232142683669}}]}, 
    {Hue[0.6626052263552867], AbsoluteThickness[0.5], 
     LineBox[{{5.887302745128805, -3.684232142683669}, {
      5.616473148431152, -3.839546036759751}}]}, 
    {Hue[0.45994785209312083`], AbsoluteThickness[0.5], 
     LineBox[{{7.474559788528993, -4.071123810438171}, {
      7.579937962894859, -4.3161032824231205`}}]}, 
    {Hue[0.4824300607737383], AbsoluteThickness[0.5], 
     LineBox[{{7.579937962894859, -4.3161032824231205`}, {
      7.666259953006467, -4.416423503191367}}]}, 
    {Hue[0.5819966000877796], AbsoluteThickness[0.5], 
     LineBox[{{7.666259953006467, -4.416423503191367}, {
      7.798279980013547, -4.407131294580484}}]}, 
    {Hue[0.6815631394018214], AbsoluteThickness[0.5], 
     LineBox[{{7.798279980013547, -4.407131294580484}, {
      7.869698474112256, -4.295708534910429}}]}, 
    {Hue[0.6309392488093816], AbsoluteThickness[0.5], 
     LineBox[{{7.094646516432469, -2.548964716506338}, {
      7.017709930673849, -2.8118212473725794`}}]}, 
    {Hue[0.6311246276407358], AbsoluteThickness[0.5], 
     LineBox[{{7.017709930673849, -2.8118212473725794`}, {
      6.929734262581606, -3.1213235621942435`}}]}, 
    {Hue[0.6980281984842046], AbsoluteThickness[0.5], 
     LineBox[{{4.516406202241529, 3.153786736063154}, {4.4247886751073, 
      3.2215031330595845`}}]}, 
    {Hue[0.6982393993737264], AbsoluteThickness[0.5], 
     LineBox[{{4.4247886751073, 3.2215031330595845`}, {4.134348357352752, 
      3.424274933828437}}]}, 
    {Hue[0.47433076441473065`], AbsoluteThickness[0.5], 
     LineBox[{{4.897134594666521, -1.0567814332362302`}, {
      4.838260177596472, -1.1224294320918338`}}]}, 
    {Hue[0.4745325728115748], AbsoluteThickness[0.5], 
     LineBox[{{4.838260177596472, -1.1224294320918338`}, {
      4.628548247530289, -1.346088855764899}}]}, 
    {Hue[0.6991829702721443], AbsoluteThickness[0.5], 
     LineBox[{{5.863954869871214, 1.9176321217127803`}, {5.828851133311871, 
      1.7536027718809188`}}]}, 
    {Hue[0.5864684288348889], AbsoluteThickness[0.5], 
     LineBox[{{4.828233618459975, 2.9715138482660324`}, {4.657936910198665, 
      2.9071816910221346`}}]}, 
    {Hue[0.587673714990687], AbsoluteThickness[0.5], 
     LineBox[{{4.657936910198665, 2.9071816910221346`}, {4.451625246734025, 
      2.8573328742422452`}}]}, 
    {Hue[0.5892955014590743], AbsoluteThickness[0.5], 
     LineBox[{{4.56275376786472, 1.7150572909505666`}, {4.411361324814766, 
      1.641264663471477}}]}, 
    {Hue[0.5930089541196042], AbsoluteThickness[0.5], 
     LineBox[{{4.411361324814766, 1.641264663471477}, {4.234404632860996, 
      1.5925539569764573`}}]}, 
    {Hue[0.5800782311858548], AbsoluteThickness[0.5], 
     LineBox[{{5.116889302356681, 2.756812497992865}, {4.90488330168855, 
      2.735726286789342}}]}, 
    {Hue[0.5803041302877321], AbsoluteThickness[0.5], 
     LineBox[{{4.90488330168855, 2.735726286789342}, {4.604009722506619, 
      2.7158150708953386`}}]}, 
    {Hue[0.4447633951857377], AbsoluteThickness[0.5], 
     LineBox[{{8.281273842308778, -1.8821019026795236`}, {
      8.257770156028219, -2.0656888230253854`}}]}, 
    {Hue[0.444946634975223], AbsoluteThickness[0.5], 
     LineBox[{{8.257770156028219, -2.0656888230253854`}, {
      8.215440038407017, -2.401181598702991}}]}, 
    {Hue[0.5459871500773157], AbsoluteThickness[0.5], 
     LineBox[{{6.093639983498253, -0.7145902088797783}, {
      5.914514873020996, -0.7476928139270784}}]}, 
    {Hue[0.5462190280690427], AbsoluteThickness[0.5], 
     LineBox[{{5.914514873020996, -0.7476928139270784}, {
      5.630380699138552, -0.7899309361355071}}]}, 
    {Hue[0.6372889299153355], AbsoluteThickness[0.5], 
     LineBox[{{6.094872903973718, -2.6425988951424286`}, {
      5.951171420434094, -2.8273803728010924`}}]}, 
    {Hue[0.6385072868555185], AbsoluteThickness[0.5], 
     LineBox[{{5.951171420434094, -2.8273803728010924`}, {
      5.8301339973671515`, -3.0309964858953027`}}]}, 
    {Hue[0.4686747228591265], AbsoluteThickness[0.5], 
     LineBox[{{7.207895388041592, -3.412112857650837}, {
      7.186656610075415, -3.4851689095687415`}}]}, 
    {Hue[0.47122181365725085`], AbsoluteThickness[0.5], 
     LineBox[{{7.186656610075415, -3.4851689095687415`}, {
      7.104736350691827, -3.6563018927554336`}}]}, 
    {Hue[0.6918939664923619], AbsoluteThickness[0.5], 
     LineBox[{{4.097702904223805, 3.381360299048231}, {4.09629675294918, 
      3.437049686041319}}]}, 
    {Hue[0.6924109485444581], AbsoluteThickness[0.5], 
     LineBox[{{4.09629675294918, 3.437049686041319}, {4.07115545095173, 
      3.6707940629447973`}}]}, 
    {Hue[0.6017081075573192], AbsoluteThickness[0.5], 
     LineBox[{{2.6408519376863855`, 1.35138276775199}, {2.5958833832665844`, 
      1.3589087179036896`}}]}, 
    {Hue[0.6021472092802145], AbsoluteThickness[0.5], 
     LineBox[{{2.5958833832665844`, 1.3589087179036896`}, {
      2.3206781979850604`, 1.4260747983155784`}}]}, 
    {Hue[0.44837878549352894`], AbsoluteThickness[0.5], 
     LineBox[{{3.2698138327236355`, -0.4405777175670541}, {
      2.937998642286805, -0.8530764190411502}}]}, 
    {Hue[0.449355951113289], AbsoluteThickness[0.5], 
     LineBox[{{2.937998642286805, -0.8530764190411502}, {
      2.8297096805049433`, -1.02433477027403}}]}, 
    {Hue[0.6187207138177967], AbsoluteThickness[0.5], 
     LineBox[{{3.8973613008508083`, -1.124342701262884}, {
      3.892751312928141, -1.1897116440320903`}}]}, 
    {Hue[0.6192171734108007], AbsoluteThickness[0.5], 
     LineBox[{{3.892751312928141, -1.1897116440320903`}, {
      3.860881282240003, -1.4002161107014388`}}]}, 
    {Hue[0.6953045180625012], AbsoluteThickness[0.5], 
     LineBox[{{4.3351822088776855`, -1.3548246086900826`}, {
      4.21139443529494, -1.5520424102655443`}}]}, 
    {Hue[0.6957892737205457], AbsoluteThickness[0.5], 
     LineBox[{{4.21139443529494, -1.5520424102655443`}, {
      4.07555611396809, -1.8117704305492082`}}]}, 
    {Hue[0.6678981503472141], AbsoluteThickness[0.5], 
     LineBox[{{2.1941208268320462`, 3.3746548047126277`}, {
      2.1530100585787526`, 3.5825554779714337`}}]}, 
    {Hue[0.6683378460993142], AbsoluteThickness[0.5], 
     LineBox[{{2.1530100585787526`, 3.5825554779714337`}, {
      2.1227029962502155`, 3.8305644736481965`}}]}, 
    {Hue[0.6834137988462666], AbsoluteThickness[0.5], 
     LineBox[{{2.6728400483340056`, -0.6450395782798753}, {
      2.6728293627882644`, -0.6816242794814096}}]}, 
    {Hue[0.6844034291671544], AbsoluteThickness[0.5], 
     LineBox[{{2.6728293627882644`, -0.6816242794814096}, {
      2.6958045992808475`, -0.8824309136322641}}]}, 
    {Hue[0.6997365206711762], AbsoluteThickness[0.5], 
     LineBox[{{2.291385780639463, -1.436690548982074}, {
      2.2897548956541605`, -1.5658933942645108`}}]}, 
    {Hue[0.6999241485218473], AbsoluteThickness[0.5], 
     LineBox[{{2.2897548956541605`, -1.5658933942645108`}, {
      2.282771181374178, -1.8615689193742373`}}]}, 
    {Hue[0.5982488662009264], AbsoluteThickness[0.5], 
     LineBox[{{5.907182003757885, 3.882611126529649}, {6.679674476361992, 
      3.916929071821072}}]}, 
    {Hue[0.6130692635640774], AbsoluteThickness[0.5], 
     LineBox[{{6.679674476361992, 3.916929071821072}, {6.834619754427745, 
      3.8806501516394767`}}]}, 
    {Hue[0.666321659352443], AbsoluteThickness[0.5], 
     LineBox[{{7.841941765830849, 3.367434628351651}, {8.081998778109991, 
      3.196453475142506}}]}, 
    {Hue[0.667209688042434], AbsoluteThickness[0.5], 
     LineBox[{{8.081998778109991, 3.196453475142506}, {8.27378532912938, 
      3.089154647252922}}]}, 
    {Hue[0.6763526075190623], AbsoluteThickness[0.5], 
     LineBox[{{7.370656595532074, 1.2520823986515497`}, {7.442301448445294, 
      1.1956261762702811`}}]}, 
    {Hue[0.6766046881764476], AbsoluteThickness[0.5], 
     LineBox[{{7.442301448445294, 1.1956261762702811`}, {7.690322061937462, 
      0.9829898218117369}}]}, 
    {Hue[0.4887127131583928], AbsoluteThickness[0.5], 
     LineBox[{{8.135770010216715, 3.527245556395318}, {8.25819076382651, 
      3.567834013922942}}]}, 
    {Hue[0.4907152721839182], AbsoluteThickness[0.5], 
     LineBox[{{8.25819076382651, 3.567834013922942}, {8.495946585525004, 
      3.6887914096803205`}}]}, 
    {Hue[0.6560883859410045], AbsoluteThickness[0.5], 
     LineBox[{{7.812765773017162, -0.10705713229944788`}, {
      7.898297320087702, -0.13106147713959804`}}]}, 
    {Hue[0.6584883170351642], AbsoluteThickness[0.5], 
     LineBox[{{7.898297320087702, -0.13106147713959804`}, {
      8.085192016271241, -0.15233612156201284`}}]}, 
    {Hue[0.5447673489301068], AbsoluteThickness[0.5], 
     LineBox[{{7.888113141749456, -0.22169323589710355`}, {
      7.9413563276372345`, -0.3837138304238663}}]}, 
    {Hue[0.5449726404695836], AbsoluteThickness[0.5], 
     LineBox[{{7.9413563276372345`, -0.3837138304238663}, {
      8.023749465279174, -0.6564234254441896}}]}, 
    {Hue[0.6816321474537278], AbsoluteThickness[0.5], 
     LineBox[{{7.834918368184336, -0.34814076765746804`}, {
      7.220197575325882, -1.1366431247685609`}}]}, 
    {Hue[0.6827508703927666], AbsoluteThickness[0.5], 
     LineBox[{{7.220197575325882, -1.1366431247685609`}, {
      7.110066133937232, -1.3196122735009896`}}]}, 
    {Hue[0.5685613129769082], AbsoluteThickness[0.5], 
     LineBox[{{5.319840476503305, -0.3754533054975368}, {
      5.329960608744796, -0.6756262338699552}}]}, 
    {Hue[0.5698864015519589], AbsoluteThickness[0.5], 
     LineBox[{{5.329960608744796, -0.6756262338699552}, {
      5.311374477317961, -0.8702033506379357}}]}, 
    {Hue[0.5951438588421815], AbsoluteThickness[0.5], 
     LineBox[{{2.9646265652922676`, 0.4058709806656777}, {2.871601740402528, 
      0.35450208351356993`}}]}, 
    {Hue[0.5953394211538343], AbsoluteThickness[0.5], 
     LineBox[{{2.871601740402528, 0.35450208351356993`}, {2.568609747241561, 
      0.17993281888803214`}}]}, 
    {Hue[0.6790410359000163], AbsoluteThickness[0.5], 
     LineBox[{{3.1344910450342534`, 2.2090378699962967`}, {2.605605904911915, 
      2.0102812707078206`}}]}, 
    {Hue[0.679224463447879], AbsoluteThickness[0.5], 
     LineBox[{{2.605605904911915, 2.0102812707078206`}, {2.352085693409248, 
      1.914169228756334}}]}, 
    {Hue[0.6420723723533294], AbsoluteThickness[0.5], 
     LineBox[{{3.1808192602493235`, 2.3452581568970534`}, {
      3.1380886835098276`, 2.34835699848299}}]}, 
    {Hue[0.643576361668892], AbsoluteThickness[0.5], 
     LineBox[{{3.1380886835098276`, 2.34835699848299}, {2.9377092946462433`, 
      2.335707755262018}}]}, 
    {Hue[0.6391837164621486], AbsoluteThickness[0.5], 
     LineBox[{{3.013239309426549, -0.6172267168862021}, {
      2.9142006442519786`, -0.7002105201445175}}]}, 
    {Hue[0.6393826699834937], AbsoluteThickness[0.5], 
     LineBox[{{2.9142006442519786`, -0.7002105201445175}, {
      2.7009504064931456`, -0.886442425745927}}]}, 
    {Hue[0.6691656009027344], AbsoluteThickness[0.5], 
     LineBox[{{7.640428094261788, -1.1038480785083356`}, {
      7.653211682028765, -1.1404403509867747`}}]}, 
    {Hue[0.6695066166801936], AbsoluteThickness[0.5], 
     LineBox[{{7.653211682028765, -1.1404403509867747`}, {
      7.766147741904659, -1.4105064288629432`}}]}, 
    {Hue[0.6788935323273754], AbsoluteThickness[0.5], 
     LineBox[{{3.264465092946304, 1.5995015474563508`}, {3.1433883712892046`, 
      1.578667178518207}}]}, 
    {Hue[0.679103651157179], AbsoluteThickness[0.5], 
     LineBox[{{3.1433883712892046`, 1.578667178518207}, {2.8156411223846534`, 
      1.5132813511973178`}}]}, 
    {Hue[0.6792843063408219], AbsoluteThickness[0.5], 
     LineBox[{{5.4640233858549445`, 1.9477339013071668`}, {5.332146241952127, 
      1.7879499890282105`}}]}, 
    {Hue[0.6797904735053178], AbsoluteThickness[0.5], 
     LineBox[{{5.332146241952127, 1.7879499890282105`}, {5.1875130680893315`, 
      1.639042991257376}}]}, 
    {Hue[0.6843687269486151], AbsoluteThickness[0.5], 
     LineBox[{{7.862360376716455, 1.1678882075169161`}, {7.880779110920352, 
      1.1105665064762662`}}]}, 
    {Hue[0.6851178604731175], AbsoluteThickness[0.5], 
     LineBox[{{7.880779110920352, 1.1105665064762662`}, {7.977761929985089, 
      0.8882111978820659}}]}, 
    {Hue[0.6664125086698033], AbsoluteThickness[0.5], 
     LineBox[{{7.380816080976115, -0.003170653943217805}, {
      7.29815300656839, -0.1434792057361047}}]}, 
    {Hue[0.666606449798822], AbsoluteThickness[0.5], 
     LineBox[{{7.29815300656839, -0.1434792057361047}, {
      7.14183109987971, -0.3988120264075526}}]}, 
    {Hue[0.6843378242696065], AbsoluteThickness[0.5], 
     LineBox[{{2.8900303313193105`, 1.3625771376378866`}, {
      2.8701993775974306`, 1.3585039727833168`}}]}, 
    {Hue[0.6847912388820765], AbsoluteThickness[0.5], 
     LineBox[{{2.8701993775974306`, 1.3585039727833168`}, {
      2.5939123039010066`, 1.2797169994967676`}}]}, 
    {Hue[0.669876666665496], AbsoluteThickness[0.5], 
     LineBox[{{2.9274205586807724`, -1.6459941452217333`}, {
      2.880748875491625, -1.6966098945074817`}}]}, 
    {Hue[0.670241627030915], AbsoluteThickness[0.5], 
     LineBox[{{2.880748875491625, -1.6966098945074817`}, {
      2.6744488706177325`, -1.8935461606096162`}}]}, 
    {Hue[0.6702513974827228], AbsoluteThickness[0.5], 
     LineBox[{{2.0824279862392947`, -0.7938827603812862}, {
      2.0544620146035415`, -0.8470505500838811}}]}, 
    {Hue[0.6704345145859876], AbsoluteThickness[0.5], 
     LineBox[{{2.0544620146035415`, -0.8470505500838811}, {
      1.8756163776684474`, -1.1869631499097286`}}]}, 
    {Hue[0.6441835394158721], AbsoluteThickness[0.5], 
     LineBox[{{3.9177412468353956`, -2.1479226278260843`}, {
      3.9031775651540577`, -2.147791139500906}}]}, 
    {Hue[0.6445107570521581], AbsoluteThickness[0.5], 
     LineBox[{{3.9031775651540577`, -2.147791139500906}, {
      3.6672522571574695`, -2.159269702104077}}]}, 
    {Hue[0.6755677334627935], AbsoluteThickness[0.5], 
     LineBox[{{5.071169419359076, -2.318045595221131}, {
      4.914250378235094, -2.2890980576784323`}}]}, 
    {Hue[0.6757528939413044], AbsoluteThickness[0.5], 
     LineBox[{{4.914250378235094, -2.2890980576784323`}, {
      4.626555883353152, -2.233817827673968}}]}, 
    {Hue[0.6889278071194233], AbsoluteThickness[0.5], 
     LineBox[{{8.193310352004639, 1.0700518446392056`}, {8.207500799389074, 
      1.1265603554403336`}}]}, 
    {Hue[0.6891375040246034], AbsoluteThickness[0.5], 
     LineBox[{{8.207500799389074, 1.1265603554403336`}, {8.300156147257562, 
      1.4583259666974322`}}]}, 
    {Hue[0.6670569634908022], AbsoluteThickness[0.5], 
     LineBox[{{4.413118909568857, 1.5107447399974474`}, {4.349313759099647, 
      1.5968430133600238`}}]}, 
    {Hue[0.6672618058027888], AbsoluteThickness[0.5], 
     LineBox[{{4.349313759099647, 1.5968430133600238`}, {4.162346604277734, 
      1.862138328747747}}]}, 
    {Hue[0.5242817934696802], AbsoluteThickness[0.5], 
     LineBox[{{3.6249144125819277`, -4.291219948717063}, {
      3.5146907617059844`, -4.384345781536437}}]}, 
    {Hue[0.5245842267810413], AbsoluteThickness[0.5], 
     LineBox[{{3.5146907617059844`, -4.384345781536437}, {
      3.2909883109441656`, -4.5946589053852165`}}]}, 
    {Hue[0.6627884100696575], AbsoluteThickness[0.5], 
     LineBox[{{5.616473148431152, -3.839546036759751}, {
      5.580849709699812, -3.8600389169282856`}}]}, 
    {Hue[0.6631841971202809], AbsoluteThickness[0.5], 
     LineBox[{{5.580849709699812, -3.8600389169282856`}, {
      5.362099643024295, -4.006547355628791}}]}, 
    {Hue[0.5595143914071581], AbsoluteThickness[0.5], 
     LineBox[{{7.579937962894859, -4.3161032824231205`}, {
      7.583838827532015, -4.362254507597883}}]}, 
    {Hue[0.5598168449504872], AbsoluteThickness[0.5], 
     LineBox[{{7.583838827532015, -4.362254507597883}, {
      7.592086742145651, -4.625886100022921}}]}, 
    {Hue[0.5049122694543542], AbsoluteThickness[0.5], 
     LineBox[{{7.666259953006467, -4.416423503191367}, {
      7.813075213571055, -4.507642203723091}}]}, 
    {Hue[0.5052625661877026], AbsoluteThickness[0.5], 
     LineBox[{{7.813075213571055, -4.507642203723091}, {
      8.074781152017092, -4.648738151644846}}]}, 
    {Hue[0.6044788087683953], AbsoluteThickness[0.5], 
     LineBox[{{7.798279980013547, -4.407131294580484}, {
      7.862689890837578, -4.381808975953809}}]}, 
    {Hue[0.6078327337114449], AbsoluteThickness[0.5], 
     LineBox[{{7.862689890837578, -4.381808975953809}, {
      8.051406858091678, -4.344427070346459}}]}, 
    {Hue[0.6313100064720901], AbsoluteThickness[0.5], 
     LineBox[{{6.929734262581606, -3.1213235621942435`}, {
      6.9071799002491305`, -3.203089436157028}}]}, 
    {Hue[0.6344196356199621], AbsoluteThickness[0.5], 
     LineBox[{{6.9071799002491305`, -3.203089436157028}, {
      6.8268878473143895`, -3.3719473963555866`}}]}, 
    {Hue[0.6984506002632481], AbsoluteThickness[0.5], 
     LineBox[{{4.134348357352752, 3.424274933828437}, {4.103650192613267, 
      3.4444959002671793`}}]}, 
    {Hue[0.6986425782256793], AbsoluteThickness[0.5], 
     LineBox[{{4.103650192613267, 3.4444959002671793`}, {3.862323337613243, 
      3.6088293415498454`}}]}, 
    {Hue[0.4747343812084191], AbsoluteThickness[0.5], 
     LineBox[{{4.628548247530289, -1.346088855764899}, {
      4.614717322515146, -1.3601992666660045`}}]}, 
    {Hue[0.47494229309974756`], AbsoluteThickness[0.5], 
     LineBox[{{4.614717322515146, -1.3601992666660045`}, {
      4.414914889031484, -1.574690063371122}}]}, 
    {Hue[0.5888790011464852], AbsoluteThickness[0.5], 
     LineBox[{{4.451625246734025, 2.8573328742422452`}, {4.42224035122515, 
      2.8539994316229933`}}]}, 
    {Hue[0.5890814809585552], AbsoluteThickness[0.5], 
     LineBox[{{4.42224035122515, 2.8539994316229933`}, {4.107906924151698, 
      2.811140438077034}}]}, 
    {Hue[0.596722406780134], AbsoluteThickness[0.5], 
     LineBox[{{4.234404632860996, 1.5925539569764573`}, {4.134558778891135, 
      1.5841778176651693`}}]}, 
    {Hue[0.5970603994730845], AbsoluteThickness[0.5], 
     LineBox[{{4.134558778891135, 1.5841778176651693`}, {3.8776235649819144`, 
      1.547137372789917}}]}, 
    {Hue[0.5805300293896095], AbsoluteThickness[0.5], 
     LineBox[{{4.604009722506619, 2.7158150708953386`}, {4.405039731031097, 
      2.7092409194679954`}}]}, 
    {Hue[0.5809080897249176], AbsoluteThickness[0.5], 
     LineBox[{{4.405039731031097, 2.7092409194679954`}, {4.128791118712853, 
      2.7182553933505633`}}]}, 
    {Hue[0.4451298747647083], AbsoluteThickness[0.5], 
     LineBox[{{8.215440038407017, -2.401181598702991}, {
      8.187344793038829, -2.6271694339600202`}}]}, 
    {Hue[0.44554483431683584`], AbsoluteThickness[0.5], 
     LineBox[{{8.187344793038829, -2.6271694339600202`}, {
      8.170792281269932, -2.938696871178345}}]}, 
    {Hue[0.5464509060607696], AbsoluteThickness[0.5], 
     LineBox[{{5.630380699138552, -0.7899309361355071}, {
      5.345367726580626, -0.8221047988375817}}]}, 
    {Hue[0.5467597581778985], AbsoluteThickness[0.5], 
     LineBox[{{5.345367726580626, -0.8221047988375817}, {
      5.081982035900316, -0.837429909266994}}]}, 
    {Hue[0.6397256437957015], AbsoluteThickness[0.5], 
     LineBox[{{5.8301339973671515`, -3.0309964858953027`}, {
      5.78627592501987, -3.131449517541143}}]}, 
    {Hue[0.6399108166494791], AbsoluteThickness[0.5], 
     LineBox[{{5.78627592501987, -3.131449517541143}, {
      5.656320172600433, -3.4231682308452736`}}]}, 
    {Hue[0.47376890445537506`], AbsoluteThickness[0.5], 
     LineBox[{{7.104736350691827, -3.6563018927554336`}, {
      6.968545787671244, -3.8511629426954896`}}]}, 
    {Hue[0.4743617940675031], AbsoluteThickness[0.5], 
     LineBox[{{6.968545787671244, -3.8511629426954896`}, {
      6.848439921609096, -4.060339923633495}}]}, 
    {Hue[0.6025863110031098], AbsoluteThickness[0.5], 
     LineBox[{{2.3206781979850604`, 1.4260747983155784`}, {
      2.1758216835623503`, 1.4729453427395387`}}]}, 
    {Hue[0.6027699305553069], AbsoluteThickness[0.5], 
     LineBox[{{2.1758216835623503`, 1.4729453427395387`}, {
      1.8240741026616254`, 1.588190619940066}}]}, 
    {Hue[0.4503331167330491], AbsoluteThickness[0.5], 
     LineBox[{{2.8297096805049433`, -1.02433477027403}, {
      2.800016384379107, -1.0857634080385206`}}]}, 
    {Hue[0.45058867864715213`], AbsoluteThickness[0.5], 
     LineBox[{{2.800016384379107, -1.0857634080385206`}, {
      2.690471506059175, -1.3392204971550752`}}]}, 
    {Hue[0.6197136330038048], AbsoluteThickness[0.5], 
     LineBox[{{3.860881282240003, -1.4002161107014388`}, {
      3.792643879086505, -1.6915080459494076`}}]}, 
    {Hue[0.6200172047627803], AbsoluteThickness[0.5], 
     LineBox[{{3.792643879086505, -1.6915080459494076`}, {
      3.7253197317359628`, -1.9226930520229284`}}]}, 
    {Hue[0.6962740293785903], AbsoluteThickness[0.5], 
     LineBox[{{4.07555611396809, -1.8117704305492082`}, {
      4.035231998209413, -1.9062904564970764`}}]}, 
    {Hue[0.6964573659264705], AbsoluteThickness[0.5], 
     LineBox[{{4.035231998209413, -1.9062904564970764`}, {
      3.9291983209491628`, -2.1531670824734057`}}]}, 
    {Hue[0.6853930594880423], AbsoluteThickness[0.5], 
     LineBox[{{2.6958045992808475`, -0.8824309136322641}, {
      2.7450952301165734`, -1.0947326431897753`}}]}, 
    {Hue[0.6855811853822601], AbsoluteThickness[0.5], 
     LineBox[{{2.7450952301165734`, -1.0947326431897753`}, {
      2.81530561668199, -1.3819969648385397`}}]}, 
    {Hue[0.6278896609272283], AbsoluteThickness[0.5], 
     LineBox[{{6.834619754427745, 3.8806501516394767`}, {7.134549649453645, 
      3.7150840089529598`}}]}, 
    {Hue[0.628173584488685], AbsoluteThickness[0.5], 
     LineBox[{{7.134549649453645, 3.7150840089529598`}, {7.396143214128973, 
      3.5870377413582615`}}]}, 
    {Hue[0.6768567688338327], AbsoluteThickness[0.5], 
     LineBox[{{7.690322061937462, 0.9829898218117369}, {7.7545209504678905`, 
      0.9231714981215575}}]}, 
    {Hue[0.677233884303418], AbsoluteThickness[0.5], 
     LineBox[{{7.7545209504678905`, 0.9231714981215575}, {7.951636345348979, 
      0.7137730150913497}}]}, 
    {Hue[0.6608882481293237], AbsoluteThickness[0.5], 
     LineBox[{{8.085192016271241, -0.15233612156201284`}, {
      8.118623229274593, -0.15076632007160554`}}]}, 
    {Hue[0.6612257055589325], AbsoluteThickness[0.5], 
     LineBox[{{8.118623229274593, -0.15076632007160554`}, {
      8.417195633114394, -0.1544898434743955}}]}, 
    {Hue[0.5451779320090604], AbsoluteThickness[0.5], 
     LineBox[{{8.023749465279174, -0.6564234254441896}, {
      8.086800653178619, -0.8848543317206131}}]}, 
    {Hue[0.5455223125573594], AbsoluteThickness[0.5], 
     LineBox[{{8.086800653178619, -0.8848543317206131}, {
      8.140126437614487, -1.1365465124910128`}}]}, 
    {Hue[0.6838695933318052], AbsoluteThickness[0.5], 
     LineBox[{{7.110066133937232, -1.3196122735009896`}, {
      7.060689219099167, -1.4297462813242712`}}]}, 
    {Hue[0.6841318565706347], AbsoluteThickness[0.5], 
     LineBox[{{7.060689219099167, -1.4297462813242712`}, {
      6.941744632947714, -1.6665184367310864`}}]}, 
    {Hue[0.5712114901270094], AbsoluteThickness[0.5], 
     LineBox[{{5.311374477317961, -0.8702033506379357}, {
      5.24895411678124, -1.1439807200337655`}}]}, 
    {Hue[0.5714363320901612], AbsoluteThickness[0.5], 
     LineBox[{{5.24895411678124, -1.1439807200337655`}, {
      5.1971633524093805`, -1.411110251959242}}]}, 
    {Hue[0.5955349834654873], AbsoluteThickness[0.5], 
     LineBox[{{2.568609747241561, 0.17993281888803214`}, {2.527798254498685, 
      0.1554213130849209}}]}, 
    {Hue[0.5961535912393059], AbsoluteThickness[0.5], 
     LineBox[{{2.527798254498685, 0.1554213130849209}, {
      2.3141454695633144`, -0.0009303562125356022}}]}, 
    {Hue[0.6794078909957417], AbsoluteThickness[0.5], 
     LineBox[{{2.352085693409248, 1.914169228756334}, {2.3220548648436976`, 
      1.9026847111612062`}}]}, 
    {Hue[0.682238749155003], AbsoluteThickness[0.5], 
     LineBox[{{2.3220548648436976`, 1.9026847111612062`}, {
      2.2076719681319608`, 1.8799915918934478`}}]}, 
    {Hue[0.6450803509844547], AbsoluteThickness[0.5], 
     LineBox[{{2.9377092946462433`, 2.335707755262018}, {2.8772032825485674`, 
      2.323538337846488}}]}, 
    {Hue[0.6452834344015165], AbsoluteThickness[0.5], 
     LineBox[{{2.8772032825485674`, 2.323538337846488}, {2.5359324408170836`, 
      2.2629931975671616`}}]}, 
    {Hue[0.6395816235048388], AbsoluteThickness[0.5], 
     LineBox[{{2.7009504064931456`, -0.886442425745927}, {
      2.6416685364883628`, -0.9403888692305328}}]}, 
    {Hue[0.6397818926537436], AbsoluteThickness[0.5], 
     LineBox[{{2.6416685364883628`, -0.9403888692305328}, {
      2.3882353982456106`, -1.1810577998572418`}}]}, 
    {Hue[0.6698476324576529], AbsoluteThickness[0.5], 
     LineBox[{{7.766147741904659, -1.4105064288629432`}, {
      7.850274393352393, -1.582000064127832}}]}, 
    {Hue[0.6843764058359394], AbsoluteThickness[0.5], 
     LineBox[{{7.850274393352393, -1.582000064127832}, {
      7.942643768053254, -1.6854126608445184`}}]}, 
    {Hue[0.6793137699869826], AbsoluteThickness[0.5], 
     LineBox[{{2.8156411223846534`, 1.5132813511973178`}, {
      2.6527186743894404`, 1.4762625269830916`}}]}, 
    {Hue[0.6795262660221101], AbsoluteThickness[0.5], 
     LineBox[{{2.6527186743894404`, 1.4762625269830916`}, {
      2.3269097514349193`, 1.4116366195782286`}}]}, 
    {Hue[0.6802966406698138], AbsoluteThickness[0.5], 
     LineBox[{{5.1875130680893315`, 1.639042991257376}, {5.138377464275786, 
      1.5960238694596374`}}]}, 
    {Hue[0.6804825418083417], AbsoluteThickness[0.5], 
     LineBox[{{5.138377464275786, 1.5960238694596374`}, {4.883148682769548, 
      1.3764357895408095`}}]}, 
    {Hue[0.68586699399762], AbsoluteThickness[0.5], 
     LineBox[{{7.977761929985089, 0.8882111978820659}, {8.06130159699868, 
      0.7394461874404072}}]}, 
    {Hue[0.6937172099453792], AbsoluteThickness[0.5], 
     LineBox[{{8.06130159699868, 0.7394461874404072}, {8.171750587440552, 
      0.6191664772526606}}]}, 
    {Hue[0.6668003909278408], AbsoluteThickness[0.5], 
     LineBox[{{7.14183109987971, -0.39881202640755253`}, {
      7.1216425990063, -0.4305655282711646}}]}, 
    {Hue[0.6683432450694717], AbsoluteThickness[0.5], 
     LineBox[{{7.1216425990063, -0.4305655282711646}, {
      7.048745360448051, -0.5896979328317056}}]}, 
    {Hue[0.6852446534945463], AbsoluteThickness[0.5], 
     LineBox[{{2.5939123039010066`, 1.2797169994967676`}, {2.412278309774798, 
      1.2127964730526846`}}]}, 
    {Hue[0.6854946645971154], AbsoluteThickness[0.5], 
     LineBox[{{2.412278309774798, 1.2127964730526846`}, {2.1178173572235908`, 
      1.1177483207118895`}}]}, 
    {Hue[0.6706065873963342], AbsoluteThickness[0.5], 
     LineBox[{{2.6744488706177325`, -1.8935461606096162`}, {
      2.6340094531314135`, -1.927500485180183}}]}, 
    {Hue[0.6708928992051714], AbsoluteThickness[0.5], 
     LineBox[{{2.6340094531314135`, -1.927500485180183}, {
      2.4018199732914707`, -2.10354895449524}}]}, 
    {Hue[0.6448379746884441], AbsoluteThickness[0.5], 
     LineBox[{{3.6672522571574695`, -2.159269702104077}, {
      3.4330706213555873`, -2.184247532440832}}]}, 
    {Hue[0.6450211117039332], AbsoluteThickness[0.5], 
     LineBox[{{3.4330706213555873`, -2.184247532440832}, {
      3.134775657365511, -2.2162878220725832`}}]}, 
    {Hue[0.6759380544198154], AbsoluteThickness[0.5], 
     LineBox[{{4.626555883353152, -2.233817827673968}, {
      4.397673717117399, -2.1880767136477473`}}]}, 
    {Hue[0.6761908539592285], AbsoluteThickness[0.5], 
     LineBox[{{4.397673717117399, -2.1880767136477473`}, {
      4.099114995086564, -2.141213723451201}}]}, 
    {Hue[0.6674666481147754], AbsoluteThickness[0.5], 
     LineBox[{{4.162346604277734, 1.862138328747747}, {4.162179615633744, 
      1.862387703249933}}]}, 
    {Hue[0.667669884809998], AbsoluteThickness[0.5], 
     LineBox[{{4.162179615633744, 1.862387703249933}, {3.975437887865956, 
      2.127856256636735}}]}, 
    {Hue[0.6635799841709044], AbsoluteThickness[0.5], 
     LineBox[{{5.362099643024295, -4.006547355628791}, {
      5.279787419090234, -4.070198385837125}}]}, 
    {Hue[0.663957462684769], AbsoluteThickness[0.5], 
     LineBox[{{5.279787419090234, -4.070198385837125}, {
      5.092301143738348, -4.23590309475546}}]}, 
    {Hue[0.6111866586544941], AbsoluteThickness[0.5], 
     LineBox[{{8.051406858091678, -4.344427070346459}, {
      8.11099580886446, -4.343442291022954}}]}, 
    {Hue[0.6114182124468496], AbsoluteThickness[0.5], 
     LineBox[{{8.11099580886446, -4.343442291022954}, {
      8.470391685845325, -4.324888481466}}]}, 
    {Hue[0.6375292647678339], AbsoluteThickness[0.5], 
     LineBox[{{6.8268878473143895`, -3.3719473963555866`}, {6.665933962421392,
       -3.5980869677647735`}}]}, 
    {Hue[0.6391261463958097], AbsoluteThickness[0.5], 
     LineBox[{{6.665933962421392, -3.5980869677647735`}, {
      6.56398960641994, -3.7938934235005783`}}]}, 
    {Hue[0.6988345561881104], AbsoluteThickness[0.5], 
     LineBox[{{3.862323337613243, 3.6088293415498454`}, {3.829911836817922, 
      3.63163678705379}}]}, 
    {Hue[0.6993359372658947], AbsoluteThickness[0.5], 
     LineBox[{{3.829911836817922, 3.63163678705379}, {3.636771330728353, 
      3.7921973243101887`}}]}, 
    {Hue[0.475150204991076], AbsoluteThickness[0.5], 
     LineBox[{{4.414914889031484, -1.574690063371122}, {
      4.37831481021951, -1.6160413907100193`}}]}, 
    {Hue[0.4753416747097047], AbsoluteThickness[0.5], 
     LineBox[{{4.37831481021951, -1.6160413907100193`}, {
      4.136185292466732, -1.8815145244865437`}}]}, 
    {Hue[0.5892839607706253], AbsoluteThickness[0.5], 
     LineBox[{{4.107906924151698, 2.811140438077034}, {3.9126355914282813`, 
      2.7800145138044243`}}]}, 
    {Hue[0.5894680503005783], AbsoluteThickness[0.5], 
     LineBox[{{3.9126355914282813`, 2.7800145138044243`}, {3.652329238880699, 
      2.7398869964278223`}}]}, 
    {Hue[0.5973983921660351], AbsoluteThickness[0.5], 
     LineBox[{{3.8776235649819144`, 1.547137372789917}, {3.603518065205677, 
      1.4908146381672884`}}]}, 
    {Hue[0.5975964815910364], AbsoluteThickness[0.5], 
     LineBox[{{3.603518065205677, 1.4908146381672884`}, {3.33269357193641, 
      1.4407580715476331`}}]}, 
    {Hue[0.5812861500602258], AbsoluteThickness[0.5], 
     LineBox[{{4.128791118712853, 2.7182553933505633`}, {3.9106446064727507`, 
      2.739761757931408}}]}, 
    {Hue[0.5814729394796928], AbsoluteThickness[0.5], 
     LineBox[{{3.9106446064727507`, 2.739761757931408}, {3.6496634334844873`, 
      2.7681090417856065`}}]}, 
    {Hue[0.44595979386896323`], AbsoluteThickness[0.5], 
     LineBox[{{8.170792281269932, -2.938696871178345}, {
      8.175387372593446, -3.200941815523302}}]}, 
    {Hue[0.4468029937792086], AbsoluteThickness[0.5], 
     LineBox[{{8.175387372593446, -3.200941815523302}, {
      8.202925738185447, -3.42230821353291}}]}, 
    {Hue[0.5470686102950272], AbsoluteThickness[0.5], 
     LineBox[{{5.081982035900316, -0.837429909266994}, {
      4.8549634431669375`, -0.8382992390160692}}]}, 
    {Hue[0.5484713245435942], AbsoluteThickness[0.5], 
     LineBox[{{4.8549634431669375`, -0.8382992390160692}, {
      4.658065848402106, -0.8129543347630941}}]}, 
    {Hue[0.6400959895032566], AbsoluteThickness[0.5], 
     LineBox[{{5.656320172600433, -3.4231682308452736`}, {
      5.638641215965254, -3.462072466565094}}]}, 
    {Hue[0.6407192778624254], AbsoluteThickness[0.5], 
     LineBox[{{5.638641215965254, -3.462072466565094}, {
      5.513356881400975, -3.6820117133582566`}}]}, 
    {Hue[0.47495468367963123`], AbsoluteThickness[0.5], 
     LineBox[{{6.848439921609096, -4.060339923633495}, {
      6.810830744740259, -4.141818437470286}}]}, 
    {Hue[0.4751628084812073], AbsoluteThickness[0.5], 
     LineBox[{{6.810830744740259, -4.141818437470286}, {
      6.672843912771113, -4.421741734640321}}]}, 
    {Hue[0.4508442405612552], AbsoluteThickness[0.5], 
     LineBox[{{2.690471506059175, -1.3392204971550752`}, {
      2.6285767423124753`, -1.5008821935487953`}}]}, 
    {Hue[0.4552266490388204], AbsoluteThickness[0.5], 
     LineBox[{{2.6285767423124753`, -1.5008821935487953`}, {
      2.543596105985032, -1.6363224572962705`}}]}, 
    {Hue[0.6673508374438394], AbsoluteThickness[0.5], 
     LineBox[{{2.543596105985032, -1.6363224572962705`}, {
      2.3849479729325935`, -1.616409057948625}}]}, 
    {Hue[0.6203207765217559], AbsoluteThickness[0.5], 
     LineBox[{{3.7253197317359628`, -1.9226930520229284`}, {
      3.5646833574010808`, -2.3816995048095375`}}]}, 
    {Hue[0.6205052536230327], AbsoluteThickness[0.5], 
     LineBox[{{3.5646833574010808`, -2.3816995048095375`}, {
      3.461323438055423, -2.6714090529866406`}}]}, 
    {Hue[0.6966407024743507], AbsoluteThickness[0.5], 
     LineBox[{{3.9291983209491628`, -2.1531670824734057`}, {
      3.9174504507025527`, -2.180336851323488}}]}, 
    {Hue[0.6975147279922088], AbsoluteThickness[0.5], 
     LineBox[{{3.9174504507025527`, -2.180336851323488}, {
      3.822596609712692, -2.3474960651091377`}}]}, 
    {Hue[0.6857693112764779], AbsoluteThickness[0.5], 
     LineBox[{{2.81530561668199, -1.3819969648385397`}, {
      2.8545555271329692`, -1.5348882764083038`}}]}, 
    {Hue[0.6284575080501417], AbsoluteThickness[0.5], 
     LineBox[{{7.396143214128973, 3.5870377413582615`}, {7.403854419465872, 
      3.5837227126396174`}}]}, 
    {Hue[0.6286771208575923], AbsoluteThickness[0.5], 
     LineBox[{{7.403854419465872, 3.5837227126396174`}, {7.6717827922214505`, 
      3.458681008403295}}]}, 
    {Hue[0.6776109997730033], AbsoluteThickness[0.5], 
     LineBox[{{7.951636345348979, 0.7137730150913497}, {7.984278723080915, 
      0.6741966303886024}}]}, 
    {Hue[0.6778926399945416], AbsoluteThickness[0.5], 
     LineBox[{{7.984278723080915, 0.6741966303886024}, {8.165363385013364, 
      0.43148520809964575`}}]}, 
    {Hue[0.5458666931056584], AbsoluteThickness[0.5], 
     LineBox[{{8.140126437614487, -1.1365465124910128`}, {
      8.14040047723197, -1.138381443590131}}]}, 
    {Hue[0.5464626386554406], AbsoluteThickness[0.5], 
     LineBox[{{8.14040047723197, -1.138381443590131}, {
      8.194207568944458, -1.3608744551039436`}}]}, 
    {Hue[0.6843941198094641], AbsoluteThickness[0.5], 
     LineBox[{{6.941744632947714, -1.6665184367310864`}, {
      6.700922205001355, -2.0974585618943045`}}]}, 
    {Hue[0.6884568744240289], AbsoluteThickness[0.5], 
     LineBox[{{6.700922205001355, -2.0974585618943045`}, {
      6.649765790317664, -2.252140099420774}}]}, 
    {Hue[0.5716611740533131], AbsoluteThickness[0.5], 
     LineBox[{{5.1971633524093805`, -1.411110251959242}, {
      5.171495430089541, -1.571344055739821}}]}, 
    {Hue[0.5721562129477288], AbsoluteThickness[0.5], 
     LineBox[{{5.171495430089541, -1.571344055739821}, {
      5.149893895290433, -1.8437437694677532`}}]}, 
    {Hue[0.5967721990131247], AbsoluteThickness[0.5], 
     LineBox[{{2.3141454695633144`, -0.0009303562125356213}, {
      1.9827536820664209`, -0.29313647247103203`}}]}, 
    {Hue[0.5980061884157732], AbsoluteThickness[0.5], 
     LineBox[{{1.9827536820664209`, -0.29313647247103203`}, {
      1.8423080769447733`, -0.45235163317290616`}}]}, 
    {Hue[0.6454865178185784], AbsoluteThickness[0.5], 
     LineBox[{{2.5359324408170836`, 2.2629931975671616`}, {2.373788782868912, 
      2.2380415331809025`}}]}, 
    {Hue[0.6456727844431853], AbsoluteThickness[0.5], 
     LineBox[{{2.373788782868912, 2.2380415331809025`}, {2.0947908614681428`, 
      2.1924778196150227`}}]}, 
    {Hue[0.6399821618026486], AbsoluteThickness[0.5], 
     LineBox[{{2.3882353982456106`, -1.1810577998572418`}, {
      2.3688702250328464`, -1.200246830713806}}]}, 
    {Hue[0.6401813181158459], AbsoluteThickness[0.5], 
     LineBox[{{2.3688702250328464`, -1.200246830713806}, {
      2.1535509058181757`, -1.4225705938373867`}}]}, 
    {Hue[0.6989051792142249], AbsoluteThickness[0.5], 
     LineBox[{{7.942643768053254, -1.6854126608445184`}, {
      8.06431006465274, -1.7631830852736665`}}]}, 
    {Hue[0.699327682852922], AbsoluteThickness[0.5], 
     LineBox[{{8.06431006465274, -1.7631830852736665`}, {
      8.282380208947151, -1.8815251178425596`}}]}, 
    {Hue[0.6797387620572375], AbsoluteThickness[0.5], 
     LineBox[{{2.3269097514349193`, 1.4116366195782286`}, {
      2.0829310118783844`, 1.3702071945206948`}}]}, 
    {Hue[0.6878440630541756], AbsoluteThickness[0.5], 
     LineBox[{{2.0829310118783844`, 1.3702071945206948`}, {1.900105784987952, 
      1.382113841150748}}]}, 
    {Hue[0.6806684429468693], AbsoluteThickness[0.5], 
     LineBox[{{4.883148682769548, 1.3764357895408095`}, {4.852140342572451, 
      1.35022068032724}}]}, 
    {Hue[0.6808671848709531], AbsoluteThickness[0.5], 
     LineBox[{{4.852140342572451, 1.35022068032724}, {4.651262681609272, 
      1.1872731524470477`}}]}, 
    {Hue[0.6698860992111028], AbsoluteThickness[0.5], 
     LineBox[{{7.048745360448051, -0.5896979328317056}, {
      6.9629454351588285`, -0.8743022802455626}}]}, 
    {Hue[0.6700929256216313], AbsoluteThickness[0.5], 
     LineBox[{{6.9629454351588285`, -0.8743022802455626}, {
      6.8750291013448415`, -1.1416594337420962`}}]}, 
    {Hue[0.6857446756996843], AbsoluteThickness[0.5], 
     LineBox[{{2.1178173572235908`, 1.1177483207118895`}, {
      2.1143800737692033`, 1.1167916407522147`}}]}, 
    {Hue[0.6860289809023866], AbsoluteThickness[0.5], 
     LineBox[{{2.1143800737692033`, 1.1167916407522147`}, {
      1.8238439393769457`, 1.0202765181166027`}}]}, 
    {Hue[0.6711792110140086], AbsoluteThickness[0.5], 
     LineBox[{{2.4018199732914707`, -2.10354895449524}, {
      2.391765974104575, -2.1104128801252755`}}]}, 
    {Hue[0.6713831132522274], AbsoluteThickness[0.5], 
     LineBox[{{2.391765974104575, -2.1104128801252755`}, {
      2.122311827895533, -2.3037455073972075`}}]}, 
    {Hue[0.6452042487194223], AbsoluteThickness[0.5], 
     LineBox[{{3.134775657365511, -2.2162878220725832`}, {
      2.86782894591727, -2.2451615561793226`}}]}, 
    {Hue[0.6454214936329451], AbsoluteThickness[0.5], 
     LineBox[{{2.86782894591727, -2.2451615561793226`}, {
      2.5579443007284106`, -2.269403900700476}}]}, 
    {Hue[0.6764436534986413], AbsoluteThickness[0.5], 
     LineBox[{{4.099114995086564, -2.141213723451201}, {
      4.059116012474011, -2.136628299514328}}]}, 
    {Hue[0.6771393704466223], AbsoluteThickness[0.5], 
     LineBox[{{4.059116012474011, -2.136628299514328}, {
      3.862287847875723, -2.0944986984044083`}}]}, 
    {Hue[0.6678731215052205], AbsoluteThickness[0.5], 
     LineBox[{{3.975437887865956, 2.127856256636735}, {3.4230846793690546`, 
      2.8759319963892263`}}]}, 
    {Hue[0.6709779881687814], AbsoluteThickness[0.5], 
     LineBox[{{3.4230846793690546`, 2.8759319963892263`}, {3.339779505009526, 
      3.0434863985286267`}}]}, 
    {Hue[0.6643349411986337], AbsoluteThickness[0.5], 
     LineBox[{{5.092301143738348, -4.23590309475546}, {
      4.988579227331983, -4.340452516713437}}]}, 
    {Hue[0.6647974069045111], AbsoluteThickness[0.5], 
     LineBox[{{4.988579227331983, -4.340452516713437}, {
      4.815103198866747, -4.5442523639535395`}}]}, 
    {Hue[0.6407230280237852], AbsoluteThickness[0.5], 
     LineBox[{{6.56398960641994, -3.7938934235005783`}, {
      6.543285241504151, -3.852149876543363}}]}, 
    {Hue[0.6409071293681822], AbsoluteThickness[0.5], 
     LineBox[{{6.543285241504151, -3.852149876543363}, {
      6.434314923225942, -4.16383908087726}}]}, 
    {Hue[0.4755331444283334], AbsoluteThickness[0.5], 
     LineBox[{{4.136185292466732, -1.8815145244865437`}, {
      4.080829143176823, -1.940417865237979}}]}, 
    {Hue[0.4757197305722944], AbsoluteThickness[0.5], 
     LineBox[{{4.080829143176823, -1.940417865237979}, {
      3.895683725659957, -2.133657255674023}}]}, 
    {Hue[0.5896521398305313], AbsoluteThickness[0.5], 
     LineBox[{{3.652329238880699, 2.7398869964278223`}, {3.4438157125500233`, 
      2.7088351887185578`}}]}, 
    {Hue[0.5899462626759655], AbsoluteThickness[0.5], 
     LineBox[{{3.4438157125500233`, 2.7088351887185578`}, {
      3.1602250446055833`, 2.681392119152333}}]}, 
    {Hue[0.5977945710160378], AbsoluteThickness[0.5], 
     LineBox[{{3.33269357193641, 1.4407580715476331`}, {3.1302201679194464`, 
      1.4074849028546426`}}]}, 
    {Hue[0.5983624794768422], AbsoluteThickness[0.5], 
     LineBox[{{3.1302201679194464`, 1.4074849028546426`}, {2.861739231903491, 
      1.3869725520795433`}}]}, 
    {Hue[0.58165972889916], AbsoluteThickness[0.5], 
     LineBox[{{3.6496634334844873`, 2.7681090417856065`}, {3.451260765305006, 
      2.791653704045864}}]}, 
    {Hue[0.5818743077838583], AbsoluteThickness[0.5], 
     LineBox[{{3.451260765305006, 2.791653704045864}, {3.1468993997360766`, 
      2.818992318919108}}]}, 
    {Hue[0.4476461936894539], AbsoluteThickness[0.5], 
     LineBox[{{8.202925738185447, -3.42230821353291}, {
      8.248112007121396, -3.615283735849963}}]}, 
    {Hue[0.44782931984860536`], AbsoluteThickness[0.5], 
     LineBox[{{8.248112007121396, -3.615283735849963}, {
      8.319354478030785, -3.9202359941616067`}}]}, 
    {Hue[0.5498740387921611], AbsoluteThickness[0.5], 
     LineBox[{{4.658065848402106, -0.8129543347630941}, {
      4.424263155239173, -0.7507918497619795}}]}, 
    {Hue[0.5501276554693967], AbsoluteThickness[0.5], 
     LineBox[{{4.424263155239173, -0.7507918497619795}, {
      4.144075751525485, -0.6886994227943991}}]}, 
    {Hue[0.6413425662215942], AbsoluteThickness[0.5], 
     LineBox[{{5.513356881400975, -3.6820117133582566`}, {
      5.4472361063926655`, -3.7768066801453966`}}]}, 
    {Hue[0.64223909182631], AbsoluteThickness[0.5], 
     LineBox[{{5.4472361063926655`, -3.7768066801453966`}, {
      5.301047359768452, -3.944042993187486}}]}, 
    {Hue[0.47537093328278335`], AbsoluteThickness[0.5], 
     LineBox[{{6.672843912771113, -4.421741734640321}, {
      6.659903152929509, -4.446385810830566}}]}, 
    {Hue[0.4757089555999912], AbsoluteThickness[0.5], 
     LineBox[{{6.659903152929509, -4.446385810830566}, {
      6.515057093215638, -4.686380860885859}}]}, 
    {Hue[0.6629684289662717], AbsoluteThickness[0.5], 
     LineBox[{{2.6285767423124753`, -1.5008821935487953`}, {
      2.6594651458304117`, -1.5781593961122107`}}]}, 
    {Hue[0.6631516267852688], AbsoluteThickness[0.5], 
     LineBox[{{2.6594651458304117`, -1.5781593961122107`}, {
      2.7823370711004873`, -1.8868877195185065`}}]}, 
    {Hue[0.4596090575163852], AbsoluteThickness[0.5], 
     LineBox[{{2.543596105985032, -1.6363224572962705`}, {
      2.3965708830209524`, -1.7925522233475382`}}]}, 
    {Hue[0.47639870285477626`], AbsoluteThickness[0.5], 
     LineBox[{{2.3965708830209524`, -1.7925522233475382`}, {
      2.279009699303809, -1.8618269030697097`}}]}, 
    {Hue[0.5949094149220885], AbsoluteThickness[0.5], 
     LineBox[{{2.279009699303809, -1.8618269030697097`}, {
      2.154464827177917, -1.8060757775677903`}}]}, 
    {Hue[0.6717332459214043], AbsoluteThickness[0.5], 
     LineBox[{{2.3849479729325935`, -1.616409057948625}, {
      2.382855125444696, -1.6157165107911804`}}]}, 
    {Hue[0.6734707053003216], AbsoluteThickness[0.5], 
     LineBox[{{2.382855125444696, -1.6157165107911804`}, {
      2.1992812968316877`, -1.582953166762202}}]}, 
    {Hue[0.6206897307243096], AbsoluteThickness[0.5], 
     LineBox[{{3.461323438055423, -2.6714090529866406`}, {
      3.4057873386829636`, -2.8241461926857054`}}]}, 
    {Hue[0.62156545135443], AbsoluteThickness[0.5], 
     LineBox[{{3.4057873386829636`, -2.8241461926857054`}, {
      3.351553571969628, -3.045170916975937}}]}, 
    {Hue[0.6983887535100668], AbsoluteThickness[0.5], 
     LineBox[{{3.822596609712692, -2.3474960651091377`}, {
      3.623646102364506, -2.623732783245161}}]}, 
    {Hue[0.628896733665043], AbsoluteThickness[0.5], 
     LineBox[{{7.6717827922214505`, 3.458681008403295}, {7.772022016348352, 
      3.40810360023285}}]}, 
    {Hue[0.643943210276023], AbsoluteThickness[0.5], 
     LineBox[{{7.772022016348352, 3.40810360023285}, {7.877126940960202, 
      3.311600672087688}}]}, 
    {Hue[0.6781742802160801], AbsoluteThickness[0.5], 
     LineBox[{{8.165363385013364, 0.43148520809964575`}, {8.203554124833435, 
      0.37473041028837395`}}]}, 
    {Hue[0.6784491491004498], AbsoluteThickness[0.5], 
     LineBox[{{8.203554124833435, 0.37473041028837395`}, {8.353958111122084, 
      0.12673605509693064`}}]}, 
    {Hue[0.5470585842052231], AbsoluteThickness[0.5], 
     LineBox[{{8.194207568944458, -1.3608744551039436`}, {
      8.280785062159566, -1.6167105668714303`}}]}, 
    {Hue[0.5477028272410148], AbsoluteThickness[0.5], 
     LineBox[{{8.280785062159566, -1.6167105668714303`}, {
      8.333292854791026, -1.8375753072924508`}}]}, 
    {Hue[0.6925196290385938], AbsoluteThickness[0.5], 
     LineBox[{{6.649765790317664, -2.252140099420774}, {
      6.642168701414975, -2.310614675154861}}]}, 
    {Hue[0.6927925717775251], AbsoluteThickness[0.5], 
     LineBox[{{6.642168701414975, -2.310614675154861}, {
      6.586852865388811, -2.621865656387353}}]}, 
    {Hue[0.5726512518421444], AbsoluteThickness[0.5], 
     LineBox[{{5.149893895290433, -1.8437437694677532`}, {
      5.150028337380061, -2.0794393420918182`}}]}, 
    {Hue[0.5729042508387178], AbsoluteThickness[0.5], 
     LineBox[{{5.150028337380061, -2.0794393420918182`}, {
      5.1633437138595895`, -2.3949405336234557`}}]}, 
    {Hue[0.6458590510677922], AbsoluteThickness[0.5], 
     LineBox[{{2.0947908614681428`, 2.1924778196150227`}, {
      2.0375417428426617`, 2.1825871052305135`}}]}, 
    {Hue[0.6403804744290433], AbsoluteThickness[0.5], 
     LineBox[{{2.1535509058181757`, -1.4225705938373867`}, {
      2.1410113125605466`, -1.4360627430792223`}}]}, 
    {Hue[0.6407001951020924], AbsoluteThickness[0.5], 
     LineBox[{{2.1410113125605466`, -1.4360627430792223`}, {
      1.9679775262061567`, -1.6446457138116022`}}]}, 
    {Hue[0.6810659267950367], AbsoluteThickness[0.5], 
     LineBox[{{4.651262681609272, 1.1872731524470477`}, {4.613254550733855, 
      1.1577011222800127`}}]}, 
    {Hue[0.6812841010018914], AbsoluteThickness[0.5], 
     LineBox[{{4.613254550733855, 1.1577011222800127`}, {4.34950135708816, 
      0.9394537482734076}}]}, 
    {Hue[0.6702997520321597], AbsoluteThickness[0.5], 
     LineBox[{{6.8750291013448415`, -1.1416594337420962`}, {
      6.862194451580757, -1.177646071358585}}]}, 
    {Hue[0.6705181800462715], AbsoluteThickness[0.5], 
     LineBox[{{6.862194451580757, -1.177646071358585}, {
      6.778138158256813, -1.4378788033585193`}}]}, 
    {Hue[0.6715870154904463], AbsoluteThickness[0.5], 
     LineBox[{{2.122311827895533, -2.3037455073972075`}, {
      2.0846919533166233`, -2.3320911188318774`}}]}, 
    {Hue[0.6718619405427748], AbsoluteThickness[0.5], 
     LineBox[{{2.0846919533166233`, -2.3320911188318774`}, {
      1.8478535170951083`, -2.5287092081334865`}}]}, 
    {Hue[0.6456387385464681], AbsoluteThickness[0.5], 
     LineBox[{{2.5579443007284106`, -2.269403900700476}, {
      2.4442099759061167`, -2.2749127608980144`}}]}, 
    {Hue[0.6458485717952915], AbsoluteThickness[0.5], 
     LineBox[{{2.4442099759061167`, -2.2749127608980144`}, {
      2.1147820855425192`, -2.2821698249394347`}}]}, 
    {Hue[0.6778350873946032], AbsoluteThickness[0.5], 
     LineBox[{{3.862287847875723, -2.0944986984044083`}, {
      3.6469436431969653`, -2.026091854644832}}]}, 
    {Hue[0.6780183391550341], AbsoluteThickness[0.5], 
     LineBox[{{3.6469436431969653`, -2.026091854644832}, {
      3.3899699046641167`, -1.9450005602570204`}}]}, 
    {Hue[0.6740828548323422], AbsoluteThickness[0.5], 
     LineBox[{{3.339779505009526, 3.0434863985286267`}, {3.315343322038069, 
      3.126349591829431}}]}, 
    {Hue[0.674268526783114], AbsoluteThickness[0.5], 
     LineBox[{{3.315343322038069, 3.126349591829431}, {3.2238502271956717`, 
      3.427387713933632}}]}, 
    {Hue[0.6410912307125791], AbsoluteThickness[0.5], 
     LineBox[{{6.434314923225942, -4.16383908087726}, {
      6.400555111761498, -4.262022410720735}}]}, 
    {Hue[0.6430633885141018], AbsoluteThickness[0.5], 
     LineBox[{{6.400555111761498, -4.262022410720735}, {
      6.302464808170437, -4.450050301458311}}]}, 
    {Hue[0.47590631671625533`], AbsoluteThickness[0.5], 
     LineBox[{{3.895683725659957, -2.133657255674023}, {
      3.894363137934695, -2.1350092208711593`}}]}, 
    {Hue[0.4760956570648765], AbsoluteThickness[0.5], 
     LineBox[{{3.894363137934695, -2.1350092208711593`}, {
      3.7055343143627244`, -2.3234015063995175`}}]}, 
    {Hue[0.5902403855213996], AbsoluteThickness[0.5], 
     LineBox[{{3.1602250446055833`, 2.681392119152333}, {3.088276325440507, 
      2.678144610161838}}]}, 
    {Hue[0.5946359786763061], AbsoluteThickness[0.5], 
     LineBox[{{3.088276325440507, 2.678144610161838}, {2.892263836527015, 
      2.630179466514019}}]}, 
    {Hue[0.5989303879376464], AbsoluteThickness[0.5], 
     LineBox[{{2.861739231903491, 1.3869725520795433`}, {2.8189310068960913`, 
      1.3874165313898386`}}]}, 
    {Hue[0.6045913323621981], AbsoluteThickness[0.5], 
     LineBox[{{2.8189310068960913`, 1.3874165313898386`}, {
      2.6407767730931617`, 1.3513135172147952`}}]}, 
    {Hue[0.5820888866685566], AbsoluteThickness[0.5], 
     LineBox[{{3.1468993997360766`, 2.818992318919108}, {2.859142571987567, 
      2.8365806538130016`}}]}, 
    {Hue[0.5824916305523856], AbsoluteThickness[0.5], 
     LineBox[{{2.859142571987567, 2.8365806538130016`}, {2.597929550289893, 
      2.8344956544945057`}}]}, 
    {Hue[0.4480124460077568], AbsoluteThickness[0.5], 
     LineBox[{{8.319354478030785, -3.9202359941616067`}, {
      8.361110025060112, -4.099381638041829}}]}, 
    {Hue[0.4483998285795804], AbsoluteThickness[0.5], 
     LineBox[{{8.361110025060112, -4.099381638041829}, {
      8.412962572471049, -4.416584131883879}}]}, 
    {Hue[0.5503812721466321], AbsoluteThickness[0.5], 
     LineBox[{{4.144075751525485, -0.6886994227943991}, {
      3.915434832123526, -0.647965335292557}}]}, 
    {Hue[0.5509399125287269], AbsoluteThickness[0.5], 
     LineBox[{{3.915434832123526, -0.647965335292557}, {
      3.6767553638289288`, -0.6263039518208819}}]}, 
    {Hue[0.643135617431026], AbsoluteThickness[0.5], 
     LineBox[{{5.301047359768452, -3.944042993187486}, {
      5.1473790497722725`, -4.085249162367698}}]}, 
    {Hue[0.6494973331039944], AbsoluteThickness[0.5], 
     LineBox[{{5.1473790497722725`, -4.085249162367698}, {
      5.017777290759835, -4.160408289752661}}]}, 
    {Hue[0.6633348246042658], AbsoluteThickness[0.5], 
     LineBox[{{2.7823370711004873`, -1.8868877195185065`}, {
      2.9520001666773728`, -2.3150268609912428`}}]}, 
    {Hue[0.663539403388908], AbsoluteThickness[0.5], 
     LineBox[{{2.9520001666773728`, -2.3150268609912428`}, {
      3.068991289281188, -2.631997311602204}}]}, 
    {Hue[0.5781197695836926], AbsoluteThickness[0.5], 
     LineBox[{{2.3965708830209524`, -1.7925522233475382`}, {
      2.3818224814643028`, -1.8307828693178243`}}]}, 
    {Hue[0.5795577002800348], AbsoluteThickness[0.5], 
     LineBox[{{2.3818224814643028`, -1.8307828693178243`}, {
      2.3331305227023598`, -2.0340983190730886`}}]}, 
    {Hue[0.4931883481931661], AbsoluteThickness[0.5], 
     LineBox[{{2.279009699303809, -1.8618269030697097`}, {
      2.183786388996578, -1.8860639242246482`}}]}, 
    {Hue[0.49337771590141294`], AbsoluteThickness[0.5], 
     LineBox[{{2.183786388996578, -1.8860639242246482`}, {
      1.8575330775666872`, -1.973609833425109}}]}, 
    {Hue[0.6116990602604782], AbsoluteThickness[0.5], 
     LineBox[{{2.154464827177917, -1.8060757775677903`}, {
      1.9635584338880692`, -1.6439212922441218`}}]}, 
    {Hue[0.6135016210539022], AbsoluteThickness[0.5], 
     LineBox[{{1.9635584338880692`, -1.6439212922441218`}, {
      1.8331971455187728`, -1.49581634012526}}]}, 
    {Hue[0.675208164679239], AbsoluteThickness[0.5], 
     LineBox[{{2.1992812968316877`, -1.582953166762202}, {
      2.1201065284469833`, -1.5802870100530664`}}]}, 
    {Hue[0.6755609594904822], AbsoluteThickness[0.5], 
     LineBox[{{2.1201065284469833`, -1.5802870100530664`}, {
      1.847484571749867, -1.5541627057341192`}}]}, 
    {Hue[0.6224411719845504], AbsoluteThickness[0.5], 
     LineBox[{{3.351553571969628, -3.045170916975937}, {
      3.337120111113439, -3.153467306216698}}]}, 
    {Hue[0.6226504269374717], AbsoluteThickness[0.5], 
     LineBox[{{3.337120111113439, -3.153467306216698}, {
      3.289440215654356, -3.451588365206402}}]}, 
    {Hue[0.6589896868870025], AbsoluteThickness[0.5], 
     LineBox[{{7.877126940960202, 3.311600672087688}, {7.954147366881353, 
      3.186700566472998}}]}, 
    {Hue[0.6592016807924593], AbsoluteThickness[0.5], 
     LineBox[{{7.954147366881353, 3.186700566472998}, {8.103699191777398, 
      2.928621355054173}}]}, 
    {Hue[0.5483470702768064], AbsoluteThickness[0.5], 
     LineBox[{{8.333292854791026, -1.8375753072924508`}, {
      8.37502059150578, -2.132620862057291}}]}, 
    {Hue[0.550416242718447], AbsoluteThickness[0.5], 
     LineBox[{{8.37502059150578, -2.132620862057291}, {
      8.372609199076223, -2.338139090646819}}]}, 
    {Hue[0.6930655145164563], AbsoluteThickness[0.5], 
     LineBox[{{6.586852865388811, -2.621865656387353}, {
      6.5283406794940015`, -2.8804016821273737`}}]}, 
    {Hue[0.6932510062179943], AbsoluteThickness[0.5], 
     LineBox[{{6.5283406794940015`, -2.8804016821273737`}, {
      6.455915662084558, -3.1889427043325047`}}]}, 
    {Hue[0.5731572498352913], AbsoluteThickness[0.5], 
     LineBox[{{5.1633437138595895`, -2.3949405336234557`}, {
      5.177189268849019, -2.5598001098368637`}}]}, 
    {Hue[0.5733663780166944], AbsoluteThickness[0.5], 
     LineBox[{{5.177189268849019, -2.5598001098368637`}, {
      5.2141051080821414`, -2.8945932194192343`}}]}, 
    {Hue[0.6815022752087458], AbsoluteThickness[0.5], 
     LineBox[{{4.34950135708816, 0.9394537482734076}, {4.308246115973363, 
      0.9031733340704978}}]}, 
    {Hue[0.6818332088633584], AbsoluteThickness[0.5], 
     LineBox[{{4.308246115973363, 0.9031733340704978}, {4.102079489920942, 
      0.6993790946992785}}]}, 
    {Hue[0.6707366080603833], AbsoluteThickness[0.5], 
     LineBox[{{6.778138158256813, -1.4378788033585193`}, {
      6.730084543669796, -1.6035765617551552`}}]}, 
    {Hue[0.6709330336928004], AbsoluteThickness[0.5], 
     LineBox[{{6.730084543669796, -1.6035765617551552`}, {
      6.648066431511518, -1.8677482212282193`}}]}, 
    {Hue[0.6782015909154648], AbsoluteThickness[0.5], 
     LineBox[{{3.3899699046641167`, -1.9450005602570204`}, {
      2.876920695888101, -1.784177655015215}}]}, 
    {Hue[0.6783847230077492], AbsoluteThickness[0.5], 
     LineBox[{{2.876920695888101, -1.784177655015215}, {
      2.5598910142943008`, -1.6845745240638166`}}]}, 
    {Hue[0.6744541987338858], AbsoluteThickness[0.5], 
     LineBox[{{3.2238502271956717`, 3.427387713933632}, {3.164101554416602, 
      3.6182791304508584`}}]}, 
    {Hue[0.6748295146168196], AbsoluteThickness[0.5], 
     LineBox[{{3.164101554416602, 3.6182791304508584`}, {3.101985669129406, 
      3.8742308283456834`}}]}, 
    {Hue[0.4762849974134975], AbsoluteThickness[0.5], 
     LineBox[{{3.7055343143627244`, -2.3234015063995175`}, {
      3.6126373039872774`, -2.4137232822676298`}}]}, 
    {Hue[0.47646828064178315`], AbsoluteThickness[0.5], 
     LineBox[{{3.6126373039872774`, -2.4137232822676298`}, {
      3.3922309432078155`, -2.628930241020917}}]}, 
    {Hue[0.5990315718312124], AbsoluteThickness[0.5], 
     LineBox[{{2.892263836527015, 2.630179466514019}, {2.656542139953466, 
      2.52067965515237}}]}, 
    {Hue[0.5993567045305944], AbsoluteThickness[0.5], 
     LineBox[{{2.656542139953466, 2.52067965515237}, {2.4021847771895124`, 
      2.4197950374793806`}}]}, 
    {Hue[0.6102522767867494], AbsoluteThickness[0.5], 
     LineBox[{{2.6407767730931617`, 1.3513135172147952`}, {
      2.4100475676243165`, 1.2509610945770788`}}]}, 
    {Hue[0.610455060668061], AbsoluteThickness[0.5], 
     LineBox[{{2.4100475676243165`, 1.2509610945770788`}, {2.109843693225373, 
      1.128427125877418}}]}, 
    {Hue[0.5828943744362148], AbsoluteThickness[0.5], 
     LineBox[{{2.597929550289893, 2.8344956544945057`}, {2.4952292852444606`, 
      2.826571044663803}}]}, 
    {Hue[0.6088358492320624], AbsoluteThickness[0.5], 
     LineBox[{{2.4952292852444606`, 2.826571044663803}, {2.358105900150826, 
      2.859797487829117}}]}, 
    {Hue[0.6994179834249068], AbsoluteThickness[0.5], 
     LineBox[{{2.358105900150826, 2.859797487829117}, {2.301619792494541, 
      2.9890883958884147`}}]}, 
    {Hue[0.5514985529108214], AbsoluteThickness[0.5], 
     LineBox[{{3.6767553638289288`, -0.6263039518208819}, {
      3.660707579059717, -0.6262284193186336}}]}, 
    {Hue[0.5518733619186962], AbsoluteThickness[0.5], 
     LineBox[{{3.660707579059717, -0.6262284193186336}, {
      3.380318304137456, -0.6066002737367311}}]}, 
    {Hue[0.6558590487769625], AbsoluteThickness[0.5], 
     LineBox[{{5.017777290759835, -4.160408289752661}, {
      4.871824473011491, -4.206822074429016}}]}, 
    {Hue[0.6560558405259831], AbsoluteThickness[0.5], 
     LineBox[{{4.871824473011491, -4.206822074429016}, {
      4.566101814353904, -4.310487669884657}}]}, 
    {Hue[0.6637439821735502], AbsoluteThickness[0.5], 
     LineBox[{{3.068991289281188, -2.631997311602204}, {
      3.084678752134776, -2.677816872230564}}]}, 
    {Hue[0.6644846926086467], AbsoluteThickness[0.5], 
     LineBox[{{3.084678752134776, -2.677816872230564}, {
      3.186830152915206, -2.9007350279240947`}}]}, 
    {Hue[0.5809956309763771], AbsoluteThickness[0.5], 
     LineBox[{{2.3331305227023598`, -2.0340983190730886`}, {
      2.328960687100035, -2.0748605967363356`}}]}, 
    {Hue[0.5811924649254615], AbsoluteThickness[0.5], 
     LineBox[{{2.328960687100035, -2.0748605967363356`}, {
      2.2886130596423895`, -2.406696796436617}}]}, 
    {Hue[0.6228596818903932], AbsoluteThickness[0.5], 
     LineBox[{{3.289440215654356, -3.451588365206402}, {
      3.265160825292077, -3.581552939267163}}]}, 
    {Hue[0.6230802268653091], AbsoluteThickness[0.5], 
     LineBox[{{3.265160825292077, -3.581552939267163}, {
      3.21414977933437, -3.9108801651768457`}}]}, 
    {Hue[0.6594136746979161], AbsoluteThickness[0.5], 
     LineBox[{{8.103699191777398, 2.928621355054173}, {8.12458174917919, 
      2.890196586484368}}]}, 
    {Hue[0.6596076882264308], AbsoluteThickness[0.5], 
     LineBox[{{8.12458174917919, 2.890196586484368}, {8.301227485802736, 
      2.5779427149896432`}}]}, 
    {Hue[0.5524854151600876], AbsoluteThickness[0.5], 
     LineBox[{{8.372609199076223, -2.338139090646819}, {
      8.328067160359495, -2.6073615446193075`}}]}, 
    {Hue[0.5526710230269669], AbsoluteThickness[0.5], 
     LineBox[{{8.328067160359495, -2.6073615446193075`}, {
      8.264249979302264, -2.9744161410151913`}}]}, 
    {Hue[0.6934364979195323], AbsoluteThickness[0.5], 
     LineBox[{{6.455915662084558, -3.1889427043325047`}, {
      6.424566515033717, -3.317857071873617}}]}, 
    {Hue[0.6938299223755943], AbsoluteThickness[0.5], 
     LineBox[{{6.424566515033717, -3.317857071873617}, {
      6.380694900367936, -3.572269944766505}}]}, 
    {Hue[0.5735755061980976], AbsoluteThickness[0.5], 
     LineBox[{{5.2141051080821414`, -2.8945932194192343`}, {
      5.240643944512358, -3.0887371814349898`}}]}, 
    {Hue[0.5737601432364442], AbsoluteThickness[0.5], 
     LineBox[{{5.240643944512358, -3.0887371814349898`}, {
      5.2846673386373135`, -3.42689019718041}}]}, 
    {Hue[0.6821641425179711], AbsoluteThickness[0.5], 
     LineBox[{{4.102079489920942, 0.6993790946992785}, {4.087892909975138, 
      0.6836188491282627}}]}, 
    {Hue[0.6823552190956946], AbsoluteThickness[0.5], 
     LineBox[{{4.087892909975138, 0.6836188491282627}, {3.8723596812644248`, 
      0.43704591406790944`}}]}, 
    {Hue[0.6711294593252175], AbsoluteThickness[0.5], 
     LineBox[{{6.648066431511518, -1.8677482212282193`}, {
      6.633457387841712, -1.9118605919964782`}}]}, 
    {Hue[0.6733925220404379], AbsoluteThickness[0.5], 
     LineBox[{{6.633457387841712, -1.9118605919964782`}, {
      6.609319392222294, -2.0588667500189346`}}]}, 
    {Hue[0.6785678551000334], AbsoluteThickness[0.5], 
     LineBox[{{2.5598910142943008`, -1.6845745240638166`}, {
      2.3957522094877737`, -1.632889265754243}}]}, 
    {Hue[0.6794246598778245], AbsoluteThickness[0.5], 
     LineBox[{{2.3957522094877737`, -1.632889265754243}, {
      2.1864040273262773`, -1.5908839168081363`}}]}, 
    {Hue[0.47665156387006885`], AbsoluteThickness[0.5], 
     LineBox[{{3.3922309432078155`, -2.628930241020917}, {
      3.373086493082613, -2.647702492049789}}]}, 
    {Hue[0.476843975477795], AbsoluteThickness[0.5], 
     LineBox[{{3.373086493082613, -2.647702492049789}, {
      3.135354215431099, -2.873588876929993}}]}, 
    {Hue[0.5996818372299765], AbsoluteThickness[0.5], 
     LineBox[{{2.4021847771895124`, 2.4197950374793806`}, {
      2.2508515589624474`, 2.369591616676134}}]}, 
    {Hue[0.602377029214115], AbsoluteThickness[0.5], 
     LineBox[{{2.2508515589624474`, 2.369591616676134}, {2.105089716554118, 
      2.2924074478347602`}}]}, 
    {Hue[0.6106578445493726], AbsoluteThickness[0.5], 
     LineBox[{{2.109843693225373, 1.128427125877418}, {2.1045353568776313`, 
      1.1263999011482146`}}]}, 
    {Hue[0.6109360019354945], AbsoluteThickness[0.5], 
     LineBox[{{2.1045353568776313`, 1.1263999011482146`}, {
      1.8227355325169223`, 1.0030155268912893`}}]}, 
    {Hue[0.6734765086290531], AbsoluteThickness[0.5], 
     LineBox[{{2.4952292852444606`, 2.826571044663803}, {2.3308064325818236`, 
      2.763043043820169}}]}, 
    {Hue[0.6737677161111548], AbsoluteThickness[0.5], 
     LineBox[{{2.3308064325818236`, 2.763043043820169}, {2.107523011322846, 
      2.6895580339560903`}}]}, 
    {Hue[0.6347773240279074], AbsoluteThickness[0.5], 
     LineBox[{{2.358105900150826, 2.859797487829117}, {2.158132977113625, 
      2.9830817346584992`}}]}, 
    {Hue[0.6351566978856993], AbsoluteThickness[0.5], 
     LineBox[{{2.158132977113625, 2.9830817346584992`}, {1.9620053601186829`, 
      3.0868466436547135`}}]}, 
    {Hue[0.552248170926571], AbsoluteThickness[0.5], 
     LineBox[{{3.380318304137456, -0.6066002737367311}, {
      3.1133430358425915`, -0.5703185624998235}}]}, 
    {Hue[0.5526456162683362], AbsoluteThickness[0.5], 
     LineBox[{{3.1133430358425915`, -0.5703185624998235}, {
      2.8546878672361986`, -0.5169710757238604}}]}, 
    {Hue[0.6562526322750036], AbsoluteThickness[0.5], 
     LineBox[{{4.566101814353904, -4.310487669884657}, {
      4.446348884020257, -4.35365092609602}}]}, 
    {Hue[0.6675004308266732], AbsoluteThickness[0.5], 
     LineBox[{{4.446348884020257, -4.35365092609602}, {
      4.30456992408814, -4.450885268302151}}]}, 
    {Hue[0.6652254030437434], AbsoluteThickness[0.5], 
     LineBox[{{3.186830152915206, -2.9007350279240947`}, {
      3.333988727489665, -3.1521740169841297`}}]}, 
    {Hue[0.6662048021117332], AbsoluteThickness[0.5], 
     LineBox[{{3.333988727489665, -3.1521740169841297`}, {
      3.4218536151488363`, -3.351156547170038}}]}, 
    {Hue[0.581389298874546], AbsoluteThickness[0.5], 
     LineBox[{{2.2886130596423895`, -2.406696796436617}, {
      2.269709177066505, -2.5407943245044953`}}]}, 
    {Hue[0.5815759198066873], AbsoluteThickness[0.5], 
     LineBox[{{2.269709177066505, -2.5407943245044953`}, {
      2.2269974575965636`, -2.866598855823816}}]}, 
    {Hue[0.6233007718402248], AbsoluteThickness[0.5], 
     LineBox[{{3.21414977933437, -3.9108801651768457`}, {
      3.1878751517765105`, -4.124011085105019}}]}, 
    {Hue[0.6241587694106465], AbsoluteThickness[0.5], 
     LineBox[{{3.1878751517765105`, -4.124011085105019}, {
      3.1843017802244207`, -4.353766402763522}}]}, 
    {Hue[0.5528566308938463], AbsoluteThickness[0.5], 
     LineBox[{{8.264249979302264, -2.9744161410151913`}, {
      8.230821166008036, -3.1577858296872368`}}]}, 
    {Hue[0.5532308159126438], AbsoluteThickness[0.5], 
     LineBox[{{8.230821166008036, -3.1577858296872368`}, {
      8.200425868156623, -3.420396074804406}}]}, 
    {Hue[0.6942233468316561], AbsoluteThickness[0.5], 
     LineBox[{{6.380694900367936, -3.572269944766505}, {
      6.3661669333633055`, -3.7128484852223758`}}]}, 
    {Hue[0.5739447802747908], AbsoluteThickness[0.5], 
     LineBox[{{5.2846673386373135`, -3.42689019718041}, {
      5.3101931958713955`, -3.633260269225098}}]}, 
    {Hue[0.5741486959288132], AbsoluteThickness[0.5], 
     LineBox[{{5.3101931958713955`, -3.633260269225098}, {
      5.340524913380642, -3.9364533047015757`}}]}, 
    {Hue[0.6825462956734183], AbsoluteThickness[0.5], 
     LineBox[{{3.8723596812644248`, 0.43704591406790944`}, {
      3.8163508583297476`, 0.37105506085661005`}}]}, 
    {Hue[0.6827865261382268], AbsoluteThickness[0.5], 
     LineBox[{{3.8163508583297476`, 0.37105506085661005`}, {
      3.6277582609737444`, 0.13098454742641094`}}]}, 
    {Hue[0.6756555847556583], AbsoluteThickness[0.5], 
     LineBox[{{6.609319392222294, -2.0588667500189346`}, {
      6.607990499786304, -2.292803609693519}}]}, 
    {Hue[0.6759028778406423], AbsoluteThickness[0.5], 
     LineBox[{{6.607990499786304, -2.292803609693519}, {
      6.6188993657553175`, -2.610571620417632}}]}, 
    {Hue[0.6802814646556156], AbsoluteThickness[0.5], 
     LineBox[{{2.1864040273262773`, -1.5908839168081363`}, {
      2.116943046812807, -1.584546922441695}}]}, 
    {Hue[0.680615655354816], AbsoluteThickness[0.5], 
     LineBox[{{2.116943046812807, -1.584546922441695}, {
      1.8429277720194244`, -1.5431834720036013`}}]}, 
    {Hue[0.47703638708552115`], AbsoluteThickness[0.5], 
     LineBox[{{3.135354215431099, -2.873588876929993}, {
      3.1291590347370537`, -2.8792926509807226`}}]}, 
    {Hue[0.4772197600781822], AbsoluteThickness[0.5], 
     LineBox[{{3.1291590347370537`, -2.8792926509807226`}, {
      2.8747270856212968`, -3.114781565921408}}]}, 
    {Hue[0.6740589235932566], AbsoluteThickness[0.5], 
     LineBox[{{2.107523011322846, 2.6895580339560903`}, {1.9715389495919409`, 
      2.652334402765798}}]}, 
    {Hue[0.6814240337499895], AbsoluteThickness[0.5], 
     LineBox[{{1.9715389495919409`, 2.652334402765798}, {1.8126837753289176`, 
      2.5667455556332626`}}]}, 
    {Hue[0.5530430616101015], AbsoluteThickness[0.5], 
     LineBox[{{2.8546878672361986`, -0.5169710757238604}, {
      2.7081137701951414`, -0.4761334728962817}}]}, 
    {Hue[0.5534059770350082], AbsoluteThickness[0.5], 
     LineBox[{{2.7081137701951414`, -0.4761334728962817}, {
      2.4233374609525127`, -0.41594306614899723`}}]}, 
    {Hue[0.6671842011797229], AbsoluteThickness[0.5], 
     LineBox[{{3.4218536151488363`, -3.351156547170038}, {
      3.4253620668364504`, -3.362413453139368}}]}, 
    {Hue[0.6675221783121797], AbsoluteThickness[0.5], 
     LineBox[{{3.4253620668364504`, -3.362413453139368}, {
      3.5187321549010875`, -3.6092674409253935`}}]}, 
    {Hue[0.5817625407388287], AbsoluteThickness[0.5], 
     LineBox[{{2.2269974575965636`, -2.866598855823816}, {
      2.2005832540538934`, -3.084454745644393}}]}, 
    {Hue[0.5822772169517367], AbsoluteThickness[0.5], 
     LineBox[{{2.2005832540538934`, -3.084454745644393}, {
      2.19117527744928, -3.3256825326061277`}}]}, 
    {Hue[0.5536050009314412], AbsoluteThickness[0.5], 
     LineBox[{{8.200425868156623, -3.420396074804406}, {
      8.189281402749307, -3.642485901268315}}]}, 
    {Hue[0.554065633043255], AbsoluteThickness[0.5], 
     LineBox[{{8.189281402749307, -3.642485901268315}, {
      8.195899279209828, -3.8980626220087173`}}]}, 
    {Hue[0.5743526115828356], AbsoluteThickness[0.5], 
     LineBox[{{5.340524913380642, -3.9364533047015757`}, {
      5.354799821483549, -4.123047464971758}}]}, 
    {Hue[0.5758656654135312], AbsoluteThickness[0.5], 
     LineBox[{{5.354799821483549, -4.123047464971758}, {
      5.3435873933583835`, -4.311607522435026}}]}, 
    {Hue[0.6830267566030352], AbsoluteThickness[0.5], 
     LineBox[{{3.6277582609737444`, 0.1309845474264109}, {3.5846098472847885`,
       0.0715563325483261}}]}, 
    {Hue[0.6832553021659725], AbsoluteThickness[0.5], 
     LineBox[{{3.5846098472847885`, 0.0715563325483261}, {
      3.3955428969268873`, -0.17104557766406175`}}]}, 
    {Hue[0.6761501709256261], AbsoluteThickness[0.5], 
     LineBox[{{6.6188993657553175`, -2.610571620417632}, {
      6.621906511845788, -2.650963131536688}}]}, 
    {Hue[0.6768035410795097], AbsoluteThickness[0.5], 
     LineBox[{{6.621906511845788, -2.650963131536688}, {
      6.617583509206603, -2.8749985982825743`}}]}, 
    {Hue[0.47740313307084326`], AbsoluteThickness[0.5], 
     LineBox[{{2.8747270856212968`, -3.114781565921408}, {
      2.838082340362363, -3.148877303266252}}]}, 
    {Hue[0.47759889013088336`], AbsoluteThickness[0.5], 
     LineBox[{{2.838082340362363, -3.148877303266252}, {
      2.6159504524003254`, -3.3632753449875312`}}]}, 
    {Hue[0.5537688924599147], AbsoluteThickness[0.5], 
     LineBox[{{2.4233374609525127`, -0.41594306614899723`}, {
      2.3635825394116026`, -0.40722552239788085`}}]}, 
    {Hue[0.5543853343055669], AbsoluteThickness[0.5], 
     LineBox[{{2.3635825394116026`, -0.40722552239788085`}, {
      2.1264231119612176`, -0.3502980429841255}}]}, 
    {Hue[0.6678601554446366], AbsoluteThickness[0.5], 
     LineBox[{{3.5187321549010875`, -3.6092674409253935`}, {
      3.66216580349884, -3.929519671680314}}]}, 
    {Hue[0.6723153966640277], AbsoluteThickness[0.5], 
     LineBox[{{3.66216580349884, -3.929519671680314}, {
      3.70053918451893, -4.096874564738043}}]}, 
    {Hue[0.5827918931646449], AbsoluteThickness[0.5], 
     LineBox[{{2.19117527744928, -3.3256825326061277`}, {
      2.2006771023350336`, -3.5480932227332427`}}]}, 
    {Hue[0.5829756773369932], AbsoluteThickness[0.5], 
     LineBox[{{2.2006771023350336`, -3.5480932227332427`}, {
      2.2155922311191225`, -3.8656354417860164`}}]}, 
    {Hue[0.5545262651550686], AbsoluteThickness[0.5], 
     LineBox[{{8.195899279209828, -3.8980626220087173`}, {
      8.216390756546161, -4.098432075737106}}]}, 
    {Hue[0.5547382902140563], AbsoluteThickness[0.5], 
     LineBox[{{8.216390756546161, -4.098432075737106}, {
      8.2637206997027, -4.46240798472222}}]}, 
    {Hue[0.6834838477289098], AbsoluteThickness[0.5], 
     LineBox[{{3.3955428969268873`, -0.17104557766406175`}, {
      3.386058930047751, -0.1823967932116381}}]}, 
    {Hue[0.6836799190793889], AbsoluteThickness[0.5], 
     LineBox[{{3.386058930047751, -0.1823967932116381}, {
      3.1814876357625916`, -0.4182253843986803}}]}, 
    {Hue[0.6774569112333934], AbsoluteThickness[0.5], 
     LineBox[{{6.617583509206603, -2.8749985982825743`}, {
      6.610183188278267, -2.940267322267495}}]}, 
    {Hue[0.6787246974918877], AbsoluteThickness[0.5], 
     LineBox[{{6.610183188278267, -2.940267322267495}, {
      6.612659338632755, -3.1199280820686464`}}]}, 
    {Hue[0.47779464719092346`], AbsoluteThickness[0.5], 
     LineBox[{{2.6159504524003254`, -3.3632753449875312`}, {
      2.610911570792706, -3.368320156404455}}]}, 
    {Hue[0.47799735051420794`], AbsoluteThickness[0.5], 
     LineBox[{{2.610911570792706, -3.368320156404455}, {
      2.3994172582498967`, -3.5898937933800235`}}]}, 
    {Hue[0.5550017761512192], AbsoluteThickness[0.5], 
     LineBox[{{2.1264231119612176`, -0.3502980429841255}, {
      2.1230759113004076`, -0.3491653743978561}}]}, 
    {Hue[0.5566179126052286], AbsoluteThickness[0.5], 
     LineBox[{{2.1230759113004076`, -0.3491653743978561}, {
      1.9247809079917395`, -0.31161928865510713`}}]}, 
    {Hue[0.6767706378834186], AbsoluteThickness[0.5], 
     LineBox[{{3.70053918451893, -4.096874564738043}, {
      3.702257626811304, -4.154703283557864}}]}, 
    {Hue[0.677071472946378], AbsoluteThickness[0.5], 
     LineBox[{{3.702257626811304, -4.154703283557864}, {
      3.7259065841173045`, -4.4409374302681215`}}]}, 
    {Hue[0.5831594615093416], AbsoluteThickness[0.5], 
     LineBox[{{2.2155922311191225`, -3.8656354417860164`}, {
      2.228243500126284, -4.112630251758305}}]}, 
    {Hue[0.5833580526693767], AbsoluteThickness[0.5], 
     LineBox[{{2.228243500126284, -4.112630251758305}, {
      2.2382741906794665`, -4.436492633377812}}]}, 
    {Hue[0.6838759904298678], AbsoluteThickness[0.5], 
     LineBox[{{3.1814876357625916`, -0.4182253843986803}, {
      3.157010076547749, -0.4454088774003837}}]}, 
    {Hue[0.6844046024763212], AbsoluteThickness[0.5], 
     LineBox[{{3.157010076547749, -0.4454088774003837}, {
      2.9759563094528474`, -0.6156758306537146}}]}, 
    {Hue[0.679992483750382], AbsoluteThickness[0.5], 
     LineBox[{{6.612659338632755, -3.1199280820686464`}, {
      6.613883624297096, -3.128586745291935}}]}, 
    {Hue[0.6808649248830938], AbsoluteThickness[0.5], 
     LineBox[{{6.613883624297096, -3.128586745291935}, {
      6.620701540397806, -3.3381284650382446`}}]}, 
    {Hue[0.4782000538374923], AbsoluteThickness[0.5], 
     LineBox[{{2.3994172582498967`, -3.5898937933800235`}, {
      2.357224672434786, -3.6361538172685215`}}]}, 
    {Hue[0.4784366997769924], AbsoluteThickness[0.5], 
     LineBox[{{2.357224672434786, -3.6361538172685215`}, {
      2.1468082288758534`, -3.850481151304229}}]}, 
    {Hue[0.6849332145227746], AbsoluteThickness[0.5], 
     LineBox[{{2.9759563094528474`, -0.6156758306537146}, {
      2.898480630675166, -0.6772683293156354}}]}, 
    {Hue[0.6851165419952965], AbsoluteThickness[0.5], 
     LineBox[{{2.898480630675166, -0.6772683293156354}, {
      2.672209777524318, -0.858033741578869}}]}, 
    {Hue[0.6817373660158055], AbsoluteThickness[0.5], 
     LineBox[{{6.620701540397806, -3.3381284650382446`}, {
      6.617152559466575, -3.3851007019041273`}}]}, 
    {Hue[0.6856076269106717], AbsoluteThickness[0.5], 
     LineBox[{{6.617152559466575, -3.3851007019041273`}, {
      6.630213745123582, -3.5013041336861583`}}]}, 
    {Hue[0.47867334571649234`], AbsoluteThickness[0.5], 
     LineBox[{{2.1468082288758534`, -3.850481151304229}, {
      2.132850973422473, -3.8636901345735404`}}]}, 
    {Hue[0.47886001499339187`], AbsoluteThickness[0.5], 
     LineBox[{{2.132850973422473, -3.8636901345735404`}, {
      1.892191514199834, -4.095942514368096}}]}, 
    {Hue[0.6852998694678184], AbsoluteThickness[0.5], 
     LineBox[{{2.672209777524318, -0.858033741578869}, {
      2.6138631964053385`, -0.9048745229806487}}]}, 
    {Hue[0.6854873616201218], AbsoluteThickness[0.5], 
     LineBox[{{2.6138631964053385`, -0.9048745229806487}, {
      2.3384123243514687`, -1.1309549887150265`}}]}, 
    {Hue[0.6894778878055379], AbsoluteThickness[0.5], 
     LineBox[{{6.630213745123582, -3.5013041336861583`}, {
      6.660778854575984, -3.600368690908474}}]}, 
    {Hue[0.6896684177149801], AbsoluteThickness[0.5], 
     LineBox[{{6.660778854575984, -3.600368690908474}, {
      6.757251316699107, -3.9294027223609964`}}]}, 
    {Hue[0.685674853772425], AbsoluteThickness[0.5], 
     LineBox[{{2.3384123243514687`, -1.1309549887150265`}, {
      2.315348086617261, -1.1503070340854382`}}]}, 
    {Hue[0.685905840636639], AbsoluteThickness[0.5], 
     LineBox[{{2.315348086617261, -1.1503070340854382`}, {
      2.0918985495275626`, -1.3514712695253897`}}]}, 
    {Hue[0.6898589476244223], AbsoluteThickness[0.5], 
     LineBox[{{6.757251316699107, -3.9294027223609964`}, {
      6.818098322848967, -4.148287247464208}}]}, 
    {Hue[0.6957122375759417], AbsoluteThickness[0.5], 
     LineBox[{{6.818098322848967, -4.148287247464208}, {
      6.866441308379045, -4.240348940993934}}]}, 
    {Hue[0.686136827500853], AbsoluteThickness[0.5], 
     LineBox[{{2.0918985495275626`, -1.3514712695253897`}, {
      2.083749471856234, -1.3593388178846615`}}]}, 
    {Hue[0.6863311149416329], AbsoluteThickness[0.5], 
     LineBox[{{2.083749471856234, -1.3593388178846615`}, {
      1.8626583431103891`, -1.5802739192837725`}}]}, 
    {Hue[0.4439743751153728], AbsoluteThickness[0.5], 
     LineBox[{{1.7667114977152143`, 0.}, {0.7500000000000002, 
      0.2310098625111181}}]}, 
    {Hue[0.4443490017329914], AbsoluteThickness[0.5], 
     LineBox[{{1.7737198649463215`, -0.07722951543100699}, {
      0.75, -0.2645718457173044}}]}, 
    {Hue[0.4464027951407989], AbsoluteThickness[0.5], 
     LineBox[{{1.7672930323709903`, 0.004669646611714488}, {
      0.7499999999999998, 0.011079305361220593`}}]}, 
    {Hue[0.44676207265291906`], AbsoluteThickness[0.5], 
     LineBox[{{1.7661119968940817`, -0.006264234149068747}, {
      0.75, -0.008397797803824991}}]}, 
    {Hue[0.4447996067321794], AbsoluteThickness[0.5], 
     LineBox[{{2.3675489352810515`, 0.11310424430511475`}, {
      0.7499999999999998, 0.35379247403818237`}}]}, 
    {Hue[0.4473601597146207], AbsoluteThickness[0.5], 
     LineBox[{{1.850524420653777, -0.5013247962187429}, {
      0.7500000000000002, -0.928706845010267}}]}, 
    {Hue[0.44960323804411473`], AbsoluteThickness[0.5], 
     LineBox[{{1.9375366706374482`, 0.3992115048105958}, {0.7500000000000002, 
      0.5757269206438212}}]}, 
    {Hue[0.44603505217227446`], AbsoluteThickness[0.5], 
     LineBox[{{1.842422203976989, -0.4570800530492261}, {
      0.75, -0.8587765005445434}}]}, 
    {Hue[0.5497875452548775], AbsoluteThickness[0.5], 
     LineBox[{{2.1679364592479047`, 0.7873630095557195}, {0.75, 
      0.6218552987430191}}]}, 
    {Hue[0.5322694545838517], AbsoluteThickness[0.5], 
     LineBox[{{2.1968282486405424`, -1.5843271908251064`}, {
      0.75, -2.088120711125074}}]}, 
    {Hue[0.6615143307010756], AbsoluteThickness[0.5], 
     LineBox[{{1.9265945208348418`, -0.5911279665573725}, {
      0.75, -2.921154990973647}}]}, 
    {Hue[0.46206727044117835`], AbsoluteThickness[0.5], 
     LineBox[{{1.8849683746156314`, 0.8698811764446064}, {0.75, 
      0.9551550171248132}}]}, 
    {Hue[0.4515072749488838], AbsoluteThickness[0.5], 
     LineBox[{{1.981736479233178, 2.1791356728325355`}, {0.75, 
      2.966776391674025}}]}, 
    {Hue[0.6676012625176487], AbsoluteThickness[0.5], 
     LineBox[{{2.0330784063531713`, -2.120040053223454}, {
      0.7499999999999998, -3.832482196669296}}]}, 
    {Hue[0.4567893551367266], AbsoluteThickness[0.5], 
     LineBox[{{1.871705955361084, -2.579383011099843}, {
      1.574703078245685, -5.4}}]}, 
    {Hue[0.6531565131084971], AbsoluteThickness[0.5], 
     LineBox[{{1.8907195989671668`, 1.684804414747426}, {0.7499999999999998, 
      4.016141094002052}}]}, 
    {Hue[0.6627691514417526], AbsoluteThickness[0.5], 
     LineBox[{{1.8604948557158172`, -0.18781759303254186`}, {
      0.7500000000000002, -4.038364933774184}}]}, 
    {Hue[0.6936972969362344], AbsoluteThickness[0.5], 
     LineBox[{{2.0670908527082337`, -0.6339946714700225}, {
      0.7500000000000002, -1.147294791143008}}]}, 
    {Hue[0.4568498437867404], AbsoluteThickness[0.5], 
     LineBox[{{1.82287096155126, 1.0079416589077277`}, {0.75, 
      1.4930922703543543`}}]}, 
    {Hue[0.5371659555315883], AbsoluteThickness[0.5], 
     LineBox[{{8.382099314299674, 0.22347529134967298`}, {
      9.75, -0.05704594163051452}}]}, 
    {Hue[0.4551878767831321], AbsoluteThickness[0.5], 
     LineBox[{{1.8528470577585507`, -1.17291256256883}, {
      0.7499999999999998, -1.6019322081523129`}}]}, 
    {Hue[0.6935840713703021], AbsoluteThickness[0.5], 
     LineBox[{{5.410142819605809, 3.6812770041790377`}, {6.398097770588954, 
      4.6}}]}, 
    {Hue[0.6372789894495439], AbsoluteThickness[0.5], 
     LineBox[{{3.1531498249152365`, 3.3914826324245704`}, {4.096020104562012, 
      4.6}}]}, 
    {Hue[0.4445030572331928], AbsoluteThickness[0.5], 
     LineBox[{{1.841612151678042, -2.4839424729838475`}, {
      0.75, -3.7999334201003583`}}]}, 
    {Hue[0.6805650962193226], AbsoluteThickness[0.5], 
     LineBox[{{8.34571974139002, 2.320663474652185}, {9.75, 
      2.798201103792634}}]}, 
    {Hue[0.2477644718790087], AbsoluteThickness[0.5], 
     LineBox[{{8.371022184652178, -0.3716808198235361}, {
      9.75, -0.4126332128078969}}]}, 
    {Hue[0.5472415749376509], AbsoluteThickness[0.5], 
     LineBox[{{2.0921927069666446`, 0.3256054024297014}, {0.75, 
      0.10026814533756578`}}]}, 
    {Hue[0.6807233953114465], AbsoluteThickness[0.5], 
     LineBox[{{2.18705552402088, 0.7293805768078586}, {0.75, 
      0.26803405995480933`}}]}, 
    {Hue[0.6900078202097506], AbsoluteThickness[0.5], 
     LineBox[{{2.074965366139089, -0.7819802989291605}, {
      0.7500000000000002, -1.0556499518973506`}}]}, 
    {Hue[0.025920357492011624`], AbsoluteThickness[0.5], 
     LineBox[{{8.279619357017198, 2.3844659508650694`}, {9.75, 
      3.4820796197269925`}}]}, 
    {Hue[0.5224288471655328], AbsoluteThickness[0.5], 
     LineBox[{{8.353376858084014, 1.4486758481567938`}, {9.75, 
      1.475934126222417}}]}, 
    {Hue[0.3303712818554711], AbsoluteThickness[0.5], 
     LineBox[{{8.471556087494077, 1.3036155224815655`}, {
      9.75, -1.1488836651565428`}}]}, 
    {Hue[0.5289156132568249], AbsoluteThickness[0.5], 
     LineBox[{{8.18182694304322, 0.5465277883779298}, {
      9.75, -0.3682938018806834}}]}, 
    {Hue[0.677317416524692], AbsoluteThickness[0.5], 
     LineBox[{{8.40513098295746, -1.2478631540215561`}, {
      9.75, -1.0051899138897755`}}]}, 
    {Hue[0.4738353200678347], AbsoluteThickness[0.5], 
     LineBox[{{1.8631456608056345`, -1.9991716919118454`}, {
      0.75, -2.54891212154094}}]}, 
    {Hue[0.6605056992942635], AbsoluteThickness[0.5], 
     LineBox[{{2.0003485458539485`, 3.6568472194308046`}, {
      1.8899101609401012`, 4.6}}]}, 
    {Hue[0.5146153261653152], AbsoluteThickness[0.5], 
     LineBox[{{8.347403889598631, 0.3164039243675053}, {9.75, 
      2.3150971450631865`}}]}, 
    {Hue[0.22127587508459864`], AbsoluteThickness[0.5], 
     LineBox[{{8.33682100981092, -2.372116296911316}, {
      9.75, -3.3637609551454264`}}]}, 
    {Hue[0.5756694352723559], AbsoluteThickness[0.5], 
     LineBox[{{8.311903601845028, -1.6379705011059962`}, {9.75, 
      1.2905317992727268`}}]}, 
    {Hue[0.5884469906108598], AbsoluteThickness[0.5], 
     LineBox[{{8.336491908698271, -1.3533739219868754`}, {
      9.75, -5.137849265650147}}]}, 
    {Hue[0.5007992865216053], AbsoluteThickness[0.5], 
     LineBox[{{8.468165047516123, 1.3220799330813995`}, {9.547044756836728, 
      4.6}}]}, 
    {Hue[0.4349318823414036], AbsoluteThickness[0.5], 
     LineBox[{{8.454284569695465, -0.7830988991393053}, {
      9.75, -2.9427746248001707`}}]}, 
    {Hue[0.5288254040738685], AbsoluteThickness[0.5], 
     LineBox[{{8.192257270270463, 1.011642970905468}, {9.75, 
      1.6024250208275874`}}]}, 
    {Hue[0.659502239692715], AbsoluteThickness[0.5], 
     LineBox[{{1.822712616640818, -1.146059333803818}, {
      0.75, -1.338546865179533}}]}, 
    {Hue[0.5209176902592223], AbsoluteThickness[0.5], 
     LineBox[{{8.11164321715692, -2.5383145838870496`}, {
      9.75, -2.2312511425493917`}}]}, 
    {Hue[0.6632224724079415], AbsoluteThickness[0.5], 
     LineBox[{{8.45538678793015, -0.7653751126454883}, {9.75, 
      0.3727948734462406}}]}, 
    {Hue[0.6289407020085737], AbsoluteThickness[0.5], 
     LineBox[{{8.367052651840087, 0.14943348693084343`}, {9.75, 
      0.4050411595395943}}]}, 
    {Hue[0.4703950034775129], AbsoluteThickness[0.5], 
     LineBox[{{7.295863451371103, 3.872524143458744}, {7.453531826332829, 
      4.6}}]}, 
    {Hue[0.6878801459554527], AbsoluteThickness[0.5], 
     LineBox[{{5.825246023854241, 3.9303156676656474`}, {6.28487639933107, 
      4.6}}]}, 
    {Hue[0.6905643831487307], AbsoluteThickness[0.5], 
     LineBox[{{8.43413732121714, -0.8473346537407715}, {
      9.75, -1.949015893495694}}]}, 
    {Hue[0.24424578164520963`], AbsoluteThickness[0.5], 
     LineBox[{{6.942088537623861, 3.6182506337634655`}, {7.184896479020065, 
      4.6}}]}, 
    {Hue[0.47210949671125707`], AbsoluteThickness[0.5], 
     LineBox[{{8.469682112473555, 1.3151141464055818`}, {9.75, 
      0.8473077115705722}}]}, 
    {Hue[0.6423771744268696], AbsoluteThickness[0.5], 
     LineBox[{{7.114318319292503, -4.651750633423436}, {
      7.424573157315425, -5.4}}]}, 
    {Hue[0.6959190977219294], AbsoluteThickness[0.5], 
     LineBox[{{1.8170903467914052`, 1.5473035894966969`}, {0.7499999999999998,
       0.8961459321822772}}]}, 
    {Hue[0.6639993040684513], AbsoluteThickness[0.5], 
     LineBox[{{1.779063316539821, -0.9682283827490923}, {
      0.75, -0.9106411150436824}}]}, 
    {Hue[0.6287226303949174], AbsoluteThickness[0.5], 
     LineBox[{{8.397117182488653, -0.1252058009954891}, {9.582253220006294, 
      4.6}}]}, 
    {Hue[0.5075284242811571], AbsoluteThickness[0.5], 
     LineBox[{{1.8258596958523285`, 1.0332433360189008`}, {0.75, 
      1.6060528093408535`}}]}, 
    {Hue[0.6498963990677253], AbsoluteThickness[0.5], 
     LineBox[{{6.996997111901896, 3.6103894700818837`}, {7.002175056042999, 
      4.6}}]}, 
    {Hue[0.5318889398955645], AbsoluteThickness[0.5], 
     LineBox[{{6.576370351743306, 3.840641917987641}, {6.703907454306172, 
      4.6}}]}, 
    {Hue[0.4068776943241567], AbsoluteThickness[0.5], 
     LineBox[{{4.5651883069599, 3.6848540105536114`}, {4.214078151596347, 
      4.6}}]}, 
    {Hue[0.6510170123596705], AbsoluteThickness[0.5], 
     LineBox[{{5.1726285273595956`, 3.9255726373682482`}, {5.063450928584296, 
      4.6}}]}, 
    {Hue[0.6540269666147916], AbsoluteThickness[0.5], 
     LineBox[{{4.557058154927904, 3.6857111952687807`}, {4.299288985045942, 
      4.6}}]}, 
    {Hue[0.6220624667310747], AbsoluteThickness[0.5], 
     LineBox[{{5.000414990405947, -4.159206389957394}, {
      5.598862526758939, -5.4}}]}, 
    {Hue[0.6961388600770135], AbsoluteThickness[0.5], 
     LineBox[{{4.021738605429321, 3.6895005923389186`}, {4.2565580051618515`, 
      4.6}}]}, 
    {Hue[0.41902552137909743`], AbsoluteThickness[0.5], 
     LineBox[{{2.11741073100309, 3.1862318942371473`}, {0.75, 
      4.48138308290737}}]}, 
    {Hue[0.638798335559538], AbsoluteThickness[0.5], 
     LineBox[{{8.28456357642351, 1.882574819793523}, {9.095478664054873, 
      4.6}}]}, 
    {Hue[0.6981562941165711], AbsoluteThickness[0.5], 
     LineBox[{{6.893635248830319, 3.7624543145467406`}, {6.92910395054671, 
      4.6}}]}, 
    {Hue[0.6905676203680414], AbsoluteThickness[0.5], 
     LineBox[{{3.057522303906609, 3.7785231599775653`}, {2.151173025599504, 
      4.6}}]}, 
    {Hue[0.43878164058041874`], AbsoluteThickness[0.5], 
     LineBox[{{8.393442965850957, -2.303851857405552}, {
      9.75, -4.986211477490428}}]}, 
    {Hue[0.4396401656720452], AbsoluteThickness[0.5], 
     LineBox[{{2.202642609176679, 0.8816321711879552}, {0.75, 
      0.4042047935943578}}]}, 
    {Hue[0.46443994298087715`], AbsoluteThickness[0.5], 
     LineBox[{{6.377435097169095, 3.658150991890274}, {7.039248119545805, 
      4.6}}]}, 
    {Hue[0.6397201255033617], AbsoluteThickness[0.5], 
     LineBox[{{6.345897813530606, 3.806407466702233}, {5.975765862474676, 
      4.6}}]}, 
    {Hue[0.6977230585196296], AbsoluteThickness[0.5], 
     LineBox[{{1.8591223699710941`, -0.379751604104828}, {0.75, 
      0.11183972014175736`}}]}, 
    {Hue[0.5320662143421057], AbsoluteThickness[0.5], 
     LineBox[{{8.370476193877607, 3.3020565011722733`}, {9.75, 
      3.3939851403745727`}}]}, 
    {Hue[0.5352892609917521], AbsoluteThickness[0.5], 
     LineBox[{{5.6634007260393116`, 3.889464890278438}, {3.997703916991005, 
      4.6}}]}, 
    {Hue[0.5312950995972401], AbsoluteThickness[0.5], 
     LineBox[{{2.1664863383255795`, 1.7124017880902116`}, {0.75, 
      2.59384875361945}}]}, 
    {Hue[0.6938697028423856], AbsoluteThickness[0.5], 
     LineBox[{{3.1688661246212564`, 3.9136726985842807`}, {
      2.8078833745951814`, 4.6}}]}, 
    {Hue[0.6708895927388838], AbsoluteThickness[0.5], 
     LineBox[{{2.057599674808473, -3.732319033051137}, {
      0.75, -4.456095867831128}}]}, 
    {Hue[0.6830495905819289], AbsoluteThickness[0.5], 
     LineBox[{{1.939751687198152, 2.8785860260273344`}, {0.75, 
      2.251784413451983}}]}, 
    {Hue[0.6903876399114214], AbsoluteThickness[0.5], 
     LineBox[{{2.3669117145038703`, 3.764223584864702}, {2.54043304516074, 
      4.6}}]}, 
    {Hue[0.6363867841097792], AbsoluteThickness[0.5], 
     LineBox[{{1.7735416284485892`, -1.0338422441077806`}, {
      0.7499999999999998, -1.3049203825930151`}}]}, 
    {Hue[0.6995516631920774], AbsoluteThickness[0.5], 
     LineBox[{{6.957214733053927, 3.6183783225821378`}, {7.189188771260336, 
      4.6}}]}, 
    {Hue[0.651034350923142], AbsoluteThickness[0.5], 
     LineBox[{{5.988617948777935, -4.710701163914752}, {
      6.246975915126126, -5.4}}]}, 
    {Hue[0.5923533500772142], AbsoluteThickness[0.5], 
     LineBox[{{7.249413289851313, 3.865881414191816}, {7.096338363960726, 
      4.6}}]}, 
    {Hue[0.3230629449987243], AbsoluteThickness[0.5], 
     LineBox[{{3.1854391618308204`, 3.917440606065164}, {2.7269243355216988`, 
      4.6}}]}, 
    {Hue[0.6010254422738865], AbsoluteThickness[0.5], 
     LineBox[{{3.6447050878359932`, 3.7340071536615724`}, {
      3.1539235737992732`, 4.6}}]}, 
    {Hue[0.5177930225743089], AbsoluteThickness[0.5], 
     LineBox[{{3.666413661944249, 3.8758765752816933`}, {4.004056392175901, 
      4.6}}]}, 
    {Hue[0.6351805456579714], AbsoluteThickness[0.5], 
     LineBox[{{3.7945631340613906`, 3.9404978394038013`}, {
      7.3663440076069335`, 4.6}}]}, 
    {Hue[0.6217955673581762], AbsoluteThickness[0.5], 
     LineBox[{{3.0875717529220807`, 3.857537429702332}, {1.3952982896641766`, 
      4.6}}]}, 
    {Hue[0.4847182148229387], AbsoluteThickness[0.5], 
     LineBox[{{1.866738553866757, 1.6632737373389903`}, {0.7499999999999998, 
      1.6226898414554505`}}]}, 
    {Hue[0.6692874222681603], AbsoluteThickness[0.5], 
     LineBox[{{1.9255244467780555`, 0.4850253643387584}, {0.75, 
      0.6350326116805584}}]}, 
    {Hue[0.4708397500197929], AbsoluteThickness[0.5], 
     LineBox[{{4.1545226228344525`, 3.848702210669975}, {3.5800354857925454`, 
      4.6}}]}, 
    {Hue[0.461389198658302], AbsoluteThickness[0.5], 
     LineBox[{{1.9002821581533915`, 2.948691825759078}, {0.75, 
      3.196372152840666}}]}, 
    {Hue[0.6738863612023681], AbsoluteThickness[0.5], 
     LineBox[{{8.145218465973057, 3.002605801682305}, {9.75, 
      2.9934296759182932`}}]}, 
    {Hue[0.680765647074016], AbsoluteThickness[0.5], 
     LineBox[{{1.9254498630377734`, 0.4847035724536128}, {0.75, 
      0.8292542812134315}}]}, 
    {Hue[0.6743307171979602], AbsoluteThickness[0.5], 
     LineBox[{{8.464967287231055, -2.8252742464879286`}, {
      9.75, -4.327625127895923}}]}, 
    {Hue[0.58954182708302], AbsoluteThickness[0.5], 
     LineBox[{{7.705414945740973, 3.888998368063742}, {7.5745167285675254`, 
      4.6}}]}, 
    {Hue[0.6930740470255741], AbsoluteThickness[0.5], 
     LineBox[{{7.88750394744357, 3.8598451511704264`}, {8.360700078604824, 
      4.6}}]}, 
    {Hue[0.5902714293287991], AbsoluteThickness[0.5], 
     LineBox[{{5.928757673475447, 3.59616286765204}, {6.764964971778461, 
      4.6}}]}, 
    {Hue[0.6945906893328795], AbsoluteThickness[0.5], 
     LineBox[{{1.8999957360474449`, 1.691340859919253}, {0.75, 
      4.09124363753976}}]}, 
    {Hue[0.5979750027306632], AbsoluteThickness[0.5], 
     LineBox[{{4.315560330733823, 3.842826281431774}, {5.930886695834191, 
      4.6}}]}, 
    {Hue[0.6299497925110854], AbsoluteThickness[0.5], 
     LineBox[{{2.089830620806531, 3.644610377272796}, {0.9077638619197765, 
      4.6}}]}, 
    {Hue[0.5296122987328485], AbsoluteThickness[0.5], 
     LineBox[{{1.8184609758976726`, -0.1543466785264378}, {
      0.75, -0.47408743664388747`}}]}, 
    {Hue[0.4813477642174457], AbsoluteThickness[0.5], 
     LineBox[{{1.8925223693054563`, -3.0614739192830824`}, {
      0.75, -3.735555503708284}}]}, 
    {Hue[0.5797671467119694], AbsoluteThickness[0.5], 
     LineBox[{{2.735202566971461, 3.941086772914109}, {2.3976433451061703`, 
      4.6}}]}, 
    {Hue[0.5695407226211872], AbsoluteThickness[0.5], 
     LineBox[{{3.5490640983277992`, 3.6362395798778353`}, {
      2.9906241608010675`, 4.6}}]}, 
    {Hue[0.5984342281509849], AbsoluteThickness[0.5], 
     LineBox[{{8.35458679363506, 0.12765032623837}, {
      9.75, -1.0717124374373639`}}]}, 
    {Hue[0.694912458911663], AbsoluteThickness[0.5], 
     LineBox[{{2.133292155381548, 3.839095338540685}, {2.101890100273397, 
      4.6}}]}, 
    {Hue[0.5930596648731132], AbsoluteThickness[0.5], 
     LineBox[{{6.816528145569681, -4.383112257242901}, {
      6.344021416112138, -5.4}}]}, 
    {Hue[0.5024660663913902], AbsoluteThickness[0.5], 
     LineBox[{{6.750818439690522, -4.419688470805187}, {
      6.401005318061502, -5.4}}]}, 
    {Hue[0.6406419525674321], AbsoluteThickness[0.5], 
     LineBox[{{8.166895214856064, -3.0588244373516718`}, {
      9.75, -3.742805141543442}}]}, 
    {Hue[0.331979964623488], AbsoluteThickness[0.5], 
     LineBox[{{5.624661889022492, 3.837040565238847}, {5.271286518202127, 
      4.6}}]}, 
    {Hue[0.6983067829377599], AbsoluteThickness[0.5], 
     LineBox[{{6.882779322650426, 3.811935048904515}, {7.828399084772261, 
      4.6}}]}, 
    {Hue[0.6086547979995681], AbsoluteThickness[0.5], 
     LineBox[{{6.475677707174433, 3.668722634526091}, {6.636523485148712, 
      4.6}}]}, 
    {Hue[0.4485408740875305], AbsoluteThickness[0.5], 
     LineBox[{{1.8654612149900247`, 0.8885482619526972}, {0.7500000000000002, 
      0.6160840059493612}}]}, 
    {Hue[0.43442836451599154`], AbsoluteThickness[0.5], 
     LineBox[{{1.905450895359237, 2.9302119632853034`}, {0.75, 
      2.8526439560842514`}}]}, 
    {Hue[0.5328922939503512], AbsoluteThickness[0.5], 
     LineBox[{{2.001820259253169, 0.8322686305099309}, {
      0.75, -0.06447361069971824}}]}, 
    {Hue[0.606987383510744], AbsoluteThickness[0.5], 
     LineBox[{{2.553007083039228, 3.824253879775438}, {0.75, 
      4.365551956770799}}]}, 
    {Hue[0.5881778417474645], AbsoluteThickness[0.5], 
     LineBox[{{1.8717760217040529`, -3.596276373248007}, {
      0.7499999999999998, -4.264103608630234}}]}, 
    {Hue[0.6901174648520068], AbsoluteThickness[0.5], 
     LineBox[{{8.277153594740588, -1.8841482342927005`}, {
      9.75, -2.7016737323025786`}}]}, 
    {Hue[0.4782361577619069], AbsoluteThickness[0.5], 
     LineBox[{{5.78884187988963, 3.9356753447342863`}, {5.337352751897541, 
      4.6}}]}, 
    {Hue[0.6446424707363977], AbsoluteThickness[0.5], 
     LineBox[{{1.7936828751715794`, 0.0789026636679371}, {0.75, 
      0.2982847768764263}}]}, 
    {Hue[0.6613855052234563], AbsoluteThickness[0.5], 
     LineBox[{{1.7818741487236447`, -1.0752584328605608`}, {
      0.75, -1.0459322082683495`}}]}, 
    {Hue[0.6929279305965544], AbsoluteThickness[0.5], 
     LineBox[{{4.07115545095173, 3.6707940629447973`}, {3.893366391537607, 
      4.6}}]}, 
    {Hue[0.6687775418514145], AbsoluteThickness[0.5], 
     LineBox[{{2.1227029962502155`, 3.8305644736481965`}, {2.085762264531462, 
      4.6}}]}, 
    {Hue[0.6680977167324249], AbsoluteThickness[0.5], 
     LineBox[{{8.27378532912938, 3.089154647252922}, {9.75, 
      2.462813743293564}}]}, 
    {Hue[0.49271783120944335`], AbsoluteThickness[0.5], 
     LineBox[{{8.495946585525004, 3.6887914096803205`}, {9.75, 
      4.586149244763882}}]}, 
    {Hue[0.6706176316892525], AbsoluteThickness[0.5], 
     LineBox[{{1.8756163776684474`, -1.1869631499097286`}, {
      0.75, -3.3256616220227384`}}]}, 
    {Hue[0.6893472009297835], AbsoluteThickness[0.5], 
     LineBox[{{8.300156147257562, 1.4583259666974322`}, {9.267337733411882, 
      4.6}}]}, 
    {Hue[0.5248866600924025], AbsoluteThickness[0.5], 
     LineBox[{{3.2909883109441656`, -4.5946589053852165`}, {
      2.520638746641396, -5.4}}]}, 
    {Hue[0.5601192984938164], AbsoluteThickness[0.5], 
     LineBox[{{7.592086742145651, -4.625886100022921}, {
      7.575230077813286, -5.4}}]}, 
    {Hue[0.5056128629210511], AbsoluteThickness[0.5], 
     LineBox[{{8.074781152017092, -4.648738151644846}, {
      9.700038947201104, -5.4}}]}, 
    {Hue[0.6029535501075041], AbsoluteThickness[0.5], 
     LineBox[{{1.8240741026616254`, 1.588190619940066}, {0.75, 
      1.9444793858073828`}}]}, 
    {Hue[0.661563162988541], AbsoluteThickness[0.5], 
     LineBox[{{8.417195633114394, -0.1544898434743955}, {
      9.75, -0.2504338269290702}}]}, 
    {Hue[0.6850696073142645], AbsoluteThickness[0.5], 
     LineBox[{{2.2076719681319608`, 1.8799915918934478`}, {0.75, 
      1.841438773858871}}]}, 
    {Hue[0.611649766239205], AbsoluteThickness[0.5], 
     LineBox[{{8.470391685845325, -4.324888481466}, {
      9.75, -4.2137530955699525`}}]}, 
    {Hue[0.6998373183436789], AbsoluteThickness[0.5], 
     LineBox[{{3.636771330728353, 3.7921973243101887`}, {2.8101711478294145`, 
      4.6}}]}, 
    {Hue[0.5992401778184218], AbsoluteThickness[0.5], 
     LineBox[{{1.8423080769447733`, -0.45235163317290616`}, {
      0.75, -2.0574530586425595`}}]}, 
    {Hue[0.699750186491619], AbsoluteThickness[0.5], 
     LineBox[{{8.282380208947151, -1.8815251178425596`}, {
      9.75, -2.5469065420650225`}}]}, 
    {Hue[0.6959493640511131], AbsoluteThickness[0.5], 
     LineBox[{{1.900105784987952, 1.382113841150748}, {0.75, 
      1.7357057001386909`}}]}, 
    {Hue[0.6863132861050888], AbsoluteThickness[0.5], 
     LineBox[{{1.8238439393769457`, 1.0202765181166027`}, {0.75, 
      0.6037719390541022}}]}, 
    {Hue[0.6652598726103884], AbsoluteThickness[0.5], 
     LineBox[{{4.815103198866747, -4.5442523639535395`}, {
      4.192520843571415, -5.4}}]}, 
    {Hue[0.4760469779171991], AbsoluteThickness[0.5], 
     LineBox[{{6.515057093215638, -4.686380860885859}, {
      6.024217223762429, -5.4}}]}, 
    {Hue[0.6787240179848197], AbsoluteThickness[0.5], 
     LineBox[{{8.353958111122084, 0.12673605509693064`}, {
      9.75, -2.440694887693634}}]}, 
    {Hue[0.6458590510677922], AbsoluteThickness[0.5], 
     LineBox[{{2.0375417428426617`, 2.1825871052305135`}, {0.75, 
      2.7947799446624715`}}]}, 
    {Hue[0.6410199157751416], AbsoluteThickness[0.5], 
     LineBox[{{1.9679775262061567`, -1.6446457138116022`}, {
      0.7500000000000002, -3.293554580072368}}]}, 
    {Hue[0.6721368655951032], AbsoluteThickness[0.5], 
     LineBox[{{1.8478535170951083`, -2.5287092081334865`}, {
      0.75, -3.531199278342574}}]}, 
    {Hue[0.6460584050441148], AbsoluteThickness[0.5], 
     LineBox[{{2.1147820855425192`, -2.2821698249394347`}, {
      0.75, -2.2762371811996505`}}]}, 
    {Hue[0.6450355463156245], AbsoluteThickness[0.5], 
     LineBox[{{6.302464808170437, -4.450050301458311}, {
      5.609114506107334, -5.4}}]}, 
    {Hue[0.4487872111514039], AbsoluteThickness[0.5], 
     LineBox[{{8.412962572471049, -4.416584131883879}, {
      8.506745675151512, -5.4}}]}, 
    {Hue[0.4935670836096598], AbsoluteThickness[0.5], 
     LineBox[{{1.8575330775666872`, -1.973609833425109}, {
      0.75, -2.286202570382883}}]}, 
    {Hue[0.6153041818473259], AbsoluteThickness[0.5], 
     LineBox[{{1.8331971455187728`, -1.49581634012526}, {0.75, 
      0.1688199539809353}}]}, 
    {Hue[0.6759137543017253], AbsoluteThickness[0.5], 
     LineBox[{{1.847484571749867, -1.5541627057341192`}, {
      0.7500000000000002, -1.379969662677608}}]}, 
    {Hue[0.6752048304997537], AbsoluteThickness[0.5], 
     LineBox[{{3.101985669129406, 3.8742308283456834`}, {2.975288809690501, 
      4.6}}]}, 
    {Hue[0.6598017017549456], AbsoluteThickness[0.5], 
     LineBox[{{8.301227485802736, 2.5779427149896432`}, {9.75, 
      0.11567783808227661`}}]}, 
    {Hue[0.6050722211982534], AbsoluteThickness[0.5], 
     LineBox[{{2.105089716554118, 2.2924074478347602`}, {0.75, 
      1.2544260083243568`}}]}, 
    {Hue[0.6112141593216166], AbsoluteThickness[0.5], 
     LineBox[{{1.8227355325169223`, 1.0030155268912893`}, {0.7500000000000002,
       0.4707323179671955}}]}, 
    {Hue[0.635536071743491], AbsoluteThickness[0.5], 
     LineBox[{{1.9620053601186829`, 3.0868466436547135`}, {0.75, 
      3.629250892615372}}]}, 
    {Hue[0.6787482293783424], AbsoluteThickness[0.5], 
     LineBox[{{4.30456992408814, -4.450885268302151}, {
      3.481404355630144, -5.4}}]}, 
    {Hue[0.6250167669810682], AbsoluteThickness[0.5], 
     LineBox[{{3.1843017802244207`, -4.353766402763522}, {
      3.280360365742378, -5.4}}]}, 
    {Hue[0.6809498460540165], AbsoluteThickness[0.5], 
     LineBox[{{1.8429277720194244`, -1.5431834720036013`}, {
      0.7499999999999998, -1.3117594152727874`}}]}, 
    {Hue[0.6887891439067219], AbsoluteThickness[0.5], 
     LineBox[{{1.8126837753289176`, 2.5667455556332626`}, {0.75, 
      1.632450992619971}}]}, 
    {Hue[0.5773787192442268], AbsoluteThickness[0.5], 
     LineBox[{{5.3435873933583835`, -4.311607522435026}, {
      5.1284600887553955`, -5.4}}]}, 
    {Hue[0.5549503152730438], AbsoluteThickness[0.5], 
     LineBox[{{8.2637206997027, -4.46240798472222}, {
      8.41186209041113, -5.4}}]}, 
    {Hue[0.5582340490592381], AbsoluteThickness[0.5], 
     LineBox[{{1.9247809079917395`, -0.31161928865510713`}, {
      0.7499999999999998, -0.2552318476916251}}]}, 
    {Hue[0.6773723080093375], AbsoluteThickness[0.5], 
     LineBox[{{3.7259065841173045`, -4.4409374302681215`}, {
      3.856328888908827, -5.4}}]}, 
    {Hue[0.5835566438294117], AbsoluteThickness[0.5], 
     LineBox[{{2.2382741906794665`, -4.436492633377812}, {
      2.2486306484639114`, -5.4}}]}, 
    {Hue[0.47904668427029135`], AbsoluteThickness[0.5], 
     LineBox[{{1.892191514199834, -4.095942514368096}, {
      0.75, -5.219973146163546}}]}, 
    {Hue[0.6865254023824128], AbsoluteThickness[0.5], 
     LineBox[{{1.8626583431103891`, -1.5802739192837725`}, {
      0.75, -2.7311201728047454`}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJwsmHc41e//x+29xxk2GRkRkoa6XxklKSWjD8pqaBcRhZSRRGU0kFXJCCGE
1H3sskL2yN57HGT+zve6fuef93Wu8z7nfV/3/Xo9X4/HkXa4aXqBgY6OToqL
ju5/1363R4dd9NcR3f+/JsVbyiZ30YOh6Kf15s+3sJhNqdB2+3U0N8Srd7L8
C67LuL5Z/IgBmlQoT762e2OCWs6WtgEzbDube2e16Bn2N9jn9JH2+RG3Jyb5
n/zxh/Q3ejG033PnNvOYOnoeh+Wx8jYfXkf61Oyv96Rc0IcT2y4X87DCowSP
9pUbEbje+VdISjw7rCY/f1U6E4eD5eoefxZjhdiPCRM/eAvweFBYTIIWPVhc
Vmc9dvAh/v5tf9LmoXUUpNkbHJDsgRk80tnJO5jhIMW0VmkhBb3PYn7wfZYB
/I3MLC4uFiESy57bQ6c4wMFv8v0uwjtcrLdfLb2PC9js9II93ibhNXovFemb
HGBs7RRxSjQFdU7q2Z/IYAE7o66KgdpvWNXy9HdObmZ4mJWoXnmlAp8rXD3F
mMAOQ5WXsrqPpeOXTV7XvHaxwqvlWBRdhPHwosaCsSAvyL986tZmk4o5qbbX
Z7P5gLR8lVvwViIeGzwZkzLDC3PzizcuP61EkF6JDFVZoW7to9a51HKkwZ0k
d9+TCU494t3B6d2AJkhP45iuMsLIvksLukcasPCO1LRl2v6SChPNbPLb8GJU
OrfuAgu41+QfI76jYCOWGcLNf0xAtbmlak7+hWXMpOVNM3ngpOLOj1HXKZh1
sia8ag836G4KfImpbce9CTtHlaL4oZHRZah49RVm2G2Zf7hSAERkH7CypQag
v6KWDmcy+YFrRFDbcx8F3Xrb67B4lhfKXd/8tGiqR6fZ118pqfNAoNy62lfd
NoQjDtAHTXLBzSNtG0f6GxB9HhtP+CkGiP7DoMAg3IoU1ZyrHJTo4ZHT339e
z9uQzhsV5R8q9KDP/m1Zp6EN2/tle+PoDST9N8S4g6MX/3yif1n2CiO8TLQ+
PDtdj/ddi1U24KGHE7f33WYWbMU3T91WEFDghp0apXJyrzpwy7beh74xnGBu
IMpZkTGEl22+OueY8QOLA+H1HYkveNelIHXTc3zQaSViMMTaiB9E88n2HxOE
hxYSlDSlWPTioXls91MhiCQkP9v9NgtxWCWu6F4UhNko/QvXfD5j7iBHnPaG
H4Z0QkXbHIuRfG8kOvGUD6p+J1W5X6hH24O1Kose84IDu3YRx3wbKqyxyPDc
4IUfyd7qL78PI//1jw975rjAgiBdVJDXjWRJWuW6bRxA0VkuIcgNIDGzp6I6
2Zzg2cFx7vLOEhR03Id86DQH7JDf/kuJ+gGHMmFeRRF6OCjws87gRRuyZvri
Ik+3hcjHLS5nBLcjuua4zA5uevCfkh9hEmrF2wnuOc/vbSBhlt6sGujG/pMu
bmGbHPDb9YxM8sIobnJZ+ZZWxA75YwpFk3rT+PP3h58ekPigdNu4IHlPC+79
PL1XiFY/XQ2PMx769mGW8bkgc1p9BI0sU1NXPqFJXeJKYxw/LLxhucf6twC5
dpX/IhYLg53iI40LpEL0XT3g85HnBHipXfDI8XIRksq4FRSiTYBycp218bFs
3Ofze+GlgiD0MhIPMITn4dIaPbF0EIBJ44k9hQ1V+KY7U4Uvbb9aJ1lnO8Z6
EdXXOGRRghNiLs3sJ/EMIhndX1GZ0nwQWLs5eE5/EvW+lxmhs+KDRuLT2pdc
C6jr3ddWwToOMLWSt7+zZwC1NCj2+y+wAelizANzwxG0xng3rbqcHUI2c6cd
Ayn4d9OzAuluNuCscIsu1WrCnsklHfd62UB93eC6xZtZzHA3y74mlhXkQ9gj
qjXncUehj4/QXR4IlnesYAvtxxzE9/sWVbkhnjchcthpDJ+K0OIxceQHoQzG
XPqab4it5Sl/TQYfvDthbBE6WYZO6ZW0fH3HB/rcA2SeQy2ovHb9wp97wiDS
pZHzNaIOpdvqL/1mEQYm6WcqL5Pa0cAy09I3IyGYOHzOdX6tCXG+6zDvjiPA
ygivd4ZZEeq0qO7ukiCCS+FSKJW+GG2yhye/BiI4dAG7+9F65HPlA++NvwQw
Lj/fxeXfjFzUSpsqnQjgIxDaVaHViJhd2PO+/hSGZm3b1c/yDXhgSONZ3Ulh
CCzbr87V14rvML0dI2cLQeUrZQ0XmRZ8xKv1uvhFITihf7/u08MqvDdLjoc1
SQgOo+C/vLKZGMm1hJn/4IdeQl+Sdm4jzpGdkYMmPpBBKf7G2zqwb/F/Vrl8
nMCULWQUJT2IaqeVDeNp53Np13+FrfYjKGHS6ORxRz7QEjRTPr64gP7R7zS2
iecDBePP5fanllDzl/OtUjms4GTz5mfuxXE0kvnd5UYjC7yirpqy6E4ja3uD
n4wSrKCatpkSnzaH9K4zqpubs0FOhV6EZMI8Yhl+Jun3k/Y8s5GLAzHNOPDq
l9XLeawQsXo3bjxuAJ9E03ylNqwgIh21c/zWPCZni154oMMMQas+c2/vL+K3
wQ6Gd/i5IcpmT5a36Dg+OpsTdTuOE7gj63MsXeawtpe5oV4mHxgabXpt35eM
3S/e9WQm8IGXy9P7hPvFOO0Kw3+6+3kh7L/ufRqGf1Ca2OX5g+nc8Ca7QUgx
sRXpnaf82on5IKj5cSRBdAD9zMhlnprigxiPklpfjik0f/9JZ8MPYfATbEkM
x82I60fM+rQ7AbrVj+4f0B5EjD9Syy3ThcCUgypyJKIHZWY3iA/0CUITEvAb
HRpCmQa/slesBIEpR3JH7Puf6IkNvHauFgBukh67l3kJ0jvJGkS3iwS7d6Sx
92bX47t0/s87+chA+vlrKH+9Ezd7nrgldpb2nnT4c010OWbjMr7SfpIEqUAd
9aOvR52XR29te0qGmjCj+Mc+rajePf/TwBUSDLaUFTw9/QuRW7R4Ak4Qwckt
g/+oSDc6bLosoepGq9eQp38L/w2iYjEbbbfDJPAx92LIMBlEdQZiZpteBEjm
o1hsG2hDu43a9PYYC4N5zauWvbz96PLM+zq4KwRdvy896yr7jBPOmkJLqyBM
yj5Ut5qmYFcNK55T74RhLlk1+19rO/Z1P+zj6yEMRXISS39uDuLpcA+v0FAh
SNL65uTU04VHvmRN5DsLwjFb4y65vf04Lct1S9tbEGrvn45UwRVYY3X/+vv3
AiB/e4vXYGce5vD4e7LaTAiOad3n6bIswOm2kcZ3SUJwT8Gf3W+5AnEZkUp1
ZAkgTa3u+OLXjPY6rAbopRHAscHhrAClF+0uMDhy14sPrjvV8WxpdOGDx67M
WGXxwI3oaJnaF31Y63n60YpNFkBHhS5rfxtHdoMzPMrRzKD5cmBwYHwCaQiQ
3s5QmGCBbiTF03YEWd6XE7mlwA/79y9yBv/3D+Gm3PaPRfzwcci8+dbeDaR6
yaGYfY0FpG8JmONf44j9oXnhY1VmcFnL6UnsG0cJIr0P3M6zwHr0/cdDjbPo
6uOrJJndNB5id1QSLaOifqfHY+K0/rpgOHCTLn0OpagFZLjdZIWUB8uyX3QX
0fpGYsA7c1Yw0ixJL3gxjOuCJZ/GmrJAGdLJ5zGcwl/rLZv/sDKBu6jjt4UM
Ko5fc9yv/JkBqP9C+zdcl3H17WSr4C0OeHms4oaKzQL2jcDtz76zQ++pGvaX
fkt4Mv+DZ8oKDwyVfKEbNvmJCxgP7h+7wAUXZ15VFDj9wfU+zlrSqVwQsay3
0Kvfjk4fesOs+5wDbMrHCC7R3Yh/nNNZV4gftGqYV9qq55AmlwLrPn1+OFz3
mU3hwxJ649OQL/uSAPd25z8p/jqEYiSrwk5oEOG1m0Qpi/0UujWwKhMUKQj4
MiP7YvcIuibulzreLQACSvZ0ljMT6M5SzROfOAHYHN/YF+BdjEyeDDTAaxqP
7A8h3InPQdbfGfXrAokg+0Az55R4K9b+t/eRxiwBYs/3yppPdeCxmIHOTwFk
uNUaPyYX2Yunhre/TnsmAtImxpwOXUO45zzptYWtCBhfiBYVsmvDbUOzQ/dc
yWAqvOep04tU7H3Z6+LUd1r/0ZMg1rQSfR0RLqXoE4Fv9rtJ3r9fiPuDS5KC
HQGepzoYy+By9DlGg1+8kwxk0tPzx6zb0Qfm10v6NiJwBHyvn9/xFx1TOSe8
cFgE4jX+ZjP/GEBv7sWQLXPJ4LrrwRnbyUHk/139zlErMgSzEbc5qPYhdVf1
nU6nScBkfVpg6E0lKhcS22tyiQiXdRbvZ4W9Rv3/mUg50Orf6G+kaVdOL0os
+n6e3l0YtjssrEjoDiL2HX0/j9PyILVoqfzn+iA63uDkMvmaCJqzG8sjTBOo
ZOZGcXofjSc+Z+fq6E+hnea5T+ztyfDeP3uG7lg/uv3M9oWmkwhUHRbPeG/W
i6psb9UwswrDV6NNXY4LA2i5diM63UYIZIJk+UZfjSDpcyp9u1wEoauoSk2r
vRQT3E+uPjkoAESG0rMKS7WYZ7Z7mugoDLy10VeHxqexSWDdYMh9Ybj8LMwl
jGcemx3nkhwlE0B0J5Nn18w8budJKaiyFYRiIsdWs0c/vvX1pxDpvgDs2pUq
xK48jDUS5ybfhwvA/SXsHLmcg0/nk2eEQ/mhXp7h+dqhxygSuWvkdwhCxqmq
tfT+dtRk+0P5zCdBGJCL7vIoH0TUC2q3FAYI4O7j19fJOIimLV9dCLlGhBKT
SfWzIZNIjmHXmzprbvA5WFuQFjGAYx+I7iwN4IQAZZYHLJ5DOOSBI/27Ayww
Z/zS+lr5LNp7nKLXrM0MCXfMzhdXUJF5K0txpCkTFGrNfD9OR+OrICf6lQkG
GA7b9eNZ9iR6HM5vNOjPBOe+TPTJuQ2h+50R/JccGKHwRb97E41P18O/54iW
80OeoYm4yv0NdNT+zL19tgLgwUk8PLRFB2XvN04dMmYE1pT/NuwFxlH9LgaB
GUt6YB5hHBPUGENC7XHHhmn+9WEw8DPp7hLa460boLPMCL/tjjNxPV5FHoP1
CvgaKzjezLU57ElFXZsmH595sAKptOhLfdYqahuRFUzvYYT0OHKQfhIV+zNM
RQ1VM0Alr/my4Y5/+EG+RaZIOI2nJSbvXvrvH1aIPfH6yRodBCjc2D2itIaD
uE9zz9rSQ7PzT8bWnRvYmXy7/ec1BkiLZJGxLtrAvG9MlP+zYgfz7uOzbabL
uNVB0mDiHSv0Pqc/o/B8FbuMGT75tZ8T9GquvjNIacHZi6/jYs6xw+HdUq/2
WHRgwoG0Hxp32EF5IjGgQ7MXyVo5XdJSouVp9A8LJcYB9Israo+5NT+0NBvM
7/D6h+gib+u8uUPjqSb18pKzm0i1//ByG20+7/8jrnLJcxEdCAiuuYtJEPDt
5J78hiV0dkO5mRgvAGVcWZfPrU2iCDepNfHz/HDy5xt1CppDdgtMpIliPpg0
7Vh/tPYS7WzQwgZEXnBqDdvQk0/DV+VX7xj5EqDrVeu+XJcuHOSdrN5qKQzH
17MoggW9mOXsSyGRRCKU5h69frtiCKvUJBYnPSDA6bM3tx72jGLeFA+n8EQR
ePZZfY+ewTC2lduMvB8jCu0Ot7ceLo9j4/bkjMueInBN7TpJzHAcj2eJ89Cd
EYEsPr1bzaIt2OeYzmEJYxGgYOObT6qLcZjFpSp7MRHwD+NYytzRgWY1+/39
zUXAV/XLtL70AHJiLo7IlyOA4GDFlbkh2pTxXOTeWyUM13535einfkf3uIp8
pPKEQZjj0JwWbyiie2OlqLciDL1HHks+NP2MNanbU//YEiDzoOGcb0MGvmxk
JXAxngCqB3NdKy3C0btX535quYiAvP83A0JhE8qy+tA0/1oU/EweP/qkWIl4
2ri3AS0vtXSt6bf/q0ckXfNqp1YRcLjgF6/p0Y8W1eI5T/wQBaZ99c/jfceQ
lPZhQqq3CLy7FHO2sHccgYm7HHmBlp/f9ukK+E6g3UvHRTeCyKCkHFL5fWQe
XVm6cD3bXgRUa4zHJ89MIXn1byzPE8iQ1iObFb08iGYkzgTfziZByM+dy7Fj
Q6hm69Anqx1kuFGr6URf3YWOdF1hc42k8dfngujGwVLEW2m+MzlaCL5sae+N
SOvDamaT9uEjgnDe8IxDv+EQbmdUONpoLQx0XOymvYGDiKlvuKqJlpeY+mWz
P2QEadXpijfQ8nlL3IHvwcYgyt1+N/aZCgk+ipzP1WWnPT/rr3LbGyKccu/i
6JuaQB/L43uvfSdC/K1Kkzv2c6jjxo0yYjQJDrCkU6ts5xD50VzW41QCJK5e
Cu9Jn0KtMzaV9HbCsPdAv6yRzCx6zMd3Ls5aFJx7XGNYu7tQcffpfPNwMVi/
Tl8u8rgNiQVKPXBdFgRj16LIkMJx9PllreQra0GQUnpQGv7fLLKzXPkyW8oP
Sg+o/SZ7G7Bno65sHY23Pnc8FWHd1YJVrMIWCYpCcMDc80U4PRW/HT6Ue4U2
3w8xSgmVryxjivSx8rk2Ycg/XuLlPE/Fj768WOs5ToAyTerJl29XMds5FXnV
SzS+s3DfPU1cwKnLOTnbU4lATAm+FZa3gLujLxxU+swPYpfa3psLjuOw49dk
vrbxQXzyfY+r1lNY8OfjTxUpNL7/ainZJVWEKtMidh9P4gVX9f2hcf/KEZ/h
Rcm/LwRBJJTfq0lqErVy8VWUPxOEvDUGE43ZOeRbMF6m/ogIgUYH0i5Sp9Dl
oc5Po+tESE/fZTY2OofuBKZs9n/lgCptrQm8NISt2csH+e+zgWbeqU/Bv0Zw
7uiFUKIgM3yvzz6fE7SE1mLud1TLMsE/UmnGSY9VlJ/77oTQXwZ4t/fn6Tg8
iRqtIt6HNdED3883zhe7J1E4P53QOC2/XdhWEnQ0xxDT8WrBf8/poEXsS7Va
7h/Mrl1YYfZnE+mk+2r4j/djRg5iX8VtAVCXJHps06MHNwmHJnNeQTjnPrRk
fYoRfmnmczJcYIR+R79R1jPrqI6BpZvXhwGEbQ0vNHhsolkFz4WaEFZINbsy
Z/J4A5UlGTzsL2aFGJ8phXty9ADPWQ6FUBhApbD9BvuZf3j3L2XFvAR6yO2a
uqMYtIEdvzuFE4pp69v5+1N4zjp+dbindM/oFjqqR5ZbmaGjxFkxOox9ZIBB
O/4yEqKjrG4mXil5ywixArOUb1Q6Cp2wx5fMJgbQG3B4LJu7gblEA658/ssE
9IYNqsUjG1hQJrGMJMgKaYHD2TV+a5ixM+u0vj4zxKmT7Nl2b2KV6ou+RbvY
wTj0edjW4w48uPug/oliFmhTfb78u6gb/5EccThC4/0TNip2t7UHkP3Or1wS
JUywS8RGotVhGF0Xx9v+ePEDardMFt9DD1YPzdCmEz94LZ7MuL3IAE9sr+q3
XyRD0qVxVo/5FTRlOdWbTxABN5NLpxvfrCI/u5xKi238YFTyW3aoaQ6pvild
GnXgA8bu91qDWwsoJr30XaY0D6jmEDWe/M3B4aMr1CpPLij6/pqeY3sZXuuZ
/M39QghkHRsDXFL6sfKcA5/uO0E47Ik96o8MYq7swAJRWWEQCHr9KcVjEg/Q
iVtXvhKCTc+7/nVZk7jXMzf/UqQIbHa0tafEDWERYnlvzSiNV8/bdZUsteEB
yTEU/FsURu15qnRWJvCRnoYvtufFQFUyRKV1aAZfd3nWn70hCvt05/dKP5nH
nUEPMyppvnmx6aHQA/8xvJeH+fQdCxLk+nHv3O0yiivaecUkTETg060ytkGW
bzhNnzXooIUIdGz/dkZ1uRwd6n66OnpJBNjSHHOYZIeRz/X9h5MzRYDjUY/B
9xuT6CgXlt93QRj6O209dkWUo8xQz7PfkBCc3JHD6ebxE3He0Bttovmo4dln
Qtt6o/C2HtODmp5CIHze1MDyWCMWrwl30N4Uhrf8zlbdim042SIumEeDAIF3
qzvlVYdx8hhTIVcVAS5aqCmSzlVgLrXIIupbGu+W/adWdOUPnlE5Tk/gps3D
P6rlJ6ra0cli4hclmn+jB4F7ihr7UMFWrlvRkCiYRklEye0oQdSvYt/4Y8Tg
jbL0asXu9+j8w6+leztFwezSQsxxtmT8vOSlhV0UGayMvfRPX21CVyRuSNy/
TILjqsSJp6ttqN/+n4gHVQQ0hUtMbXzb0e7Rk167FETBRudT2hW1XFSrxsGy
Y1QUto9b8UhPj6Pyg9IF7vFicCw03ePJxCy6+CNZKcdHFGgQHqHBOoeadsst
XywmgYJSwUgg1yT6lvqm1jqACG2ipsdfHZ9Cidm5JYcHyFBUvFhM2D6Enov7
eFB/k6EsQ9n99tV2dGuU/b/WO2Q4PLg9SltoEemyDGW+lSWDQN+d5VO+S+i0
0AvjbFcSvP/OdaDvvyW0bvvg05U9JBCMMz8CvxbQKM/YyB2aP0m8HL06/WgC
lWdtZ5u7LAqbpPsJLs396BnjmZ1/PxLh2jsX+7lbI6infbKq1I0Ab5U/1kYc
HEOGvA9DoiJIUHwvBUvHlaA0bm6nvZmC4FbgK7UoOYxHCI8EP9F8r1wgU7Z6
Zgz3y9yPUD4kCHuZmr4Y+k0gI8RgejRfAIrOXHt9/cUEck2N2/6TxsOfuqNY
qMajyPmzxLvCuwJwZWyxNIcwiPgnVWKrpmn+GKm1qr/ahxRC79dztZFgI7T1
PqvGIBL47GR97DEZfvk5X80QGkSW/Pxs/WeJ4MOzoNzZPonc0voa37cT4MS1
Hq6mHVMouVk4I8WLADsLmq/zqo8jq95LMRBCgH3cyt6ygsNIfprxMt0GAQ4X
mfkcaB1AGkVVFknCJFjRI53xaqGid7OsE0xOJIjaKDo94LmKCvmfOK/6EWFN
apr9m/YyKq5LHQ5SJ4PN5p1SJ+45pMdUKRAZLALB4S/V3A1mUdrkoSOkRJpv
LQ5fEB6eRdV8xtV8/oLQri0e11Y5h2qYvDP2HRWHzrlLDdbHW9DBB5I/d1tI
QE4xU75DYxNK9D9J+EMnCE3Hmi+4+s0jguTF7gJfAXj7gCFiopmKrExLbzVr
80G/wI37LnyteMq81VyhiAd+P1LbpoM68cHbJZFbdoKgeXo15IHlP+xWqsp9
n3YeVcXpvBu2Gzhb85SZ5zUCxHMoX7X5uYap1J4D2dUEmLxmcs+IcROX9Ymx
57kSQS6yYWb14wbeld9boXufBI/6ll+EEhex3We/X3m/yPCwX+QcS/giJssZ
n6qJ4QMBUjmTJvc05uazmDFp4QGTBzVErd5ZnHWny87RnhdeEbXvyWdXIOYH
1A6/Ji5wmdpxdL2kFr2fQcSHiYKwY9dkxN0UKnK8/2fJqFEQnq9fD9wbvIpe
Kh7KUTIgwb6Wr9/r9ywgT1MCyzo/GXQCfhxMSFpC5/LD0xfvsEJ9bKBFcMco
Vv48lpR9hBk6ROqfHO0Yx9s6Xv6O2ssIdV6fCg0+bKAA5sdLCeUMMO7YxXuX
kQ7K3XafujhDD74MQwzbR2ZRthGF26iEDkR6N3QT4xcRm7+2WWs/HfAf3hYc
pDGJ4rzVIpu2b6LFJ4+5+FsmaLzhsBBfTwd7WKN4jtD1o0237edeHKQDEy9q
c0V8M5I/8uOeJY239Joc2/K/ssAB6Y4M21AhaOTwi3hxhg2ciX/zVQ3pwaRQ
n9vTkg4Ygz1M1HO3UO0ww+e/N+hBs3+/EGWcFQLcKYFmgQxQVPr49z9DNmit
p6TM+DDDRQ+xdeO79PCFJ1ZlXWETD04+fftDjw6O39r9vJU2v/vKRvOjSzbR
klH6YG8eAyWCP37u4fwG2nno/PPwd0wU97PcDMGYAXS8D34jfqCjjN95p8wk
ywhvZ323h4wwUFjMlJpi7zBBre35NQtDegrFOuy/sb8sMPjJzmZKg4ESz/mC
356BGTIP1dVrzm3gq0s3d5c8Z4H6e3Sv+1o2sMSGd9QiCzOcort3U91/E3+t
2opK6mOA9ObC0r5wOgrPtWvZ2VnMENuj01AJPdhFM/6bGTsjHK7sfVYS1Yeb
Luw/UnaMEawPtAwcrRtFplL6rXkP6EHcYPGtW+QEiuS9TBy154eLZ2I5JDUZ
Ic2k1FjARwQinKMFVIzWUNJrBXkVN1F4tDTutVa0jlL0KCOdA7xg7njfZCuU
ir76E/fvmeOBnS/qw0Wal1FmVbDWRCMvEJJjv25orKKTcSZbxSc5oXEgNzBB
sQ7fjT9iTSCyg0htv5mCUhsOudv13OitIKgn1HbMHx/ESXU9Fm2eArD/62n6
ycYhPM7QvP1GsBCwFZyM2hU3iSfav0Ra1wpCgk+cq7fsJDbbPX72sCcZTqR4
1+iy1+BT58r+aLORYfc26wWi4g9Myrd4VqglBt5r4/aZjWPYTCrQevyyOFx8
bWUl2ziAxw390yOHxIBtzeqKhvI8Hqz/LfM6VhyE0prM29OpuFjdaD3ivhg0
iHnmjiVQ8dSeZBmJT6Jwj/ov74DYIk4FLiugE4XQD1KrfEtL2PmPidu2FCJw
h8YxblSPYMJqzasLrgQ4onUVX3w7jBNsY31+HxOBxmTV08uBXUjReqtDYKcI
tJevflezH0TEiaPqzdqikKFiOtvIPo8Ed+vdtQoQhYDxV1lmO6moqy/gUvkV
QTje0fpHbqYa+aoONhk4CsDIDvpLX97UI8XXrrXyOkLApMxd0zLSir+vn6Wy
hAkCdXXXa566AVzA4BzNbkKAV+deX8kNmsTUgt+//rMjQEfrTkLXlXlcd6qM
3N5PhF2NX1VX3FvwxYDncaetSSD6RZfJIKcbM/rFLSZpkkH4YNXwS5kBhHJs
wmrSSHBFsDisSHsUnVQ9QrDsEQX3qWKHOIY/6OqyS/qfdlGQyPSpPvtkALk+
Hz2qGS4OGwePy07O/MDrUrJ/qzVo+a3zNyrK4ie2CxH08U6WgKSoJhGtK5k4
bOBLwoeDonDHyvGM4EYhTs7a8JlVEQHnycJ51doaHMyYvKggQwKx89XRMu3t
SKA2mrPvMBG0WBamfq52IwcCwfk/PRrPpOi9EFz8hiXzFG95Haf5tWIjpflh
C37N6aOvJi8GW6Vz5Xto6yt3ufpZ1FEMlOJ/iHv0N6HXf1o60srE4Nz4dZ2n
aXOIZyltSeaKOFSaxQ42vaYiTX3t4o0DYlCwESCVWk9F3Ydsu2uCREDNbmnq
yeQsCo5kemqoSobYMBvRhhyanyqdCbLMos1bDTMvydvTiNVztoOd5q+nz9Y9
ld82i94FpNAVFJPh2bg0V4d/JSobuidV9Y0M1ddTyHpuRRhpZ534l0kGnwtc
qydaqajuz+rvTSMRqMjo5HewWEU7G9/02tH8npvrj/jHqhUkQH5o8ESO5vPj
wh91W2n9mCUTwuJDhG17M7HziX/IVjvhWsQaESSLvtMr/6Ui1wSlLjLt/qSu
MnIpwzwalL74zXyBCBLw8apR7Bgye2rLxOwrCplqAqJfe/vQe075yQ0zMQjc
9ybo1tEm9FIrkPz5njCIJtSKGlWPI77ebMlfj4VA8uLuk2rxE8hw82urAY1n
6hh1Mw+UjmPT7a0yXLf44d/IQt6L29PYJ01dRSBLAL7+jjl1o3sK5Rej6/bX
+cGVbqhdI2QOOfe8rr5O4xnjes6hWhrPyGvuP8Z3UATOm1uXXGUZRMunA5Z9
sgkgHy35/rHKLOqaPDcZVyoMdNGUK3U755HVwRJB3jcESDgj8ft84CTKbzra
9DVFGDIPqgRM80ygiHgBxjAggHnK8kDAjSEU8WtnLc4XBlMly4rcvmZ0Xa/U
8vkuEuxQcz1qZ7OIam9Mm7IFkuAml97Heel5NM3edF3QmQQ6eck/9kmvoeLB
xrteRSQwpt8/0Vy0gUzTA+pFXMhwPj9zW2fCBpJ5fIWePosMzroBtmLzq8i1
/OlikzntfPx2q8g+WEIP0pvsmy4Q4JGzc2dKyDy6192YYHdTFAbbVLgz3GeQ
y2ZFQPRHMcDCegeTNKcRb/srhgZ/Gu+0HL584MQ8ejtz06Msgh/OMR1kLT45
j3aWBp4vfigB9L8v62X9bUI5e3V+rb6QBDUJvJWZ/QeF/Plz8hyNl4xb/eYS
2qjo0cEjysmMAqB5qUR32Pof4nMd9aH35ob7rpbl8h49ONtTz3lKkBPqb9p8
dU0dwK5pkZ/8aN+XSA+61xS3ieM+njI8VMkPR+k1O3zP01MEoc/b1JRW/8pF
XTpr6/i/uFr3sW5h8C8pzuhnpKdET4xEsD8jgc/vvft0fRgoThZzlK9kMmSb
cL3Ykmak3HM/JjGfQoYHvNV/yKEMlCJ+1xk+KxJcLde8Guq0jo8t7X8arUaG
P96FD6turGESPx+rNq0f25ifGUxWLmLXSAUUkiEK2X/aIsW5qTidm/L+AzMn
GARntTIOLmB95q/hTqls8NT3QzkhmIoJ8ydFPHdxwh2J8YsaBxpQ8sPfN58l
s0FhvbjVm4dNSG14n6PFkiCwt5/xVfbcQJSO8+7VykIwymLzOIdCB8csmShp
NP8aPvPstf+fZcTkYOt7WVEEWj2QW98TGp+9e5xUacUEXD8bY7leT+AJP4ay
l5kMoMtCvHhodQpPzd5s+RTBAL7G9uMBi3RAbjxTbivAAGFrrQ93zzNARFoX
S/UdOhgmnNY/U0JFDAFf1R1hE8nMW3pQF1dRpI5frVX4FtIuyF7Y1l+Onv9e
hVdlG4hEbFN04viJuX8kJrZmCAFqdMkK+ccG26hue8w4heGB9CHp0/Sc0MWp
UGvszQa6H99OMwqyQtbFq5s3S9hA+uftr1P+7PCM7/Cuqe2MMCxAVA4mMFKm
CMo5YsGM0D+0dpl9nokSc+Raeu4XVkhl7ItYecRA8fXdRl7nZoe8FMW0eRNG
ioCqZ86hv2ywLvenTn18Hb/qZVClP8UJH/UzmU9WrWFv85tie0oZIFRnZfVd
Ih2FeuvNSuFfOsB3foUVTdNT6L3bnW29GWAHL6fROZZ+3DfbMHXxCR0Ipnqo
fz46iD3bqEwys3Sgypq/6n9lEgF39fd7ShuI41nTjcdSswjF3TkYcVYcthN0
Yz8f2UICE7FhK7T50zOYKrv0jA6eCDPXugTwArCdqXE2oyI6YkD8Qz1u0N9h
qv+ncwH98G+/9diEB3in66TYB2h5uqfwdZEsN3AaQ/RBwiZ6dKqq7poXH7D9
OKn67OE6yvD/Ylmwkx/4Qm4Q0adN1FMiVy4hyA5xCeeexu5tw0JVYurbW1nA
/9IEpTOsF1M5YpNqP/HD7zNF1z5rjOBdG/e9dnvwQfBXDQlh8zF8UPf5/p+R
ApAqUbFkVDiJHeY5n7Xe4Ye3d8kObKlT+JmXlUdnOgnO6Fjbbbh/wcFaOn5p
t4jQRH2tts/2Czqi8P329yBx8NM6zPJn3wDmXgix4aLlA+s3S9EJ3IVds1KV
7guKwx0NFqKJwTR2DUWKARbi8LS51M3KbgC31fY8OpQqDm9tPlqHTVKx1vUX
khL2EiD35vieuel/eDOxeVbBUhxeLo3Nbz+2jIW6vl5LSBaFHaIhDR9vUrFa
KjOx/akIJL0bmy7joWLze3L4YK4IZBUxCRfyrOD8048k0qhkaL8hc+mM/yrO
6Kqw8JAjgMDn+mt/jg3jl9c3uJQ9hUHVhOd5TNAgNjD0mllZIoPIyXGPI48n
kIGlUa19Ihm0MmzUlIQX0O7TzUOvX4sC2TXvZYHxEtJ79W1bVjfN748MsLU6
ryLe/gDbk638cO3W+XirQ41I3q1XdWc0H3j97FZ5YtuMirGcc2OoIGxmbmOJ
qR/AULqP03pMANqUBZZtrk9gESXuk8tnCWDtvrnWV0bFW6Pa9W9OEuBFm4VV
d+Qqviij8GqokQS7hnWOHSkZwG8VuStq3Miwx21NdJv8BDa5tNu5wpcE80fe
L4UJjKM3/+XdFiolwi0jwnyxyxxtfu/ngU5RCBtMaUvkmkBDs8PuecOiEOhz
1FWOlvd324ONvd+JQ75QrVLUejP22PkbexaLQzjRqegv9yDulf7zlOMSLf+n
FXsa2aqwEqM0SSpQEmR7vFV0EhuwCDmg8Nw1CTh55aLZ3PdKrLS/d3xhWgLa
5PFY+qNElPc3ckH9uST8GNc1kO/8g6g3jjql+JHhC7ug20zjHzxaafBfmg8J
Zi9VrfWUd+AiJvtDVp8IsM1xLEGWvg+lnu8zlrsvDNcjr24FWQ0ibJvBeJ7G
Y2lp7zxZ37ZgEeus6/xnafNtW9z1JNV+vL/wYJTFNTG40fXkne6+BnTaYDcT
e6QYbE5+SOD1KkRu9qHLyWLi4KT34tcH12nEo+QuW/lcHGJO7eh83jeMpJtK
Wl8+EoeGG6Mybw8tociwYwqzKhKgqdXjmJqwioKPSA6rc0vAVt/72cpAKvow
m27X4iIKTxWHIhfKqWjov9MtP06JQNWBrr3Ct6nI6LHYtEsJzaet7xgyx86i
doOoQf9AIvz57UXio/HbowdyrzdShKDWlBRT834WNTIoSDjfFARP9Q+W/x2f
QyU35kpwKc1PDvPPXrrSgVVqftQ+7yGDgQ9PaTdxGFdE5zjZHxGFDZF/s8Ut
dNCmAB3mb0XBlFtsONCSAQ6NMLI9+UGC/ZcHvsc7/kO36QKTOOTJMLjMyMUt
uokMdxA1onwIsGlzqPbt4S1keCvkPN93YTjAqOM+nEMH5guv7koGC4Oyg0y1
UfM88mlMLHrbLQSLIp+7tu+dQ/6G9Y0/aP6i8XEt4/oRKqo3PrTP25oAETey
4o5NzqMbFvQv1waIEHvgmvXm8BCiYzJ7WVJEBDZBryMF4W1I3X78h56rGIQe
uS6jtdGA1Pnp/XNo+cG36TvLq1CEbP7YR3FfEILM4RtfOz9OIH675YzRB4Ig
Y1pIlMqeRPuqUhNqEvhAViVA5yhxDvOoqEaHv+WFQz0BoWefzGOXwD0nwnX4
YePoZbFXc3PI8cL2jgsOfJBhbMuqI7CILmlbvWqPFAHFvFTxjvcDyG234aP9
T2l584DJSzV0AFHPfIx09xcG4Snj4Kcx88hI+8OwqYkQhHu2nVCqXERDe90e
/bsrDFxvWj07J8eR4qHoHcyOQvD4agJH+rcx1HAip8xKWhj4+OUmi/ojMIty
2Y1M2nn3HeoyHS1sxq7dK6WDtHpero7VXTjYhnwPlBVXvhOF8h1x1l+P1qFk
gqA1VYwE/Nsuru6W2EA+1Gb+SE8ieHff8J3MoIMfAX0p0YZk+KF4QmybBx3M
yn7vuUKrFx5XC+VTmgyQf3D8TV4TCfQ7HGudOxhAMiOc6hAtAtxqvcL3Y9aR
tnXxcMkrUfjilOjHF7GGVFbmdPJo+SMq+eSgtuo80v4T7DtDy0vxX2wfGm5O
oi92QRP0P8VgIdDM5xBhGm2YZ7aYPhaHms8hKVN+kyhKt7rF6yw/rT5YAxt3
zaNLp1MsJuL44AKzEhI0nUd34jutritIgfv95z+qmxuQ631X/3elUiBTMxLT
ElWDjvu9S5wr4Yf+j2LnCExraI162Iwozg/HlHz8VdI2kf3rmSFpOw7I0M7x
kSwZxLtCyU9KnGl8kSq8W8tpFBtvKzvOGs0Pj/rGO4fb6Smmbyb3bNHxwxvh
dNMnwoyU9Afi/FdDhCGMeeJ5+ycGyiTzUQqdpTCoUE1nGs8yUTKgKG/HCAmO
vXfXt0hiorzRPGvUqUiG0xk6Div+LBQv9SGtGw/JsGDCfOOvFSNle3bJ6vcW
EfD7fUDbjZ+JciMuPl7XWBysA+fsHp5cwdLLn0JjJCSgfuHAeZY/VBxuRanO
5RSB+NtyOyxjVvFPL8c7TM5icKL4UOqsJhW7Phq3KEsSh8+3Y1ekTlDxo6OS
3Y1ebADJbwwTk6hYlpPrwL4ZFmh7b/z6iNAyzmToDSigZ4XDemLvbv/Xgs7l
vX+W0soE55IyP6gotCIOod68xGNCsPUsRka/mx5yYsuYsl8LQaXq+zxmKgMw
mjDuL/YRAWv/O2PrgWvIPB/rjNP8OSTCZFbZagOV6P2X8hfRQ7xveycEzuK9
9O2LuokbKOJ3xBIqm8fPZYVLS87Sw/W4vuncvczAKyVHQhM07jQpOfqUiRV+
E1v99hoIg0bMF45DJ7ng88sv99bfCwN94XvrQy7c8NH9b7BoHRvwWD/pusbL
AUbqT2M+7mUHhwKPxGJpTuC4uC2PwsMEH/kHo9tDWCgse0q0KsOY4Kvu8ubB
SDaKTOigSOsrLuAU8q+4dIaFYlPdY/p0iBvSH28ahexgpUy9LNYsneWCkd2G
3Lnzq/gXv+t7Y1keuMgYOWFevorz+6gpLyXpYCFJPyrHj4Fi+y/3+MG7G+jE
wK794j2MFJVjc0KZUlK0EWqrTSyhB6GckB0MWVLAs5eZMf8FA6ixLMpdtGEH
15B+M2RF8/1USdKLnyzAurRdf0h0BoUbPTB9x8wNrRIOhhVhm8jWycLlAi8X
dH5Ksucj0YPoJ2cm4kN+OK9yIarj0hZqwTCVHCwAv04dbtmsoQOCvqMwy3tm
cP3eqDHANoDHhVo3LtQwQlX//VrF3iF81Uj+MosEL0ymPq3r5Z7AGce+/S5+
xw26k4rBL/1pfCDhEj75gQ/4vly98ylyGoulPWtU/ckDaTjowZTYLP6Wzw2F
/ESQPrt3r/AljH6UGz5SMCdAzhnG3WkatSjiVc2pHaMSILK6UBp8sg3z2cQ7
94dIgszZv3lq/+pw9y3vQ73nxKGPI0BmNK4PlxGDA6Vfi4N3cdXAJ/sWzKZ1
MVbwgzgYv59lM75HxdvvitnZ0/i5Lu8Ik97VefzygYVrcqoEBPVnNJNi13Dc
jz01a0aS8Obfrb7ZgU1cyWEcfOyNJGhcvvpReWEVlwg0jsvuF4ds22LeQrpl
3O8RQnK6LgYqe3Ze/OS1iOXPcNzwriBD4q2lhmtfF7HA/ld56fdIoM59XZCL
cRH/tP9dXHCcDB/iGtilrqxj3tnDmrkvSMBYcftplOUmvqJjekk1XgjsW3JN
LT72YuO9I4lF7wXB0WVE/vLZdlxY5p/34CoZLAt2/XnMtIwmbr/T9Kf5uUKU
EF/O2X8o+1KXQfsuMbh7/L/Z0d1b6JzOIPOLE2LwtO2QwfVpOogS/q6dUMgF
SUMTLaSRdlQZajizN4IDzIu6vc7SdyP/e/q3+5MFADuatYzJTGP5yH8xv5gE
4A5LTtA+6hxOKmRvemVAgK9cxaPP+tZx1wXrW/bSBAjc0I4zY6CnENN93wi+
IMOqX5F/4aVJXP23WWp0vwj8Avbg+zvmcVzG3SmneCJIVPEdWzw0j8r2vA/f
10SAtot7lRk+LCEbx3fnvy2LglafpG+YwhJ6vnRX/wu9GBAWNdN+ma+iT4yD
G2F94jAhtGZl0jOO02Ty++1IEiD03cF+RXUePykavj2pIEHzPD1HpbCfuOzz
+I7laHHwqE+e4dtWjIdJQqfP6ErBs5CwnRsJzbjdMjV26bsUtJpe+y/2VysO
W04N3lcrBf7H5I8LRVPwC9tzfQ3mEiBwv1A0qbkCbxj0PavxF4djWbdv37D5
ilVEOLJCsiThv/ZVZ6eVVrSxn9mBV1EKvneNORqcGkKe3kFZYaYkEJf6bne0
rBP3hP+pdjlOhBjjp+w9uBe7HLEL/XJOGFg3jC4TYgZRoOFf651naX7b9ibb
694I0u0IvP7irijI5U8pOWkN4wDF+i2LAFHIaV83eGs9iVVOSQf2LIjBrtnW
mtecxXhfJeL3OS0OTI/ye5BiB34/OVfCnSEOhqWyYQ/dB1Fc3Yz0f+oSoDMt
vo8V/UEGkmCqSOufn+wZFJlRKiIH5au07BEDGaXrp3byLqDtoje9n9hIwL2r
s9F2VWtIpijrZs+CBLxXy/vn+HITxfK62h/7JglL11RECKnryK02XKHYVhLs
hd4sFh/7hxSvu50qW6f5WG5H/fZrC2hUiZ9DrkscgqPceOqYJlHhuK2/4y0y
qNc+WcxcWURHv1bOJuwiQRmrreYvWEQ/8l9WROUQIG8mUYHz9AyyOcD3l/OC
MIy0dG293ZpCb+9ci1f6JACRchLbol/NIRY0tMBA88moIOHeCwVzqCNw/xjj
Chm+KTgEfXkxjh3KkgrEd4iA3pl0ZdCZx/DB5l55mijsi/74ozOHAaZfCbQx
k8RA8FHL6RZ2ZvCeVVm3uE6GRham2PQXdPDWuPNl1mea3/XrnlT3YoB4odX2
m4+EwW9Hy6dldno4+VX7SNJVIXBO/3b2SBwDJO+s5A1KFIKckP1MS72zyH1R
LsrJSRDcKrQKY0an0J2DqWVPBAiw4uFrZ3d1Hi3sWtzY1SYMnd3zvE4m82jp
bTp/Gm1eXXz90mnP8BzyaftdvxlDBHdR3W3c0SUoRQrH80cRIfHAjbZ01kLc
eDJE44of7bz/42Lhq/HB9JbnAz10JUBfdOV3an0lvpYslK2dLwBD1Y0Tr89P
o2KG8FxZK354QXy/ovRtFl3omxDS5OEF50/JXsp981grkSM//Aw39DyAK4Yq
i/jCyKDXnzReKM506pv5QkWzp/j6Jqk8sIcw/eXOvWV01V7jw+cWMeAnb53n
LR5EQbx3DeRp6+Fu4+g7fm4YmQjLvijlEoJcfVaqFVBRwQe+5F/nBOFzAeNl
f45lxPVU0Dg4QhB4PrIptvuMogCxxYFJKwHY73LzXaz/MBKWT2q98UQIQu85
7OGZ6sTcDaUXV7cLQVWV2omC/UOYwJZhs/VLFKKVk4xZtX+gP2psh5OFxeCL
T8dIw8lsfIWZ86H0USJE8lu4+brRg3Kiw4reOAGQ0grDtggGkDG/Ecd3hwyC
048zvBEdvNzU0+2m8cmeS1xMx0c20NEh/pxzA2QgH/7rrFPGABESV/wbzUVg
y3mHcxA/Mwhk+q8aaZAhbrNSTkmcCX4r1HkOJ5PAZMWGaDPLAEpp3Em9QTQ/
/mokGPqeEaIEBS0FzMTgVOSX0bGUVSTiVrBf/Ko4mB/J3M8Y9w85JbC807sk
DDvSKzJzwidQXm21HaLV0zsRu9Z1wiAKq5lhrvWSgPGZHMvQ/WNooyHnCU++
JHSV/qJaHh1C33bLGanG8MGPjVe1p83mkR/7C+48D16YWPkhO/luHk0wPFvI
r+MDNu8izb/CdBDz6rpi0h4+aMIS478l6CHzr2hzM4kXuM6yK9WZ0oH7+k1Z
SWNWqHFPa/Cnm8BRpQyCaovMYNYWtmUlMIXvcfzlf/qCD8pLpvoLKxkpOzjj
5K4b8sKY3GRpEi8z5fcSX/GUqTDUbQjm975lomQqt2SHiwjDcFFc2mkZVgpv
hltH2ikycNwkiuxrZ6XoBJrGBb6l8a5Wdcjjs+yU+edj2//nu8y+nxqcHJko
fp7VCQQ9MTjrZrRLLJqJcqHd/UP3Iwmg8M4dz/+9iH12jxJyEiSh9kO3SBPX
PF6XufWPI5S2X1dP5hgcoeIPOw9rqZVIwv04AflTa4u49f471VtWjJCg+Gze
LmQNqzm9+bAnlB5m1/WfG7tv4Iolb067SwzwoMBgg6zbgsp/pz7+XUQHm4G5
HPktTSgi79WmgLswHD2lePDFDyboc70p6cZKAI3pWvv268yQwnt0p+2cKHjO
54htK9lEjQXVHc+sxeDO2XgLEgcdTAa6hGq+pIM7UwoD1yrYgHzmnTehmgms
OTk8OkvYKWoxVqkFJ3jhxa0mv/V6VkqGw1sqWxIfXExUqMj9xkZhIvOOndDh
gwgGw9gS/TXMPG4pfTGdH1w4Pdm/j67hlkjJm+vHGUHh2qfB3q4xFJB4e5nw
gB6iD9+dEbYcQWzZga4nkjhhJomxi62eHp7td94bmswB8v+cQ9xFGEEmz/3b
jZ3sUPyyznf0AgMEr0tcsUkXAO/48G9+NO4uc3yfaRoiCGtsG4vkCXrIlVuM
OS/ACIxSTnsmUoaxiabk7ceRdJDyFILXmMfwSofE7Sc3aLzY2jCh5jaBbW4X
vBw05oR9uge7sx5M4GIuOPTQjxusBHwNP4XOYpvLjftu2XFC/PcvJyoZ5rBj
WuygZzqtH+4f4GGP7kFpCuSJC6mCEFFyeS7t+yDq2JXTea9VElqkTH27T5fj
JHK91bSxFBwTKInJ/JmKGPjCHR/T5pFFSp9IsmMl3hRoVMw3loAEDcuhmvN5
6B89e2jBnBicvz/7OdNuGpv+1V6zthUDpmBW3dR7g3i0otX/Mo0HYjZ/vHVk
XseqPz+ntNuLAdpum63mv4493/5X3eEiCZ9frywtvdvCdtUym4acUtBhHbfS
yU1P8UosN7Q9JgUR5c8W4lS3cKD/692+MZKQMy/0fC52FT87QanQm5KEIDe/
lhirJWzn3PkteUwUhg1gHN7O4549vr25SBTeert+kI6ZwZq36EQ10ojA41+u
V+O1gIMJo1v3rhDgIqtSdmfuPHY+qvXZOJgEcup3SSv2m1ijYNf803wipJmE
ku120FGcHmdVzR4XhFJfpbSEjRY8On1FvPigADih/CPb+Wvxtmh/RjF3Mkwf
UG1uD/uHTrW7ED4lkOFUT9aAc906khdm1Fo0EYOslMbyC0700LRl99P7hhgc
orxdWKHVj17AXXrZy+ww32MmMLSrB3EKO/8EIitIe2hs0xnqQz1rzylNKfxQ
0XJ8S+HEAk7NiHS53kGr7/78WbZpKn7y/sGjj8wE4GsXWQ7zYaD83PFLWqtZ
GGrf8y/R0zNTLnCvcLCEikB1xPV/72i8Hei1ezBPTRRicD5v5/oSXm5TPEOI
o+3HDzYbq+xlVMhdqVtC609VxaDQn3dXkTZZSvoIoxgYPMqV//d7E5GeFmmr
bYqCbfKh4fBz9PB0rS9i3EQCZKP+fU/SWcKOoedaS/73/yTfj1eiDf+wv4xr
V9teKZBV3sh54DyMv3J13a8/KgU11qe/KZIncWH3tOahFinwybTbl3V7Hh10
kqqKr5YCZX/+0Y76JaSfQDmQ+1YM2HiFXv2rjkfMYRVuLU2iwLZwUH45iIJi
xRKSmXdIgcJqU0dF6RA6f6iQVdxbCs7v6KjbwzqN6q6THITfEsBk4dxFg2/9
OKBm89xoiDBMmtV9yJYcwvVsD0+GXRQEk9FrlwO/jSNfRWnW7aUC0KIdU2OV
M4EmT+pQx/1F4T/4lvZf9CTOzXasYQ0UBc5frz6/tZzHeQalGj2W4rDolJmf
yNuJ6/atV9fT+BLtCO3k7x7Adt5aZfWnJcAsP1s1ObkKuel4nXn6RQLOMM42
Rh3PQLkHskI0L9H8KupYR1hCNmryP7QlPyMKgQvsUgvm86jvyM4bnHdE4VcO
24u7D2eR9xRf9lKSKKiV7Wp+uTiBWg0ebZ9llICIhhGOF70baEuNYcLEQRzO
VNlw3BCmh0dFxvvXpaXAW8lNvfsTPZy6+UVf6bkU1Epd7XcQZITosxTFuSdS
0BB44IfIXzpI1C/+PZUjBW5Xhgoqdiyj12xpNTfnpMCga+9CdOcimj/ycnfL
LykodHa6WSo9j1jYJJ7BigSc1GH9MfRsCR2w3y2gHC8Bpm8M1+MjF9CTDwZ3
TWrEgXfyCUNr3CC6qR/slpNP459P23iJUo0ohXxPPI9ChLxcxqaU5QW09rK9
l8uSANNpfU9C5BaQVI+08LlXQiBX0JB7y2gKUU/d1+31EISDvMBfMTeJMk50
jKoU8AF5m4VIfMwcamIQG2/4P4rLPB6qt43DDLMY+27MDJOiUpZKQuXctkqL
kD0UkV2KLGUt5IdEytKiskRIiiTFOVFEInv2su/Z9+Wd989n5jNznvM89/29
r4vMC9v37bozrjODvLbbPBVnKg7/bTUKxx1bRGNKTML2eDHXX0fE8k+voq5S
hPg9zjQoX6NYKtcQYM8gB6/WYxpY2KTf2DAkwWqfMbWwiALvbwpsKvzEQY1y
lSY6RwGVtX1ZCh54aDs3GnN4UBBch64ui15ig9O13xS9MgRBoWVAK0WRHeyS
WWjutYKg1zZb+kgYD4cN61VfHRUCtbcvSp4446H+4LUb5i+FQPaap/nNGXYY
GNEZmPkoBKwECbtqHDvQIgvMJJyFoM10dImPOacuvDv94+iMIFh1vRnZb8wG
nxfuphRkCoLMYd32I8LsUFlUu6hTIQgRT8tcylnwcORRafIPBSEICFiNinLB
gzuf3szoUyEQ0D7x+hYRDx8CVbT+e8cPzUr9mztfjSCi5ev9+X58kO+fIXtM
ahCp174hLZokDNoClxtUwuaQUzT9Mb14ITjaFJF3ibqI0Du2r4vfFoY/wfum
3KJnkTgW8QP/dIWg9oZve/cR5n3enLjefVYY/qbU2N5/PYMkcysreb8ThT8P
Htr5Z7SiODH7sOl6URAZHRloY/ZLE8NbcNJOAgYdNYgsQT9QE9MswSYlSdBv
CfGMetiG3j4wYXa0lA+0eboGcj1mEAXpgV4xM1445jFTt91uFtE42LGkJMkF
mBTu9XkmzwhZlVgWDpNhtMlYqWZjEc1oPBrNtZ8TOHrD9eZGVlB+toQzoY48
EHDoZ9nDsRWkJz39i60TNyT99kBLkjaR95Ttb1QiJeD4zqUYf78xpH2zXrjY
QxJehLea4GUmkV+i2TrqfQKwMUiZn69bRgiKHs9JGgIQOYv1695fQ2Qlh318
nvFDTJXGGpsOkz8ps0f84/ggycxZ9MauASTzA3Lig44g/GlLDpx9MIPSbp57
e+StABh1KLxPbV5AFbTGXzrZ0eDZN6EfAvfr0LShqwcc22ng/lqMR7a6Ew2s
3JGc8VQEkvIZpy1OsQFeVkjqQpkwZEzXVtoew4N+sA/lUI04EM48uLEd2UC2
l0uGnk+kgjbD9W+rzBoid/dH4tez4nBjIEr01jZW2NfxzmvXK3F4d1bF+2nJ
JqJJlfr6+P/9w1EeIEHDQ4cCn9j6V3FI7VF9+58iEWzQcCohgAoylML8ret4
COMPwu3pFgNu/axbWbVsoBE6xG1SLgpITjH5+CAObtu+5776SQQavprdLwN2
sHp6MrgsVhiSWljFD7HiwTirVb3ClQ738uK0+56uINlmZz/aPJUAEYnb3GcS
lxHvh0FXE58JwcnNWOsXf/oRh84YZ8sOQRgJovVoDbYj0fuufLerlISJhJts
vBKDyPLPHy5iVgwIJcr/3hnwFzGv6AhVWOaBaJ3O7szHs8jY2WrhzWhueDT6
zr1peRa5/8L8DK6PD3Z82e+km8cCc9McZ2UU+WGpf8vlwmE2GI56FjDoxQP9
P/++o1njwJNa0ph7mRsuROH3637DQc7W3ZQTCVzgd8bZ++06K6wPXW/p3cUD
Y/XZDqjgFqI2mhMI3VxQZWx8asB2HYkOD7ygJoaHnJQ3nCO/J9EjMv/qDvnh
QCLhc0Wa3jR6v7/STb2JBzqsRqZsTfDYqOC3lMAiLqAv9MU6PCZgMY9bffsm
hSBpv2uR4QcS9vm4aXpyvhD8ZKl+QTrBiYn9x6FvOkqBgz/zgyQ8yZj+sLVE
soM4uERW6th7cmGR+97vcDekQ+8SWSL1BTt2z2f9oE6MBNxtCg8xTWbHpKZT
OZcLJGGOEhi+/ncGnRM72phnwYAF521JH4anUAWeiKh4hMFEFsvNW6nzqFgt
u5FbPQPmAystkKU5tIl4pcDHhBV4Pg20fH+9gdJuczddrd9ARB+Xej1e30Kl
7rqcGDgpApNPRj/2J+Jhm7lkaPEVUXiXIpRx7xIB1N4/rS0+wwIMRcdrjZ1k
aDUnlRaxsADR7gpdVYMbqPZuQZca+EDiiJWOTD8Je3uqr1P1Ej+kN9qLSKZx
YMM7ZcuXfQRgV/JhkuyxddSFx4ojK0IQXEK+nbYIX0dlE/hm+Qy44IzHPw18
Nw6Orz/oN9riAhdJSpC1BTsomsrVpH/kAMrhlLRdbOzwR/E1v+gkEbpDJFSy
/fDga7Pz7N4+dnixTgx6zLGFXPkm47TbhQ3UfHsO/fbYQByHBi5HOQqDY9ce
sZ7r7OCqmeripikCUb+jnxZZ44G8drT9RzMZvpcVNupnjqNvj1hQ/j4jgbVH
4xDWNI7mnxqRk0JJ0Mvxr+b6zhnUKB/VK8YIsL+o5soyk/dXtcuFL8QJQtVC
P2fAvkHkfae87bmbAnAyIqrlKecYoiTDRcYZMeBI56HnxP63yJMsxYmetwyY
Yu1VX0SakQW3XgWBSxLQBEfDecXKkfkPNc99e5j9duXzJ95dvxFOCedTmdo0
UJzQFjN27UOh9KjvvS9UOHemyDTXtRGtz9vQPmhGhS/S+98m8W2go9y68TRn
cYj64wM7jm+gQk/TT5t1SsAwxilB7GbBCk7z7IcrEhD4LO8+NsmKaZ48p9O6
iwG+HrsabNxYsY/+OT89cxlwy3SCKraKwxLCYk4k3WTAGYuDXBGhLFgyDpMa
ZtafjYisHnZ2E33Zub/57TMGbLDaxDAOrqJenzKHjekMmNh0Q0e+zqIkpTP+
ntoM4BUOqJWkT6Izp1g8L4tTwfXAq48RilNoPYvyn8vh4mB4YpxH8eMwauaf
wtJ3SgQ+7TCg3k+bRRnIoo2zqzBcWTofIv9hBmXDmrUpwqKgwrk21DXLgqkH
Z+htHRWBEr3X8ivSOOwT4ar0hxx+EDm9N8DoVzlqskH0dWvnAxVvlWM6DW9R
XNgL4pGXFLh3qcJrdHwDYb92UdntBwVu9GULLDB5zVjLiqfSg+m/Iely5nuZ
856gz8brQ4MGy+42DQ926JhfSnZ9QwAIVc1N0e9D9i2Kix36zQ6ZTS6WS2yD
yPbV1o+qV/igD20k0oWXUO0zoXnee3ih4otxFk1jBa07qdtY/VwYPAPd3hY/
ImLvpzoavr4RhhPGobXUVyTMK04lVVOXCkeyGvdnOCyhzzZ0Q934aLDnrPOK
ptsquqZqNCb4kR/uC9w/pRLN7M/j+15yc/PD4RD3wOo3ROgK5fHtXaRCT878
8Y3HONgbdLX3+jAV5Hm9+qNF8CBwL1zs12UJCFX/yArcmyj/YhzN6YwEsClt
M2dNYsFsO7Mzfa4zQGrbuY4Cgxn0gVdP9glmPfCK9Du5ZC6gqefvL8oUMcCB
X3kRWlcRMsv9cYFHDOBSF0T9WDaRc/cPpM/epQL/rlCTbP+vyHTFKVrmJXGw
/nuPUv6pEbljfWco/TMDrnWfGFUYnkFiXcGo4B8DOMIKdY/uXEDIDzlKu5i8
krjzFktvxCD6u1lydyQIgVD5lYSLzPoo1ra6zuklAJlVQ5djM8YRk76Ui41R
VPj4tWPmwP45tD5gWuDsLSo0XuiROXVxES11/femabsElBX3xxD0x1D7Ay8P
HnglAS6sFQLuOjPo9c9K4dvkJeCDgbvM4qNihOC0vi+thQ7Z2vc5otir0LVO
dpaxxwxoXb5hK9/ch1a0FqwnjjCA/F3WVZp3FMUKthHLQiXhq2HcNLWxEHEi
JzdwKjJAhH+l5LFcGYLJVbR7OlEhPUxXpCZ3Fml44l518ziTBy66yMZmzyEj
5+3qFrdRQXk+zfqU+STyLepJ/RM/ccDTbVNs+gaQMj/CvC+z/51nQq1TDvYj
3XHKNl+SaXDzzm4NH892BJl5G7esR4dIZaNx8kVWaBgzcX/2mQZ1zVfDf1my
QWbhuGVkkiQI2F/yKptlhY4PPkHPTCVAc0V05OkNHCxOa4rfDmaAC8vXT8uw
ieSYPuKs9mTAHXG9l3qfVxAvPhunHub3GGLjWbU1iWyynvIx3MOALxu1oTA+
iNw4lFPWc1cCSn2SHm58n0WSHL+tdfJLQL7k6q/o/HEk4NDwevUbOrCHnuls
n8lDfpYhr80+0SEirYsmLPANjVoorWyIYPbDiYGgtQ+zSFjLW802GyHoN+77
9fLSLLL9WEfpfJoAcGDnTE/unESEPteN8V/mB6O/feFFXFOIMavuw6kwbjiS
YU/tnZtG3qqSrNV5OUH59gUcn/k0kkM7qmnA9A38q1+eX0xW0ZrYJ3jsgThg
OyzUBzs30K6mC8800mjg2yu3HvWNBDx7+0lvf9PgQh6CdrhywssSg5eZXOJg
QV62P3OTAKoEs5DYo+KQ4BzKubFIArPB0g+eefywg6+CJXAED9KGp2Vr7/KB
aEJIo9ZOIpgkxv7qYc67hOytqYuBeNifLW/IrysIhQJClkEGRPA2fb8aoywM
Fu5BPhHmJNDOOTr/EWXy/A+e3Gh5DvD8ckIm1UIEpu95lUXGkYDI2VQaFigE
Y/cU/u1wYPqLnJ2Ia7gwRCkYjdxwx8Opt8FdAaIisC87Pm3vYVa4Z1PRVRov
Ane+IjutXm8h+MwnHquPhWBHPxb3eBUHsb2nObn9hCBC4lD6v0kWEHESVmtm
7jfmScC7EBccXNoylj7pJADCMaG5v81YIRGavRmR/PBhOIK7ijl/nyfw+dgy
8+67liLmGUMAT7sJIambTN8qOkXYboGH/04ekwxkCAL9ZTYsuRJhIJCgc6JZ
GFp1veMW2shAU6qRPvufCMyaCqQ6ErnBMDk2z8+HD+5XxbIcpw0i1o8EvFcy
eQCvGHzlWfxf5NPAiPDtO0LwAp9BOXNkEam9Mi99yEUQJIV12ruPryAndezN
/jkwz/v9oeYmpv/aHnK878vMi93N/xruNM4hZw4PhTS2CQGZoKKmtD6BjJ6M
MteyZK75N284vxtG6rhOuJ4dF4XWzjSW3RNjaB2f8r0KYTEQ7TO8efrwLPq0
J/Y54i0Jza0SQY76HagM8rHzijwDVufw4fqmfSjPs61zXwZ5YEuMwWsYMYt0
vUR1WC5ww1+uQziayxySJvr77+kNMtDxDR3/XZtHMwSb30gGk8DEMKQ2LH8W
zc+N127/wwGrjVUQRF9B82dYmmZLSKAp9eyFJN86qk5aze5b4ITe338I+nkb
6O/vh7etMnnU1abz19IvFsyE82Qt/3FuYDmVSs3T3kLa2Y/lPPqPC9K/10s4
ibNC+JqlGCVHEmgtRH7rx5PIu+vBUVdsGfDhmFJkvsI0clNUK/TLEj+Qn1YF
TIpuIF1mP/X3hPFDcKEpW6gwC6RKDuwvj+GD3tYwjvM7BxB79ofKxSU8cFvZ
e65CsR+5vZ6gF/FMAASSrP4R9BZRGqfmcJEFHYak+u28vftR35kK0lQuHcaV
DaJV5UbRNwfzeWRjhEGnJJFom4eHnh6i//1BIWjaKJD/MUiAqfT59PdNVDD8
aHRY3GsVYblkPj5ygQZFWbIEe7tl5L2QXUYd04cemV1DWA9sIHaXXzloCVNB
tf1tnsz2FcTkkK+/o7449JnKqaZT8XB0tSR2WY8CnyMKwiPa2aFuzPn8tD4V
ZC/MCtHdOUC5aw++KIIKcVwGpXcwMnyY5xJ4NC4OoRWP/t1z5ISOZ4FdrNlU
KPDfqru1yg5H13dp/LWkgZKiTmYCs5+oMcsdB0RFob9XoUnBHQevKUyFOi8C
L2pL83bVsYKTtmhzhoswiNZP+HIJ46FO6YCs7HUhcOz57NP1Fg93hcqeRttL
QufToy+fVC4ht3WmqVpqDNheJFYuU7SI8EkvPv7mJQjk19ZjZOUmJML2NDmr
SgCKSQnBN6+XI2sSgwpbNpyg3+ww3XJ4HnmZUXfuLnBA9/lCbMelBaTR/AT1
mgs/rPbIPyTp4mHHsQh85F1+qDwafK7oGBGK4x1/jbzkhgC+3SoWWngoOz6r
EezADa+d2f5KlBOAfdN8RPgaF/jSE0ynp3Dg1kdt/f2SDJhByxS/OxsMnO0y
F5zmhIGl+jQhHla4yWlwPuAUJ6gUuvUXp20hLwPM5P2Z9StWXLn6mmsVYSR/
4ntYTgaiusDZ6FeLiPeq3wffA6xw+2nq8qrgDHr/lUNh8+4NRNWx96ymySx6
SHZt6m4qF7w4eaTSJJOAyfvoaVGYz+dpDa2LnydiundT/AYzhaB0o6D110dO
LOEzLfmYsxCo8HmK9SxxYRKW19jrbotDw03fE2wLXJjz/Cb5GrNexEozDGyd
eTHTAdYThdckQWrHm3Ptd9ixIvbS07tVGZDHcfmPjx47VnXFVjyayUd8SlfM
FLsm0Ts2uOu7RhkQdwudnQsYQU1N3XJ8TMTgVsrXRl5hIoT6uUTo76DAkZ8V
o2UeROhxTM3K+ckPEQuOLzltyJgdSd5h4okAqI4M9O5k48IqUlW3y7kKQafH
mQe9EevolAgtSCxfGD7U71oUNV1HEcoGJmHFDR9pDr/q7uFh9I0hn8Q6NyA1
lb6ZMkTo638Xni5IBPEnvDq6XAQo8TUjhgAefjaoXpqiEkHB4UUD/TgbyNSf
s0k12EA276Qt6J1iBQO5zTR6/Bri1r4ZQ2DWq9vd9QnXa3iw5T+6O47pg9kf
qwMvOBPA2Pj0dIspCT6kdJ2zqhpHHxRIvOxeJcDkVv+nZpcJ1LvJXnbSCA80
CvpusmQavbavQ/oHkzN2GTltS5GbRv2Mrtw0PCYARX3yJ7mnx5DyzQvLFqb8
UP9jdiCv+R/i+WPeTchDElLMLjitmvcjPww57RN+SsJmvljfxa+jSO3gy731
nFTA9YZt1pEKkc8XQpaCY8RhX1OG5YfvrYjhJY2eXSfE4RvhV9ai9ga6VTl5
WPg6BYpb7tiHZW2gYB3yfV1CAnwmisW7xNmwH8G199rv0uGahfrvUiM8dico
sKYnXhLSSp/LsVxjxZ7mp2jd8JMAFeeitvgHrFiVyLuP3lYMWFx017lgtIka
E9d0lVQY4MQxJOWsvYp+CGVkfzrBgF022PPb7BNocdAZ3RFvBrA9No/QXOpD
Rc74j2x3FYefqTpPhi8PofMF425XUQpIv4uvHErvQJfHiNxuRULQ/vRh+J+n
02jJkm1O7mNBGH17h11hahI9Jlg8akMUASvznYfPheCwxpo9hS+1hWH+n8Da
8jIbVi7eu6L3ig8uetT+l3E9D+Us68J4J3jA79CFnpjRe8i3C5XJyAoFLOPl
c52/48CxqGz1iyIzP/X/rV49wczHtIQHF7VogJYeF+vIIcDgRdbMQ0z/4PiZ
MrytmQQt33c//YCwwSkHXyVvyghiWpyuXezHCgvvp356XhtHXBIiChNYeGCQ
Xe86f9oqGvUHHrnf4YKMDIcRQt46yp1/8HIrQwTWpQQX7AbImEFN5WEtLxFY
GEniUV7hwrauprz5606DhYs/5ajla+iFKLXZKyfpIOuaOPwsdxPlYLMXcrrK
C7iYa6YXr3BAxsQoG2EPN6jHSY4eHCFDnwTb+eNdVOD6c9HJsJYAcvV7l/t7
qLBxML8h4B0J0lkvnY3coAMJ28Xg4GHDvusnll8voMOOW+2SEITHCrWPB6u4
MeAtftTbpIoFVpLUdvsfYYCSQ4MFYRoHDMUCge1eFHjWcN/rRWE7Yh30JjG0
RAwMXi3S9jR2Id7qXRf8HgmCr9uossvZUfT6AbI6sUQAHLKqLux9N4YWrRVY
TYZQ4ZFNg2WS0yJ6Z887P2F3KvTVp5WyU1fRfyS1Y/eLJcB4x5Ef1+tm0GXO
ZNJBXUnIXMpWDw1fRI9S2nb/SqPDV2e2QvpsC6ogfGvvi6t0cFnMyTwc0Ic6
Wce9b9zP5HOj+geGSBliy0DOTX1iQFp1xkwqowKpORp2YIy5/10yF1dvxc8j
B6UrqjzPiMFQ8KXVvtwF5JwaC8sxM3Gwzd7ekrrWh9wvMc6ZaaeAqcta70nL
dqTjley0Uj4NXmF6SLNNM7LtVggr6zQNUpwr3T7zFiNh8eWfRP6jQeGJ+g3K
FhsU93zh1+KhwcNpEcN+Hjx0vZbP5bKngsahrHNJt9ih7aPC0tgaHR6NOtLO
p+Kg/d6VlkMIHc4cOZRz4BAb5Kc51nOepkP4+a0KoVp2uKhncxp1YcDfXJJK
zfoiQgvo61d0YECN0Y2gaaFZpNx46tl+GQZszU8/dLMdRCjTkzInMiThM9+c
35V7v5GVgPvZxq/pwKWnx8PvM4DEnRt7Wq1DBwFFhW61B63Ih38cn8Ya6ZA0
vU92L2cLyi25OC21SQebgP8ewO4BtPy/LMUaAyHQyIutXLKdRSqM6ywc/hOE
WecARmHHDHJfwTHPz0MQ1IqDiEkOk4jXDdyzrXw++E/uikD+4BSyuHzxkzk7
L9Qn9XI6n5tGpFuy9eofcMDIQYnP23v+IfqSLo8/1xOAFETXnHObQmxFft0d
/cH0Fw72Uw9rWLAy39TeXlEqfFqEcu8hHIaQWiy6mOcf5qbx7WcwF/T8lWhe
lKeDL+vu6clVHtgd2EGvthMH8vSNYVl/Tlg6KdjjZikOS6+yC+v7uMA58wDL
PwM+0N74+NvMgekrX2XDJqt5oC594e8VCxI80ez6kkcSBGre4ZzaNBJ0mvyo
c8wRgDfE2fquv2So3Rr2Wz8gDBQWC/IuTQ5oRFaqXGnCsND6L/X9FBk6C/11
f+eKQHPtM8OXVDKcR6QC7iaKwtt3HGK+c2TIPpVZsItVFJ78GgtkjyZCTPDN
fQR3UQhS147wiiDAsyekE7cMReBZN67hSyge6Jd90resRSHEJfWr53c88Doh
m94TIjBheE040nMDUW56eOblCVE46u38uiJ7FTl8ZF/YiLcQrNja2/DdYYGW
HSWZrtZCsPdoielE3Aainti+z44uAFbVnX2VgqywdFha73E0PyhYL82FaLOA
dZWeyzYpPgjBFbOs/yFA2RsbEYVEHkihKjxf7SFC3kDIxcBOARgvEE47+ZkE
i+8uHuiLFYCzYiqqlFQykKdMH7xMEAH23OqhdCVuSHKXP8V9RhQepB8x1WXm
2Hm13odlE1xMHiYo3ufvRnjVem4d4+QEBXuF/0jf2xBhxygPAX1B2HY1VB8X
t4L0/DHocT7FPP871BN8SutIUXhKq1kaP+zXb5Ci98whIh5cexzt+KBHwPdN
RvscYv9v+vJfRSE40fr0+7LcEPK2Oz8FHywInJhkElb/B4mardXTPyQGlbHs
tqr3F1A/vqtCTifEYMVBsn/jvxW0xP/ukaRzDPi6q2xcY/sAGnlAFTnew4Cp
fMNYK/o4ylg0aRky4ATFs4wstn0LSEYwUrDykgO+p1of59NbRKJvGvNo1BNB
lXXG0F9lFv107YVMWRkBAkIfbY9fm0aTSH9XImVI4L4cKz08tYEmrtzBTuoS
4YazZ9e2VyzYYbePjy5K8YCK+6ecjCp2LAET5b+SzwPXP7aFp5UTsDXv7Sru
IZyATkT8aPyGg4jakr2+z8hwwMhbjDky4eQPVocOE344bq6u2DTGAjc+Tz1y
rOUD2q9dCmJMDpLWPeva3sYFD/K7hQ9y9yH8387Fnf2PDM7G268VWv9BaOcP
qI9EC0GZXude7CoR9rv3IrVRglDiTktgmyXBernuZatsGjyv8fX1ZF1CRFw2
/bwd6bCH90n6FbE5JPDirsoFpl9EOJml3LVeRIKvu4jz36BCYobN00TuOUT3
gJCr6VcxUPrItv/vI3a4NxdFS7kjCt/bzszuXWQDrqbnKyoaNFBbiVbRdOIA
j+xtww/96LAUWKJx7zYH7Pb8nBgcTYUHP+0c746S4a1kdOe7r1QIXLS/JDfL
BRR+mw+9dBrkXBTM0lsng1P4DwGV6+JQlWge4IVxQnXAro8ehhQ4MyxlFZzA
BTKjuZJUDjoECxWsOi2zgKaEzGybuzDkmFlvPOpmgaz71rka34VgxjvyyEQU
C0SrzZ70SWXW06pf5NwZAtDq36Xj7wjAd8cTt4+zEZneFnHjuwkDIrkPHRoO
XES2y4fsvTHNABPxh9vekxeQB0YsPc+YeZJT2aX1ThNFflgOxxE/8IPBA3cZ
0btvUeHPaT5ZT0gQw7LuffL9AoKrVblq/YQA9LaNzl3UJaSMlceTPYYfsM6S
c5csibCayl0YW8APB+bHuDz+kaAN7b5vZMwNx+ST6WxbRJA7r16fzey3nyca
/wKDA3AshPqt9xxw5GP4+/4fbGDQRXewmyOAlPDDReJPdmB0hOtLcHPCLHd2
xLWzm8hxvSj5PaJkCCHdNVJNWkFK+T+1Xi1k+kf1p813AYuI3QtWw28RHDCp
le1/uGQWud+SOm9xgAh/x7z6xVzJWJXi4P7iaDwIfIl6MGXLidXvE85N7qUC
W4Vj17g+P5ZdFdnFe50GX3+mhNo9FsDcTil1ijLvR1/d313Lh+kTWvFeRU/E
4TzuT5vyWyIk6zUmeYsJQvMqm8M6jRtz3XNBvNdZEKpZhtSl1Xiw8gXDow7u
IlCRzJpqJ76OFkZqkHnyRWHPk5baM9lr6PxmgMHXOh6opr2cbmwnAWJdcOuC
Ly8M36Y86XtLhmKYjDzWwg5Bse+thAyIsC7QmaAeg4PMdkvFEx4kyE28ehVf
zQK/KLD9h8QaUhPZcu6nwAYSP/vU8cuXZYTAnur+3ZICaw+/epwyJsFL7j6Z
1sPi4PtMpejpMgnekpyv+S0RYMZshf/dlQk0m3UzWvErHmprt1YuVkygbyPN
PosgrOAl5mrQ3f8P1W1+Lsbps47QJnpEStamUKnlp19GcvhgHZqyduBnkc6L
uERVIT5YmCfdTlOcQ5TUNO9mDEuCxc/BvOceE4giWbEtTJoBO2oP3+JRn0PO
tFQ8WLYSBwVjkkuZYw9iv09HyHaLAsMcPoar3INIG9+12wtKFFB4erNJbYzp
DzFcu6sjxUDcIM4cOb6JWqllH4+IpIPBUIS/nS0eG+J5mTWzRYPO/fahdkFE
TGnHN13e/+hwW67jalk1K+ZXNWhwQJcGXq/WLnXx47AMWpbJdqY/cOxd0hTW
XEXlTqS/lBdkQHRgjlfI1UW04f2rjbSnDDi9hDVe+NSOtv4LnDH8wQDZSh3b
MgKGarFTl+tvU6C5a6WFTaQZPVY6VGc3KwYJYvVlt+ilaMh/VzyXmP2w7egO
51uuI6iWT6ebzBM++Pd2bu/114PoXac7oi38wjD9SoN/zokdW7ih0cVyVgj2
GfosbDcgYEsNWnEaV7nAIPoCri6nBEEO8n+V3CDDqU9BWtqeKLLv3z9kp4o4
3C8j9/4uxENDqLLnAS9xuOWZb/phhACH+vwJ3n+o8G3thWbyDzJEq7u+Usmj
QrHyBavIcS6IPO4mxzrDAm4nO3+4uE8gq4ZcWcXKG0ikHJ+sbMQ0EmebLB3f
zwlnT7393PZ+A/Xd3qfEIsAJrpZxanpxW+h954sVz4JFQCF8Pei7LTc2ZD09
OVAnAmENibbKJ3mxFF2X5EYLOtxXVcsW+buJ/kjp2VJTlQA7o5B79YUsmMyD
Q7KXt3EDXyDPfyZMXhl9MNFSz+SSnrY+0zZLLjBRFOB8PUuFyOnqeUYTGYZO
J9ZPrFMhKKmnV5DJT7N+4zt7mTwZPVHpPvUWj6nNH26ZtKcD/84R8fVrRCzz
ud6MHtMfpL32JOrO4iDU2O6pFBcD0LYhadcFdnDfwOmbmotB6E3V8HTLbqQ8
WPtV1hFRINQ7z5QU9yJtp95M1jsIAJ3/t1PHvzHUYNAgI+AOPyh/ylYcM5tA
VZIKLf64UEHOQOG7YQoLlvfzcniVNTP/k6Nuh7XjMK7ZGkNTpk9/zPc/Gf1x
CS29+pDLZ04SSv0MxGLpayh3BzlmnysddHpMJB7/7Uc7/OWTpxToUPFptBJH
nELxu6dj5ChiIDZfMvyldQHh+3L538s4UVg3SbEo719Eyt4lPr/6mAKNfjVm
J7ubkFv9wnHUFTFg3XE9xzwHQ15LHeleOECHfJX+npCgcnTXPaVPeg50MJ8Q
z9pNbUelxsJ5YotpTG687iFEwcNk1D9TEQE6lPEMd87IEaE+bqnFOpwKJ0zy
LlUO4CF1mDbU/UwcQuJ52xEaES6eW+5+Yy0OSvoUJREVNhhIVlP5VUqBaqR6
clcNDjYw89k5S6Y/Kj/8pBnFCkp2Pvv7a2jw2olHUHGABfZr1/x7focGOw7i
LHUF2CGgpDllJJUKvNqy93Ln2KEwpfejEXOef5Ua+v2wHA/IaNyoizMDklDx
3k/8U4jkT/vEWg8GeJipRmKx/cjyzi7vH7clQWDvpn1mWTOTh24eSO6QgM/K
GcoSRzORtDLd+OOKdDh1jGs8J68BSUcVLylP0WC0Y8AkY+YD4uTlQG2gSEAN
C4d/hMkYam6i0Verw/y9yyV58z2z6KMPxCb+akGIfdOjLm6/gIjv96jaNBcE
ZYmsMdyTZeSTUGgzKyoAZNExlYHv00jt8bEO4cv8cD+uh+UK1xTSHKpWMO4p
CJsJebY5Z8eQynSBJrZLgiCCLbr+kelH0kZyS4JCuUF+iX/0ysY08nLzVtK9
05xw26DCKqJkBlE9r+oplsQO4470QkvrSUT4S8RVrz84mHRW6qqfn0CGCBHZ
Hwqo8PD4Hj+rewSsOv91YhKTP2yzT342Y+HAPiyce1RuKA4f/I/dKD3MDVf8
o4lKeuKQrnbKN/UjD0w0hQ8ozHDD+9ax6Y6vJHBu4TieuMbsQwWz1JdPOGC7
UWvXS2luuLXDY6X7DxkiH/Alyp/kAWl28772a5zg9OMYa2YS8/01NdK1XTnh
66DqR0xTAKoH9Uof3OAG1+GId77/hICusVhj/pYLBrytIr7lC0HIXf/n9x14
gSv2eUZRkih4FF/beW2eDDJhYU5a18SAELzXyrGKE6z/eA3vaxGFMhu7bTYE
PEhMWt664SsG+FrRpENvcHA1+HiuoaIY0LSP4QuoBHhkda9cLogC7Yb+8ZKP
CPDaI155xEcUajRXWsdGlhENn9Qo3IAo+P6y7NOdX0BMv+747mwhBIXKl7cM
VTYQ08QtFjsbIei+IHyTsGsN8ebP/mJI44ce4u83hNxNxI9nt0htAB9khL8L
3xmwhsgWXea0U+AGlmRrg+5qEnDExVtjJZxAvLA4H36NAw54377ZFCQAxEH7
vhwdTiiIXPB0UxOAF1ffypj4M3Ow4mrLRyZH9gmx3xIMbkN4a3P+/nlAgooy
unx/ZgNCCPN5tTLAD9cDWB737d9APIYM5O7684LEaQPXmh9zyMJVfXhryg12
Xux83bfnkA724maFOQEwmkxvMjvYgdzsPtSb6SIAlP76iOzcZoQ9pmxsSFMM
pAQJ5bEJG6hrTPblbypiYD9MPO/8hgWT3TH2zo+PAwI+8kcnJiwiEQ/He3eE
E+CkklDaxvoSEnZpL3vvFg4EBiVw37MGUO9f9R6EdFZwNryU/Y3xF/XiiL7S
NEsAr5qdiIU/K2YyfUx4nU4AC/1XbNwTOEySIhoerckLvTFSbi6RHNjzibk9
wQbM9desKL8lMubn6R74O5AM0tepCawd7HBwZ/1oDNNv6KS3w/m7iNBQWPPf
gY98kD2DpOQnsMEThU/nh+X4gGJ3ZLLBDQ+VZ15ebL7EAadKv/EdrOpBwhiq
f/gtiCBj25/Obd2FPOw1Tq+NFISzOnWrrnMk+DbXtaEfJgC5ujsLrXzI4PlL
LiiDyQ+XhWS8Bk1mkWOsSzEyxhLQmSpY/5N1Apnl+RrhFUKF+NOHv6xxzSAn
FGmU46+o8Pwny57m8XGkV/fo0sdXIjBb5WXq5skGxxoyjXKeCUMyYSf1DZEN
cvbe5btlJgGXbt5qLXzNAZkR1w+3R0rCNImrKXCBA3JPj8643KbCH9sfnjVt
ZCjqy/C3RcXh0C0Rczl3DpDfHD0ZcIAGXxgHhcW8mfMzUP8nLYHJPxzLT3zq
SSA8k8gB2hTgftx8s/M5F7y6iSXMGovBp7DU9i4vbrhz9v2vkmN0oAQo775w
iAVeXn7sq21Fh9Q2Nu+/ulsIoeumyKiXEBj/VXi1L5Lp46+muns/CUJPNjnc
2ZIFxD6+M2CEC8BncY93FUzf8E+2FrcO4Ie/UjgjyQ9EOBVsRr7DnJceJy/f
fj1RgoqeaWXFX+UD/LnahLW1ZnQ8zvlsiSIe7pQd78qwX0YEHpce28bBBmyl
vUV+LKvIpXO6xCP8AjBxY2HnGxondExlCJS5C0AGh8p/ojbc8A1trkgc5gR2
0WA5QggZumOrbbf3k8GqZcji/n4uMBqIpJkHEmCnaOz13Hl2iPO09p98yg7H
WBpMCjE8SLdoNn6/RYJra7tOisfNIuZ3BDcKXYhgyR78OnthDOH3vumupcYB
Zyj7hzwKZ5AxodQGjW9EsFnW25hn5ncPrjSL1QoPR+sjPff6cWI3fl1Zixdl
gwaNHVJrEVyYZvmsHS6ZCvcmBQ5XDBLhd5zihxNMX+X5d7QyhZ8Efoylq4ZP
BcHu5JXzBra8GHt/RLUrixA8+Li8RUjjw3Q4vSr1/MWgzuRjtojVGnrONPT5
EzkKmEQ9fSx1eQ1dxxnW1CXzwpGl7/nChznhbSg9Q1OEmUdmC31izDkyZQw7
fxzEgd7QsvvDxyR41hXDcX2aBeYqPko7BHDAsKabWoU3K/iXbVNdnCFD5nzp
Fc9hcTiXIu//8jQHSKVievpBVJgueCfzopYD5Lp2jXxNZwcB0TIsVHICXTud
YvMfLxvU8KNcx+wm0NZdofwnHRjQNF657XXNCmJettfgXRwDHj5QqiRIbiLt
nN5j4jkUUDuwusvoxCjy6ev7L0F3xMA4N+1mGJPnOfKuY5nFoiBzIPZme9wm
WjvvfKMokwZDb+4/zqwkYWVKLdU7jtNASr76p1scGfvFvRAhXEKF0ndhNuh+
HOa35hLd9kocth12YTc9h8M2WoTP3PooCZ5lMmLu6zPoXR+Pk+spkvBec/z1
Fss/9Ir5uyyHT2LQ9Qcj3y3JRu1ZxONr20Qh06FFH0OqkIWk3o0Nfj4YpKmd
3R02gHLyXcIKvvBAdrnoJZTeh2ZKSb5M2icEunEnpmnpBOyHpoVNTaggGP9T
lezJImG3NXRi7YLJ4NyfduDz6TJk794vn7dzccDdQbYHtdlfkPMR/xRPm1Hh
Rcy1xm4fDmj5tX2/WBwVWncdKsq6RYZSuo2EcDwVli/+zAih8ACf/LMk2nEq
PK0581/odl6Ian3JW5BBhsvrFfE3fVmwWEv17xreHFB87mLQeCAOC6+N2qcm
Igp9hEccEwZ82Es/7ne6waKgqnH7ibk/P/ZSuGpcNkkCmp9xHgjbz4pdLqXf
KE+QBB9ipvRmDA777ucVmiRMhuqLN14/mOMCiJmGuuskWNcoMXdW4wGS1o7t
X6h0ODygFtRWR8Jq1M4bcT6iAe1y3nixIid2WEm2piZGEviDp32CHIlwtbny
rKKDJPQGTW479JkEW0q8Doa3+eHbzHi/5aUJ1BgGIhpr+YDnv8EcU/lJNEmU
3UXqPJP33+iNH5djwx7qh0RIXKVC+kBM+itLdsz+95/nQltU2N0Z4K3xix0z
dlywbQxiAIvCQMK2MBbssan6+avVDBgXnvur647DzNfGvjht0iBBptqnkDKL
ZuVMnNgopYHF7VL5+W+LaJhwTOUlpr9Mh0w0Vj9cQY69f5PObykCTnfwk9cf
riEFJkWtHzAxsPbvPf3fuUIk4IPFk1/lolDfaLuTcxhDFcvs/COZfI2b294s
r9KObq6b7L3/mA7hd9Sd5eP70dv3IjLEPOgwWFfVnWfNAYK61PMXfenwiJY3
45VKBm/DF78qo8RhXUo91vQAEZJXcnaxOzL7pZrRzh1IAsPZOGGHexRwM1M/
o/gFBy2vB/g9ksWg4pmf3yVbHMioTnx97ECF9dHzBsVSeJDdWW9ooSoOz/PG
bzyTIkDomTpYuM4Anm7Gndvcv5HPJpwbd28yQKn8x/e+y3mI2Ac+jf+yJGDH
cpkx7+AzlGN/lLTPdgm41qKfzJb2HVUfCmqbVKbBC+W+1MCzzejljd0tOrlU
SIhz7Z962I+SDqs9G3Rl8nN+Yf+2gkVUeIf2tl4nCXi371hIbeUKytZv+axD
RxD0zYP6xZ1XkLlZnlcNdQIQy6lGbvu8gVg7V/1tI/LDV++hyAaJSSRz8H3N
qg8fDAX+5Yu5MoaUe+xO9fHlgzXznr38BwaRHUck0xbUBOHVsyGVwPe/kZEg
x/VGVkF4sdSuU4QvRxhKGt5df5j5HiZtOKgziwD39bZUAyJIvuAOe8Izi5Sf
Tan72USAb5j8bL7cFFL0MuDPjSocfMw5Ry1h8jQuLFmE7RkrtBv8yDFSnkDY
9fPPP2LmZQqWlbs/dhgROVSq8uEwDWS62W4u5HFgxMgq/OMnNNgT8jpueD8n
tqolqmO/jxtstr0eEKskQWXrnEpGHRluJJ9RzMkhwS2KYmrtJS5Yfn64J4U5
v4rrjtV9pXJCfpV59+6nXPBD9H4xnzI3YJNz9g4kTsiZO7lieoEbrg+/YxfS
4oKmnMaBSg8uEFkI+GkrxA3ue1bdVbh54XfzyUreR5wQ7jbIteceM7+evtru
wOCCfec7rdd5KNDa1jAR6cUFpb8emQXeooD+Rn32gBY3VPuf4zhgS4Hpfnx5
mCcPVCLyO2vixcDqIsf0xGkcaOHdbt3dS4HfvLGFfJ4s4GjyItjwOQV+5b3I
Ws4ggFKvd4R6pDgMtHudPMH0R9mIrINPlMRgx1AJ9lNrHilueTq4VS0Gubsv
nchonkEophxON3yFQErG0HRodAVBPA462yQIwYnvXQL0uEXE+oq9ufExPmg0
jUgcY6wiZuf3/NQx5gWcZN7IX6lFZN9ysRSnPCf8eaH9+mMyB+jseBApW0cC
Np8J/Hl9MjSX205LniRC+uBie07vD4SQIPe2qYEdVotuPlGIQpH5AW7d6SJ+
+FATOPXAdgM5UvR5p8ocH3zZbvbtxL1NpGFjQtt1B5M7TNtd3YhzCNk4wPPi
Nw7Y5CfvlHeeRYY9TDK1fvODvWuSnuCOX8i6+bqI2ggfdMjPHt95qAy5a/tb
SnWHGPQIsezapsGGTZhKqygIiEGGW8S5dCM89jgmw96Vjoe7F26w7OteRpSX
E0fOzeDAWQNfQetYQZxq2/u9FFmhYH9V/ZjeH1T48Q7KUtkGIr/Ik9t+5jeq
apFc9iYIDyGbuqbpH9gw9yyxaAdZdqBcpuzeZOCxvZ0HGpWBF2qNHI5KhHNi
hqxe0p+uMz1OLFm94iMRosj2hRRmHX55cvPdTDQHyBrLJdzx4QVfy2/U7DwC
PHCMOL83gwekvvzUihUhQautw6R3ATuMeSm5HnjcgVg/0ZU0GcFBjgvhy3fe
TuSc0JSYF10A1M4elJ8X44T5Outmr4f8MH/Sb1pkHxe014nhVMIkgFf6osI3
kTGkbgVVf3JGElLOJsXFr/chrceKqEkEGuj9uZankNuPbB/bJ/LdlgZX2qUu
RfQ0I+llBiyZJsKgn6s/Ir6Eg1fCXrFLdkKQf3cnmS8KB+lcRbuQ3QyInP6j
bS1HBjijwfOmlAFbL/STnziTIcL5beevi+Kg4iY98Z7pZ8qRkudOOlHgbP2j
nl5uImwkl9/pZs4zdNctDWcZIggF+tjjXOjg/zzuSHgjHrDRBv/3jaKgbntm
dHyLG3gmKWGGmSKwN+D912d0XpDG3BJeXKRDY/c5k8gbG4i5rNPqtQA63NWq
lr68uILsuVtTUlkjAAkE9artDVvIYLn4tZpIfkiaOs7S+GYTeTCjN2Z/mhcM
TaRHqaocECebWNA4wgV5kGiB0yVDrOvmjJoms770ruxBfdrQz7gEzyWUB8R/
qkyhfH1obXrph4rHOBAqn3cahlUksUigZtGIFZ6btzlv2a8hp3sPBvgw/eb1
+pDOzXkmHzYtXlfzIMMFcaHo59u5wVTp4c1Wcw6QNi19ceAsLxifaJC7fgUH
EsI9RoJ/CSC+jlNSPMMKoQu1B1cOE6Ekut1Z6T4L3OU5V8R3mgDRSzfdwoAI
nSVkVENvFPnds5rSz/w8u+PL2anvf5HK1a6QUCsiNAqQPgRNDyOc18xSfwsS
oNvUomih4C8SXFxh+TUFBzPeTw1SvjD5Odi/YfE6CxyKqhaq6eTGTgrlkP8G
0yHxyORs224SxJTVvpK+IwHxfxrkC/eQwM5bWZ1xWhwycbvxhOk1VH9BKFTc
iQpJX94XqTuvo74Ht1XFqjPze5ZnryMbCYqJeXyqHFtIoJA2zYxIhFovRFXW
BQf5l3qrcYVc0BPyzvHKPxwoPlbX2Ebngd/fU1P1tWkQ2aJkrllOhoWGOw91
2egw1/SMn3CJE15u33hZLMUKFwPkZzVlp1BK8FcFt4vrSEqWmmxK5DRqNLDd
7L8cEeBrJhl9ObqFfn7OayBrLAxvvWIDwthZMAOLf5KyR5j/r9LXVN9Gxppq
Kea7u6mA+dyZCTjLjam+Hih+4SQOe4Z+27Ia4bBZn2WtrEIKNI7fqip6gcPe
XYt0OvdKEkriLunX3hhERTfYlc4w+bfuNN/Xy89/o/Gn+VgsskRAZgdPwdO5
biRhtXqp470wcNr/mpoOHURis6Vi0x244d5RAbGogG6UVRNdlf7NCS/sO23y
frehUNl9ffyyIOjwy/e8InJgOwVN3uPeC0CAdngBjzonxtPjrXNOh3n/Bu4X
tjNqEE8VgOlodog6mttXfb4JsZu45S76iApnbAzoI11k2NttQlFspoK7VbCx
xywXTCcR+31JHOChKrs3TpsNC8y4+/ZdGRF4+NNOWhzHYy2WHb0xEaKgtoqX
HUvkxxIXfLXM5kWheRnjLG8TwGLuaQlspUtC1ovEz4w0Jv9G/rT9Dxjg7h09
3bXBhkle65vkTaSBdWhQVhVzv9kuDcuagjQgvdq073HgxvZX5DzZYycJvA1/
bR5ocgDfkRuZklqSMD6Qc/sS0z/73nMffBPFBz5fdY1pjEnUMap83neVB+xs
MQ/78EmU6WpHVl6KA/toirrWMjuGcF24eP6MOOgdVFmW1SFgaF5X3OtOKpze
/6U3+QYB+7ZdoTbwJA3iH7t3dbeRsP0hgbW7uOiwfzZ4e+sOPDZ1b5fV13Rm
nvz6o5OaiMckS9P2r0fRwPugVPmm2Brq/6vre1cIDbQf3MvftW8TfWOxa56V
mY+Ea8fCzxaxwB1NIsvOOCFIJBcVlI/jIBq+KH3zFAXF55LRs6+/owebpVle
P2XmV6Ctpr10G5p9cWrz5BgdiuLSblaVjqH1Jj6ml40loJ9WJESQmEWlaBmF
KngJaBgtYzd8QYa7D05v8WRLgP2TtuaYI1wgK5uv+VebDkIyJZf2u3JBpH30
/stbNFAz23bk3CQP7Eym7S8yosB1WyXjF/Ek2PG0TRy7KgZHytQvx1RwwA1U
jWO3NgUIkfExfyQ5wXKJVh56ShRWLk/q7GZyGFXkpN2oswgwbp3qxGRZgTmF
QrIaKfCYdGhZOogAIwVr+dPmFBiNV6X4HyfCxypiWxKTnx36A6+0BZFg7ufv
vRDAAP0pfx0i+1t0m0SL+r3bDLiY+izfm9SBSnFp0UYi6GBZ8TG0a6oF/QMv
OoZXaYD7svPV37VOdNe0DedDpg/TLvNprPoOoTM5nevIujiYH5sefb57ChU7
1WNnrykBBQW/7wT7b6D1iTvuiXJIQLlQ2Lh/Owvmo8j3RKFEAMqlexIUXDeR
I3+QrX8HBKCq6DtDWJAVjC/yyPs+5QP2ycHxIfYpxCdI/V4HjhfcL9UaWbhN
I5hV9FDxOi+ciNTQfVw6hOCO/Go3zOWB9/2cObeS/iBCiqa3S/z4AP7qqYpx
DCJ3Zaw2gpn16r/PO1lXthuRoghonfkmANid6KujmQWoTca8McdtAUD4b9lZ
XG1Dlbh0xFNLiXBeUzn3uvECUvCI9HTzEQH0rGZNYnAryE6rpttWzHzXDgp0
/46fRXJDQrq/KeCBcqI8tOrSDBIvP1Cw7TMByMj1T/l3xhGz7uFEbWb+y/Cn
OQYw89+h8q9a4SQrnE4sEtEankZsjE4NJFWxwMVgj1vRH+aR7pKET7/CWaGC
er36mkc7YrlIplU/ZAU72egiaZmvSOIb8Tr1C3TQDKes/bvGjf17ELfD7xUd
OiQvvopO4sGklT2upCdyQEXEMYncGBJcUK7NeCVCBKXiIuWrZ0hQbqlYr5lH
hoy/nTXattwgn78WXnWTA/gfFFPGTXhBazy+Rvw7DwzieLkLnLkg3THj/h0G
HzQ0SSbGB3GDXKzEjvO7uEGfO3gH0ssNA1pP3/wy4oYyk5n4H6y8IHHw8ZjW
eR648XDfp+3hzLV9weO0ATK4ygydV23jBo/mogazAhL0mAQ8PNLFA/+x2Pov
pvLDjJGFnGUNF2RzHRATvS8Ap/c0E0YOcENMWHCA4ykKPDc51RvjxAUlw0Qe
iwBxaBvewo/t5gJGc+yFIg8KmGlGtoZ7byGRGtz1OpsUuJ+de+3MyQ3Er2qu
VfMpFYQbcpNnuEjgH8nidPgGDTz04i+QnpDgtdHPzK9yFJhxdWXTjJ1G9n1f
5eCREIdHGyhMd4wj+5+V6Rxl8vi/j4PVGJO3/YJTA1YyhCAgiLptyGcGCfl8
defoOV5YAo1rShKLSIfbj29W25jvNSy5nGY+i1zKCtpWHImHNw67p9qsOOHU
nSiscQAH9byZn+nKXOA8HMBRWsEOjyVUdeLFUGTX7bTA13dxoH4gaPx14DPE
5FFbiXstHwSfy3bl+bOJXPe4Hvue+byBsK8P5vJY4P3dx5X/KBwgkPyH4j8/
g3AGSzpa/CbAlVRF3bT304jSz7xvlCI+WF2I3ma2+B5hsTrmVs+8Z5thJyN7
YjFqu8axkE8QA2lrv0jTGALmLvjt2p4pUdi6+iLtywUOzJBacu/tAVY48oss
J2y1ivCnT6vv7tlAXmRLTXx9sor4pljwYS5sYPAon/u/Kjw2672Tq7meFbQV
/E/cnSJg19qcQ4jtRJgKuPefoiAnqL4hqXluECDgvtYYaZmZl0cV8RqmPOCV
G7V1+jMJck9/kT1rwg2pU4yEHlFOwGLbvjQweSvqtWHi17kuBF0cKZ6t20Ss
Fe2aMsm9yIdPug/1DPmhaIBFLovJiYVaeXKHU/ggd9HbdkcNDxzqv1jA6iEJ
VkP3kOGhv8jIhrplA5OPg8t3Lak2tyIOBu+NfnnQ4MGj1Tmf1AZkOd8gePc7
Ggjn3lLjIhYjeYf4IigxgnAhusbZZYUVrNWr0767CoDgC56Uq2dZIStO8WeX
HQUOebwPyMcToY5xyeeSoxiM3+iRph/Fw4SpnIF3OB2mdkgfFN2JB8vVnfEb
s3RYe6D34DCT8xrKHMrfMfm4YMmLk3d2BRn98GPv05d0yI07fLajdQHJXtus
47bkBw3DbvRAxCayKEItyLvP9EHlcHcnmw0keF0t086dCzzfaF1pvU0GjYT+
/QJMrshbWo3vDuIEe7W+IJ9EHhCWe8Xz5lUfamP2vXJjGzdw3eY429Q7glqa
7rnhRmLW2//KevNwqN8vfnhmGMMsZsa+G7RIWcuSlvfJUimUUnZJki2ya5Ol
LNmSQrJUikiWRJK834UWJSpEpBDZs+/LM9/neT4+1+/3mf9e17nv+yz3uc85
r8tcI7jb+hr7PYhvLdt4PBYPm0cLtMpXyPB0lwV5lxQecu6F1EjrkKCBN1s3
9tQyojbm9nIwkQSjmu+NkmdXkO6srRO71IjAyFjSsEwlArd5kYNM/HckAneY
MH2LE8RAdBuJpwYZ04qf/t/voRmYzqUfYfMpM501/Jb7WLBAfqdylMgNwrLU
PXBcAjTo5rYlbxfRLNPcvTORkmC3N2z4usISGqGxRkPcWQBaJYN/GevjsBC/
C5KCO/nBc4aH9joIh/nh8k+Vsd97OGfKnhAiHeusd55w9ReHbr2ud3V2DOw6
LysXd0sUVHp3mOmVEzANN46x379FwFxIcHMjjQMzcdUucKqVBj9SkOT219Wo
gJZIPuegNBxLv2sfvOk1cjQ0rVYxUhB6nqonqib3Ik7PbQ7uShKASsNNNbd5
h5AWAaPn2QgFNAX0L1m5NKPX1+Ar7L6z/ZJ+d8nNqgHd+2Ltsu9dPmB6qfsE
XqBgIamPFz+R+SDqt+b6vQtUTC3DzCQS8GBjKR8Q+eY78tlqKfQ+O9/FTRdl
7Ik/kSSb9s+nrEhwMXXiWNMnIua1e9m+cpoI29452HDYkbBaa5dF30AWxEma
lGU1c2KcFVqqjBEWeGwys9+QwoUZxtJUnHLY9fBy3iPvaV6M049ufO2EOPT8
Wrnjps3ADvfQDskISkMoj9wnrbvs96T3cL/5Fyl4h8grPpJg913qWIVzPg1+
yVhyTcuPoLQtZ3H9TArUjLzi/O7wF+X5EOKRrSAGBj/O5NIFSVjAwbuiOa9E
wc5oel/BeR5MtLIoXsJSAqx7N8x828yD8SSq2Aq9lYBf7pw26QYUbKvCqXdq
llIQsKbpzdQFLoy+66ZsGEkaXPumWvs3kDDF7icxc6ESEGiJe7A9Yxm1/Pqw
aMd5CRizUIicmsRh5a84hbTdBUA1gV7w5iAHvBtZMar+wg+GrwKru2SI8Pt0
tBxyXAjO3TIf8t79HdVZOXe4ylUQAmMXh7PedaPPfHJQ/bNScEE7cOx87gQ6
czFj4v13KUgjE73PHJ5GefkQ/vRmKeAUm6cdeUmFrTYlTXXR0nBdPSNw+hcv
RHl5HB8VFwWDqlOvlQNIsOfXI7ljqSLgkPYqjG+JE54kHdmc91kYhGeDzzm9
IkOf5i0THwdhAOHz9dYFFHg9dhKoz4QhY0caz1g1FdZa+FYJnBaFE5uOFm22
oIBa8+iwspMYxPjfyVbFqGC+vIdP7ZgQBLe6HfZai4dqjYAepZeCIFomIney
BAdLM1u000JEwea3ByPpIhfsfmfEq6kqAneGJ+IVXbnAprEhQuaPCMybYS4/
rnHDefdb66v8RWBPsNAmGRUyOMQoHD7hKQrED2XGcvncoBZLtFDNF4Vrrw5S
rNj15lXHGauGcBakqtVtLHjXhfKlnd+cfY0FD1csKA8ERtAhx7zklAAJELnT
Zb8/7ieaN+fae/+MOAS9oUZ9LOlCmcevZrsNsflbvy9jxnQajT1kMG6UzsbZ
YXsL1s6hJQnljN8vJaHJ+mvqXQk2f0m6/LeHXU/9ini+3DYgYg2te1qelzJB
q+QovTaaAN9Xti2YWzAhY0ix3YDMCXXthbKu1jSI+LrZ7PuDMaTgzrBP9BMK
NFmm4hzOjCNnrcyEOn7QoL3QKjmBrwXp6xVwVuihwo2ldtU2jhrkhtPXKP4A
BjyNM13cEVWNbCb1TSofYYD2l49RqZoY6iJ5ysjTnw9uan5UWxfThtb65+EN
1fkgFn+gM21dL+rsoJ6taMsFbp8njeIn5pCcqF9CarZEqIyXrTLftYwou5t/
md7ACT+19Uoi94whV+7WDHhNEODn64lQ6sdRJPqTwNYhGhc01jYGqBd9RzSv
05qmA4jQ9zef/5XiE6T6rXiwTjAO0r9MOd2snUKq6+uGjzsuI+SOBfcX9AXE
ujpITyiPzcfrNp8uWMBQV9IJG9sWPDhNraxtftOGDpSteSRdJAkcSY24yCpe
bLAsYTSDSwrmAyTFnHYzMLNPVkjdCCcYbpsvvsbgBqED0s0TzgSo872lVFVD
As+5W0EkdjyyUg+aKaM0eJZrgsjqMiHqUdJT8UpeWHZKjsxL4oOsIqeO0+o0
yLYb2yRawg8PjfubupNpEPNgundaVxyu3DNrOrZAgbQXDqMzRyXgY7E9w/cF
BbQb7BOiQ8UgxHDs7Nm6BcTi8H7xW7biUBjhgV8fO4ec+OgffrhMAt4mDt44
Xc4NvMbqHnnukqAR93LTjAUPPHIzVpbwFoM/s/GDF3cNIOZZkjeOZIvDkMSv
SGrcb0TxRHgqR4UAfO18sr6pbAh5de7a0uYeAdDbv11T1bEb8TOUsByIocGO
nO75nQWjiJ5/eOCcCZvXXf/CRAIGEcez+T+ru/EQO/Bng1Y4FcbMGyXnnuFA
3GHvhQ3sOfl9TaSPqjoerinIKjCUMlG5sL2RLiJLiIiGzru7r6pQH1OfwO5A
XjhWtNOxcwMePhHK22pzqdDqV/u0cwsBuLruZRfmc8LInwytv0l/EVNq+8k1
1QSg3L2Z/rR/GAnV9VI6+Z4XJMihBzedfI06oTeXrRKo7HmyNJy20oTq6Hbp
besUhgbied+QRTLm0OfSeee7MJj5ZXK820XDJqIEMpy98fBEb0OS4BoSFtOi
GlmzZxkpJr7l6b3IjbGWvpxf7uSC2VMTHGW7aCCQId9V1EkE8kBIkHk4Ha6Y
V5RnGdEg+cG5t4FKFBD8VPfsvAMV5md+vuEUpsEgD3Xq5VYW0BzGv6eoNCGS
oT6O0SUscN2pE91yFEOo28aqWkUk4cAv/yFtn1fo0fluu2AvSZA7rXKy1aQF
7Q8b0it6wQDd8fYiJX8cnHkUvYG5xAsXH/9RDYteQXI8ikydj4vAB55MhxoV
ImySPqDcFCMMHAxCnlAUB2x+o5PLJSEFdrKM3pUn7PktLTDxvbcUvFBW/fgy
cxmZTJe+/aVEEt6ZCmuZL40jyc3KDTbsepMs+L5c7uwQ0h/1bkOODR3KH3ME
jvkvIOQjdqLqWTR46YzL9xKcR2Y9NO1EJXjgVM/425fdVChT5hUe/EMCTb4P
u/LDaEBx/vaq/C8ViHt2fTD93I/S8j/4vTKjwPzm6ObF4VGUW5R+wGYvm8d7
dnyvYffbYpdd5xYYeFhgDKT5l/LCd0MnRm0YJ9xP8PFN432NxJv/LuA7xwGz
6/ROR91+gx6lat12fyYJesFlDpjmEuq326V+MZ0P8okxVz1v4DDePp8nx48z
4eHwiefn7+EwEUOeyM3s+rvNq22kvJWBTY7qT0rricMhLdsbxhFMbO1MU7Pg
TmG44rf1A0OJA6tV+pZxyFUIyrMD/vpzcWDcy29UL3CwAG/rzkria0Z+OAny
bxdlgct2znZCSg9y5NpuXa1QAbhuGdwqfX4IyT5E1O48zQ/6ejbvKnaNIeN3
z+eWHSDB9XvRF+qvvEOHN56zvmVGhK7i7OZtLzA0OHLypvIJJshRHnNIHuLF
lntqih+w+Q/XQmii8z46ZnxfS0ckhAPy5C7vPZPDgxWsK9gwhCOA1tuCTFIL
GftYf+H0EyNxWEde/juQwcC8P8dGN+PE4bB/SMPrx0wso2WwFRvkBlGfu+/L
lUdRwb33B7fncsHrA2+Jbcmj6IeVy2EaGaLQNXeS+RnI2Du/RepJNv/0da6z
uylHwYprfkVN75UEr5cCHuscadg0X/O3A4mS8HRs6wOjfl6szWfii7qLNEQK
Vk098CFhTaZy+7yPsMCSemQ8IIAb21V2KVn3rAQ8lSnPvErDY9981kwKs/mH
Yc+U7Ku3BExmRe1x+G1+KLI8sfTnIxG+8+m+ObvABx7Mr5V1XiQQdgx78R4E
oWNfqg8J14PuXtaot/jf97O+v/jC7TiI9tGCee3spYGk7ORx4tcsSpHcoDU0
x+Y/3no79aQW0GWNTQF8t0VA41nV7/RpTjix8nFxXkgExntzNrfcJMDEcOGm
zHxhkLM+Z7E1jwysnvVft+ULQcpIk8UNMhmyJece8vIKA8XghNb+p1TAZ76y
+d//g/cj9B/SecILd4ftYrZeEgN5zq+KdZ1U8D0bbDQTLg5SG6PrvrHrXMc3
LP/VQwEoVjvOMWuzghTHrXFPe88P5Un3Gmr7l5CpKv7RBg9hYO4bkm604IIT
H9+yajYKAc/Z89zbEC74IyNxqW+/CARlXJM5yUsBK8Zs/WiPMHjmzzwObqXC
E6aacWOpKGwPdErSnyeDPy6OV+SPKATxP4IoCxpIc5cUedxgQQ6q0PPo8Bjq
pF9bq5fMAtOEgSW+4Sl0q0umb/xrMThzij6Zqv4b9Xi8rVHmjSgMIR0E3es9
6FGzUZt7PKJw4/pumTMXcdiF5fMb1SpEQPR8WJxYNwGz9w7ZXXKFPZ8Y9Y0Q
rYjYk7DzH3+YSIJvVPeXB0Ek7KxYxMczG5mQd8P1epUYEaLke1T3vWNAx5DL
ercoEkjUXtBsHSLDz5KkbVJp48j7K9VWw/t4wJPa/hl3cAJRJ179mpFChc1t
Q9kF7iVI6EBZhU44BZ6YfjXxEnuLegrqut3ZxICffDb3/hY3o2IfEn1/dtLh
x0MjpeS83+jficlt52h8UJgg676DMoDmbBp/f/s5Eyq7ZCZiE8fQGxM4J8NH
HHD2lhqrT5IDxPPgTQoHBzTGjlNfUoiQ6L71zRc9PMj5koVMt/5FGl162oZb
lpDcNVjVovsQwhNUtV1emAinn/VvKjWvQT3f1fJ3ChEhhdRbve5EE8qU8T6c
PIKHXfaJN8gbOtHWI/1zY2sIkG78d3CD7yA6S0oRVDgoBW5DJrVDeCY2XqrU
J1UgBQI+lEiLPCa2Zu8ZD7FdeHb9beHPvEuCSu0F/vILy4iunv4snycJBsar
OW7sFID+/cEu5l9psJlyzuhHqiBoTOyz4zzFCzfkqdsDAiVhewTPjaP+FLDX
CzQk3ZWChgNb1LiNKRB6+KlU23FxwM+oeh8Im0N4sUcq1IMSUJ9YwLMVZhCd
8eSqWlspaOH4frMliQzhkSnLE/zSkFBhzpDTp0CtrP6Z5R/iUNmjldt+rRtJ
kh/qNsuUgLgEAZMljQ4EEYcXfNyCYCkWsd/7biuiMm4ov6QgCPkeXOqnfCoQ
2TN0KGDP+R+4e3SU0v4gH7adMcjo4AGZibLMFze7kN/fh1SlSymQCPejCioJ
YDtmU73ekgJBoQtu4p8J8NVs80X1bhzcHtaQJ2wZQpyL6WblHDigthd+Gbs7
gOAl1kjEH6KCWESK2ZjfN/T5J//GMBoFekbaOg9OtaPHr9BcH/0QBsOfGw98
zOTFkpWu8pR3C0M+hqu/HM/AOukxLmHs/vxrcPvN8UMtaGk/d+vTj5Jw4UYo
JUrmN/qm+9AlNy1eIITOHF7Pv4JQT+ZdMeGmgUyTa0DeqyXkmvSXDXNMYbiW
9aR3yYcADnNMppqfEMglh+5iUfBw2Lf50t1QKTAxrZGxj1tCjn28wz/I5l9r
XW+cuy8zh+wrfPDz01NJGM2yzf9++TcimGau45shCcXB51P0I78gjgbd5uuC
qeDX5qdWdWYO6dkPN7clk0Hn6YhnwbpZhKu+uMBehgT+ua+4TlbTYPIXzMe6
cULKbx5XvmReeCMdtafuAxla6ZVGHMfH0YmrA9SCzTzQ6+uV8InNT3aLxElR
TDlAvi5l0lPzI1p/V1DS0okAZ25x/Klqb0O5D5dstgMmTGqsdT90F4f1t6Y9
3xHMgCbtBnzedxzG1GyevucsBGrT7RNFRA6s707g+JpzbP4p3H3c8x0Bu0qK
3smSYsGfk73BJsJ9yJEQ33n7bSzoV5t4m9Q2hHhlcQ3FL/EBPv9tjmzoOMIp
H7jhuQsfDM2VaPhFTSLycWn+yhOcwHfUVJbXHkXf/njabRRLgNYW7umlR3lo
wD5BB+VHDNipKZgS6kfH7P76XDG8TocPh/nitfYxsGx1eY0DgnjYKR3yieFN
wa4GDjh/GF9C9n3hj95UQ8VONfS3njQlwsr2Hb6hb0fR3aqjnqcvEUC2vbZK
TWAMNXZ8f663QATGiqm0jdxU7E3O1FhIrTAcUnxjdVmNhu26YrzpDrtf2mxy
1kIGeTHVAWPcRI8kENWk8xv3MjD9yPbEWi8JeB747qwALwc2S9rMOWgnAR9c
cWl7HDixHhUfj8qXfOBnvvBCf5kEXw8mv//I4INdtw5cndTmAelzSZ2YhQDI
Nke326cPoh/qg7xzE/nB4uDQg4Q+9rzVWUDPYLFgg3hG6cTYAnritRf/nxgW
iGR7pgesXUbv5aPm16rZfHz8OTa3GQ+n9H7cLPQRBleEm5iRv4xc2yVkEhMs
AFUvT9lsSuOGvyM6ZyUO8sO+Ax60HDYfitpreNBXjx8G9gfNqm9YQhhlfGE6
wAcB9tP9P88sIIU8IwfswwRBnif73oAaFyhd2t9Y5C8Arbm40gk2z/PdHhF3
FhUGh0S3wFIfGhyw8VB4s54dP98BS90LdHBcSA4/xO5XF/Pnz/dzzaMBPzlY
HGy+fXnmfJeQ5DLa4adUpOItCnwDD1XfvO5BTX8PyHcfEwGjN2sNhn70ouep
Ew0qt0TgZM6PwWFVTmzgWL31Ovb83P2wrJu8hojp+KBfxOUlIeL2s7dG37mx
0ZBD4V2NElA+6/4Vb0jBPApvnTG5yoCqjGM+4ht5YLtfvzbVgQFGO7rvcLHr
SMzz25n9DiTYKBjVdCRsEikKpy/4sYjQOH0xUjdjCmnzEJ7WNqKAi/HC67cX
6tB479T1N+TJILPC1+Wm1o4q+d5Ya8f2k+Y6cl310SC6r2759QdFOvQ8L60x
XhpD+y2uxBx9wASRe7b7HzSOo5mH9PHaZkwg77gXb/14Cv1okUmvECFA4pnb
Eudvc0Nq+RGtuBg8eO3I49y/QgbLu9zlbspE0HzU1C2xoxX9ppc8PXecCM6f
cskK93+jkjv+/o7fTQBtsZTIUJVx1HnYi/nalACfUh5oFyxOo15lEQbOV4QA
P9BoqPGOF55mlppM3hGGxJ0Sbol0OiiOZ2352iwFKrJ3C8T3U0D8iu/CWltp
iA7GxwePkmFv09dk3WAJOKswuMJ6M42EnaafijnPnh8L78aEc08i6oMqWjRj
aWCMSmeRXSggbJLwIFSfBdwejy9/1KTCr9znj/RBGkqTSfdEnF6g9S2UiNMx
0pDEP53lafcRrX6u9W3yqDQMx/3UGN3TjEYwPZmpWwQhWS3757dtiegWfrLu
5T2CcMmWz+g0qQX9K9Xwev4cD4w1Pef44NuJvNedlol9RoLCQqE9tXOtiBOO
TP7jSIGrNxIl/FIJoKMZRD7DzwNZ/PMUiTw8ZKkcpmPaFBi9NdZ7so4A3fR9
tiZePBDv6FAiVEUAx1NFd1xpPFCxzVffObwTLWNya0iKc4PRx1M7D2HdqM5V
nKtPnzBYoxWxRb5M7BH3M68ElhQEXLQkJZkMoGTFzuMf46TgtcyBFOucMVRE
yXBWGqHAO7K3TGbOPJIg1v8zQ5IMzhm6f2OT5hC+I9GuZ3yFwKJV640xDx7w
xvvH5dsE4eeHaeLghhWEHHSusF9EGpSeyGduyZpG5Hx23OL1lgaJkqtRjwrG
EaMjiVmT7Pntl8jbn2Zzzqiq9ov6ckUeaGo8YXuWNIPoPhvUeidFgvD+3QWS
dVPIdxlzngcsHiiv7t22FDSNqtgZBFi5kkBLfnxy6cg8ynf6oIluJx42B69s
KZHtRKXsefAND3GwTS/x84VT/aiDpNaajv0MyNWJ0gpewmH735OfR5jRoaie
iz6uhMcUDkto7rUXhHvC9il0Nj84f7Hr3q+9AnDzt8pFq6j//d73vP2a7Syo
Kut52jE0hKx9TE+Ys2eB+0pb/ojUGFJa19EhvosPBqlgyLtrCjnV+Ow+dzYT
5gyUHhM2zSK3rpqHPFbHg/v6oJ/uf4NRN8nLDUNPFpFDJ4ncM2pPkcf1i1px
BbxAP/5wcSmWgYmXZLG+rlBhpnwkTl2BiW0r9+1+o4yHpc6XnU6KY2hl0QP/
2JBFRHFdpbLOFjYeQIRvRbPraWJasfFZGjYc+LhCz18IGidT+k8848Uu2Xbu
ajORgvAclRuFukzMSSWBCrlScGl2x5BLLhPDmlONz6hKw2TKY64/d5hYZ036
9uvnpOGi5XfNT0pMjHO7aYwsnwSsMbaRSw3kwrq4lXWoZeKwpaPjQsAsN7Ze
5XTdwhMmZKTremTW8MDXU/fTrkcygN8rd9eAAwVu6u76ZWfJDxUe7tcCpsZQ
6VPt6+6F8oH84Qb/G5FT6E/jBYvKg8LwzKf07SveReR95B2N8rt8kP3a+2zf
LhIwBHVb/T6x52fkytHPbVxQnLf5zzZ2fSJTrSrSdeaRwbw71aRRBpTqPWgT
PT+HJH84XX4rna3v6n2/6i4iyIYfCgtm9++GpvOw9JwIh2ibvOdDWZD1/UZ7
eBgOo7pIyRu7s+DuxaIn6eocWOmhHYl+D4VBPq/vnOjwHzTV5PblEHY94ssQ
3Sm5px/Fpwd2rtQJQ5Ru462z6VyY61T4A95DwnC/sF/wPMKN5bvR+2VRCfjJ
fLn9TicFmywKxYOrBMxdGt4iDjTsfciTtNv27PlAresP/yUK7BM4P9e+lwEG
SYJ73tvQoPfX92Dbak4IN7VkCldOIXeE1r9ArxEg//6bT5s/TyNRoffcicEk
UHsoMuhoOIhOR2k27szkgvay9W15J0ZR6O3+aLmGDrGpefx0ngm0Ou/tc8Fu
XjAq20QwODWNliY5vfNvYcDecBk3haZZ9C9x/oatEQMsRIuWCEuL6JYzbkdt
tuIhYayghS+HCpEsu5L9CzioMk5dXL7PCyGlp6wn2fV8hBRf9qO+B7101QtH
iCdC7JTdq5/bh9CNYTUcriYEMNU8uq2XNocOcoVESuoSgNsRvbj4bgk1TFm5
ufhMDJbeverrOEIHN++kuKyj4uDKd9n4OoUOZYlulQsbWBB6XHjz0es84B+g
nqQYzYKWXtXSxFJu4FPGHg1US0KwfFP/XpkJRHHA9n33ayn47C7Nl+3zF9kW
fvqG6mUWTHzTjhu6SgWR9/MlQ0ss6HzJx/cghAa1ngXQliQNejvJVhlvMPRr
+DOD9I0sSPtBI2CXqtC0o9X941XSkGy3yac6tgVtNPvcLU9lATmWv9gV34PG
vpA9e76Tfb+5wcWFyuOoxV0NxZIzEqDkcPy1jOQUWieertppIggVBy36ytN7
UOE474mWnYJwNvj8k6ctgyjXYZMj5Dku2HupKnhDYTMyUeqgFxrNCdUThl08
3G+Rh93pfXtaOCEw9YM5ryAOLB82GvGxeUeZwbt+jzvLSMG89Y5PYjwQE9nh
4PGeAE4GtBeng0hg0a8UHV7A7g+WTqf3HiSBIXr1t7RTL6pFxXVH3SZCeHFU
cIXNELpYOnKlO5XN/9wfHt+JjKPLkWnckQxpKNvqpuIRP41WhrjUPVzLAzeZ
o6FaOnNIjMmB7+5hXOB551qwo8Ys0lY0v0bKVBC+rk/18ry9iBQxFt04MAHo
4Khac2XrPHI1NX5q4Io0pCTctO+sHkO277B30+6Xho/Etu6tbkPInpx44gFV
SUB91jaE2bxGcfLLG7fHS0Ar7tEv2bBWNHinrfDGaS6w9nLOca+YQqQT6CJH
ME6YvHEgouzsJHK6Ds98QyFBRl6By8G1C+hTTqa3/kkiLMUI0Gf2L6MpNe1v
Iz1wIOp85BWP+CA60ZJuEkZYRhZLHPnqlsZR16tv5Eu20kHYelrqMbv+W52Y
sog4SoMvO2NVlXfjMdug/aD6kB/Whgfc5ztIwDjPXvuRFMwHX7OSO9s68NiW
q35RO1xYUH38+ToHrnFE35SbmX+LnR+zP24bHZlBvgbFBD85yYRTmd46j6Ln
EP0pZZWdWQyAZOc4kw9LyMj9hypCUlTo0Hw3Gh/JxJgqs4/HDpPBLv227ogd
H8atvkmv9pAQaE26Clp38mL4F0+QWi9B2LDllsVTLga27erZltYjUhDfcr5l
3IuJpd3PXtzP5suG5xQM+oL4MJM/w+8T2fPLxR2pVl9JfFjsVYFnButYkDd8
osE4mQ/7Mx4778Dux9823B+ZDWNifolDKyZiLOBccL1YZMfEbO5FV0/cEYfl
h8WWwxk8mEWxUOELY3Go9zgbi86RMZ7lx7vlXBiwubH5x+FYCkwTFN/y9PKC
kMv0QGcHFUbGVX0DfPng2vxJY7uqKZSLt93r50Mm4HZqqY+ozqGiu4zfHCtk
QuqiW/ZSIxeYzYmsv+TOgDXchWqaF7ngel/tm/fs/pFY3tFcaz6HlNuOBB0j
0kGjSV6K/9Us8sVja8XrdCZ8+dgQFJZHBCT60efOUAasH+EsWKwkwrSl1MPB
Yyz4pX/JyZOTiFkPLwp6mbHgcLRpsHcICWshfeB/eFwQ2qIknucbD6CJWwxF
Jw4LwMtP0vVbPw6gpbZSl9euFQadg0mn1Gk8WIjIlpN8d4RAMzCYK8uegi3/
uepf+1McvsYcvqxUz4ttLz/gUecgDgnJ5ej7HWx+l9GrJuiEB97al7LK8TPI
heSww07KSwiX8Z54bec5RO742SV3Ry74HBTlbXBsDI3DaocEw4hwLKM5wOv0
FFrodC3viBkvRNvdf+nCWEDPJ/u7+9TRwHZKodaiahmVNbVr41/DgN0HplwV
gpbRQx8vha+402GvXUNOwVY81kYduTA5RYRPn/XtuC6PoZ7rL01UXuGCRk+v
1ocS0+hPG5b920gJyK4izFwso4HPD4H4rJuSsE6j5xs8oYLSnVa5u5zSYImX
mUy/Oox8a+J/ffYTe74uuR6s/a0XCYkTUK5gz0M7fhDjDhhWofuvBOWmNLFA
+cn9ikNvqtBu8zRZz00saGrh5S4/OIQOPCNmV+5hAV+I+cn97HpZhos5uHan
BFxuWbq349c0mvom8Kl5tTgk8l7aTs+dR0ulZr4OLwvAfO328kqjcfSBfopK
z3sBeO45YdaXwOYHOXH7RrQ4oeWqY0DL7yqEVahcbBtKgIM8jZjDBWO0diME
xScQoP0mI+yk5zJSefzF4IEcPBxZ2cnwElhGnAYT1odykkDf7Y7e7UQC0Bzj
xxMNOCF/1kcxVYwAJc9EJOVkiUCpajuZKzyCWg8IbBAX54DtG5g/UnvG0WuG
d0zzHaXhh9Jtw58H5tAoPXcnvRppmPPboOc9M482DF+Kr9Yiws6dt31q0mcQ
LxBtD0kjQFFt/h5G4jRyVd/9y5MYAXjornz4YOQc8hTXwjKP4Ifo8c8RncRp
JCFFb8hemgVBj7hoUTl/kEBwKvrLzt/x6EOaGg3dyF6Ze7/iLkiAmcvjZ/ax
bSj9a5XRgKoE1C7hNn/q6ELrc8jXzQ05wN5rz+60UxOIizNee98YDqR/bGAY
do0hch6m0d58ROiaeYySvy2j/aadJ4Y1OOByhdNZZiMOU3jQXj7sR4GWNNWa
o2fxmJ7PFR2iAA9o3uKTmCrHY6NLJ99qJjGhiqpmoxSMx2JfP3cMPMkA6VfS
OVtk8Jhib7UzH7venemxpZp9XEKoBySPP6mjAxHbHdRKxMMtw7akIClBEEsd
Fuzaw8Asp3pVLtsKQPdK8Y1rYwzslcwhz0YtFjBJuKMFx5iYEnez4rdRFrjO
DVwrMGTXy5vPkgZyxECvZOpz5zsqJuf+4WLYLjHQiU348NuCF5uIV/z8MJMX
ntecS0yi0aCGqRcvLkKDYtZKtOtRXugeXTvlEMqE0wfuahq3zaFL1vryPlEM
UOq1mMsXW0bnP17v5jeiA+NaKxKwgwveVFg4zGrSYMvazJ8Gg0SQaby8B99I
hZyt6t5232eQg97miFUOGRYGB4+Y09j4nggZZ0CHd5ucNbjZ65Pe4StD1GiA
tHpaCq3lgvXfco99tGDXo+ujx8Nv82BtlK7OnlMsmHrwl9VtR8EaStwjz7vy
g3Dl/JD51wE0AR/G0c6eh5NtpOrLOAbQLR+Cp2dihCB32z3q4ScUrHaT3OnH
NCEo6L0X+9qHhr3CKbrs2ykOLunbvmvFM7C4h/eWlwrFoCGmlPGjgInhmNo7
D5PYdtFI1DSOWfR4yP6BvRacMF616GOnNI8G7TqcckyAA1ziYirr2+fQewz9
koDLVPacdjCgjMaBHUwtN6stpABfeFYJ5RgRO1BJ0R09SodLN329TD3xWI0M
Z8TjG7ywlW7BmcfmU0maRuoyzVzwe8We8Cd2Fq2vO8ARnSYJua/0G/weUWHX
aXLjnwIpiBH/Om73iAKD0jOve/9Kg+nUl3rOhB5ERdE3JNeUBULlx2R90tqQ
YnG9613seuJ5od+3XmMcFQzO3eRxggVfZQb2rXkzhUYIjkRX1onBoBNmmfwW
hx3toW2xviUGfxT3kuw5CVhiUuCl1AIBkMqVzd26Zg7tjOd+f/GWAMQJBvvP
XVpCTRfeDlk9X0F63909h77+gpatK+cWObeEVOoV6ZpOtKPteipzl5cIsK0B
Mwn5gwfO5/RSmdc4CE3LrFe9iodnP8O3/e/7BRNFB4kaWybQOYHSngBtPDwM
o9q3vp5G3ecKkWEWCyprgv1X1BdR15HLcjeusYD6bkGgnJ1/4hXLL77l4MDW
hv+47dAUIu/67VCT4zJi76d6Sk5yGqmoszqX5MQPmAYXLjhlCunxL0/5ncIH
le18snwr40i9FWLL+10c1srGvdk7P4iuM5y6QwoShxtni/K3642jw1p3RWEA
B3F3zfrtOsaQT+JXF/yUlhAEdyKAdngUefNsQu2oLAd8jetfy+rCYafqHmQE
zuPgdsZvaT53AsbV42x0cIwLkjUYusLTeKxnzCHokR8n8J/w3/ZyPQF7unCm
L2I7A1jzowkNwnjs1MCXjTM9vPBq362IiFc4DO66aJ2zp8CK8Jl7fXgS3Pir
ZNLxjAyphNSTdAtuMLk5KGE8yQ8SQfdvZlgzsdtLz5xzdfhhtu7nxYOKfNid
TPuZQ5vE4IKl+eTmz7zYrnxJ2ssKUSh7kuxek82uJ9zzP6sPMYBhdiFlgrKC
NqzL1bZWoAM6ptxTzsRjEV8T4W80BT46xr4rekQEuSwf5pq9PGAtLFF60ZsI
K+P8PwvJPJC9VNLNe2UaUXrQFPntNxe8Fz0nQ1adRm5nZKcopVJgjO9KpPER
LqBaPE5q3cQDJn77W/bHcMG9nIBI7kssGOkW7RQdomK245LuIZksiFG3Lrxv
TccybtmTvdh8eSxJ7O4Frj7U4gNHckQCA2buqh/7ytOL4lTIurPvBeHCgaeu
vRq8WCnh8Gv9LYJQx8h3doyhY/JnxrJeZopBcc4ja9H3bD5f4cpypYtBmmtL
xvdKPkwvOj7n5m4iaDbJMtfAHHr/lsboVh0uONXjpFiksoz6z/RZKm7iAI+T
53bsz19EEzVGPJy3EUB96hmeUruE7vwtz2u+HQ9txKHSgp5FNIclbCHE4AAp
A7PYudY5tKbmdy0rGQ+swLXFbw7PoddVs9xpCAW4cq9MtSZxYeYaxSYL9WR4
K9saH2LNjWX5/1XQXqKCXCsl7dQSJ2bOHTQaLSQNcmSOLx90KWDmm3RNMUQa
mrdCoHwgGXSAjGg5seDhEdC5ufANed5iu7K1hAUXqkcEu7UwJMh6N70qjgW+
M9t7KR1z6Lt77tYPclnwRCbapsRxCTWxpebdiBcDgZsLUXIXCNiDezJTf83F
IDn0SvGNOU5MQnAf6S77vWc6EkSK7uGwUVmBBN1sAbDXkrrZLM+B/Zg4XdBl
iIM9wqe1R33xoBmyHFnLYs9zAXuHJeb/9/eJB7jmCysIfcdaroCD82iB6E7c
nDcfKFU9Sh27Mo48OUUu6GbP/xco6cZ4xggyf1hVrNtLHBpnNjplfhtH9Uea
kAYJcTh0E7bE4GfQy00xc16PcXDY0feE9EN2fYo53/rp2hIioFX4+4M2Jzaf
WDb1MoYDps8p+BE3EzCehIoOvkEcuOg2QNcuApYl9Pf96CYa/JTxfuChjsPk
s5OuPpSiQJvQwb4yqRV04tDWsi9XyFC4YV1CFYEHwuh9i561PEDzHUX2uVIg
nHJFamOKKJzwPZxygMrEXsg8PvJcXRRIu88utn5kYm6ux9uz19MhyrGr9JIA
ex5YV7zp730aWD51DT+cSMCctjZr1j7lhpDGRoFvbkT4vH9Ay0qOBM+NtSNu
k4lw3kG2eCP7XRxb1H3cpjaNlNVkXj/AIsKXvapD8+lTSJ4ReU3YTy7AKu+r
mRRxQY9PpUHcO04g5tbwUh+z++W7t87dZSx41NpoWH2SgbkExDZ6fGXPmz2t
pJu5TKz3meGl+kN0kKgM+ihT8Rs9Z2T+bNmZzecy627mk3+j1dG3IwYSBeDD
Fc/Y/WYMbFPxe/UtfALwfV6UT+c+Ays6fFr3SRoJNsRcrdt0hYA5HBM13h/D
DTYjurdNeYmYoez02CyNA/ox6/mufUvoC6+uI5BLgM9yA0eb9HHY7SvxKw4B
7PnSJsrGRHEZfatamuJTtoQ4rNz68ydhBSVZ3EQqXFYQK+VS5yCjeTRlvij8
jekSwhlvKfljZAaVK7dxnp/CgWfUeu62vex+dD5gYX/cEnIzO7W09ccs2udl
R3J7QoZXDzYwjbR5sBy6HPebg2SwDLO1/p5KwVL2dOKpn6XBdWPrD+tAHvBK
PUcXUWeBxS0v7s+nSSBQ+PcJAWPj07Vht+l4TMuT+96bShbsTA/UC3lKwPr3
fTpKlBSDt/eDeBgUEpYTvSG27Yso7HK65DAZwoNduhcl5lkiAAeO/ToXcI4T
Uz93w3ZnG7t/cp+8yJInYYTevI7725hg4x9b9aF3COHXuB0W7sSA7pxTegeP
9yJ/gi323h4Ug3vDN3uQh3Po9z6O8vQkMeg+6Tu1v2sJldh8ZmWEgwQRJU4d
S1GLKB39IffwHCds9otw4ZycR60jP5wVOMgDdwrkTbePU8H++sf2Hw3ckKgW
/sJtmRcazpFO5PdSYZ//zDrjAxyYqQ913kCOAgWbiTeo3ERM1dZa4RYQwT3B
VMRSgRMmvpCy8zQ5YHhufdBLKw5Iw/dyvt3DAeDe/vYvxySic2u0fOoXDjbi
RVN4eMeRto3BNdrTHOCj8WDP51QuUNMyuuP4gwC5+lbBP35xAf25XuYzZwIs
RRsoZveTQAqR5ZUxoMFAwi0lBjv/fJ8/OfSbTIHALUrzes7dqD66FINe4Iev
NH+F918ZWJPbI9VCXT4g/ag/N7qDiS0+LqO5PeYGKZ0k2OhGxC65Pvh0h32v
vjbz155uIWG2klxrSu8SoH5EPfTgLRwW1itrI3CAAGdzcTAAHFjsubBMqjQZ
vKy1tInZVMwjsEn+RikPPOeHq+cN6NiJT42K7xEWRBQeOCEtTYLHVioXtVPY
+VEh5X4ngxPO6G91nc1mgc2fJNtfbZxYw5rpmv3hLLjefL0w5QMJy1C+fO3V
E1FYWubImr1KxgyO7u9qvCIKHNRaXcINKtZ5v9LGdVoAytI7m1+UcGOiaGnT
JTlBSFmwddJ3oWB/r5vdwlkyoHdw6d6WXz1ICo9radI8L1BcxtziZtuQ/a8L
aTkRYmCl+EVmIXEZ1c/e6jbmwe5vWz1l4gJw2KdYJ9kgBQ644JcVeJA1j8rl
8Zx8dREP0zVZRTo+cyhp0qtGYJEMXTJ/7gcqEbERTf2kLYI84BGipyCxxIXd
XH/ArxJPgMsr/N5DkwQInFnavfUbDhZ9DJ+1HiWA1RWRe0LNOFA+IfbnBXEc
sX3c/GJowxISRDtKsKSOIkHT779dfECAMaWSA6ViXPA4yYBLvR0H9/bex2le
JoLsfJ9Wmy4eqrb+mLT4QYK9Ny+/OOawgjhLqmW3F3HDb/tXDqw+brhx920p
FbpQhauFSY7s+Zj6rneIK+oX6vs7Jp/+nglGMn/85VyYGK9mmmKnJhP83dZ1
PK1jYnOnlPYS8sjgv/CZkK3Jg/WKv3k/eYwCpLmRDRvrydg6n5m9NvIEyP8Z
PRd1mBMT1iJSfjfgwVjy8vEPI1zYvW7OwuogHrAMoFQtBjKwq3rqGt5neWBo
o/PLXWx9Rr5Sqkp+LNiy7brmWl0eLI2goJXuyK6/GsT0WWsKJlc44jfpJwqC
eiJ9/cU0zKF5eW/mDkHwcot/PcCgYc9rRK89sRaE9Sf/arddpGOfin2musJ5
wWxn63Mb9Bty0+mKdBaRBq7yL4li1RgS4VlFv+kuBud273TNMSNg2RU2r7Cz
YlB9Nu+Ydxcn9suT2nzpLw4kmh7/NLKcQ2td2hrvXlhClF+srOssnEXLTqtG
XObmgQMp7TdruUlYowVt4MwKFziFLyfzDXJjQ7cm3dyiVhDfcx6iC5pEKDrT
UIzhlhC5942/iyI4oSvfMUYzlwgKJdnhswEdaFaxMrZsz+63f8Jy69O/o/yb
VLTXnKJAUP9urq29ZMwuQJ9is44Kx4/m3n77k4pp77/n8CEFDyu7BVKn87ix
fYkn/oSF46H2WILnSgoZ2yY6dbHfjl1vS0Yf1MvRMANuSr+hAwuKDct9tinT
MUryzP2DroKwLTNpPY59H/Ibs481HRMEGeUWshDCxBroAcN7HlOB8luSetnk
CRJRPuHAp0CBnVkiRl9+16DaKmH0pgtiENEQJr9JnYj525TXnwoQA1mrH7or
K1yYbNGtUIenXOC24eTNXhUezIa1191/mBNIJp5/Fv+QMYbV8em0PgLQ+9Qy
F+jf0e7s71IDBDzs5k0/v9e1Ge31eXpT0pAGe1v8CA896NjOlDKDpyk06PBZ
Etx8goFJ5FckL7L9P3ZCqDjQnoptPO3hGvEcD4NN+ru/DPFiQZTh6lp3Fhjn
vbP74MDACnAGjlzseqKqEHcuuJWJSfD5M7KEKCB0p0Ptrflb1LpRprbAm52P
VkKntlR/R6N7ktu/nhGDg8IlP3OvkDA+5vZZa28xqP/+5HvqFDf23ZV8e203
J7x/Ft9sMk7GbGWG8/BqHNDkWbJdrIyKORUob6Uv4oBQt/D8uXkzmnmvgvHn
wzLS8duBdH3sK6q7cQ2yNZ0GK21pkS7pDIzZ6Svx8BMNfh0hi12pYmJykZym
nl/xcNwWMT/izcAGkkINF9m8r0u9Zmimks2nD6GXYnfxgISI1/Ybwe0ow/G8
0utPJOCgFX9MK+5Gn2dk96X5iEHjl7oL5iQezNtMR/nWeTH4dMHiyYWnZGyD
z+Dt5DYC3FnH0fBNiIaleo7U5mzCQ2x5E/19HS/2s7Q3VUiFBEMdd+4q5fWg
D9YKXCmwI0KWrq0ih+8g+muL0rdpfzEwfK3zuECAgsUqhWJHr4hBC7S/fESg
YlPlDRsFGHhQn4091tzHixVLTN522b2MrCOte7XTnoEZbgsTV+3nhJC/J11e
TA6ha7caXWGWEGCtv4SOg8g4umWjgUbmfTFQmswWja2jYq5Gd7rdSOKQ31hb
5MLOhwrOZ5pNVwjgJLzd4uGpcdRdIcxYvQIHFVeCj97JmEL/qgrFv9AXB0Xh
56ktSQys5drwie3+4jDw3oFbapqBaZ9p+nb5EQ4uzHiws28KTb/4tMmrbgmJ
K2cZ17HnIQLuf58+xGlST+lFfB2C+/+xveBmrHKkAV1e+d/nDxJUGaKKFoat
yoPknMx+qAWvygvXO6hE3m9G/jnPP7DdZebZ8Or5OWPj7ZZuXav7QYXWJnJ+
EP0Hb9SxFdzR270q16dn3g14isP+wce2cYWE2ZJWsYzC2l13r42srj+0543O
1AsS/GOPcgLP6aGHvNjD1J/fF1TnkJRb//sIYv/IWZ7n94UzGPCPfQaB0nIG
6xnYP1jN4PQ7E6vxVft2m3iWPe2e+f/0BckBt435Rpb641X/79S8yQ29O4dy
b1g7lpUkCo7/74cPPjrJiRy2Z6zif86r9FcL1HXkxf45T9ImU+eZPRf8gy9o
XJO96fR9VT9OhffIpkfPV/29J+BuGrD+82q8l6s1tox1j6L/7Dew2R1n2EZZ
Pc+0Xk3sdNq/9p8RiW7+enx8db2A8y0F1vVvq9i9vpdTR3B0VX/2xq88mxw4
Ma/vrR58O5aR/8Mf9vqpn31ZJuw8/Qef2vc3aKGPvOpfhQoxjzNrclV/53y6
lXyMAPZKWgSEROTg/z4vWlrere4qaXW/2PhG14jMuVX/FTAZqUKXqVV7jxhO
qKW04lfXy1o5kH62fVvVJ+Zy5pXqUCvyXDH7gUuD5Kq+LsmrmaVyov/RP7JR
et9G5RU0dW1u0JGXEv+Rv+Joo6+VHEQuP9M3rnoiCf93fnkf6tmm/Xho1d5a
xdGmWblh9FcTv4ikgtx/8mG3wXZ3hydziK3BVUVtwr/6rDPSJesaxFZxX0Kc
kWbbv/l0Nr9izxwIrGIFow/1AWrMVSww2K65/aTQqn1d73evecbF/I9+5OW3
gr9DTHi6wexGl4rsqvxP+UOuU8/EV3FHD2lLijr+P/G4RBl07Rzjx/45r2Xc
7N3FjlbkS+izhyry//ojGx6noPxH+D/6z/CfWhN+t2L1vlzXOeV3rqPAxquT
KoYL9P+snw678GYzxgnh41xxUX5c/5E/KL72gfyVuWrPc4vBqGwOAhDW+sZ9
OsS5uv6f+2ocGVOd/DWJJhy5Ulz+6l97Ff1Fd/1ZFFmN3+hOhbAs+3/lKW0v
n75sIK5icWfrvdu38azi36MdVus5/72vCJJyl6z/v/l33+q+4ZrD08j/bY/K
/ciMyOl/8z185ni/8qHfSPMi/UF/JvU//qI2atc2XudZvY9dcSSdqHHSqtxo
3fbdEDmwGt/c++umLxxgYvvqcZLGhlKr53lG6eQ/LmOtYu5Lu+YP0cX/o0/p
U/usuw0DnsQ+stZ+/u99Rkye/uhIHUb+7/XqUlONXmYdq/VEJi5syKWLhjVl
HLl3TIljdf/wGgXrj0Ok/+RXlnzL6Iu1Y+if/KpXjxpwq3Kq0el1e+xEV+/n
qr2l3N2Uf/FqfjZ7ftEdo2GuIryyHwUFV/c7RFxu3XNQehXTHFfqP0b9+97+
qa+hl9d8mir9tz+FSNxY1vjCteqfCMW5yCy4cNU/3j0xcNiPuXqfivvWK3ry
MlftsUpbK0VKI2IH/cZXvCwE/xPfRupJblHhr6v6HoXrO8tVjKJCK2Z70tb+
+x4m1u5n3S/A/SdeF/Ilir4Vc6xiHvOJYE3zf89ftxl/fpI9P+9b+HDxV8S/
7z34W/4DPTaP/yd+nyLokjxGUqvY9gAEuzrK/Z/xZZ+3PSPVJVFiZTW/pHdI
pYiTGlbjcXV6MijCb2lVLhHvKtz1nYHFlWGEbef/+34PO66M5/jiVuNFEwuO
ZNhxrupT2ipq5l2zsBofGau4cNFD3QgDE1deU8NYtW9+u53jRxGR/+RDqV48
OSqMY/W80xXuiSVWXKv3/Yrj3ZrNFuRVOVl6l1MPQl3F2RGtzS/UCZgaLqb0
hce/9TXB1HCjD4fMf+LzM6Xy+pp9hFX8+9Bdl9+3a1b7d8DrXKaVwDS6YYuS
lkPdf/O/xduDn5H2ctVfLYFreBm+ydX9tmUlnudYHavybSLrip5y06A1tz1s
oJWyao9m7oEExZ3k//Srrcy6MzOLk6v3JUZIGbksNY+8VbpDjgoVWF1/NDY4
8ecX1n/2BwzlTz070oAyOrqnXrfyrsr9LqAMtSX8f+KxXnAiEzoFVrGp3MWI
I61E7P8B/bw1JQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56340482028636*^9, 3.5661014079787817`*^9, 
  3.6147278832518682`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->
  "During evaluation of \
In[279]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData["19.71978199999999858960109122563153505325`7.315502022834089"], \
"Output",
 CellChangeTimes->{3.566101477795525*^9, 3.6147278835299177`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"Out[279]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[TurboPlot[
\t{Move[LineOfRays[.5, IntrinsicMedium->1.3, NumberOfRays->5],-4],
\trodlens,
\tMove[ClearBoundary[9,10],{.75,-.4}]},
\tPlotType->TopView, ThresholdIntensity->.1, ReportedSurfaces->All, \
ColorView->Log[Intensity],
\tCreateClones -> randomclonedata, RunningCommentary->TurboTrace]][[1]]\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[280]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883814904*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278838183823`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883820916*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883823553*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.1`"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.1`"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`PlotType -> Optica`Optica`TopView, 
     Optica`Optica`ThresholdIntensity -> 0.1, Optica`Optica`ReportedSurfaces -> 
     All, Optica`Optica`ColorView -> Log[Optica`Optica`Intensity], 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`RunningCommentary -> 
     Optica`Optica`TurboTrace, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`PlotType -> 
     Optica`Optica`TopView, Optica`Optica`ThresholdIntensity -> 0.1, 
     Optica`Optica`ReportedSurfaces -> All, Optica`Optica`ColorView -> 
     Log[Optica`Optica`Intensity], 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`RunningCommentary -> 
     Optica`Optica`TurboTrace, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278838692713`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278839383583`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883940633*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.01812899999999999928190774767244874965`4.278973762247743", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.01812899999999999928190774767244874965`4.278973762247743, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883942791*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883944996*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883947134*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883948513*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.61472788394973*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278839512253`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883953225*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727883955326*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278839573383`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727884502479*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727884504961*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727884507275*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278845093927`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"LineOfRays", "[", 
              RowBox[{"0.5`", ",", 
               RowBox[{"IntrinsicMedium", "\[Rule]", "1.3`"}], ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "5"}]}], "]"}], ",", 
             RowBox[{"-", "4.`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}], 
       "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`LineOfRays[{
           Optica`Optica`Ray[]}, 0.5, Optica`Optica`IntrinsicMedium -> 1.3, 
          Optica`Optica`NumberOfRays -> 5, 
          Optica`Optica`SourceTransformation -> {{-4., 0, 0}, {{1., 0, 0}, {
             0, 1., 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{-4, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-4., 0, 0}, {{1., 0, 0}, {
          0, 1., 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-4, 0, 0}, {{1, 0, 
         0}, {0, 1, 0}, {0, 0, 1}}}, Optica`Optica`SourceLevel :> {1, 1}, 
       Optica`Optica`NumberOfRays :> 5, Optica`Optica`BirthPoint :> {0, 0, 0},
        Optica`Optica`CoordinateSystem :> Optica`Optica`CartesianCoordinates, 
       Optica`Optica`StartAtBirthPoint :> True, Optica`Optica`MonteCarlo :> 
       False, Optica`Optica`SourceID :> 82764, Optica`Optica`SourceFraction :> 
       1, Optica`Optica`SourceOffset :> 0, Optica`Optica`GridSpacing :> (#& ),
        Optica`Optica`PowerOutput :> 100, Optica`Optica`SymbolicValues -> {}, 
       Optica`Optica`IntrinsicMedium :> 1.3], False, False, False, 
      False, {{-4., 0, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727884512101*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278853064947`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278853083973`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278853105497`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727885566908*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727885623219*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.61472788562565*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727885627931*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727885630657*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "10"}],
  SequenceForm["maximum used clone sort position = ", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891057007*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1356", ",", "601", ",", "214", ",", "96", ",", "27", ",", "11", ",", "7",
      ",", "4", ",", "2", ",", "1"}], "}"}]}],
  SequenceForm[
  "Histogram of used sort positions: ", {1356, 601, 214, 96, 27, 11, 7, 4, 2, 
   1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891059524*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({1356, 601, 214, 96, 27, \
11, 7, 4, 2, 1}\\)\\), \\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \
\[Rule] All\\)\\)\\)\\)]\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/optx\\\", \
ButtonNote -> \\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6147278911095123`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You may wish to set CloneSortLength -> \"\>", 
   "\[InvisibleSpace]", "11"}],
  SequenceForm["You may wish to set CloneSortLength -> ", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891116206*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "5.63365000000000026858515411731787025928`6.771389775490918", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "5026",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   5.63365000000000026858515411731787025928`6.771389775490918, 
   " seconds with ", 5026, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891229021*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.61472789126847*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891270051*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891271454*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891272752*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891274062*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891275403*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.61472789127676*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891278302*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278912796593`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891281067*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891282434*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891283698*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891285079*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.6147278912863398`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727891460648*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727893995339*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727895604268*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[280]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}, {{
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}, {{
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}, {{
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}, {{
       1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}, {{
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}, {{
       1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}, {{
       1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}, {{
       1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}, {{
       1.9082683230708108`, -4.671972379741226}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}}, {{
       1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}, {{
       1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}, {{
       1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}, {{
       1.842038851964358, -4.600524765038519}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.600524765038519}, {
       1.842038851964358, -4.600524765038519}}, {{
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}, {{
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}, {{
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}, {{
       1.8257677239076813`, -4.529077150335811}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}, {
       1.8257677239076813`, -4.529077150335811}, {
       1.8257677239076813`, -4.529077150335811}}, {{
       1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}, {{
       1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}, {{
       1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}, {{
       1.842038851964358, -4.457629535633104}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.842038851964358, -4.457629535633104}, {
       1.842038851964358, -4.457629535633104}}, {{
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}, {{
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}, {{
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}, {{
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}}, {{
       2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}, {{
       2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}, {{
       2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}, {{
       2.1270094067410783`, -4.622157362144561}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.1270094067410783`, -4.622157362144561}, {
       2.1270094067410783`, -4.622157362144561}}, {{
       2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}, {{
       2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}, {{
       2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}, {{
       2.0732695213970698`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0732695213970698`, -4.671972379741226}, {
       2.0732695213970698`, -4.671972379741226}}, {{
       2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}, {{
       2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}, {{
       2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}, {{
       2.0032585079963843`, -4.693604976847268}, {
       1.9082683230708108`, -4.671972379741226}, {
       1.9082683230708108`, -4.671972379741226}, {
       2.0032585079963843`, -4.693604976847268}, {
       2.0032585079963843`, -4.693604976847268}}, {{
       1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}, {{
       1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}, {{
       1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}, {{
       1.9082683230708108`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}, {
       1.9082683230708108`, -4.3861819209303965`}, {
       1.9082683230708108`, -4.3861819209303965`}}, {{
       2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}, {{
       2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}, {{
       2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}, {{
       2.0032585079963843`, -4.364549323824355}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0032585079963843`, -4.364549323824355}, {
       2.0032585079963843`, -4.364549323824355}}, {{
       2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}, {{
       2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}, {{
       2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}, {{
       2.0732695213970698`, -4.3861819209303965`}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.0732695213970698`, -4.3861819209303965`}, {
       2.0732695213970698`, -4.3861819209303965`}}, {{
       2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}, {{
       2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}, {{
       2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}, {{
       2.1270094067410783`, -4.435996938527062}, {
       2.155770120560199, -4.529077150335811}, {
       2.155770120560199, -4.529077150335811}, {
       2.1270094067410783`, -4.435996938527062}, {
       2.1270094067410783`, -4.435996938527062}}, {{
       1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.939389508723094, -3.8456018485870693`}, {
       1.939389508723094, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145356}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}, {{
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}, {{
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}, {{
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}, {{
       1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}, {{
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}, {{
       1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}, {{
       1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}, {{
       1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}, {{
       1.939389508723094, -4.136506149331451}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}, {
       1.939389508723094, -4.136506149331451}, {
       1.939389508723094, -4.136506149331451}}, {{
       1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}, {{
       1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}, {{
       1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}, {{
       1.871974948905176, -4.063780074145355}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -4.063780074145355}, {
       1.871974948905176, -4.063780074145355}}, {{
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}, {{
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}, {{
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}, {{
       1.8554126705514997`, -3.99105399895926}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.8554126705514997`, -3.99105399895926}, {
       1.8554126705514997`, -3.99105399895926}}, {{
       1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}, {{
       1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}, {{
       1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}, {{
       1.871974948905176, -3.9183279237731647`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.871974948905176, -3.9183279237731647`}, {
       1.871974948905176, -3.9183279237731647`}}, {{
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}, {{
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}, {{
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}, {{
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}}, {{
       2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}, {{
       2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}, {{
       2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}, {{
       2.1620446745181403`, -4.08579975793957}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1620446745181403`, -4.08579975793957}, {
       2.1620446745181403`, -4.08579975793957}}, {{
       2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}, {{
       2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}, {{
       2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}, {{
       2.1073431850662825`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.1073431850662825`, -4.136506149331451}, {
       2.1073431850662825`, -4.136506149331451}}, {{
       2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}, {{
       2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}, {{
       2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}, {{
       2.0360794172607486`, -4.158525833125666}, {
       1.9393895087230941`, -4.136506149331451}, {
       1.9393895087230941`, -4.136506149331451}, {
       2.0360794172607486`, -4.158525833125666}, {
       2.0360794172607486`, -4.158525833125666}}, {{
       1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}, {{
       1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}, {{
       1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}, {{
       1.9393895087230941`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       1.9393895087230941`, -3.8456018485870693`}, {
       1.9393895087230941`, -3.8456018485870693`}}, {{
       2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}, {{
       2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}, {{
       2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}, {{
       2.0360794172607486`, -3.8235821647928545`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.0360794172607486`, -3.8235821647928545`}, {
       2.0360794172607486`, -3.8235821647928545`}}, {{
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}, {{
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}, {{
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}, {{
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1073431850662825`, -3.8456018485870693`}, {
       2.1073431850662825`, -3.8456018485870693`}}, {{
       2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}, {{
       2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}, {{
       2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}, {{
       2.1620446745181403`, -3.89630823997895}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1913200232378767`, -3.99105399895926}, {
       2.1620446745181403`, -3.89630823997895}, {
       2.1620446745181403`, -3.89630823997895}}, {{
       1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}, {{
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}, {{
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}, {{
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}, {{
       1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}, {{
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}, {{
       1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}, {{
       1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}, {{
       1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}, {{
       1.906316920389868, -3.623174589458843}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}}, {{
       1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}, {{
       1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}, {{
       1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}, {{
       1.842465362383498, -3.55429224088514}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.55429224088514}, {
       1.842465362383498, -3.55429224088514}}, {{
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}, {{
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}, {{
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}, {{
       1.8267784354069856`, -3.485409892311437}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}, {
       1.8267784354069856`, -3.485409892311437}, {
       1.8267784354069856`, -3.485409892311437}}, {{
       1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}, {{
       1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}, {{
       1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}, {{
       1.842465362383498, -3.416527543737734}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.842465362383498, -3.416527543737734}, {
       1.842465362383498, -3.416527543737734}}, {{
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}, {{
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}, {{
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}, {{
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}}, {{
       2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}, {{
       2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}, {{
       2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}, {{
       2.117204290604538, -3.5751481379030206`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.117204290604538, -3.5751481379030206`}, {
       2.117204290604538, -3.5751481379030206`}}, {{
       2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}, {{
       2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}, {{
       2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}, {{
       2.0653938903556326`, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       2.0653938903556326`, -3.623174589458843}, {
       2.0653938903556326`, -3.623174589458843}}, {{
       1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}, {{
       1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}, {{
       1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}, {{
       1.9978965631302146`, -3.6440304864767237`}, {
       1.906316920389868, -3.623174589458843}, {
       1.906316920389868, -3.623174589458843}, {
       1.9978965631302146`, -3.6440304864767237`}, {
       1.9978965631302146`, -3.6440304864767237`}}, {{
       1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}, {{
       1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}, {{
       1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}, {{
       1.906316920389868, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.906316920389868, -3.3476451951640307`}, {
       1.906316920389868, -3.3476451951640307`}}, {{
       1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}, {{
       1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}, {{
       1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}, {{
       1.9978965631302146`, -3.32678929814615}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       1.9978965631302146`, -3.32678929814615}, {
       1.9978965631302146`, -3.32678929814615}}, {{
       2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}, {{
       2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}, {{
       2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}, {{
       2.0653938903556326`, -3.3476451951640307`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.0653938903556326`, -3.3476451951640307`}, {
       2.0653938903556326`, -3.3476451951640307`}}, {{
       2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}, {{
       2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}, {{
       2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}, {{
       2.117204290604538, -3.3956716467198533`}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.1449323753385148`, -3.485409892311437}, {
       2.117204290604538, -3.3956716467198533`}, {
       2.117204290604538, -3.3956716467198533`}}, {{
       1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}, {{
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}, {{
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}, {{
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}, {{
       1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}, {{
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}, {{
       1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}, {{
       1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}, {{
       1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}, {{
       1.956467884875891, -3.127554967853727}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}}, {{
       1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}, {{
       1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}, {{
       1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}, {{
       1.88927299362198, -3.0550658686642884`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -3.0550658686642884`}, {
       1.88927299362198, -3.0550658686642884`}}, {{
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}, {{
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}, {{
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}, {{
       1.872764683015219, -2.9825767694748495`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.872764683015219, -2.9825767694748495`}, {
       1.872764683015219, -2.9825767694748495`}}, {{
       1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}, {{
       1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}, {{
       1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}, {{
       1.88927299362198, -2.9100876702854106`}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}, {
       1.88927299362198, -2.9100876702854106`}, {
       1.88927299362198, -2.9100876702854106`}}, {{
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}, {{
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}, {{
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}, {{
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}}, {{
       2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}, {{
       2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}, {{
       2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}, {{
       2.178397534689358, -3.077013801899988}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}, {
       2.178397534689358, -3.077013801899988}, {
       2.178397534689358, -3.077013801899988}}, {{
       2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}, {{
       2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}, {{
       2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}, {{
       2.123874288597235, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}, {
       2.123874288597235, -3.127554967853727}, {
       2.123874288597235, -3.127554967853727}}, {{
       2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}, {{
       2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}, {{
       2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}, {{
       2.05284273189835, -3.149502901089427}, {
       1.956467884875891, -3.127554967853727}, {
       1.956467884875891, -3.127554967853727}, {
       2.05284273189835, -3.149502901089427}, {
       2.05284273189835, -3.149502901089427}}, {{
       1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}, {{
       1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}, {{
       1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}, {{
       1.956467884875891, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}, {
       1.956467884875891, -2.837598571095972}, {
       1.956467884875891, -2.837598571095972}}, {{
       2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}, {{
       2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}, {{
       2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}, {{
       2.05284273189835, -2.815650637860272}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}, {
       2.05284273189835, -2.815650637860272}, {
       2.05284273189835, -2.815650637860272}}, {{
       2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}, {{
       2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}, {{
       2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}, {{
       2.123874288597235, -2.837598571095972}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}, {
       2.123874288597235, -2.837598571095972}, {
       2.123874288597235, -2.837598571095972}}, {{
       2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}, {{
       2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}, {{
       2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}, {{
       2.178397534689358, -2.888139737049711}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.2075774904579064`, -2.9825767694748495`}, {
       2.178397534689358, -2.888139737049711}, {
       2.178397534689358, -2.888139737049711}}, {{
       1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}, {{
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}, {{
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}, {{
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}, {{
       1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}, {{
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}, {{
       1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}, {{
       1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}, {{
       1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}, {{
       1.9258842705196906`, -2.6292283127944702`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}}, {{
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}, {{
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}, {{
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}, {{
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.5562453286449105`}, {
       1.8582315649659973`, -2.5562453286449105`}}, {{
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}, {{
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}, {{
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}, {{
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8416107794296694`, -2.4832623444953508`}, {
       1.8416107794296694`, -2.4832623444953508`}}, {{
       1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}, {{
       1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}, {{
       1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}, {{
       1.8582315649659973`, -2.410279360345791}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.8582315649659973`, -2.410279360345791}, {
       1.8582315649659973`, -2.410279360345791}}, {{
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}, {{
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}, {{
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}, {{
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}}, {{
       2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}, {{
       2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}, {{
       2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}, {{
       2.1493259782490846`, -2.5783427982143774`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.1493259782490846`, -2.5783427982143774`}, {
       2.1493259782490846`, -2.5783427982143774`}}, {{
       2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}, {{
       2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}, {{
       2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}, {{
       2.094431252699733, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.094431252699733, -2.6292283127944702`}, {
       2.094431252699733, -2.6292283127944702`}}, {{
       2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}, {{
       2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}, {{
       2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}, {{
       2.022915741614053, -2.6513257823639376`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       1.9258842705196906`, -2.6292283127944702`}, {
       2.022915741614053, -2.6513257823639376`}, {
       2.022915741614053, -2.6513257823639376`}}, {{
       1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}, {{
       1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}, {{
       1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}, {{
       1.9258842705196906`, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}, {
       1.9258842705196906`, -2.3372963761962313`}, {
       1.9258842705196906`, -2.3372963761962313`}}, {{
       2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}, {{
       2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}, {{
       2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}, {{
       2.022915741614053, -2.315198906626764}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.022915741614053, -2.315198906626764}, {
       2.022915741614053, -2.315198906626764}}, {{
       2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}, {{
       2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}, {{
       2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}, {{
       2.094431252699733, -2.3372963761962313`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.094431252699733, -2.3372963761962313`}, {
       2.094431252699733, -2.3372963761962313`}}, {{
       2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}, {{
       2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}, {{
       2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}, {{
       2.1493259782490846`, -2.388181890776324}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.178704743789754, -2.4832623444953508`}, {
       2.1493259782490846`, -2.388181890776324}, {
       2.1493259782490846`, -2.388181890776324}}, {{
       1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.0236927843385946`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}, {{
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}, {{
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}, {{
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}, {{
       1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}, {{
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}, {{
       1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}, {{
       1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}, {{
       1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}, {{
       1.9409791054711163`, -2.0973841956308057`}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}}, {{
       1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}, {{
       1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}, {{
       1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}, {{
       1.8726697124244887`, -2.023692784338594}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -2.023692784338594}, {
       1.8726697124244887`, -2.023692784338594}}, {{
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}, {{
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}, {{
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}, {{
       1.8558875931780732`, -1.950001373046383}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8558875931780732`, -1.950001373046383}, {
       1.8558875931780732`, -1.950001373046383}}, {{
       1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}, {{
       1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}, {{
       1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}, {{
       1.8726697124244887`, -1.8763099617541716`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.8726697124244887`, -1.8763099617541716`}, {
       1.8726697124244887`, -1.8763099617541716`}}, {{
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}, {{
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}, {{
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}, {{
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}}, {{
       2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}, {{
       2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}, {{
       2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}, {{
       2.1665897046537776`, -2.0460047483879644`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.1665897046537776`, -2.0460047483879644`}, {
       2.1665897046537776`, -2.0460047483879644`}}, {{
       2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}, {{
       2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}, {{
       2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}, {{
       2.111162130057203, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.111162130057203, -2.0973841956308057`}, {
       2.111162130057203, -2.0973841956308057`}}, {{
       2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}, {{
       2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}, {{
       2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}, {{
       2.038952436214213, -2.1196961596801756`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       1.9409791054711163`, -2.0973841956308057`}, {
       2.038952436214213, -2.1196961596801756`}, {
       2.038952436214213, -2.1196961596801756`}}, {{
       1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}, {{
       1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}, {{
       1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}, {{
       1.9409791054711163`, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}, {
       1.9409791054711163`, -1.8026185504619603`}, {
       1.9409791054711163`, -1.8026185504619603`}}, {{
       2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}, {{
       2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}, {{
       2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}, {{
       2.038952436214213, -1.7803065864125904`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.038952436214213, -1.7803065864125904`}, {
       2.038952436214213, -1.7803065864125904`}}, {{
       2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}, {{
       2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}, {{
       2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}, {{
       2.111162130057203, -1.8026185504619603`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.111162130057203, -1.8026185504619603`}, {
       2.111162130057203, -1.8026185504619603`}}, {{
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}, {{
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}, {{
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}, {{
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1962536423502463`, -1.950001373046383}, {
       2.1665897046537776`, -1.8539979977048018`}, {
       2.1665897046537776`, -1.8539979977048018`}}, {{
       1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}, {{
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}, {{
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}, {{
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}, {{
       1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}, {{
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}, {{
       1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}, {{
       1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}, {{
       1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}, {{
       1.9121957020737574`, -1.6251660034221425`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}}, {{
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}, {{
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}, {{
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}, {{
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.5565842168531903`}, {
       1.8486227546647065`, -1.5565842168531903`}}, {{
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}, {{
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}, {{
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}, {{
       1.8330042761995773`, -1.488002430284238}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8330042761995773`, -1.488002430284238}, {
       1.8330042761995773`, -1.488002430284238}}, {{
       1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}, {{
       1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}, {{
       1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}, {{
       1.8486227546647065`, -1.4194206437152859`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.8486227546647065`, -1.4194206437152859`}, {
       1.8486227546647065`, -1.4194206437152859`}}, {{
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}, {{
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}, {{
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}, {{
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}}, {{
       2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}, {{
       2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}, {{
       2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}, {{
       2.1221628839951876`, -1.5773491110184044`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.1221628839951876`, -1.5773491110184044`}, {
       2.1221628839951876`, -1.5773491110184044`}}, {{
       2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}, {{
       2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}, {{
       2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}, {{
       2.0705785538221173`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.0705785538221173`, -1.6251660034221425`}, {
       2.0705785538221173`, -1.6251660034221425`}}, {{
       2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}, {{
       2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}, {{
       2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}, {{
       2.003375745183918, -1.6459308975873566`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       1.9121957020737574`, -1.6251660034221425`}, {
       2.003375745183918, -1.6459308975873566`}, {
       2.003375745183918, -1.6459308975873566`}}, {{
       1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}, {{
       1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}, {{
       1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}, {{
       1.9121957020737574`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}, {
       1.9121957020737574`, -1.3508388571463337`}, {
       1.9121957020737574`, -1.3508388571463337`}}, {{
       2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}, {{
       2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}, {{
       2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}, {{
       2.003375745183918, -1.3300739629811196`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.003375745183918, -1.3300739629811196`}, {
       2.003375745183918, -1.3300739629811196`}}, {{
       2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}, {{
       2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}, {{
       2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}, {{
       2.0705785538221173`, -1.3508388571463337`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.0705785538221173`, -1.3508388571463337`}, {
       2.0705785538221173`, -1.3508388571463337`}}, {{
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}, {{
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}, {{
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}, {{
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1497699796962975`, -1.488002430284238}, {
       2.1221628839951876`, -1.3986557495500718`}, {
       2.1221628839951876`, -1.3986557495500718`}}, {{
       1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845168}, {
       1.8688159381993599`, -0.8505848171753346}, {
       1.8688159381993599`, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}, {{
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}, {{
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.86881593819936, -1.1832181088120635`}, {
       1.86881593819936, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}, {{
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}, {{
       1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}, {{
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}, {{
       1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}, {{
       1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}, {{
       1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}, {{
       1.8688159381993599`, -1.1832181088120635`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}}, {{
       1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}, {{
       1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}, {{
       1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}, {{
       1.791731045060638, -1.1000597859028811`}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -1.1000597859028811`}, {
       1.791731045060638, -1.1000597859028811`}}, {{
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}, {{
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}, {{
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}, {{
       1.7727929779654117`, -1.016901462993699}, {
       1.791731045060638, -0.9337431400845169}, {
       1.791731045060638, -0.9337431400845169}, {
       1.7727929779654117`, -1.016901462993699}, {
       1.7727929779654117`, -1.016901462993699}}, {{
       1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}, {{
       1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}, {{
       1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}, {{
       1.791731045060638, -0.9337431400845168}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}, {
       1.791731045060638, -0.9337431400845168}, {
       1.791731045060638, -0.9337431400845168}}, {{
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}, {{
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}, {{
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}, {{
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}}, {{
       2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}, {{
       2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}, {{
       2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}, {{
       2.1234100452951044`, -1.1252381001544318`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.1234100452951044`, -1.1252381001544318`}, {
       2.1234100452951044`, -1.1252381001544318`}}, {{
       2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}, {{
       2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}, {{
       2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}, {{
       2.0608618586672565`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       2.0608618586672565`, -1.1832181088120635`}, {
       2.0608618586672565`, -1.1832181088120635`}}, {{
       1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}, {{
       1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}, {{
       1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}, {{
       1.9793756049441822`, -1.2083964230636142`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.8688159381993599`, -1.1832181088120635`}, {
       1.9793756049441822`, -1.2083964230636142`}, {
       1.9793756049441822`, -1.2083964230636142`}}, {{
       1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}, {{
       1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}, {{
       1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}, {{
       1.86881593819936, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.86881593819936, -0.8505848171753346}, {
       1.86881593819936, -0.8505848171753346}}, {{
       1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}, {{
       1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}, {{
       1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}, {{
       1.9793756049441822`, -0.8254065029237838}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}, {
       1.9793756049441822`, -0.8254065029237838}, {
       1.9793756049441822`, -0.8254065029237838}}, {{
       2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}, {{
       2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}, {{
       2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}, {{
       2.0608618586672565`, -0.8505848171753346}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.0608618586672565`, -0.8505848171753346}, {
       2.0608618586672565`, -0.8505848171753346}}, {{
       2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}, {{
       2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}, {{
       2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}, {{
       2.1234100452951044`, -0.908564825832966}, {
       2.156884818901205, -1.016901462993699}, {
       2.156884818901205, -1.016901462993699}, {
       2.1234100452951044`, -0.908564825832966}, {
       2.1234100452951044`, -0.908564825832966}}, {{
       1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667408}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}, {{
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}, {{
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}, {{
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}, {{
       1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}, {{
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}, {{
       1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}, {{
       1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}, {{
       1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}, {{
       1.921707610118562, -0.5884199870898144}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}}, {{
       1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}, {{
       1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}, {{
       1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}, {{
       1.8579621567971443`, -0.5196521030667407}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.5196521030667407}, {
       1.8579621567971443`, -0.5196521030667407}}, {{
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}, {{
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}, {{
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}, {{
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8423012974139168`, -0.45088421904366716`}, {
       1.8423012974139168`, -0.45088421904366716`}}, {{
       1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}, {{
       1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}, {{
       1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}, {{
       1.8579621567971443`, -0.38211633502059356`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.8579621567971443`, -0.38211633502059356`}, {
       1.8579621567971443`, -0.38211633502059356`}}, {{
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}, {{
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}, {{
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}, {{
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}}, {{
       2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}, {{
       2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}, {{
       2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}, {{
       2.132244540364722, -0.5404733430073067}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}, {
       2.132244540364722, -0.5404733430073067}, {
       2.132244540364722, -0.5404733430073067}}, {{
       2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}, {{
       2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}, {{
       2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}, {{
       2.080520235527852, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.080520235527852, -0.5884199870898144}, {
       2.080520235527852, -0.5884199870898144}}, {{
       2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}, {{
       2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}, {{
       2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}, {{
       2.0131350713077545`, -0.6092412270303803}, {
       1.921707610118562, -0.5884199870898144}, {
       1.921707610118562, -0.5884199870898144}, {
       2.0131350713077545`, -0.6092412270303803}, {
       2.0131350713077545`, -0.6092412270303803}}, {{
       1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}, {{
       1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}, {{
       1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}, {{
       1.921707610118562, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}, {
       1.921707610118562, -0.31334845099751996`}, {
       1.921707610118562, -0.31334845099751996`}}, {{
       2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}, {{
       2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}, {{
       2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}, {{
       2.0131350713077545`, -0.292527211056954}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.0131350713077545`, -0.292527211056954}, {
       2.0131350713077545`, -0.292527211056954}}, {{
       2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}, {{
       2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}, {{
       2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}, {{
       2.080520235527852, -0.31334845099751996`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}, {
       2.080520235527852, -0.31334845099751996`}, {
       2.080520235527852, -0.31334845099751996`}}, {{
       2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}, {{
       2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}, {{
       2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}, {{
       2.132244540364722, -0.3612950950800276}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.1599265482324967`, -0.45088421904366716`}, {
       2.132244540364722, -0.3612950950800276}, {
       2.132244540364722, -0.3612950950800276}}, {{
       1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {1.7845464039473522`, 
       0.0620762328448697}, {1.8620391706844055`, 0.1456745652424888}, {
       1.8620391706844055`, 0.1456745652424888}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036867`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}, {{
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}, {{
       2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844057`, -0.18871876434798784`}, {
       1.8620391706844057`, -0.18871876434798784`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}, {{
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}, {{1.8620391706844057`, 
       0.14567456524248884`}, {1.973183833623286, 0.17098610364750924`}, {
       2.0551012495386827`, 0.1456745652424888}, {2.117980392763994, 
       0.08738777124989006}, {2.1516322889658213`, -0.02152209955274947}, {
       2.1516322889658213`, -0.02152209955274947}, {2.117980392763994, 
       0.08738777124989006}, {2.0551012495386827`, 0.1456745652424888}, {
       1.973183833623286, 0.17098610364750924`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.8620391706844057`, 0.14567456524248884`}}, {{
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}}, {{1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}, {{
       1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}, {{
       1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}, {{
       1.8620391706844055`, -0.18871876434798782`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}}, {{
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}, {{
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}, {{
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}, {{
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7845464039473522`, -0.10512043195036865`}, {
       1.7845464039473522`, -0.10512043195036865`}}, {{
       1.7655081312572671`, -0.02152209955274949}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7845464039473522`, 0.06207623284486967}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}, {{
       1.7655081312572671`, -0.02152209955274949}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7845464039473522`, 0.06207623284486967}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}, {{
       1.7655081312572671`, -0.02152209955274949}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7845464039473522`, 0.06207623284486967}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}, {{
       1.7655081312572671`, -0.02152209955274949}, {1.7845464039473522`, 
       0.06207623284486967}, {1.7845464039473522`, 0.06207623284486967}, {
       1.7655081312572671`, -0.02152209955274949}, {
       1.7655081312572671`, -0.02152209955274949}}, {{1.7845464039473522`, 
       0.0620762328448697}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.7845464039473522`, 
       0.0620762328448697}, {1.7845464039473522`, 0.0620762328448697}}, {{
       1.7845464039473522`, 0.0620762328448697}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.7845464039473522`, 0.0620762328448697}, {1.7845464039473522`, 
       0.0620762328448697}}, {{1.7845464039473522`, 0.0620762328448697}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.7845464039473522`, 0.0620762328448697}, {
       1.7845464039473522`, 0.0620762328448697}}, {{1.7845464039473522`, 
       0.0620762328448697}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.7845464039473522`, 
       0.0620762328448697}, {1.7845464039473522`, 0.0620762328448697}}, {{
       2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}, {{
       2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}, {{
       2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}, {{
       2.1516322889658213`, -0.021522099552749512`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.1516322889658213`, -0.021522099552749512`}, {
       2.1516322889658213`, -0.021522099552749512`}}, {{
       2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}, {{
       2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}, {{
       2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}, {{
       2.117980392763994, -0.13043197035538903`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.117980392763994, -0.13043197035538903`}, {
       2.117980392763994, -0.13043197035538903`}}, {{
       2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}, {{
       2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}, {{
       2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}, {{
       2.0551012495386827`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}, {
       2.0551012495386827`, -0.18871876434798782`}, {
       2.0551012495386827`, -0.18871876434798782`}}, {{
       1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}, {{
       1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}, {{
       1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}, {{
       1.973183833623286, -0.21403030275300824`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.8620391706844055`, -0.18871876434798782`}, {
       1.973183833623286, -0.21403030275300824`}, {
       1.973183833623286, -0.21403030275300824`}}, {{1.8620391706844057`, 
       0.14567456524248884`}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.8620391706844057`, 0.14567456524248884`}}, {{
       1.8620391706844057`, 0.14567456524248884`}, {1.973183833623286, 
       0.17098610364750924`}, {1.973183833623286, 0.17098610364750924`}, {
       1.8620391706844057`, 0.14567456524248884`}, {1.8620391706844057`, 
       0.14567456524248884`}}, {{1.8620391706844057`, 0.14567456524248884`}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}, {1.8620391706844057`, 0.14567456524248884`}, {
       1.8620391706844057`, 0.14567456524248884`}}, {{1.8620391706844057`, 
       0.14567456524248884`}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}, {1.8620391706844057`, 
       0.14567456524248884`}, {1.8620391706844057`, 0.14567456524248884`}}, {{
       1.973183833623286, 0.17098610364750924`}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}}, {{1.973183833623286, 0.17098610364750924`}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}, {1.973183833623286, 0.17098610364750924`}, {
       1.973183833623286, 0.17098610364750924`}}, {{1.973183833623286, 
       0.17098610364750924`}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}, {1.973183833623286, 
       0.17098610364750924`}, {1.973183833623286, 0.17098610364750924`}}, {{
       1.973183833623286, 0.17098610364750924`}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}, {
       1.973183833623286, 0.17098610364750924`}, {1.973183833623286, 
       0.17098610364750924`}}, {{2.0551012495386827`, 0.1456745652424888}, {
       2.117980392763994, 0.08738777124989006}, {2.117980392763994, 
       0.08738777124989006}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}}, {{2.0551012495386827`, 
       0.1456745652424888}, {2.117980392763994, 0.08738777124989006}, {
       2.117980392763994, 0.08738777124989006}, {2.0551012495386827`, 
       0.1456745652424888}, {2.0551012495386827`, 0.1456745652424888}}, {{
       2.0551012495386827`, 0.1456745652424888}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}, {
       2.0551012495386827`, 0.1456745652424888}, {2.0551012495386827`, 
       0.1456745652424888}}, {{2.0551012495386827`, 0.1456745652424888}, {
       2.117980392763994, 0.08738777124989006}, {2.117980392763994, 
       0.08738777124989006}, {2.0551012495386827`, 0.1456745652424888}, {
       2.0551012495386827`, 0.1456745652424888}}, {{2.117980392763994, 
       0.08738777124989006}, {2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}, {{
       2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}, {{
       2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}, {{
       2.117980392763994, 0.08738777124989006}, {
       2.1516322889658213`, -0.021522099552749523`}, {
       2.1516322889658213`, -0.021522099552749523`}, {2.117980392763994, 
       0.08738777124989006}, {2.117980392763994, 0.08738777124989006}}, {{
       1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.922378633863552, 
       0.4576864744029721}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}, {{1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}}, {{2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.0518578650457386`, 
       0.3376636991690015}, {1.98256268345552, 0.35344464270443887`}, {
       1.98256268345552, 0.35344464270443887`}, {2.0518578650457386`, 
       0.3376636991690015}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1631148322314235`, 0.4576864744029721}}, {{
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}}, {{1.98256268345552, 0.5619283061015053}, {
       2.0518578650457386`, 0.5777092496369427}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1029307826394557`, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {1.98256268345552, 0.5619283061015053}, {
       1.98256268345552, 0.5619283061015053}}, {{2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}}, {{
       1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}, {{1.98256268345552, 0.35344464270443887`}, {
       1.934248394663034, 0.40556555855370546`}, {1.934248394663034, 
       0.40556555855370546`}, {1.98256268345552, 0.35344464270443887`}, {
       1.98256268345552, 0.35344464270443887`}}, {{1.98256268345552, 
       0.35344464270443887`}, {1.934248394663034, 0.40556555855370546`}, {
       1.934248394663034, 0.40556555855370546`}, {1.98256268345552, 
       0.35344464270443887`}, {1.98256268345552, 0.35344464270443887`}}, {{
       1.98256268345552, 0.35344464270443887`}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}}, {{1.934248394663034, 0.40556555855370546`}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.934248394663034, 0.40556555855370546`}, {
       1.934248394663034, 0.40556555855370546`}}, {{1.934248394663034, 
       0.40556555855370546`}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}, {1.934248394663034, 
       0.40556555855370546`}, {1.934248394663034, 0.40556555855370546`}}, {{
       1.934248394663034, 0.40556555855370546`}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.40556555855370546`}, {1.934248394663034, 
       0.40556555855370546`}}, {{1.934248394663034, 0.40556555855370546`}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}, {1.934248394663034, 0.40556555855370546`}, {
       1.934248394663034, 0.40556555855370546`}}, {{1.922378633863552, 
       0.4576864744029721}, {1.934248394663034, 0.5098073902522388}, {
       1.934248394663034, 0.5098073902522388}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}}, {{
       1.922378633863552, 0.4576864744029721}, {1.934248394663034, 
       0.5098073902522388}, {1.934248394663034, 0.5098073902522388}, {
       1.922378633863552, 0.4576864744029721}, {1.922378633863552, 
       0.4576864744029721}}, {{1.922378633863552, 0.4576864744029721}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}, {1.922378633863552, 0.4576864744029721}, {
       1.922378633863552, 0.4576864744029721}}, {{1.922378633863552, 
       0.4576864744029721}, {1.934248394663034, 0.5098073902522388}, {
       1.934248394663034, 0.5098073902522388}, {1.922378633863552, 
       0.4576864744029721}, {1.922378633863552, 0.4576864744029721}}, {{
       1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}}, {{1.934248394663034, 0.5098073902522388}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}, {1.934248394663034, 0.5098073902522388}, {
       1.934248394663034, 0.5098073902522388}}, {{1.934248394663034, 
       0.5098073902522388}, {1.98256268345552, 0.5619283061015053}, {
       1.98256268345552, 0.5619283061015053}, {1.934248394663034, 
       0.5098073902522388}, {1.934248394663034, 0.5098073902522388}}, {{
       1.934248394663034, 0.5098073902522388}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}, {
       1.934248394663034, 0.5098073902522388}, {1.934248394663034, 
       0.5098073902522388}}, {{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}, {{2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1631148322314235`, 0.4576864744029721}}, {{
       2.1631148322314235`, 0.4576864744029721}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}}, {{2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}}, {{2.1421339394336907`, 
       0.38978461501826817`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1421339394336907`, 0.38978461501826817`}}, {{
       2.1421339394336907`, 0.38978461501826817`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1421339394336907`, 0.38978461501826817`}, {2.1421339394336907`, 
       0.38978461501826817`}}, {{2.1421339394336907`, 0.38978461501826817`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1421339394336907`, 0.38978461501826817`}, {
       2.1421339394336907`, 0.38978461501826817`}}, {{2.1421339394336907`, 
       0.38978461501826817`}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1421339394336907`, 
       0.38978461501826817`}, {2.1421339394336907`, 0.38978461501826817`}}, {{
       2.1029307826394557`, 0.35344464270443887`}, {2.0518578650457386`, 
       0.3376636991690015}, {2.0518578650457386`, 0.3376636991690015}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}}, {{2.1029307826394557`, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}, {2.1029307826394557`, 0.35344464270443887`}, {
       2.1029307826394557`, 0.35344464270443887`}}, {{2.1029307826394557`, 
       0.35344464270443887`}, {2.0518578650457386`, 0.3376636991690015}, {
       2.0518578650457386`, 0.3376636991690015}, {2.1029307826394557`, 
       0.35344464270443887`}, {2.1029307826394557`, 0.35344464270443887`}}, {{
       2.1029307826394557`, 0.35344464270443887`}, {2.0518578650457386`, 
       0.3376636991690015}, {2.0518578650457386`, 0.3376636991690015}, {
       2.1029307826394557`, 0.35344464270443887`}, {2.1029307826394557`, 
       0.35344464270443887`}}, {{2.0518578650457386`, 0.3376636991690015}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}, {2.0518578650457386`, 0.3376636991690015}, {
       2.0518578650457386`, 0.3376636991690015}}, {{2.0518578650457386`, 
       0.3376636991690015}, {1.98256268345552, 0.35344464270443887`}, {
       1.98256268345552, 0.35344464270443887`}, {2.0518578650457386`, 
       0.3376636991690015}, {2.0518578650457386`, 0.3376636991690015}}, {{
       2.0518578650457386`, 0.3376636991690015}, {1.98256268345552, 
       0.35344464270443887`}, {1.98256268345552, 0.35344464270443887`}, {
       2.0518578650457386`, 0.3376636991690015}, {2.0518578650457386`, 
       0.3376636991690015}}, {{2.0518578650457386`, 0.3376636991690015}, {
       1.98256268345552, 0.35344464270443887`}, {1.98256268345552, 
       0.35344464270443887`}, {2.0518578650457386`, 0.3376636991690015}, {
       2.0518578650457386`, 0.3376636991690015}}, {{1.98256268345552, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}}, {{
       1.98256268345552, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.0518578650457386`, 0.5777092496369427}, {
       1.98256268345552, 0.5619283061015053}, {1.98256268345552, 
       0.5619283061015053}}, {{1.98256268345552, 0.5619283061015053}, {
       2.0518578650457386`, 0.5777092496369427}, {2.0518578650457386`, 
       0.5777092496369427}, {1.98256268345552, 0.5619283061015053}, {
       1.98256268345552, 0.5619283061015053}}, {{1.98256268345552, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}, {1.98256268345552, 
       0.5619283061015053}, {1.98256268345552, 0.5619283061015053}}, {{
       2.0518578650457386`, 0.5777092496369427}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.0518578650457386`, 0.5777092496369427}, {2.0518578650457386`, 
       0.5777092496369427}}, {{2.0518578650457386`, 0.5777092496369427}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}, {2.0518578650457386`, 0.5777092496369427}, {
       2.0518578650457386`, 0.5777092496369427}}, {{2.0518578650457386`, 
       0.5777092496369427}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}, {2.0518578650457386`, 
       0.5777092496369427}, {2.0518578650457386`, 0.5777092496369427}}, {{
       2.0518578650457386`, 0.5777092496369427}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}, {
       2.0518578650457386`, 0.5777092496369427}, {2.0518578650457386`, 
       0.5777092496369427}}, {{2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}, {{2.1029307826394557`, 
       0.5619283061015053}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1029307826394557`, 
       0.5619283061015053}, {2.1029307826394557`, 0.5619283061015053}}, {{
       2.1029307826394557`, 0.5619283061015053}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1029307826394557`, 0.5619283061015053}, {2.1029307826394557`, 
       0.5619283061015053}}, {{2.1029307826394557`, 0.5619283061015053}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1029307826394557`, 0.5619283061015053}, {
       2.1029307826394557`, 0.5619283061015053}}, {{2.1421339394336907`, 
       0.5255883337876761}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1421339394336907`, 0.5255883337876761}}, {{
       2.1421339394336907`, 0.5255883337876761}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1421339394336907`, 0.5255883337876761}, {2.1421339394336907`, 
       0.5255883337876761}}, {{2.1421339394336907`, 0.5255883337876761}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1631148322314235`, 
       0.4576864744029721}, {2.1421339394336907`, 0.5255883337876761}, {
       2.1421339394336907`, 0.5255883337876761}}, {{2.1421339394336907`, 
       0.5255883337876761}, {2.1631148322314235`, 0.4576864744029721}, {
       2.1631148322314235`, 0.4576864744029721}, {2.1421339394336907`, 
       0.5255883337876761}, {2.1421339394336907`, 0.5255883337876761}}, {{
       1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.839375011674674, 0.927711313596769}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}, {{1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}}, {{2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 0.9055703260666121}, {
       2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {1.9071609500300508`, 0.8545845993868387}, {
       1.9071609500300508`, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.076039862566275, 0.8545845993868387}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1604793188343874`, 1.0008380278066993`}}, {{
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}, {{1.9071609500300508`, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.076039862566275, 1.1470914562265597`}, {2.004383511408823, 
       1.1692324437567168`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.9071609500300508`, 1.1470914562265597`}}, {{2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}}, {{
       1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}, {{1.9071609500300508`, 0.8545845993868387}, {
       1.839375011674674, 0.9277113135967691}, {1.839375011674674, 
       0.9277113135967691}, {1.9071609500300508`, 0.8545845993868387}, {
       1.9071609500300508`, 0.8545845993868387}}, {{1.9071609500300508`, 
       0.8545845993868387}, {1.839375011674674, 0.9277113135967691}, {
       1.839375011674674, 0.9277113135967691}, {1.9071609500300508`, 
       0.8545845993868387}, {1.9071609500300508`, 0.8545845993868387}}, {{
       1.9071609500300508`, 0.8545845993868387}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}}, {{1.839375011674674, 0.9277113135967691}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.839375011674674, 0.9277113135967691}, {
       1.839375011674674, 0.9277113135967691}}, {{1.839375011674674, 
       0.9277113135967691}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.839375011674674, 
       0.9277113135967691}, {1.839375011674674, 0.9277113135967691}}, {{
       1.839375011674674, 0.9277113135967691}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 0.9277113135967691}, {1.839375011674674, 
       0.9277113135967691}}, {{1.839375011674674, 0.9277113135967691}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.839375011674674, 0.9277113135967691}, {
       1.839375011674674, 0.9277113135967691}}, {{1.8227214937619387`, 
       1.0008380278066993`}, {1.839375011674674, 1.0739647420166296`}, {
       1.839375011674674, 1.0739647420166296`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}}, {{
       1.8227214937619387`, 1.0008380278066993`}, {1.839375011674674, 
       1.0739647420166296`}, {1.839375011674674, 1.0739647420166296`}, {
       1.8227214937619387`, 1.0008380278066993`}, {1.8227214937619387`, 
       1.0008380278066993`}}, {{1.8227214937619387`, 1.0008380278066993`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}, {1.8227214937619387`, 1.0008380278066993`}, {
       1.8227214937619387`, 1.0008380278066993`}}, {{1.8227214937619387`, 
       1.0008380278066993`}, {1.839375011674674, 1.0739647420166296`}, {
       1.839375011674674, 1.0739647420166296`}, {1.8227214937619387`, 
       1.0008380278066993`}, {1.8227214937619387`, 1.0008380278066993`}}, {{
       1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}}, {{1.839375011674674, 1.0739647420166296`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.839375011674674, 1.0739647420166296`}, {
       1.839375011674674, 1.0739647420166296`}}, {{1.839375011674674, 
       1.0739647420166296`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.839375011674674, 
       1.0739647420166296`}, {1.839375011674674, 1.0739647420166296`}}, {{
       1.839375011674674, 1.0739647420166296`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.839375011674674, 1.0739647420166296`}, {1.839375011674674, 
       1.0739647420166296`}}, {{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}, {{2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 0.9055703260666121}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1604793188343874`, 1.0008380278066993`}}, {{
       2.1604793188343874`, 1.0008380278066993`}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1310426958109914`, 0.9055703260666121}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}}, {{2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}}, {{2.1310426958109914`, 
       0.9055703260666121}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1310426958109914`, 0.9055703260666121}}, {{
       2.1310426958109914`, 0.9055703260666121}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}, {
       2.1310426958109914`, 0.9055703260666121}, {2.1310426958109914`, 
       0.9055703260666121}}, {{2.1310426958109914`, 0.9055703260666121}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}, {2.1310426958109914`, 0.9055703260666121}, {
       2.1310426958109914`, 0.9055703260666121}}, {{2.1310426958109914`, 
       0.9055703260666121}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}, {2.1310426958109914`, 
       0.9055703260666121}, {2.1310426958109914`, 0.9055703260666121}}, {{
       2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}, {{2.076039862566275, 0.8545845993868387}, {
       2.004383511408823, 0.8324436118566818}, {2.004383511408823, 
       0.8324436118566818}, {2.076039862566275, 0.8545845993868387}, {
       2.076039862566275, 0.8545845993868387}}, {{2.076039862566275, 
       0.8545845993868387}, {2.004383511408823, 0.8324436118566818}, {
       2.004383511408823, 0.8324436118566818}, {2.076039862566275, 
       0.8545845993868387}, {2.076039862566275, 0.8545845993868387}}, {{
       2.076039862566275, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}, {
       2.076039862566275, 0.8545845993868387}, {2.076039862566275, 
       0.8545845993868387}}, {{2.004383511408823, 0.8324436118566818}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}, {2.004383511408823, 0.8324436118566818}, {
       2.004383511408823, 0.8324436118566818}}, {{2.004383511408823, 
       0.8324436118566818}, {1.9071609500300508`, 0.8545845993868387}, {
       1.9071609500300508`, 0.8545845993868387}, {2.004383511408823, 
       0.8324436118566818}, {2.004383511408823, 0.8324436118566818}}, {{
       2.004383511408823, 0.8324436118566818}, {1.9071609500300508`, 
       0.8545845993868387}, {1.9071609500300508`, 0.8545845993868387}, {
       2.004383511408823, 0.8324436118566818}, {2.004383511408823, 
       0.8324436118566818}}, {{2.004383511408823, 0.8324436118566818}, {
       1.9071609500300508`, 0.8545845993868387}, {1.9071609500300508`, 
       0.8545845993868387}, {2.004383511408823, 0.8324436118566818}, {
       2.004383511408823, 0.8324436118566818}}, {{1.9071609500300508`, 
       1.1470914562265597`}, {2.004383511408823, 1.1692324437567168`}, {
       2.004383511408823, 1.1692324437567168`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}}, {{
       1.9071609500300508`, 1.1470914562265597`}, {2.004383511408823, 
       1.1692324437567168`}, {2.004383511408823, 1.1692324437567168`}, {
       1.9071609500300508`, 1.1470914562265597`}, {1.9071609500300508`, 
       1.1470914562265597`}}, {{1.9071609500300508`, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}, {1.9071609500300508`, 1.1470914562265597`}, {
       1.9071609500300508`, 1.1470914562265597`}}, {{1.9071609500300508`, 
       1.1470914562265597`}, {2.004383511408823, 1.1692324437567168`}, {
       2.004383511408823, 1.1692324437567168`}, {1.9071609500300508`, 
       1.1470914562265597`}, {1.9071609500300508`, 1.1470914562265597`}}, {{
       2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}}, {{2.004383511408823, 1.1692324437567168`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}, {2.004383511408823, 1.1692324437567168`}, {
       2.004383511408823, 1.1692324437567168`}}, {{2.004383511408823, 
       1.1692324437567168`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}, {2.004383511408823, 
       1.1692324437567168`}, {2.004383511408823, 1.1692324437567168`}}, {{
       2.004383511408823, 1.1692324437567168`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}, {
       2.004383511408823, 1.1692324437567168`}, {2.004383511408823, 
       1.1692324437567168`}}, {{2.076039862566275, 1.1470914562265597`}, {
       2.1310426958109914`, 1.0961057295467864`}, {2.1310426958109914`, 
       1.0961057295467864`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}}, {{2.076039862566275, 
       1.1470914562265597`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1310426958109914`, 1.0961057295467864`}, {2.076039862566275, 
       1.1470914562265597`}, {2.076039862566275, 1.1470914562265597`}}, {{
       2.076039862566275, 1.1470914562265597`}, {2.1310426958109914`, 
       1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.076039862566275, 1.1470914562265597`}, {2.076039862566275, 
       1.1470914562265597`}}, {{2.076039862566275, 1.1470914562265597`}, {
       2.1310426958109914`, 1.0961057295467864`}, {2.1310426958109914`, 
       1.0961057295467864`}, {2.076039862566275, 1.1470914562265597`}, {
       2.076039862566275, 1.1470914562265597`}}, {{2.1310426958109914`, 
       1.0961057295467864`}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1310426958109914`, 
       1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}}, {{
       2.1310426958109914`, 1.0961057295467864`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1310426958109914`, 1.0961057295467864`}, {2.1310426958109914`, 
       1.0961057295467864`}}, {{2.1310426958109914`, 1.0961057295467864`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1604793188343874`, 
       1.0008380278066993`}, {2.1310426958109914`, 1.0961057295467864`}, {
       2.1310426958109914`, 1.0961057295467864`}}, {{2.1310426958109914`, 
       1.0961057295467864`}, {2.1604793188343874`, 1.0008380278066993`}, {
       2.1604793188343874`, 1.0008380278066993`}, {2.1310426958109914`, 
       1.0961057295467864`}, {2.1310426958109914`, 1.0961057295467864`}}, {{
       1.9093839864924338`, 1.3763864165475082`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.9093839864924338`, 1.6971408329300592`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}}, {{1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}, {{2.187165459455775, 
       1.5367636247387837`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`, 
       1.3521072608036129`}, {1.909383986492434, 1.3763864165475082`}, {
       1.909383986492434, 1.3763864165475082`}, {2.0159953879179824`, 
       1.3521072608036129`}, {2.094571635134661, 1.3763864165475082`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.187165459455775, 
       1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}}, {{
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}, {{1.909383986492434, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661, 
       1.6971408329300592`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.094571635134661, 1.6971408329300592`}, {2.0159953879179824`, 
       1.7214199886739545`}, {1.909383986492434, 1.6971408329300592`}, {
       1.909383986492434, 1.6971408329300592`}}, {{2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}}, {{
       1.9093839864924338`, 1.3763864165475082`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}}, {{1.9093839864924338`, 1.3763864165475082`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}}, {{1.9093839864924338`, 
       1.3763864165475082`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.9093839864924338`, 
       1.3763864165475082`}, {1.9093839864924338`, 1.3763864165475082`}}, {{
       1.9093839864924338`, 1.3763864165475082`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}}, {{1.8350519201230076`, 1.4565750206431458`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}}, {{1.8350519201230076`, 
       1.4565750206431458`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8350519201230076`, 
       1.4565750206431458`}, {1.8350519201230076`, 1.4565750206431458`}}, {{
       1.8350519201230076`, 1.4565750206431458`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.4565750206431458`}, {1.8350519201230076`, 
       1.4565750206431458`}}, {{1.8350519201230076`, 1.4565750206431458`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.4565750206431458`}, {
       1.8350519201230076`, 1.4565750206431458`}}, {{1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}}, {{
       1.8167901621713203`, 1.5367636247387837`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8167901621713203`, 1.5367636247387837`}, {1.8167901621713203`, 
       1.5367636247387837`}}, {{1.8167901621713203`, 1.5367636247387837`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8167901621713203`, 1.5367636247387837`}, {
       1.8167901621713203`, 1.5367636247387837`}}, {{1.8167901621713203`, 
       1.5367636247387837`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8167901621713203`, 
       1.5367636247387837`}, {1.8167901621713203`, 1.5367636247387837`}}, {{
       1.8350519201230076`, 1.6169522288344216`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.9093839864924338`, 1.6971408329300592`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}}, {{1.8350519201230076`, 1.6169522288344216`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.8350519201230076`, 1.6169522288344216`}, {
       1.8350519201230076`, 1.6169522288344216`}}, {{1.8350519201230076`, 
       1.6169522288344216`}, {1.9093839864924338`, 1.6971408329300592`}, {
       1.9093839864924338`, 1.6971408329300592`}, {1.8350519201230076`, 
       1.6169522288344216`}, {1.8350519201230076`, 1.6169522288344216`}}, {{
       1.8350519201230076`, 1.6169522288344216`}, {1.9093839864924338`, 
       1.6971408329300592`}, {1.9093839864924338`, 1.6971408329300592`}, {
       1.8350519201230076`, 1.6169522288344216`}, {1.8350519201230076`, 
       1.6169522288344216`}}, {{2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}, {2.187165459455775, 1.5367636247387837`}, {
       2.187165459455775, 1.5367636247387837`}}, {{2.187165459455775, 
       1.5367636247387837`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.187165459455775, 
       1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}}, {{
       2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`, 
       1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}}, {{2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}, {2.187165459455775, 1.5367636247387837`}, {
       2.187165459455775, 1.5367636247387837`}}, {{2.1548861243996527`, 
       1.4322958648992508`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.1548861243996527`, 
       1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}}, {{
       2.1548861243996527`, 1.4322958648992508`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}, {
       2.1548861243996527`, 1.4322958648992508`}, {2.1548861243996527`, 
       1.4322958648992508`}}, {{2.1548861243996527`, 1.4322958648992508`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}, {2.1548861243996527`, 1.4322958648992508`}, {
       2.1548861243996527`, 1.4322958648992508`}}, {{2.1548861243996527`, 
       1.4322958648992508`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}, {2.1548861243996527`, 
       1.4322958648992508`}, {2.1548861243996527`, 1.4322958648992508`}}, {{
       2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`, 
       1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}, {{2.094571635134661, 1.3763864165475082`}, {
       2.0159953879179824`, 1.3521072608036129`}, {2.0159953879179824`, 
       1.3521072608036129`}, {2.094571635134661, 1.3763864165475082`}, {
       2.094571635134661, 1.3763864165475082`}}, {{2.094571635134661, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}, {2.094571635134661, 
       1.3763864165475082`}, {2.094571635134661, 1.3763864165475082`}}, {{
       2.094571635134661, 1.3763864165475082`}, {2.0159953879179824`, 
       1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.094571635134661, 1.3763864165475082`}, {2.094571635134661, 
       1.3763864165475082`}}, {{2.0159953879179824`, 1.3521072608036129`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}}, {{2.0159953879179824`, 
       1.3521072608036129`}, {1.9093839864924338`, 1.3763864165475082`}, {
       1.9093839864924338`, 1.3763864165475082`}, {2.0159953879179824`, 
       1.3521072608036129`}, {2.0159953879179824`, 1.3521072608036129`}}, {{
       2.0159953879179824`, 1.3521072608036129`}, {1.9093839864924338`, 
       1.3763864165475082`}, {1.9093839864924338`, 1.3763864165475082`}, {
       2.0159953879179824`, 1.3521072608036129`}, {2.0159953879179824`, 
       1.3521072608036129`}}, {{2.0159953879179824`, 1.3521072608036129`}, {
       1.9093839864924338`, 1.3763864165475082`}, {1.9093839864924338`, 
       1.3763864165475082`}, {2.0159953879179824`, 1.3521072608036129`}, {
       2.0159953879179824`, 1.3521072608036129`}}, {{1.909383986492434, 
       1.6971408329300592`}, {2.0159953879179824`, 1.7214199886739545`}, {
       2.0159953879179824`, 1.7214199886739545`}, {1.909383986492434, 
       1.6971408329300592`}, {1.909383986492434, 1.6971408329300592`}}, {{
       1.909383986492434, 1.6971408329300592`}, {2.0159953879179824`, 
       1.7214199886739545`}, {2.0159953879179824`, 1.7214199886739545`}, {
       1.909383986492434, 1.6971408329300592`}, {1.909383986492434, 
       1.6971408329300592`}}, {{1.909383986492434, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}, {1.909383986492434, 1.6971408329300592`}, {
       1.909383986492434, 1.6971408329300592`}}, {{1.909383986492434, 
       1.6971408329300592`}, {2.0159953879179824`, 1.7214199886739545`}, {
       2.0159953879179824`, 1.7214199886739545`}, {1.909383986492434, 
       1.6971408329300592`}, {1.909383986492434, 1.6971408329300592`}}, {{
       2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}}, {{2.0159953879179824`, 1.7214199886739545`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}, {2.0159953879179824`, 1.7214199886739545`}, {
       2.0159953879179824`, 1.7214199886739545`}}, {{2.0159953879179824`, 
       1.7214199886739545`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}, {2.0159953879179824`, 
       1.7214199886739545`}, {2.0159953879179824`, 1.7214199886739545`}}, {{
       2.0159953879179824`, 1.7214199886739545`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}, {
       2.0159953879179824`, 1.7214199886739545`}, {2.0159953879179824`, 
       1.7214199886739545`}}, {{2.094571635134661, 1.6971408329300592`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}}, {{2.094571635134661, 
       1.6971408329300592`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.094571635134661, 
       1.6971408329300592`}, {2.094571635134661, 1.6971408329300592`}}, {{
       2.094571635134661, 1.6971408329300592`}, {2.1548861243996527`, 
       1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.094571635134661, 1.6971408329300592`}, {2.094571635134661, 
       1.6971408329300592`}}, {{2.094571635134661, 1.6971408329300592`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}, {2.094571635134661, 1.6971408329300592`}, {
       2.094571635134661, 1.6971408329300592`}}, {{2.1548861243996527`, 
       1.6412313845783166`}, {2.187165459455775, 1.5367636247387837`}, {
       2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`, 
       1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}}, {{
       2.1548861243996527`, 1.6412313845783166`}, {2.187165459455775, 
       1.5367636247387837`}, {2.187165459455775, 1.5367636247387837`}, {
       2.1548861243996527`, 1.6412313845783166`}, {2.1548861243996527`, 
       1.6412313845783166`}}, {{2.1548861243996527`, 1.6412313845783166`}, {
       2.187165459455775, 1.5367636247387837`}, {2.187165459455775, 
       1.5367636247387837`}, {2.1548861243996527`, 1.6412313845783166`}, {
       2.1548861243996527`, 1.6412313845783166`}}, {{2.1548861243996527`, 
       1.6412313845783166`}, {2.187165459455775, 1.5367636247387837`}, {
       2.187165459455775, 1.5367636247387837`}, {2.1548861243996527`, 
       1.6412313845783166`}, {2.1548861243996527`, 1.6412313845783166`}}, {{
       1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`, 
       1.9803982896703187`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.9472272080721864`, 
       2.164879500957241}, {1.9472272080721864`, 2.164879500957241}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.876220356740898, 
       2.0418920267659595`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}, {{1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}}, {{2.1602477620660525`, 
       2.0418920267659595`}, {2.135493908747994, 1.9617794842046625`}, {
       2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {1.9472272080721866`, 1.918904552574678}, {
       1.9472272080721866`, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.089240910734764, 1.918904552574678}, {
       2.135493908747994, 1.9617794842046625`}, {2.1602477620660525`, 
       2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}}, {{
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}, {{1.9472272080721866`, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.135493908747994, 2.1220045693272565`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}, {2.135493908747994, 2.1220045693272565`}, {
       2.089240910734764, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {1.9472272080721866`, 2.164879500957241}, {
       1.9472272080721866`, 2.164879500957241}}, {{2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}}, {{
       1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`, 
       1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}, {{1.9472272080721864`, 1.918904552574678}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.8902246377113703`, 
       1.9803982896703187`}, {1.9472272080721864`, 1.918904552574678}, {
       1.9472272080721864`, 1.918904552574678}}, {{1.9472272080721864`, 
       1.918904552574678}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.9472272080721864`, 
       1.918904552574678}, {1.9472272080721864`, 1.918904552574678}}, {{
       1.9472272080721864`, 1.918904552574678}, {1.8902246377113703`, 
       1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}}, {{1.8902246377113703`, 1.9803982896703187`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.8902246377113703`, 1.9803982896703187`}}, {{1.8902246377113703`, 
       1.9803982896703187`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}, {1.8902246377113703`, 
       1.9803982896703187`}, {1.8902246377113703`, 1.9803982896703187`}}, {{
       1.8902246377113703`, 1.9803982896703187`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 1.9803982896703187`}, {1.8902246377113703`, 
       1.9803982896703187`}}, {{1.8902246377113703`, 1.9803982896703187`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}, {1.8902246377113703`, 1.9803982896703187`}, {
       1.8902246377113703`, 1.9803982896703187`}}, {{1.876220356740898, 
       2.0418920267659595`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}}, {{
       1.876220356740898, 2.0418920267659595`}, {1.8902246377113703`, 
       2.1033857638616005`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.876220356740898, 2.0418920267659595`}, {1.876220356740898, 
       2.0418920267659595`}}, {{1.876220356740898, 2.0418920267659595`}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.8902246377113703`, 
       2.1033857638616005`}, {1.876220356740898, 2.0418920267659595`}, {
       1.876220356740898, 2.0418920267659595`}}, {{1.876220356740898, 
       2.0418920267659595`}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.876220356740898, 
       2.0418920267659595`}, {1.876220356740898, 2.0418920267659595`}}, {{
       1.8902246377113703`, 2.1033857638616005`}, {1.9472272080721864`, 
       2.164879500957241}, {1.9472272080721864`, 2.164879500957241}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.8902246377113703`, 
       2.1033857638616005`}}, {{1.8902246377113703`, 2.1033857638616005`}, {
       1.9472272080721864`, 2.164879500957241}, {1.9472272080721864`, 
       2.164879500957241}, {1.8902246377113703`, 2.1033857638616005`}, {
       1.8902246377113703`, 2.1033857638616005`}}, {{1.8902246377113703`, 
       2.1033857638616005`}, {1.9472272080721864`, 2.164879500957241}, {
       1.9472272080721864`, 2.164879500957241}, {1.8902246377113703`, 
       2.1033857638616005`}, {1.8902246377113703`, 2.1033857638616005`}}, {{
       1.8902246377113703`, 2.1033857638616005`}, {1.9472272080721864`, 
       2.164879500957241}, {1.9472272080721864`, 2.164879500957241}, {
       1.8902246377113703`, 2.1033857638616005`}, {1.8902246377113703`, 
       2.1033857638616005`}}, {{2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.1602477620660525`, 2.0418920267659595`}}, {{2.1602477620660525`, 
       2.0418920267659595`}, {2.135493908747994, 1.9617794842046625`}, {
       2.135493908747994, 1.9617794842046625`}, {2.1602477620660525`, 
       2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}}, {{
       2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994, 
       1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}}, {{2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.1602477620660525`, 2.0418920267659595`}}, {{2.135493908747994, 
       1.9617794842046625`}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.135493908747994, 
       1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}}, {{
       2.135493908747994, 1.9617794842046625`}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}, {
       2.135493908747994, 1.9617794842046625`}, {2.135493908747994, 
       1.9617794842046625`}}, {{2.135493908747994, 1.9617794842046625`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}, {2.135493908747994, 1.9617794842046625`}, {
       2.135493908747994, 1.9617794842046625`}}, {{2.135493908747994, 
       1.9617794842046625`}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}, {2.135493908747994, 
       1.9617794842046625`}, {2.135493908747994, 1.9617794842046625`}}, {{
       2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}, {{2.089240910734764, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.028983631751061, 
       1.9002857471090215`}, {2.089240910734764, 1.918904552574678}, {
       2.089240910734764, 1.918904552574678}}, {{2.089240910734764, 
       1.918904552574678}, {2.028983631751061, 1.9002857471090215`}, {
       2.028983631751061, 1.9002857471090215`}, {2.089240910734764, 
       1.918904552574678}, {2.089240910734764, 1.918904552574678}}, {{
       2.089240910734764, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}, {
       2.089240910734764, 1.918904552574678}, {2.089240910734764, 
       1.918904552574678}}, {{2.028983631751061, 1.9002857471090215`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}, {2.028983631751061, 1.9002857471090215`}, {
       2.028983631751061, 1.9002857471090215`}}, {{2.028983631751061, 
       1.9002857471090215`}, {1.9472272080721864`, 1.918904552574678}, {
       1.9472272080721864`, 1.918904552574678}, {2.028983631751061, 
       1.9002857471090215`}, {2.028983631751061, 1.9002857471090215`}}, {{
       2.028983631751061, 1.9002857471090215`}, {1.9472272080721864`, 
       1.918904552574678}, {1.9472272080721864`, 1.918904552574678}, {
       2.028983631751061, 1.9002857471090215`}, {2.028983631751061, 
       1.9002857471090215`}}, {{2.028983631751061, 1.9002857471090215`}, {
       1.9472272080721864`, 1.918904552574678}, {1.9472272080721864`, 
       1.918904552574678}, {2.028983631751061, 1.9002857471090215`}, {
       2.028983631751061, 1.9002857471090215`}}, {{1.9472272080721866`, 
       2.164879500957241}, {2.028983631751061, 2.1834983064228974`}, {
       2.028983631751061, 2.1834983064228974`}, {1.9472272080721866`, 
       2.164879500957241}, {1.9472272080721866`, 2.164879500957241}}, {{
       1.9472272080721866`, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.028983631751061, 2.1834983064228974`}, {
       1.9472272080721866`, 2.164879500957241}, {1.9472272080721866`, 
       2.164879500957241}}, {{1.9472272080721866`, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}, {1.9472272080721866`, 2.164879500957241}, {
       1.9472272080721866`, 2.164879500957241}}, {{1.9472272080721866`, 
       2.164879500957241}, {2.028983631751061, 2.1834983064228974`}, {
       2.028983631751061, 2.1834983064228974`}, {1.9472272080721866`, 
       2.164879500957241}, {1.9472272080721866`, 2.164879500957241}}, {{
       2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}}, {{2.028983631751061, 2.1834983064228974`}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}, {2.028983631751061, 2.1834983064228974`}, {
       2.028983631751061, 2.1834983064228974`}}, {{2.028983631751061, 
       2.1834983064228974`}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}, {2.028983631751061, 
       2.1834983064228974`}, {2.028983631751061, 2.1834983064228974`}}, {{
       2.028983631751061, 2.1834983064228974`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}, {
       2.028983631751061, 2.1834983064228974`}, {2.028983631751061, 
       2.1834983064228974`}}, {{2.089240910734764, 2.164879500957241}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}}, {{2.089240910734764, 
       2.164879500957241}, {2.135493908747994, 2.1220045693272565`}, {
       2.135493908747994, 2.1220045693272565`}, {2.089240910734764, 
       2.164879500957241}, {2.089240910734764, 2.164879500957241}}, {{
       2.089240910734764, 2.164879500957241}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}, {
       2.089240910734764, 2.164879500957241}, {2.089240910734764, 
       2.164879500957241}}, {{2.089240910734764, 2.164879500957241}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}, {2.089240910734764, 2.164879500957241}, {
       2.089240910734764, 2.164879500957241}}, {{2.135493908747994, 
       2.1220045693272565`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}}, {{
       2.135493908747994, 2.1220045693272565`}, {2.1602477620660525`, 
       2.0418920267659595`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.135493908747994, 2.1220045693272565`}, {2.135493908747994, 
       2.1220045693272565`}}, {{2.135493908747994, 2.1220045693272565`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.1602477620660525`, 
       2.0418920267659595`}, {2.135493908747994, 2.1220045693272565`}, {
       2.135493908747994, 2.1220045693272565`}}, {{2.135493908747994, 
       2.1220045693272565`}, {2.1602477620660525`, 2.0418920267659595`}, {
       2.1602477620660525`, 2.0418920267659595`}, {2.135493908747994, 
       2.1220045693272565`}, {2.135493908747994, 2.1220045693272565`}}, {{
       1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`, 
       2.3941263153558743`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`, 
       2.628267920438913}, {1.8760012596253415`, 2.628267920438913}, {
       1.8036541993202009`, 2.550220718744567}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}, {{1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}, {{2.146364697071709, 
       2.4721735170502206`}, {2.1149473678626873`, 2.370495524089671}, {
       2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`, 
       2.2924483223953245`}, {1.8760012596253415`, 2.3160791136615275`}, {
       1.8760012596253415`, 2.3160791136615275`}, {1.9797656491395037`, 
       2.2924483223953245`}, {2.0562435512562534`, 2.316079113661528}, {
       2.1149473678626873`, 2.370495524089671}, {2.146364697071709, 
       2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}}, {{
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}, {{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {2.0562435512562534`, 
       2.628267920438913}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}, {{2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}}, {{
       1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`, 
       2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}, {{1.8760012596253415`, 2.316079113661528}, {
       1.8036541993202009`, 2.3941263153558743`}, {1.8036541993202009`, 
       2.3941263153558743`}, {1.8760012596253415`, 2.316079113661528}, {
       1.8760012596253415`, 2.316079113661528}}, {{1.8760012596253415`, 
       2.316079113661528}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}, {1.8760012596253415`, 
       2.316079113661528}, {1.8760012596253415`, 2.316079113661528}}, {{
       1.8760012596253415`, 2.316079113661528}, {1.8036541993202009`, 
       2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}}, {{1.8036541993202009`, 2.3941263153558743`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}}, {{1.8036541993202009`, 
       2.3941263153558743`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.8036541993202009`, 
       2.3941263153558743`}, {1.8036541993202009`, 2.3941263153558743`}}, {{
       1.8036541993202009`, 2.3941263153558743`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.3941263153558743`}, {1.8036541993202009`, 
       2.3941263153558743`}}, {{1.8036541993202009`, 2.3941263153558743`}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.3941263153558743`}, {
       1.8036541993202009`, 2.3941263153558743`}}, {{1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.550220718744567}, {
       1.8036541993202009`, 2.550220718744567}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}}, {{
       1.7858801138098856`, 2.4721735170502206`}, {1.8036541993202009`, 
       2.550220718744567}, {1.8036541993202009`, 2.550220718744567}, {
       1.7858801138098856`, 2.4721735170502206`}, {1.7858801138098856`, 
       2.4721735170502206`}}, {{1.7858801138098856`, 2.4721735170502206`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}, {1.7858801138098856`, 2.4721735170502206`}, {
       1.7858801138098856`, 2.4721735170502206`}}, {{1.7858801138098856`, 
       2.4721735170502206`}, {1.8036541993202009`, 2.550220718744567}, {
       1.8036541993202009`, 2.550220718744567}, {1.7858801138098856`, 
       2.4721735170502206`}, {1.7858801138098856`, 2.4721735170502206`}}, {{
       1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`, 
       2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}}, {{1.8036541993202009`, 2.550220718744567}, {
       1.8760012596253415`, 2.6282679204389137`}, {1.8760012596253415`, 
       2.6282679204389137`}, {1.8036541993202009`, 2.550220718744567}, {
       1.8036541993202009`, 2.550220718744567}}, {{1.8036541993202009`, 
       2.550220718744567}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}, {1.8036541993202009`, 
       2.550220718744567}, {1.8036541993202009`, 2.550220718744567}}, {{
       1.8036541993202009`, 2.550220718744567}, {1.8760012596253415`, 
       2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8036541993202009`, 2.550220718744567}, {1.8036541993202009`, 
       2.550220718744567}}, {{2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}, {2.146364697071709, 2.4721735170502206`}, {
       2.146364697071709, 2.4721735170502206`}}, {{2.146364697071709, 
       2.4721735170502206`}, {2.1149473678626873`, 2.370495524089671}, {
       2.1149473678626873`, 2.370495524089671}, {2.146364697071709, 
       2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}}, {{
       2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`, 
       2.370495524089671}, {2.1149473678626873`, 2.370495524089671}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}}, {{2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}, {2.146364697071709, 2.4721735170502206`}, {
       2.146364697071709, 2.4721735170502206`}}, {{2.1149473678626873`, 
       2.370495524089671}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.1149473678626873`, 
       2.370495524089671}, {2.1149473678626873`, 2.370495524089671}}, {{
       2.1149473678626873`, 2.370495524089671}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}, {
       2.1149473678626873`, 2.370495524089671}, {2.1149473678626873`, 
       2.370495524089671}}, {{2.1149473678626873`, 2.370495524089671}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}, {2.1149473678626873`, 2.370495524089671}, {
       2.1149473678626873`, 2.370495524089671}}, {{2.1149473678626873`, 
       2.370495524089671}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}, {2.1149473678626873`, 
       2.370495524089671}, {2.1149473678626873`, 2.370495524089671}}, {{
       2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`, 
       2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}, {{2.0562435512562534`, 2.316079113661528}, {
       1.9797656491395037`, 2.2924483223953245`}, {1.9797656491395037`, 
       2.2924483223953245`}, {2.0562435512562534`, 2.316079113661528}, {
       2.0562435512562534`, 2.316079113661528}}, {{2.0562435512562534`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}, {2.0562435512562534`, 
       2.316079113661528}, {2.0562435512562534`, 2.316079113661528}}, {{
       2.0562435512562534`, 2.316079113661528}, {1.9797656491395037`, 
       2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}, {
       2.0562435512562534`, 2.316079113661528}, {2.0562435512562534`, 
       2.316079113661528}}, {{1.9797656491395037`, 2.2924483223953245`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}}, {{1.9797656491395037`, 
       2.2924483223953245`}, {1.8760012596253415`, 2.316079113661528}, {
       1.8760012596253415`, 2.316079113661528}, {1.9797656491395037`, 
       2.2924483223953245`}, {1.9797656491395037`, 2.2924483223953245`}}, {{
       1.9797656491395037`, 2.2924483223953245`}, {1.8760012596253415`, 
       2.316079113661528}, {1.8760012596253415`, 2.316079113661528}, {
       1.9797656491395037`, 2.2924483223953245`}, {1.9797656491395037`, 
       2.2924483223953245`}}, {{1.9797656491395037`, 2.2924483223953245`}, {
       1.8760012596253415`, 2.316079113661528}, {1.8760012596253415`, 
       2.316079113661528}, {1.9797656491395037`, 2.2924483223953245`}, {
       1.9797656491395037`, 2.2924483223953245`}}, {{1.8760012596253415`, 
       2.6282679204389137`}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.8760012596253415`, 
       2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}}, {{
       1.8760012596253415`, 2.6282679204389137`}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.8760012596253415`, 2.6282679204389137`}, {1.8760012596253415`, 
       2.6282679204389137`}}, {{1.8760012596253415`, 2.6282679204389137`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.8760012596253415`, 2.6282679204389137`}, {
       1.8760012596253415`, 2.6282679204389137`}}, {{1.8760012596253415`, 
       2.6282679204389137`}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.8760012596253415`, 
       2.6282679204389137`}, {1.8760012596253415`, 2.6282679204389137`}}, {{
       1.9797656491395037`, 2.6518987117051167`}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}}, {{1.9797656491395037`, 2.6518987117051167`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}, {1.9797656491395037`, 2.6518987117051167`}, {
       1.9797656491395037`, 2.6518987117051167`}}, {{1.9797656491395037`, 
       2.6518987117051167`}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}, {1.9797656491395037`, 
       2.6518987117051167`}, {1.9797656491395037`, 2.6518987117051167`}}, {{
       1.9797656491395037`, 2.6518987117051167`}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}, {
       1.9797656491395037`, 2.6518987117051167`}, {1.9797656491395037`, 
       2.6518987117051167`}}, {{2.0562435512562534`, 2.628267920438913}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}}, {{2.0562435512562534`, 
       2.628267920438913}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.0562435512562534`, 
       2.628267920438913}, {2.0562435512562534`, 2.628267920438913}}, {{
       2.0562435512562534`, 2.628267920438913}, {2.1149473678626873`, 
       2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.0562435512562534`, 2.628267920438913}, {2.0562435512562534`, 
       2.628267920438913}}, {{2.0562435512562534`, 2.628267920438913}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}, {2.0562435512562534`, 2.628267920438913}, {
       2.0562435512562534`, 2.628267920438913}}, {{2.1149473678626873`, 
       2.5738515100107704`}, {2.146364697071709, 2.4721735170502206`}, {
       2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`, 
       2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}}, {{
       2.1149473678626873`, 2.5738515100107704`}, {2.146364697071709, 
       2.4721735170502206`}, {2.146364697071709, 2.4721735170502206`}, {
       2.1149473678626873`, 2.5738515100107704`}, {2.1149473678626873`, 
       2.5738515100107704`}}, {{2.1149473678626873`, 2.5738515100107704`}, {
       2.146364697071709, 2.4721735170502206`}, {2.146364697071709, 
       2.4721735170502206`}, {2.1149473678626873`, 2.5738515100107704`}, {
       2.1149473678626873`, 2.5738515100107704`}}, {{2.1149473678626873`, 
       2.5738515100107704`}, {2.146364697071709, 2.4721735170502206`}, {
       2.146364697071709, 2.4721735170502206`}, {2.1149473678626873`, 
       2.5738515100107704`}, {2.1149473678626873`, 2.5738515100107704`}}, {{
       1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.0873594139807965`}, {1.962885544125747, 3.0873594139807965`}, {
       1.9105626923628816`, 3.030914105110803}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}, {{1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}, {{2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 2.900933222980723}, {
       2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {1.962885544125747, 2.8615781785008205`}, {
       1.962885544125747, 2.8615781785008205`}, {2.0379300414130537`, 
       2.844487914110729}, {2.093240401208077, 2.861578178500821}, {
       2.1356961842248015`, 2.900933222980723}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1584178297492427`, 2.9744687962408087`}}, {{
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}, {{1.962885544125747, 3.087359413980797}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077, 
       3.0873594139807965`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.093240401208077, 3.0873594139807965`}, {2.0379300414130537`, 
       3.1044496783708886`}, {1.962885544125747, 3.087359413980797}, {
       1.962885544125747, 3.087359413980797}}, {{2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}}, {{
       1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}, {{1.962885544125747, 2.861578178500821}, {
       1.9105626923628816`, 2.9180234873708146`}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.962885544125747, 2.861578178500821}, {
       1.962885544125747, 2.861578178500821}}, {{1.962885544125747, 
       2.861578178500821}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}, {1.962885544125747, 
       2.861578178500821}, {1.962885544125747, 2.861578178500821}}, {{
       1.962885544125747, 2.861578178500821}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}}, {{1.9105626923628816`, 2.9180234873708146`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}}, {{1.9105626923628816`, 
       2.9180234873708146`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.9105626923628816`, 
       2.9180234873708146`}, {1.9105626923628816`, 2.9180234873708146`}}, {{
       1.9105626923628816`, 2.9180234873708146`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 2.9180234873708146`}, {1.9105626923628816`, 
       2.9180234873708146`}}, {{1.9105626923628816`, 2.9180234873708146`}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 2.9180234873708146`}, {
       1.9105626923628816`, 2.9180234873708146`}}, {{1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 3.030914105110803}, {
       1.9105626923628816`, 3.030914105110803}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}}, {{
       1.8977081155845816`, 2.9744687962408087`}, {1.9105626923628816`, 
       3.030914105110803}, {1.9105626923628816`, 3.030914105110803}, {
       1.8977081155845816`, 2.9744687962408087`}, {1.8977081155845816`, 
       2.9744687962408087`}}, {{1.8977081155845816`, 2.9744687962408087`}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}, {1.8977081155845816`, 2.9744687962408087`}, {
       1.8977081155845816`, 2.9744687962408087`}}, {{1.8977081155845816`, 
       2.9744687962408087`}, {1.9105626923628816`, 3.030914105110803}, {
       1.9105626923628816`, 3.030914105110803}, {1.8977081155845816`, 
       2.9744687962408087`}, {1.8977081155845816`, 2.9744687962408087`}}, {{
       1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}}, {{1.9105626923628816`, 3.030914105110803}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}, {1.9105626923628816`, 3.030914105110803}, {
       1.9105626923628816`, 3.030914105110803}}, {{1.9105626923628816`, 
       3.030914105110803}, {1.962885544125747, 3.087359413980797}, {
       1.962885544125747, 3.087359413980797}, {1.9105626923628816`, 
       3.030914105110803}, {1.9105626923628816`, 3.030914105110803}}, {{
       1.9105626923628816`, 3.030914105110803}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}, {
       1.9105626923628816`, 3.030914105110803}, {1.9105626923628816`, 
       3.030914105110803}}, {{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}, {{2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 2.900933222980723}, {
       2.1356961842248015`, 2.900933222980723}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1584178297492427`, 2.9744687962408087`}}, {{
       2.1584178297492427`, 2.9744687962408087`}, {2.1356961842248015`, 
       2.900933222980723}, {2.1356961842248015`, 2.900933222980723}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}}, {{2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}}, {{2.1356961842248015`, 
       2.900933222980723}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.1356961842248015`, 
       2.900933222980723}, {2.1356961842248015`, 2.900933222980723}}, {{
       2.1356961842248015`, 2.900933222980723}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}, {
       2.1356961842248015`, 2.900933222980723}, {2.1356961842248015`, 
       2.900933222980723}}, {{2.1356961842248015`, 2.900933222980723}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}, {2.1356961842248015`, 2.900933222980723}, {
       2.1356961842248015`, 2.900933222980723}}, {{2.1356961842248015`, 
       2.900933222980723}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}, {2.1356961842248015`, 
       2.900933222980723}, {2.1356961842248015`, 2.900933222980723}}, {{
       2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}, {{2.093240401208077, 2.861578178500821}, {
       2.0379300414130537`, 2.844487914110729}, {2.0379300414130537`, 
       2.844487914110729}, {2.093240401208077, 2.861578178500821}, {
       2.093240401208077, 2.861578178500821}}, {{2.093240401208077, 
       2.861578178500821}, {2.0379300414130537`, 2.844487914110729}, {
       2.0379300414130537`, 2.844487914110729}, {2.093240401208077, 
       2.861578178500821}, {2.093240401208077, 2.861578178500821}}, {{
       2.093240401208077, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}, {
       2.093240401208077, 2.861578178500821}, {2.093240401208077, 
       2.861578178500821}}, {{2.0379300414130537`, 2.844487914110729}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}, {2.0379300414130537`, 2.844487914110729}, {
       2.0379300414130537`, 2.844487914110729}}, {{2.0379300414130537`, 
       2.844487914110729}, {1.962885544125747, 2.861578178500821}, {
       1.962885544125747, 2.861578178500821}, {2.0379300414130537`, 
       2.844487914110729}, {2.0379300414130537`, 2.844487914110729}}, {{
       2.0379300414130537`, 2.844487914110729}, {1.962885544125747, 
       2.861578178500821}, {1.962885544125747, 2.861578178500821}, {
       2.0379300414130537`, 2.844487914110729}, {2.0379300414130537`, 
       2.844487914110729}}, {{2.0379300414130537`, 2.844487914110729}, {
       1.962885544125747, 2.861578178500821}, {1.962885544125747, 
       2.861578178500821}, {2.0379300414130537`, 2.844487914110729}, {
       2.0379300414130537`, 2.844487914110729}}, {{1.962885544125747, 
       3.087359413980797}, {2.0379300414130537`, 3.1044496783708886`}, {
       2.0379300414130537`, 3.1044496783708886`}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}}, {{
       1.962885544125747, 3.087359413980797}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.0379300414130537`, 3.1044496783708886`}, {
       1.962885544125747, 3.087359413980797}, {1.962885544125747, 
       3.087359413980797}}, {{1.962885544125747, 3.087359413980797}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}, {1.962885544125747, 3.087359413980797}, {
       1.962885544125747, 3.087359413980797}}, {{1.962885544125747, 
       3.087359413980797}, {2.0379300414130537`, 3.1044496783708886`}, {
       2.0379300414130537`, 3.1044496783708886`}, {1.962885544125747, 
       3.087359413980797}, {1.962885544125747, 3.087359413980797}}, {{
       2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}}, {{2.0379300414130537`, 3.1044496783708886`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}, {2.0379300414130537`, 3.1044496783708886`}, {
       2.0379300414130537`, 3.1044496783708886`}}, {{2.0379300414130537`, 
       3.1044496783708886`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}, {2.0379300414130537`, 
       3.1044496783708886`}, {2.0379300414130537`, 3.1044496783708886`}}, {{
       2.0379300414130537`, 3.1044496783708886`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}, {
       2.0379300414130537`, 3.1044496783708886`}, {2.0379300414130537`, 
       3.1044496783708886`}}, {{2.093240401208077, 3.0873594139807965`}, {
       2.1356961842248015`, 3.0480043695008945`}, {2.1356961842248015`, 
       3.0480043695008945`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}}, {{2.093240401208077, 
       3.0873594139807965`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1356961842248015`, 3.0480043695008945`}, {2.093240401208077, 
       3.0873594139807965`}, {2.093240401208077, 3.0873594139807965`}}, {{
       2.093240401208077, 3.0873594139807965`}, {2.1356961842248015`, 
       3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.093240401208077, 3.0873594139807965`}, {2.093240401208077, 
       3.0873594139807965`}}, {{2.093240401208077, 3.0873594139807965`}, {
       2.1356961842248015`, 3.0480043695008945`}, {2.1356961842248015`, 
       3.0480043695008945`}, {2.093240401208077, 3.0873594139807965`}, {
       2.093240401208077, 3.0873594139807965`}}, {{2.1356961842248015`, 
       3.0480043695008945`}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1356961842248015`, 
       3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}}, {{
       2.1356961842248015`, 3.0480043695008945`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1356961842248015`, 3.0480043695008945`}, {2.1356961842248015`, 
       3.0480043695008945`}}, {{2.1356961842248015`, 3.0480043695008945`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1584178297492427`, 
       2.9744687962408087`}, {2.1356961842248015`, 3.0480043695008945`}, {
       2.1356961842248015`, 3.0480043695008945`}}, {{2.1356961842248015`, 
       3.0480043695008945`}, {2.1584178297492427`, 2.9744687962408087`}, {
       2.1584178297492427`, 2.9744687962408087`}, {2.1356961842248015`, 
       3.0480043695008945`}, {2.1356961842248015`, 3.0480043695008945`}}, {{
       1.9302069051947932`, 3.3742196091609893`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.8544491665585008`, 3.505435861545571}, {
       1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`, 
       3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.9302069051947932`, 3.3742196091609893`}, {1.9302069051947932`, 
       3.3742196091609893`}}, {{1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}}, {{2.15748012110367, 
       3.505435861545571}, {2.1310700505998925`, 3.419963193105008}, {
       2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.081722382467378, 3.3742196091609893`}, {
       2.1310700505998925`, 3.419963193105008}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}}, {{
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}, {{1.9302069051947932`, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.081722382467378, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {1.9302069051947932`, 3.636652113930153}, {
       1.9302069051947932`, 3.636652113930153}}, {{2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}}, {{
       1.9302069051947932`, 3.3742196091609893`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.9302069051947932`, 3.3742196091609893`}, {1.9302069051947932`, 
       3.3742196091609893`}}, {{1.9302069051947932`, 3.3742196091609893`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}}, {{1.9302069051947932`, 
       3.3742196091609893`}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}}, {{
       1.9302069051947932`, 3.3742196091609893`}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.9302069051947932`, 3.3742196091609893`}, {1.9302069051947932`, 
       3.3742196091609893`}}, {{1.8693904382479098`, 3.4398277353532802`}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}}, {{1.8693904382479098`, 
       3.4398277353532802`}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`, 
       3.4398277353532802`}, {1.8693904382479098`, 3.4398277353532802`}}, {{
       1.8693904382479098`, 3.4398277353532802`}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}, {
       1.8693904382479098`, 3.4398277353532802`}, {1.8693904382479098`, 
       3.4398277353532802`}}, {{1.8693904382479098`, 3.4398277353532802`}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.4398277353532802`}, {
       1.8693904382479098`, 3.4398277353532802`}}, {{1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.571043987737862}, {
       1.8693904382479098`, 3.571043987737862}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}}, {{
       1.8544491665585008`, 3.505435861545571}, {1.8693904382479098`, 
       3.571043987737862}, {1.8693904382479098`, 3.571043987737862}, {
       1.8544491665585008`, 3.505435861545571}, {1.8544491665585008`, 
       3.505435861545571}}, {{1.8544491665585008`, 3.505435861545571}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}, {1.8544491665585008`, 3.505435861545571}, {
       1.8544491665585008`, 3.505435861545571}}, {{1.8544491665585008`, 
       3.505435861545571}, {1.8693904382479098`, 3.571043987737862}, {
       1.8693904382479098`, 3.571043987737862}, {1.8544491665585008`, 
       3.505435861545571}, {1.8544491665585008`, 3.505435861545571}}, {{
       1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`, 
       3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}}, {{1.8693904382479098`, 3.571043987737862}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}, {1.8693904382479098`, 3.571043987737862}, {
       1.8693904382479098`, 3.571043987737862}}, {{1.8693904382479098`, 
       3.571043987737862}, {1.9302069051947932`, 3.636652113930153}, {
       1.9302069051947932`, 3.636652113930153}, {1.8693904382479098`, 
       3.571043987737862}, {1.8693904382479098`, 3.571043987737862}}, {{
       1.8693904382479098`, 3.571043987737862}, {1.9302069051947932`, 
       3.636652113930153}, {1.9302069051947932`, 3.636652113930153}, {
       1.8693904382479098`, 3.571043987737862}, {1.8693904382479098`, 
       3.571043987737862}}, {{2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}, {2.15748012110367, 3.505435861545571}, {
       2.15748012110367, 3.505435861545571}}, {{2.15748012110367, 
       3.505435861545571}, {2.1310700505998925`, 3.419963193105008}, {
       2.1310700505998925`, 3.419963193105008}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}}, {{
       2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}}, {{2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}, {2.15748012110367, 3.505435861545571}, {
       2.15748012110367, 3.505435861545571}}, {{2.1310700505998925`, 
       3.419963193105008}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}}, {{
       2.1310700505998925`, 3.419963193105008}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}, {
       2.1310700505998925`, 3.419963193105008}, {2.1310700505998925`, 
       3.419963193105008}}, {{2.1310700505998925`, 3.419963193105008}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}, {2.1310700505998925`, 3.419963193105008}, {
       2.1310700505998925`, 3.419963193105008}}, {{2.1310700505998925`, 
       3.419963193105008}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}, {2.1310700505998925`, 
       3.419963193105008}, {2.1310700505998925`, 3.419963193105008}}, {{
       2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}, {{2.081722382467378, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.017433442645454, 
       3.354355066912717}, {2.081722382467378, 3.3742196091609893`}, {
       2.081722382467378, 3.3742196091609893`}}, {{2.081722382467378, 
       3.3742196091609893`}, {2.017433442645454, 3.354355066912717}, {
       2.017433442645454, 3.354355066912717}, {2.081722382467378, 
       3.3742196091609893`}, {2.081722382467378, 3.3742196091609893`}}, {{
       2.081722382467378, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}, {
       2.081722382467378, 3.3742196091609893`}, {2.081722382467378, 
       3.3742196091609893`}}, {{2.017433442645454, 3.354355066912717}, {
       1.9302069051947932`, 3.3742196091609893`}, {1.9302069051947932`, 
       3.3742196091609893`}, {2.017433442645454, 3.354355066912717}, {
       2.017433442645454, 3.354355066912717}}, {{2.017433442645454, 
       3.354355066912717}, {1.9302069051947932`, 3.3742196091609893`}, {
       1.9302069051947932`, 3.3742196091609893`}, {2.017433442645454, 
       3.354355066912717}, {2.017433442645454, 3.354355066912717}}, {{
       2.017433442645454, 3.354355066912717}, {1.9302069051947932`, 
       3.3742196091609893`}, {1.9302069051947932`, 3.3742196091609893`}, {
       2.017433442645454, 3.354355066912717}, {2.017433442645454, 
       3.354355066912717}}, {{2.017433442645454, 3.354355066912717}, {
       1.9302069051947932`, 3.3742196091609893`}, {1.9302069051947932`, 
       3.3742196091609893`}, {2.017433442645454, 3.354355066912717}, {
       2.017433442645454, 3.354355066912717}}, {{1.9302069051947932`, 
       3.636652113930153}, {2.017433442645454, 3.6565166561784253`}, {
       2.017433442645454, 3.6565166561784253`}, {1.9302069051947932`, 
       3.636652113930153}, {1.9302069051947932`, 3.636652113930153}}, {{
       1.9302069051947932`, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.017433442645454, 3.6565166561784253`}, {
       1.9302069051947932`, 3.636652113930153}, {1.9302069051947932`, 
       3.636652113930153}}, {{1.9302069051947932`, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}, {1.9302069051947932`, 3.636652113930153}, {
       1.9302069051947932`, 3.636652113930153}}, {{1.9302069051947932`, 
       3.636652113930153}, {2.017433442645454, 3.6565166561784253`}, {
       2.017433442645454, 3.6565166561784253`}, {1.9302069051947932`, 
       3.636652113930153}, {1.9302069051947932`, 3.636652113930153}}, {{
       2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}}, {{2.017433442645454, 3.6565166561784253`}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}, {2.017433442645454, 3.6565166561784253`}, {
       2.017433442645454, 3.6565166561784253`}}, {{2.017433442645454, 
       3.6565166561784253`}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}, {2.017433442645454, 
       3.6565166561784253`}, {2.017433442645454, 3.6565166561784253`}}, {{
       2.017433442645454, 3.6565166561784253`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}, {
       2.017433442645454, 3.6565166561784253`}, {2.017433442645454, 
       3.6565166561784253`}}, {{2.081722382467378, 3.636652113930153}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}}, {{2.081722382467378, 
       3.636652113930153}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.081722382467378, 
       3.636652113930153}, {2.081722382467378, 3.636652113930153}}, {{
       2.081722382467378, 3.636652113930153}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.081722382467378, 3.636652113930153}, {2.081722382467378, 
       3.636652113930153}}, {{2.081722382467378, 3.636652113930153}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.081722382467378, 3.636652113930153}, {
       2.081722382467378, 3.636652113930153}}, {{2.1310700505998925`, 
       3.5909085299861343`}, {2.15748012110367, 3.505435861545571}, {
       2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}}, {{
       2.1310700505998925`, 3.5909085299861343`}, {2.15748012110367, 
       3.505435861545571}, {2.15748012110367, 3.505435861545571}, {
       2.1310700505998925`, 3.5909085299861343`}, {2.1310700505998925`, 
       3.5909085299861343`}}, {{2.1310700505998925`, 3.5909085299861343`}, {
       2.15748012110367, 3.505435861545571}, {2.15748012110367, 
       3.505435861545571}, {2.1310700505998925`, 3.5909085299861343`}, {
       2.1310700505998925`, 3.5909085299861343`}}, {{2.1310700505998925`, 
       3.5909085299861343`}, {2.15748012110367, 3.505435861545571}, {
       2.15748012110367, 3.505435861545571}, {2.1310700505998925`, 
       3.5909085299861343`}, {2.1310700505998925`, 3.5909085299861343`}}, {{
       2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}, {{
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}, {{
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}, {{
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}, {{
       2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.2144819406651965`, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}, {{
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}, {{
       2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}, {{
       2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}, {{
       2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}, {{
       2.1194917557396233`, -4.418425060118223}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}}, {{
       2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}, {{
       2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}, {{
       2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}, {{
       2.0532622846331705`, -4.346977445415516}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.346977445415516}, {
       2.0532622846331705`, -4.346977445415516}}, {{
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}, {{
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}, {{
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}, {{
       2.036991156576494, -4.2755298307128085`}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.036991156576494, -4.2755298307128085`}, {
       2.036991156576494, -4.2755298307128085`}}, {{
       2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}, {{
       2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}, {{
       2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}, {{
       2.0532622846331705`, -4.204082216010101}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.0532622846331705`, -4.204082216010101}, {
       2.0532622846331705`, -4.204082216010101}}, {{
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}, {{
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}, {{
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}, {{
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}}, {{
       2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}, {{
       2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}, {{
       2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}, {{
       2.338232839409891, -4.368610042521558}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}, {
       2.338232839409891, -4.368610042521558}, {
       2.338232839409891, -4.368610042521558}}, {{
       2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}, {{
       2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}, {{
       2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}, {{
       2.284492954065882, -4.418425060118223}, {
       2.214481940665197, -4.440057657224265}, {
       2.214481940665197, -4.440057657224265}, {
       2.284492954065882, -4.418425060118223}, {
       2.284492954065882, -4.418425060118223}}, {{
       2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}, {{
       2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}, {{
       2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}, {{
       2.2144819406651965`, -4.440057657224265}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.1194917557396233`, -4.418425060118223}, {
       2.2144819406651965`, -4.440057657224265}, {
       2.2144819406651965`, -4.440057657224265}}, {{
       2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}, {{
       2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}, {{
       2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}, {{
       2.1194917557396233`, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}, {
       2.1194917557396233`, -4.132634601307394}, {
       2.1194917557396233`, -4.132634601307394}}, {{
       2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}, {{
       2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}, {{
       2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}, {{
       2.214481940665197, -4.111002004201352}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}, {
       2.214481940665197, -4.111002004201352}, {
       2.214481940665197, -4.111002004201352}}, {{
       2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}, {{
       2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}, {{
       2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}, {{
       2.284492954065882, -4.132634601307394}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}, {
       2.284492954065882, -4.132634601307394}, {
       2.284492954065882, -4.132634601307394}}, {{
       2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}, {{
       2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}, {{
       2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}, {{
       2.338232839409891, -4.182449618904059}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.3669935532290114`, -4.2755298307128085`}, {
       2.338232839409891, -4.182449618904059}, {
       2.338232839409891, -4.182449618904059}}, {{
       2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}, {{
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}, {{
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}, {{
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}, {{
       2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}, {{
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}, {{
       2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}, {{
       2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}, {{
       2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}, {{
       2.1350390309002663`, -3.844326405317597}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}}, {{
       2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}, {{
       2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}, {{
       2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}, {{
       2.071187472893896, -3.775444056743894}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.775444056743894}, {
       2.071187472893896, -3.775444056743894}}, {{
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}, {{
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}, {{
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}, {{
       2.055500545917384, -3.7065617081701907`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.055500545917384, -3.7065617081701907`}, {
       2.055500545917384, -3.7065617081701907`}}, {{
       2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}, {{
       2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}, {{
       2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}, {{
       2.071187472893896, -3.6376793595964876`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.071187472893896, -3.6376793595964876`}, {
       2.071187472893896, -3.6376793595964876`}}, {{
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}, {{
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}, {{
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}, {{
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}}, {{
       2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}, {{
       2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}, {{
       2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}, {{
       2.3459264011149363`, -3.7962999537617743`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.3459264011149363`, -3.7962999537617743`}, {
       2.3459264011149363`, -3.7962999537617743`}}, {{
       2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}, {{
       2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}, {{
       2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}, {{
       2.2941160008660306`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.2941160008660306`, -3.844326405317597}, {
       2.2941160008660306`, -3.844326405317597}}, {{
       2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}, {{
       2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}, {{
       2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}, {{
       2.226618673640613, -3.8651823023354774`}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.1350390309002663`, -3.844326405317597}, {
       2.226618673640613, -3.8651823023354774`}, {
       2.226618673640613, -3.8651823023354774`}}, {{
       2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}, {{
       2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}, {{
       2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}, {{
       2.1350390309002663`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}, {
       2.1350390309002663`, -3.5687970110227845`}, {
       2.1350390309002663`, -3.5687970110227845`}}, {{
       2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}, {{
       2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}, {{
       2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}, {{
       2.226618673640613, -3.547941114004904}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.226618673640613, -3.547941114004904}, {
       2.226618673640613, -3.547941114004904}}, {{
       2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}, {{
       2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}, {{
       2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}, {{
       2.2941160008660306`, -3.5687970110227845`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.2941160008660306`, -3.5687970110227845`}, {
       2.2941160008660306`, -3.5687970110227845`}}, {{
       2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}, {{
       2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}, {{
       2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}, {{
       2.3459264011149363`, -3.616823462578607}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.373654485848913, -3.7065617081701907`}, {
       2.3459264011149363`, -3.616823462578607}, {
       2.3459264011149363`, -3.616823462578607}}, {{
       2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}, {{
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}, {{
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}, {{
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}, {{
       2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}, {{
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}, {{
       2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}, {{
       2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}, {{
       2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}, {{
       2.211467446590762, -3.3397203822511474`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}}, {{
       2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}, {{
       2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}, {{
       2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}, {{
       2.150708561743013, -3.274174374985128}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.274174374985128}, {
       2.150708561743013, -3.274174374985128}}, {{
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}, {{
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}, {{
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}, {{
       2.1357814367120795`, -3.2086283677191094`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.1357814367120795`, -3.2086283677191094`}, {
       2.1357814367120795`, -3.2086283677191094`}}, {{
       2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}, {{
       2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}, {{
       2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}, {{
       2.150708561743013, -3.1430823604530906`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.150708561743013, -3.1430823604530906`}, {
       2.150708561743013, -3.1430823604530906`}}, {{
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}, {{
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}, {{
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}, {{
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}}, {{
       2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}, {{
       2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}, {{
       2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}, {{
       2.4121404112416722`, -3.294020109135883}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.4121404112416722`, -3.294020109135883}, {
       2.4121404112416722`, -3.294020109135883}}, {{
       2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}, {{
       2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}, {{
       2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}, {{
       2.362839466348127, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.362839466348127, -3.3397203822511474`}, {
       2.362839466348127, -3.3397203822511474`}}, {{
       2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}, {{
       2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}, {{
       2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}, {{
       2.2986113964236483`, -3.359566116401902}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.211467446590762, -3.3397203822511474`}, {
       2.2986113964236483`, -3.359566116401902}, {
       2.2986113964236483`, -3.359566116401902}}, {{
       2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}, {{
       2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}, {{
       2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}, {{
       2.211467446590762, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.211467446590762, -3.0775363531870714`}, {
       2.211467446590762, -3.0775363531870714`}}, {{
       2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}, {{
       2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}, {{
       2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}, {{
       2.2986113964236483`, -3.057690619036317}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.2986113964236483`, -3.057690619036317}, {
       2.2986113964236483`, -3.057690619036317}}, {{
       2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}, {{
       2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}, {{
       2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}, {{
       2.362839466348127, -3.0775363531870714`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.362839466348127, -3.0775363531870714`}, {
       2.362839466348127, -3.0775363531870714`}}, {{
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}, {{
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}, {{
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}, {{
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4385254762268094`, -3.2086283677191094`}, {
       2.4121404112416722`, -3.1232366263023357`}, {
       2.4121404112416722`, -3.1232366263023357`}}, {{
       2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}, {{
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}, {{
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}, {{
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}, {{
       2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}, {{
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}, {{
       2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}, {{
       2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}, {{
       2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}, {{
       2.1809628880699874`, -2.8485729018293755`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}}, {{
       2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}, {{
       2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}, {{
       2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}, {{
       2.114733332008338, -2.7771251954779497`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.7771251954779497`}, {
       2.114733332008338, -2.7771251954779497`}}, {{
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}, {{
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}, {{
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}, {{
       2.098462183080033, -2.7056774891265234`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}, {
       2.098462183080033, -2.7056774891265234`}, {
       2.098462183080033, -2.7056774891265234`}}, {{
       2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}, {{
       2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}, {{
       2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}, {{
       2.114733332008338, -2.634229782775097}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.114733332008338, -2.634229782775097}, {
       2.114733332008338, -2.634229782775097}}, {{
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}, {{
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}, {{
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}, {{
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}}, {{
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}, {{
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}, {{
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}, {{
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3997042523282097`, -2.7987578203329906`}, {
       2.3997042523282097`, -2.7987578203329906`}}, {{
       2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}, {{
       2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}, {{
       2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}, {{
       2.3459642980498963`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.3459642980498963`, -2.8485729018293755`}, {
       2.3459642980498963`, -2.8485729018293755`}}, {{
       2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}, {{
       2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}, {{
       2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}, {{
       2.2759531948432783`, -2.870205526684417}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.1809628880699874`, -2.8485729018293755`}, {
       2.2759531948432783`, -2.870205526684417}, {
       2.2759531948432783`, -2.870205526684417}}, {{
       2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}, {{
       2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}, {{
       2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}, {{
       2.1809628880699874`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.1809628880699874`, -2.5627820764236713`}, {
       2.1809628880699874`, -2.5627820764236713`}}, {{
       2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}, {{
       2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}, {{
       2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}, {{
       2.2759531948432783`, -2.54114945156863}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.2759531948432783`, -2.54114945156863}, {
       2.2759531948432783`, -2.54114945156863}}, {{
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}, {{
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}, {{
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}, {{
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3459642980498963`, -2.5627820764236713`}, {
       2.3459642980498963`, -2.5627820764236713`}}, {{
       2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}, {{
       2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}, {{
       2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}, {{
       2.3997042523282097`, -2.612597157920056}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.4284650030398507`, -2.7056774891265234`}, {
       2.3997042523282097`, -2.612597157920056}, {
       2.3997042523282097`, -2.612597157920056}}, {{
       2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}, {{
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}, {{
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}, {{
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}, {{
       2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}, {{
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}, {{
       2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}, {{
       2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}, {{
       2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}, {{
       2.193639817486818, -2.3842326027401874`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}}, {{
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}, {{
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}, {{
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}, {{
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.3106694354532737`}, {
       2.1254493022036924`, -2.3106694354532737`}}, {{
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}, {{
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}, {{
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}, {{
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1086963886157357`, -2.2371062681663596`}, {
       2.1086963886157357`, -2.2371062681663596`}}, {{
       2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}, {{
       2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}, {{
       2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}, {{
       2.1254493022036924`, -2.1635431008794455`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.1254493022036924`, -2.1635431008794455`}, {
       2.1254493022036924`, -2.1635431008794455`}}, {{
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}, {{
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}, {{
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}, {{
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}}, {{
       2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}, {{
       2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}, {{
       2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}, {{
       2.4188577900883166`, -2.3329425703421545`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.4188577900883166`, -2.3329425703421545`}, {
       2.4188577900883166`, -2.3329425703421545`}}, {{
       2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}, {{
       2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}, {{
       2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}, {{
       2.363526675228983, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.363526675228983, -2.3842326027401874`}, {
       2.363526675228983, -2.3842326027401874`}}, {{
       2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}, {{
       2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}, {{
       2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}, {{
       2.2914426467816926`, -2.406505737629068}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.193639817486818, -2.3842326027401874`}, {
       2.2914426467816926`, -2.406505737629068}, {
       2.2914426467816926`, -2.406505737629068}}, {{
       2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}, {{
       2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}, {{
       2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}, {{
       2.193639817486818, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.193639817486818, -2.0899799335925318`}, {
       2.193639817486818, -2.0899799335925318`}}, {{
       2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}, {{
       2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}, {{
       2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}, {{
       2.2914426467816926`, -2.067706798703651}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.2914426467816926`, -2.067706798703651}, {
       2.2914426467816926`, -2.067706798703651}}, {{
       2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}, {{
       2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}, {{
       2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}, {{
       2.363526675228983, -2.0899799335925318`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.363526675228983, -2.0899799335925318`}, {
       2.363526675228983, -2.0899799335925318`}}, {{
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}, {{
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}, {{
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}, {{
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4484701041000654`, -2.2371062681663596`}, {
       2.4188577900883166`, -2.1412699659905647`}, {
       2.4188577900883166`, -2.1412699659905647`}}, {{
       2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}, {{
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}, {{
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}, {{
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}, {{
       2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}, {{
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}, {{
       2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}, {{
       2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}, {{
       2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}, {{
       2.1963696751289064`, -1.8421370651475164`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}}, {{
       2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}, {{
       2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}, {{
       2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}, {{
       2.136685566370438, -1.777750514338506}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.777750514338506}, {
       2.136685566370438, -1.777750514338506}}, {{
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}, {{
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}, {{
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}, {{
       2.122022490245359, -1.7133639635294955`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}, {
       2.122022490245359, -1.7133639635294955`}, {
       2.122022490245359, -1.7133639635294955`}}, {{
       2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}, {{
       2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}, {{
       2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}, {{
       2.136685566370438, -1.648977412720485}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.136685566370438, -1.648977412720485}, {
       2.136685566370438, -1.648977412720485}}, {{
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}, {{
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}, {{
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}, {{
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}}, {{
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}, {{
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}, {{
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}, {{
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3934928954961223`, -1.7972451933210676`}, {
       2.3934928954961223`, -1.7972451933210676`}}, {{
       2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}, {{
       2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}, {{
       2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}, {{
       2.3450640448960014`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.3450640448960014`, -1.8421370651475164`}, {
       2.3450640448960014`, -1.8421370651475164`}}, {{
       2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}, {{
       2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}, {{
       2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}, {{
       2.2819721181708013`, -1.861631744130078}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.1963696751289064`, -1.8421370651475164`}, {
       2.2819721181708013`, -1.861631744130078}, {
       2.2819721181708013`, -1.861631744130078}}, {{
       2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}, {{
       2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}, {{
       2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}, {{
       2.1963696751289064`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.1963696751289064`, -1.5845908619114746`}, {
       2.1963696751289064`, -1.5845908619114746`}}, {{
       2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}, {{
       2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}, {{
       2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}, {{
       2.2819721181708013`, -1.565096182928913}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.2819721181708013`, -1.565096182928913}, {
       2.2819721181708013`, -1.565096182928913}}, {{
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}, {{
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}, {{
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}, {{
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3450640448960014`, -1.5845908619114746`}, {
       2.3450640448960014`, -1.5845908619114746`}}, {{
       2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}, {{
       2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}, {{
       2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}, {{
       2.3934928954961223`, -1.6294827337379234`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.419411229779549, -1.7133639635294955`}, {
       2.3934928954961223`, -1.6294827337379234`}, {
       2.3934928954961223`, -1.6294827337379234`}}, {{
       2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}, {{
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}, {{
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}, {{
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}, {{
       2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}, {{
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}, {{
       2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}, {{
       2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}, {{
       2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}, {{
       2.1577914141855574`, -1.4251078691109635`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}}, {{
       2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}, {{
       2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}, {{
       2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}, {{
       2.094218466776507, -1.3565260825420113`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.3565260825420113`}, {
       2.094218466776507, -1.3565260825420113`}}, {{
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}, {{
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}, {{
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}, {{
       2.0785999883113777`, -1.2879442959730592`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}, {
       2.0785999883113777`, -1.2879442959730592`}, {
       2.0785999883113777`, -1.2879442959730592`}}, {{
       2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}, {{
       2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}, {{
       2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}, {{
       2.094218466776507, -1.219362509404107}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.094218466776507, -1.219362509404107}, {
       2.094218466776507, -1.219362509404107}}, {{
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}, {{
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}, {{
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}, {{
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}}, {{
       2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}, {{
       2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}, {{
       2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}, {{
       2.367758596106988, -1.3772909767072254`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.367758596106988, -1.3772909767072254`}, {
       2.367758596106988, -1.3772909767072254`}}, {{
       2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}, {{
       2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}, {{
       2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}, {{
       2.3161742659339177`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.3161742659339177`, -1.4251078691109635`}, {
       2.3161742659339177`, -1.4251078691109635`}}, {{
       2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}, {{
       2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}, {{
       2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}, {{
       2.248971457295718, -1.4458727632761776`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.1577914141855574`, -1.4251078691109635`}, {
       2.248971457295718, -1.4458727632761776`}, {
       2.248971457295718, -1.4458727632761776`}}, {{
       2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}, {{
       2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}, {{
       2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}, {{
       2.1577914141855574`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.1577914141855574`, -1.1507807228351548`}, {
       2.1577914141855574`, -1.1507807228351548`}}, {{
       2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}, {{
       2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}, {{
       2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}, {{
       2.248971457295718, -1.1300158286699407`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.248971457295718, -1.1300158286699407`}, {
       2.248971457295718, -1.1300158286699407`}}, {{
       2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}, {{
       2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}, {{
       2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}, {{
       2.3161742659339177`, -1.1507807228351548`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.3161742659339177`, -1.1507807228351548`}, {
       2.3161742659339177`, -1.1507807228351548`}}, {{
       2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}, {{
       2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}, {{
       2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}, {{
       2.367758596106988, -1.1985976152388929`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.3953656918080974`, -1.2879442959730592`}, {
       2.367758596106988, -1.1985976152388929`}, {
       2.367758596106988, -1.1985976152388929`}}, {{
       2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.1360185284934627`, -0.5568514435778976}, {
       2.1360185284934627`, -0.5568514435778976}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}, {{
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}, {{
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.136018528493463, -0.8434037329586608}, {
       2.136018528493463, -0.8434037329586608}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}, {{
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}, {{
       2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}, {{
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}, {{
       2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}, {{
       2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}, {{
       2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}, {{
       2.1360185284934627`, -0.8434037329586607}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}}, {{
       2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}, {{
       2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}, {{
       2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}, {{
       2.0696125097306277`, -0.77176566061347}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.77176566061347}, {
       2.0696125097306277`, -0.77176566061347}}, {{
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}, {{
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}, {{
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}, {{
       2.0532980077880194`, -0.7001275882682791}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0532980077880194`, -0.7001275882682791}, {
       2.0532980077880194`, -0.7001275882682791}}, {{
       2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}, {{
       2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}, {{
       2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}, {{
       2.0696125097306277`, -0.6284895159230883}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}, {
       2.0696125097306277`, -0.6284895159230883}, {
       2.0696125097306277`, -0.6284895159230883}}, {{
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}, {{
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}, {{
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}, {{
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}}, {{
       2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}, {{
       2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}, {{
       2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}, {{
       2.3553427094621284`, -0.7934559236536758}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3553427094621284`, -0.7934559236536758}, {
       2.3553427094621284`, -0.7934559236536758}}, {{
       2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}, {{
       2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}, {{
       2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}, {{
       2.3014595699043503`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}, {
       2.3014595699043503`, -0.8434037329586607}, {
       2.3014595699043503`, -0.8434037329586607}}, {{
       2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}, {{
       2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}, {{
       2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}, {{
       2.231261928403963, -0.8650939959988666}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.1360185284934627`, -0.8434037329586607}, {
       2.231261928403963, -0.8650939959988666}, {
       2.231261928403963, -0.8650939959988666}}, {{
       2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}, {{
       2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}, {{
       2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}, {{
       2.136018528493463, -0.5568514435778975}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}, {
       2.136018528493463, -0.5568514435778975}, {
       2.136018528493463, -0.5568514435778975}}, {{
       2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}, {{
       2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}, {{
       2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}, {{
       2.231261928403963, -0.5351611805376917}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.231261928403963, -0.5351611805376917}, {
       2.231261928403963, -0.5351611805376917}}, {{
       2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}, {{
       2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}, {{
       2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}, {{
       2.3014595699043503`, -0.5568514435778976}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3014595699043503`, -0.5568514435778976}, {
       2.3014595699043503`, -0.5568514435778976}}, {{
       2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}, {{
       2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}, {{
       2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}, {{
       2.3553427094621284`, -0.6067992528828825}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3841800906097936`, -0.7001275882682791}, {
       2.3553427094621284`, -0.6067992528828825}, {
       2.3553427094621284`, -0.6067992528828825}}, {{
       2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}, {{
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}, {{
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}, {{
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}, {{
       2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}, {{
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}, {{
       2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}, {{
       2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}, {{
       2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}, {{
       2.189342467951618, -0.41737209078516563`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}}, {{
       2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}, {{
       2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}, {{
       2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}, {{
       2.1255970146302, -0.34860420676209203`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.34860420676209203`}, {
       2.1255970146302, -0.34860420676209203`}}, {{
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}, {{
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}, {{
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}, {{
       2.109936155246973, -0.27983632273901843`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.109936155246973, -0.27983632273901843`}, {
       2.109936155246973, -0.27983632273901843`}}, {{
       2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}, {{
       2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}, {{
       2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}, {{
       2.1255970146302, -0.21106843871594483`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.1255970146302, -0.21106843871594483`}, {
       2.1255970146302, -0.21106843871594483`}}, {{
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}, {{
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}, {{
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}, {{
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}}, {{
       2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}, {{
       2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}, {{
       2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}, {{
       2.3998793981977777`, -0.369425446702658}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3998793981977777`, -0.369425446702658}, {
       2.3998793981977777`, -0.369425446702658}}, {{
       2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}, {{
       2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}, {{
       2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}, {{
       2.3481550933609077`, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.3481550933609077`, -0.41737209078516563`}, {
       2.3481550933609077`, -0.41737209078516563`}}, {{
       2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}, {{
       2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}, {{
       2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}, {{
       2.2807699291408103`, -0.4381933307257316}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.189342467951618, -0.41737209078516563`}, {
       2.2807699291408103`, -0.4381933307257316}, {
       2.2807699291408103`, -0.4381933307257316}}, {{
       2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}, {{
       2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}, {{
       2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}, {{
       2.189342467951618, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.189342467951618, -0.14230055469287123`}, {
       2.189342467951618, -0.14230055469287123`}}, {{
       2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}, {{
       2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}, {{
       2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}, {{
       2.2807699291408103`, -0.12147931475230528`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.2807699291408103`, -0.12147931475230528`}, {
       2.2807699291408103`, -0.12147931475230528`}}, {{
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}, {{
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}, {{
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}, {{
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3481550933609077`, -0.14230055469287123`}, {
       2.3481550933609077`, -0.14230055469287123`}}, {{
       2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}, {{
       2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}, {{
       2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}, {{
       2.3998793981977777`, -0.19024719877537888`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.4275614060655526`, -0.27983632273901843`}, {
       2.3998793981977777`, -0.19024719877537888`}, {
       2.3998793981977777`, -0.19024719877537888`}}, {{2.142432594166141, 
       0.1734570629829672}, {2.094118305373655, 0.22557797883223382`}, {
       2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.3298198105307671}, {2.142432594166141, 0.3819407263800337}, {
       2.142432594166141, 0.3819407263800337}, {2.094118305373655, 
       0.3298198105307671}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.2255779788322338}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}}, {{
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}, {{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.21172777575636, 0.15767611944752985`}, {
       2.142432594166141, 0.17345706298296718`}, {2.142432594166141, 
       0.17345706298296718`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}, {{2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}}, {{
       2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.262800693350077, 0.3819407263800337}, {
       2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.262800693350077, 
       0.3819407263800337}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}, {{2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}}, {{2.142432594166141, 
       0.1734570629829672}, {2.094118305373655, 0.22557797883223382`}, {
       2.094118305373655, 0.22557797883223382`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}}, {{
       2.142432594166141, 0.1734570629829672}, {2.094118305373655, 
       0.22557797883223382`}, {2.094118305373655, 0.22557797883223382`}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}}, {{2.142432594166141, 0.1734570629829672}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}, {2.142432594166141, 0.1734570629829672}, {
       2.142432594166141, 0.1734570629829672}}, {{2.142432594166141, 
       0.1734570629829672}, {2.094118305373655, 0.22557797883223382`}, {
       2.094118305373655, 0.22557797883223382`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}}, {{
       2.094118305373655, 0.22557797883223382`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}}, {{2.094118305373655, 0.22557797883223382`}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}, {2.094118305373655, 0.22557797883223382`}, {
       2.094118305373655, 0.22557797883223382`}}, {{2.094118305373655, 
       0.22557797883223382`}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.22557797883223382`}, {2.094118305373655, 0.22557797883223382`}}, {{
       2.094118305373655, 0.22557797883223382`}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.22557797883223382`}, {2.094118305373655, 
       0.22557797883223382`}}, {{2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}}, {{2.082248544574173, 
       0.27769889468150044`}, {2.094118305373655, 0.3298198105307671}, {
       2.094118305373655, 0.3298198105307671}, {2.082248544574173, 
       0.27769889468150044`}, {2.082248544574173, 0.27769889468150044`}}, {{
       2.082248544574173, 0.27769889468150044`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}, {
       2.082248544574173, 0.27769889468150044`}, {2.082248544574173, 
       0.27769889468150044`}}, {{2.082248544574173, 0.27769889468150044`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}, {2.082248544574173, 0.27769889468150044`}, {
       2.082248544574173, 0.27769889468150044`}}, {{2.094118305373655, 
       0.3298198105307671}, {2.142432594166141, 0.38194072638003373`}, {
       2.142432594166141, 0.38194072638003373`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}}, {{
       2.094118305373655, 0.3298198105307671}, {2.142432594166141, 
       0.38194072638003373`}, {2.142432594166141, 0.38194072638003373`}, {
       2.094118305373655, 0.3298198105307671}, {2.094118305373655, 
       0.3298198105307671}}, {{2.094118305373655, 0.3298198105307671}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}, {2.094118305373655, 0.3298198105307671}, {
       2.094118305373655, 0.3298198105307671}}, {{2.094118305373655, 
       0.3298198105307671}, {2.142432594166141, 0.38194072638003373`}, {
       2.142432594166141, 0.38194072638003373`}, {2.094118305373655, 
       0.3298198105307671}, {2.094118305373655, 0.3298198105307671}}, {{
       2.3229847429420447`, 0.27769889468150044`}, {2.302003850144312, 
       0.2097970352967965}, {2.302003850144312, 0.2097970352967965}, {
       2.3229847429420447`, 0.27769889468150044`}, {2.3229847429420447`, 
       0.27769889468150044`}}, {{2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}}, {{2.3229847429420447`, 
       0.27769889468150044`}, {2.302003850144312, 0.2097970352967965}, {
       2.302003850144312, 0.2097970352967965}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}}, {{
       2.3229847429420447`, 0.27769889468150044`}, {2.302003850144312, 
       0.2097970352967965}, {2.302003850144312, 0.2097970352967965}, {
       2.3229847429420447`, 0.27769889468150044`}, {2.3229847429420447`, 
       0.27769889468150044`}}, {{2.302003850144312, 0.2097970352967965}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.302003850144312, 0.2097970352967965}, {
       2.302003850144312, 0.2097970352967965}}, {{2.302003850144312, 
       0.2097970352967965}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}, {2.302003850144312, 
       0.2097970352967965}, {2.302003850144312, 0.2097970352967965}}, {{
       2.302003850144312, 0.2097970352967965}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}, {
       2.302003850144312, 0.2097970352967965}, {2.302003850144312, 
       0.2097970352967965}}, {{2.302003850144312, 0.2097970352967965}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}, {2.302003850144312, 0.2097970352967965}, {
       2.302003850144312, 0.2097970352967965}}, {{2.262800693350077, 
       0.1734570629829672}, {2.21172777575636, 0.15767611944752985`}, {
       2.21172777575636, 0.15767611944752985`}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}}, {{
       2.262800693350077, 0.1734570629829672}, {2.21172777575636, 
       0.15767611944752985`}, {2.21172777575636, 0.15767611944752985`}, {
       2.262800693350077, 0.1734570629829672}, {2.262800693350077, 
       0.1734570629829672}}, {{2.262800693350077, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}, {2.262800693350077, 0.1734570629829672}, {
       2.262800693350077, 0.1734570629829672}}, {{2.262800693350077, 
       0.1734570629829672}, {2.21172777575636, 0.15767611944752985`}, {
       2.21172777575636, 0.15767611944752985`}, {2.262800693350077, 
       0.1734570629829672}, {2.262800693350077, 0.1734570629829672}}, {{
       2.21172777575636, 0.15767611944752985`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}}, {{2.21172777575636, 0.15767611944752985`}, {
       2.142432594166141, 0.1734570629829672}, {2.142432594166141, 
       0.1734570629829672}, {2.21172777575636, 0.15767611944752985`}, {
       2.21172777575636, 0.15767611944752985`}}, {{2.21172777575636, 
       0.15767611944752985`}, {2.142432594166141, 0.1734570629829672}, {
       2.142432594166141, 0.1734570629829672}, {2.21172777575636, 
       0.15767611944752985`}, {2.21172777575636, 0.15767611944752985`}}, {{
       2.21172777575636, 0.15767611944752985`}, {2.142432594166141, 
       0.1734570629829672}, {2.142432594166141, 0.1734570629829672}, {
       2.21172777575636, 0.15767611944752985`}, {2.21172777575636, 
       0.15767611944752985`}}, {{2.142432594166141, 0.38194072638003373`}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}, {2.142432594166141, 0.38194072638003373`}, {
       2.142432594166141, 0.38194072638003373`}}, {{2.142432594166141, 
       0.38194072638003373`}, {2.21172777575636, 0.39772166991547103`}, {
       2.21172777575636, 0.39772166991547103`}, {2.142432594166141, 
       0.38194072638003373`}, {2.142432594166141, 0.38194072638003373`}}, {{
       2.142432594166141, 0.38194072638003373`}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}, {
       2.142432594166141, 0.38194072638003373`}, {2.142432594166141, 
       0.38194072638003373`}}, {{2.142432594166141, 0.38194072638003373`}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}, {2.142432594166141, 0.38194072638003373`}, {
       2.142432594166141, 0.38194072638003373`}}, {{2.21172777575636, 
       0.39772166991547103`}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}}, {{
       2.21172777575636, 0.39772166991547103`}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}, {
       2.21172777575636, 0.39772166991547103`}, {2.21172777575636, 
       0.39772166991547103`}}, {{2.21172777575636, 0.39772166991547103`}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}, {2.21172777575636, 0.39772166991547103`}, {
       2.21172777575636, 0.39772166991547103`}}, {{2.21172777575636, 
       0.39772166991547103`}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}, {2.21172777575636, 
       0.39772166991547103`}, {2.21172777575636, 0.39772166991547103`}}, {{
       2.262800693350077, 0.3819407263800337}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}, {{2.262800693350077, 0.3819407263800337}, {
       2.302003850144312, 0.3456007540662044}, {2.302003850144312, 
       0.3456007540662044}, {2.262800693350077, 0.3819407263800337}, {
       2.262800693350077, 0.3819407263800337}}, {{2.262800693350077, 
       0.3819407263800337}, {2.302003850144312, 0.3456007540662044}, {
       2.302003850144312, 0.3456007540662044}, {2.262800693350077, 
       0.3819407263800337}, {2.262800693350077, 0.3819407263800337}}, {{
       2.262800693350077, 0.3819407263800337}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}, {
       2.262800693350077, 0.3819407263800337}, {2.262800693350077, 
       0.3819407263800337}}, {{2.302003850144312, 0.3456007540662044}, {
       2.3229847429420447`, 0.27769889468150044`}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.302003850144312, 0.3456007540662044}, {
       2.302003850144312, 0.3456007540662044}}, {{2.302003850144312, 
       0.3456007540662044}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.3229847429420447`, 0.27769889468150044`}, {2.302003850144312, 
       0.3456007540662044}, {2.302003850144312, 0.3456007540662044}}, {{
       2.302003850144312, 0.3456007540662044}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.3229847429420447`, 0.27769889468150044`}, {
       2.302003850144312, 0.3456007540662044}, {2.302003850144312, 
       0.3456007540662044}}, {{2.302003850144312, 0.3456007540662044}, {
       2.3229847429420447`, 0.27769889468150044`}, {2.3229847429420447`, 
       0.27769889468150044`}, {2.302003850144312, 0.3456007540662044}, {
       2.302003850144312, 0.3456007540662044}}, {{2.2291699102503326`, 
       0.6891462206629825}, {2.1797864462122365`, 0.7424205508415777}, {
       2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.848969211198768}, {2.2291699102503326`, 0.9022435413773632}, {
       2.2291699102503326`, 0.9022435413773632}, {2.1797864462122365`, 
       0.848969211198768}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}}, {{
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}, {{2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.7262903815470088}, {2.352201705728368, 
       0.6891462206629825}, {2.299998565573644, 0.6730160513684136}, {
       2.2291699102503326`, 0.6891462206629825}, {2.2291699102503326`, 
       0.6891462206629825}, {2.299998565573644, 0.6730160513684136}, {
       2.352201705728368, 0.6891462206629825}, {2.392272412182171, 
       0.7262903815470088}, {2.413717603467386, 0.7956948810201728}, {
       2.413717603467386, 0.7956948810201728}}, {{2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}}, {{
       2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.352201705728368, 0.9022435413773632}, {
       2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.352201705728368, 
       0.9022435413773632}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}, {{2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}}, {{2.2291699102503326`, 
       0.6891462206629825}, {2.1797864462122365`, 0.7424205508415777}, {
       2.1797864462122365`, 0.7424205508415777}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}}, {{
       2.2291699102503326`, 0.6891462206629825}, {2.1797864462122365`, 
       0.7424205508415777}, {2.1797864462122365`, 0.7424205508415777}, {
       2.2291699102503326`, 0.6891462206629825}, {2.2291699102503326`, 
       0.6891462206629825}}, {{2.2291699102503326`, 0.6891462206629825}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}}, {{2.2291699102503326`, 
       0.6891462206629825}, {2.1797864462122365`, 0.7424205508415777}, {
       2.1797864462122365`, 0.7424205508415777}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}}, {{
       2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}}, {{2.1797864462122365`, 0.7424205508415777}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}, {2.1797864462122365`, 0.7424205508415777}, {
       2.1797864462122365`, 0.7424205508415777}}, {{2.1797864462122365`, 
       0.7424205508415777}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.7424205508415777}, {2.1797864462122365`, 0.7424205508415777}}, {{
       2.1797864462122365`, 0.7424205508415777}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.7424205508415777}, {2.1797864462122365`, 
       0.7424205508415777}}, {{2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}}, {{2.167654012511315, 
       0.7956948810201728}, {2.1797864462122365`, 0.848969211198768}, {
       2.1797864462122365`, 0.848969211198768}, {2.167654012511315, 
       0.7956948810201728}, {2.167654012511315, 0.7956948810201728}}, {{
       2.167654012511315, 0.7956948810201728}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}, {
       2.167654012511315, 0.7956948810201728}, {2.167654012511315, 
       0.7956948810201728}}, {{2.167654012511315, 0.7956948810201728}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}, {2.167654012511315, 0.7956948810201728}, {
       2.167654012511315, 0.7956948810201728}}, {{2.1797864462122365`, 
       0.848969211198768}, {2.2291699102503326`, 0.9022435413773632}, {
       2.2291699102503326`, 0.9022435413773632}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}}, {{
       2.1797864462122365`, 0.848969211198768}, {2.2291699102503326`, 
       0.9022435413773632}, {2.2291699102503326`, 0.9022435413773632}, {
       2.1797864462122365`, 0.848969211198768}, {2.1797864462122365`, 
       0.848969211198768}}, {{2.1797864462122365`, 0.848969211198768}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}, {2.1797864462122365`, 0.848969211198768}, {
       2.1797864462122365`, 0.848969211198768}}, {{2.1797864462122365`, 
       0.848969211198768}, {2.2291699102503326`, 0.9022435413773632}, {
       2.2291699102503326`, 0.9022435413773632}, {2.1797864462122365`, 
       0.848969211198768}, {2.1797864462122365`, 0.848969211198768}}, {{
       2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}, {{2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.7262903815470088}, {2.392272412182171, 
       0.7262903815470088}, {2.413717603467386, 0.7956948810201728}, {
       2.413717603467386, 0.7956948810201728}}, {{2.413717603467386, 
       0.7956948810201728}, {2.392272412182171, 0.7262903815470088}, {
       2.392272412182171, 0.7262903815470088}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}}, {{
       2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}}, {{2.392272412182171, 0.7262903815470088}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.392272412182171, 0.7262903815470088}, {
       2.392272412182171, 0.7262903815470088}}, {{2.392272412182171, 
       0.7262903815470088}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}, {2.392272412182171, 
       0.7262903815470088}, {2.392272412182171, 0.7262903815470088}}, {{
       2.392272412182171, 0.7262903815470088}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}, {
       2.392272412182171, 0.7262903815470088}, {2.392272412182171, 
       0.7262903815470088}}, {{2.392272412182171, 0.7262903815470088}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}, {2.392272412182171, 0.7262903815470088}, {
       2.392272412182171, 0.7262903815470088}}, {{2.352201705728368, 
       0.6891462206629825}, {2.299998565573644, 0.6730160513684136}, {
       2.299998565573644, 0.6730160513684136}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}}, {{
       2.352201705728368, 0.6891462206629825}, {2.299998565573644, 
       0.6730160513684136}, {2.299998565573644, 0.6730160513684136}, {
       2.352201705728368, 0.6891462206629825}, {2.352201705728368, 
       0.6891462206629825}}, {{2.352201705728368, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}, {2.352201705728368, 0.6891462206629825}, {
       2.352201705728368, 0.6891462206629825}}, {{2.352201705728368, 
       0.6891462206629825}, {2.299998565573644, 0.6730160513684136}, {
       2.299998565573644, 0.6730160513684136}, {2.352201705728368, 
       0.6891462206629825}, {2.352201705728368, 0.6891462206629825}}, {{
       2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}}, {{2.299998565573644, 0.6730160513684136}, {
       2.2291699102503326`, 0.6891462206629825}, {2.2291699102503326`, 
       0.6891462206629825}, {2.299998565573644, 0.6730160513684136}, {
       2.299998565573644, 0.6730160513684136}}, {{2.299998565573644, 
       0.6730160513684136}, {2.2291699102503326`, 0.6891462206629825}, {
       2.2291699102503326`, 0.6891462206629825}, {2.299998565573644, 
       0.6730160513684136}, {2.299998565573644, 0.6730160513684136}}, {{
       2.299998565573644, 0.6730160513684136}, {2.2291699102503326`, 
       0.6891462206629825}, {2.2291699102503326`, 0.6891462206629825}, {
       2.299998565573644, 0.6730160513684136}, {2.299998565573644, 
       0.6730160513684136}}, {{2.2291699102503326`, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}, {2.2291699102503326`, 0.9022435413773632}, {
       2.2291699102503326`, 0.9022435413773632}}, {{2.2291699102503326`, 
       0.9022435413773632}, {2.299998565573644, 0.9183737106719321}, {
       2.299998565573644, 0.9183737106719321}, {2.2291699102503326`, 
       0.9022435413773632}, {2.2291699102503326`, 0.9022435413773632}}, {{
       2.2291699102503326`, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}, {
       2.2291699102503326`, 0.9022435413773632}, {2.2291699102503326`, 
       0.9022435413773632}}, {{2.2291699102503326`, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}, {2.2291699102503326`, 0.9022435413773632}, {
       2.2291699102503326`, 0.9022435413773632}}, {{2.299998565573644, 
       0.9183737106719321}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}}, {{
       2.299998565573644, 0.9183737106719321}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}, {
       2.299998565573644, 0.9183737106719321}, {2.299998565573644, 
       0.9183737106719321}}, {{2.299998565573644, 0.9183737106719321}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}, {2.299998565573644, 0.9183737106719321}, {
       2.299998565573644, 0.9183737106719321}}, {{2.299998565573644, 
       0.9183737106719321}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}, {2.299998565573644, 
       0.9183737106719321}, {2.299998565573644, 0.9183737106719321}}, {{
       2.352201705728368, 0.9022435413773632}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}, {{2.352201705728368, 0.9022435413773632}, {
       2.392272412182171, 0.8650993804933369}, {2.392272412182171, 
       0.8650993804933369}, {2.352201705728368, 0.9022435413773632}, {
       2.352201705728368, 0.9022435413773632}}, {{2.352201705728368, 
       0.9022435413773632}, {2.392272412182171, 0.8650993804933369}, {
       2.392272412182171, 0.8650993804933369}, {2.352201705728368, 
       0.9022435413773632}, {2.352201705728368, 0.9022435413773632}}, {{
       2.352201705728368, 0.9022435413773632}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}, {
       2.352201705728368, 0.9022435413773632}, {2.352201705728368, 
       0.9022435413773632}}, {{2.392272412182171, 0.8650993804933369}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}, {2.392272412182171, 0.8650993804933369}, {
       2.392272412182171, 0.8650993804933369}}, {{2.392272412182171, 
       0.8650993804933369}, {2.413717603467386, 0.7956948810201728}, {
       2.413717603467386, 0.7956948810201728}, {2.392272412182171, 
       0.8650993804933369}, {2.392272412182171, 0.8650993804933369}}, {{
       2.392272412182171, 0.8650993804933369}, {2.413717603467386, 
       0.7956948810201728}, {2.413717603467386, 0.7956948810201728}, {
       2.392272412182171, 0.8650993804933369}, {2.392272412182171, 
       0.8650993804933369}}, {{2.392272412182171, 0.8650993804933369}, {
       2.413717603467386, 0.7956948810201728}, {2.413717603467386, 
       0.7956948810201728}, {2.392272412182171, 0.8650993804933369}, {
       2.392272412182171, 0.8650993804933369}}, {{2.163703687295601, 
       1.078592341256198}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.163703687295601, 1.36593372501566}, {
       2.163703687295601, 1.36593372501566}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.0807553746641787`, 1.222263033135929}, {
       2.0971148027241178`, 1.1504276871960635`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}}, {{
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}, {{2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.329600312558446, 
       1.078592341256198}, {2.259209364054909, 1.0568423485775569`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}, {2.259209364054909, 1.0568423485775569`}, {
       2.329600312558446, 1.078592341256198}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.412548625189868, 1.222263033135929}, {
       2.412548625189868, 1.222263033135929}}, {{2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}}, {{
       2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.329600312558446, 1.36593372501566}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868, 
       1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.329600312558446, 
       1.36593372501566}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}, {{2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}}, {{2.163703687295601, 
       1.078592341256198}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}}, {{
       2.163703687295601, 1.078592341256198}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}}, {{2.163703687295601, 1.078592341256198}, {
       2.0971148027241178`, 1.1504276871960635`}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.163703687295601, 1.078592341256198}, {
       2.163703687295601, 1.078592341256198}}, {{2.163703687295601, 
       1.078592341256198}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}}, {{
       2.0971148027241178`, 1.1504276871960635`}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0971148027241178`, 1.1504276871960635`}, {2.0971148027241178`, 
       1.1504276871960635`}}, {{2.0971148027241178`, 1.1504276871960635`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.1504276871960635`}, {
       2.0971148027241178`, 1.1504276871960635`}}, {{2.0971148027241178`, 
       1.1504276871960635`}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`, 
       1.1504276871960635`}, {2.0971148027241178`, 1.1504276871960635`}}, {{
       2.0971148027241178`, 1.1504276871960635`}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}, {
       2.0971148027241178`, 1.1504276871960635`}, {2.0971148027241178`, 
       1.1504276871960635`}}, {{2.0807553746641787`, 1.222263033135929}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}}, {{2.0807553746641787`, 
       1.222263033135929}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0807553746641787`, 
       1.222263033135929}, {2.0807553746641787`, 1.222263033135929}}, {{
       2.0807553746641787`, 1.222263033135929}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0807553746641787`, 1.222263033135929}, {2.0807553746641787`, 
       1.222263033135929}}, {{2.0807553746641787`, 1.222263033135929}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.0807553746641787`, 1.222263033135929}, {
       2.0807553746641787`, 1.222263033135929}}, {{2.0971148027241178`, 
       1.2940983790757945`}, {2.163703687295601, 1.36593372501566}, {
       2.163703687295601, 1.36593372501566}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}}, {{
       2.0971148027241178`, 1.2940983790757945`}, {2.163703687295601, 
       1.36593372501566}, {2.163703687295601, 1.36593372501566}, {
       2.0971148027241178`, 1.2940983790757945`}, {2.0971148027241178`, 
       1.2940983790757945`}}, {{2.0971148027241178`, 1.2940983790757945`}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}, {2.0971148027241178`, 1.2940983790757945`}, {
       2.0971148027241178`, 1.2940983790757945`}}, {{2.0971148027241178`, 
       1.2940983790757945`}, {2.163703687295601, 1.36593372501566}, {
       2.163703687295601, 1.36593372501566}, {2.0971148027241178`, 
       1.2940983790757945`}, {2.0971148027241178`, 1.2940983790757945`}}, {{
       2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}, {{2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.412548625189868, 1.222263033135929}, {
       2.412548625189868, 1.222263033135929}}, {{2.412548625189868, 
       1.222263033135929}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.412548625189868, 
       1.222263033135929}, {2.412548625189868, 1.222263033135929}}, {{
       2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}}, {{2.3836318330020427`, 1.1286776945174224`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.3836318330020427`, 1.1286776945174224`}}, {{2.3836318330020427`, 
       1.1286776945174224`}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}, {2.3836318330020427`, 
       1.1286776945174224`}, {2.3836318330020427`, 1.1286776945174224`}}, {{
       2.3836318330020427`, 1.1286776945174224`}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}, {
       2.3836318330020427`, 1.1286776945174224`}, {2.3836318330020427`, 
       1.1286776945174224`}}, {{2.3836318330020427`, 1.1286776945174224`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}, {2.3836318330020427`, 1.1286776945174224`}, {
       2.3836318330020427`, 1.1286776945174224`}}, {{2.329600312558446, 
       1.078592341256198}, {2.259209364054909, 1.0568423485775569`}, {
       2.259209364054909, 1.0568423485775569`}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}}, {{
       2.329600312558446, 1.078592341256198}, {2.259209364054909, 
       1.0568423485775569`}, {2.259209364054909, 1.0568423485775569`}, {
       2.329600312558446, 1.078592341256198}, {2.329600312558446, 
       1.078592341256198}}, {{2.329600312558446, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}, {2.329600312558446, 1.078592341256198}, {
       2.329600312558446, 1.078592341256198}}, {{2.329600312558446, 
       1.078592341256198}, {2.259209364054909, 1.0568423485775569`}, {
       2.259209364054909, 1.0568423485775569`}, {2.329600312558446, 
       1.078592341256198}, {2.329600312558446, 1.078592341256198}}, {{
       2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}}, {{2.259209364054909, 1.0568423485775569`}, {
       2.163703687295601, 1.078592341256198}, {2.163703687295601, 
       1.078592341256198}, {2.259209364054909, 1.0568423485775569`}, {
       2.259209364054909, 1.0568423485775569`}}, {{2.259209364054909, 
       1.0568423485775569`}, {2.163703687295601, 1.078592341256198}, {
       2.163703687295601, 1.078592341256198}, {2.259209364054909, 
       1.0568423485775569`}, {2.259209364054909, 1.0568423485775569`}}, {{
       2.259209364054909, 1.0568423485775569`}, {2.163703687295601, 
       1.078592341256198}, {2.163703687295601, 1.078592341256198}, {
       2.259209364054909, 1.0568423485775569`}, {2.259209364054909, 
       1.0568423485775569`}}, {{2.163703687295601, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}, {2.163703687295601, 1.36593372501566}, {
       2.163703687295601, 1.36593372501566}}, {{2.163703687295601, 
       1.36593372501566}, {2.259209364054909, 1.387683717694301}, {
       2.259209364054909, 1.387683717694301}, {2.163703687295601, 
       1.36593372501566}, {2.163703687295601, 1.36593372501566}}, {{
       2.163703687295601, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}, {
       2.163703687295601, 1.36593372501566}, {2.163703687295601, 
       1.36593372501566}}, {{2.163703687295601, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}, {2.163703687295601, 1.36593372501566}, {
       2.163703687295601, 1.36593372501566}}, {{2.259209364054909, 
       1.387683717694301}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}}, {{
       2.259209364054909, 1.387683717694301}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}, {
       2.259209364054909, 1.387683717694301}, {2.259209364054909, 
       1.387683717694301}}, {{2.259209364054909, 1.387683717694301}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}, {2.259209364054909, 1.387683717694301}, {
       2.259209364054909, 1.387683717694301}}, {{2.259209364054909, 
       1.387683717694301}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}, {2.259209364054909, 
       1.387683717694301}, {2.259209364054909, 1.387683717694301}}, {{
       2.329600312558446, 1.36593372501566}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}, {{2.329600312558446, 1.36593372501566}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.329600312558446, 1.36593372501566}, {
       2.329600312558446, 1.36593372501566}}, {{2.329600312558446, 
       1.36593372501566}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.329600312558446, 
       1.36593372501566}, {2.329600312558446, 1.36593372501566}}, {{
       2.329600312558446, 1.36593372501566}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.329600312558446, 1.36593372501566}, {2.329600312558446, 
       1.36593372501566}}, {{2.3836318330020427`, 1.3158483717544356`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.3836318330020427`, 1.3158483717544356`}}, {{2.3836318330020427`, 
       1.3158483717544356`}, {2.412548625189868, 1.222263033135929}, {
       2.412548625189868, 1.222263033135929}, {2.3836318330020427`, 
       1.3158483717544356`}, {2.3836318330020427`, 1.3158483717544356`}}, {{
       2.3836318330020427`, 1.3158483717544356`}, {2.412548625189868, 
       1.222263033135929}, {2.412548625189868, 1.222263033135929}, {
       2.3836318330020427`, 1.3158483717544356`}, {2.3836318330020427`, 
       1.3158483717544356`}}, {{2.3836318330020427`, 1.3158483717544356`}, {
       2.412548625189868, 1.222263033135929}, {2.412548625189868, 
       1.222263033135929}, {2.3836318330020427`, 1.3158483717544356`}, {
       2.3836318330020427`, 1.3158483717544356`}}, {{2.220879893889163, 
       1.653768181760945}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`, 
       1.829952976718999}, {2.220879893889163, 1.8886812417050172`}, {
       2.220879893889163, 1.8886812417050172`}, {2.1664408206575665`, 
       1.829952976718999}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}}, {{
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}, {{2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.694714958862928}, {2.3565070122840317`, 
       1.653768181760945}, {2.298959599903037, 1.63598669387691}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}, {2.298959599903037, 1.63598669387691}, {
       2.3565070122840317`, 1.653768181760945}, {2.400679938699189, 
       1.694714958862928}, {2.424320571481466, 1.7712247117329811`}, {
       2.424320571481466, 1.7712247117329811`}}, {{2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}}, {{
       2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}, {{2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}}, {{2.220879893889163, 
       1.653768181760945}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}}, {{
       2.220879893889163, 1.653768181760945}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}}, {{2.220879893889163, 1.653768181760945}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.220879893889163, 1.653768181760945}, {
       2.220879893889163, 1.653768181760945}}, {{2.220879893889163, 
       1.653768181760945}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}}, {{
       2.1664408206575665`, 1.7124964467469632`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}}, {{2.1664408206575665`, 1.7124964467469632`}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}, {2.1664408206575665`, 1.7124964467469632`}, {
       2.1664408206575665`, 1.7124964467469632`}}, {{2.1664408206575665`, 
       1.7124964467469632`}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`, 
       1.7124964467469632`}, {2.1664408206575665`, 1.7124964467469632`}}, {{
       2.1664408206575665`, 1.7124964467469632`}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.7124964467469632`}, {2.1664408206575665`, 
       1.7124964467469632`}}, {{2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}}, {{2.153066334691729, 
       1.7712247117329811`}, {2.1664408206575665`, 1.829952976718999}, {
       2.1664408206575665`, 1.829952976718999}, {2.153066334691729, 
       1.7712247117329811`}, {2.153066334691729, 1.7712247117329811`}}, {{
       2.153066334691729, 1.7712247117329811`}, {2.1664408206575665`, 
       1.829952976718999}, {2.1664408206575665`, 1.829952976718999}, {
       2.153066334691729, 1.7712247117329811`}, {2.153066334691729, 
       1.7712247117329811`}}, {{2.153066334691729, 1.7712247117329811`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}, {2.153066334691729, 1.7712247117329811`}, {
       2.153066334691729, 1.7712247117329811`}}, {{2.1664408206575665`, 
       1.829952976718999}, {2.220879893889163, 1.8886812417050172`}, {
       2.220879893889163, 1.8886812417050172`}, {2.1664408206575665`, 
       1.829952976718999}, {2.1664408206575665`, 1.829952976718999}}, {{
       2.1664408206575665`, 1.829952976718999}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}, {
       2.1664408206575665`, 1.829952976718999}, {2.1664408206575665`, 
       1.829952976718999}}, {{2.1664408206575665`, 1.829952976718999}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}, {2.1664408206575665`, 1.829952976718999}, {
       2.1664408206575665`, 1.829952976718999}}, {{2.1664408206575665`, 
       1.829952976718999}, {2.220879893889163, 1.8886812417050172`}, {
       2.220879893889163, 1.8886812417050172`}, {2.1664408206575665`, 
       1.829952976718999}, {2.1664408206575665`, 1.829952976718999}}, {{
       2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}, {{2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.694714958862928}, {2.400679938699189, 
       1.694714958862928}, {2.424320571481466, 1.7712247117329811`}, {
       2.424320571481466, 1.7712247117329811`}}, {{2.424320571481466, 
       1.7712247117329811`}, {2.400679938699189, 1.694714958862928}, {
       2.400679938699189, 1.694714958862928}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}}, {{
       2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}}, {{2.400679938699189, 1.694714958862928}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.400679938699189, 1.694714958862928}, {
       2.400679938699189, 1.694714958862928}}, {{2.400679938699189, 
       1.694714958862928}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}, {2.400679938699189, 
       1.694714958862928}, {2.400679938699189, 1.694714958862928}}, {{
       2.400679938699189, 1.694714958862928}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}, {
       2.400679938699189, 1.694714958862928}, {2.400679938699189, 
       1.694714958862928}}, {{2.400679938699189, 1.694714958862928}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}, {2.400679938699189, 1.694714958862928}, {
       2.400679938699189, 1.694714958862928}}, {{2.3565070122840317`, 
       1.653768181760945}, {2.298959599903037, 1.63598669387691}, {
       2.298959599903037, 1.63598669387691}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}}, {{
       2.3565070122840317`, 1.653768181760945}, {2.298959599903037, 
       1.63598669387691}, {2.298959599903037, 1.63598669387691}, {
       2.3565070122840317`, 1.653768181760945}, {2.3565070122840317`, 
       1.653768181760945}}, {{2.3565070122840317`, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}, {2.3565070122840317`, 1.653768181760945}, {
       2.3565070122840317`, 1.653768181760945}}, {{2.3565070122840317`, 
       1.653768181760945}, {2.298959599903037, 1.63598669387691}, {
       2.298959599903037, 1.63598669387691}, {2.3565070122840317`, 
       1.653768181760945}, {2.3565070122840317`, 1.653768181760945}}, {{
       2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}}, {{2.298959599903037, 1.63598669387691}, {
       2.220879893889163, 1.653768181760945}, {2.220879893889163, 
       1.653768181760945}, {2.298959599903037, 1.63598669387691}, {
       2.298959599903037, 1.63598669387691}}, {{2.298959599903037, 
       1.63598669387691}, {2.220879893889163, 1.653768181760945}, {
       2.220879893889163, 1.653768181760945}, {2.298959599903037, 
       1.63598669387691}, {2.298959599903037, 1.63598669387691}}, {{
       2.298959599903037, 1.63598669387691}, {2.220879893889163, 
       1.653768181760945}, {2.220879893889163, 1.653768181760945}, {
       2.298959599903037, 1.63598669387691}, {2.298959599903037, 
       1.63598669387691}}, {{2.220879893889163, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}, {2.220879893889163, 1.8886812417050172`}, {
       2.220879893889163, 1.8886812417050172`}}, {{2.220879893889163, 
       1.8886812417050172`}, {2.298959599903037, 1.9064627295890522`}, {
       2.298959599903037, 1.9064627295890522`}, {2.220879893889163, 
       1.8886812417050172`}, {2.220879893889163, 1.8886812417050172`}}, {{
       2.220879893889163, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}, {
       2.220879893889163, 1.8886812417050172`}, {2.220879893889163, 
       1.8886812417050172`}}, {{2.220879893889163, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}, {2.220879893889163, 1.8886812417050172`}, {
       2.220879893889163, 1.8886812417050172`}}, {{2.298959599903037, 
       1.9064627295890522`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}}, {{
       2.298959599903037, 1.9064627295890522`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.298959599903037, 1.9064627295890522`}, {2.298959599903037, 
       1.9064627295890522`}}, {{2.298959599903037, 1.9064627295890522`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.298959599903037, 1.9064627295890522`}, {
       2.298959599903037, 1.9064627295890522`}}, {{2.298959599903037, 
       1.9064627295890522`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.298959599903037, 
       1.9064627295890522`}, {2.298959599903037, 1.9064627295890522`}}, {{
       2.3565070122840317`, 1.8886812417050172`}, {2.400679938699189, 
       1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}}, {{2.3565070122840317`, 1.8886812417050172`}, {
       2.400679938699189, 1.8477344646030343`}, {2.400679938699189, 
       1.8477344646030343`}, {2.3565070122840317`, 1.8886812417050172`}, {
       2.3565070122840317`, 1.8886812417050172`}}, {{2.3565070122840317`, 
       1.8886812417050172`}, {2.400679938699189, 1.8477344646030343`}, {
       2.400679938699189, 1.8477344646030343`}, {2.3565070122840317`, 
       1.8886812417050172`}, {2.3565070122840317`, 1.8886812417050172`}}, {{
       2.3565070122840317`, 1.8886812417050172`}, {2.400679938699189, 
       1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}, {
       2.3565070122840317`, 1.8886812417050172`}, {2.3565070122840317`, 
       1.8886812417050172`}}, {{2.400679938699189, 1.8477344646030343`}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}, {2.400679938699189, 1.8477344646030343`}, {
       2.400679938699189, 1.8477344646030343`}}, {{2.400679938699189, 
       1.8477344646030343`}, {2.424320571481466, 1.7712247117329811`}, {
       2.424320571481466, 1.7712247117329811`}, {2.400679938699189, 
       1.8477344646030343`}, {2.400679938699189, 1.8477344646030343`}}, {{
       2.400679938699189, 1.8477344646030343`}, {2.424320571481466, 
       1.7712247117329811`}, {2.424320571481466, 1.7712247117329811`}, {
       2.400679938699189, 1.8477344646030343`}, {2.400679938699189, 
       1.8477344646030343`}}, {{2.400679938699189, 1.8477344646030343`}, {
       2.424320571481466, 1.7712247117329811`}, {2.424320571481466, 
       1.7712247117329811`}, {2.400679938699189, 1.8477344646030343`}, {
       2.400679938699189, 1.8477344646030343`}}, {{2.1610676327125864`, 
       2.105837267114838}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.1610676327125864`, 2.351812215497401}, {
       2.1610676327125864`, 2.351812215497401}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.1673310042104785`}, {2.1610676327125864`, 
       2.105837267114838}, {2.1610676327125864`, 2.105837267114838}}, {{
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}}, {{2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.1487121987448226`}, {2.303081335375164, 
       2.105837267114838}, {2.242824056391461, 2.0872184616491816`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}, {2.242824056391461, 2.0872184616491816`}, {
       2.303081335375164, 2.105837267114838}, {2.349334333388394, 
       2.1487121987448226`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.3740881867064525`, 2.2288247413061195`}}, {{2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}}, {{
       2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.303081335375164, 2.351812215497401}, {
       2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`, 
       2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.303081335375164, 
       2.351812215497401}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}, {{2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}}, {{2.1610676327125864`, 
       2.105837267114838}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}, {2.1610676327125864`, 
       2.105837267114838}, {2.1610676327125864`, 2.105837267114838}}, {{
       2.1610676327125864`, 2.105837267114838}, {2.1040650623517703`, 
       2.1673310042104785`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}}, {{2.1610676327125864`, 2.105837267114838}, {
       2.1040650623517703`, 2.1673310042104785`}, {2.1040650623517703`, 
       2.1673310042104785`}, {2.1610676327125864`, 2.105837267114838}, {
       2.1610676327125864`, 2.105837267114838}}, {{2.1610676327125864`, 
       2.105837267114838}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}, {2.1610676327125864`, 
       2.105837267114838}, {2.1610676327125864`, 2.105837267114838}}, {{
       2.1040650623517703`, 2.1673310042104785`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.1673310042104785`}, {2.1040650623517703`, 
       2.1673310042104785`}}, {{2.1040650623517703`, 2.1673310042104785`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.1673310042104785`}, {
       2.1040650623517703`, 2.1673310042104785`}}, {{2.1040650623517703`, 
       2.1673310042104785`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.1040650623517703`, 
       2.1673310042104785`}, {2.1040650623517703`, 2.1673310042104785`}}, {{
       2.1040650623517703`, 2.1673310042104785`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.1673310042104785`}, {2.1040650623517703`, 
       2.1673310042104785`}}, {{2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}, {{2.0900607813812977`, 
       2.2288247413061195`}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.0900607813812977`, 
       2.2288247413061195`}, {2.0900607813812977`, 2.2288247413061195`}}, {{
       2.0900607813812977`, 2.2288247413061195`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.0900607813812977`, 2.2288247413061195`}, {2.0900607813812977`, 
       2.2288247413061195`}}, {{2.0900607813812977`, 2.2288247413061195`}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.0900607813812977`, 2.2288247413061195`}, {
       2.0900607813812977`, 2.2288247413061195`}}, {{2.1040650623517703`, 
       2.2903184784017605`}, {2.1610676327125864`, 2.351812215497401}, {
       2.1610676327125864`, 2.351812215497401}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.1040650623517703`, 2.2903184784017605`}}, {{
       2.1040650623517703`, 2.2903184784017605`}, {2.1610676327125864`, 
       2.351812215497401}, {2.1610676327125864`, 2.351812215497401}, {
       2.1040650623517703`, 2.2903184784017605`}, {2.1040650623517703`, 
       2.2903184784017605`}}, {{2.1040650623517703`, 2.2903184784017605`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}, {2.1040650623517703`, 2.2903184784017605`}, {
       2.1040650623517703`, 2.2903184784017605`}}, {{2.1040650623517703`, 
       2.2903184784017605`}, {2.1610676327125864`, 2.351812215497401}, {
       2.1610676327125864`, 2.351812215497401}, {2.1040650623517703`, 
       2.2903184784017605`}, {2.1040650623517703`, 2.2903184784017605`}}, {{
       2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394, 
       2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}, {{2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.1487121987448226`}, {2.349334333388394, 
       2.1487121987448226`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.3740881867064525`, 2.2288247413061195`}}, {{2.3740881867064525`, 
       2.2288247413061195`}, {2.349334333388394, 2.1487121987448226`}, {
       2.349334333388394, 2.1487121987448226`}, {2.3740881867064525`, 
       2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}}, {{
       2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394, 
       2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}}, {{2.349334333388394, 2.1487121987448226`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.349334333388394, 2.1487121987448226`}, {
       2.349334333388394, 2.1487121987448226`}}, {{2.349334333388394, 
       2.1487121987448226`}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}, {2.349334333388394, 
       2.1487121987448226`}, {2.349334333388394, 2.1487121987448226`}}, {{
       2.349334333388394, 2.1487121987448226`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}, {
       2.349334333388394, 2.1487121987448226`}, {2.349334333388394, 
       2.1487121987448226`}}, {{2.349334333388394, 2.1487121987448226`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}, {2.349334333388394, 2.1487121987448226`}, {
       2.349334333388394, 2.1487121987448226`}}, {{2.303081335375164, 
       2.105837267114838}, {2.242824056391461, 2.0872184616491816`}, {
       2.242824056391461, 2.0872184616491816`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}}, {{
       2.303081335375164, 2.105837267114838}, {2.242824056391461, 
       2.0872184616491816`}, {2.242824056391461, 2.0872184616491816`}, {
       2.303081335375164, 2.105837267114838}, {2.303081335375164, 
       2.105837267114838}}, {{2.303081335375164, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}, {2.303081335375164, 2.105837267114838}, {
       2.303081335375164, 2.105837267114838}}, {{2.303081335375164, 
       2.105837267114838}, {2.242824056391461, 2.0872184616491816`}, {
       2.242824056391461, 2.0872184616491816`}, {2.303081335375164, 
       2.105837267114838}, {2.303081335375164, 2.105837267114838}}, {{
       2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`, 
       2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}}, {{2.242824056391461, 2.0872184616491816`}, {
       2.1610676327125864`, 2.105837267114838}, {2.1610676327125864`, 
       2.105837267114838}, {2.242824056391461, 2.0872184616491816`}, {
       2.242824056391461, 2.0872184616491816`}}, {{2.242824056391461, 
       2.0872184616491816`}, {2.1610676327125864`, 2.105837267114838}, {
       2.1610676327125864`, 2.105837267114838}, {2.242824056391461, 
       2.0872184616491816`}, {2.242824056391461, 2.0872184616491816`}}, {{
       2.242824056391461, 2.0872184616491816`}, {2.1610676327125864`, 
       2.105837267114838}, {2.1610676327125864`, 2.105837267114838}, {
       2.242824056391461, 2.0872184616491816`}, {2.242824056391461, 
       2.0872184616491816`}}, {{2.1610676327125864`, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}, {2.1610676327125864`, 2.351812215497401}, {
       2.1610676327125864`, 2.351812215497401}}, {{2.1610676327125864`, 
       2.351812215497401}, {2.242824056391461, 2.3704310209630575`}, {
       2.242824056391461, 2.3704310209630575`}, {2.1610676327125864`, 
       2.351812215497401}, {2.1610676327125864`, 2.351812215497401}}, {{
       2.1610676327125864`, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}, {
       2.1610676327125864`, 2.351812215497401}, {2.1610676327125864`, 
       2.351812215497401}}, {{2.1610676327125864`, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}, {2.1610676327125864`, 2.351812215497401}, {
       2.1610676327125864`, 2.351812215497401}}, {{2.242824056391461, 
       2.3704310209630575`}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}}, {{
       2.242824056391461, 2.3704310209630575`}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}, {
       2.242824056391461, 2.3704310209630575`}, {2.242824056391461, 
       2.3704310209630575`}}, {{2.242824056391461, 2.3704310209630575`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}, {2.242824056391461, 2.3704310209630575`}, {
       2.242824056391461, 2.3704310209630575`}}, {{2.242824056391461, 
       2.3704310209630575`}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}, {2.242824056391461, 
       2.3704310209630575`}, {2.242824056391461, 2.3704310209630575`}}, {{
       2.303081335375164, 2.351812215497401}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}, {{2.303081335375164, 2.351812215497401}, {
       2.349334333388394, 2.3089372838674165`}, {2.349334333388394, 
       2.3089372838674165`}, {2.303081335375164, 2.351812215497401}, {
       2.303081335375164, 2.351812215497401}}, {{2.303081335375164, 
       2.351812215497401}, {2.349334333388394, 2.3089372838674165`}, {
       2.349334333388394, 2.3089372838674165`}, {2.303081335375164, 
       2.351812215497401}, {2.303081335375164, 2.351812215497401}}, {{
       2.303081335375164, 2.351812215497401}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}, {
       2.303081335375164, 2.351812215497401}, {2.303081335375164, 
       2.351812215497401}}, {{2.349334333388394, 2.3089372838674165`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}, {2.349334333388394, 2.3089372838674165`}, {
       2.349334333388394, 2.3089372838674165`}}, {{2.349334333388394, 
       2.3089372838674165`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.349334333388394, 
       2.3089372838674165`}, {2.349334333388394, 2.3089372838674165`}}, {{
       2.349334333388394, 2.3089372838674165`}, {2.3740881867064525`, 
       2.2288247413061195`}, {2.3740881867064525`, 2.2288247413061195`}, {
       2.349334333388394, 2.3089372838674165`}, {2.349334333388394, 
       2.3089372838674165`}}, {{2.349334333388394, 2.3089372838674165`}, {
       2.3740881867064525`, 2.2288247413061195`}, {2.3740881867064525`, 
       2.2288247413061195`}, {2.349334333388394, 2.3089372838674165`}, {
       2.349334333388394, 2.3089372838674165`}}, {{2.136362568075988, 
       2.666962461712102}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.136362568075988, 2.8927436971920786`}, {
       2.136362568075988, 2.8927436971920786`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.7234077705820963`}, {2.136362568075988, 
       2.666962461712102}, {2.136362568075988, 2.666962461712102}}, {{
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}}, {{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}, {{2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}}, {{
       2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`, 
       2.9098339615821702`}, {2.266717425158318, 2.8927436971920786`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`, 
       2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.266717425158318, 
       2.8927436971920786`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}, {{2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}}, {{2.136362568075988, 
       2.666962461712102}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}, {2.136362568075988, 
       2.666962461712102}, {2.136362568075988, 2.666962461712102}}, {{
       2.136362568075988, 2.666962461712102}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}}, {{2.136362568075988, 2.666962461712102}, {
       2.0840397163131223`, 2.7234077705820963`}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.136362568075988, 2.666962461712102}, {
       2.136362568075988, 2.666962461712102}}, {{2.136362568075988, 
       2.666962461712102}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}, {2.136362568075988, 
       2.666962461712102}, {2.136362568075988, 2.666962461712102}}, {{
       2.0840397163131223`, 2.7234077705820963`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.7234077705820963`}, {2.0840397163131223`, 
       2.7234077705820963`}}, {{2.0840397163131223`, 2.7234077705820963`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.7234077705820963`}, {
       2.0840397163131223`, 2.7234077705820963`}}, {{2.0840397163131223`, 
       2.7234077705820963`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0840397163131223`, 
       2.7234077705820963`}, {2.0840397163131223`, 2.7234077705820963`}}, {{
       2.0840397163131223`, 2.7234077705820963`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.7234077705820963`}, {2.0840397163131223`, 
       2.7234077705820963`}}, {{2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}, {{2.0711851395348226`, 
       2.7798530794520904`}, {2.0840397163131223`, 2.8362983883220845`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0711851395348226`, 
       2.7798530794520904`}, {2.0711851395348226`, 2.7798530794520904`}}, {{
       2.0711851395348226`, 2.7798530794520904`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0840397163131223`, 2.8362983883220845`}, {
       2.0711851395348226`, 2.7798530794520904`}, {2.0711851395348226`, 
       2.7798530794520904`}}, {{2.0711851395348226`, 2.7798530794520904`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0711851395348226`, 2.7798530794520904`}, {
       2.0711851395348226`, 2.7798530794520904`}}, {{2.0840397163131223`, 
       2.8362983883220845`}, {2.136362568075988, 2.8927436971920786`}, {
       2.136362568075988, 2.8927436971920786`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0840397163131223`, 2.8362983883220845`}}, {{
       2.0840397163131223`, 2.8362983883220845`}, {2.136362568075988, 
       2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}, {
       2.0840397163131223`, 2.8362983883220845`}, {2.0840397163131223`, 
       2.8362983883220845`}}, {{2.0840397163131223`, 2.8362983883220845`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}, {2.0840397163131223`, 2.8362983883220845`}, {
       2.0840397163131223`, 2.8362983883220845`}}, {{2.0840397163131223`, 
       2.8362983883220845`}, {2.136362568075988, 2.8927436971920786`}, {
       2.136362568075988, 2.8927436971920786`}, {2.0840397163131223`, 
       2.8362983883220845`}, {2.0840397163131223`, 2.8362983883220845`}}, {{
       2.3318948536994837`, 2.7798530794520904`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3091732081750425`, 2.7063175061920046`}, {
       2.3318948536994837`, 2.7798530794520904`}, {2.3318948536994837`, 
       2.7798530794520904`}}, {{2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}}, {{2.3318948536994837`, 
       2.7798530794520904`}, {2.3091732081750425`, 2.7063175061920046`}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3318948536994837`, 
       2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}}, {{
       2.3318948536994837`, 2.7798530794520904`}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3091732081750425`, 2.7063175061920046`}, {
       2.3318948536994837`, 2.7798530794520904`}, {2.3318948536994837`, 
       2.7798530794520904`}}, {{2.3091732081750425`, 2.7063175061920046`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.3091732081750425`, 2.7063175061920046`}, {
       2.3091732081750425`, 2.7063175061920046`}}, {{2.3091732081750425`, 
       2.7063175061920046`}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}, {2.3091732081750425`, 
       2.7063175061920046`}, {2.3091732081750425`, 2.7063175061920046`}}, {{
       2.3091732081750425`, 2.7063175061920046`}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}, {
       2.3091732081750425`, 2.7063175061920046`}, {2.3091732081750425`, 
       2.7063175061920046`}}, {{2.3091732081750425`, 2.7063175061920046`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}, {2.3091732081750425`, 2.7063175061920046`}, {
       2.3091732081750425`, 2.7063175061920046`}}, {{2.266717425158318, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}}, {{
       2.266717425158318, 2.666962461712102}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.266717425158318, 2.666962461712102}, {2.266717425158318, 
       2.666962461712102}}, {{2.266717425158318, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.266717425158318, 2.666962461712102}, {
       2.266717425158318, 2.666962461712102}}, {{2.266717425158318, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.266717425158318, 
       2.666962461712102}, {2.266717425158318, 2.666962461712102}}, {{
       2.2114070653632947`, 2.6498721973220105`}, {2.136362568075988, 
       2.666962461712102}, {2.136362568075988, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}}, {{2.2114070653632947`, 2.6498721973220105`}, {
       2.136362568075988, 2.666962461712102}, {2.136362568075988, 
       2.666962461712102}, {2.2114070653632947`, 2.6498721973220105`}, {
       2.2114070653632947`, 2.6498721973220105`}}, {{2.2114070653632947`, 
       2.6498721973220105`}, {2.136362568075988, 2.666962461712102}, {
       2.136362568075988, 2.666962461712102}, {2.2114070653632947`, 
       2.6498721973220105`}, {2.2114070653632947`, 2.6498721973220105`}}, {{
       2.2114070653632947`, 2.6498721973220105`}, {2.136362568075988, 
       2.666962461712102}, {2.136362568075988, 2.666962461712102}, {
       2.2114070653632947`, 2.6498721973220105`}, {2.2114070653632947`, 
       2.6498721973220105`}}, {{2.136362568075988, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}, {2.136362568075988, 2.8927436971920786`}, {
       2.136362568075988, 2.8927436971920786`}}, {{2.136362568075988, 
       2.8927436971920786`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.136362568075988, 
       2.8927436971920786`}, {2.136362568075988, 2.8927436971920786`}}, {{
       2.136362568075988, 2.8927436971920786`}, {2.2114070653632947`, 
       2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.136362568075988, 2.8927436971920786`}, {2.136362568075988, 
       2.8927436971920786`}}, {{2.136362568075988, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}, {2.136362568075988, 2.8927436971920786`}, {
       2.136362568075988, 2.8927436971920786`}}, {{2.2114070653632947`, 
       2.9098339615821702`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.2114070653632947`, 
       2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}}, {{
       2.2114070653632947`, 2.9098339615821702`}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}, {
       2.2114070653632947`, 2.9098339615821702`}, {2.2114070653632947`, 
       2.9098339615821702`}}, {{2.2114070653632947`, 2.9098339615821702`}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}, {2.2114070653632947`, 2.9098339615821702`}, {
       2.2114070653632947`, 2.9098339615821702`}}, {{2.2114070653632947`, 
       2.9098339615821702`}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}, {2.2114070653632947`, 
       2.9098339615821702`}, {2.2114070653632947`, 2.9098339615821702`}}, {{
       2.266717425158318, 2.8927436971920786`}, {2.3091732081750425`, 
       2.853388652712176}, {2.3091732081750425`, 2.853388652712176}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}, {{2.266717425158318, 2.8927436971920786`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3091732081750425`, 
       2.853388652712176}, {2.266717425158318, 2.8927436971920786`}, {
       2.266717425158318, 2.8927436971920786`}}, {{2.266717425158318, 
       2.8927436971920786`}, {2.3091732081750425`, 2.853388652712176}, {
       2.3091732081750425`, 2.853388652712176}, {2.266717425158318, 
       2.8927436971920786`}, {2.266717425158318, 2.8927436971920786`}}, {{
       2.266717425158318, 2.8927436971920786`}, {2.3091732081750425`, 
       2.853388652712176}, {2.3091732081750425`, 2.853388652712176}, {
       2.266717425158318, 2.8927436971920786`}, {2.266717425158318, 
       2.8927436971920786`}}, {{2.3091732081750425`, 2.853388652712176}, {
       2.3318948536994837`, 2.7798530794520904`}, {2.3318948536994837`, 
       2.7798530794520904`}, {2.3091732081750425`, 2.853388652712176}, {
       2.3091732081750425`, 2.853388652712176}}, {{2.3091732081750425`, 
       2.853388652712176}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3318948536994837`, 2.7798530794520904`}, {2.3091732081750425`, 
       2.853388652712176}, {2.3091732081750425`, 2.853388652712176}}, {{
       2.3091732081750425`, 2.853388652712176}, {2.3318948536994837`, 
       2.7798530794520904`}, {2.3318948536994837`, 2.7798530794520904`}, {
       2.3091732081750425`, 2.853388652712176}, {2.3091732081750425`, 
       2.853388652712176}}, {{2.3091732081750425`, 2.853388652712176}, {
       2.3318948536994837`, 2.7798530794520904`}, {2.3318948536994837`, 
       2.7798530794520904`}, {2.3091732081750425`, 2.853388652712176}, {
       2.3091732081750425`, 2.853388652712176}}, {{2.1892517173890385`, 
       3.0970481097196063`}, {2.125544106196512, 3.1657751700761247`}, {
       2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.3032292907891616`}, {2.1892517173890385`, 3.37195635114568}, {
       2.1892517173890385`, 3.37195635114568}, {2.125544106196512, 
       3.3032292907891616`}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}}, {{
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}, {{2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.1449662905472344`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.2806249031814727`, 3.076239230190716}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.2806249031814727`, 3.076239230190716}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.427329238173724, 3.234502230432643}, {
       2.427329238173724, 3.234502230432643}}, {{2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}}, {{
       2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.3479700645788286`, 3.37195635114568}, {
       2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}, {{2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}}, {{2.1892517173890385`, 
       3.0970481097196063`}, {2.125544106196512, 3.1657751700761247`}, {
       2.125544106196512, 3.1657751700761247`}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}}, {{
       2.1892517173890385`, 3.0970481097196063`}, {2.125544106196512, 
       3.1657751700761247`}, {2.125544106196512, 3.1657751700761247`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}}, {{2.1892517173890385`, 3.0970481097196063`}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.1892517173890385`, 3.0970481097196063`}}, {{2.1892517173890385`, 
       3.0970481097196063`}, {2.125544106196512, 3.1657751700761247`}, {
       2.125544106196512, 3.1657751700761247`}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}}, {{
       2.125544106196512, 3.1657751700761247`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}}, {{2.125544106196512, 3.1657751700761247`}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}, {2.125544106196512, 3.1657751700761247`}, {
       2.125544106196512, 3.1657751700761247`}}, {{2.125544106196512, 
       3.1657751700761247`}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.1657751700761247`}, {2.125544106196512, 3.1657751700761247`}}, {{
       2.125544106196512, 3.1657751700761247`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.1657751700761247`}, {2.125544106196512, 
       3.1657751700761247`}}, {{2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}}, {{2.109892543794143, 
       3.234502230432643}, {2.125544106196512, 3.3032292907891616`}, {
       2.125544106196512, 3.3032292907891616`}, {2.109892543794143, 
       3.234502230432643}, {2.109892543794143, 3.234502230432643}}, {{
       2.109892543794143, 3.234502230432643}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}, {
       2.109892543794143, 3.234502230432643}, {2.109892543794143, 
       3.234502230432643}}, {{2.109892543794143, 3.234502230432643}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}, {2.109892543794143, 3.234502230432643}, {
       2.109892543794143, 3.234502230432643}}, {{2.125544106196512, 
       3.3032292907891616`}, {2.1892517173890385`, 3.37195635114568}, {
       2.1892517173890385`, 3.37195635114568}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}}, {{
       2.125544106196512, 3.3032292907891616`}, {2.1892517173890385`, 
       3.37195635114568}, {2.1892517173890385`, 3.37195635114568}, {
       2.125544106196512, 3.3032292907891616`}, {2.125544106196512, 
       3.3032292907891616`}}, {{2.125544106196512, 3.3032292907891616`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}, {2.125544106196512, 3.3032292907891616`}, {
       2.125544106196512, 3.3032292907891616`}}, {{2.125544106196512, 
       3.3032292907891616`}, {2.1892517173890385`, 3.37195635114568}, {
       2.1892517173890385`, 3.37195635114568}, {2.125544106196512, 
       3.3032292907891616`}, {2.125544106196512, 3.3032292907891616`}}, {{
       2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}, {{2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.1449662905472344`}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.427329238173724, 3.234502230432643}, {
       2.427329238173724, 3.234502230432643}}, {{2.427329238173724, 
       3.234502230432643}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}}, {{
       2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}}, {{2.3996636635738158`, 3.1449662905472344`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}}, {{2.3996636635738158`, 
       3.1449662905472344`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3996636635738158`, 
       3.1449662905472344`}, {2.3996636635738158`, 3.1449662905472344`}}, {{
       2.3996636635738158`, 3.1449662905472344`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3996636635738158`, 3.1449662905472344`}, {2.3996636635738158`, 
       3.1449662905472344`}}, {{2.3996636635738158`, 3.1449662905472344`}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3996636635738158`, 3.1449662905472344`}, {
       2.3996636635738158`, 3.1449662905472344`}}, {{2.3479700645788286`, 
       3.0970481097196063`}, {2.2806249031814727`, 3.076239230190716}, {
       2.2806249031814727`, 3.076239230190716}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}}, {{
       2.3479700645788286`, 3.0970481097196063`}, {2.2806249031814727`, 
       3.076239230190716}, {2.2806249031814727`, 3.076239230190716}, {
       2.3479700645788286`, 3.0970481097196063`}, {2.3479700645788286`, 
       3.0970481097196063`}}, {{2.3479700645788286`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}, {2.3479700645788286`, 3.0970481097196063`}, {
       2.3479700645788286`, 3.0970481097196063`}}, {{2.3479700645788286`, 
       3.0970481097196063`}, {2.2806249031814727`, 3.076239230190716}, {
       2.2806249031814727`, 3.076239230190716}, {2.3479700645788286`, 
       3.0970481097196063`}, {2.3479700645788286`, 3.0970481097196063`}}, {{
       2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}}, {{2.2806249031814727`, 3.076239230190716}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.2806249031814727`, 3.076239230190716}, {
       2.2806249031814727`, 3.076239230190716}}, {{2.2806249031814727`, 
       3.076239230190716}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.1892517173890385`, 3.0970481097196063`}, {2.2806249031814727`, 
       3.076239230190716}, {2.2806249031814727`, 3.076239230190716}}, {{
       2.2806249031814727`, 3.076239230190716}, {2.1892517173890385`, 
       3.0970481097196063`}, {2.1892517173890385`, 3.0970481097196063`}, {
       2.2806249031814727`, 3.076239230190716}, {2.2806249031814727`, 
       3.076239230190716}}, {{2.1892517173890385`, 3.37195635114568}, {
       2.2806249031814727`, 3.3927652306745704`}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.1892517173890385`, 3.37195635114568}, {
       2.1892517173890385`, 3.37195635114568}}, {{2.1892517173890385`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.2806249031814727`, 3.3927652306745704`}, {2.1892517173890385`, 
       3.37195635114568}, {2.1892517173890385`, 3.37195635114568}}, {{
       2.1892517173890385`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.1892517173890385`, 3.37195635114568}, {2.1892517173890385`, 
       3.37195635114568}}, {{2.1892517173890385`, 3.37195635114568}, {
       2.2806249031814727`, 3.3927652306745704`}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.1892517173890385`, 3.37195635114568}, {
       2.1892517173890385`, 3.37195635114568}}, {{2.2806249031814727`, 
       3.3927652306745704`}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}}, {{
       2.2806249031814727`, 3.3927652306745704`}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}, {
       2.2806249031814727`, 3.3927652306745704`}, {2.2806249031814727`, 
       3.3927652306745704`}}, {{2.2806249031814727`, 3.3927652306745704`}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}, {2.2806249031814727`, 3.3927652306745704`}, {
       2.2806249031814727`, 3.3927652306745704`}}, {{2.2806249031814727`, 
       3.3927652306745704`}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}, {2.2806249031814727`, 
       3.3927652306745704`}, {2.2806249031814727`, 3.3927652306745704`}}, {{
       2.3479700645788286`, 3.37195635114568}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}, {{2.3479700645788286`, 3.37195635114568}, {
       2.3996636635738158`, 3.324038170318052}, {2.3996636635738158`, 
       3.324038170318052}, {2.3479700645788286`, 3.37195635114568}, {
       2.3479700645788286`, 3.37195635114568}}, {{2.3479700645788286`, 
       3.37195635114568}, {2.3996636635738158`, 3.324038170318052}, {
       2.3996636635738158`, 3.324038170318052}, {2.3479700645788286`, 
       3.37195635114568}, {2.3479700645788286`, 3.37195635114568}}, {{
       2.3479700645788286`, 3.37195635114568}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}, {
       2.3479700645788286`, 3.37195635114568}, {2.3479700645788286`, 
       3.37195635114568}}, {{2.3996636635738158`, 3.324038170318052}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}, {2.3996636635738158`, 3.324038170318052}, {
       2.3996636635738158`, 3.324038170318052}}, {{2.3996636635738158`, 
       3.324038170318052}, {2.427329238173724, 3.234502230432643}, {
       2.427329238173724, 3.234502230432643}, {2.3996636635738158`, 
       3.324038170318052}, {2.3996636635738158`, 3.324038170318052}}, {{
       2.3996636635738158`, 3.324038170318052}, {2.427329238173724, 
       3.234502230432643}, {2.427329238173724, 3.234502230432643}, {
       2.3996636635738158`, 3.324038170318052}, {2.3996636635738158`, 
       3.324038170318052}}, {{2.3996636635738158`, 3.324038170318052}, {
       2.427329238173724, 3.234502230432643}, {2.427329238173724, 
       3.234502230432643}, {2.3996636635738158`, 3.324038170318052}, {
       2.3996636635738158`, 3.324038170318052}}, {{2.14719901162296, 
       3.5857430952338682`}, {2.0863825446760766`, 3.651351221426159}, {
       2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.782567473810741}, {2.14719901162296, 3.848175600003032}, {
       2.14719901162296, 3.848175600003032}, {2.0863825446760766`, 
       3.782567473810741}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}}, {{
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}, {{2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.631486679177887}, {2.298714488895545, 
       3.5857430952338682`}, {2.234425549073621, 3.565878552985596}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}, {2.234425549073621, 3.565878552985596}, {
       2.298714488895545, 3.5857430952338682`}, {2.3480621570280595`, 
       3.631486679177887}, {2.374472227531837, 3.71695934761845}, {
       2.374472227531837, 3.71695934761845}}, {{2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}}, {{
       2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.298714488895545, 3.848175600003032}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837, 
       3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.298714488895545, 
       3.848175600003032}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}, {{2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}}, {{2.14719901162296, 
       3.5857430952338682`}, {2.0863825446760766`, 3.651351221426159}, {
       2.0863825446760766`, 3.651351221426159}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}}, {{
       2.14719901162296, 3.5857430952338682`}, {2.0863825446760766`, 
       3.651351221426159}, {2.0863825446760766`, 3.651351221426159}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}}, {{2.14719901162296, 3.5857430952338682`}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}, {2.14719901162296, 3.5857430952338682`}, {
       2.14719901162296, 3.5857430952338682`}}, {{2.14719901162296, 
       3.5857430952338682`}, {2.0863825446760766`, 3.651351221426159}, {
       2.0863825446760766`, 3.651351221426159}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}}, {{
       2.0863825446760766`, 3.651351221426159}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}}, {{2.0863825446760766`, 3.651351221426159}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}, {2.0863825446760766`, 3.651351221426159}, {
       2.0863825446760766`, 3.651351221426159}}, {{2.0863825446760766`, 
       3.651351221426159}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.651351221426159}, {2.0863825446760766`, 3.651351221426159}}, {{
       2.0863825446760766`, 3.651351221426159}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.651351221426159}, {2.0863825446760766`, 
       3.651351221426159}}, {{2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}}, {{2.071441272986668, 
       3.71695934761845}, {2.0863825446760766`, 3.782567473810741}, {
       2.0863825446760766`, 3.782567473810741}, {2.071441272986668, 
       3.71695934761845}, {2.071441272986668, 3.71695934761845}}, {{
       2.071441272986668, 3.71695934761845}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}, {
       2.071441272986668, 3.71695934761845}, {2.071441272986668, 
       3.71695934761845}}, {{2.071441272986668, 3.71695934761845}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}, {2.071441272986668, 3.71695934761845}, {
       2.071441272986668, 3.71695934761845}}, {{2.0863825446760766`, 
       3.782567473810741}, {2.14719901162296, 3.848175600003032}, {
       2.14719901162296, 3.848175600003032}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}}, {{
       2.0863825446760766`, 3.782567473810741}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}, {
       2.0863825446760766`, 3.782567473810741}, {2.0863825446760766`, 
       3.782567473810741}}, {{2.0863825446760766`, 3.782567473810741}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}, {2.0863825446760766`, 3.782567473810741}, {
       2.0863825446760766`, 3.782567473810741}}, {{2.0863825446760766`, 
       3.782567473810741}, {2.14719901162296, 3.848175600003032}, {
       2.14719901162296, 3.848175600003032}, {2.0863825446760766`, 
       3.782567473810741}, {2.0863825446760766`, 3.782567473810741}}, {{
       2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}, {{2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.631486679177887}, {2.3480621570280595`, 
       3.631486679177887}, {2.374472227531837, 3.71695934761845}, {
       2.374472227531837, 3.71695934761845}}, {{2.374472227531837, 
       3.71695934761845}, {2.3480621570280595`, 3.631486679177887}, {
       2.3480621570280595`, 3.631486679177887}, {2.374472227531837, 
       3.71695934761845}, {2.374472227531837, 3.71695934761845}}, {{
       2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}}, {{2.3480621570280595`, 3.631486679177887}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.3480621570280595`, 3.631486679177887}, {
       2.3480621570280595`, 3.631486679177887}}, {{2.3480621570280595`, 
       3.631486679177887}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}, {2.3480621570280595`, 
       3.631486679177887}, {2.3480621570280595`, 3.631486679177887}}, {{
       2.3480621570280595`, 3.631486679177887}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}, {
       2.3480621570280595`, 3.631486679177887}, {2.3480621570280595`, 
       3.631486679177887}}, {{2.3480621570280595`, 3.631486679177887}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}, {2.3480621570280595`, 3.631486679177887}, {
       2.3480621570280595`, 3.631486679177887}}, {{2.298714488895545, 
       3.5857430952338682`}, {2.234425549073621, 3.565878552985596}, {
       2.234425549073621, 3.565878552985596}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}}, {{
       2.298714488895545, 3.5857430952338682`}, {2.234425549073621, 
       3.565878552985596}, {2.234425549073621, 3.565878552985596}, {
       2.298714488895545, 3.5857430952338682`}, {2.298714488895545, 
       3.5857430952338682`}}, {{2.298714488895545, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}, {2.298714488895545, 3.5857430952338682`}, {
       2.298714488895545, 3.5857430952338682`}}, {{2.298714488895545, 
       3.5857430952338682`}, {2.234425549073621, 3.565878552985596}, {
       2.234425549073621, 3.565878552985596}, {2.298714488895545, 
       3.5857430952338682`}, {2.298714488895545, 3.5857430952338682`}}, {{
       2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}}, {{2.234425549073621, 3.565878552985596}, {
       2.14719901162296, 3.5857430952338682`}, {2.14719901162296, 
       3.5857430952338682`}, {2.234425549073621, 3.565878552985596}, {
       2.234425549073621, 3.565878552985596}}, {{2.234425549073621, 
       3.565878552985596}, {2.14719901162296, 3.5857430952338682`}, {
       2.14719901162296, 3.5857430952338682`}, {2.234425549073621, 
       3.565878552985596}, {2.234425549073621, 3.565878552985596}}, {{
       2.234425549073621, 3.565878552985596}, {2.14719901162296, 
       3.5857430952338682`}, {2.14719901162296, 3.5857430952338682`}, {
       2.234425549073621, 3.565878552985596}, {2.234425549073621, 
       3.565878552985596}}, {{2.14719901162296, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}, {2.14719901162296, 3.848175600003032}, {
       2.14719901162296, 3.848175600003032}}, {{2.14719901162296, 
       3.848175600003032}, {2.234425549073621, 3.868040142251304}, {
       2.234425549073621, 3.868040142251304}, {2.14719901162296, 
       3.848175600003032}, {2.14719901162296, 3.848175600003032}}, {{
       2.14719901162296, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}, {
       2.14719901162296, 3.848175600003032}, {2.14719901162296, 
       3.848175600003032}}, {{2.14719901162296, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}, {2.14719901162296, 3.848175600003032}, {
       2.14719901162296, 3.848175600003032}}, {{2.234425549073621, 
       3.868040142251304}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}}, {{
       2.234425549073621, 3.868040142251304}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}, {
       2.234425549073621, 3.868040142251304}, {2.234425549073621, 
       3.868040142251304}}, {{2.234425549073621, 3.868040142251304}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}, {2.234425549073621, 3.868040142251304}, {
       2.234425549073621, 3.868040142251304}}, {{2.234425549073621, 
       3.868040142251304}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}, {2.234425549073621, 
       3.868040142251304}, {2.234425549073621, 3.868040142251304}}, {{
       2.298714488895545, 3.848175600003032}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}, {{2.298714488895545, 3.848175600003032}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.298714488895545, 3.848175600003032}, {
       2.298714488895545, 3.848175600003032}}, {{2.298714488895545, 
       3.848175600003032}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.298714488895545, 
       3.848175600003032}, {2.298714488895545, 3.848175600003032}}, {{
       2.298714488895545, 3.848175600003032}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.298714488895545, 3.848175600003032}, {2.298714488895545, 
       3.848175600003032}}, {{2.3480621570280595`, 3.8024320160590133`}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.3480621570280595`, 3.8024320160590133`}}, {{2.3480621570280595`, 
       3.8024320160590133`}, {2.374472227531837, 3.71695934761845}, {
       2.374472227531837, 3.71695934761845}, {2.3480621570280595`, 
       3.8024320160590133`}, {2.3480621570280595`, 3.8024320160590133`}}, {{
       2.3480621570280595`, 3.8024320160590133`}, {2.374472227531837, 
       3.71695934761845}, {2.374472227531837, 3.71695934761845}, {
       2.3480621570280595`, 3.8024320160590133`}, {2.3480621570280595`, 
       3.8024320160590133`}}, {{2.3480621570280595`, 3.8024320160590133`}, {
       2.374472227531837, 3.71695934761845}, {2.374472227531837, 
       3.71695934761845}, {2.3480621570280595`, 3.8024320160590133`}, {
       2.3480621570280595`, 3.8024320160590133`}}, {{
       2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}, {{
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}, {{
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}, {{
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}, {{
       2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}, {{
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}, {{
       2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}, {{
       2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}, {{
       2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}, {{
       2.4629971546626503`, -4.649179509208643}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}}, {{
       2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}, {{
       2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}, {{
       2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}, {{
       2.394844010642376, -4.575656657623252}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.575656657623252}, {
       2.394844010642376, -4.575656657623252}}, {{
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}, {{
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}, {{
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}, {{
       2.378100278353821, -4.502133806037861}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}, {
       2.378100278353821, -4.502133806037861}, {
       2.378100278353821, -4.502133806037861}}, {{
       2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}, {{
       2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}, {{
       2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}, {{
       2.394844010642376, -4.42861095445247}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.394844010642376, -4.42861095445247}, {
       2.394844010642376, -4.42861095445247}}, {{
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}, {{
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}, {{
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}, {{
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}}, {{
       2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}, {{
       2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}, {{
       2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}, {{
       2.688091698367653, -4.597917585899894}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.688091698367653, -4.597917585899894}, {
       2.688091698367653, -4.597917585899894}}, {{
       2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}, {{
       2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}, {{
       2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}, {{
       2.6327909072803086`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.6327909072803086`, -4.649179509208643}, {
       2.6327909072803086`, -4.649179509208643}}, {{
       2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}, {{
       2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}, {{
       2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}, {{
       2.5607463839044096`, -4.671440437485285}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.4629971546626503`, -4.649179509208643}, {
       2.5607463839044096`, -4.671440437485285}, {
       2.5607463839044096`, -4.671440437485285}}, {{
       2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}, {{
       2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}, {{
       2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}, {{
       2.4629971546626503`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.4629971546626503`, -4.355088102867079}, {
       2.4629971546626503`, -4.355088102867079}}, {{
       2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}, {{
       2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}, {{
       2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}, {{
       2.5607463839044096`, -4.332827174590437}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.5607463839044096`, -4.332827174590437}, {
       2.5607463839044096`, -4.332827174590437}}, {{
       2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}, {{
       2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}, {{
       2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}, {{
       2.6327909072803086`, -4.355088102867079}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}, {
       2.6327909072803086`, -4.355088102867079}, {
       2.6327909072803086`, -4.355088102867079}}, {{
       2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}, {{
       2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}, {{
       2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}, {{
       2.688091698367653, -4.406350026175828}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.7176877835891378`, -4.502133806037861}, {
       2.688091698367653, -4.406350026175828}, {
       2.688091698367653, -4.406350026175828}}, {{
       2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}, {{
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}, {{
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.454381886469539, -4.186417887001175}, {
       2.454381886469539, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}, {{
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}, {{
       2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}, {{
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}, {{
       2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}, {{
       2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}, {{
       2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}, {{
       2.4543818864695384`, -4.186417887001175}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}}, {{
       2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}, {{
       2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}, {{
       2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}, {{
       2.3888817975858627`, -4.115757121704832}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -4.115757121704832}, {
       2.3888817975858627`, -4.115757121704832}}, {{
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}, {{
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}, {{
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}, {{
       2.372789862739562, -4.04509635640849}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.372789862739562, -4.04509635640849}, {
       2.372789862739562, -4.04509635640849}}, {{
       2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}, {{
       2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}, {{
       2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}, {{
       2.3888817975858627`, -3.974435591112148}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.4543818864695384`, -3.9037748258158054`}, {
       2.3888817975858627`, -3.974435591112148}, {
       2.3888817975858627`, -3.974435591112148}}, {{
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}, {{
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}, {{
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}, {{
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}}, {{
       2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}, {{
       2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}, {{
       2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}, {{
       2.670713984303824, -4.137151479980064}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}, {
       2.670713984303824, -4.137151479980064}, {
       2.670713984303824, -4.137151479980064}}, {{
       2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}, {{
       2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}, {{
       2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}, {{
       2.617565933929492, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.617565933929492, -4.186417887001175}, {
       2.617565933929492, -4.186417887001175}}, {{
       2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}, {{
       2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}, {{
       2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}, {{
       2.5483259487088588`, -4.207812245276406}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.4543818864695384`, -4.186417887001175}, {
       2.5483259487088588`, -4.207812245276406}, {
       2.5483259487088588`, -4.207812245276406}}, {{
       2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}, {{
       2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}, {{
       2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}, {{
       2.454381886469539, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.454381886469539, -3.9037748258158054`}, {
       2.454381886469539, -3.9037748258158054`}}, {{
       2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}, {{
       2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}, {{
       2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}, {{
       2.5483259487088588`, -3.8823804675405746`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.5483259487088588`, -3.8823804675405746`}, {
       2.5483259487088588`, -3.8823804675405746`}}, {{
       2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}, {{
       2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}, {{
       2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}, {{
       2.617565933929492, -3.9037748258158054`}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}, {
       2.617565933929492, -3.9037748258158054`}, {
       2.617565933929492, -3.9037748258158054`}}, {{
       2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}, {{
       2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}, {{
       2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}, {{
       2.670713984303824, -3.953041232836917}, {
       2.699157957659468, -4.04509635640849}, {
       2.699157957659468, -4.04509635640849}, {
       2.670713984303824, -3.953041232836917}, {
       2.670713984303824, -3.953041232836917}}, {{
       2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}, {{
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}, {{
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}, {{
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}, {{
       2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}, {{
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}, {{
       2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}, {{
       2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}, {{
       2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}, {{
       2.4508030468067927`, -3.637715750001646}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}}, {{
       2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}, {{
       2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}, {{
       2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}, {{
       2.3879040222471026`, -3.569860983885614}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.569860983885614}, {
       2.3879040222471026`, -3.569860983885614}}, {{
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}, {{
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}, {{
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}, {{
       2.3724511118410123`, -3.502006217769582}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3724511118410123`, -3.502006217769582}, {
       2.3724511118410123`, -3.502006217769582}}, {{
       2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}, {{
       2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}, {{
       2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}, {{
       2.3879040222471026`, -3.43415145165355}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.3879040222471026`, -3.43415145165355}, {
       2.3879040222471026`, -3.43415145165355}}, {{
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}, {{
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}, {{
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}, {{
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}}, {{
       2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}, {{
       2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}, {{
       2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}, {{
       2.6585444127596434`, -3.590405753969551}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6585444127596434`, -3.590405753969551}, {
       2.6585444127596434`, -3.590405753969551}}, {{
       2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}, {{
       2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}, {{
       2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}, {{
       2.6075069167383536`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}, {
       2.6075069167383536`, -3.637715750001646}, {
       2.6075069167383536`, -3.637715750001646}}, {{
       2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}, {{
       2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}, {{
       2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}, {{
       2.541016510310973, -3.658260520085583}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.4508030468067927`, -3.637715750001646}, {
       2.541016510310973, -3.658260520085583}, {
       2.541016510310973, -3.658260520085583}}, {{
       2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}, {{
       2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}, {{
       2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}, {{
       2.4508030468067927`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.4508030468067927`, -3.366296685537518}, {
       2.4508030468067927`, -3.366296685537518}}, {{
       2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}, {{
       2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}, {{
       2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}, {{
       2.541016510310973, -3.3457519154535813`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.541016510310973, -3.3457519154535813`}, {
       2.541016510310973, -3.3457519154535813`}}, {{
       2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}, {{
       2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}, {{
       2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}, {{
       2.6075069167383536`, -3.366296685537518}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6075069167383536`, -3.366296685537518}, {
       2.6075069167383536`, -3.366296685537518}}, {{
       2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}, {{
       2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}, {{
       2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}, {{
       2.6585444127596434`, -3.4136066815696133`}, {
       2.685858851704134, -3.502006217769582}, {
       2.685858851704134, -3.502006217769582}, {
       2.6585444127596434`, -3.4136066815696133`}, {
       2.6585444127596434`, -3.4136066815696133`}}, {{
       2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}, {{
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}, {{
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}, {{
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}, {{
       2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}, {{
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}, {{
       2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}, {{
       2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}, {{
       2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}, {{
       2.39153911966457, -3.0963520482015103`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}}, {{
       2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}, {{
       2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}, {{
       2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}, {{
       2.330780234816821, -3.030806040935491}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -3.030806040935491}, {
       2.330780234816821, -3.030806040935491}}, {{
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}, {{
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}, {{
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}, {{
       2.3158531097858877`, -2.9652600336694723`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.3158531097858877`, -2.9652600336694723`}, {
       2.3158531097858877`, -2.9652600336694723`}}, {{
       2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}, {{
       2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}, {{
       2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}, {{
       2.330780234816821, -2.8997140264034535`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.330780234816821, -2.8997140264034535`}, {
       2.330780234816821, -2.8997140264034535`}}, {{
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}, {{
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}, {{
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}, {{
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}}, {{
       2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}, {{
       2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}, {{
       2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}, {{
       2.5922120843154803`, -3.050651775086246}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.5922120843154803`, -3.050651775086246}, {
       2.5922120843154803`, -3.050651775086246}}, {{
       2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}, {{
       2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}, {{
       2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}, {{
       2.542911139421935, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.542911139421935, -3.0963520482015103`}, {
       2.542911139421935, -3.0963520482015103`}}, {{
       2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}, {{
       2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}, {{
       2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}, {{
       2.4786830694974564`, -3.116197782352265}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.39153911966457, -3.0963520482015103`}, {
       2.4786830694974564`, -3.116197782352265}, {
       2.4786830694974564`, -3.116197782352265}}, {{
       2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}, {{
       2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}, {{
       2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}, {{
       2.39153911966457, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.39153911966457, -2.8341680191374343`}, {
       2.39153911966457, -2.8341680191374343`}}, {{
       2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}, {{
       2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}, {{
       2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}, {{
       2.4786830694974564`, -2.81432228498668}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.4786830694974564`, -2.81432228498668}, {
       2.4786830694974564`, -2.81432228498668}}, {{
       2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}, {{
       2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}, {{
       2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}, {{
       2.542911139421935, -2.8341680191374343`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.542911139421935, -2.8341680191374343`}, {
       2.542911139421935, -2.8341680191374343`}}, {{
       2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}, {{
       2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}, {{
       2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}, {{
       2.5922120843154803`, -2.8798682922526986`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.6185971493006175`, -2.9652600336694723`}, {
       2.5922120843154803`, -2.8798682922526986`}, {
       2.5922120843154803`, -2.8798682922526986`}}, {{
       2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}, {{
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}, {{
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}, {{
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}, {{
       2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}, {{
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}, {{
       2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}, {{
       2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}, {{
       2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}, {{
       2.445783324935272, -2.619576898070133}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}}, {{
       2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}, {{
       2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}, {{
       2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}, {{
       2.380955167810568, -2.5496410052606078`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.5496410052606078`}, {
       2.380955167810568, -2.5496410052606078`}}, {{
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}, {{
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}, {{
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}, {{
       2.3650283118560798`, -2.4797051124510827`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.3650283118560798`, -2.4797051124510827`}, {
       2.3650283118560798`, -2.4797051124510827`}}, {{
       2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}, {{
       2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}, {{
       2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}, {{
       2.380955167810568, -2.4097692196415577`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.380955167810568, -2.4097692196415577`}, {
       2.380955167810568, -2.4097692196415577`}}, {{
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}, {{
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}, {{
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}, {{
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}}, {{
       2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}, {{
       2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}, {{
       2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}, {{
       2.6598961829258068`, -2.570815889806368}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6598961829258068`, -2.570815889806368}, {
       2.6598961829258068`, -2.570815889806368}}, {{
       2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}, {{
       2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}, {{
       2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}, {{
       2.6072933510936567`, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.6072933510936567`, -2.619576898070133}, {
       2.6072933510936567`, -2.619576898070133}}, {{
       2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}, {{
       2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}, {{
       2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}, {{
       2.5387636633070185`, -2.6407517826158933`}, {
       2.445783324935272, -2.619576898070133}, {
       2.445783324935272, -2.619576898070133}, {
       2.5387636633070185`, -2.6407517826158933`}, {
       2.5387636633070185`, -2.6407517826158933`}}, {{
       2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}, {{
       2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}, {{
       2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}, {{
       2.445783324935272, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.445783324935272, -2.3398333268320326`}, {
       2.445783324935272, -2.3398333268320326`}}, {{
       2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}, {{
       2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}, {{
       2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}, {{
       2.5387636633070185`, -2.318658442286272}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.5387636633070185`, -2.318658442286272}, {
       2.5387636633070185`, -2.318658442286272}}, {{
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}, {{
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}, {{
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}, {{
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6072933510936567`, -2.3398333268320326`}, {
       2.6072933510936567`, -2.3398333268320326`}}, {{
       2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}, {{
       2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}, {{
       2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}, {{
       2.6598961829258068`, -2.388594335095797}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.688048364172849, -2.4797051124510827`}, {
       2.6598961829258068`, -2.388594335095797}, {
       2.6598961829258068`, -2.388594335095797}}, {{
       2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}, {{
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}, {{
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}, {{
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}, {{
       2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}, {{
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}, {{
       2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}, {{
       2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}, {{
       2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}, {{
       2.396047021933314, -2.100371667250561}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}}, {{
       2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}, {{
       2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}, {{
       2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}, {{
       2.331429764772882, -2.0306632909701032`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -2.0306632909701032`}, {
       2.331429764772882, -2.0306632909701032`}}, {{
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}, {{
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}, {{
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}, {{
       2.315554722312726, -1.9609549146896452`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.315554722312726, -1.9609549146896452`}, {
       2.315554722312726, -1.9609549146896452`}}, {{
       2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}, {{
       2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}, {{
       2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}, {{
       2.331429764772882, -1.8912465384091872`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.331429764772882, -1.8912465384091872`}, {
       2.331429764772882, -1.8912465384091872`}}, {{
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}, {{
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}, {{
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}, {{
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}}, {{
       2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}, {{
       2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}, {{
       2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}, {{
       2.609463324659854, -2.0517692890536807`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}, {
       2.609463324659854, -2.0517692890536807`}, {
       2.609463324659854, -2.0517692890536807`}}, {{
       2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}, {{
       2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}, {{
       2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}, {{
       2.557031621174491, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.557031621174491, -2.100371667250561}, {
       2.557031621174491, -2.100371667250561}}, {{
       2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}, {{
       2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}, {{
       2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}, {{
       2.4887248752289715`, -2.1214776653341385`}, {
       2.396047021933314, -2.100371667250561}, {
       2.396047021933314, -2.100371667250561}, {
       2.4887248752289715`, -2.1214776653341385`}, {
       2.4887248752289715`, -2.1214776653341385`}}, {{
       2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}, {{
       2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}, {{
       2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}, {{
       2.396047021933314, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.396047021933314, -1.8215381621287294`}, {
       2.396047021933314, -1.8215381621287294`}}, {{
       2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}, {{
       2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}, {{
       2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}, {{
       2.4887248752289715`, -1.800432164045152}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.4887248752289715`, -1.800432164045152}, {
       2.4887248752289715`, -1.800432164045152}}, {{
       2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}, {{
       2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}, {{
       2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}, {{
       2.557031621174491, -1.8215381621287294`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.557031621174491, -1.8215381621287294`}, {
       2.557031621174491, -1.8215381621287294`}}, {{
       2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}, {{
       2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}, {{
       2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}, {{
       2.609463324659854, -1.8701405403256097`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.6375239207950787`, -1.9609549146896452`}, {
       2.609463324659854, -1.8701405403256097`}, {
       2.609463324659854, -1.8701405403256097`}}, {{
       2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}, {{
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}, {{
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}, {{
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}, {{
       2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}, {{
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}, {{
       2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}, {{
       2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}, {{
       2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}, {{
       2.405539153203893, -1.6307412472050327`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}}, {{
       2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}, {{
       2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}, {{
       2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}, {{
       2.345855044445425, -1.5663546963960222`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.5663546963960222`}, {
       2.345855044445425, -1.5663546963960222`}}, {{
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}, {{
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}, {{
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}, {{
       2.3311919683203457`, -1.5019681455870117`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.3311919683203457`, -1.5019681455870117`}, {
       2.3311919683203457`, -1.5019681455870117`}}, {{
       2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}, {{
       2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}, {{
       2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}, {{
       2.345855044445425, -1.4375815947780013`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.345855044445425, -1.4375815947780013`}, {
       2.345855044445425, -1.4375815947780013`}}, {{
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}, {{
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}, {{
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}, {{
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}}, {{
       2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}, {{
       2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}, {{
       2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}, {{
       2.602662373571109, -1.5858493753785838`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.602662373571109, -1.5858493753785838`}, {
       2.602662373571109, -1.5858493753785838`}}, {{
       2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}, {{
       2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}, {{
       2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}, {{
       2.5542335229709883`, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.5542335229709883`, -1.6307412472050327`}, {
       2.5542335229709883`, -1.6307412472050327`}}, {{
       2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}, {{
       2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}, {{
       2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}, {{
       2.491141596245788, -1.6502359261875943`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.405539153203893, -1.6307412472050327`}, {
       2.491141596245788, -1.6502359261875943`}, {
       2.491141596245788, -1.6502359261875943`}}, {{
       2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}, {{
       2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}, {{
       2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}, {{
       2.405539153203893, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.405539153203893, -1.3731950439689908`}, {
       2.405539153203893, -1.3731950439689908`}}, {{
       2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}, {{
       2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}, {{
       2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}, {{
       2.491141596245788, -1.3537003649864292`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.491141596245788, -1.3537003649864292`}, {
       2.491141596245788, -1.3537003649864292`}}, {{
       2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}, {{
       2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}, {{
       2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}, {{
       2.5542335229709883`, -1.3731950439689908`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.5542335229709883`, -1.3731950439689908`}, {
       2.5542335229709883`, -1.3731950439689908`}}, {{
       2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}, {{
       2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}, {{
       2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}, {{
       2.602662373571109, -1.4180869157954397`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.628580707854536, -1.5019681455870117`}, {
       2.602662373571109, -1.4180869157954397`}, {
       2.602662373571109, -1.4180869157954397`}}, {{
       2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946978`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}, {{
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}, {{
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}, {{
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}, {{
       2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}, {{
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}, {{
       2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}, {{
       2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}, {{
       2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}, {{
       2.398281706685074, -1.187309305166769}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}}, {{
       2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}, {{
       2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}, {{
       2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}, {{
       2.326381779592412, -1.1097444657946975`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -1.1097444657946975`}, {
       2.326381779592412, -1.1097444657946975`}}, {{
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}, {{
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}, {{
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}, {{
       2.308717544902843, -1.0321796264226264`}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}, {
       2.308717544902843, -1.0321796264226264`}, {
       2.308717544902843, -1.0321796264226264`}}, {{
       2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}, {{
       2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}, {{
       2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}, {{
       2.326381779592412, -0.9546147870505551}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}, {
       2.326381779592412, -0.9546147870505551}, {
       2.326381779592412, -0.9546147870505551}}, {{
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}, {{
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}, {{
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}, {{
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}}, {{
       2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}, {{
       2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}, {{
       2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}, {{
       2.6357510342414243`, -1.1332292095011562`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.6357510342414243`, -1.1332292095011562`}, {
       2.6357510342414243`, -1.1332292095011562`}}, {{
       2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}, {{
       2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}, {{
       2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}, {{
       2.5774100302495357`, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.5774100302495357`, -1.187309305166769}, {
       2.5774100302495357`, -1.187309305166769}}, {{
       2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}, {{
       2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}, {{
       2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}, {{
       2.501404791568078, -1.2107940488732276`}, {
       2.398281706685074, -1.187309305166769}, {
       2.398281706685074, -1.187309305166769}, {
       2.501404791568078, -1.2107940488732276`}, {
       2.501404791568078, -1.2107940488732276`}}, {{
       2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}, {{
       2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}, {{
       2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}, {{
       2.398281706685074, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}, {
       2.398281706685074, -0.8770499476784839}, {
       2.398281706685074, -0.8770499476784839}}, {{
       2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}, {{
       2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}, {{
       2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}, {{
       2.501404791568078, -0.8535652039720253}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.501404791568078, -0.8535652039720253}, {
       2.501404791568078, -0.8535652039720253}}, {{
       2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}, {{
       2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}, {{
       2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}, {{
       2.5774100302495357`, -0.8770499476784839}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.5774100302495357`, -0.8770499476784839}, {
       2.5774100302495357`, -0.8770499476784839}}, {{
       2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}, {{
       2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}, {{
       2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}, {{
       2.6357510342414243`, -0.9311300433440965}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6669741920317667`, -1.0321796264226264`}, {
       2.6357510342414243`, -0.9311300433440965}, {
       2.6357510342414243`, -0.9311300433440965}}, {{
       2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664749}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}, {{
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}, {{
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}, {{
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}, {{
       2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}, {{
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}, {{
       2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}, {{
       2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}, {{
       2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}, {{
       2.463129571569093, -0.6774669026398183}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}}, {{
       2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}, {{
       2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}, {{
       2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}, {{
       2.3951486982510466`, -0.6041298947664748}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.6041298947664748}, {
       2.3951486982510466`, -0.6041298947664748}}, {{
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}, {{
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}, {{
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}, {{
       2.3784472890946198`, -0.5307928868931314}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3784472890946198`, -0.5307928868931314}, {
       2.3784472890946198`, -0.5307928868931314}}, {{
       2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}, {{
       2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}, {{
       2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}, {{
       2.3951486982510466`, -0.45745587901978796`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}, {
       2.3951486982510466`, -0.45745587901978796`}, {
       2.3951486982510466`, -0.45745587901978796`}}, {{
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}, {{
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}, {{
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}, {{
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}}, {{
       2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}, {{
       2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}, {{
       2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}, {{
       2.68765514379568, -0.6263345540946827}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}, {
       2.68765514379568, -0.6263345540946827}, {
       2.68765514379568, -0.6263345540946827}}, {{
       2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}, {{
       2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}, {{
       2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}, {{
       2.632494136518039, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.632494136518039, -0.6774669026398183}, {
       2.632494136518039, -0.6774669026398183}}, {{
       2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}, {{
       2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}, {{
       2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}, {{
       2.5606317200839706`, -0.6996715619680263}, {
       2.463129571569093, -0.6774669026398183}, {
       2.463129571569093, -0.6774669026398183}, {
       2.5606317200839706`, -0.6996715619680263}, {
       2.5606317200839706`, -0.6996715619680263}}, {{
       2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}, {{
       2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}, {{
       2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}, {{
       2.463129571569093, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.463129571569093, -0.3841188711464445}, {
       2.463129571569093, -0.3841188711464445}}, {{
       2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}, {{
       2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}, {{
       2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}, {{
       2.5606317200839706`, -0.36191421181823663`}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}, {
       2.5606317200839706`, -0.36191421181823663`}, {
       2.5606317200839706`, -0.36191421181823663`}}, {{
       2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}, {{
       2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}, {{
       2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}, {{
       2.632494136518039, -0.3841188711464445}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}, {
       2.632494136518039, -0.3841188711464445}, {
       2.632494136518039, -0.3841188711464445}}, {{
       2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}, {{
       2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}, {{
       2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}, {{
       2.68765514379568, -0.4352512196915801}, {
       2.717176418992512, -0.5307928868931314}, {
       2.717176418992512, -0.5307928868931314}, {
       2.68765514379568, -0.4352512196915801}, {
       2.68765514379568, -0.4352512196915801}}, {{
       2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {2.330800232545931, 
       0.0626697869094773}, {2.4000468632139706`, 0.13737227969367127`}, {
       2.4000468632139706`, 0.13737227969367127`}, {2.330800232545931, 
       0.06266978690947729}, {2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.08673519865891072}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}, {{
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}, {{
       2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}, {{
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}, {{2.400046863213971, 
       0.13737227969367133`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.628752947979398, 
       0.08528788180238134}, {2.6588238891225138`, -0.012032705874716687`}, {
       2.6588238891225138`, -0.012032705874716687`}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}}, {{
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}}, {{2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}, {{
       2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}, {{
       2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}, {{
       2.4000468632139706`, -0.1614376914431047}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}, {
       2.4000468632139706`, -0.1614376914431047}, {
       2.4000468632139706`, -0.1614376914431047}}, {{
       2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}, {{
       2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}, {{
       2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}, {{
       2.330800232545931, -0.0867351986589107}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.330800232545931, -0.0867351986589107}, {
       2.330800232545931, -0.0867351986589107}}, {{
       2.31378785457779, -0.012032705874716706`}, {2.330800232545931, 
       0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}, {{
       2.31378785457779, -0.012032705874716706`}, {2.330800232545931, 
       0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}, {{
       2.31378785457779, -0.012032705874716706`}, {2.330800232545931, 
       0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}, {{
       2.31378785457779, -0.012032705874716706`}, {2.330800232545931, 
       0.06266978690947729}, {2.330800232545931, 0.06266978690947729}, {
       2.31378785457779, -0.012032705874716706`}, {
       2.31378785457779, -0.012032705874716706`}}, {{2.330800232545931, 
       0.0626697869094773}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}, {2.330800232545931, 
       0.0626697869094773}, {2.330800232545931, 0.0626697869094773}}, {{
       2.330800232545931, 0.0626697869094773}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}, {
       2.330800232545931, 0.0626697869094773}, {2.330800232545931, 
       0.0626697869094773}}, {{2.330800232545931, 0.0626697869094773}, {
       2.400046863213971, 0.13737227969367133`}, {2.400046863213971, 
       0.13737227969367133`}, {2.330800232545931, 0.0626697869094773}, {
       2.330800232545931, 0.0626697869094773}}, {{2.330800232545931, 
       0.0626697869094773}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}, {2.330800232545931, 
       0.0626697869094773}, {2.330800232545931, 0.0626697869094773}}, {{
       2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}, {{
       2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}, {{
       2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}, {{
       2.6588238891225138`, -0.012032705874716726`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.6588238891225138`, -0.012032705874716726`}, {
       2.6588238891225138`, -0.012032705874716726`}}, {{
       2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}, {{
       2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}, {{
       2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}, {{
       2.628752947979398, -0.10935329355181475`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.628752947979398, -0.10935329355181475`}, {
       2.628752947979398, -0.10935329355181475`}}, {{
       2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}, {{
       2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}, {{
       2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}, {{
       2.5725648804863326`, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.5725648804863326`, -0.1614376914431047}, {
       2.5725648804863326`, -0.1614376914431047}}, {{
       2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}, {{
       2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}, {{
       2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}, {{
       2.4993644350251265`, -0.18405578633600878`}, {
       2.400046863213971, -0.1614376914431047}, {
       2.400046863213971, -0.1614376914431047}, {
       2.4993644350251265`, -0.18405578633600878`}, {
       2.4993644350251265`, -0.18405578633600878`}}, {{2.400046863213971, 
       0.13737227969367133`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}}, {{
       2.400046863213971, 0.13737227969367133`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.400046863213971, 0.13737227969367133`}, {2.400046863213971, 
       0.13737227969367133`}}, {{2.400046863213971, 0.13737227969367133`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.400046863213971, 0.13737227969367133`}, {
       2.400046863213971, 0.13737227969367133`}}, {{2.400046863213971, 
       0.13737227969367133`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.400046863213971, 
       0.13737227969367133`}, {2.400046863213971, 0.13737227969367133`}}, {{
       2.4993644350251265`, 0.15999037458657533`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}}, {{2.4993644350251265`, 0.15999037458657533`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.4993644350251265`, 0.15999037458657533`}, {
       2.4993644350251265`, 0.15999037458657533`}}, {{2.4993644350251265`, 
       0.15999037458657533`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.4993644350251265`, 
       0.15999037458657533`}, {2.4993644350251265`, 0.15999037458657533`}}, {{
       2.4993644350251265`, 0.15999037458657533`}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.4993644350251265`, 0.15999037458657533`}, {2.4993644350251265`, 
       0.15999037458657533`}}, {{2.5725648804863326`, 0.13737227969367127`}, {
       2.628752947979398, 0.08528788180238134}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}, {{2.5725648804863326`, 
       0.13737227969367127`}, {2.628752947979398, 0.08528788180238134}, {
       2.628752947979398, 0.08528788180238134}, {2.5725648804863326`, 
       0.13737227969367127`}, {2.5725648804863326`, 0.13737227969367127`}}, {{
       2.5725648804863326`, 0.13737227969367127`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}, {
       2.5725648804863326`, 0.13737227969367127`}, {2.5725648804863326`, 
       0.13737227969367127`}}, {{2.5725648804863326`, 0.13737227969367127`}, {
       2.628752947979398, 0.08528788180238134}, {2.628752947979398, 
       0.08528788180238134}, {2.5725648804863326`, 0.13737227969367127`}, {
       2.5725648804863326`, 0.13737227969367127`}}, {{2.628752947979398, 
       0.08528788180238134}, {2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}, {{
       2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}, {{
       2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}, {{
       2.628752947979398, 0.08528788180238134}, {
       2.6588238891225138`, -0.012032705874716736`}, {
       2.6588238891225138`, -0.012032705874716736`}, {2.628752947979398, 
       0.08528788180238134}, {2.628752947979398, 0.08528788180238134}}, {{
       2.3987127096745144`, 0.3952951383987243}, {2.3340987007333425`, 
       0.4650000105364749}, {2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`, 
       0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.318224456289397, 
       0.5347048826742254}, {2.3340987007333425`, 0.4650000105364749}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}}, {{2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}}, {{2.640177469829867, 
       0.5347048826742254}, {2.612118284261615, 0.44389507342194034`}, {
       2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.398712709674515, 0.3952951383987243}, {
       2.398712709674515, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.55968921644475, 0.3952951383987243}, {
       2.612118284261615, 0.44389507342194034`}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}}, {{
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}, {{2.398712709674515, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.612118284261615, 0.6255146919265105}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}, {2.612118284261615, 0.6255146919265105}, {
       2.55968921644475, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.398712709674515, 0.6741146269497266}, {
       2.398712709674515, 0.6741146269497266}}, {{2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}}, {{
       2.3987127096745144`, 0.3952951383987243}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3340987007333425`, 0.4650000105364749}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}}, {{2.3987127096745144`, 0.3952951383987243}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}}, {{2.3987127096745144`, 
       0.3952951383987243}, {2.3340987007333425`, 0.4650000105364749}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3987127096745144`, 
       0.3952951383987243}, {2.3987127096745144`, 0.3952951383987243}}, {{
       2.3987127096745144`, 0.3952951383987243}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3340987007333425`, 0.4650000105364749}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}}, {{2.3340987007333425`, 0.4650000105364749}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.3340987007333425`, 0.4650000105364749}, {
       2.3340987007333425`, 0.4650000105364749}}, {{2.3340987007333425`, 
       0.4650000105364749}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.4650000105364749}, {2.3340987007333425`, 0.4650000105364749}}, {{
       2.3340987007333425`, 0.4650000105364749}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.4650000105364749}, {2.3340987007333425`, 
       0.4650000105364749}}, {{2.3340987007333425`, 0.4650000105364749}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}, {2.3340987007333425`, 0.4650000105364749}, {
       2.3340987007333425`, 0.4650000105364749}}, {{2.318224456289397, 
       0.5347048826742254}, {2.3340987007333425`, 0.604409754811976}, {
       2.3340987007333425`, 0.604409754811976}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}}, {{
       2.318224456289397, 0.5347048826742254}, {2.3340987007333425`, 
       0.604409754811976}, {2.3340987007333425`, 0.604409754811976}, {
       2.318224456289397, 0.5347048826742254}, {2.318224456289397, 
       0.5347048826742254}}, {{2.318224456289397, 0.5347048826742254}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}, {2.318224456289397, 0.5347048826742254}, {
       2.318224456289397, 0.5347048826742254}}, {{2.318224456289397, 
       0.5347048826742254}, {2.3340987007333425`, 0.604409754811976}, {
       2.3340987007333425`, 0.604409754811976}, {2.318224456289397, 
       0.5347048826742254}, {2.318224456289397, 0.5347048826742254}}, {{
       2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`, 
       0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}}, {{2.3340987007333425`, 0.604409754811976}, {
       2.3987127096745144`, 0.6741146269497266}, {2.3987127096745144`, 
       0.6741146269497266}, {2.3340987007333425`, 0.604409754811976}, {
       2.3340987007333425`, 0.604409754811976}}, {{2.3340987007333425`, 
       0.604409754811976}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3987127096745144`, 0.6741146269497266}, {2.3340987007333425`, 
       0.604409754811976}, {2.3340987007333425`, 0.604409754811976}}, {{
       2.3340987007333425`, 0.604409754811976}, {2.3987127096745144`, 
       0.6741146269497266}, {2.3987127096745144`, 0.6741146269497266}, {
       2.3340987007333425`, 0.604409754811976}, {2.3340987007333425`, 
       0.604409754811976}}, {{2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}, {2.640177469829867, 0.5347048826742254}, {
       2.640177469829867, 0.5347048826742254}}, {{2.640177469829867, 
       0.5347048826742254}, {2.612118284261615, 0.44389507342194034`}, {
       2.612118284261615, 0.44389507342194034`}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}}, {{
       2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}}, {{2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}, {2.640177469829867, 0.5347048826742254}, {
       2.640177469829867, 0.5347048826742254}}, {{2.612118284261615, 
       0.44389507342194034`}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}}, {{
       2.612118284261615, 0.44389507342194034`}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}, {
       2.612118284261615, 0.44389507342194034`}, {2.612118284261615, 
       0.44389507342194034`}}, {{2.612118284261615, 0.44389507342194034`}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}, {2.612118284261615, 0.44389507342194034`}, {
       2.612118284261615, 0.44389507342194034`}}, {{2.612118284261615, 
       0.44389507342194034`}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}, {2.612118284261615, 
       0.44389507342194034`}, {2.612118284261615, 0.44389507342194034`}}, {{
       2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}, {{2.55968921644475, 0.3952951383987243}, {
       2.4913859041839386`, 0.3741902012841898}, {2.4913859041839386`, 
       0.3741902012841898}, {2.55968921644475, 0.3952951383987243}, {
       2.55968921644475, 0.3952951383987243}}, {{2.55968921644475, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}, {2.55968921644475, 
       0.3952951383987243}, {2.55968921644475, 0.3952951383987243}}, {{
       2.55968921644475, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}, {
       2.55968921644475, 0.3952951383987243}, {2.55968921644475, 
       0.3952951383987243}}, {{2.4913859041839386`, 0.3741902012841898}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}}, {{2.4913859041839386`, 
       0.3741902012841898}, {2.3987127096745144`, 0.3952951383987243}, {
       2.3987127096745144`, 0.3952951383987243}, {2.4913859041839386`, 
       0.3741902012841898}, {2.4913859041839386`, 0.3741902012841898}}, {{
       2.4913859041839386`, 0.3741902012841898}, {2.3987127096745144`, 
       0.3952951383987243}, {2.3987127096745144`, 0.3952951383987243}, {
       2.4913859041839386`, 0.3741902012841898}, {2.4913859041839386`, 
       0.3741902012841898}}, {{2.4913859041839386`, 0.3741902012841898}, {
       2.3987127096745144`, 0.3952951383987243}, {2.3987127096745144`, 
       0.3952951383987243}, {2.4913859041839386`, 0.3741902012841898}, {
       2.4913859041839386`, 0.3741902012841898}}, {{2.398712709674515, 
       0.6741146269497266}, {2.4913859041839386`, 0.6952195640642611}, {
       2.4913859041839386`, 0.6952195640642611}, {2.398712709674515, 
       0.6741146269497266}, {2.398712709674515, 0.6741146269497266}}, {{
       2.398712709674515, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.4913859041839386`, 0.6952195640642611}, {
       2.398712709674515, 0.6741146269497266}, {2.398712709674515, 
       0.6741146269497266}}, {{2.398712709674515, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}, {2.398712709674515, 0.6741146269497266}, {
       2.398712709674515, 0.6741146269497266}}, {{2.398712709674515, 
       0.6741146269497266}, {2.4913859041839386`, 0.6952195640642611}, {
       2.4913859041839386`, 0.6952195640642611}, {2.398712709674515, 
       0.6741146269497266}, {2.398712709674515, 0.6741146269497266}}, {{
       2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}}, {{2.4913859041839386`, 0.6952195640642611}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}, {2.4913859041839386`, 0.6952195640642611}, {
       2.4913859041839386`, 0.6952195640642611}}, {{2.4913859041839386`, 
       0.6952195640642611}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}, {2.4913859041839386`, 
       0.6952195640642611}, {2.4913859041839386`, 0.6952195640642611}}, {{
       2.4913859041839386`, 0.6952195640642611}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}, {
       2.4913859041839386`, 0.6952195640642611}, {2.4913859041839386`, 
       0.6952195640642611}}, {{2.55968921644475, 0.6741146269497266}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}}, {{2.55968921644475, 
       0.6741146269497266}, {2.612118284261615, 0.6255146919265105}, {
       2.612118284261615, 0.6255146919265105}, {2.55968921644475, 
       0.6741146269497266}, {2.55968921644475, 0.6741146269497266}}, {{
       2.55968921644475, 0.6741146269497266}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}, {
       2.55968921644475, 0.6741146269497266}, {2.55968921644475, 
       0.6741146269497266}}, {{2.55968921644475, 0.6741146269497266}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}, {2.55968921644475, 0.6741146269497266}, {
       2.55968921644475, 0.6741146269497266}}, {{2.612118284261615, 
       0.6255146919265105}, {2.640177469829867, 0.5347048826742254}, {
       2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}}, {{
       2.612118284261615, 0.6255146919265105}, {2.640177469829867, 
       0.5347048826742254}, {2.640177469829867, 0.5347048826742254}, {
       2.612118284261615, 0.6255146919265105}, {2.612118284261615, 
       0.6255146919265105}}, {{2.612118284261615, 0.6255146919265105}, {
       2.640177469829867, 0.5347048826742254}, {2.640177469829867, 
       0.5347048826742254}, {2.612118284261615, 0.6255146919265105}, {
       2.612118284261615, 0.6255146919265105}}, {{2.612118284261615, 
       0.6255146919265105}, {2.640177469829867, 0.5347048826742254}, {
       2.640177469829867, 0.5347048826742254}, {2.612118284261615, 
       0.6255146919265105}, {2.612118284261615, 0.6255146919265105}}, {{
       2.4018332238518814`, 0.8644592861496427}, {2.3524497598137852`, 
       0.9177336163282379}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}}, {{2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}, {{2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 0.9016034470336689}, {
       2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.524865019329917, 0.8644592861496427}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5863809170689347`, 0.9710079465068331}}, {{
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}, {{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917, 
       1.0775566068640234`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}, {{2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}}, {{
       2.4018332238518814`, 0.8644592861496427}, {2.3524497598137852`, 
       0.9177336163282379}, {2.3524497598137852`, 0.9177336163282379}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}}, {{2.4018332238518814`, 0.8644592861496427}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3524497598137852`, 
       0.9177336163282379}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}}, {{2.4018332238518814`, 
       0.8644592861496427}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4018332238518814`, 0.8644592861496427}}, {{
       2.4018332238518814`, 0.8644592861496427}, {2.3524497598137852`, 
       0.9177336163282379}, {2.3524497598137852`, 0.9177336163282379}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}}, {{2.3524497598137852`, 0.9177336163282379}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}}, {{2.3524497598137852`, 
       0.9177336163282379}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3524497598137852`, 
       0.9177336163282379}, {2.3524497598137852`, 0.9177336163282379}}, {{
       2.3524497598137852`, 0.9177336163282379}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 0.9177336163282379}, {2.3524497598137852`, 
       0.9177336163282379}}, {{2.3524497598137852`, 0.9177336163282379}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 0.9177336163282379}, {
       2.3524497598137852`, 0.9177336163282379}}, {{2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}}, {{
       2.3403173261128636`, 0.9710079465068331}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3403173261128636`, 0.9710079465068331}, {2.3403173261128636`, 
       0.9710079465068331}}, {{2.3403173261128636`, 0.9710079465068331}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3403173261128636`, 0.9710079465068331}, {
       2.3403173261128636`, 0.9710079465068331}}, {{2.3403173261128636`, 
       0.9710079465068331}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3403173261128636`, 
       0.9710079465068331}, {2.3403173261128636`, 0.9710079465068331}}, {{
       2.3524497598137852`, 1.0242822766854283`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}}, {{2.3524497598137852`, 1.0242822766854283`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.3524497598137852`, 1.0242822766854283`}, {
       2.3524497598137852`, 1.0242822766854283`}}, {{2.3524497598137852`, 
       1.0242822766854283`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.3524497598137852`, 
       1.0242822766854283`}, {2.3524497598137852`, 1.0242822766854283`}}, {{
       2.3524497598137852`, 1.0242822766854283`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.3524497598137852`, 1.0242822766854283`}, {2.3524497598137852`, 
       1.0242822766854283`}}, {{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}, {{2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 0.9016034470336689}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5863809170689347`, 0.9710079465068331}}, {{
       2.5863809170689347`, 0.9710079465068331}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5649357257837195`, 0.9016034470336689}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}}, {{2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}}, {{2.5649357257837195`, 
       0.9016034470336689}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5649357257837195`, 0.9016034470336689}}, {{
       2.5649357257837195`, 0.9016034470336689}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}, {
       2.5649357257837195`, 0.9016034470336689}, {2.5649357257837195`, 
       0.9016034470336689}}, {{2.5649357257837195`, 0.9016034470336689}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}, {2.5649357257837195`, 0.9016034470336689}, {
       2.5649357257837195`, 0.9016034470336689}}, {{2.5649357257837195`, 
       0.9016034470336689}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}, {2.5649357257837195`, 
       0.9016034470336689}, {2.5649357257837195`, 0.9016034470336689}}, {{
       2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}, {{2.524865019329917, 0.8644592861496427}, {
       2.4726618791751926`, 0.8483291168550737}, {2.4726618791751926`, 
       0.8483291168550737}, {2.524865019329917, 0.8644592861496427}, {
       2.524865019329917, 0.8644592861496427}}, {{2.524865019329917, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}, {2.524865019329917, 
       0.8644592861496427}, {2.524865019329917, 0.8644592861496427}}, {{
       2.524865019329917, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}, {
       2.524865019329917, 0.8644592861496427}, {2.524865019329917, 
       0.8644592861496427}}, {{2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}}, {{2.4726618791751926`, 
       0.8483291168550737}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4726618791751926`, 
       0.8483291168550737}, {2.4726618791751926`, 0.8483291168550737}}, {{
       2.4726618791751926`, 0.8483291168550737}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4018332238518814`, 0.8644592861496427}, {
       2.4726618791751926`, 0.8483291168550737}, {2.4726618791751926`, 
       0.8483291168550737}}, {{2.4726618791751926`, 0.8483291168550737}, {
       2.4018332238518814`, 0.8644592861496427}, {2.4018332238518814`, 
       0.8644592861496427}, {2.4726618791751926`, 0.8483291168550737}, {
       2.4726618791751926`, 0.8483291168550737}}, {{2.4018332238518814`, 
       1.0775566068640234`}, {2.4726618791751926`, 1.0936867761585924`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.4018332238518814`, 1.0775566068640234`}}, {{
       2.4018332238518814`, 1.0775566068640234`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4726618791751926`, 1.0936867761585924`}, {
       2.4018332238518814`, 1.0775566068640234`}, {2.4018332238518814`, 
       1.0775566068640234`}}, {{2.4018332238518814`, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4018332238518814`, 1.0775566068640234`}, {
       2.4018332238518814`, 1.0775566068640234`}}, {{2.4018332238518814`, 
       1.0775566068640234`}, {2.4726618791751926`, 1.0936867761585924`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4018332238518814`, 
       1.0775566068640234`}, {2.4018332238518814`, 1.0775566068640234`}}, {{
       2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}}, {{2.4726618791751926`, 1.0936867761585924`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}, {2.4726618791751926`, 1.0936867761585924`}, {
       2.4726618791751926`, 1.0936867761585924`}}, {{2.4726618791751926`, 
       1.0936867761585924`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}, {2.4726618791751926`, 
       1.0936867761585924`}, {2.4726618791751926`, 1.0936867761585924`}}, {{
       2.4726618791751926`, 1.0936867761585924`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}, {
       2.4726618791751926`, 1.0936867761585924`}, {2.4726618791751926`, 
       1.0936867761585924`}}, {{2.524865019329917, 1.0775566068640234`}, {
       2.5649357257837195`, 1.0404124459799973`}, {2.5649357257837195`, 
       1.0404124459799973`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}}, {{2.524865019329917, 
       1.0775566068640234`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5649357257837195`, 1.0404124459799973`}, {2.524865019329917, 
       1.0775566068640234`}, {2.524865019329917, 1.0775566068640234`}}, {{
       2.524865019329917, 1.0775566068640234`}, {2.5649357257837195`, 
       1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.524865019329917, 1.0775566068640234`}, {2.524865019329917, 
       1.0775566068640234`}}, {{2.524865019329917, 1.0775566068640234`}, {
       2.5649357257837195`, 1.0404124459799973`}, {2.5649357257837195`, 
       1.0404124459799973`}, {2.524865019329917, 1.0775566068640234`}, {
       2.524865019329917, 1.0775566068640234`}}, {{2.5649357257837195`, 
       1.0404124459799973`}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5649357257837195`, 
       1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}}, {{
       2.5649357257837195`, 1.0404124459799973`}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5649357257837195`, 1.0404124459799973`}, {2.5649357257837195`, 
       1.0404124459799973`}}, {{2.5649357257837195`, 1.0404124459799973`}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5863809170689347`, 
       0.9710079465068331}, {2.5649357257837195`, 1.0404124459799973`}, {
       2.5649357257837195`, 1.0404124459799973`}}, {{2.5649357257837195`, 
       1.0404124459799973`}, {2.5863809170689347`, 0.9710079465068331}, {
       2.5863809170689347`, 0.9710079465068331}, {2.5649357257837195`, 
       1.0404124459799973`}, {2.5649357257837195`, 1.0404124459799973`}}, {{
       2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864, 
       1.4124740794433617`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}, {{2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}}, {{2.653044640806072, 
       1.4868386887120868`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.3954380777291933`, 1.3381094701746366`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.6231097121965172`, 1.3899582874473329`}, {2.653044640806072, 
       1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}}, {{
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}}, {{2.3954380777291933`, 1.635567907249537}, {
       2.4943064306580776`, 1.6580836992455659`}, {2.5671757864471125`, 
       1.635567907249537}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.5671757864471125`, 1.635567907249537}, {2.4943064306580776`, 
       1.6580836992455659`}, {2.3954380777291933`, 1.635567907249537}, {
       2.3954380777291933`, 1.635567907249537}}, {{2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}}, {{
       2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864, 
       1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}, {{2.3954380777291933`, 1.3381094701746366`}, {
       2.326504653409864, 1.4124740794433617`}, {2.326504653409864, 
       1.4124740794433617`}, {2.3954380777291933`, 1.3381094701746366`}, {
       2.3954380777291933`, 1.3381094701746366`}}, {{2.3954380777291933`, 
       1.3381094701746366`}, {2.326504653409864, 1.4124740794433617`}, {
       2.326504653409864, 1.4124740794433617`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.3954380777291933`, 1.3381094701746366`}}, {{
       2.3954380777291933`, 1.3381094701746366`}, {2.326504653409864, 
       1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}}, {{2.326504653409864, 1.4124740794433617`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.326504653409864, 1.4124740794433617`}, {
       2.326504653409864, 1.4124740794433617`}}, {{2.326504653409864, 
       1.4124740794433617`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.326504653409864, 
       1.4124740794433617`}, {2.326504653409864, 1.4124740794433617`}}, {{
       2.326504653409864, 1.4124740794433617`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.4124740794433617`}, {2.326504653409864, 
       1.4124740794433617`}}, {{2.326504653409864, 1.4124740794433617`}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.326504653409864, 1.4124740794433617`}, {
       2.326504653409864, 1.4124740794433617`}}, {{2.3095692233702336`, 
       1.4868386887120868`}, {2.326504653409864, 1.561203297980812}, {
       2.326504653409864, 1.561203297980812}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}}, {{
       2.3095692233702336`, 1.4868386887120868`}, {2.326504653409864, 
       1.561203297980812}, {2.326504653409864, 1.561203297980812}, {
       2.3095692233702336`, 1.4868386887120868`}, {2.3095692233702336`, 
       1.4868386887120868`}}, {{2.3095692233702336`, 1.4868386887120868`}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}, {2.3095692233702336`, 1.4868386887120868`}, {
       2.3095692233702336`, 1.4868386887120868`}}, {{2.3095692233702336`, 
       1.4868386887120868`}, {2.326504653409864, 1.561203297980812}, {
       2.326504653409864, 1.561203297980812}, {2.3095692233702336`, 
       1.4868386887120868`}, {2.3095692233702336`, 1.4868386887120868`}}, {{
       2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}}, {{2.326504653409864, 1.561203297980812}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}, {2.326504653409864, 1.561203297980812}, {
       2.326504653409864, 1.561203297980812}}, {{2.326504653409864, 
       1.561203297980812}, {2.3954380777291933`, 1.635567907249537}, {
       2.3954380777291933`, 1.635567907249537}, {2.326504653409864, 
       1.561203297980812}, {2.326504653409864, 1.561203297980812}}, {{
       2.326504653409864, 1.561203297980812}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}, {
       2.326504653409864, 1.561203297980812}, {2.326504653409864, 
       1.561203297980812}}, {{2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.3899582874473329`}, {2.6231097121965172`, 
       1.3899582874473329`}, {2.653044640806072, 1.4868386887120868`}, {
       2.653044640806072, 1.4868386887120868`}}, {{2.653044640806072, 
       1.4868386887120868`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.6231097121965172`, 1.3899582874473329`}, {2.653044640806072, 
       1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}}, {{
       2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`, 
       1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}}, {{2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.3899582874473329`}, {2.6231097121965172`, 
       1.3899582874473329`}, {2.653044640806072, 1.4868386887120868`}, {
       2.653044640806072, 1.4868386887120868`}}, {{2.6231097121965172`, 
       1.3899582874473329`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.6231097121965172`, 
       1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}}, {{
       2.6231097121965172`, 1.3899582874473329`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.6231097121965172`, 1.3899582874473329`}, {2.6231097121965172`, 
       1.3899582874473329`}}, {{2.6231097121965172`, 1.3899582874473329`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.6231097121965172`, 1.3899582874473329`}, {
       2.6231097121965172`, 1.3899582874473329`}}, {{2.6231097121965172`, 
       1.3899582874473329`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.6231097121965172`, 
       1.3899582874473329`}, {2.6231097121965172`, 1.3899582874473329`}}, {{
       2.5671757864471125`, 1.3381094701746366`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}}, {{2.5671757864471125`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.5671757864471125`, 1.3381094701746366`}, {
       2.5671757864471125`, 1.3381094701746366`}}, {{2.5671757864471125`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.5671757864471125`, 
       1.3381094701746366`}, {2.5671757864471125`, 1.3381094701746366`}}, {{
       2.5671757864471125`, 1.3381094701746366`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.5671757864471125`, 1.3381094701746366`}, {2.5671757864471125`, 
       1.3381094701746366`}}, {{2.4943064306580776`, 1.3155936781786077`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}}, {{2.4943064306580776`, 
       1.3155936781786077`}, {2.3954380777291933`, 1.3381094701746366`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.4943064306580776`, 
       1.3155936781786077`}, {2.4943064306580776`, 1.3155936781786077`}}, {{
       2.4943064306580776`, 1.3155936781786077`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.3954380777291933`, 1.3381094701746366`}, {
       2.4943064306580776`, 1.3155936781786077`}, {2.4943064306580776`, 
       1.3155936781786077`}}, {{2.4943064306580776`, 1.3155936781786077`}, {
       2.3954380777291933`, 1.3381094701746366`}, {2.3954380777291933`, 
       1.3381094701746366`}, {2.4943064306580776`, 1.3155936781786077`}, {
       2.4943064306580776`, 1.3155936781786077`}}, {{2.3954380777291933`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}}, {{
       2.3954380777291933`, 1.635567907249537}, {2.4943064306580776`, 
       1.6580836992455659`}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.3954380777291933`, 1.635567907249537}, {2.3954380777291933`, 
       1.635567907249537}}, {{2.3954380777291933`, 1.635567907249537}, {
       2.4943064306580776`, 1.6580836992455659`}, {2.4943064306580776`, 
       1.6580836992455659`}, {2.3954380777291933`, 1.635567907249537}, {
       2.3954380777291933`, 1.635567907249537}}, {{2.3954380777291933`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}, {2.3954380777291933`, 
       1.635567907249537}, {2.3954380777291933`, 1.635567907249537}}, {{
       2.4943064306580776`, 1.6580836992455659`}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.4943064306580776`, 1.6580836992455659`}, {2.4943064306580776`, 
       1.6580836992455659`}}, {{2.4943064306580776`, 1.6580836992455659`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}, {2.4943064306580776`, 1.6580836992455659`}, {
       2.4943064306580776`, 1.6580836992455659`}}, {{2.4943064306580776`, 
       1.6580836992455659`}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}, {2.4943064306580776`, 
       1.6580836992455659`}, {2.4943064306580776`, 1.6580836992455659`}}, {{
       2.4943064306580776`, 1.6580836992455659`}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}, {
       2.4943064306580776`, 1.6580836992455659`}, {2.4943064306580776`, 
       1.6580836992455659`}}, {{2.5671757864471125`, 1.635567907249537}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}}, {{2.5671757864471125`, 
       1.635567907249537}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.5671757864471125`, 
       1.635567907249537}, {2.5671757864471125`, 1.635567907249537}}, {{
       2.5671757864471125`, 1.635567907249537}, {2.6231097121965172`, 
       1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.5671757864471125`, 1.635567907249537}, {2.5671757864471125`, 
       1.635567907249537}}, {{2.5671757864471125`, 1.635567907249537}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}, {2.5671757864471125`, 1.635567907249537}, {
       2.5671757864471125`, 1.635567907249537}}, {{2.6231097121965172`, 
       1.5837190899768407`}, {2.653044640806072, 1.4868386887120868`}, {
       2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`, 
       1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}}, {{
       2.6231097121965172`, 1.5837190899768407`}, {2.653044640806072, 
       1.4868386887120868`}, {2.653044640806072, 1.4868386887120868`}, {
       2.6231097121965172`, 1.5837190899768407`}, {2.6231097121965172`, 
       1.5837190899768407`}}, {{2.6231097121965172`, 1.5837190899768407`}, {
       2.653044640806072, 1.4868386887120868`}, {2.653044640806072, 
       1.4868386887120868`}, {2.6231097121965172`, 1.5837190899768407`}, {
       2.6231097121965172`, 1.5837190899768407`}}, {{2.6231097121965172`, 
       1.5837190899768407`}, {2.653044640806072, 1.4868386887120868`}, {
       2.653044640806072, 1.4868386887120868`}, {2.6231097121965172`, 
       1.5837190899768407`}, {2.6231097121965172`, 1.5837190899768407`}}, {{
       2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353, 
       1.9073760379293059`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}, {{2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}}, {{2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 1.8895945500452707`}, {
       2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`, 
       1.8308662850592528`}, {2.4095616521939496`, 1.8486477729432877`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4876413582078234`, 
       1.8308662850592528`}, {2.545188770588818, 1.8486477729432877`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.6130023297862524`, 1.9661043029153238`}}, {{
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}, {{2.4095616521939496`, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.545188770588818, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4095616521939496`, 2.08356083288736}, {
       2.4095616521939496`, 2.08356083288736}}, {{2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}}, {{
       2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353, 
       1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}, {{2.4095616521939496`, 1.8486477729432877`}, {
       2.355122578962353, 1.9073760379293059`}, {2.355122578962353, 
       1.9073760379293059`}, {2.4095616521939496`, 1.8486477729432877`}, {
       2.4095616521939496`, 1.8486477729432877`}}, {{2.4095616521939496`, 
       1.8486477729432877`}, {2.355122578962353, 1.9073760379293059`}, {
       2.355122578962353, 1.9073760379293059`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4095616521939496`, 1.8486477729432877`}}, {{
       2.4095616521939496`, 1.8486477729432877`}, {2.355122578962353, 
       1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}}, {{2.355122578962353, 1.9073760379293059`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.355122578962353, 1.9073760379293059`}, {
       2.355122578962353, 1.9073760379293059`}}, {{2.355122578962353, 
       1.9073760379293059`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.355122578962353, 
       1.9073760379293059`}, {2.355122578962353, 1.9073760379293059`}}, {{
       2.355122578962353, 1.9073760379293059`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 1.9073760379293059`}, {2.355122578962353, 
       1.9073760379293059`}}, {{2.355122578962353, 1.9073760379293059`}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.355122578962353, 1.9073760379293059`}, {
       2.355122578962353, 1.9073760379293059`}}, {{2.3417480929965153`, 
       1.9661043029153238`}, {2.355122578962353, 2.024832567901342}, {
       2.355122578962353, 2.024832567901342}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}}, {{
       2.3417480929965153`, 1.9661043029153238`}, {2.355122578962353, 
       2.024832567901342}, {2.355122578962353, 2.024832567901342}, {
       2.3417480929965153`, 1.9661043029153238`}, {2.3417480929965153`, 
       1.9661043029153238`}}, {{2.3417480929965153`, 1.9661043029153238`}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}, {2.3417480929965153`, 1.9661043029153238`}, {
       2.3417480929965153`, 1.9661043029153238`}}, {{2.3417480929965153`, 
       1.9661043029153238`}, {2.355122578962353, 2.024832567901342}, {
       2.355122578962353, 2.024832567901342}, {2.3417480929965153`, 
       1.9661043029153238`}, {2.3417480929965153`, 1.9661043029153238`}}, {{
       2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}}, {{2.355122578962353, 2.024832567901342}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}, {2.355122578962353, 2.024832567901342}, {
       2.355122578962353, 2.024832567901342}}, {{2.355122578962353, 
       2.024832567901342}, {2.4095616521939496`, 2.08356083288736}, {
       2.4095616521939496`, 2.08356083288736}, {2.355122578962353, 
       2.024832567901342}, {2.355122578962353, 2.024832567901342}}, {{
       2.355122578962353, 2.024832567901342}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}, {
       2.355122578962353, 2.024832567901342}, {2.355122578962353, 
       2.024832567901342}}, {{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}, {{2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 1.8895945500452707`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.6130023297862524`, 1.9661043029153238`}}, {{
       2.6130023297862524`, 1.9661043029153238`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.5893616970039752`, 1.8895945500452707`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}}, {{2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}}, {{2.5893616970039752`, 
       1.8895945500452707`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.5893616970039752`, 1.8895945500452707`}}, {{
       2.5893616970039752`, 1.8895945500452707`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}, {
       2.5893616970039752`, 1.8895945500452707`}, {2.5893616970039752`, 
       1.8895945500452707`}}, {{2.5893616970039752`, 1.8895945500452707`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}, {2.5893616970039752`, 1.8895945500452707`}, {
       2.5893616970039752`, 1.8895945500452707`}}, {{2.5893616970039752`, 
       1.8895945500452707`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}, {2.5893616970039752`, 
       1.8895945500452707`}, {2.5893616970039752`, 1.8895945500452707`}}, {{
       2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`, 
       1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}, {{2.545188770588818, 1.8486477729432877`}, {
       2.4876413582078234`, 1.8308662850592528`}, {2.4876413582078234`, 
       1.8308662850592528`}, {2.545188770588818, 1.8486477729432877`}, {
       2.545188770588818, 1.8486477729432877`}}, {{2.545188770588818, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}, {2.545188770588818, 
       1.8486477729432877`}, {2.545188770588818, 1.8486477729432877`}}, {{
       2.545188770588818, 1.8486477729432877`}, {2.4876413582078234`, 
       1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.545188770588818, 1.8486477729432877`}, {2.545188770588818, 
       1.8486477729432877`}}, {{2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}}, {{2.4876413582078234`, 
       1.8308662850592528`}, {2.4095616521939496`, 1.8486477729432877`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4876413582078234`, 
       1.8308662850592528`}, {2.4876413582078234`, 1.8308662850592528`}}, {{
       2.4876413582078234`, 1.8308662850592528`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4095616521939496`, 1.8486477729432877`}, {
       2.4876413582078234`, 1.8308662850592528`}, {2.4876413582078234`, 
       1.8308662850592528`}}, {{2.4876413582078234`, 1.8308662850592528`}, {
       2.4095616521939496`, 1.8486477729432877`}, {2.4095616521939496`, 
       1.8486477729432877`}, {2.4876413582078234`, 1.8308662850592528`}, {
       2.4876413582078234`, 1.8308662850592528`}}, {{2.4095616521939496`, 
       2.08356083288736}, {2.4876413582078234`, 2.101342320771395}, {
       2.4876413582078234`, 2.101342320771395}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}}, {{
       2.4095616521939496`, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4876413582078234`, 2.101342320771395}, {
       2.4095616521939496`, 2.08356083288736}, {2.4095616521939496`, 
       2.08356083288736}}, {{2.4095616521939496`, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}, {2.4095616521939496`, 2.08356083288736}, {
       2.4095616521939496`, 2.08356083288736}}, {{2.4095616521939496`, 
       2.08356083288736}, {2.4876413582078234`, 2.101342320771395}, {
       2.4876413582078234`, 2.101342320771395}, {2.4095616521939496`, 
       2.08356083288736}, {2.4095616521939496`, 2.08356083288736}}, {{
       2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}}, {{2.4876413582078234`, 2.101342320771395}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}, {2.4876413582078234`, 2.101342320771395}, {
       2.4876413582078234`, 2.101342320771395}}, {{2.4876413582078234`, 
       2.101342320771395}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}, {2.4876413582078234`, 
       2.101342320771395}, {2.4876413582078234`, 2.101342320771395}}, {{
       2.4876413582078234`, 2.101342320771395}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}, {
       2.4876413582078234`, 2.101342320771395}, {2.4876413582078234`, 
       2.101342320771395}}, {{2.545188770588818, 2.08356083288736}, {
       2.5893616970039752`, 2.0426140557853767`}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}}, {{2.545188770588818, 
       2.08356083288736}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.5893616970039752`, 2.0426140557853767`}, {2.545188770588818, 
       2.08356083288736}, {2.545188770588818, 2.08356083288736}}, {{
       2.545188770588818, 2.08356083288736}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.545188770588818, 2.08356083288736}, {2.545188770588818, 
       2.08356083288736}}, {{2.545188770588818, 2.08356083288736}, {
       2.5893616970039752`, 2.0426140557853767`}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.545188770588818, 2.08356083288736}, {
       2.545188770588818, 2.08356083288736}}, {{2.5893616970039752`, 
       2.0426140557853767`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}}, {{
       2.5893616970039752`, 2.0426140557853767`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.5893616970039752`, 2.0426140557853767`}, {2.5893616970039752`, 
       2.0426140557853767`}}, {{2.5893616970039752`, 2.0426140557853767`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.6130023297862524`, 
       1.9661043029153238`}, {2.5893616970039752`, 2.0426140557853767`}, {
       2.5893616970039752`, 2.0426140557853767`}}, {{2.5893616970039752`, 
       2.0426140557853767`}, {2.6130023297862524`, 1.9661043029153238`}, {
       2.6130023297862524`, 1.9661043029153238`}, {2.5893616970039752`, 
       2.0426140557853767`}, {2.5893616970039752`, 2.0426140557853767`}}, {{
       2.4244243699269568`, 2.4042167880991805`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.3466967895383344`, 2.538844906481669}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.4244243699269568`, 
       2.4042167880991805`}}, {{2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}}, {{2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5139189591763444`, 
       2.383835730899222}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.5139189591763444`, 
       2.383835730899222}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.6305103297592787`, 2.4511497900904664`}, {2.6576071110928248`, 
       2.538844906481669}, {2.6576071110928248`, 2.538844906481669}}, {{
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}}, {{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}, {{2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}}, {{
       2.4244243699269568`, 2.4042167880991805`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.4244243699269568`, 
       2.4042167880991805`}}, {{2.4244243699269568`, 2.4042167880991805`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}}, {{2.4244243699269568`, 
       2.4042167880991805`}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.4244243699269568`, 
       2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}}, {{
       2.4244243699269568`, 2.4042167880991805`}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.4244243699269568`, 
       2.4042167880991805`}}, {{2.3620265620111156`, 2.4715308472904245`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}}, {{2.3620265620111156`, 
       2.4715308472904245`}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`, 
       2.4715308472904245`}, {2.3620265620111156`, 2.4715308472904245`}}, {{
       2.3620265620111156`, 2.4715308472904245`}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}, {
       2.3620265620111156`, 2.4715308472904245`}, {2.3620265620111156`, 
       2.4715308472904245`}}, {{2.3620265620111156`, 2.4715308472904245`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.4715308472904245`}, {
       2.3620265620111156`, 2.4715308472904245`}}, {{2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}}, {{
       2.3466967895383344`, 2.538844906481669}, {2.3620265620111156`, 
       2.6061589656729134`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3466967895383344`, 2.538844906481669}, {2.3466967895383344`, 
       2.538844906481669}}, {{2.3466967895383344`, 2.538844906481669}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.3620265620111156`, 
       2.6061589656729134`}, {2.3466967895383344`, 2.538844906481669}, {
       2.3466967895383344`, 2.538844906481669}}, {{2.3466967895383344`, 
       2.538844906481669}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.3466967895383344`, 
       2.538844906481669}, {2.3466967895383344`, 2.538844906481669}}, {{
       2.3620265620111156`, 2.6061589656729134`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.3620265620111156`, 
       2.6061589656729134`}}, {{2.3620265620111156`, 2.6061589656729134`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.3620265620111156`, 2.6061589656729134`}, {
       2.3620265620111156`, 2.6061589656729134`}}, {{2.3620265620111156`, 
       2.6061589656729134`}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.3620265620111156`, 
       2.6061589656729134`}, {2.3620265620111156`, 2.6061589656729134`}}, {{
       2.3620265620111156`, 2.6061589656729134`}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.3620265620111156`, 2.6061589656729134`}, {2.3620265620111156`, 
       2.6061589656729134`}}, {{2.6576071110928248`, 2.538844906481669}, {
       2.6305103297592787`, 2.4511497900904664`}, {2.6305103297592787`, 
       2.4511497900904664`}, {2.6576071110928248`, 2.538844906481669}, {
       2.6576071110928248`, 2.538844906481669}}, {{2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6305103297592787`, 2.4511497900904664`}, {2.6576071110928248`, 
       2.538844906481669}, {2.6576071110928248`, 2.538844906481669}}, {{
       2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`, 
       2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}}, {{2.6576071110928248`, 2.538844906481669}, {
       2.6305103297592787`, 2.4511497900904664`}, {2.6305103297592787`, 
       2.4511497900904664`}, {2.6576071110928248`, 2.538844906481669}, {
       2.6576071110928248`, 2.538844906481669}}, {{2.6305103297592787`, 
       2.4511497900904664`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.6305103297592787`, 
       2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}}, {{
       2.6305103297592787`, 2.4511497900904664`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.6305103297592787`, 2.4511497900904664`}, {2.6305103297592787`, 
       2.4511497900904664`}}, {{2.6305103297592787`, 2.4511497900904664`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.6305103297592787`, 2.4511497900904664`}, {
       2.6305103297592787`, 2.4511497900904664`}}, {{2.6305103297592787`, 
       2.4511497900904664`}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.6305103297592787`, 
       2.4511497900904664`}, {2.6305103297592787`, 2.4511497900904664`}}, {{
       2.5798795307042024`, 2.4042167880991805`}, {2.5139189591763444`, 
       2.383835730899222}, {2.5139189591763444`, 2.383835730899222}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}}, {{2.5798795307042024`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}, {2.5798795307042024`, 2.4042167880991805`}, {
       2.5798795307042024`, 2.4042167880991805`}}, {{2.5798795307042024`, 
       2.4042167880991805`}, {2.5139189591763444`, 2.383835730899222}, {
       2.5139189591763444`, 2.383835730899222}, {2.5798795307042024`, 
       2.4042167880991805`}, {2.5798795307042024`, 2.4042167880991805`}}, {{
       2.5798795307042024`, 2.4042167880991805`}, {2.5139189591763444`, 
       2.383835730899222}, {2.5139189591763444`, 2.383835730899222}, {
       2.5798795307042024`, 2.4042167880991805`}, {2.5798795307042024`, 
       2.4042167880991805`}}, {{2.5139189591763444`, 2.383835730899222}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.4244243699269568`, 
       2.4042167880991805`}, {2.5139189591763444`, 2.383835730899222}, {
       2.5139189591763444`, 2.383835730899222}}, {{2.5139189591763444`, 
       2.383835730899222}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.5139189591763444`, 
       2.383835730899222}, {2.5139189591763444`, 2.383835730899222}}, {{
       2.5139189591763444`, 2.383835730899222}, {2.4244243699269568`, 
       2.4042167880991805`}, {2.4244243699269568`, 2.4042167880991805`}, {
       2.5139189591763444`, 2.383835730899222}, {2.5139189591763444`, 
       2.383835730899222}}, {{2.5139189591763444`, 2.383835730899222}, {
       2.4244243699269568`, 2.4042167880991805`}, {2.4244243699269568`, 
       2.4042167880991805`}, {2.5139189591763444`, 2.383835730899222}, {
       2.5139189591763444`, 2.383835730899222}}, {{2.4244243699269568`, 
       2.6734730248641574`}, {2.5139189591763444`, 2.693854082064116}, {
       2.5139189591763444`, 2.693854082064116}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.4244243699269568`, 2.6734730248641574`}}, {{
       2.4244243699269568`, 2.6734730248641574`}, {2.5139189591763444`, 
       2.693854082064116}, {2.5139189591763444`, 2.693854082064116}, {
       2.4244243699269568`, 2.6734730248641574`}, {2.4244243699269568`, 
       2.6734730248641574`}}, {{2.4244243699269568`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}, {2.4244243699269568`, 2.6734730248641574`}, {
       2.4244243699269568`, 2.6734730248641574`}}, {{2.4244243699269568`, 
       2.6734730248641574`}, {2.5139189591763444`, 2.693854082064116}, {
       2.5139189591763444`, 2.693854082064116}, {2.4244243699269568`, 
       2.6734730248641574`}, {2.4244243699269568`, 2.6734730248641574`}}, {{
       2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}}, {{2.5139189591763444`, 2.693854082064116}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5139189591763444`, 2.693854082064116}, {
       2.5139189591763444`, 2.693854082064116}}, {{2.5139189591763444`, 
       2.693854082064116}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5139189591763444`, 
       2.693854082064116}, {2.5139189591763444`, 2.693854082064116}}, {{
       2.5139189591763444`, 2.693854082064116}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5139189591763444`, 2.693854082064116}, {2.5139189591763444`, 
       2.693854082064116}}, {{2.5798795307042024`, 2.6734730248641574`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}, {{2.5798795307042024`, 
       2.6734730248641574`}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.5798795307042024`, 
       2.6734730248641574`}, {2.5798795307042024`, 2.6734730248641574`}}, {{
       2.5798795307042024`, 2.6734730248641574`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.5798795307042024`, 2.6734730248641574`}, {2.5798795307042024`, 
       2.6734730248641574`}}, {{2.5798795307042024`, 2.6734730248641574`}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.5798795307042024`, 2.6734730248641574`}, {
       2.5798795307042024`, 2.6734730248641574`}}, {{2.6305103297592787`, 
       2.6265400228728715`}, {2.6576071110928248`, 2.538844906481669}, {
       2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.6305103297592787`, 2.6265400228728715`}}, {{
       2.6305103297592787`, 2.6265400228728715`}, {2.6576071110928248`, 
       2.538844906481669}, {2.6576071110928248`, 2.538844906481669}, {
       2.6305103297592787`, 2.6265400228728715`}, {2.6305103297592787`, 
       2.6265400228728715`}}, {{2.6305103297592787`, 2.6265400228728715`}, {
       2.6576071110928248`, 2.538844906481669}, {2.6576071110928248`, 
       2.538844906481669}, {2.6305103297592787`, 2.6265400228728715`}, {
       2.6305103297592787`, 2.6265400228728715`}}, {{2.6305103297592787`, 
       2.6265400228728715`}, {2.6576071110928248`, 2.538844906481669}, {
       2.6576071110928248`, 2.538844906481669}, {2.6305103297592787`, 
       2.6265400228728715`}, {2.6305103297592787`, 2.6265400228728715`}}, {{
       2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.301431734658341, 
       2.981364336584796}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}, {{2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}}, {{2.618868429037922, 
       2.981364336584796}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.4721640940456706`, 
       2.823101336342869}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.4721640940456706`, 
       2.823101336342869}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5912028544380137`, 2.8918283966993874`}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}}, {{
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}}, {{2.3807909082532364`, 3.118818457297833}, {
       2.4721640940456706`, 3.1396273368267233`}, {2.5395092554430265`, 
       3.118818457297833}, {2.5912028544380137`, 3.070900276470205}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}, {2.5912028544380137`, 3.070900276470205}, {
       2.5395092554430265`, 3.118818457297833}, {2.4721640940456706`, 
       3.1396273368267233`}, {2.3807909082532364`, 3.118818457297833}, {
       2.3807909082532364`, 3.118818457297833}}, {{2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}}, {{
       2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}, {{2.3807909082532364`, 2.8439102158717593`}, {
       2.31708329706071, 2.9126372762282777`}, {2.31708329706071, 
       2.9126372762282777`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.3807909082532364`, 2.8439102158717593`}}, {{2.3807909082532364`, 
       2.8439102158717593`}, {2.31708329706071, 2.9126372762282777`}, {
       2.31708329706071, 2.9126372762282777`}, {2.3807909082532364`, 
       2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}}, {{
       2.3807909082532364`, 2.8439102158717593`}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}}, {{2.31708329706071, 2.9126372762282777`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.31708329706071, 2.9126372762282777`}, {
       2.31708329706071, 2.9126372762282777`}}, {{2.31708329706071, 
       2.9126372762282777`}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}, {2.31708329706071, 
       2.9126372762282777`}, {2.31708329706071, 2.9126372762282777`}}, {{
       2.31708329706071, 2.9126372762282777`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 2.9126372762282777`}, {2.31708329706071, 
       2.9126372762282777`}}, {{2.31708329706071, 2.9126372762282777`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}, {2.31708329706071, 2.9126372762282777`}, {
       2.31708329706071, 2.9126372762282777`}}, {{2.301431734658341, 
       2.981364336584796}, {2.31708329706071, 3.0500913969413146`}, {
       2.31708329706071, 3.0500913969413146`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}}, {{
       2.301431734658341, 2.981364336584796}, {2.31708329706071, 
       3.0500913969413146`}, {2.31708329706071, 3.0500913969413146`}, {
       2.301431734658341, 2.981364336584796}, {2.301431734658341, 
       2.981364336584796}}, {{2.301431734658341, 2.981364336584796}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}, {2.301431734658341, 2.981364336584796}, {
       2.301431734658341, 2.981364336584796}}, {{2.301431734658341, 
       2.981364336584796}, {2.31708329706071, 3.0500913969413146`}, {
       2.31708329706071, 3.0500913969413146`}, {2.301431734658341, 
       2.981364336584796}, {2.301431734658341, 2.981364336584796}}, {{
       2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}}, {{2.31708329706071, 3.0500913969413146`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}, {2.31708329706071, 3.0500913969413146`}, {
       2.31708329706071, 3.0500913969413146`}}, {{2.31708329706071, 
       3.0500913969413146`}, {2.3807909082532364`, 3.118818457297833}, {
       2.3807909082532364`, 3.118818457297833}, {2.31708329706071, 
       3.0500913969413146`}, {2.31708329706071, 3.0500913969413146`}}, {{
       2.31708329706071, 3.0500913969413146`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}, {
       2.31708329706071, 3.0500913969413146`}, {2.31708329706071, 
       3.0500913969413146`}}, {{2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 2.8918283966993874`}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.618868429037922, 2.981364336584796}, {
       2.618868429037922, 2.981364336584796}}, {{2.618868429037922, 
       2.981364336584796}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5912028544380137`, 2.8918283966993874`}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}}, {{
       2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}}, {{2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 2.8918283966993874`}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.618868429037922, 2.981364336584796}, {
       2.618868429037922, 2.981364336584796}}, {{2.5912028544380137`, 
       2.8918283966993874`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}}, {{
       2.5912028544380137`, 2.8918283966993874`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5912028544380137`, 2.8918283966993874`}, {2.5912028544380137`, 
       2.8918283966993874`}}, {{2.5912028544380137`, 2.8918283966993874`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5912028544380137`, 2.8918283966993874`}, {
       2.5912028544380137`, 2.8918283966993874`}}, {{2.5912028544380137`, 
       2.8918283966993874`}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5912028544380137`, 
       2.8918283966993874`}, {2.5912028544380137`, 2.8918283966993874`}}, {{
       2.5395092554430265`, 2.8439102158717593`}, {2.4721640940456706`, 
       2.823101336342869}, {2.4721640940456706`, 2.823101336342869}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}}, {{2.5395092554430265`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}, {2.5395092554430265`, 2.8439102158717593`}, {
       2.5395092554430265`, 2.8439102158717593`}}, {{2.5395092554430265`, 
       2.8439102158717593`}, {2.4721640940456706`, 2.823101336342869}, {
       2.4721640940456706`, 2.823101336342869}, {2.5395092554430265`, 
       2.8439102158717593`}, {2.5395092554430265`, 2.8439102158717593`}}, {{
       2.5395092554430265`, 2.8439102158717593`}, {2.4721640940456706`, 
       2.823101336342869}, {2.4721640940456706`, 2.823101336342869}, {
       2.5395092554430265`, 2.8439102158717593`}, {2.5395092554430265`, 
       2.8439102158717593`}}, {{2.4721640940456706`, 2.823101336342869}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}, {2.4721640940456706`, 2.823101336342869}, {
       2.4721640940456706`, 2.823101336342869}}, {{2.4721640940456706`, 
       2.823101336342869}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.4721640940456706`, 
       2.823101336342869}, {2.4721640940456706`, 2.823101336342869}}, {{
       2.4721640940456706`, 2.823101336342869}, {2.3807909082532364`, 
       2.8439102158717593`}, {2.3807909082532364`, 2.8439102158717593`}, {
       2.4721640940456706`, 2.823101336342869}, {2.4721640940456706`, 
       2.823101336342869}}, {{2.4721640940456706`, 2.823101336342869}, {
       2.3807909082532364`, 2.8439102158717593`}, {2.3807909082532364`, 
       2.8439102158717593`}, {2.4721640940456706`, 2.823101336342869}, {
       2.4721640940456706`, 2.823101336342869}}, {{2.3807909082532364`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}}, {{
       2.3807909082532364`, 3.118818457297833}, {2.4721640940456706`, 
       3.1396273368267233`}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.3807909082532364`, 3.118818457297833}, {2.3807909082532364`, 
       3.118818457297833}}, {{2.3807909082532364`, 3.118818457297833}, {
       2.4721640940456706`, 3.1396273368267233`}, {2.4721640940456706`, 
       3.1396273368267233`}, {2.3807909082532364`, 3.118818457297833}, {
       2.3807909082532364`, 3.118818457297833}}, {{2.3807909082532364`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}, {2.3807909082532364`, 
       3.118818457297833}, {2.3807909082532364`, 3.118818457297833}}, {{
       2.4721640940456706`, 3.1396273368267233`}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.4721640940456706`, 3.1396273368267233`}, {2.4721640940456706`, 
       3.1396273368267233`}}, {{2.4721640940456706`, 3.1396273368267233`}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}, {2.4721640940456706`, 3.1396273368267233`}, {
       2.4721640940456706`, 3.1396273368267233`}}, {{2.4721640940456706`, 
       3.1396273368267233`}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}, {2.4721640940456706`, 
       3.1396273368267233`}, {2.4721640940456706`, 3.1396273368267233`}}, {{
       2.4721640940456706`, 3.1396273368267233`}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}, {
       2.4721640940456706`, 3.1396273368267233`}, {2.4721640940456706`, 
       3.1396273368267233`}}, {{2.5395092554430265`, 3.118818457297833}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}}, {{2.5395092554430265`, 
       3.118818457297833}, {2.5912028544380137`, 3.070900276470205}, {
       2.5912028544380137`, 3.070900276470205}, {2.5395092554430265`, 
       3.118818457297833}, {2.5395092554430265`, 3.118818457297833}}, {{
       2.5395092554430265`, 3.118818457297833}, {2.5912028544380137`, 
       3.070900276470205}, {2.5912028544380137`, 3.070900276470205}, {
       2.5395092554430265`, 3.118818457297833}, {2.5395092554430265`, 
       3.118818457297833}}, {{2.5395092554430265`, 3.118818457297833}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}, {2.5395092554430265`, 3.118818457297833}, {
       2.5395092554430265`, 3.118818457297833}}, {{2.5912028544380137`, 
       3.070900276470205}, {2.618868429037922, 2.981364336584796}, {
       2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       3.070900276470205}, {2.5912028544380137`, 3.070900276470205}}, {{
       2.5912028544380137`, 3.070900276470205}, {2.618868429037922, 
       2.981364336584796}, {2.618868429037922, 2.981364336584796}, {
       2.5912028544380137`, 3.070900276470205}, {2.5912028544380137`, 
       3.070900276470205}}, {{2.5912028544380137`, 3.070900276470205}, {
       2.618868429037922, 2.981364336584796}, {2.618868429037922, 
       2.981364336584796}, {2.5912028544380137`, 3.070900276470205}, {
       2.5912028544380137`, 3.070900276470205}}, {{2.5912028544380137`, 
       3.070900276470205}, {2.618868429037922, 2.981364336584796}, {
       2.618868429037922, 2.981364336584796}, {2.5912028544380137`, 
       3.070900276470205}, {2.5912028544380137`, 3.070900276470205}}, {{
       2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.351811450299151, 
       3.468550018932752}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}, {{2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}}, {{2.69941577430308, 
       3.468550018932752}, {2.669120998912425, 3.3705050215868937`}, {
       2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.438712531300133, 3.318032931406392}, {
       2.438712531300133, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.612514693302098, 3.318032931406392}, {
       2.669120998912425, 3.3705050215868937`}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}}, {{
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}, {{2.438712531300133, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098, 
       3.6190671064591116`}, {2.669120998912425, 3.56659501627861}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}, {2.669120998912425, 3.56659501627861}, {
       2.612514693302098, 3.6190671064591116`}, {2.5387693774109517`, 
       3.6418535600417896`}, {2.438712531300133, 3.6190671064591116`}, {
       2.438712531300133, 3.6190671064591116`}}, {{2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}}, {{
       2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}, {{2.438712531300133, 3.318032931406392}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.438712531300133, 3.318032931406392}, {
       2.438712531300133, 3.318032931406392}}, {{2.438712531300133, 
       3.318032931406392}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}}, {{
       2.438712531300133, 3.318032931406392}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}}, {{2.3689504605799696`, 3.3932914751695717`}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.3689504605799696`, 3.3932914751695717`}}, {{2.3689504605799696`, 
       3.3932914751695717`}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}, {2.3689504605799696`, 
       3.3932914751695717`}, {2.3689504605799696`, 3.3932914751695717`}}, {{
       2.3689504605799696`, 3.3932914751695717`}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.3932914751695717`}, {2.3689504605799696`, 
       3.3932914751695717`}}, {{2.3689504605799696`, 3.3932914751695717`}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}, {2.3689504605799696`, 3.3932914751695717`}, {
       2.3689504605799696`, 3.3932914751695717`}}, {{2.351811450299151, 
       3.468550018932752}, {2.3689504605799696`, 3.543808562695932}, {
       2.3689504605799696`, 3.543808562695932}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}}, {{
       2.351811450299151, 3.468550018932752}, {2.3689504605799696`, 
       3.543808562695932}, {2.3689504605799696`, 3.543808562695932}, {
       2.351811450299151, 3.468550018932752}, {2.351811450299151, 
       3.468550018932752}}, {{2.351811450299151, 3.468550018932752}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}, {2.351811450299151, 3.468550018932752}, {
       2.351811450299151, 3.468550018932752}}, {{2.351811450299151, 
       3.468550018932752}, {2.3689504605799696`, 3.543808562695932}, {
       2.3689504605799696`, 3.543808562695932}, {2.351811450299151, 
       3.468550018932752}, {2.351811450299151, 3.468550018932752}}, {{
       2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}}, {{2.3689504605799696`, 3.543808562695932}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}, {2.3689504605799696`, 3.543808562695932}, {
       2.3689504605799696`, 3.543808562695932}}, {{2.3689504605799696`, 
       3.543808562695932}, {2.438712531300133, 3.6190671064591116`}, {
       2.438712531300133, 3.6190671064591116`}, {2.3689504605799696`, 
       3.543808562695932}, {2.3689504605799696`, 3.543808562695932}}, {{
       2.3689504605799696`, 3.543808562695932}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}, {
       2.3689504605799696`, 3.543808562695932}, {2.3689504605799696`, 
       3.543808562695932}}, {{2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}, {2.69941577430308, 3.468550018932752}, {
       2.69941577430308, 3.468550018932752}}, {{2.69941577430308, 
       3.468550018932752}, {2.669120998912425, 3.3705050215868937`}, {
       2.669120998912425, 3.3705050215868937`}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}}, {{
       2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}}, {{2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}, {2.69941577430308, 3.468550018932752}, {
       2.69941577430308, 3.468550018932752}}, {{2.669120998912425, 
       3.3705050215868937`}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}}, {{
       2.669120998912425, 3.3705050215868937`}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}, {
       2.669120998912425, 3.3705050215868937`}, {2.669120998912425, 
       3.3705050215868937`}}, {{2.669120998912425, 3.3705050215868937`}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}, {2.669120998912425, 3.3705050215868937`}, {
       2.669120998912425, 3.3705050215868937`}}, {{2.669120998912425, 
       3.3705050215868937`}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}, {2.669120998912425, 
       3.3705050215868937`}, {2.669120998912425, 3.3705050215868937`}}, {{
       2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}, {{2.612514693302098, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.5387693774109517`, 
       3.295246477823714}, {2.612514693302098, 3.318032931406392}, {
       2.612514693302098, 3.318032931406392}}, {{2.612514693302098, 
       3.318032931406392}, {2.5387693774109517`, 3.295246477823714}, {
       2.5387693774109517`, 3.295246477823714}, {2.612514693302098, 
       3.318032931406392}, {2.612514693302098, 3.318032931406392}}, {{
       2.612514693302098, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}, {
       2.612514693302098, 3.318032931406392}, {2.612514693302098, 
       3.318032931406392}}, {{2.5387693774109517`, 3.295246477823714}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}, {2.5387693774109517`, 3.295246477823714}, {
       2.5387693774109517`, 3.295246477823714}}, {{2.5387693774109517`, 
       3.295246477823714}, {2.438712531300133, 3.318032931406392}, {
       2.438712531300133, 3.318032931406392}, {2.5387693774109517`, 
       3.295246477823714}, {2.5387693774109517`, 3.295246477823714}}, {{
       2.5387693774109517`, 3.295246477823714}, {2.438712531300133, 
       3.318032931406392}, {2.438712531300133, 3.318032931406392}, {
       2.5387693774109517`, 3.295246477823714}, {2.5387693774109517`, 
       3.295246477823714}}, {{2.5387693774109517`, 3.295246477823714}, {
       2.438712531300133, 3.318032931406392}, {2.438712531300133, 
       3.318032931406392}, {2.5387693774109517`, 3.295246477823714}, {
       2.5387693774109517`, 3.295246477823714}}, {{2.438712531300133, 
       3.6190671064591116`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}}, {{
       2.438712531300133, 3.6190671064591116`}, {2.5387693774109517`, 
       3.6418535600417896`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.438712531300133, 3.6190671064591116`}, {2.438712531300133, 
       3.6190671064591116`}}, {{2.438712531300133, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}, {2.438712531300133, 3.6190671064591116`}, {
       2.438712531300133, 3.6190671064591116`}}, {{2.438712531300133, 
       3.6190671064591116`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.438712531300133, 
       3.6190671064591116`}, {2.438712531300133, 3.6190671064591116`}}, {{
       2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}}, {{2.5387693774109517`, 3.6418535600417896`}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}, {2.5387693774109517`, 3.6418535600417896`}, {
       2.5387693774109517`, 3.6418535600417896`}}, {{2.5387693774109517`, 
       3.6418535600417896`}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}, {2.5387693774109517`, 
       3.6418535600417896`}, {2.5387693774109517`, 3.6418535600417896`}}, {{
       2.5387693774109517`, 3.6418535600417896`}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}, {
       2.5387693774109517`, 3.6418535600417896`}, {2.5387693774109517`, 
       3.6418535600417896`}}, {{2.612514693302098, 3.6190671064591116`}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}}, {{2.612514693302098, 
       3.6190671064591116`}, {2.669120998912425, 3.56659501627861}, {
       2.669120998912425, 3.56659501627861}, {2.612514693302098, 
       3.6190671064591116`}, {2.612514693302098, 3.6190671064591116`}}, {{
       2.612514693302098, 3.6190671064591116`}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}, {
       2.612514693302098, 3.6190671064591116`}, {2.612514693302098, 
       3.6190671064591116`}}, {{2.612514693302098, 3.6190671064591116`}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}, {2.612514693302098, 3.6190671064591116`}, {
       2.612514693302098, 3.6190671064591116`}}, {{2.669120998912425, 
       3.56659501627861}, {2.69941577430308, 3.468550018932752}, {
       2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}}, {{
       2.669120998912425, 3.56659501627861}, {2.69941577430308, 
       3.468550018932752}, {2.69941577430308, 3.468550018932752}, {
       2.669120998912425, 3.56659501627861}, {2.669120998912425, 
       3.56659501627861}}, {{2.669120998912425, 3.56659501627861}, {
       2.69941577430308, 3.468550018932752}, {2.69941577430308, 
       3.468550018932752}, {2.669120998912425, 3.56659501627861}, {
       2.669120998912425, 3.56659501627861}}, {{2.669120998912425, 
       3.56659501627861}, {2.69941577430308, 3.468550018932752}, {
       2.69941577430308, 3.468550018932752}, {2.669120998912425, 
       3.56659501627861}, {2.669120998912425, 3.56659501627861}}, {{
       2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}, {{
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}, {{
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7020187365642525`, -4.3990022793182435`}, {
       2.7020187365642525`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}, {{
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}, {{
       2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}, {{
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}, {{
       2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}, {{
       2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}, {{
       2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}, {{
       2.702018736564252, -4.3990022793182435`}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}}, {{
       2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}, {{
       2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}, {{
       2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}, {{
       2.6365186476805764`, -4.328341514021901}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.328341514021901}, {
       2.6365186476805764`, -4.328341514021901}}, {{
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}, {{
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}, {{
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}, {{
       2.6204267128342758`, -4.257680748725559}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6204267128342758`, -4.257680748725559}, {
       2.6204267128342758`, -4.257680748725559}}, {{
       2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}, {{
       2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}, {{
       2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}, {{
       2.6365186476805764`, -4.1870199834292166`}, {
       2.702018736564252, -4.116359218132874}, {
       2.702018736564252, -4.116359218132874}, {
       2.6365186476805764`, -4.1870199834292166`}, {
       2.6365186476805764`, -4.1870199834292166`}}, {{
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}, {{
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}, {{
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}, {{
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}}, {{
       2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}, {{
       2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}, {{
       2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}, {{
       2.9183508343985376`, -4.349735872297132}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.9183508343985376`, -4.349735872297132}, {
       2.9183508343985376`, -4.349735872297132}}, {{
       2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}, {{
       2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}, {{
       2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}, {{
       2.8652027840242056`, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.8652027840242056`, -4.3990022793182435`}, {
       2.8652027840242056`, -4.3990022793182435`}}, {{
       2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}, {{
       2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}, {{
       2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}, {{
       2.7959627988035725`, -4.420396637593474}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.702018736564252, -4.3990022793182435`}, {
       2.7959627988035725`, -4.420396637593474}, {
       2.7959627988035725`, -4.420396637593474}}, {{
       2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}, {{
       2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}, {{
       2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}, {{
       2.7020187365642525`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7020187365642525`, -4.116359218132874}, {
       2.7020187365642525`, -4.116359218132874}}, {{
       2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}, {{
       2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}, {{
       2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}, {{
       2.7959627988035725`, -4.094964859857643}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.7959627988035725`, -4.094964859857643}, {
       2.7959627988035725`, -4.094964859857643}}, {{
       2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}, {{
       2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}, {{
       2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}, {{
       2.8652027840242056`, -4.116359218132874}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.8652027840242056`, -4.116359218132874}, {
       2.8652027840242056`, -4.116359218132874}}, {{
       2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}, {{
       2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}, {{
       2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}, {{
       2.9183508343985376`, -4.165625625153985}, {
       2.946794807754182, -4.257680748725559}, {
       2.946794807754182, -4.257680748725559}, {
       2.9183508343985376`, -4.165625625153985}, {
       2.9183508343985376`, -4.165625625153985}}, {{
       2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}, {{
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}, {{
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}, {{
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}, {{
       2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}, {{
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}, {{
       2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}, {{
       2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}, {{
       2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}, {{
       2.667206291943791, -3.86548416623189}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}}, {{
       2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}, {{
       2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}, {{
       2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}, {{
       2.6041715603267424`, -3.7974830008560634`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.7974830008560634`}, {
       2.6041715603267424`, -3.7974830008560634`}}, {{
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}, {{
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}, {{
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}, {{
       2.5886853096739073`, -3.729481835480237}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.5886853096739073`, -3.729481835480237}, {
       2.5886853096739073`, -3.729481835480237}}, {{
       2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}, {{
       2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}, {{
       2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}, {{
       2.6041715603267424`, -3.6614806701044103`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.6041715603267424`, -3.6614806701044103`}, {
       2.6041715603267424`, -3.6614806701044103`}}, {{
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}, {{
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}, {{
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}, {{
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}}, {{
       2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}, {{
       2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}, {{
       2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}, {{
       2.8753958678595533`, -3.818072097069248}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}, {
       2.8753958678595533`, -3.818072097069248}, {
       2.8753958678595533`, -3.818072097069248}}, {{
       2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}, {{
       2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}, {{
       2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}, {{
       2.824248256483558, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.824248256483558, -3.86548416623189}, {
       2.824248256483558, -3.86548416623189}}, {{
       2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}, {{
       2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}, {{
       2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}, {{
       2.757614394454728, -3.8860732624450747`}, {
       2.667206291943791, -3.86548416623189}, {
       2.667206291943791, -3.86548416623189}, {
       2.757614394454728, -3.8860732624450747`}, {
       2.757614394454728, -3.8860732624450747`}}, {{
       2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}, {{
       2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}, {{
       2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}, {{
       2.667206291943791, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}, {
       2.667206291943791, -3.5934795047285837`}, {
       2.667206291943791, -3.5934795047285837`}}, {{
       2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}, {{
       2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}, {{
       2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}, {{
       2.757614394454728, -3.572890408515399}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.757614394454728, -3.572890408515399}, {
       2.757614394454728, -3.572890408515399}}, {{
       2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}, {{
       2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}, {{
       2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}, {{
       2.824248256483558, -3.5934795047285837`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.824248256483558, -3.5934795047285837`}, {
       2.824248256483558, -3.5934795047285837`}}, {{
       2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}, {{
       2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}, {{
       2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}, {{
       2.8753958678595533`, -3.6408915738912255`}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.9027692387534416`, -3.729481835480237}, {
       2.8753958678595533`, -3.6408915738912255`}, {
       2.8753958678595533`, -3.6408915738912255`}}, {{
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}, {{
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}, {{
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.8751543228139944`, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}, {{
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}, {{
       2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}, {{
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}, {{
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}, {{
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}, {{
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}, {{
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}}, {{
       2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}, {{
       2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}, {{
       2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}, {{
       2.6045139323014532`, -3.3433558884189645`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.3433558884189645`}, {
       2.6045139323014532`, -3.3433558884189645`}}, {{
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}, {{
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}, {{
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}, {{
       2.589061021895363, -3.2755011223029324`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.589061021895363, -3.2755011223029324`}, {
       2.589061021895363, -3.2755011223029324`}}, {{
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}, {{
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}, {{
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}, {{
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6045139323014532`, -3.2076463561869004`}, {
       2.6045139323014532`, -3.2076463561869004`}}, {{
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}, {{
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}, {{
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}, {{
       2.9024687617584846`, -3.2755011223029324`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}}, {{
       2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}, {{
       2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}, {{
       2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}, {{
       2.875154322813994, -3.363900658502901}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.875154322813994, -3.363900658502901}, {
       2.875154322813994, -3.363900658502901}}, {{
       2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}, {{
       2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}, {{
       2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}, {{
       2.824116826792704, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.824116826792704, -3.4112106545349965`}, {
       2.824116826792704, -3.4112106545349965`}}, {{
       2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}, {{
       2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}, {{
       2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}, {{
       2.7576264203653236`, -3.4317554246189332`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.6674129568611433`, -3.4112106545349965`}, {
       2.7576264203653236`, -3.4317554246189332`}, {
       2.7576264203653236`, -3.4317554246189332`}}, {{
       2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}, {{
       2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}, {{
       2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}, {{
       2.6674129568611433`, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.6674129568611433`, -3.1397915900708684`}, {
       2.6674129568611433`, -3.1397915900708684`}}, {{
       2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}, {{
       2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}, {{
       2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}, {{
       2.7576264203653236`, -3.1192468199869317`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.7576264203653236`, -3.1192468199869317`}, {
       2.7576264203653236`, -3.1192468199869317`}}, {{
       2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}, {{
       2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}, {{
       2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}, {{
       2.824116826792704, -3.1397915900708684`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.875154322813994, -3.1871015861029637`}, {
       2.824116826792704, -3.1397915900708684`}, {
       2.824116826792704, -3.1397915900708684`}}, {{
       2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}, {{
       2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}, {{
       2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}, {{
       2.8751543228139944`, -3.1871015861029637`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.9024687617584846`, -3.2755011223029324`}, {
       2.8751543228139944`, -3.1871015861029637`}, {
       2.8751543228139944`, -3.1871015861029637`}}, {{
       2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}, {{
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}, {{
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}, {{
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}, {{
       2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}, {{
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}, {{
       2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}, {{
       2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}, {{
       2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}, {{
       2.661310626527749, -2.8986928513546903`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}}, {{
       2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}, {{
       2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}, {{
       2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}, {{
       2.591786408080856, -2.823690899970898}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.823690899970898}, {
       2.591786408080856, -2.823690899970898}}, {{
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}, {{
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}, {{
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}, {{
       2.57470583288539, -2.7486889485871053`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}, {
       2.57470583288539, -2.7486889485871053`}, {
       2.57470583288539, -2.7486889485871053`}}, {{
       2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}, {{
       2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}, {{
       2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}, {{
       2.591786408080856, -2.673686997203313}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.591786408080856, -2.673686997203313}, {
       2.591786408080856, -2.673686997203313}}, {{
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}, {{
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}, {{
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}, {{
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}}, {{
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}, {{
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}, {{
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}, {{
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8909335214465046`, -2.8463996636322695`}, {
       2.8909335214465046`, -2.8463996636322695`}}, {{
       2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}, {{
       2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}, {{
       2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}, {{
       2.8345202138124685`, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.8345202138124685`, -2.8986928513546903`}, {
       2.8345202138124685`, -2.8986928513546903`}}, {{
       2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}, {{
       2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}, {{
       2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}, {{
       2.7610263309829652`, -2.921401615016062}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.661310626527749, -2.8986928513546903`}, {
       2.7610263309829652`, -2.921401615016062}, {
       2.7610263309829652`, -2.921401615016062}}, {{
       2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}, {{
       2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}, {{
       2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}, {{
       2.661310626527749, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.661310626527749, -2.5986850458195203`}, {
       2.661310626527749, -2.5986850458195203`}}, {{
       2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}, {{
       2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}, {{
       2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}, {{
       2.7610263309829652`, -2.5759762821581487`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.7610263309829652`, -2.5759762821581487`}, {
       2.7610263309829652`, -2.5759762821581487`}}, {{
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}, {{
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}, {{
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}, {{
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8345202138124685`, -2.5986850458195203`}, {
       2.8345202138124685`, -2.5986850458195203`}}, {{
       2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}, {{
       2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}, {{
       2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}, {{
       2.8909335214465046`, -2.650978233541941}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.921125007454828, -2.7486889485871053`}, {
       2.8909335214465046`, -2.650978233541941}, {
       2.8909335214465046`, -2.650978233541941}}, {{
       2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}, {{
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}, {{
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}, {{
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}, {{
       2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}, {{
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}, {{
       2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}, {{
       2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}, {{
       2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}, {{
       2.6287040068975798`, -2.353340202047266}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}}, {{
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}, {{
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}, {{
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}, {{
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.2834043092377407`}, {
       2.5638758497728755`, -2.2834043092377407`}}, {{
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}, {{
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}, {{
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}, {{
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5479489938183875`, -2.2134684164282157`}, {
       2.5479489938183875`, -2.2134684164282157`}}, {{
       2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}, {{
       2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}, {{
       2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}, {{
       2.5638758497728755`, -2.1435325236186906`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.5638758497728755`, -2.1435325236186906`}, {
       2.5638758497728755`, -2.1435325236186906`}}, {{
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}, {{
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}, {{
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}, {{
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}}, {{
       2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}, {{
       2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}, {{
       2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}, {{
       2.8428168648881145`, -2.304579193783501}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.8428168648881145`, -2.304579193783501}, {
       2.8428168648881145`, -2.304579193783501}}, {{
       2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}, {{
       2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}, {{
       2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}, {{
       2.7902140330559644`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7902140330559644`, -2.353340202047266}, {
       2.7902140330559644`, -2.353340202047266}}, {{
       2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}, {{
       2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}, {{
       2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}, {{
       2.7216843452693262`, -2.3745150865930262`}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.6287040068975798`, -2.353340202047266}, {
       2.7216843452693262`, -2.3745150865930262`}, {
       2.7216843452693262`, -2.3745150865930262`}}, {{
       2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}, {{
       2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}, {{
       2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}, {{
       2.6287040068975798`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.6287040068975798`, -2.0735966308091656`}, {
       2.6287040068975798`, -2.0735966308091656`}}, {{
       2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}, {{
       2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}, {{
       2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}, {{
       2.7216843452693262`, -2.052421746263405}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7216843452693262`, -2.052421746263405}, {
       2.7216843452693262`, -2.052421746263405}}, {{
       2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}, {{
       2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}, {{
       2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}, {{
       2.7902140330559644`, -2.0735966308091656`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.7902140330559644`, -2.0735966308091656`}, {
       2.7902140330559644`, -2.0735966308091656`}}, {{
       2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}, {{
       2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}, {{
       2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}, {{
       2.8428168648881145`, -2.12235763907293}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8709690461351567`, -2.2134684164282157`}, {
       2.8428168648881145`, -2.12235763907293}, {
       2.8428168648881145`, -2.12235763907293}}, {{
       2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}, {{
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}, {{
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}, {{
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}, {{
       2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}, {{
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}, {{
       2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}, {{
       2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}, {{
       2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}, {{
       2.6356358636834867`, -1.8772901760982348`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}}, {{
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}, {{
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}, {{
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}, {{
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.8053420036797827`}, {
       2.5689423928632578`, -1.8053420036797827`}}, {{
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}, {{
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}, {{
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}, {{
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5525572702564965`, -1.7333938312613306`}, {
       2.5525572702564965`, -1.7333938312613306`}}, {{
       2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}, {{
       2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}, {{
       2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}, {{
       2.5689423928632578`, -1.6614456588428785`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.5689423928632578`, -1.6614456588428785`}, {
       2.5689423928632578`, -1.6614456588428785`}}, {{
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}, {{
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}, {{
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}, {{
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}}, {{
       2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}, {{
       2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}, {{
       2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}, {{
       2.855909434304328, -1.8271261574674311`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.855909434304328, -1.8271261574674311`}, {
       2.855909434304328, -1.8271261574674311`}}, {{
       2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}, {{
       2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}, {{
       2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}, {{
       2.801793050537466, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.801793050537466, -1.8772901760982348`}, {
       2.801793050537466, -1.8772901760982348`}}, {{
       2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}, {{
       2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}, {{
       2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}, {{
       2.7312915441638435`, -1.8990743298858832`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.6356358636834867`, -1.8772901760982348`}, {
       2.7312915441638435`, -1.8990743298858832`}, {
       2.7312915441638435`, -1.8990743298858832`}}, {{
       2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}, {{
       2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}, {{
       2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}, {{
       2.6356358636834867`, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.6356358636834867`, -1.5894974864244265`}, {
       2.6356358636834867`, -1.5894974864244265`}}, {{
       2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}, {{
       2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}, {{
       2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}, {{
       2.7312915441638435`, -1.567713332636778}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.7312915441638435`, -1.567713332636778}, {
       2.7312915441638435`, -1.567713332636778}}, {{
       2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}, {{
       2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}, {{
       2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}, {{
       2.801793050537466, -1.5894974864244265`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.801793050537466, -1.5894974864244265`}, {
       2.801793050537466, -1.5894974864244265`}}, {{
       2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}, {{
       2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}, {{
       2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}, {{
       2.855909434304328, -1.6396615050552301`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.8848716439644564`, -1.7333938312613306`}, {
       2.855909434304328, -1.6396615050552301`}, {
       2.855909434304328, -1.6396615050552301`}}, {{
       2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.721727770850301, -1.1056427388683707`}, {
       2.721727770850301, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}, {{
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}, {{
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}, {{
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}, {{
       2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}, {{
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}, {{
       2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}, {{
       2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}, {{
       2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}, {{
       2.721727770850301, -1.363309987001727}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.721727770850301, -1.363309987001727}, {
       2.721727770850301, -1.363309987001727}}, {{
       2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}, {{
       2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}, {{
       2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}, {{
       2.66201561098207, -1.2988931749683879`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.2988931749683879`}, {
       2.66201561098207, -1.2988931749683879`}}, {{
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}, {{
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}, {{
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}, {{
       2.6473456433147295`, -1.2344763629350488`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.6473456433147295`, -1.2344763629350488`}, {
       2.6473456433147295`, -1.2344763629350488`}}, {{
       2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}, {{
       2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}, {{
       2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}, {{
       2.66201561098207, -1.1700595509017098`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.66201561098207, -1.1700595509017098`}, {
       2.66201561098207, -1.1700595509017098`}}, {{
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}, {{
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}, {{
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}, {{
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}}, {{
       2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}, {{
       2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}, {{
       2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}, {{
       2.918943637739453, -1.318397016312444}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}, {
       2.918943637739453, -1.318397016312444}, {
       2.918943637739453, -1.318397016312444}}, {{
       2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}, {{
       2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}, {{
       2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}, {{
       2.870492025921444, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.870492025921444, -1.363309987001727}, {
       2.870492025921444, -1.363309987001727}}, {{
       2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}, {{
       2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}, {{
       2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}, {{
       2.8073704464360953`, -1.3828138283457831`}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.7217277708503014`, -1.363309987001727}, {
       2.8073704464360953`, -1.3828138283457831`}, {
       2.8073704464360953`, -1.3828138283457831`}}, {{
       2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}, {{
       2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}, {{
       2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}, {{
       2.7217277708503014`, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.7217277708503014`, -1.1056427388683707`}, {
       2.7217277708503014`, -1.1056427388683707`}}, {{
       2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}, {{
       2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}, {{
       2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}, {{
       2.8073704464360953`, -1.0861388975243145`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.8073704464360953`, -1.0861388975243145`}, {
       2.8073704464360953`, -1.0861388975243145`}}, {{
       2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}, {{
       2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}, {{
       2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}, {{
       2.870492025921444, -1.1056427388683707`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.870492025921444, -1.1056427388683707`}, {
       2.870492025921444, -1.1056427388683707`}}, {{
       2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}, {{
       2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}, {{
       2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}, {{
       2.918943637739453, -1.1505557095576535`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.944874153457016, -1.2344763629350488`}, {
       2.918943637739453, -1.1505557095576535`}, {
       2.918943637739453, -1.1505557095576535`}}, {{
       2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750842}, {
       2.7149858853970987`, -0.6447945605750842}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}, {{
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}, {{
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.895670479371751}, {
       2.7149858853970987`, -0.895670479371751}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}, {{
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}, {{
       2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}, {{
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}, {{
       2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}, {{
       2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}, {{
       2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}, {{
       2.7149858853970987`, -0.8956704793717509}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}}, {{
       2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}, {{
       2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}, {{
       2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}, {{
       2.656847557461362, -0.8329514996725843}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.8329514996725843}, {
       2.656847557461362, -0.8329514996725843}}, {{
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}, {{
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}, {{
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}, {{
       2.6425642457718737`, -0.7702325199734176}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}, {
       2.6425642457718737`, -0.7702325199734176}, {
       2.6425642457718737`, -0.7702325199734176}}, {{
       2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}, {{
       2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}, {{
       2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}, {{
       2.656847557461362, -0.7075135402742508}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.656847557461362, -0.7075135402742508}, {
       2.656847557461362, -0.7075135402742508}}, {{
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}, {{
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}, {{
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}, {{
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}}, {{
       2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}, {{
       2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}, {{
       2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}, {{
       2.907003738521724, -0.8519412787488995}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}, {
       2.907003738521724, -0.8519412787488995}, {
       2.907003738521724, -0.8519412787488995}}, {{
       2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}, {{
       2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}, {{
       2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}, {{
       2.859829164647549, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.859829164647549, -0.8956704793717509}, {
       2.859829164647549, -0.8956704793717509}}, {{
       2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}, {{
       2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}, {{
       2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}, {{
       2.7983712790838857`, -0.9146602584480662}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7149858853970987`, -0.8956704793717509}, {
       2.7983712790838857`, -0.9146602584480662}, {
       2.7983712790838857`, -0.9146602584480662}}, {{
       2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}, {{
       2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}, {{
       2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}, {{
       2.7149858853970987`, -0.6447945605750841}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7149858853970987`, -0.6447945605750841}, {
       2.7149858853970987`, -0.6447945605750841}}, {{
       2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}, {{
       2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}, {{
       2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}, {{
       2.7983712790838857`, -0.625804781498769}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}, {
       2.7983712790838857`, -0.625804781498769}, {
       2.7983712790838857`, -0.625804781498769}}, {{
       2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}, {{
       2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}, {{
       2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}, {{
       2.859829164647549, -0.6447945605750842}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}, {
       2.859829164647549, -0.6447945605750842}, {
       2.859829164647549, -0.6447945605750842}}, {{
       2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}, {{
       2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}, {{
       2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}, {{
       2.907003738521724, -0.6885237611979357}, {
       2.932250804272774, -0.7702325199734176}, {
       2.932250804272774, -0.7702325199734176}, {
       2.907003738521724, -0.6885237611979357}, {
       2.907003738521724, -0.6885237611979357}}, {{
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}, {{
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}, {{
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}, {{
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}, {{
       2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}, {{
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}, {{
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}, {{
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}, {{
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}, {{
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}}, {{
       2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}, {{
       2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}, {{
       2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}, {{
       2.6274687735728874`, -0.31844261558574344`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.31844261558574344`}, {
       2.6274687735728874`, -0.31844261558574344`}}, {{
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}, {{
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}, {{
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}, {{
       2.612014227204692, -0.25058066585037264`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.612014227204692, -0.25058066585037264`}, {
       2.612014227204692, -0.25058066585037264`}}, {{
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}, {{
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}, {{
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}, {{
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6274687735728874`, -0.18271871611500184`}, {
       2.6274687735728874`, -0.18271871611500184`}}, {{
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}, {{
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}, {{
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}, {{
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}}, {{
       2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}, {{
       2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}, {{
       2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}, {{
       2.898137816126463, -0.3389895606946069}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.898137816126463, -0.3389895606946069}, {
       2.898137816126463, -0.3389895606946069}}, {{
       2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}, {{
       2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}, {{
       2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}, {{
       2.847094916889387, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.847094916889387, -0.38630456532111423`}, {
       2.847094916889387, -0.38630456532111423`}}, {{
       2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}, {{
       2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}, {{
       2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}, {{
       2.7805974712841155`, -0.4068515104299777}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.6903744570995904`, -0.38630456532111423`}, {
       2.7805974712841155`, -0.4068515104299777}, {
       2.7805974712841155`, -0.4068515104299777}}, {{
       2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}, {{
       2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}, {{
       2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}, {{
       2.6903744570995904`, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.6903744570995904`, -0.11485676637963105`}, {
       2.6903744570995904`, -0.11485676637963105`}}, {{
       2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}, {{
       2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}, {{
       2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}, {{
       2.7805974712841155`, -0.09430982127076759}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.7805974712841155`, -0.09430982127076759}, {
       2.7805974712841155`, -0.09430982127076759}}, {{
       2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}, {{
       2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}, {{
       2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}, {{
       2.847094916889387, -0.11485676637963105`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}, {
       2.847094916889387, -0.11485676637963105`}, {
       2.847094916889387, -0.11485676637963105`}}, {{
       2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}, {{
       2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}, {{
       2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}, {{
       2.898137816126463, -0.1621717710061384}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.9254551467842855`, -0.25058066585037264`}, {
       2.898137816126463, -0.1621717710061384}, {
       2.898137816126463, -0.1621717710061384}}, {{2.6465276450782134`, 
       0.08724129137790171}, {2.57529902478603, 0.16408193246140756`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603, 
       0.3177632146284193}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}, {2.57529902478603, 
       0.3177632146284193}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.6465276450782134`, 
       0.08724129137790171}, {2.6465276450782134`, 0.08724129137790171}}, {{
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}}, {{2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.14081645835361378`}, {2.8239835043352755`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8817797968885, 
       0.14081645835361378`}, {2.9127114339638065`, 0.2409225735449134}, {
       2.9127114339638065`, 0.2409225735449134}}, {{2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}}, {{
       2.6465276450782134`, 0.39460385571192513`}, {2.7486879024457034`, 
       0.4178693298197189}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8817797968885, 0.34102868873621306`}, {2.9127114339638065`, 
       0.24092257354491345`}, {2.9127114339638065`, 0.24092257354491345`}, {
       2.8817797968885, 0.34102868873621306`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.6465276450782134`, 0.39460385571192513`}, {2.6465276450782134`, 
       0.39460385571192513`}}, {{2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}}, {{2.6465276450782134`, 
       0.08724129137790171}, {2.57529902478603, 0.16408193246140756`}, {
       2.57529902478603, 0.16408193246140756`}, {2.6465276450782134`, 
       0.08724129137790171}, {2.6465276450782134`, 0.08724129137790171}}, {{
       2.6465276450782134`, 0.08724129137790171}, {2.57529902478603, 
       0.16408193246140756`}, {2.57529902478603, 0.16408193246140756`}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}}, {{2.6465276450782134`, 0.08724129137790171}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}, {2.6465276450782134`, 0.08724129137790171}, {
       2.6465276450782134`, 0.08724129137790171}}, {{2.6465276450782134`, 
       0.08724129137790171}, {2.57529902478603, 0.16408193246140756`}, {
       2.57529902478603, 0.16408193246140756`}, {2.6465276450782134`, 
       0.08724129137790171}, {2.6465276450782134`, 0.08724129137790171}}, {{
       2.57529902478603, 0.16408193246140756`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}}, {{2.57529902478603, 0.16408193246140756`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.57529902478603, 0.16408193246140756`}, {
       2.57529902478603, 0.16408193246140756`}}, {{2.57529902478603, 
       0.16408193246140756`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603, 
       0.16408193246140756`}, {2.57529902478603, 0.16408193246140756`}}, {{
       2.57529902478603, 0.16408193246140756`}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.16408193246140756`}, {2.57529902478603, 
       0.16408193246140756`}}, {{2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}}, {{2.5577997154496823`, 
       0.24092257354491342`}, {2.57529902478603, 0.3177632146284193}, {
       2.57529902478603, 0.3177632146284193}, {2.5577997154496823`, 
       0.24092257354491342`}, {2.5577997154496823`, 0.24092257354491342`}}, {{
       2.5577997154496823`, 0.24092257354491342`}, {2.57529902478603, 
       0.3177632146284193}, {2.57529902478603, 0.3177632146284193}, {
       2.5577997154496823`, 0.24092257354491342`}, {2.5577997154496823`, 
       0.24092257354491342`}}, {{2.5577997154496823`, 0.24092257354491342`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}, {2.5577997154496823`, 0.24092257354491342`}, {
       2.5577997154496823`, 0.24092257354491342`}}, {{2.57529902478603, 
       0.3177632146284193}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}, {2.57529902478603, 
       0.3177632146284193}, {2.57529902478603, 0.3177632146284193}}, {{
       2.57529902478603, 0.3177632146284193}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.57529902478603, 0.3177632146284193}, {2.57529902478603, 
       0.3177632146284193}}, {{2.57529902478603, 0.3177632146284193}, {
       2.6465276450782134`, 0.39460385571192513`}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.57529902478603, 0.3177632146284193}, {
       2.57529902478603, 0.3177632146284193}}, {{2.57529902478603, 
       0.3177632146284193}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}, {2.57529902478603, 
       0.3177632146284193}, {2.57529902478603, 0.3177632146284193}}, {{
       2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}, {{2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.14081645835361378`}, {2.8817797968885, 
       0.14081645835361378`}, {2.9127114339638065`, 0.2409225735449134}, {
       2.9127114339638065`, 0.2409225735449134}}, {{2.9127114339638065`, 
       0.2409225735449134}, {2.8817797968885, 0.14081645835361378`}, {
       2.8817797968885, 0.14081645835361378`}, {2.9127114339638065`, 
       0.2409225735449134}, {2.9127114339638065`, 0.2409225735449134}}, {{
       2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}}, {{2.8817797968885, 0.14081645835361378`}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8817797968885, 0.14081645835361378`}, {
       2.8817797968885, 0.14081645835361378`}}, {{2.8817797968885, 
       0.14081645835361378`}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8817797968885, 
       0.14081645835361378`}, {2.8817797968885, 0.14081645835361378`}}, {{
       2.8817797968885, 0.14081645835361378`}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8817797968885, 0.14081645835361378`}, {2.8817797968885, 
       0.14081645835361378`}}, {{2.8817797968885, 0.14081645835361378`}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8817797968885, 0.14081645835361378`}, {
       2.8817797968885, 0.14081645835361378`}}, {{2.8239835043352755`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}}, {{
       2.8239835043352755`, 0.08724129137790171}, {2.7486879024457034`, 
       0.06397581727010793}, {2.7486879024457034`, 0.06397581727010793}, {
       2.8239835043352755`, 0.08724129137790171}, {2.8239835043352755`, 
       0.08724129137790171}}, {{2.8239835043352755`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}, {2.8239835043352755`, 0.08724129137790171}, {
       2.8239835043352755`, 0.08724129137790171}}, {{2.8239835043352755`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}, {2.8239835043352755`, 
       0.08724129137790171}, {2.8239835043352755`, 0.08724129137790171}}, {{
       2.7486879024457034`, 0.06397581727010793}, {2.6465276450782134`, 
       0.08724129137790171}, {2.6465276450782134`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}}, {{2.7486879024457034`, 0.06397581727010793}, {
       2.6465276450782134`, 0.08724129137790171}, {2.6465276450782134`, 
       0.08724129137790171}, {2.7486879024457034`, 0.06397581727010793}, {
       2.7486879024457034`, 0.06397581727010793}}, {{2.7486879024457034`, 
       0.06397581727010793}, {2.6465276450782134`, 0.08724129137790171}, {
       2.6465276450782134`, 0.08724129137790171}, {2.7486879024457034`, 
       0.06397581727010793}, {2.7486879024457034`, 0.06397581727010793}}, {{
       2.7486879024457034`, 0.06397581727010793}, {2.6465276450782134`, 
       0.08724129137790171}, {2.6465276450782134`, 0.08724129137790171}, {
       2.7486879024457034`, 0.06397581727010793}, {2.7486879024457034`, 
       0.06397581727010793}}, {{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}, {{2.6465276450782134`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.7486879024457034`, 0.4178693298197189}, {2.6465276450782134`, 
       0.39460385571192513`}, {2.6465276450782134`, 0.39460385571192513`}}, {{
       2.6465276450782134`, 0.39460385571192513`}, {2.7486879024457034`, 
       0.4178693298197189}, {2.7486879024457034`, 0.4178693298197189}, {
       2.6465276450782134`, 0.39460385571192513`}, {2.6465276450782134`, 
       0.39460385571192513`}}, {{2.6465276450782134`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}, {2.6465276450782134`, 0.39460385571192513`}, {
       2.6465276450782134`, 0.39460385571192513`}}, {{2.7486879024457034`, 
       0.4178693298197189}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.7486879024457034`, 
       0.4178693298197189}, {2.7486879024457034`, 0.4178693298197189}}, {{
       2.7486879024457034`, 0.4178693298197189}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.7486879024457034`, 0.4178693298197189}, {2.7486879024457034`, 
       0.4178693298197189}}, {{2.7486879024457034`, 0.4178693298197189}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.7486879024457034`, 0.4178693298197189}, {
       2.7486879024457034`, 0.4178693298197189}}, {{2.7486879024457034`, 
       0.4178693298197189}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.7486879024457034`, 
       0.4178693298197189}, {2.7486879024457034`, 0.4178693298197189}}, {{
       2.8239835043352755`, 0.39460385571192513`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}}, {{2.8239835043352755`, 0.39460385571192513`}, {
       2.8817797968885, 0.34102868873621306`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8239835043352755`, 0.39460385571192513`}, {
       2.8239835043352755`, 0.39460385571192513`}}, {{2.8239835043352755`, 
       0.39460385571192513`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8817797968885, 0.34102868873621306`}, {2.8239835043352755`, 
       0.39460385571192513`}, {2.8239835043352755`, 0.39460385571192513`}}, {{
       2.8239835043352755`, 0.39460385571192513`}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}, {
       2.8239835043352755`, 0.39460385571192513`}, {2.8239835043352755`, 
       0.39460385571192513`}}, {{2.8817797968885, 0.34102868873621306`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}, {2.8817797968885, 0.34102868873621306`}, {
       2.8817797968885, 0.34102868873621306`}}, {{2.8817797968885, 
       0.34102868873621306`}, {2.9127114339638065`, 0.2409225735449134}, {
       2.9127114339638065`, 0.2409225735449134}, {2.8817797968885, 
       0.34102868873621306`}, {2.8817797968885, 0.34102868873621306`}}, {{
       2.8817797968885, 0.34102868873621306`}, {2.9127114339638065`, 
       0.2409225735449134}, {2.9127114339638065`, 0.2409225735449134}, {
       2.8817797968885, 0.34102868873621306`}, {2.8817797968885, 
       0.34102868873621306`}}, {{2.8817797968885, 0.34102868873621306`}, {
       2.9127114339638065`, 0.2409225735449134}, {2.9127114339638065`, 
       0.2409225735449134}, {2.8817797968885, 0.34102868873621306`}, {
       2.8817797968885, 0.34102868873621306`}}, {{2.676164126733447, 
       0.5752985413695367}, {2.609998974613347, 0.646676769467184}, {
       2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.7894332256624785}, {2.676164126733447, 0.8608114537601258}, {
       2.676164126733447, 0.8608114537601258}, {2.609998974613347, 
       0.7894332256624785}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}}, {{
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}}, {{2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.6250651809347391}, {2.841005083559268, 
       0.5752985413695367}, {2.77106206160318, 0.5536869528370918}, {
       2.6761641267334473`, 0.5752985413695367}, {2.6761641267334473`, 
       0.5752985413695367}, {2.77106206160318, 0.5536869528370918}, {
       2.841005083559268, 0.5752985413695367}, {2.894692779222545, 
       0.6250651809347391}, {2.923425561972178, 0.7180549975648313}, {
       2.923425561972178, 0.7180549975648313}}, {{2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}}, {{
       2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.841005083559268, 0.8608114537601258}, {
       2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.841005083559268, 
       0.8608114537601258}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}, {{2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}}, {{2.676164126733447, 
       0.5752985413695367}, {2.609998974613347, 0.646676769467184}, {
       2.609998974613347, 0.646676769467184}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}}, {{
       2.676164126733447, 0.5752985413695367}, {2.609998974613347, 
       0.646676769467184}, {2.609998974613347, 0.646676769467184}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}}, {{2.676164126733447, 0.5752985413695367}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}, {2.676164126733447, 0.5752985413695367}, {
       2.676164126733447, 0.5752985413695367}}, {{2.676164126733447, 
       0.5752985413695367}, {2.609998974613347, 0.646676769467184}, {
       2.609998974613347, 0.646676769467184}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}}, {{
       2.609998974613347, 0.646676769467184}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}}, {{2.609998974613347, 0.646676769467184}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}, {2.609998974613347, 0.646676769467184}, {
       2.609998974613347, 0.646676769467184}}, {{2.609998974613347, 
       0.646676769467184}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.646676769467184}, {2.609998974613347, 0.646676769467184}}, {{
       2.609998974613347, 0.646676769467184}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.646676769467184}, {2.609998974613347, 
       0.646676769467184}}, {{2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}}, {{2.5937436483205367`, 
       0.7180549975648313}, {2.609998974613347, 0.7894332256624785}, {
       2.609998974613347, 0.7894332256624785}, {2.5937436483205367`, 
       0.7180549975648313}, {2.5937436483205367`, 0.7180549975648313}}, {{
       2.5937436483205367`, 0.7180549975648313}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}, {
       2.5937436483205367`, 0.7180549975648313}, {2.5937436483205367`, 
       0.7180549975648313}}, {{2.5937436483205367`, 0.7180549975648313}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}, {2.5937436483205367`, 0.7180549975648313}, {
       2.5937436483205367`, 0.7180549975648313}}, {{2.609998974613347, 
       0.7894332256624785}, {2.6761641267334473`, 0.8608114537601258}, {
       2.6761641267334473`, 0.8608114537601258}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}}, {{
       2.609998974613347, 0.7894332256624785}, {2.6761641267334473`, 
       0.8608114537601258}, {2.6761641267334473`, 0.8608114537601258}, {
       2.609998974613347, 0.7894332256624785}, {2.609998974613347, 
       0.7894332256624785}}, {{2.609998974613347, 0.7894332256624785}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}, {2.609998974613347, 0.7894332256624785}, {
       2.609998974613347, 0.7894332256624785}}, {{2.609998974613347, 
       0.7894332256624785}, {2.6761641267334473`, 0.8608114537601258}, {
       2.6761641267334473`, 0.8608114537601258}, {2.609998974613347, 
       0.7894332256624785}, {2.609998974613347, 0.7894332256624785}}, {{
       2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}, {{2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.6250651809347391}, {2.894692779222545, 
       0.6250651809347391}, {2.923425561972178, 0.7180549975648313}, {
       2.923425561972178, 0.7180549975648313}}, {{2.923425561972178, 
       0.7180549975648313}, {2.894692779222545, 0.6250651809347391}, {
       2.894692779222545, 0.6250651809347391}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}}, {{
       2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}}, {{2.894692779222545, 0.6250651809347391}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.894692779222545, 0.6250651809347391}, {
       2.894692779222545, 0.6250651809347391}}, {{2.894692779222545, 
       0.6250651809347391}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}, {2.894692779222545, 
       0.6250651809347391}, {2.894692779222545, 0.6250651809347391}}, {{
       2.894692779222545, 0.6250651809347391}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}, {
       2.894692779222545, 0.6250651809347391}, {2.894692779222545, 
       0.6250651809347391}}, {{2.894692779222545, 0.6250651809347391}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}, {2.894692779222545, 0.6250651809347391}, {
       2.894692779222545, 0.6250651809347391}}, {{2.841005083559268, 
       0.5752985413695367}, {2.77106206160318, 0.5536869528370918}, {
       2.77106206160318, 0.5536869528370918}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}}, {{
       2.841005083559268, 0.5752985413695367}, {2.77106206160318, 
       0.5536869528370918}, {2.77106206160318, 0.5536869528370918}, {
       2.841005083559268, 0.5752985413695367}, {2.841005083559268, 
       0.5752985413695367}}, {{2.841005083559268, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}, {2.841005083559268, 0.5752985413695367}, {
       2.841005083559268, 0.5752985413695367}}, {{2.841005083559268, 
       0.5752985413695367}, {2.77106206160318, 0.5536869528370918}, {
       2.77106206160318, 0.5536869528370918}, {2.841005083559268, 
       0.5752985413695367}, {2.841005083559268, 0.5752985413695367}}, {{
       2.77106206160318, 0.5536869528370918}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}}, {{2.77106206160318, 0.5536869528370918}, {
       2.676164126733447, 0.5752985413695367}, {2.676164126733447, 
       0.5752985413695367}, {2.77106206160318, 0.5536869528370918}, {
       2.77106206160318, 0.5536869528370918}}, {{2.77106206160318, 
       0.5536869528370918}, {2.676164126733447, 0.5752985413695367}, {
       2.676164126733447, 0.5752985413695367}, {2.77106206160318, 
       0.5536869528370918}, {2.77106206160318, 0.5536869528370918}}, {{
       2.77106206160318, 0.5536869528370918}, {2.676164126733447, 
       0.5752985413695367}, {2.676164126733447, 0.5752985413695367}, {
       2.77106206160318, 0.5536869528370918}, {2.77106206160318, 
       0.5536869528370918}}, {{2.6761641267334473`, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}, {2.6761641267334473`, 0.8608114537601258}, {
       2.6761641267334473`, 0.8608114537601258}}, {{2.6761641267334473`, 
       0.8608114537601258}, {2.77106206160318, 0.8824230422925707}, {
       2.77106206160318, 0.8824230422925707}, {2.6761641267334473`, 
       0.8608114537601258}, {2.6761641267334473`, 0.8608114537601258}}, {{
       2.6761641267334473`, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}, {
       2.6761641267334473`, 0.8608114537601258}, {2.6761641267334473`, 
       0.8608114537601258}}, {{2.6761641267334473`, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}, {2.6761641267334473`, 0.8608114537601258}, {
       2.6761641267334473`, 0.8608114537601258}}, {{2.77106206160318, 
       0.8824230422925707}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}}, {{
       2.77106206160318, 0.8824230422925707}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}, {
       2.77106206160318, 0.8824230422925707}, {2.77106206160318, 
       0.8824230422925707}}, {{2.77106206160318, 0.8824230422925707}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}, {2.77106206160318, 0.8824230422925707}, {
       2.77106206160318, 0.8824230422925707}}, {{2.77106206160318, 
       0.8824230422925707}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}, {2.77106206160318, 
       0.8824230422925707}, {2.77106206160318, 0.8824230422925707}}, {{
       2.841005083559268, 0.8608114537601258}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}, {{2.841005083559268, 0.8608114537601258}, {
       2.894692779222545, 0.8110448141949235}, {2.894692779222545, 
       0.8110448141949235}, {2.841005083559268, 0.8608114537601258}, {
       2.841005083559268, 0.8608114537601258}}, {{2.841005083559268, 
       0.8608114537601258}, {2.894692779222545, 0.8110448141949235}, {
       2.894692779222545, 0.8110448141949235}, {2.841005083559268, 
       0.8608114537601258}, {2.841005083559268, 0.8608114537601258}}, {{
       2.841005083559268, 0.8608114537601258}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}, {
       2.841005083559268, 0.8608114537601258}, {2.841005083559268, 
       0.8608114537601258}}, {{2.894692779222545, 0.8110448141949235}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}, {2.894692779222545, 0.8110448141949235}, {
       2.894692779222545, 0.8110448141949235}}, {{2.894692779222545, 
       0.8110448141949235}, {2.923425561972178, 0.7180549975648313}, {
       2.923425561972178, 0.7180549975648313}, {2.894692779222545, 
       0.8110448141949235}, {2.894692779222545, 0.8110448141949235}}, {{
       2.894692779222545, 0.8110448141949235}, {2.923425561972178, 
       0.7180549975648313}, {2.923425561972178, 0.7180549975648313}, {
       2.894692779222545, 0.8110448141949235}, {2.894692779222545, 
       0.8110448141949235}}, {{2.894692779222545, 0.8110448141949235}, {
       2.923425561972178, 0.7180549975648313}, {2.923425561972178, 
       0.7180549975648313}, {2.894692779222545, 0.8110448141949235}, {
       2.894692779222545, 0.8110448141949235}}, {{2.671956865229452, 
       1.070497511236409}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.671956865229452, 1.3742475979879145`}, {
       2.671956865229452, 1.3742475979879145`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}}, {{
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}, {{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.8473270595818057`, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}, {{2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}}, {{
       2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`, 
       1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}, {{2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}, {{2.671956865229452, 
       1.070497511236409}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}}, {{
       2.671956865229452, 1.070497511236409}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}}, {{2.671956865229452, 1.070497511236409}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.671956865229452, 1.070497511236409}, {
       2.671956865229452, 1.070497511236409}}, {{2.671956865229452, 
       1.070497511236409}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}}, {{
       2.6015654054242545`, 1.1464350329242854`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}}, {{2.6015654054242545`, 1.1464350329242854`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}, {2.6015654054242545`, 1.1464350329242854`}, {
       2.6015654054242545`, 1.1464350329242854`}}, {{2.6015654054242545`, 
       1.1464350329242854`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`, 
       1.1464350329242854`}, {2.6015654054242545`, 1.1464350329242854`}}, {{
       2.6015654054242545`, 1.1464350329242854`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.1464350329242854`}, {2.6015654054242545`, 
       1.1464350329242854`}}, {{2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}}, {{2.584271768053275, 
       1.2223725546121618`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.584271768053275, 
       1.2223725546121618`}, {2.584271768053275, 1.2223725546121618`}}, {{
       2.584271768053275, 1.2223725546121618`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.584271768053275, 1.2223725546121618`}, {2.584271768053275, 
       1.2223725546121618`}}, {{2.584271768053275, 1.2223725546121618`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.584271768053275, 1.2223725546121618`}, {
       2.584271768053275, 1.2223725546121618`}}, {{2.6015654054242545`, 
       1.2983100763000381`}, {2.671956865229452, 1.3742475979879145`}, {
       2.671956865229452, 1.3742475979879145`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}}, {{
       2.6015654054242545`, 1.2983100763000381`}, {2.671956865229452, 
       1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}, {
       2.6015654054242545`, 1.2983100763000381`}, {2.6015654054242545`, 
       1.2983100763000381`}}, {{2.6015654054242545`, 1.2983100763000381`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}, {2.6015654054242545`, 1.2983100763000381`}, {
       2.6015654054242545`, 1.2983100763000381`}}, {{2.6015654054242545`, 
       1.2983100763000381`}, {2.671956865229452, 1.3742475979879145`}, {
       2.671956865229452, 1.3742475979879145`}, {2.6015654054242545`, 
       1.2983100763000381`}, {2.6015654054242545`, 1.2983100763000381`}}, {{
       2.9350121567579825`, 1.2223725546121618`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9350121567579825`, 1.2223725546121618`}, {2.9350121567579825`, 
       1.2223725546121618`}}, {{2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}}, {{2.9350121567579825`, 
       1.2223725546121618`}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9350121567579825`, 
       1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}}, {{
       2.9350121567579825`, 1.2223725546121618`}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9350121567579825`, 1.2223725546121618`}, {2.9350121567579825`, 
       1.2223725546121618`}}, {{2.9044440637784485`, 1.1234430013674515`}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}}, {{2.9044440637784485`, 
       1.1234430013674515`}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}, {2.9044440637784485`, 
       1.1234430013674515`}, {2.9044440637784485`, 1.1234430013674515`}}, {{
       2.9044440637784485`, 1.1234430013674515`}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}, {
       2.9044440637784485`, 1.1234430013674515`}, {2.9044440637784485`, 
       1.1234430013674515`}}, {{2.9044440637784485`, 1.1234430013674515`}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}, {2.9044440637784485`, 1.1234430013674515`}, {
       2.9044440637784485`, 1.1234430013674515`}}, {{2.8473270595818057`, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.772916418014183, 1.047505479679575}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}}, {{
       2.8473270595818057`, 1.070497511236409}, {2.772916418014183, 
       1.047505479679575}, {2.772916418014183, 1.047505479679575}, {
       2.8473270595818057`, 1.070497511236409}, {2.8473270595818057`, 
       1.070497511236409}}, {{2.8473270595818057`, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}, {2.8473270595818057`, 1.070497511236409}, {
       2.8473270595818057`, 1.070497511236409}}, {{2.8473270595818057`, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.772916418014183, 1.047505479679575}, {2.8473270595818057`, 
       1.070497511236409}, {2.8473270595818057`, 1.070497511236409}}, {{
       2.772916418014183, 1.047505479679575}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}}, {{2.772916418014183, 1.047505479679575}, {
       2.671956865229452, 1.070497511236409}, {2.671956865229452, 
       1.070497511236409}, {2.772916418014183, 1.047505479679575}, {
       2.772916418014183, 1.047505479679575}}, {{2.772916418014183, 
       1.047505479679575}, {2.671956865229452, 1.070497511236409}, {
       2.671956865229452, 1.070497511236409}, {2.772916418014183, 
       1.047505479679575}, {2.772916418014183, 1.047505479679575}}, {{
       2.772916418014183, 1.047505479679575}, {2.671956865229452, 
       1.070497511236409}, {2.671956865229452, 1.070497511236409}, {
       2.772916418014183, 1.047505479679575}, {2.772916418014183, 
       1.047505479679575}}, {{2.671956865229452, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}, {2.671956865229452, 1.3742475979879145`}, {
       2.671956865229452, 1.3742475979879145`}}, {{2.671956865229452, 
       1.3742475979879145`}, {2.772916418014183, 1.3972396295447485`}, {
       2.772916418014183, 1.3972396295447485`}, {2.671956865229452, 
       1.3742475979879145`}, {2.671956865229452, 1.3742475979879145`}}, {{
       2.671956865229452, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}, {
       2.671956865229452, 1.3742475979879145`}, {2.671956865229452, 
       1.3742475979879145`}}, {{2.671956865229452, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}, {2.671956865229452, 1.3742475979879145`}, {
       2.671956865229452, 1.3742475979879145`}}, {{2.772916418014183, 
       1.3972396295447485`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}}, {{
       2.772916418014183, 1.3972396295447485`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.772916418014183, 1.3972396295447485`}, {2.772916418014183, 
       1.3972396295447485`}}, {{2.772916418014183, 1.3972396295447485`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.772916418014183, 1.3972396295447485`}, {
       2.772916418014183, 1.3972396295447485`}}, {{2.772916418014183, 
       1.3972396295447485`}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.772916418014183, 
       1.3972396295447485`}, {2.772916418014183, 1.3972396295447485`}}, {{
       2.8473270595818057`, 1.3742475979879145`}, {2.9044440637784485`, 
       1.321302107856872}, {2.9044440637784485`, 1.321302107856872}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}}, {{2.8473270595818057`, 1.3742475979879145`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}, {2.8473270595818057`, 1.3742475979879145`}, {
       2.8473270595818057`, 1.3742475979879145`}}, {{2.8473270595818057`, 
       1.3742475979879145`}, {2.9044440637784485`, 1.321302107856872}, {
       2.9044440637784485`, 1.321302107856872}, {2.8473270595818057`, 
       1.3742475979879145`}, {2.8473270595818057`, 1.3742475979879145`}}, {{
       2.8473270595818057`, 1.3742475979879145`}, {2.9044440637784485`, 
       1.321302107856872}, {2.9044440637784485`, 1.321302107856872}, {
       2.8473270595818057`, 1.3742475979879145`}, {2.8473270595818057`, 
       1.3742475979879145`}}, {{2.9044440637784485`, 1.321302107856872}, {
       2.9350121567579825`, 1.2223725546121618`}, {2.9350121567579825`, 
       1.2223725546121618`}, {2.9044440637784485`, 1.321302107856872}, {
       2.9044440637784485`, 1.321302107856872}}, {{2.9044440637784485`, 
       1.321302107856872}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9350121567579825`, 1.2223725546121618`}, {2.9044440637784485`, 
       1.321302107856872}, {2.9044440637784485`, 1.321302107856872}}, {{
       2.9044440637784485`, 1.321302107856872}, {2.9350121567579825`, 
       1.2223725546121618`}, {2.9350121567579825`, 1.2223725546121618`}, {
       2.9044440637784485`, 1.321302107856872}, {2.9044440637784485`, 
       1.321302107856872}}, {{2.9044440637784485`, 1.321302107856872}, {
       2.9350121567579825`, 1.2223725546121618`}, {2.9350121567579825`, 
       1.2223725546121618`}, {2.9044440637784485`, 1.321302107856872}, {
       2.9044440637784485`, 1.321302107856872}}, {{2.6973738914708894`, 
       1.641328684369108}, {2.6350785394072926`, 1.708532215329749}, {
       2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.842939277251031}, {2.6973738914708894`, 1.910142808211672}, {
       2.6973738914708894`, 1.910142808211672}, {2.6350785394072926`, 
       1.842939277251031}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6973738914708894`, 
       1.641328684369108}, {2.6973738914708894`, 1.641328684369108}}, {{
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}, {{2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.688184623385299}, {2.8525737982333674`, 
       1.641328684369108}, {2.786721532538617, 1.6209810924246582`}, {
       2.69737389147089, 1.641328684369108}, {2.69737389147089, 
       1.641328684369108}, {2.786721532538617, 1.6209810924246582`}, {
       2.8525737982333674`, 1.641328684369108}, {2.9031214626104753`, 
       1.688184623385299}, {2.930173751614606, 1.77573574629039}, {
       2.930173751614606, 1.77573574629039}}, {{2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}}, {{
       2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.8525737982333674`, 1.910142808211672}, {
       2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.8525737982333674`, 
       1.910142808211672}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}, {{2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}}, {{2.6973738914708894`, 
       1.641328684369108}, {2.6350785394072926`, 1.708532215329749}, {
       2.6350785394072926`, 1.708532215329749}, {2.6973738914708894`, 
       1.641328684369108}, {2.6973738914708894`, 1.641328684369108}}, {{
       2.6973738914708894`, 1.641328684369108}, {2.6350785394072926`, 
       1.708532215329749}, {2.6350785394072926`, 1.708532215329749}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}}, {{2.6973738914708894`, 1.641328684369108}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}, {2.6973738914708894`, 1.641328684369108}, {
       2.6973738914708894`, 1.641328684369108}}, {{2.6973738914708894`, 
       1.641328684369108}, {2.6350785394072926`, 1.708532215329749}, {
       2.6350785394072926`, 1.708532215329749}, {2.6973738914708894`, 
       1.641328684369108}, {2.6973738914708894`, 1.641328684369108}}, {{
       2.6350785394072926`, 1.708532215329749}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}}, {{2.6350785394072926`, 1.708532215329749}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}, {2.6350785394072926`, 1.708532215329749}, {
       2.6350785394072926`, 1.708532215329749}}, {{2.6350785394072926`, 
       1.708532215329749}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.708532215329749}, {2.6350785394072926`, 1.708532215329749}}, {{
       2.6350785394072926`, 1.708532215329749}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.708532215329749}, {2.6350785394072926`, 
       1.708532215329749}}, {{2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}}, {{2.6197739380896508`, 
       1.77573574629039}, {2.6350785394072926`, 1.842939277251031}, {
       2.6350785394072926`, 1.842939277251031}, {2.6197739380896508`, 
       1.77573574629039}, {2.6197739380896508`, 1.77573574629039}}, {{
       2.6197739380896508`, 1.77573574629039}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}, {
       2.6197739380896508`, 1.77573574629039}, {2.6197739380896508`, 
       1.77573574629039}}, {{2.6197739380896508`, 1.77573574629039}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}, {2.6197739380896508`, 1.77573574629039}, {
       2.6197739380896508`, 1.77573574629039}}, {{2.6350785394072926`, 
       1.842939277251031}, {2.6973738914708894`, 1.910142808211672}, {
       2.6973738914708894`, 1.910142808211672}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}}, {{
       2.6350785394072926`, 1.842939277251031}, {2.6973738914708894`, 
       1.910142808211672}, {2.6973738914708894`, 1.910142808211672}, {
       2.6350785394072926`, 1.842939277251031}, {2.6350785394072926`, 
       1.842939277251031}}, {{2.6350785394072926`, 1.842939277251031}, {
       2.6973738914708894`, 1.910142808211672}, {2.6973738914708894`, 
       1.910142808211672}, {2.6350785394072926`, 1.842939277251031}, {
       2.6350785394072926`, 1.842939277251031}}, {{2.6350785394072926`, 
       1.842939277251031}, {2.6973738914708894`, 1.910142808211672}, {
       2.6973738914708894`, 1.910142808211672}, {2.6350785394072926`, 
       1.842939277251031}, {2.6350785394072926`, 1.842939277251031}}, {{
       2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}, {{2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.688184623385299}, {2.9031214626104753`, 
       1.688184623385299}, {2.930173751614606, 1.77573574629039}, {
       2.930173751614606, 1.77573574629039}}, {{2.930173751614606, 
       1.77573574629039}, {2.9031214626104753`, 1.688184623385299}, {
       2.9031214626104753`, 1.688184623385299}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}}, {{
       2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}}, {{2.9031214626104753`, 1.688184623385299}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.9031214626104753`, 1.688184623385299}, {
       2.9031214626104753`, 1.688184623385299}}, {{2.9031214626104753`, 
       1.688184623385299}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}, {2.9031214626104753`, 
       1.688184623385299}, {2.9031214626104753`, 1.688184623385299}}, {{
       2.9031214626104753`, 1.688184623385299}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}, {
       2.9031214626104753`, 1.688184623385299}, {2.9031214626104753`, 
       1.688184623385299}}, {{2.9031214626104753`, 1.688184623385299}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}, {2.9031214626104753`, 1.688184623385299}, {
       2.9031214626104753`, 1.688184623385299}}, {{2.8525737982333674`, 
       1.641328684369108}, {2.786721532538617, 1.6209810924246582`}, {
       2.786721532538617, 1.6209810924246582`}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}}, {{
       2.8525737982333674`, 1.641328684369108}, {2.786721532538617, 
       1.6209810924246582`}, {2.786721532538617, 1.6209810924246582`}, {
       2.8525737982333674`, 1.641328684369108}, {2.8525737982333674`, 
       1.641328684369108}}, {{2.8525737982333674`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}, {2.8525737982333674`, 1.641328684369108}, {
       2.8525737982333674`, 1.641328684369108}}, {{2.8525737982333674`, 
       1.641328684369108}, {2.786721532538617, 1.6209810924246582`}, {
       2.786721532538617, 1.6209810924246582`}, {2.8525737982333674`, 
       1.641328684369108}, {2.8525737982333674`, 1.641328684369108}}, {{
       2.786721532538617, 1.6209810924246582`}, {2.6973738914708894`, 
       1.641328684369108}, {2.6973738914708894`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}}, {{2.786721532538617, 1.6209810924246582`}, {
       2.6973738914708894`, 1.641328684369108}, {2.6973738914708894`, 
       1.641328684369108}, {2.786721532538617, 1.6209810924246582`}, {
       2.786721532538617, 1.6209810924246582`}}, {{2.786721532538617, 
       1.6209810924246582`}, {2.6973738914708894`, 1.641328684369108}, {
       2.6973738914708894`, 1.641328684369108}, {2.786721532538617, 
       1.6209810924246582`}, {2.786721532538617, 1.6209810924246582`}}, {{
       2.786721532538617, 1.6209810924246582`}, {2.6973738914708894`, 
       1.641328684369108}, {2.6973738914708894`, 1.641328684369108}, {
       2.786721532538617, 1.6209810924246582`}, {2.786721532538617, 
       1.6209810924246582`}}, {{2.69737389147089, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}, {2.69737389147089, 1.910142808211672}, {
       2.69737389147089, 1.910142808211672}}, {{2.69737389147089, 
       1.910142808211672}, {2.786721532538617, 1.9304904001561218`}, {
       2.786721532538617, 1.9304904001561218`}, {2.69737389147089, 
       1.910142808211672}, {2.69737389147089, 1.910142808211672}}, {{
       2.69737389147089, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}, {
       2.69737389147089, 1.910142808211672}, {2.69737389147089, 
       1.910142808211672}}, {{2.69737389147089, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}, {2.69737389147089, 1.910142808211672}, {
       2.69737389147089, 1.910142808211672}}, {{2.786721532538617, 
       1.9304904001561218`}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}}, {{
       2.786721532538617, 1.9304904001561218`}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}, {
       2.786721532538617, 1.9304904001561218`}, {2.786721532538617, 
       1.9304904001561218`}}, {{2.786721532538617, 1.9304904001561218`}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}, {2.786721532538617, 1.9304904001561218`}, {
       2.786721532538617, 1.9304904001561218`}}, {{2.786721532538617, 
       1.9304904001561218`}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}, {2.786721532538617, 
       1.9304904001561218`}, {2.786721532538617, 1.9304904001561218`}}, {{
       2.8525737982333674`, 1.910142808211672}, {2.9031214626104753`, 
       1.863286869195481}, {2.9031214626104753`, 1.863286869195481}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}, {{2.8525737982333674`, 1.910142808211672}, {
       2.9031214626104753`, 1.863286869195481}, {2.9031214626104753`, 
       1.863286869195481}, {2.8525737982333674`, 1.910142808211672}, {
       2.8525737982333674`, 1.910142808211672}}, {{2.8525737982333674`, 
       1.910142808211672}, {2.9031214626104753`, 1.863286869195481}, {
       2.9031214626104753`, 1.863286869195481}, {2.8525737982333674`, 
       1.910142808211672}, {2.8525737982333674`, 1.910142808211672}}, {{
       2.8525737982333674`, 1.910142808211672}, {2.9031214626104753`, 
       1.863286869195481}, {2.9031214626104753`, 1.863286869195481}, {
       2.8525737982333674`, 1.910142808211672}, {2.8525737982333674`, 
       1.910142808211672}}, {{2.9031214626104753`, 1.863286869195481}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}, {2.9031214626104753`, 1.863286869195481}, {
       2.9031214626104753`, 1.863286869195481}}, {{2.9031214626104753`, 
       1.863286869195481}, {2.930173751614606, 1.77573574629039}, {
       2.930173751614606, 1.77573574629039}, {2.9031214626104753`, 
       1.863286869195481}, {2.9031214626104753`, 1.863286869195481}}, {{
       2.9031214626104753`, 1.863286869195481}, {2.930173751614606, 
       1.77573574629039}, {2.930173751614606, 1.77573574629039}, {
       2.9031214626104753`, 1.863286869195481}, {2.9031214626104753`, 
       1.863286869195481}}, {{2.9031214626104753`, 1.863286869195481}, {
       2.930173751614606, 1.77573574629039}, {2.930173751614606, 
       1.77573574629039}, {2.9031214626104753`, 1.863286869195481}, {
       2.9031214626104753`, 1.863286869195481}}, {{2.6247494575628445`, 
       2.0974156803741835`}, {2.55316978268104, 2.174635035233291}, {
       2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.3290737449515064`}, {2.6247494575628445`, 2.406293099810614}, {
       2.6247494575628445`, 2.406293099810614}, {2.55316978268104, 
       2.3290737449515064`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}}, {{
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}, {{2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.1512548958205713`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.7274132179755792`, 2.074035540961464}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.7274132179755792`, 2.074035540961464}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.861161063919244, 
       2.1512548958205713`}, {2.892245149450175, 2.2518543900923986`}, {
       2.892245149450175, 2.2518543900923986`}}, {{2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}}, {{
       2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`, 
       2.4296732392233333`}, {2.8030799188210644`, 2.406293099810614}, {
       2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}, {{2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}}, {{2.6247494575628445`, 
       2.0974156803741835`}, {2.55316978268104, 2.174635035233291}, {
       2.55316978268104, 2.174635035233291}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}}, {{
       2.6247494575628445`, 2.0974156803741835`}, {2.55316978268104, 
       2.174635035233291}, {2.55316978268104, 2.174635035233291}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}}, {{2.6247494575628445`, 2.0974156803741835`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.6247494575628445`, 2.0974156803741835`}}, {{2.6247494575628445`, 
       2.0974156803741835`}, {2.55316978268104, 2.174635035233291}, {
       2.55316978268104, 2.174635035233291}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}}, {{
       2.55316978268104, 2.174635035233291}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}}, {{2.55316978268104, 2.174635035233291}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}, {2.55316978268104, 2.174635035233291}, {
       2.55316978268104, 2.174635035233291}}, {{2.55316978268104, 
       2.174635035233291}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.174635035233291}, {2.55316978268104, 2.174635035233291}}, {{
       2.55316978268104, 2.174635035233291}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.174635035233291}, {2.55316978268104, 
       2.174635035233291}}, {{2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}}, {{2.535584226933734, 
       2.2518543900923986`}, {2.55316978268104, 2.3290737449515064`}, {
       2.55316978268104, 2.3290737449515064`}, {2.535584226933734, 
       2.2518543900923986`}, {2.535584226933734, 2.2518543900923986`}}, {{
       2.535584226933734, 2.2518543900923986`}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}, {
       2.535584226933734, 2.2518543900923986`}, {2.535584226933734, 
       2.2518543900923986`}}, {{2.535584226933734, 2.2518543900923986`}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}, {2.535584226933734, 2.2518543900923986`}, {
       2.535584226933734, 2.2518543900923986`}}, {{2.55316978268104, 
       2.3290737449515064`}, {2.6247494575628445`, 2.406293099810614}, {
       2.6247494575628445`, 2.406293099810614}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}}, {{
       2.55316978268104, 2.3290737449515064`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}, {
       2.55316978268104, 2.3290737449515064`}, {2.55316978268104, 
       2.3290737449515064`}}, {{2.55316978268104, 2.3290737449515064`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}, {2.55316978268104, 2.3290737449515064`}, {
       2.55316978268104, 2.3290737449515064`}}, {{2.55316978268104, 
       2.3290737449515064`}, {2.6247494575628445`, 2.406293099810614}, {
       2.6247494575628445`, 2.406293099810614}, {2.55316978268104, 
       2.3290737449515064`}, {2.55316978268104, 2.3290737449515064`}}, {{
       2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}, {{2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.1512548958205713`}, {2.861161063919244, 
       2.1512548958205713`}, {2.892245149450175, 2.2518543900923986`}, {
       2.892245149450175, 2.2518543900923986`}}, {{2.892245149450175, 
       2.2518543900923986`}, {2.861161063919244, 2.1512548958205713`}, {
       2.861161063919244, 2.1512548958205713`}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}}, {{
       2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}}, {{2.861161063919244, 2.1512548958205713`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.861161063919244, 2.1512548958205713`}, {
       2.861161063919244, 2.1512548958205713`}}, {{2.861161063919244, 
       2.1512548958205713`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.861161063919244, 
       2.1512548958205713`}, {2.861161063919244, 2.1512548958205713`}}, {{
       2.861161063919244, 2.1512548958205713`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.861161063919244, 2.1512548958205713`}, {2.861161063919244, 
       2.1512548958205713`}}, {{2.861161063919244, 2.1512548958205713`}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.861161063919244, 2.1512548958205713`}, {
       2.861161063919244, 2.1512548958205713`}}, {{2.8030799188210644`, 
       2.0974156803741835`}, {2.7274132179755792`, 2.074035540961464}, {
       2.7274132179755792`, 2.074035540961464}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}}, {{
       2.8030799188210644`, 2.0974156803741835`}, {2.7274132179755792`, 
       2.074035540961464}, {2.7274132179755792`, 2.074035540961464}, {
       2.8030799188210644`, 2.0974156803741835`}, {2.8030799188210644`, 
       2.0974156803741835`}}, {{2.8030799188210644`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}, {2.8030799188210644`, 2.0974156803741835`}, {
       2.8030799188210644`, 2.0974156803741835`}}, {{2.8030799188210644`, 
       2.0974156803741835`}, {2.7274132179755792`, 2.074035540961464}, {
       2.7274132179755792`, 2.074035540961464}, {2.8030799188210644`, 
       2.0974156803741835`}, {2.8030799188210644`, 2.0974156803741835`}}, {{
       2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}}, {{2.7274132179755792`, 2.074035540961464}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.7274132179755792`, 2.074035540961464}, {
       2.7274132179755792`, 2.074035540961464}}, {{2.7274132179755792`, 
       2.074035540961464}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.6247494575628445`, 2.0974156803741835`}, {2.7274132179755792`, 
       2.074035540961464}, {2.7274132179755792`, 2.074035540961464}}, {{
       2.7274132179755792`, 2.074035540961464}, {2.6247494575628445`, 
       2.0974156803741835`}, {2.6247494575628445`, 2.0974156803741835`}, {
       2.7274132179755792`, 2.074035540961464}, {2.7274132179755792`, 
       2.074035540961464}}, {{2.6247494575628445`, 2.406293099810614}, {
       2.7274132179755792`, 2.4296732392233333`}, {2.7274132179755792`, 
       2.4296732392233333`}, {2.6247494575628445`, 2.406293099810614}, {
       2.6247494575628445`, 2.406293099810614}}, {{2.6247494575628445`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.7274132179755792`, 2.4296732392233333`}, {2.6247494575628445`, 
       2.406293099810614}, {2.6247494575628445`, 2.406293099810614}}, {{
       2.6247494575628445`, 2.406293099810614}, {2.7274132179755792`, 
       2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.6247494575628445`, 2.406293099810614}, {2.6247494575628445`, 
       2.406293099810614}}, {{2.6247494575628445`, 2.406293099810614}, {
       2.7274132179755792`, 2.4296732392233333`}, {2.7274132179755792`, 
       2.4296732392233333`}, {2.6247494575628445`, 2.406293099810614}, {
       2.6247494575628445`, 2.406293099810614}}, {{2.7274132179755792`, 
       2.4296732392233333`}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.7274132179755792`, 
       2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}}, {{
       2.7274132179755792`, 2.4296732392233333`}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}, {
       2.7274132179755792`, 2.4296732392233333`}, {2.7274132179755792`, 
       2.4296732392233333`}}, {{2.7274132179755792`, 2.4296732392233333`}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}, {2.7274132179755792`, 2.4296732392233333`}, {
       2.7274132179755792`, 2.4296732392233333`}}, {{2.7274132179755792`, 
       2.4296732392233333`}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}, {2.7274132179755792`, 
       2.4296732392233333`}, {2.7274132179755792`, 2.4296732392233333`}}, {{
       2.8030799188210644`, 2.406293099810614}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}, {{2.8030799188210644`, 2.406293099810614}, {
       2.861161063919244, 2.352453884364226}, {2.861161063919244, 
       2.352453884364226}, {2.8030799188210644`, 2.406293099810614}, {
       2.8030799188210644`, 2.406293099810614}}, {{2.8030799188210644`, 
       2.406293099810614}, {2.861161063919244, 2.352453884364226}, {
       2.861161063919244, 2.352453884364226}, {2.8030799188210644`, 
       2.406293099810614}, {2.8030799188210644`, 2.406293099810614}}, {{
       2.8030799188210644`, 2.406293099810614}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}, {
       2.8030799188210644`, 2.406293099810614}, {2.8030799188210644`, 
       2.406293099810614}}, {{2.861161063919244, 2.352453884364226}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}, {2.861161063919244, 2.352453884364226}, {
       2.861161063919244, 2.352453884364226}}, {{2.861161063919244, 
       2.352453884364226}, {2.892245149450175, 2.2518543900923986`}, {
       2.892245149450175, 2.2518543900923986`}, {2.861161063919244, 
       2.352453884364226}, {2.861161063919244, 2.352453884364226}}, {{
       2.861161063919244, 2.352453884364226}, {2.892245149450175, 
       2.2518543900923986`}, {2.892245149450175, 2.2518543900923986`}, {
       2.861161063919244, 2.352453884364226}, {2.861161063919244, 
       2.352453884364226}}, {{2.861161063919244, 2.352453884364226}, {
       2.892245149450175, 2.2518543900923986`}, {2.892245149450175, 
       2.2518543900923986`}, {2.861161063919244, 2.352453884364226}, {
       2.861161063919244, 2.352453884364226}}, {{2.6514813726365816`, 
       2.616608750210834}, {2.5890835647207404`, 2.683922809402078}, {
       2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`, 
       2.818550927784567}, {2.6514813726365816`, 2.885864986975811}, {
       2.6514813726365816`, 2.885864986975811}, {2.5890835647207404`, 
       2.818550927784567}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.6514813726365816`, 
       2.616608750210834}, {2.6514813726365816`, 2.616608750210834}}, {{
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}, {{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}, {{2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}}, {{
       2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`, 
       2.9062460441757696`}, {2.806936533413827, 2.885864986975811}, {
       2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`, 
       2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.806936533413827, 
       2.885864986975811}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}, {{2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}}, {{2.6514813726365816`, 
       2.616608750210834}, {2.5890835647207404`, 2.683922809402078}, {
       2.5890835647207404`, 2.683922809402078}, {2.6514813726365816`, 
       2.616608750210834}, {2.6514813726365816`, 2.616608750210834}}, {{
       2.6514813726365816`, 2.616608750210834}, {2.5890835647207404`, 
       2.683922809402078}, {2.5890835647207404`, 2.683922809402078}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}}, {{2.6514813726365816`, 2.616608750210834}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}, {2.6514813726365816`, 2.616608750210834}, {
       2.6514813726365816`, 2.616608750210834}}, {{2.6514813726365816`, 
       2.616608750210834}, {2.5890835647207404`, 2.683922809402078}, {
       2.5890835647207404`, 2.683922809402078}, {2.6514813726365816`, 
       2.616608750210834}, {2.6514813726365816`, 2.616608750210834}}, {{
       2.5890835647207404`, 2.683922809402078}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}}, {{2.5890835647207404`, 2.683922809402078}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}, {2.5890835647207404`, 2.683922809402078}, {
       2.5890835647207404`, 2.683922809402078}}, {{2.5890835647207404`, 
       2.683922809402078}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`, 
       2.683922809402078}, {2.5890835647207404`, 2.683922809402078}}, {{
       2.5890835647207404`, 2.683922809402078}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.683922809402078}, {2.5890835647207404`, 
       2.683922809402078}}, {{2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}}, {{2.573753792247959, 
       2.7512368685933226`}, {2.5890835647207404`, 2.818550927784567}, {
       2.5890835647207404`, 2.818550927784567}, {2.573753792247959, 
       2.7512368685933226`}, {2.573753792247959, 2.7512368685933226`}}, {{
       2.573753792247959, 2.7512368685933226`}, {2.5890835647207404`, 
       2.818550927784567}, {2.5890835647207404`, 2.818550927784567}, {
       2.573753792247959, 2.7512368685933226`}, {2.573753792247959, 
       2.7512368685933226`}}, {{2.573753792247959, 2.7512368685933226`}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}, {2.573753792247959, 2.7512368685933226`}, {
       2.573753792247959, 2.7512368685933226`}}, {{2.5890835647207404`, 
       2.818550927784567}, {2.6514813726365816`, 2.885864986975811}, {
       2.6514813726365816`, 2.885864986975811}, {2.5890835647207404`, 
       2.818550927784567}, {2.5890835647207404`, 2.818550927784567}}, {{
       2.5890835647207404`, 2.818550927784567}, {2.6514813726365816`, 
       2.885864986975811}, {2.6514813726365816`, 2.885864986975811}, {
       2.5890835647207404`, 2.818550927784567}, {2.5890835647207404`, 
       2.818550927784567}}, {{2.5890835647207404`, 2.818550927784567}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}, {2.5890835647207404`, 2.818550927784567}, {
       2.5890835647207404`, 2.818550927784567}}, {{2.5890835647207404`, 
       2.818550927784567}, {2.6514813726365816`, 2.885864986975811}, {
       2.6514813726365816`, 2.885864986975811}, {2.5890835647207404`, 
       2.818550927784567}, {2.5890835647207404`, 2.818550927784567}}, {{
       2.8846641138024496`, 2.7512368685933226`}, {2.8575673324689035`, 
       2.66354175220212}, {2.8575673324689035`, 2.66354175220212}, {
       2.8846641138024496`, 2.7512368685933226`}, {2.8846641138024496`, 
       2.7512368685933226`}}, {{2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}}, {{2.8846641138024496`, 
       2.7512368685933226`}, {2.8575673324689035`, 2.66354175220212}, {
       2.8575673324689035`, 2.66354175220212}, {2.8846641138024496`, 
       2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}}, {{
       2.8846641138024496`, 2.7512368685933226`}, {2.8575673324689035`, 
       2.66354175220212}, {2.8575673324689035`, 2.66354175220212}, {
       2.8846641138024496`, 2.7512368685933226`}, {2.8846641138024496`, 
       2.7512368685933226`}}, {{2.8575673324689035`, 2.66354175220212}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.8575673324689035`, 2.66354175220212}, {
       2.8575673324689035`, 2.66354175220212}}, {{2.8575673324689035`, 
       2.66354175220212}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}, {2.8575673324689035`, 
       2.66354175220212}, {2.8575673324689035`, 2.66354175220212}}, {{
       2.8575673324689035`, 2.66354175220212}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}, {
       2.8575673324689035`, 2.66354175220212}, {2.8575673324689035`, 
       2.66354175220212}}, {{2.8575673324689035`, 2.66354175220212}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}, {2.8575673324689035`, 2.66354175220212}, {
       2.8575673324689035`, 2.66354175220212}}, {{2.806936533413827, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}}, {{
       2.806936533413827, 2.616608750210834}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.806936533413827, 2.616608750210834}, {2.806936533413827, 
       2.616608750210834}}, {{2.806936533413827, 2.616608750210834}, {
       2.7409759618859693`, 2.5962276930108756`}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.806936533413827, 2.616608750210834}, {
       2.806936533413827, 2.616608750210834}}, {{2.806936533413827, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}, {2.806936533413827, 
       2.616608750210834}, {2.806936533413827, 2.616608750210834}}, {{
       2.7409759618859693`, 2.5962276930108756`}, {2.6514813726365816`, 
       2.616608750210834}, {2.6514813726365816`, 2.616608750210834}, {
       2.7409759618859693`, 2.5962276930108756`}, {2.7409759618859693`, 
       2.5962276930108756`}}, {{2.7409759618859693`, 2.5962276930108756`}, {
       2.6514813726365816`, 2.616608750210834}, {2.6514813726365816`, 
       2.616608750210834}, {2.7409759618859693`, 2.5962276930108756`}, {
       2.7409759618859693`, 2.5962276930108756`}}, {{2.7409759618859693`, 
       2.5962276930108756`}, {2.6514813726365816`, 2.616608750210834}, {
       2.6514813726365816`, 2.616608750210834}, {2.7409759618859693`, 
       2.5962276930108756`}, {2.7409759618859693`, 2.5962276930108756`}}, {{
       2.7409759618859693`, 2.5962276930108756`}, {2.6514813726365816`, 
       2.616608750210834}, {2.6514813726365816`, 2.616608750210834}, {
       2.7409759618859693`, 2.5962276930108756`}, {2.7409759618859693`, 
       2.5962276930108756`}}, {{2.6514813726365816`, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}, {2.6514813726365816`, 2.885864986975811}, {
       2.6514813726365816`, 2.885864986975811}}, {{2.6514813726365816`, 
       2.885864986975811}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.6514813726365816`, 
       2.885864986975811}, {2.6514813726365816`, 2.885864986975811}}, {{
       2.6514813726365816`, 2.885864986975811}, {2.7409759618859693`, 
       2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.6514813726365816`, 2.885864986975811}, {2.6514813726365816`, 
       2.885864986975811}}, {{2.6514813726365816`, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}, {2.6514813726365816`, 2.885864986975811}, {
       2.6514813726365816`, 2.885864986975811}}, {{2.7409759618859693`, 
       2.9062460441757696`}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.7409759618859693`, 
       2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}}, {{
       2.7409759618859693`, 2.9062460441757696`}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}, {
       2.7409759618859693`, 2.9062460441757696`}, {2.7409759618859693`, 
       2.9062460441757696`}}, {{2.7409759618859693`, 2.9062460441757696`}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}, {2.7409759618859693`, 2.9062460441757696`}, {
       2.7409759618859693`, 2.9062460441757696`}}, {{2.7409759618859693`, 
       2.9062460441757696`}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}, {2.7409759618859693`, 
       2.9062460441757696`}, {2.7409759618859693`, 2.9062460441757696`}}, {{
       2.806936533413827, 2.885864986975811}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}, {{2.806936533413827, 2.885864986975811}, {
       2.8575673324689035`, 2.838931984984525}, {2.8575673324689035`, 
       2.838931984984525}, {2.806936533413827, 2.885864986975811}, {
       2.806936533413827, 2.885864986975811}}, {{2.806936533413827, 
       2.885864986975811}, {2.8575673324689035`, 2.838931984984525}, {
       2.8575673324689035`, 2.838931984984525}, {2.806936533413827, 
       2.885864986975811}, {2.806936533413827, 2.885864986975811}}, {{
       2.806936533413827, 2.885864986975811}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}, {
       2.806936533413827, 2.885864986975811}, {2.806936533413827, 
       2.885864986975811}}, {{2.8575673324689035`, 2.838931984984525}, {
       2.8846641138024496`, 2.7512368685933226`}, {2.8846641138024496`, 
       2.7512368685933226`}, {2.8575673324689035`, 2.838931984984525}, {
       2.8575673324689035`, 2.838931984984525}}, {{2.8575673324689035`, 
       2.838931984984525}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8846641138024496`, 2.7512368685933226`}, {2.8575673324689035`, 
       2.838931984984525}, {2.8575673324689035`, 2.838931984984525}}, {{
       2.8575673324689035`, 2.838931984984525}, {2.8846641138024496`, 
       2.7512368685933226`}, {2.8846641138024496`, 2.7512368685933226`}, {
       2.8575673324689035`, 2.838931984984525}, {2.8575673324689035`, 
       2.838931984984525}}, {{2.8575673324689035`, 2.838931984984525}, {
       2.8846641138024496`, 2.7512368685933226`}, {2.8846641138024496`, 
       2.7512368685933226`}, {2.8575673324689035`, 2.838931984984525}, {
       2.8575673324689035`, 2.838931984984525}}, {{2.685911913296408, 
       3.061827971251255}, {2.621619736032427, 3.1311856549653796`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427, 
       3.269901022393628}, {2.685911913296408, 3.3392587061077523`}, {
       2.685911913296408, 3.3392587061077523`}, {2.621619736032427, 
       3.269901022393628}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}}, {{
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}}, {{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8460866227472827`, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8982545500606327`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}, {{2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}}, {{
       2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`, 
       3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}, {{2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}, {{2.685911913296408, 
       3.061827971251255}, {2.621619736032427, 3.1311856549653796`}, {
       2.621619736032427, 3.1311856549653796`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}}, {{
       2.685911913296408, 3.061827971251255}, {2.621619736032427, 
       3.1311856549653796`}, {2.621619736032427, 3.1311856549653796`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}}, {{2.685911913296408, 3.061827971251255}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}, {2.685911913296408, 3.061827971251255}, {
       2.685911913296408, 3.061827971251255}}, {{2.685911913296408, 
       3.061827971251255}, {2.621619736032427, 3.1311856549653796`}, {
       2.621619736032427, 3.1311856549653796`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}}, {{
       2.621619736032427, 3.1311856549653796`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}}, {{2.621619736032427, 3.1311856549653796`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.621619736032427, 3.1311856549653796`}, {
       2.621619736032427, 3.1311856549653796`}}, {{2.621619736032427, 
       3.1311856549653796`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427, 
       3.1311856549653796`}, {2.621619736032427, 3.1311856549653796`}}, {{
       2.621619736032427, 3.1311856549653796`}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.1311856549653796`}, {2.621619736032427, 
       3.1311856549653796`}}, {{2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}}, {{2.6058245585709714`, 
       3.2005433386795037`}, {2.621619736032427, 3.269901022393628}, {
       2.621619736032427, 3.269901022393628}, {2.6058245585709714`, 
       3.2005433386795037`}, {2.6058245585709714`, 3.2005433386795037`}}, {{
       2.6058245585709714`, 3.2005433386795037`}, {2.621619736032427, 
       3.269901022393628}, {2.621619736032427, 3.269901022393628}, {
       2.6058245585709714`, 3.2005433386795037`}, {2.6058245585709714`, 
       3.2005433386795037`}}, {{2.6058245585709714`, 3.2005433386795037`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}, {2.6058245585709714`, 3.2005433386795037`}, {
       2.6058245585709714`, 3.2005433386795037`}}, {{2.621619736032427, 
       3.269901022393628}, {2.685911913296408, 3.3392587061077523`}, {
       2.685911913296408, 3.3392587061077523`}, {2.621619736032427, 
       3.269901022393628}, {2.621619736032427, 3.269901022393628}}, {{
       2.621619736032427, 3.269901022393628}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}, {
       2.621619736032427, 3.269901022393628}, {2.621619736032427, 
       3.269901022393628}}, {{2.621619736032427, 3.269901022393628}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}, {2.621619736032427, 3.269901022393628}, {
       2.621619736032427, 3.269901022393628}}, {{2.621619736032427, 
       3.269901022393628}, {2.685911913296408, 3.3392587061077523`}, {
       2.685911913296408, 3.3392587061077523`}, {2.621619736032427, 
       3.269901022393628}, {2.621619736032427, 3.269901022393628}}, {{
       2.9261739774727196`, 3.2005433386795037`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.9261739774727196`, 3.2005433386795037`}, {2.9261739774727196`, 
       3.2005433386795037`}}, {{2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}}, {{2.9261739774727196`, 
       3.2005433386795037`}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.9261739774727196`, 
       3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}}, {{
       2.9261739774727196`, 3.2005433386795037`}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.9261739774727196`, 3.2005433386795037`}, {2.9261739774727196`, 
       3.2005433386795037`}}, {{2.8982545500606323`, 3.1101858380472214`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}}, {{2.8982545500606323`, 
       3.1101858380472214`}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}, {2.8982545500606323`, 
       3.1101858380472214`}, {2.8982545500606323`, 3.1101858380472214`}}, {{
       2.8982545500606323`, 3.1101858380472214`}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}, {
       2.8982545500606323`, 3.1101858380472214`}, {2.8982545500606323`, 
       3.1101858380472214`}}, {{2.8982545500606323`, 3.1101858380472214`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}, {2.8982545500606323`, 3.1101858380472214`}, {
       2.8982545500606323`, 3.1101858380472214`}}, {{2.8460866227472827`, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.778123517972477, 3.0408281543330973`}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}}, {{
       2.8460866227472827`, 3.061827971251255}, {2.778123517972477, 
       3.0408281543330973`}, {2.778123517972477, 3.0408281543330973`}, {
       2.8460866227472827`, 3.061827971251255}, {2.8460866227472827`, 
       3.061827971251255}}, {{2.8460866227472827`, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}, {2.8460866227472827`, 3.061827971251255}, {
       2.8460866227472827`, 3.061827971251255}}, {{2.8460866227472827`, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.778123517972477, 3.0408281543330973`}, {2.8460866227472827`, 
       3.061827971251255}, {2.8460866227472827`, 3.061827971251255}}, {{
       2.778123517972477, 3.0408281543330973`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}}, {{2.778123517972477, 3.0408281543330973`}, {
       2.685911913296408, 3.061827971251255}, {2.685911913296408, 
       3.061827971251255}, {2.778123517972477, 3.0408281543330973`}, {
       2.778123517972477, 3.0408281543330973`}}, {{2.778123517972477, 
       3.0408281543330973`}, {2.685911913296408, 3.061827971251255}, {
       2.685911913296408, 3.061827971251255}, {2.778123517972477, 
       3.0408281543330973`}, {2.778123517972477, 3.0408281543330973`}}, {{
       2.778123517972477, 3.0408281543330973`}, {2.685911913296408, 
       3.061827971251255}, {2.685911913296408, 3.061827971251255}, {
       2.778123517972477, 3.0408281543330973`}, {2.778123517972477, 
       3.0408281543330973`}}, {{2.685911913296408, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}, {2.685911913296408, 3.3392587061077523`}, {
       2.685911913296408, 3.3392587061077523`}}, {{2.685911913296408, 
       3.3392587061077523`}, {2.778123517972477, 3.36025852302591}, {
       2.778123517972477, 3.36025852302591}, {2.685911913296408, 
       3.3392587061077523`}, {2.685911913296408, 3.3392587061077523`}}, {{
       2.685911913296408, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}, {
       2.685911913296408, 3.3392587061077523`}, {2.685911913296408, 
       3.3392587061077523`}}, {{2.685911913296408, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}, {2.685911913296408, 3.3392587061077523`}, {
       2.685911913296408, 3.3392587061077523`}}, {{2.778123517972477, 
       3.36025852302591}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}}, {{
       2.778123517972477, 3.36025852302591}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.778123517972477, 3.36025852302591}, {2.778123517972477, 
       3.36025852302591}}, {{2.778123517972477, 3.36025852302591}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.778123517972477, 3.36025852302591}, {
       2.778123517972477, 3.36025852302591}}, {{2.778123517972477, 
       3.36025852302591}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.778123517972477, 
       3.36025852302591}, {2.778123517972477, 3.36025852302591}}, {{
       2.8460866227472827`, 3.3392587061077523`}, {2.8982545500606323`, 
       3.290900839311786}, {2.8982545500606323`, 3.290900839311786}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}}, {{2.8460866227472827`, 3.3392587061077523`}, {
       2.8982545500606323`, 3.290900839311786}, {2.8982545500606323`, 
       3.290900839311786}, {2.8460866227472827`, 3.3392587061077523`}, {
       2.8460866227472827`, 3.3392587061077523`}}, {{2.8460866227472827`, 
       3.3392587061077523`}, {2.8982545500606323`, 3.290900839311786}, {
       2.8982545500606323`, 3.290900839311786}, {2.8460866227472827`, 
       3.3392587061077523`}, {2.8460866227472827`, 3.3392587061077523`}}, {{
       2.8460866227472827`, 3.3392587061077523`}, {2.8982545500606323`, 
       3.290900839311786}, {2.8982545500606323`, 3.290900839311786}, {
       2.8460866227472827`, 3.3392587061077523`}, {2.8460866227472827`, 
       3.3392587061077523`}}, {{2.8982545500606327`, 3.290900839311786}, {
       2.9261739774727196`, 3.2005433386795037`}, {2.9261739774727196`, 
       3.2005433386795037`}, {2.8982545500606327`, 3.290900839311786}, {
       2.8982545500606327`, 3.290900839311786}}, {{2.8982545500606327`, 
       3.290900839311786}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.9261739774727196`, 3.2005433386795037`}, {2.8982545500606327`, 
       3.290900839311786}, {2.8982545500606327`, 3.290900839311786}}, {{
       2.8982545500606327`, 3.290900839311786}, {2.9261739774727196`, 
       3.2005433386795037`}, {2.9261739774727196`, 3.2005433386795037`}, {
       2.8982545500606327`, 3.290900839311786}, {2.8982545500606327`, 
       3.290900839311786}}, {{2.8982545500606327`, 3.290900839311786}, {
       2.9261739774727196`, 3.2005433386795037`}, {2.9261739774727196`, 
       3.2005433386795037`}, {2.8982545500606327`, 3.290900839311786}, {
       2.8982545500606327`, 3.290900839311786}}, {{2.6312213879819453`, 
       3.611369347046231}, {2.5601528287587105`, 3.688037316033885}, {
       2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.6312213879819453`, 3.918041222996845}, {
       2.6312213879819453`, 3.918041222996845}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.6312213879819453`, 
       3.611369347046231}, {2.6312213879819453`, 3.611369347046231}}, {{
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}, {{2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.664824122830031}, {2.8082784781149197`, 
       3.611369347046231}, {2.733152076393428, 3.5881561538423776`}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}, {2.733152076393428, 3.5881561538423776`}, {
       2.8082784781149197`, 3.611369347046231}, {2.865944893993159, 
       3.664824122830031}, {2.896807023181407, 3.764705285021538}, {
       2.896807023181407, 3.764705285021538}}, {{2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}}, {{
       2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.8082784781149197`, 3.918041222996845}, {
       2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.8082784781149197`, 
       3.918041222996845}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}, {{2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}}, {{2.6312213879819453`, 
       3.611369347046231}, {2.5601528287587105`, 3.688037316033885}, {
       2.5601528287587105`, 3.688037316033885}, {2.6312213879819453`, 
       3.611369347046231}, {2.6312213879819453`, 3.611369347046231}}, {{
       2.6312213879819453`, 3.611369347046231}, {2.5601528287587105`, 
       3.688037316033885}, {2.5601528287587105`, 3.688037316033885}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}}, {{2.6312213879819453`, 3.611369347046231}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}, {2.6312213879819453`, 3.611369347046231}, {
       2.6312213879819453`, 3.611369347046231}}, {{2.6312213879819453`, 
       3.611369347046231}, {2.5601528287587105`, 3.688037316033885}, {
       2.5601528287587105`, 3.688037316033885}, {2.6312213879819453`, 
       3.611369347046231}, {2.6312213879819453`, 3.611369347046231}}, {{
       2.5601528287587105`, 3.688037316033885}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}}, {{2.5601528287587105`, 3.688037316033885}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}, {2.5601528287587105`, 3.688037316033885}, {
       2.5601528287587105`, 3.688037316033885}}, {{2.5601528287587105`, 
       3.688037316033885}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.688037316033885}, {2.5601528287587105`, 3.688037316033885}}, {{
       2.5601528287587105`, 3.688037316033885}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.688037316033885}, {2.5601528287587105`, 
       3.688037316033885}}, {{2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.8413732540091914`}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}}, {{2.542692842915458, 
       3.764705285021538}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.5601528287587105`, 3.8413732540091914`}, {2.542692842915458, 
       3.764705285021538}, {2.542692842915458, 3.764705285021538}}, {{
       2.542692842915458, 3.764705285021538}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.542692842915458, 3.764705285021538}, {2.542692842915458, 
       3.764705285021538}}, {{2.542692842915458, 3.764705285021538}, {
       2.5601528287587105`, 3.8413732540091914`}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.542692842915458, 3.764705285021538}, {
       2.542692842915458, 3.764705285021538}}, {{2.5601528287587105`, 
       3.8413732540091914`}, {2.6312213879819453`, 3.918041222996845}, {
       2.6312213879819453`, 3.918041222996845}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}}, {{
       2.5601528287587105`, 3.8413732540091914`}, {2.6312213879819453`, 
       3.918041222996845}, {2.6312213879819453`, 3.918041222996845}, {
       2.5601528287587105`, 3.8413732540091914`}, {2.5601528287587105`, 
       3.8413732540091914`}}, {{2.5601528287587105`, 3.8413732540091914`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}, {2.5601528287587105`, 3.8413732540091914`}, {
       2.5601528287587105`, 3.8413732540091914`}}, {{2.5601528287587105`, 
       3.8413732540091914`}, {2.6312213879819453`, 3.918041222996845}, {
       2.6312213879819453`, 3.918041222996845}, {2.5601528287587105`, 
       3.8413732540091914`}, {2.5601528287587105`, 3.8413732540091914`}}, {{
       2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}, {{2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.664824122830031}, {2.865944893993159, 
       3.664824122830031}, {2.896807023181407, 3.764705285021538}, {
       2.896807023181407, 3.764705285021538}}, {{2.896807023181407, 
       3.764705285021538}, {2.865944893993159, 3.664824122830031}, {
       2.865944893993159, 3.664824122830031}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}}, {{
       2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}}, {{2.865944893993159, 3.664824122830031}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.865944893993159, 3.664824122830031}, {
       2.865944893993159, 3.664824122830031}}, {{2.865944893993159, 
       3.664824122830031}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}, {2.865944893993159, 
       3.664824122830031}, {2.865944893993159, 3.664824122830031}}, {{
       2.865944893993159, 3.664824122830031}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}, {
       2.865944893993159, 3.664824122830031}, {2.865944893993159, 
       3.664824122830031}}, {{2.865944893993159, 3.664824122830031}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}, {2.865944893993159, 3.664824122830031}, {
       2.865944893993159, 3.664824122830031}}, {{2.8082784781149197`, 
       3.611369347046231}, {2.733152076393428, 3.5881561538423776`}, {
       2.733152076393428, 3.5881561538423776`}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}}, {{
       2.8082784781149197`, 3.611369347046231}, {2.733152076393428, 
       3.5881561538423776`}, {2.733152076393428, 3.5881561538423776`}, {
       2.8082784781149197`, 3.611369347046231}, {2.8082784781149197`, 
       3.611369347046231}}, {{2.8082784781149197`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}, {2.8082784781149197`, 3.611369347046231}, {
       2.8082784781149197`, 3.611369347046231}}, {{2.8082784781149197`, 
       3.611369347046231}, {2.733152076393428, 3.5881561538423776`}, {
       2.733152076393428, 3.5881561538423776`}, {2.8082784781149197`, 
       3.611369347046231}, {2.8082784781149197`, 3.611369347046231}}, {{
       2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`, 
       3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}}, {{2.733152076393428, 3.5881561538423776`}, {
       2.6312213879819453`, 3.611369347046231}, {2.6312213879819453`, 
       3.611369347046231}, {2.733152076393428, 3.5881561538423776`}, {
       2.733152076393428, 3.5881561538423776`}}, {{2.733152076393428, 
       3.5881561538423776`}, {2.6312213879819453`, 3.611369347046231}, {
       2.6312213879819453`, 3.611369347046231}, {2.733152076393428, 
       3.5881561538423776`}, {2.733152076393428, 3.5881561538423776`}}, {{
       2.733152076393428, 3.5881561538423776`}, {2.6312213879819453`, 
       3.611369347046231}, {2.6312213879819453`, 3.611369347046231}, {
       2.733152076393428, 3.5881561538423776`}, {2.733152076393428, 
       3.5881561538423776`}}, {{2.6312213879819453`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}, {2.6312213879819453`, 3.918041222996845}, {
       2.6312213879819453`, 3.918041222996845}}, {{2.6312213879819453`, 
       3.918041222996845}, {2.733152076393428, 3.9412544162006986`}, {
       2.733152076393428, 3.9412544162006986`}, {2.6312213879819453`, 
       3.918041222996845}, {2.6312213879819453`, 3.918041222996845}}, {{
       2.6312213879819453`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}, {
       2.6312213879819453`, 3.918041222996845}, {2.6312213879819453`, 
       3.918041222996845}}, {{2.6312213879819453`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}, {2.6312213879819453`, 3.918041222996845}, {
       2.6312213879819453`, 3.918041222996845}}, {{2.733152076393428, 
       3.9412544162006986`}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}}, {{
       2.733152076393428, 3.9412544162006986`}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}, {
       2.733152076393428, 3.9412544162006986`}, {2.733152076393428, 
       3.9412544162006986`}}, {{2.733152076393428, 3.9412544162006986`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}, {2.733152076393428, 3.9412544162006986`}, {
       2.733152076393428, 3.9412544162006986`}}, {{2.733152076393428, 
       3.9412544162006986`}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}, {2.733152076393428, 
       3.9412544162006986`}, {2.733152076393428, 3.9412544162006986`}}, {{
       2.8082784781149197`, 3.918041222996845}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}, {{2.8082784781149197`, 3.918041222996845}, {
       2.865944893993159, 3.8645864472130453`}, {2.865944893993159, 
       3.8645864472130453`}, {2.8082784781149197`, 3.918041222996845}, {
       2.8082784781149197`, 3.918041222996845}}, {{2.8082784781149197`, 
       3.918041222996845}, {2.865944893993159, 3.8645864472130453`}, {
       2.865944893993159, 3.8645864472130453`}, {2.8082784781149197`, 
       3.918041222996845}, {2.8082784781149197`, 3.918041222996845}}, {{
       2.8082784781149197`, 3.918041222996845}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}, {
       2.8082784781149197`, 3.918041222996845}, {2.8082784781149197`, 
       3.918041222996845}}, {{2.865944893993159, 3.8645864472130453`}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}, {2.865944893993159, 3.8645864472130453`}, {
       2.865944893993159, 3.8645864472130453`}}, {{2.865944893993159, 
       3.8645864472130453`}, {2.896807023181407, 3.764705285021538}, {
       2.896807023181407, 3.764705285021538}, {2.865944893993159, 
       3.8645864472130453`}, {2.865944893993159, 3.8645864472130453`}}, {{
       2.865944893993159, 3.8645864472130453`}, {2.896807023181407, 
       3.764705285021538}, {2.896807023181407, 3.764705285021538}, {
       2.865944893993159, 3.8645864472130453`}, {2.865944893993159, 
       3.8645864472130453`}}, {{2.865944893993159, 3.8645864472130453`}, {
       2.896807023181407, 3.764705285021538}, {2.896807023181407, 
       3.764705285021538}, {2.865944893993159, 3.8645864472130453`}, {
       2.865944893993159, 3.8645864472130453`}}, {{
       2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}, {{
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}, {{
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}, {{
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}, {{
       2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}, {{
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}, {{
       2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}, {{
       2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}, {{
       2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}, {{
       2.913462864254548, -4.661246700458109}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}}, {{
       2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}, {{
       2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}, {{
       2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}, {{
       2.8461726475711813`, -4.588654765258637}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.588654765258637}, {
       2.8461726475711813`, -4.588654765258637}}, {{
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}, {{
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}, {{
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}, {{
       2.8296409175977266`, -4.516062830059166}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8296409175977266`, -4.516062830059166}, {
       2.8296409175977266`, -4.516062830059166}}, {{
       2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}, {{
       2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}, {{
       2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}, {{
       2.8461726475711813`, -4.443470894859695}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.8461726475711813`, -4.443470894859695}, {
       2.8461726475711813`, -4.443470894859695}}, {{
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}, {{
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}, {{
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}, {{
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}}, {{
       3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}, {{
       3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}, {{
       3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}, {{
       3.1357073525740784`, -4.610633834732857}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.1357073525740784`, -4.610633834732857}, {
       3.1357073525740784`, -4.610633834732857}}, {{
       3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}, {{
       3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}, {{
       3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}, {{
       3.0811067575681896`, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0811067575681896`, -4.661246700458109}, {
       3.0811067575681896`, -4.661246700458109}}, {{
       3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}, {{
       3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}, {{
       3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}, {{
       3.0099744325888467`, -4.683225769932328}, {
       2.913462864254548, -4.661246700458109}, {
       2.913462864254548, -4.661246700458109}, {
       3.0099744325888467`, -4.683225769932328}, {
       3.0099744325888467`, -4.683225769932328}}, {{
       2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}, {{
       2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}, {{
       2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}, {{
       2.913462864254548, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}, {
       2.913462864254548, -4.3708789596602236`}, {
       2.913462864254548, -4.3708789596602236`}}, {{
       3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}, {{
       3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}, {{
       3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}, {{
       3.0099744325888467`, -4.348899890186004}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0099744325888467`, -4.348899890186004}, {
       3.0099744325888467`, -4.348899890186004}}, {{
       3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}, {{
       3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}, {{
       3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}, {{
       3.0811067575681896`, -4.3708789596602236`}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.0811067575681896`, -4.3708789596602236`}, {
       3.0811067575681896`, -4.3708789596602236`}}, {{
       3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}, {{
       3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}, {{
       3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}, {{
       3.1357073525740784`, -4.421491825385475}, {
       3.164928704225011, -4.516062830059166}, {
       3.164928704225011, -4.516062830059166}, {
       3.1357073525740784`, -4.421491825385475}, {
       3.1357073525740784`, -4.421491825385475}}, {{
       2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}, {{
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}, {{
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}, {{
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}, {{
       2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}, {{
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}, {{
       2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}, {{
       2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}, {{
       2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}, {{
       2.894214723859047, -4.088387025762045}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}}, {{
       2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}, {{
       2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}, {{
       2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}, {{
       2.8304540193266963`, -4.019602688902729}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -4.019602688902729}, {
       2.8304540193266963`, -4.019602688902729}}, {{
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}, {{
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}, {{
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}, {{
       2.8147894130555353`, -3.950818352043413}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8147894130555353`, -3.950818352043413}, {
       2.8147894130555353`, -3.950818352043413}}, {{
       2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}, {{
       2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}, {{
       2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}, {{
       2.8304540193266963`, -3.882034015184097}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.8304540193266963`, -3.882034015184097}, {
       2.8304540193266963`, -3.882034015184097}}, {{
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}, {{
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}, {{
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}, {{
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}}, {{
       3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}, {{
       3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}, {{
       3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}, {{
       3.1048020254331252`, -4.040428910361281}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}, {
       3.1048020254331252`, -4.040428910361281}, {
       3.1048020254331252`, -4.040428910361281}}, {{
       3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}, {{
       3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}, {{
       3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}, {{
       3.053065345466072, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}, {
       3.053065345466072, -4.088387025762045}, {
       3.053065345466072, -4.088387025762045}}, {{
       2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}, {{
       2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}, {{
       2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}, {{
       2.985664059227857, -4.109213247220597}, {
       2.894214723859047, -4.088387025762045}, {
       2.894214723859047, -4.088387025762045}, {
       2.985664059227857, -4.109213247220597}, {
       2.985664059227857, -4.109213247220597}}, {{
       2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}, {{
       2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}, {{
       2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}, {{
       2.894214723859047, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}, {
       2.894214723859047, -3.8132496783247807`}, {
       2.894214723859047, -3.8132496783247807`}}, {{
       2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}, {{
       2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}, {{
       2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}, {{
       2.985664059227857, -3.792423456866229}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}, {
       2.985664059227857, -3.792423456866229}, {
       2.985664059227857, -3.792423456866229}}, {{
       3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}, {{
       3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}, {{
       3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}, {{
       3.053065345466072, -3.8132496783247807`}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.053065345466072, -3.8132496783247807`}, {
       3.053065345466072, -3.8132496783247807`}}, {{
       3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}, {{
       3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}, {{
       3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}, {{
       3.1048020254331252`, -3.861207793725545}, {
       3.132490656269584, -3.950818352043413}, {
       3.132490656269584, -3.950818352043413}, {
       3.1048020254331252`, -3.861207793725545}, {
       3.1048020254331252`, -3.861207793725545}}, {{
       2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.9294475372540476`, -3.40652189900994}, {
       2.9294475372540476`, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}, {{
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}, {{
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.142697993059333, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}, {{
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}, {{
       2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}, {{
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}, {{
       2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}, {{
       2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}, {{
       2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}, {{
       2.9294475372540476`, -3.6851387211615565`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.9294475372540476`, -3.6851387211615565`}, {
       2.9294475372540476`, -3.6851387211615565`}}, {{
       2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}, {{
       2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}, {{
       2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}, {{
       2.864880494500964, -3.6154845156236526`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.6154845156236526`}, {
       2.864880494500964, -3.6154845156236526`}}, {{
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}, {{
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}, {{
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}, {{
       2.849017788619051, -3.5458303100857482`}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}, {
       2.849017788619051, -3.5458303100857482`}, {
       2.849017788619051, -3.5458303100857482`}}, {{
       2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}, {{
       2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}, {{
       2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}, {{
       2.864880494500964, -3.476176104547844}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}, {
       2.864880494500964, -3.476176104547844}, {
       2.864880494500964, -3.476176104547844}}, {{
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}, {{
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}, {{
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}, {{
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}}, {{
       3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}, {{
       3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}, {{
       3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}, {{
       3.1426979930593326`, -3.6365741121261066`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.1426979930593326`, -3.6365741121261066`}, {
       3.1426979930593326`, -3.6365741121261066`}}, {{
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}, {{
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}, {{
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}, {{
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0903070345240415`, -3.6851387211615565`}, {
       3.0903070345240415`, -3.6851387211615565`}}, {{
       3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}, {{
       3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}, {{
       3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}, {{
       3.0220533701068373`, -3.706228317664011}, {
       2.929447537254048, -3.6851387211615565`}, {
       2.929447537254048, -3.6851387211615565`}, {
       3.0220533701068373`, -3.706228317664011}, {
       3.0220533701068373`, -3.706228317664011}}, {{
       2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}, {{
       2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}, {{
       2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}, {{
       2.929447537254048, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       2.929447537254048, -3.40652189900994}, {
       2.929447537254048, -3.40652189900994}}, {{
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}, {{
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}, {{
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}, {{
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0220533701068373`, -3.3854323025074855`}, {
       3.0220533701068373`, -3.3854323025074855`}}, {{
       3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}, {{
       3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}, {{
       3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}, {{
       3.0903070345240415`, -3.40652189900994}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.1426979930593326`, -3.45508650804539}, {
       3.0903070345240415`, -3.40652189900994}, {
       3.0903070345240415`, -3.40652189900994}}, {{
       3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}, {{
       3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}, {{
       3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}, {{
       3.142697993059333, -3.45508650804539}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.1707367831590387`, -3.5458303100857482`}, {
       3.142697993059333, -3.45508650804539}, {
       3.142697993059333, -3.45508650804539}}, {{
       2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}, {{
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}, {{
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}, {{
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}, {{
       2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}, {{
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}, {{
       2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}, {{
       2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}, {{
       2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}, {{
       2.9182066159980726`, -3.1504042943972586`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}}, {{
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}, {{
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}, {{
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}, {{
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -3.0753209902951495`}, {
       2.8486069863911347`, -3.0753209902951495`}}, {{
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}, {{
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}, {{
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}, {{
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8315078843280745`, -3.0002376861930404`}, {
       2.8315078843280745`, -3.0002376861930404`}}, {{
       2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}, {{
       2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}, {{
       2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}, {{
       2.8486069863911347`, -2.9251543820909314`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.8486069863911347`, -2.9251543820909314`}, {
       2.8486069863911347`, -2.9251543820909314`}}, {{
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}, {{
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}, {{
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}, {{
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}}, {{
       3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}, {{
       3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}, {{
       3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}, {{
       3.1480785770590383`, -3.098054385577691}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.1480785770590383`, -3.098054385577691}, {
       3.1480785770590383`, -3.098054385577691}}, {{
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}, {{
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}, {{
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}, {{
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0916040793380697`, -3.1504042943972586`}, {
       3.0916040793380697`, -3.1504042943972586`}}, {{
       3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}, {{
       3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}, {{
       3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}, {{
       3.0180304795540405`, -3.1731376896798}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       2.9182066159980726`, -3.1504042943972586`}, {
       3.0180304795540405`, -3.1731376896798}, {
       3.0180304795540405`, -3.1731376896798}}, {{
       2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}, {{
       2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}, {{
       2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}, {{
       2.9182066159980726`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}, {
       2.9182066159980726`, -2.8500710779888223`}, {
       2.9182066159980726`, -2.8500710779888223`}}, {{
       3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}, {{
       3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}, {{
       3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}, {{
       3.0180304795540405`, -2.827337682706281}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0180304795540405`, -2.827337682706281}, {
       3.0180304795540405`, -2.827337682706281}}, {{
       3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}, {{
       3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}, {{
       3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}, {{
       3.0916040793380697`, -2.8500710779888223`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.0916040793380697`, -2.8500710779888223`}, {
       3.0916040793380697`, -2.8500710779888223`}}, {{
       3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}, {{
       3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}, {{
       3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}, {{
       3.1480785770590383`, -2.90242098680839}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1783028110080678`, -3.0002376861930404`}, {
       3.1480785770590383`, -2.90242098680839}, {
       3.1480785770590383`, -2.90242098680839}}, {{
       2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.336748980863077}, {
       2.888016917539941, -2.336748980863077}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}, {{
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}, {{
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.8880169175399413`, -2.6367567863982466`}, {
       2.8880169175399413`, -2.6367567863982466`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}, {{
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}, {{
       2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}, {{
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}, {{
       2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}, {{
       2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}, {{
       2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}, {{
       2.888016917539941, -2.636756786398246}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}}, {{
       2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}, {{
       2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}, {{
       2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}, {{
       2.818492699093048, -2.561754835014454}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.561754835014454}, {
       2.818492699093048, -2.561754835014454}}, {{
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}, {{
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}, {{
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}, {{
       2.8014121238975815`, -2.4867528836306616`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}, {
       2.8014121238975815`, -2.4867528836306616`}, {
       2.8014121238975815`, -2.4867528836306616`}}, {{
       2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}, {{
       2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}, {{
       2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}, {{
       2.818492699093048, -2.411750932246869}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.888016917539941, -2.3367489808630766`}, {
       2.818492699093048, -2.411750932246869}, {
       2.818492699093048, -2.411750932246869}}, {{
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}, {{
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}, {{
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}, {{
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}}, {{
       3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}, {{
       3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}, {{
       3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}, {{
       3.1176398124586964`, -2.5844635986758258`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.1176398124586964`, -2.5844635986758258`}, {
       3.1176398124586964`, -2.5844635986758258`}}, {{
       3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}, {{
       3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}, {{
       3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}, {{
       3.0612265048246603`, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}, {
       3.0612265048246603`, -2.636756786398246}, {
       3.0612265048246603`, -2.636756786398246}}, {{
       2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}, {{
       2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}, {{
       2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}, {{
       2.987732621995157, -2.6594655500596183`}, {
       2.888016917539941, -2.636756786398246}, {
       2.888016917539941, -2.636756786398246}, {
       2.987732621995157, -2.6594655500596183`}, {
       2.987732621995157, -2.6594655500596183`}}, {{
       2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}, {{
       2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}, {{
       2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}, {{
       2.8880169175399413`, -2.3367489808630766`}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}, {
       2.8880169175399413`, -2.3367489808630766`}, {
       2.8880169175399413`, -2.3367489808630766`}}, {{
       2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}, {{
       2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}, {{
       2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}, {{
       2.987732621995157, -2.314040217201705}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}, {
       2.987732621995157, -2.314040217201705}, {
       2.987732621995157, -2.314040217201705}}, {{
       3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}, {{
       3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}, {{
       3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}, {{
       3.0612265048246603`, -2.336748980863077}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.0612265048246603`, -2.336748980863077}, {
       3.0612265048246603`, -2.336748980863077}}, {{
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}, {{
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}, {{
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}, {{
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1478312984670196`, -2.4867528836306616`}, {
       3.1176398124586964`, -2.3890421685854974`}, {
       3.1176398124586964`, -2.3890421685854974`}}, {{
       2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}, {{
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}, {{
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814847`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}, {{
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}, {{
       2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}, {{
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}, {{
       2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}, {{
       2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}, {{
       2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}, {{
       2.9713161527186798`, -2.148204444097589}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}}, {{
       2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}, {{
       2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}, {{
       2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}, {{
       2.9111042953067225`, -2.0832485639277305`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -2.0832485639277305`}, {
       2.9111042953067225`, -2.0832485639277305`}}, {{
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}, {{
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}, {{
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}, {{
       2.896311562915646, -2.018292683757872}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.896311562915646, -2.018292683757872}, {
       2.896311562915646, -2.018292683757872}}, {{
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}, {{
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}, {{
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}, {{
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9111042953067225`, -1.9533368035880132`}, {
       2.9111042953067225`, -1.9533368035880132`}}, {{
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}, {{
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}, {{
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}, {{
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}}, {{
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}, {{
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}, {{
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}, {{
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1701824084814842`, -2.1029156219706024`}, {
       3.1701824084814842`, -2.1029156219706024`}}, {{
       3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}, {{
       3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}, {{
       3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}, {{
       3.1213253323247474`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.1213253323247474`, -2.148204444097589}, {
       3.1213253323247474`, -2.148204444097589}}, {{
       3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}, {{
       3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}, {{
       3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}, {{
       3.0576755237769335`, -2.167871502140461}, {
       2.9713161527186798`, -2.148204444097589}, {
       2.9713161527186798`, -2.148204444097589}, {
       3.0576755237769335`, -2.167871502140461}, {
       3.0576755237769335`, -2.167871502140461}}, {{
       2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}, {{
       2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}, {{
       2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}, {{
       2.9713161527186798`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       2.9713161527186798`, -1.8883809234181548`}, {
       2.9713161527186798`, -1.8883809234181548`}}, {{
       3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}, {{
       3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}, {{
       3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}, {{
       3.0576755237769335`, -1.8687138653752828`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.0576755237769335`, -1.8687138653752828`}, {
       3.0576755237769335`, -1.8687138653752828`}}, {{
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}, {{
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}, {{
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}, {{
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1701824084814842`, -1.9336697455451413`}, {
       3.1213253323247474`, -1.8883809234181548`}, {
       3.1213253323247474`, -1.8883809234181548`}}, {{
       3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}, {{
       3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}, {{
       3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}, {{
       3.1701824084814847`, -1.9336697455451413`}, {
       3.196329922127781, -2.018292683757872}, {
       3.196329922127781, -2.018292683757872}, {
       3.1701824084814847`, -1.9336697455451413`}, {
       3.1701824084814847`, -1.9336697455451413`}}, {{
       2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}, {{
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}, {{
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}, {{
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}, {{
       2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}, {{
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}, {{
       2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}, {{
       2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}, {{
       2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}, {{
       2.9337398959944188`, -1.6498369908611012`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}}, {{
       2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}, {{
       2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}, {{
       2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}, {{
       2.8685225213678924`, -1.5794812145519623`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.5794812145519623`}, {
       2.8685225213678924`, -1.5794812145519623`}}, {{
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}, {{
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}, {{
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}, {{
       2.852500043212166, -1.5091254382428234`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.852500043212166, -1.5091254382428234`}, {
       2.852500043212166, -1.5091254382428234`}}, {{
       2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}, {{
       2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}, {{
       2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}, {{
       2.8685225213678924`, -1.4387696619336845`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.8685225213678924`, -1.4387696619336845`}, {
       2.8685225213678924`, -1.4387696619336845`}}, {{
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}, {{
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}, {{
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}, {{
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}}, {{
       3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}, {{
       3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}, {{
       3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}, {{
       3.149138252067751, -1.6007832295920914`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.149138252067751, -1.6007832295920914`}, {
       3.149138252067751, -1.6007832295920914`}}, {{
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}, {{
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}, {{
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}, {{
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0962196015589245`, -1.6498369908611012`}, {
       3.0962196015589245`, -1.6498369908611012`}}, {{
       3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}, {{
       3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}, {{
       3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}, {{
       3.0272784728943716`, -1.6711390059012303`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       2.9337398959944188`, -1.6498369908611012`}, {
       3.0272784728943716`, -1.6711390059012303`}, {
       3.0272784728943716`, -1.6711390059012303`}}, {{
       2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}, {{
       2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}, {{
       2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}, {{
       2.9337398959944188`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       2.9337398959944188`, -1.3684138856245456`}, {
       2.9337398959944188`, -1.3684138856245456`}}, {{
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}, {{
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}, {{
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}, {{
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0272784728943716`, -1.3471118705844165`}, {
       3.0272784728943716`, -1.3471118705844165`}}, {{
       3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}, {{
       3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}, {{
       3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}, {{
       3.0962196015589245`, -1.3684138856245456`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.0962196015589245`, -1.3684138856245456`}, {
       3.0962196015589245`, -1.3684138856245456`}}, {{
       3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}, {{
       3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}, {{
       3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}, {{
       3.149138252067751, -1.4174676468935554`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.1774594543411774`, -1.5091254382428234`}, {
       3.149138252067751, -1.4174676468935554`}, {
       3.149138252067751, -1.4174676468935554`}}, {{
       2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499283}, {
       2.89892525804436, -0.8685904706499283}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}, {{
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}, {{
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}, {{
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}, {{
       2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}, {{
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}, {{
       2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}, {{
       2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}, {{
       2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}, {{
       2.89892525804436, -1.119466389446595}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}}, {{
       2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}, {{
       2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}, {{
       2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}, {{
       2.840786930108623, -1.0567474097474283`}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -1.0567474097474283`}, {
       2.840786930108623, -1.0567474097474283`}}, {{
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}, {{
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}, {{
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}, {{
       2.8265036184191348`, -0.9940284300482617}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}, {
       2.8265036184191348`, -0.9940284300482617}, {
       2.8265036184191348`, -0.9940284300482617}}, {{
       2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}, {{
       2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}, {{
       2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}, {{
       2.840786930108623, -0.931309450349095}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}, {
       2.840786930108623, -0.931309450349095}, {
       2.840786930108623, -0.931309450349095}}, {{
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}, {{
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}, {{
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}, {{
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}}, {{
       3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}, {{
       3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}, {{
       3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}, {{
       3.090943111168985, -1.0757371888237437`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}, {
       3.090943111168985, -1.0757371888237437`}, {
       3.090943111168985, -1.0757371888237437`}}, {{
       3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}, {{
       3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}, {{
       3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}, {{
       3.04376853729481, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}, {
       3.04376853729481, -1.119466389446595}, {
       3.04376853729481, -1.119466389446595}}, {{
       2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}, {{
       2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}, {{
       2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}, {{
       2.982310651731147, -1.1384561685229104`}, {
       2.89892525804436, -1.119466389446595}, {
       2.89892525804436, -1.119466389446595}, {
       2.982310651731147, -1.1384561685229104`}, {
       2.982310651731147, -1.1384561685229104`}}, {{
       2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}, {{
       2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}, {{
       2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}, {{
       2.89892525804436, -0.8685904706499282}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}, {
       2.89892525804436, -0.8685904706499282}, {
       2.89892525804436, -0.8685904706499282}}, {{
       2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}, {{
       2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}, {{
       2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}, {{
       2.982310651731147, -0.8496006915736131}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}, {
       2.982310651731147, -0.8496006915736131}, {
       2.982310651731147, -0.8496006915736131}}, {{
       3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}, {{
       3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}, {{
       3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}, {{
       3.04376853729481, -0.8685904706499283}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}, {
       3.04376853729481, -0.8685904706499283}, {
       3.04376853729481, -0.8685904706499283}}, {{
       3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}, {{
       3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}, {{
       3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}, {{
       3.090943111168985, -0.9123196712727798}, {
       3.116190176920035, -0.9940284300482617}, {
       3.116190176920035, -0.9940284300482617}, {
       3.090943111168985, -0.9123196712727798}, {
       3.090943111168985, -0.9123196712727798}}, {{
       2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705926}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}, {{
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}, {{
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}, {{
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}, {{
       2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}, {{
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}, {{
       2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}, {{
       2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}, {{
       2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}, {{
       2.922704830689819, -0.5967037278059634}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}}, {{
       2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}, {{
       2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}, {{
       2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}, {{
       2.859799147163116, -0.5288417780705925}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.5288417780705925}, {
       2.859799147163116, -0.5288417780705925}}, {{
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}, {{
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}, {{
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}, {{
       2.8443446007949205`, -0.4609798283352218}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}, {
       2.8443446007949205`, -0.4609798283352218}, {
       2.8443446007949205`, -0.4609798283352218}}, {{
       2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}, {{
       2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}, {{
       2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}, {{
       2.859799147163116, -0.393117878599851}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}, {
       2.859799147163116, -0.393117878599851}, {
       2.859799147163116, -0.393117878599851}}, {{
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}, {{
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}, {{
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}, {{
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}}, {{
       3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}, {{
       3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}, {{
       3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}, {{
       3.1304681897166917`, -0.549388723179456}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.1304681897166917`, -0.549388723179456}, {
       3.1304681897166917`, -0.549388723179456}}, {{
       3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}, {{
       3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}, {{
       3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}, {{
       3.0794252904796156`, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}, {
       3.0794252904796156`, -0.5967037278059634}, {
       3.0794252904796156`, -0.5967037278059634}}, {{
       3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}, {{
       3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}, {{
       3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}, {{
       3.012927844874344, -0.6172506729148268}, {
       2.922704830689819, -0.5967037278059634}, {
       2.922704830689819, -0.5967037278059634}, {
       3.012927844874344, -0.6172506729148268}, {
       3.012927844874344, -0.6172506729148268}}, {{
       2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}, {{
       2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}, {{
       2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}, {{
       2.922704830689819, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}, {
       2.922704830689819, -0.3252559288644802}, {
       2.922704830689819, -0.3252559288644802}}, {{
       3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}, {{
       3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}, {{
       3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}, {{
       3.012927844874344, -0.3047089837556167}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.012927844874344, -0.3047089837556167}, {
       3.012927844874344, -0.3047089837556167}}, {{
       3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}, {{
       3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}, {{
       3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}, {{
       3.0794252904796156`, -0.3252559288644802}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.0794252904796156`, -0.3252559288644802}, {
       3.0794252904796156`, -0.3252559288644802}}, {{
       3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}, {{
       3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}, {{
       3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}, {{
       3.1304681897166917`, -0.3725709334909875}, {
       3.157785520374514, -0.4609798283352218}, {
       3.157785520374514, -0.4609798283352218}, {
       3.1304681897166917`, -0.3725709334909875}, {
       3.1304681897166917`, -0.3725709334909875}}, {{
       2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {2.8961820431828613`, 
       0.024849648472386653`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}, {{
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}, {{
       3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}, {{
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}, {{2.9611761774634457`, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.123099711825315, 0.09496459558635739}, {3.1758372207608407`, 
       0.04607874629936418}, {3.20406147900625, -0.04526529864158409}, {
       3.20406147900625, -0.04526529864158409}, {3.1758372207608407`, 
       0.04607874629936418}, {3.123099711825315, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {2.9611761774634457`, 
       0.09496459558635739}, {2.9611761774634457`, 0.09496459558635739}}, {{
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}, {{2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}, {{
       2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}, {{
       2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}, {{
       2.9611761774634457`, -0.1854951928695256}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}}, {{
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}, {{
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}, {{
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}, {{
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8961820431828613`, -0.11538024575555486`}, {
       2.8961820431828613`, -0.11538024575555486`}}, {{
       2.8802144102825107`, -0.04526529864158411}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8961820431828613`, 0.02484964847238664}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}, {{
       2.8802144102825107`, -0.04526529864158411}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8961820431828613`, 0.02484964847238664}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}, {{
       2.8802144102825107`, -0.04526529864158411}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8961820431828613`, 0.02484964847238664}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}, {{
       2.8802144102825107`, -0.04526529864158411}, {2.8961820431828613`, 
       0.02484964847238664}, {2.8961820431828613`, 0.02484964847238664}, {
       2.8802144102825107`, -0.04526529864158411}, {
       2.8802144102825107`, -0.04526529864158411}}, {{2.8961820431828613`, 
       0.024849648472386653`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}, {2.8961820431828613`, 
       0.024849648472386653`}, {2.8961820431828613`, 
       0.024849648472386653`}}, {{2.8961820431828613`, 
       0.024849648472386653`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}, {2.8961820431828613`, 
       0.024849648472386653`}, {2.8961820431828613`, 
       0.024849648472386653`}}, {{2.8961820431828613`, 
       0.024849648472386653`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}, {2.8961820431828613`, 
       0.024849648472386653`}, {2.8961820431828613`, 
       0.024849648472386653`}}, {{2.8961820431828613`, 
       0.024849648472386653`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}, {2.8961820431828613`, 
       0.024849648472386653`}, {2.8961820431828613`, 
       0.024849648472386653`}}, {{3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}, {{
       3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}, {{
       3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}, {{
       3.20406147900625, -0.04526529864158413}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.20406147900625, -0.04526529864158413}, {
       3.20406147900625, -0.04526529864158413}}, {{
       3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}, {{
       3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}, {{
       3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}, {{
       3.1758372207608407`, -0.1366093435825324}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}, {
       3.1758372207608407`, -0.1366093435825324}, {
       3.1758372207608407`, -0.1366093435825324}}, {{
       3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}, {{
       3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}, {{
       3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}, {{
       3.123099711825315, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.123099711825315, -0.1854951928695256}, {
       3.123099711825315, -0.1854951928695256}}, {{
       3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}, {{
       3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}, {{
       3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}, {{
       3.0543945699894386`, -0.20672429069650317`}, {
       2.9611761774634457`, -0.1854951928695256}, {
       2.9611761774634457`, -0.1854951928695256}, {
       3.0543945699894386`, -0.20672429069650317`}, {
       3.0543945699894386`, -0.20672429069650317`}}, {{2.9611761774634457`, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}, {2.9611761774634457`, 
       0.09496459558635739}, {2.9611761774634457`, 0.09496459558635739}}, {{
       2.9611761774634457`, 0.09496459558635739}, {3.0543945699894386`, 
       0.11619369341333496`}, {3.0543945699894386`, 0.11619369341333496`}, {
       2.9611761774634457`, 0.09496459558635739}, {2.9611761774634457`, 
       0.09496459558635739}}, {{2.9611761774634457`, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}, {2.9611761774634457`, 0.09496459558635739}, {
       2.9611761774634457`, 0.09496459558635739}}, {{2.9611761774634457`, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}, {2.9611761774634457`, 
       0.09496459558635739}, {2.9611761774634457`, 0.09496459558635739}}, {{
       3.0543945699894386`, 0.11619369341333496`}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}}, {{3.0543945699894386`, 0.11619369341333496`}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}, {3.0543945699894386`, 0.11619369341333496`}, {
       3.0543945699894386`, 0.11619369341333496`}}, {{3.0543945699894386`, 
       0.11619369341333496`}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}, {3.0543945699894386`, 
       0.11619369341333496`}, {3.0543945699894386`, 0.11619369341333496`}}, {{
       3.0543945699894386`, 0.11619369341333496`}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}, {
       3.0543945699894386`, 0.11619369341333496`}, {3.0543945699894386`, 
       0.11619369341333496`}}, {{3.123099711825315, 0.09496459558635739}, {
       3.1758372207608407`, 0.04607874629936418}, {3.1758372207608407`, 
       0.04607874629936418}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}}, {{3.123099711825315, 
       0.09496459558635739}, {3.1758372207608407`, 0.04607874629936418}, {
       3.1758372207608407`, 0.04607874629936418}, {3.123099711825315, 
       0.09496459558635739}, {3.123099711825315, 0.09496459558635739}}, {{
       3.123099711825315, 0.09496459558635739}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}, {
       3.123099711825315, 0.09496459558635739}, {3.123099711825315, 
       0.09496459558635739}}, {{3.123099711825315, 0.09496459558635739}, {
       3.1758372207608407`, 0.04607874629936418}, {3.1758372207608407`, 
       0.04607874629936418}, {3.123099711825315, 0.09496459558635739}, {
       3.123099711825315, 0.09496459558635739}}, {{3.1758372207608407`, 
       0.04607874629936418}, {3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}, {{
       3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}, {{
       3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}, {{
       3.1758372207608407`, 0.04607874629936418}, {
       3.20406147900625, -0.045265298641584135`}, {
       3.20406147900625, -0.045265298641584135`}, {3.1758372207608407`, 
       0.04607874629936418}, {3.1758372207608407`, 0.04607874629936418}}, {{
       2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}, {{2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}, {{3.1852190369763265`, 
       0.5384768329852746}, {3.159046411956666, 0.45377262516406985`}, {
       3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {2.959989170356145, 0.4084403088625691}, {
       2.959989170356145, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.1101424147695993`, 0.4084403088625691}, {
       3.159046411956666, 0.45377262516406985`}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}}, {{
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}, {{2.959989170356145, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.159046411956666, 0.6231810408064793}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}, {3.159046411956666, 0.6231810408064793}, {
       3.1101424147695993`, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {2.959989170356145, 0.6685133571079801}, {
       2.959989170356145, 0.6685133571079801}}, {{3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}}, {{
       2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}, {{2.959989170356145, 0.4084403088625691}, {
       2.8997194870853753`, 0.47345857092392185`}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.959989170356145, 0.4084403088625691}, {
       2.959989170356145, 0.4084403088625691}}, {{2.959989170356145, 
       0.4084403088625691}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}}, {{
       2.959989170356145, 0.4084403088625691}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}}, {{2.8997194870853753`, 0.47345857092392185`}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}}, {{2.8997194870853753`, 
       0.47345857092392185`}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8997194870853753`, 
       0.47345857092392185`}, {2.8997194870853753`, 0.47345857092392185`}}, {{
       2.8997194870853753`, 0.47345857092392185`}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.47345857092392185`}, {2.8997194870853753`, 
       0.47345857092392185`}}, {{2.8997194870853753`, 0.47345857092392185`}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.47345857092392185`}, {
       2.8997194870853753`, 0.47345857092392185`}}, {{2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.6034950950466274}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}}, {{
       2.8849125481494178`, 0.5384768329852746}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8997194870853753`, 0.6034950950466274}, {
       2.8849125481494178`, 0.5384768329852746}, {2.8849125481494178`, 
       0.5384768329852746}}, {{2.8849125481494178`, 0.5384768329852746}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8849125481494178`, 0.5384768329852746}, {
       2.8849125481494178`, 0.5384768329852746}}, {{2.8849125481494178`, 
       0.5384768329852746}, {2.8997194870853753`, 0.6034950950466274}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8849125481494178`, 
       0.5384768329852746}, {2.8849125481494178`, 0.5384768329852746}}, {{
       2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}}, {{2.8997194870853753`, 0.6034950950466274}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}, {2.8997194870853753`, 0.6034950950466274}, {
       2.8997194870853753`, 0.6034950950466274}}, {{2.8997194870853753`, 
       0.6034950950466274}, {2.959989170356145, 0.6685133571079801}, {
       2.959989170356145, 0.6685133571079801}, {2.8997194870853753`, 
       0.6034950950466274}, {2.8997194870853753`, 0.6034950950466274}}, {{
       2.8997194870853753`, 0.6034950950466274}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}, {
       2.8997194870853753`, 0.6034950950466274}, {2.8997194870853753`, 
       0.6034950950466274}}, {{3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.45377262516406985`}, {3.159046411956666, 
       0.45377262516406985`}, {3.1852190369763265`, 0.5384768329852746}, {
       3.1852190369763265`, 0.5384768329852746}}, {{3.1852190369763265`, 
       0.5384768329852746}, {3.159046411956666, 0.45377262516406985`}, {
       3.159046411956666, 0.45377262516406985`}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}}, {{
       3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}}, {{3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.45377262516406985`}, {3.159046411956666, 
       0.45377262516406985`}, {3.1852190369763265`, 0.5384768329852746}, {
       3.1852190369763265`, 0.5384768329852746}}, {{3.159046411956666, 
       0.45377262516406985`}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}}, {{
       3.159046411956666, 0.45377262516406985`}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}, {
       3.159046411956666, 0.45377262516406985`}, {3.159046411956666, 
       0.45377262516406985`}}, {{3.159046411956666, 0.45377262516406985`}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}, {3.159046411956666, 0.45377262516406985`}, {
       3.159046411956666, 0.45377262516406985`}}, {{3.159046411956666, 
       0.45377262516406985`}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}, {3.159046411956666, 
       0.45377262516406985`}, {3.159046411956666, 0.45377262516406985`}}, {{
       3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}, {{3.1101424147695993`, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.046431478646575, 
       0.3887543631027171}, {3.1101424147695993`, 0.4084403088625691}, {
       3.1101424147695993`, 0.4084403088625691}}, {{3.1101424147695993`, 
       0.4084403088625691}, {3.046431478646575, 0.3887543631027171}, {
       3.046431478646575, 0.3887543631027171}, {3.1101424147695993`, 
       0.4084403088625691}, {3.1101424147695993`, 0.4084403088625691}}, {{
       3.1101424147695993`, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}, {
       3.1101424147695993`, 0.4084403088625691}, {3.1101424147695993`, 
       0.4084403088625691}}, {{3.046431478646575, 0.3887543631027171}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}, {3.046431478646575, 0.3887543631027171}, {
       3.046431478646575, 0.3887543631027171}}, {{3.046431478646575, 
       0.3887543631027171}, {2.959989170356145, 0.4084403088625691}, {
       2.959989170356145, 0.4084403088625691}, {3.046431478646575, 
       0.3887543631027171}, {3.046431478646575, 0.3887543631027171}}, {{
       3.046431478646575, 0.3887543631027171}, {2.959989170356145, 
       0.4084403088625691}, {2.959989170356145, 0.4084403088625691}, {
       3.046431478646575, 0.3887543631027171}, {3.046431478646575, 
       0.3887543631027171}}, {{3.046431478646575, 0.3887543631027171}, {
       2.959989170356145, 0.4084403088625691}, {2.959989170356145, 
       0.4084403088625691}, {3.046431478646575, 0.3887543631027171}, {
       3.046431478646575, 0.3887543631027171}}, {{2.959989170356145, 
       0.6685133571079801}, {3.046431478646575, 0.6881993028678322}, {
       3.046431478646575, 0.6881993028678322}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}}, {{
       2.959989170356145, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.046431478646575, 0.6881993028678322}, {
       2.959989170356145, 0.6685133571079801}, {2.959989170356145, 
       0.6685133571079801}}, {{2.959989170356145, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}, {2.959989170356145, 0.6685133571079801}, {
       2.959989170356145, 0.6685133571079801}}, {{2.959989170356145, 
       0.6685133571079801}, {3.046431478646575, 0.6881993028678322}, {
       3.046431478646575, 0.6881993028678322}, {2.959989170356145, 
       0.6685133571079801}, {2.959989170356145, 0.6685133571079801}}, {{
       3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}}, {{3.046431478646575, 0.6881993028678322}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}, {3.046431478646575, 0.6881993028678322}, {
       3.046431478646575, 0.6881993028678322}}, {{3.046431478646575, 
       0.6881993028678322}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}, {3.046431478646575, 
       0.6881993028678322}, {3.046431478646575, 0.6881993028678322}}, {{
       3.046431478646575, 0.6881993028678322}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}, {
       3.046431478646575, 0.6881993028678322}, {3.046431478646575, 
       0.6881993028678322}}, {{3.1101424147695993`, 0.6685133571079801}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}}, {{3.1101424147695993`, 
       0.6685133571079801}, {3.159046411956666, 0.6231810408064793}, {
       3.159046411956666, 0.6231810408064793}, {3.1101424147695993`, 
       0.6685133571079801}, {3.1101424147695993`, 0.6685133571079801}}, {{
       3.1101424147695993`, 0.6685133571079801}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}, {
       3.1101424147695993`, 0.6685133571079801}, {3.1101424147695993`, 
       0.6685133571079801}}, {{3.1101424147695993`, 0.6685133571079801}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}, {3.1101424147695993`, 0.6685133571079801}, {
       3.1101424147695993`, 0.6685133571079801}}, {{3.159046411956666, 
       0.6231810408064793}, {3.1852190369763265`, 0.5384768329852746}, {
       3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}}, {{
       3.159046411956666, 0.6231810408064793}, {3.1852190369763265`, 
       0.5384768329852746}, {3.1852190369763265`, 0.5384768329852746}, {
       3.159046411956666, 0.6231810408064793}, {3.159046411956666, 
       0.6231810408064793}}, {{3.159046411956666, 0.6231810408064793}, {
       3.1852190369763265`, 0.5384768329852746}, {3.1852190369763265`, 
       0.5384768329852746}, {3.159046411956666, 0.6231810408064793}, {
       3.159046411956666, 0.6231810408064793}}, {{3.159046411956666, 
       0.6231810408064793}, {3.1852190369763265`, 0.5384768329852746}, {
       3.1852190369763265`, 0.5384768329852746}, {3.159046411956666, 
       0.6231810408064793}, {3.159046411956666, 0.6231810408064793}}, {{
       2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.8470178172435943`, 
       0.9900294163368778}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}, {{2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}}, {{3.197758205948302, 
       0.9900294163368778}, {3.167190112968768, 0.8910998630921676}, {
       3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {2.934702914419771, 0.838154372961125}, {
       2.934702914419771, 0.838154372961125}, {3.0356624672045025`, 
       0.8151623414042912}, {3.110073108772125, 0.8381543729611252}, {
       3.167190112968768, 0.8910998630921676}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}}, {{
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}, {{2.934702914419771, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125, 
       1.1419044597126304`}, {3.167190112968768, 1.088958969581588}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}, {3.167190112968768, 1.088958969581588}, {
       3.110073108772125, 1.1419044597126304`}, {3.0356624672045025`, 
       1.1648964912694644`}, {2.934702914419771, 1.1419044597126304`}, {
       2.934702914419771, 1.1419044597126304`}}, {{3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}}, {{
       2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}, {{2.934702914419771, 0.8381543729611252}, {
       2.864311454614574, 0.9140918946490014}, {2.864311454614574, 
       0.9140918946490014}, {2.934702914419771, 0.8381543729611252}, {
       2.934702914419771, 0.8381543729611252}}, {{2.934702914419771, 
       0.8381543729611252}, {2.864311454614574, 0.9140918946490014}, {
       2.864311454614574, 0.9140918946490014}, {2.934702914419771, 
       0.8381543729611252}, {2.934702914419771, 0.8381543729611252}}, {{
       2.934702914419771, 0.8381543729611252}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}}, {{2.864311454614574, 0.9140918946490014}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.864311454614574, 0.9140918946490014}, {
       2.864311454614574, 0.9140918946490014}}, {{2.864311454614574, 
       0.9140918946490014}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}, {2.864311454614574, 
       0.9140918946490014}, {2.864311454614574, 0.9140918946490014}}, {{
       2.864311454614574, 0.9140918946490014}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 0.9140918946490014}, {2.864311454614574, 
       0.9140918946490014}}, {{2.864311454614574, 0.9140918946490014}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}, {2.864311454614574, 0.9140918946490014}, {
       2.864311454614574, 0.9140918946490014}}, {{2.8470178172435943`, 
       0.9900294163368778}, {2.864311454614574, 1.065966938024754}, {
       2.864311454614574, 1.065966938024754}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}}, {{
       2.8470178172435943`, 0.9900294163368778}, {2.864311454614574, 
       1.065966938024754}, {2.864311454614574, 1.065966938024754}, {
       2.8470178172435943`, 0.9900294163368778}, {2.8470178172435943`, 
       0.9900294163368778}}, {{2.8470178172435943`, 0.9900294163368778}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}, {2.8470178172435943`, 0.9900294163368778}, {
       2.8470178172435943`, 0.9900294163368778}}, {{2.8470178172435943`, 
       0.9900294163368778}, {2.864311454614574, 1.065966938024754}, {
       2.864311454614574, 1.065966938024754}, {2.8470178172435943`, 
       0.9900294163368778}, {2.8470178172435943`, 0.9900294163368778}}, {{
       2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}}, {{2.864311454614574, 1.065966938024754}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}, {2.864311454614574, 1.065966938024754}, {
       2.864311454614574, 1.065966938024754}}, {{2.864311454614574, 
       1.065966938024754}, {2.934702914419771, 1.1419044597126304`}, {
       2.934702914419771, 1.1419044597126304`}, {2.864311454614574, 
       1.065966938024754}, {2.864311454614574, 1.065966938024754}}, {{
       2.864311454614574, 1.065966938024754}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}, {
       2.864311454614574, 1.065966938024754}, {2.864311454614574, 
       1.065966938024754}}, {{3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}, {3.197758205948302, 0.9900294163368778}, {
       3.197758205948302, 0.9900294163368778}}, {{3.197758205948302, 
       0.9900294163368778}, {3.167190112968768, 0.8910998630921676}, {
       3.167190112968768, 0.8910998630921676}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}}, {{
       3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}}, {{3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}, {3.197758205948302, 0.9900294163368778}, {
       3.197758205948302, 0.9900294163368778}}, {{3.167190112968768, 
       0.8910998630921676}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}}, {{
       3.167190112968768, 0.8910998630921676}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}, {
       3.167190112968768, 0.8910998630921676}, {3.167190112968768, 
       0.8910998630921676}}, {{3.167190112968768, 0.8910998630921676}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}, {3.167190112968768, 0.8910998630921676}, {
       3.167190112968768, 0.8910998630921676}}, {{3.167190112968768, 
       0.8910998630921676}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}, {3.167190112968768, 
       0.8910998630921676}, {3.167190112968768, 0.8910998630921676}}, {{
       3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}, {{3.110073108772125, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {3.0356624672045025`, 
       0.8151623414042912}, {3.110073108772125, 0.8381543729611252}, {
       3.110073108772125, 0.8381543729611252}}, {{3.110073108772125, 
       0.8381543729611252}, {3.0356624672045025`, 0.8151623414042912}, {
       3.0356624672045025`, 0.8151623414042912}, {3.110073108772125, 
       0.8381543729611252}, {3.110073108772125, 0.8381543729611252}}, {{
       3.110073108772125, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}, {
       3.110073108772125, 0.8381543729611252}, {3.110073108772125, 
       0.8381543729611252}}, {{3.0356624672045025`, 0.8151623414042912}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}, {3.0356624672045025`, 0.8151623414042912}, {
       3.0356624672045025`, 0.8151623414042912}}, {{3.0356624672045025`, 
       0.8151623414042912}, {2.934702914419771, 0.8381543729611252}, {
       2.934702914419771, 0.8381543729611252}, {3.0356624672045025`, 
       0.8151623414042912}, {3.0356624672045025`, 0.8151623414042912}}, {{
       3.0356624672045025`, 0.8151623414042912}, {2.934702914419771, 
       0.8381543729611252}, {2.934702914419771, 0.8381543729611252}, {
       3.0356624672045025`, 0.8151623414042912}, {3.0356624672045025`, 
       0.8151623414042912}}, {{3.0356624672045025`, 0.8151623414042912}, {
       2.934702914419771, 0.8381543729611252}, {2.934702914419771, 
       0.8381543729611252}, {3.0356624672045025`, 0.8151623414042912}, {
       3.0356624672045025`, 0.8151623414042912}}, {{2.934702914419771, 
       1.1419044597126304`}, {3.0356624672045025`, 1.1648964912694644`}, {
       3.0356624672045025`, 1.1648964912694644`}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}}, {{
       2.934702914419771, 1.1419044597126304`}, {3.0356624672045025`, 
       1.1648964912694644`}, {3.0356624672045025`, 1.1648964912694644`}, {
       2.934702914419771, 1.1419044597126304`}, {2.934702914419771, 
       1.1419044597126304`}}, {{2.934702914419771, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}, {2.934702914419771, 1.1419044597126304`}, {
       2.934702914419771, 1.1419044597126304`}}, {{2.934702914419771, 
       1.1419044597126304`}, {3.0356624672045025`, 1.1648964912694644`}, {
       3.0356624672045025`, 1.1648964912694644`}, {2.934702914419771, 
       1.1419044597126304`}, {2.934702914419771, 1.1419044597126304`}}, {{
       3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}}, {{3.0356624672045025`, 1.1648964912694644`}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}, {3.0356624672045025`, 1.1648964912694644`}, {
       3.0356624672045025`, 1.1648964912694644`}}, {{3.0356624672045025`, 
       1.1648964912694644`}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}, {3.0356624672045025`, 
       1.1648964912694644`}, {3.0356624672045025`, 1.1648964912694644`}}, {{
       3.0356624672045025`, 1.1648964912694644`}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}, {
       3.0356624672045025`, 1.1648964912694644`}, {3.0356624672045025`, 
       1.1648964912694644`}}, {{3.110073108772125, 1.1419044597126304`}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}}, {{3.110073108772125, 
       1.1419044597126304`}, {3.167190112968768, 1.088958969581588}, {
       3.167190112968768, 1.088958969581588}, {3.110073108772125, 
       1.1419044597126304`}, {3.110073108772125, 1.1419044597126304`}}, {{
       3.110073108772125, 1.1419044597126304`}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}, {
       3.110073108772125, 1.1419044597126304`}, {3.110073108772125, 
       1.1419044597126304`}}, {{3.110073108772125, 1.1419044597126304`}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}, {3.110073108772125, 1.1419044597126304`}, {
       3.110073108772125, 1.1419044597126304`}}, {{3.167190112968768, 
       1.088958969581588}, {3.197758205948302, 0.9900294163368778}, {
       3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}}, {{
       3.167190112968768, 1.088958969581588}, {3.197758205948302, 
       0.9900294163368778}, {3.197758205948302, 0.9900294163368778}, {
       3.167190112968768, 1.088958969581588}, {3.167190112968768, 
       1.088958969581588}}, {{3.167190112968768, 1.088958969581588}, {
       3.197758205948302, 0.9900294163368778}, {3.197758205948302, 
       0.9900294163368778}, {3.167190112968768, 1.088958969581588}, {
       3.167190112968768, 1.088958969581588}}, {{3.167190112968768, 
       1.088958969581588}, {3.197758205948302, 0.9900294163368778}, {
       3.197758205948302, 0.9900294163368778}, {3.167190112968768, 
       1.088958969581588}, {3.167190112968768, 1.088958969581588}}, {{
       2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069, 
       1.4299048668781584`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}, {{2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}}, {{3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0008277109434465`, 
       1.3326724727056334`}, {2.9016001423364717`, 1.3552700707118768`}, {
       2.9016001423364717`, 1.3552700707118768`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1601426602815654`, 1.5045396630444403`}}, {{
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}}, {{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}, {{3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}}, {{
       2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069, 
       1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}, {{2.9016001423364717`, 1.3552700707118768`}, {
       2.832416264095069, 1.4299048668781584`}, {2.832416264095069, 
       1.4299048668781584`}, {2.9016001423364717`, 1.3552700707118768`}, {
       2.9016001423364717`, 1.3552700707118768`}}, {{2.9016001423364717`, 
       1.3552700707118768`}, {2.832416264095069, 1.4299048668781584`}, {
       2.832416264095069, 1.4299048668781584`}, {2.9016001423364717`, 
       1.3552700707118768`}, {2.9016001423364717`, 1.3552700707118768`}}, {{
       2.9016001423364717`, 1.3552700707118768`}, {2.832416264095069, 
       1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}}, {{2.832416264095069, 1.4299048668781584`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.832416264095069, 1.4299048668781584`}, {
       2.832416264095069, 1.4299048668781584`}}, {{2.832416264095069, 
       1.4299048668781584`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.832416264095069, 
       1.4299048668781584`}, {2.832416264095069, 1.4299048668781584`}}, {{
       2.832416264095069, 1.4299048668781584`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.4299048668781584`}, {2.832416264095069, 
       1.4299048668781584`}}, {{2.832416264095069, 1.4299048668781584`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.832416264095069, 1.4299048668781584`}, {
       2.832416264095069, 1.4299048668781584`}}, {{2.8154193030214407`, 
       1.5045396630444403`}, {2.832416264095069, 1.5791744592107222`}, {
       2.832416264095069, 1.5791744592107222`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}}, {{
       2.8154193030214407`, 1.5045396630444403`}, {2.832416264095069, 
       1.5791744592107222`}, {2.832416264095069, 1.5791744592107222`}, {
       2.8154193030214407`, 1.5045396630444403`}, {2.8154193030214407`, 
       1.5045396630444403`}}, {{2.8154193030214407`, 1.5045396630444403`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}, {2.8154193030214407`, 1.5045396630444403`}, {
       2.8154193030214407`, 1.5045396630444403`}}, {{2.8154193030214407`, 
       1.5045396630444403`}, {2.832416264095069, 1.5791744592107222`}, {
       2.832416264095069, 1.5791744592107222`}, {2.8154193030214407`, 
       1.5045396630444403`}, {2.8154193030214407`, 1.5045396630444403`}}, {{
       2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}}, {{2.832416264095069, 1.5791744592107222`}, {
       2.9016001423364717`, 1.6538092553770039`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.832416264095069, 1.5791744592107222`}, {
       2.832416264095069, 1.5791744592107222`}}, {{2.832416264095069, 
       1.5791744592107222`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}, {2.832416264095069, 
       1.5791744592107222`}, {2.832416264095069, 1.5791744592107222`}}, {{
       2.832416264095069, 1.5791744592107222`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.832416264095069, 1.5791744592107222`}, {2.832416264095069, 
       1.5791744592107222`}}, {{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}, {{3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1601426602815654`, 1.5045396630444403`}}, {{
       3.1601426602815654`, 1.5045396630444403`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}}, {{3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}}, {{3.1300989699159936`, 
       1.4073072688719153`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1300989699159936`, 1.4073072688719153`}}, {{
       3.1300989699159936`, 1.4073072688719153`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.1300989699159936`, 1.4073072688719153`}, {3.1300989699159936`, 
       1.4073072688719153`}}, {{3.1300989699159936`, 1.4073072688719153`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.1300989699159936`, 1.4073072688719153`}, {
       3.1300989699159936`, 1.4073072688719153`}}, {{3.1300989699159936`, 
       1.4073072688719153`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.1300989699159936`, 
       1.4073072688719153`}, {3.1300989699159936`, 1.4073072688719153`}}, {{
       3.0739618209665345`, 1.3552700707118768`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}}, {{3.0739618209665345`, 1.3552700707118768`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0739618209665345`, 1.3552700707118768`}, {
       3.0739618209665345`, 1.3552700707118768`}}, {{3.0739618209665345`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0739618209665345`, 
       1.3552700707118768`}, {3.0739618209665345`, 1.3552700707118768`}}, {{
       3.0739618209665345`, 1.3552700707118768`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0739618209665345`, 1.3552700707118768`}, {3.0739618209665345`, 
       1.3552700707118768`}}, {{3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}}, {{3.0008277109434465`, 
       1.3326724727056334`}, {2.9016001423364717`, 1.3552700707118768`}, {
       2.9016001423364717`, 1.3552700707118768`}, {3.0008277109434465`, 
       1.3326724727056334`}, {3.0008277109434465`, 1.3326724727056334`}}, {{
       3.0008277109434465`, 1.3326724727056334`}, {2.9016001423364717`, 
       1.3552700707118768`}, {2.9016001423364717`, 1.3552700707118768`}, {
       3.0008277109434465`, 1.3326724727056334`}, {3.0008277109434465`, 
       1.3326724727056334`}}, {{3.0008277109434465`, 1.3326724727056334`}, {
       2.9016001423364717`, 1.3552700707118768`}, {2.9016001423364717`, 
       1.3552700707118768`}, {3.0008277109434465`, 1.3326724727056334`}, {
       3.0008277109434465`, 1.3326724727056334`}}, {{2.9016001423364717`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}}, {{
       2.9016001423364717`, 1.6538092553770039`}, {3.0008277109434465`, 
       1.6764068533832472`}, {3.0008277109434465`, 1.6764068533832472`}, {
       2.9016001423364717`, 1.6538092553770039`}, {2.9016001423364717`, 
       1.6538092553770039`}}, {{2.9016001423364717`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}, {2.9016001423364717`, 1.6538092553770039`}, {
       2.9016001423364717`, 1.6538092553770039`}}, {{2.9016001423364717`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}, {2.9016001423364717`, 
       1.6538092553770039`}, {2.9016001423364717`, 1.6538092553770039`}}, {{
       3.0008277109434465`, 1.6764068533832472`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}}, {{3.0008277109434465`, 1.6764068533832472`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0008277109434465`, 1.6764068533832472`}, {
       3.0008277109434465`, 1.6764068533832472`}}, {{3.0008277109434465`, 
       1.6764068533832472`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0008277109434465`, 
       1.6764068533832472`}, {3.0008277109434465`, 1.6764068533832472`}}, {{
       3.0008277109434465`, 1.6764068533832472`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0008277109434465`, 1.6764068533832472`}, {3.0008277109434465`, 
       1.6764068533832472`}}, {{3.0739618209665345`, 1.6538092553770039`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}, {{3.0739618209665345`, 
       1.6538092553770039`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.0739618209665345`, 
       1.6538092553770039`}, {3.0739618209665345`, 1.6538092553770039`}}, {{
       3.0739618209665345`, 1.6538092553770039`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.0739618209665345`, 1.6538092553770039`}, {3.0739618209665345`, 
       1.6538092553770039`}}, {{3.0739618209665345`, 1.6538092553770039`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.0739618209665345`, 1.6538092553770039`}, {
       3.0739618209665345`, 1.6538092553770039`}}, {{3.1300989699159936`, 
       1.6017720572169654`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.1300989699159936`, 1.6017720572169654`}}, {{
       3.1300989699159936`, 1.6017720572169654`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1300989699159936`, 1.6017720572169654`}, {3.1300989699159936`, 
       1.6017720572169654`}}, {{3.1300989699159936`, 1.6017720572169654`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1601426602815654`, 
       1.5045396630444403`}, {3.1300989699159936`, 1.6017720572169654`}, {
       3.1300989699159936`, 1.6017720572169654`}}, {{3.1300989699159936`, 
       1.6017720572169654`}, {3.1601426602815654`, 1.5045396630444403`}, {
       3.1601426602815654`, 1.5045396630444403`}, {3.1300989699159936`, 
       1.6017720572169654`}, {3.1300989699159936`, 1.6017720572169654`}}, {{
       2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`, 
       1.9236442374196498`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}, {{2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}, {{3.153947883695866, 
       1.9908477683802908`}, {3.126895594691735, 1.9032966454751998`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877, 
       1.836093114514559}, {2.921148023552149, 1.8564407064590087`}, {
       2.921148023552149, 1.8564407064590087`}, {3.010495664619877, 
       1.836093114514559}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.126895594691735, 1.9032966454751998`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}}, {{
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}, {{2.921148023552149, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.126895594691735, 2.0783988912853815`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}, {3.126895594691735, 2.0783988912853815`}, {
       3.0763479303146273`, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {2.921148023552149, 2.125254830301573}, {
       2.921148023552149, 2.125254830301573}}, {{3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}}, {{
       2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`, 
       1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}, {{2.921148023552149, 1.8564407064590087`}, {
       2.8588526714885525`, 1.9236442374196498`}, {2.8588526714885525`, 
       1.9236442374196498`}, {2.921148023552149, 1.8564407064590087`}, {
       2.921148023552149, 1.8564407064590087`}}, {{2.921148023552149, 
       1.8564407064590087`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}}, {{
       2.921148023552149, 1.8564407064590087`}, {2.8588526714885525`, 
       1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}}, {{2.8588526714885525`, 1.9236442374196498`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}}, {{2.8588526714885525`, 
       1.9236442374196498`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8588526714885525`, 
       1.9236442374196498`}, {2.8588526714885525`, 1.9236442374196498`}}, {{
       2.8588526714885525`, 1.9236442374196498`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 1.9236442374196498`}, {2.8588526714885525`, 
       1.9236442374196498`}}, {{2.8588526714885525`, 1.9236442374196498`}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 1.9236442374196498`}, {
       2.8588526714885525`, 1.9236442374196498`}}, {{2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 2.058051299340932}, {
       2.8588526714885525`, 2.058051299340932}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}}, {{
       2.8435480701709106`, 1.9908477683802908`}, {2.8588526714885525`, 
       2.058051299340932}, {2.8588526714885525`, 2.058051299340932}, {
       2.8435480701709106`, 1.9908477683802908`}, {2.8435480701709106`, 
       1.9908477683802908`}}, {{2.8435480701709106`, 1.9908477683802908`}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}, {2.8435480701709106`, 1.9908477683802908`}, {
       2.8435480701709106`, 1.9908477683802908`}}, {{2.8435480701709106`, 
       1.9908477683802908`}, {2.8588526714885525`, 2.058051299340932}, {
       2.8588526714885525`, 2.058051299340932}, {2.8435480701709106`, 
       1.9908477683802908`}, {2.8435480701709106`, 1.9908477683802908`}}, {{
       2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}}, {{2.8588526714885525`, 2.058051299340932}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}, {2.8588526714885525`, 2.058051299340932}, {
       2.8588526714885525`, 2.058051299340932}}, {{2.8588526714885525`, 
       2.058051299340932}, {2.921148023552149, 2.125254830301573}, {
       2.921148023552149, 2.125254830301573}, {2.8588526714885525`, 
       2.058051299340932}, {2.8588526714885525`, 2.058051299340932}}, {{
       2.8588526714885525`, 2.058051299340932}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}, {
       2.8588526714885525`, 2.058051299340932}, {2.8588526714885525`, 
       2.058051299340932}}, {{3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}, {3.153947883695866, 1.9908477683802908`}, {
       3.153947883695866, 1.9908477683802908`}}, {{3.153947883695866, 
       1.9908477683802908`}, {3.126895594691735, 1.9032966454751998`}, {
       3.126895594691735, 1.9032966454751998`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}}, {{
       3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}}, {{3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}, {3.153947883695866, 1.9908477683802908`}, {
       3.153947883695866, 1.9908477683802908`}}, {{3.126895594691735, 
       1.9032966454751998`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}}, {{
       3.126895594691735, 1.9032966454751998`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.126895594691735, 1.9032966454751998`}, {3.126895594691735, 
       1.9032966454751998`}}, {{3.126895594691735, 1.9032966454751998`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.126895594691735, 1.9032966454751998`}, {
       3.126895594691735, 1.9032966454751998`}}, {{3.126895594691735, 
       1.9032966454751998`}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.126895594691735, 
       1.9032966454751998`}, {3.126895594691735, 1.9032966454751998`}}, {{
       3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877, 
       1.836093114514559}, {3.010495664619877, 1.836093114514559}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}, {{3.0763479303146273`, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.010495664619877, 
       1.836093114514559}, {3.0763479303146273`, 1.8564407064590087`}, {
       3.0763479303146273`, 1.8564407064590087`}}, {{3.0763479303146273`, 
       1.8564407064590087`}, {3.010495664619877, 1.836093114514559}, {
       3.010495664619877, 1.836093114514559}, {3.0763479303146273`, 
       1.8564407064590087`}, {3.0763479303146273`, 1.8564407064590087`}}, {{
       3.0763479303146273`, 1.8564407064590087`}, {3.010495664619877, 
       1.836093114514559}, {3.010495664619877, 1.836093114514559}, {
       3.0763479303146273`, 1.8564407064590087`}, {3.0763479303146273`, 
       1.8564407064590087`}}, {{3.010495664619877, 1.836093114514559}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}, {3.010495664619877, 1.836093114514559}, {
       3.010495664619877, 1.836093114514559}}, {{3.010495664619877, 
       1.836093114514559}, {2.921148023552149, 1.8564407064590087`}, {
       2.921148023552149, 1.8564407064590087`}, {3.010495664619877, 
       1.836093114514559}, {3.010495664619877, 1.836093114514559}}, {{
       3.010495664619877, 1.836093114514559}, {2.921148023552149, 
       1.8564407064590087`}, {2.921148023552149, 1.8564407064590087`}, {
       3.010495664619877, 1.836093114514559}, {3.010495664619877, 
       1.836093114514559}}, {{3.010495664619877, 1.836093114514559}, {
       2.921148023552149, 1.8564407064590087`}, {2.921148023552149, 
       1.8564407064590087`}, {3.010495664619877, 1.836093114514559}, {
       3.010495664619877, 1.836093114514559}}, {{2.921148023552149, 
       2.125254830301573}, {3.010495664619877, 2.145602422246023}, {
       3.010495664619877, 2.145602422246023}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}}, {{
       2.921148023552149, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.010495664619877, 2.145602422246023}, {
       2.921148023552149, 2.125254830301573}, {2.921148023552149, 
       2.125254830301573}}, {{2.921148023552149, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}, {2.921148023552149, 2.125254830301573}, {
       2.921148023552149, 2.125254830301573}}, {{2.921148023552149, 
       2.125254830301573}, {3.010495664619877, 2.145602422246023}, {
       3.010495664619877, 2.145602422246023}, {2.921148023552149, 
       2.125254830301573}, {2.921148023552149, 2.125254830301573}}, {{
       3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}}, {{3.010495664619877, 2.145602422246023}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}, {3.010495664619877, 2.145602422246023}, {
       3.010495664619877, 2.145602422246023}}, {{3.010495664619877, 
       2.145602422246023}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}, {3.010495664619877, 
       2.145602422246023}, {3.010495664619877, 2.145602422246023}}, {{
       3.010495664619877, 2.145602422246023}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}, {
       3.010495664619877, 2.145602422246023}, {3.010495664619877, 
       2.145602422246023}}, {{3.0763479303146273`, 2.125254830301573}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}}, {{3.0763479303146273`, 
       2.125254830301573}, {3.126895594691735, 2.0783988912853815`}, {
       3.126895594691735, 2.0783988912853815`}, {3.0763479303146273`, 
       2.125254830301573}, {3.0763479303146273`, 2.125254830301573}}, {{
       3.0763479303146273`, 2.125254830301573}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}, {
       3.0763479303146273`, 2.125254830301573}, {3.0763479303146273`, 
       2.125254830301573}}, {{3.0763479303146273`, 2.125254830301573}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}, {3.0763479303146273`, 2.125254830301573}, {
       3.0763479303146273`, 2.125254830301573}}, {{3.126895594691735, 
       2.0783988912853815`}, {3.153947883695866, 1.9908477683802908`}, {
       3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}}, {{
       3.126895594691735, 2.0783988912853815`}, {3.153947883695866, 
       1.9908477683802908`}, {3.153947883695866, 1.9908477683802908`}, {
       3.126895594691735, 2.0783988912853815`}, {3.126895594691735, 
       2.0783988912853815`}}, {{3.126895594691735, 2.0783988912853815`}, {
       3.153947883695866, 1.9908477683802908`}, {3.153947883695866, 
       1.9908477683802908`}, {3.126895594691735, 2.0783988912853815`}, {
       3.126895594691735, 2.0783988912853815`}}, {{3.126895594691735, 
       2.0783988912853815`}, {3.153947883695866, 1.9908477683802908`}, {
       3.153947883695866, 1.9908477683802908`}, {3.126895594691735, 
       2.0783988912853815`}, {3.126895594691735, 2.0783988912853815`}}, {{
       2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`, 
       2.662963044905966}, {2.9340305420043453`, 2.662963044905966}, {
       2.858671461130262, 2.5816665090180773`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}, {{2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}}, {{3.2156500032786854`, 
       2.5003699731301885`}, {3.182924678397142, 2.394458826743442}, {
       3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`, 
       2.313162290855553}, {2.9340305420043453`, 2.3377769013544105`}, {
       2.9340305420043453`, 2.3377769013544105`}, {3.0421149477599716`, 
       2.313162290855553}, {3.1217768495205718`, 2.337776901354411}, {
       3.182924678397142, 2.394458826743442}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}}, {{
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}, {{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`, 
       2.662963044905966}, {3.182924678397142, 2.606281119516935}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}, {{3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}}, {{
       2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}, {{2.9340305420043453`, 2.337776901354411}, {
       2.858671461130262, 2.4190734372422997`}, {2.858671461130262, 
       2.4190734372422997`}, {2.9340305420043453`, 2.337776901354411}, {
       2.9340305420043453`, 2.337776901354411}}, {{2.9340305420043453`, 
       2.337776901354411}, {2.858671461130262, 2.4190734372422997`}, {
       2.858671461130262, 2.4190734372422997`}, {2.9340305420043453`, 
       2.337776901354411}, {2.9340305420043453`, 2.337776901354411}}, {{
       2.9340305420043453`, 2.337776901354411}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}}, {{2.858671461130262, 2.4190734372422997`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.858671461130262, 2.4190734372422997`}, {
       2.858671461130262, 2.4190734372422997`}}, {{2.858671461130262, 
       2.4190734372422997`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.858671461130262, 
       2.4190734372422997`}, {2.858671461130262, 2.4190734372422997`}}, {{
       2.858671461130262, 2.4190734372422997`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.4190734372422997`}, {2.858671461130262, 
       2.4190734372422997`}}, {{2.858671461130262, 2.4190734372422997`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.858671461130262, 2.4190734372422997`}, {
       2.858671461130262, 2.4190734372422997`}}, {{2.8401573882462317`, 
       2.5003699731301885`}, {2.858671461130262, 2.5816665090180773`}, {
       2.858671461130262, 2.5816665090180773`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}}, {{
       2.8401573882462317`, 2.5003699731301885`}, {2.858671461130262, 
       2.5816665090180773`}, {2.858671461130262, 2.5816665090180773`}, {
       2.8401573882462317`, 2.5003699731301885`}, {2.8401573882462317`, 
       2.5003699731301885`}}, {{2.8401573882462317`, 2.5003699731301885`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}, {2.8401573882462317`, 2.5003699731301885`}, {
       2.8401573882462317`, 2.5003699731301885`}}, {{2.8401573882462317`, 
       2.5003699731301885`}, {2.858671461130262, 2.5816665090180773`}, {
       2.858671461130262, 2.5816665090180773`}, {2.8401573882462317`, 
       2.5003699731301885`}, {2.8401573882462317`, 2.5003699731301885`}}, {{
       2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`, 
       2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}}, {{2.858671461130262, 2.5816665090180773`}, {
       2.9340305420043453`, 2.6629630449059665`}, {2.9340305420043453`, 
       2.6629630449059665`}, {2.858671461130262, 2.5816665090180773`}, {
       2.858671461130262, 2.5816665090180773`}}, {{2.858671461130262, 
       2.5816665090180773`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}, {2.858671461130262, 
       2.5816665090180773`}, {2.858671461130262, 2.5816665090180773`}}, {{
       2.858671461130262, 2.5816665090180773`}, {2.9340305420043453`, 
       2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.858671461130262, 2.5816665090180773`}, {2.858671461130262, 
       2.5816665090180773`}}, {{3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.2156500032786854`, 2.5003699731301885`}}, {{3.2156500032786854`, 
       2.5003699731301885`}, {3.182924678397142, 2.394458826743442}, {
       3.182924678397142, 2.394458826743442}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}}, {{
       3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142, 
       2.394458826743442}, {3.182924678397142, 2.394458826743442}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}}, {{3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.2156500032786854`, 2.5003699731301885`}}, {{3.182924678397142, 
       2.394458826743442}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.182924678397142, 
       2.394458826743442}, {3.182924678397142, 2.394458826743442}}, {{
       3.182924678397142, 2.394458826743442}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}, {
       3.182924678397142, 2.394458826743442}, {3.182924678397142, 
       2.394458826743442}}, {{3.182924678397142, 2.394458826743442}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}, {3.182924678397142, 2.394458826743442}, {
       3.182924678397142, 2.394458826743442}}, {{3.182924678397142, 
       2.394458826743442}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}, {3.182924678397142, 
       2.394458826743442}, {3.182924678397142, 2.394458826743442}}, {{
       3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`, 
       2.313162290855553}, {3.0421149477599716`, 2.313162290855553}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}, {{3.1217768495205718`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {3.0421149477599716`, 
       2.313162290855553}, {3.1217768495205718`, 2.337776901354411}, {
       3.1217768495205718`, 2.337776901354411}}, {{3.1217768495205718`, 
       2.337776901354411}, {3.0421149477599716`, 2.313162290855553}, {
       3.0421149477599716`, 2.313162290855553}, {3.1217768495205718`, 
       2.337776901354411}, {3.1217768495205718`, 2.337776901354411}}, {{
       3.1217768495205718`, 2.337776901354411}, {3.0421149477599716`, 
       2.313162290855553}, {3.0421149477599716`, 2.313162290855553}, {
       3.1217768495205718`, 2.337776901354411}, {3.1217768495205718`, 
       2.337776901354411}}, {{3.0421149477599716`, 2.313162290855553}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}, {3.0421149477599716`, 2.313162290855553}, {
       3.0421149477599716`, 2.313162290855553}}, {{3.0421149477599716`, 
       2.313162290855553}, {2.9340305420043453`, 2.337776901354411}, {
       2.9340305420043453`, 2.337776901354411}, {3.0421149477599716`, 
       2.313162290855553}, {3.0421149477599716`, 2.313162290855553}}, {{
       3.0421149477599716`, 2.313162290855553}, {2.9340305420043453`, 
       2.337776901354411}, {2.9340305420043453`, 2.337776901354411}, {
       3.0421149477599716`, 2.313162290855553}, {3.0421149477599716`, 
       2.313162290855553}}, {{3.0421149477599716`, 2.313162290855553}, {
       2.9340305420043453`, 2.337776901354411}, {2.9340305420043453`, 
       2.337776901354411}, {3.0421149477599716`, 2.313162290855553}, {
       3.0421149477599716`, 2.313162290855553}}, {{2.9340305420043453`, 
       2.6629630449059665`}, {3.0421149477599716`, 2.687577655404824}, {
       3.0421149477599716`, 2.687577655404824}, {2.9340305420043453`, 
       2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}}, {{
       2.9340305420043453`, 2.6629630449059665`}, {3.0421149477599716`, 
       2.687577655404824}, {3.0421149477599716`, 2.687577655404824}, {
       2.9340305420043453`, 2.6629630449059665`}, {2.9340305420043453`, 
       2.6629630449059665`}}, {{2.9340305420043453`, 2.6629630449059665`}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}, {2.9340305420043453`, 2.6629630449059665`}, {
       2.9340305420043453`, 2.6629630449059665`}}, {{2.9340305420043453`, 
       2.6629630449059665`}, {3.0421149477599716`, 2.687577655404824}, {
       3.0421149477599716`, 2.687577655404824}, {2.9340305420043453`, 
       2.6629630449059665`}, {2.9340305420043453`, 2.6629630449059665`}}, {{
       3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}}, {{3.0421149477599716`, 2.687577655404824}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}, {3.0421149477599716`, 2.687577655404824}, {
       3.0421149477599716`, 2.687577655404824}}, {{3.0421149477599716`, 
       2.687577655404824}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}, {3.0421149477599716`, 
       2.687577655404824}, {3.0421149477599716`, 2.687577655404824}}, {{
       3.0421149477599716`, 2.687577655404824}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}, {
       3.0421149477599716`, 2.687577655404824}, {3.0421149477599716`, 
       2.687577655404824}}, {{3.1217768495205718`, 2.662963044905966}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}}, {{3.1217768495205718`, 
       2.662963044905966}, {3.182924678397142, 2.606281119516935}, {
       3.182924678397142, 2.606281119516935}, {3.1217768495205718`, 
       2.662963044905966}, {3.1217768495205718`, 2.662963044905966}}, {{
       3.1217768495205718`, 2.662963044905966}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}, {
       3.1217768495205718`, 2.662963044905966}, {3.1217768495205718`, 
       2.662963044905966}}, {{3.1217768495205718`, 2.662963044905966}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}, {3.1217768495205718`, 2.662963044905966}, {
       3.1217768495205718`, 2.662963044905966}}, {{3.182924678397142, 
       2.606281119516935}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}}, {{
       3.182924678397142, 2.606281119516935}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.182924678397142, 2.606281119516935}, {3.182924678397142, 
       2.606281119516935}}, {{3.182924678397142, 2.606281119516935}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.2156500032786854`, 
       2.5003699731301885`}, {3.182924678397142, 2.606281119516935}, {
       3.182924678397142, 2.606281119516935}}, {{3.182924678397142, 
       2.606281119516935}, {3.2156500032786854`, 2.5003699731301885`}, {
       3.2156500032786854`, 2.5003699731301885`}, {3.182924678397142, 
       2.606281119516935}, {3.182924678397142, 2.606281119516935}}, {{
       2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`, 
       2.9727513799026544`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.88603184364156, 
       3.0410854545733312`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}, {{2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}}, {{3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.0557879445798726`, 
       2.883727412194738}, {2.964937236453439, 2.9044173052319775`}, {
       2.964937236453439, 2.9044173052319775`}, {3.0557879445798726`, 
       2.883727412194738}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.2016534148890745`, 3.0410854545733312`}}, {{
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}}, {{2.964937236453439, 3.177753603914685}, {
       3.0557879445798726`, 3.1984434969519246`}, {3.1227480220771957`, 
       3.177753603914685}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1227480220771957`, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {2.964937236453439, 3.177753603914685}, {
       2.964937236453439, 3.177753603914685}}, {{3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}}, {{
       2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`, 
       2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}, {{2.964937236453439, 2.9044173052319775`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.9015939094183896`, 
       2.9727513799026544`}, {2.964937236453439, 2.9044173052319775`}, {
       2.964937236453439, 2.9044173052319775`}}, {{2.964937236453439, 
       2.9044173052319775`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.964937236453439, 
       2.9044173052319775`}, {2.964937236453439, 2.9044173052319775`}}, {{
       2.964937236453439, 2.9044173052319775`}, {2.9015939094183896`, 
       2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}}, {{2.9015939094183896`, 2.9727513799026544`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.9015939094183896`, 2.9727513799026544`}}, {{2.9015939094183896`, 
       2.9727513799026544`}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}, {2.9015939094183896`, 
       2.9727513799026544`}, {2.9015939094183896`, 2.9727513799026544`}}, {{
       2.9015939094183896`, 2.9727513799026544`}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 2.9727513799026544`}, {2.9015939094183896`, 
       2.9727513799026544`}}, {{2.9015939094183896`, 2.9727513799026544`}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}, {2.9015939094183896`, 2.9727513799026544`}, {
       2.9015939094183896`, 2.9727513799026544`}}, {{2.88603184364156, 
       3.0410854545733312`}, {2.9015939094183896`, 3.109419529244008}, {
       2.9015939094183896`, 3.109419529244008}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}}, {{
       2.88603184364156, 3.0410854545733312`}, {2.9015939094183896`, 
       3.109419529244008}, {2.9015939094183896`, 3.109419529244008}, {
       2.88603184364156, 3.0410854545733312`}, {2.88603184364156, 
       3.0410854545733312`}}, {{2.88603184364156, 3.0410854545733312`}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}, {2.88603184364156, 3.0410854545733312`}, {
       2.88603184364156, 3.0410854545733312`}}, {{2.88603184364156, 
       3.0410854545733312`}, {2.9015939094183896`, 3.109419529244008}, {
       2.9015939094183896`, 3.109419529244008}, {2.88603184364156, 
       3.0410854545733312`}, {2.88603184364156, 3.0410854545733312`}}, {{
       2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}}, {{2.9015939094183896`, 3.109419529244008}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}, {2.9015939094183896`, 3.109419529244008}, {
       2.9015939094183896`, 3.109419529244008}}, {{2.9015939094183896`, 
       3.109419529244008}, {2.964937236453439, 3.177753603914685}, {
       2.964937236453439, 3.177753603914685}, {2.9015939094183896`, 
       3.109419529244008}, {2.9015939094183896`, 3.109419529244008}}, {{
       2.9015939094183896`, 3.109419529244008}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}, {
       2.9015939094183896`, 3.109419529244008}, {2.9015939094183896`, 
       3.109419529244008}}, {{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}, {{3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.2016534148890745`, 3.0410854545733312`}}, {{
       3.2016534148890745`, 3.0410854545733312`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}}, {{3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}}, {{3.1741460337976903`, 
       2.9520614868654147`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.1741460337976903`, 2.9520614868654147`}}, {{
       3.1741460337976903`, 2.9520614868654147`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1741460337976903`, 2.9520614868654147`}, {3.1741460337976903`, 
       2.9520614868654147`}}, {{3.1741460337976903`, 2.9520614868654147`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1741460337976903`, 2.9520614868654147`}, {
       3.1741460337976903`, 2.9520614868654147`}}, {{3.1741460337976903`, 
       2.9520614868654147`}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1741460337976903`, 
       2.9520614868654147`}, {3.1741460337976903`, 2.9520614868654147`}}, {{
       3.1227480220771957`, 2.9044173052319775`}, {3.0557879445798726`, 
       2.883727412194738}, {3.0557879445798726`, 2.883727412194738}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}}, {{3.1227480220771957`, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}, {3.1227480220771957`, 2.9044173052319775`}, {
       3.1227480220771957`, 2.9044173052319775`}}, {{3.1227480220771957`, 
       2.9044173052319775`}, {3.0557879445798726`, 2.883727412194738}, {
       3.0557879445798726`, 2.883727412194738}, {3.1227480220771957`, 
       2.9044173052319775`}, {3.1227480220771957`, 2.9044173052319775`}}, {{
       3.1227480220771957`, 2.9044173052319775`}, {3.0557879445798726`, 
       2.883727412194738}, {3.0557879445798726`, 2.883727412194738}, {
       3.1227480220771957`, 2.9044173052319775`}, {3.1227480220771957`, 
       2.9044173052319775`}}, {{3.0557879445798726`, 2.883727412194738}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}, {3.0557879445798726`, 2.883727412194738}, {
       3.0557879445798726`, 2.883727412194738}}, {{3.0557879445798726`, 
       2.883727412194738}, {2.964937236453439, 2.9044173052319775`}, {
       2.964937236453439, 2.9044173052319775`}, {3.0557879445798726`, 
       2.883727412194738}, {3.0557879445798726`, 2.883727412194738}}, {{
       3.0557879445798726`, 2.883727412194738}, {2.964937236453439, 
       2.9044173052319775`}, {2.964937236453439, 2.9044173052319775`}, {
       3.0557879445798726`, 2.883727412194738}, {3.0557879445798726`, 
       2.883727412194738}}, {{3.0557879445798726`, 2.883727412194738}, {
       2.964937236453439, 2.9044173052319775`}, {2.964937236453439, 
       2.9044173052319775`}, {3.0557879445798726`, 2.883727412194738}, {
       3.0557879445798726`, 2.883727412194738}}, {{2.964937236453439, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}}, {{
       2.964937236453439, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.0557879445798726`, 3.1984434969519246`}, {
       2.964937236453439, 3.177753603914685}, {2.964937236453439, 
       3.177753603914685}}, {{2.964937236453439, 3.177753603914685}, {
       3.0557879445798726`, 3.1984434969519246`}, {3.0557879445798726`, 
       3.1984434969519246`}, {2.964937236453439, 3.177753603914685}, {
       2.964937236453439, 3.177753603914685}}, {{2.964937236453439, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}, {2.964937236453439, 
       3.177753603914685}, {2.964937236453439, 3.177753603914685}}, {{
       3.0557879445798726`, 3.1984434969519246`}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.0557879445798726`, 3.1984434969519246`}, {3.0557879445798726`, 
       3.1984434969519246`}}, {{3.0557879445798726`, 3.1984434969519246`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}, {3.0557879445798726`, 3.1984434969519246`}, {
       3.0557879445798726`, 3.1984434969519246`}}, {{3.0557879445798726`, 
       3.1984434969519246`}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}, {3.0557879445798726`, 
       3.1984434969519246`}, {3.0557879445798726`, 3.1984434969519246`}}, {{
       3.0557879445798726`, 3.1984434969519246`}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}, {
       3.0557879445798726`, 3.1984434969519246`}, {3.0557879445798726`, 
       3.1984434969519246`}}, {{3.1227480220771957`, 3.177753603914685}, {
       3.1741460337976903`, 3.1301094222812478`}, {3.1741460337976903`, 
       3.1301094222812478`}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}}, {{3.1227480220771957`, 
       3.177753603914685}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1741460337976903`, 3.1301094222812478`}, {3.1227480220771957`, 
       3.177753603914685}, {3.1227480220771957`, 3.177753603914685}}, {{
       3.1227480220771957`, 3.177753603914685}, {3.1741460337976903`, 
       3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1227480220771957`, 3.177753603914685}, {3.1227480220771957`, 
       3.177753603914685}}, {{3.1227480220771957`, 3.177753603914685}, {
       3.1741460337976903`, 3.1301094222812478`}, {3.1741460337976903`, 
       3.1301094222812478`}, {3.1227480220771957`, 3.177753603914685}, {
       3.1227480220771957`, 3.177753603914685}}, {{3.1741460337976903`, 
       3.1301094222812478`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.1741460337976903`, 
       3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}}, {{
       3.1741460337976903`, 3.1301094222812478`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.1741460337976903`, 3.1301094222812478`}, {3.1741460337976903`, 
       3.1301094222812478`}}, {{3.1741460337976903`, 3.1301094222812478`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.2016534148890745`, 
       3.0410854545733312`}, {3.1741460337976903`, 3.1301094222812478`}, {
       3.1741460337976903`, 3.1301094222812478`}}, {{3.1741460337976903`, 
       3.1301094222812478`}, {3.2016534148890745`, 3.0410854545733312`}, {
       3.2016534148890745`, 3.0410854545733312`}, {3.1741460337976903`, 
       3.1301094222812478`}, {3.1741460337976903`, 3.1301094222812478`}}, {{
       2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8489083345715707`, 
       3.53712285676085}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}, {{2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}}, {{3.1576556345887448`, 
       3.53712285676085}, {3.130747367169189, 3.450037840492806}, {
       3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {2.926095159575864, 3.403431354178486}, {
       2.926095159575864, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.0804688095844512`, 3.403431354178486}, {
       3.130747367169189, 3.450037840492806}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}}, {{
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}, {{2.926095159575864, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`, 
       3.670814359343214}, {3.130747367169189, 3.624207873028894}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}, {3.130747367169189, 3.624207873028894}, {
       3.0804688095844512`, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {2.926095159575864, 3.670814359343214}, {
       2.926095159575864, 3.670814359343214}}, {{3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}}, {{
       2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}, {{2.926095159575864, 3.403431354178486}, {
       2.8641314569085345`, 3.470277105469668}, {2.8641314569085345`, 
       3.470277105469668}, {2.926095159575864, 3.403431354178486}, {
       2.926095159575864, 3.403431354178486}}, {{2.926095159575864, 
       3.403431354178486}, {2.8641314569085345`, 3.470277105469668}, {
       2.8641314569085345`, 3.470277105469668}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}}, {{
       2.926095159575864, 3.403431354178486}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}}, {{2.8641314569085345`, 3.470277105469668}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8641314569085345`, 3.470277105469668}, {
       2.8641314569085345`, 3.470277105469668}}, {{2.8641314569085345`, 
       3.470277105469668}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}, {2.8641314569085345`, 
       3.470277105469668}, {2.8641314569085345`, 3.470277105469668}}, {{
       2.8641314569085345`, 3.470277105469668}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.470277105469668}, {2.8641314569085345`, 
       3.470277105469668}}, {{2.8641314569085345`, 3.470277105469668}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}, {2.8641314569085345`, 3.470277105469668}, {
       2.8641314569085345`, 3.470277105469668}}, {{2.8489083345715707`, 
       3.53712285676085}, {2.8641314569085345`, 3.603968608052032}, {
       2.8641314569085345`, 3.603968608052032}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}}, {{
       2.8489083345715707`, 3.53712285676085}, {2.8641314569085345`, 
       3.603968608052032}, {2.8641314569085345`, 3.603968608052032}, {
       2.8489083345715707`, 3.53712285676085}, {2.8489083345715707`, 
       3.53712285676085}}, {{2.8489083345715707`, 3.53712285676085}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}, {2.8489083345715707`, 3.53712285676085}, {
       2.8489083345715707`, 3.53712285676085}}, {{2.8489083345715707`, 
       3.53712285676085}, {2.8641314569085345`, 3.603968608052032}, {
       2.8641314569085345`, 3.603968608052032}, {2.8489083345715707`, 
       3.53712285676085}, {2.8489083345715707`, 3.53712285676085}}, {{
       2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}}, {{2.8641314569085345`, 3.603968608052032}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}, {2.8641314569085345`, 3.603968608052032}, {
       2.8641314569085345`, 3.603968608052032}}, {{2.8641314569085345`, 
       3.603968608052032}, {2.926095159575864, 3.670814359343214}, {
       2.926095159575864, 3.670814359343214}, {2.8641314569085345`, 
       3.603968608052032}, {2.8641314569085345`, 3.603968608052032}}, {{
       2.8641314569085345`, 3.603968608052032}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}, {
       2.8641314569085345`, 3.603968608052032}, {2.8641314569085345`, 
       3.603968608052032}}, {{3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}, {3.1576556345887448`, 3.53712285676085}, {
       3.1576556345887448`, 3.53712285676085}}, {{3.1576556345887448`, 
       3.53712285676085}, {3.130747367169189, 3.450037840492806}, {
       3.130747367169189, 3.450037840492806}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}}, {{
       3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}}, {{3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}, {3.1576556345887448`, 3.53712285676085}, {
       3.1576556345887448`, 3.53712285676085}}, {{3.130747367169189, 
       3.450037840492806}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}}, {{
       3.130747367169189, 3.450037840492806}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}, {
       3.130747367169189, 3.450037840492806}, {3.130747367169189, 
       3.450037840492806}}, {{3.130747367169189, 3.450037840492806}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}, {3.130747367169189, 3.450037840492806}, {
       3.130747367169189, 3.450037840492806}}, {{3.130747367169189, 
       3.450037840492806}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}, {3.130747367169189, 
       3.450037840492806}, {3.130747367169189, 3.450037840492806}}, {{
       3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}, {{3.0804688095844512`, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.014967129662749, 
       3.383192089201624}, {3.0804688095844512`, 3.403431354178486}, {
       3.0804688095844512`, 3.403431354178486}}, {{3.0804688095844512`, 
       3.403431354178486}, {3.014967129662749, 3.383192089201624}, {
       3.014967129662749, 3.383192089201624}, {3.0804688095844512`, 
       3.403431354178486}, {3.0804688095844512`, 3.403431354178486}}, {{
       3.0804688095844512`, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}, {
       3.0804688095844512`, 3.403431354178486}, {3.0804688095844512`, 
       3.403431354178486}}, {{3.014967129662749, 3.383192089201624}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}, {3.014967129662749, 3.383192089201624}, {
       3.014967129662749, 3.383192089201624}}, {{3.014967129662749, 
       3.383192089201624}, {2.926095159575864, 3.403431354178486}, {
       2.926095159575864, 3.403431354178486}, {3.014967129662749, 
       3.383192089201624}, {3.014967129662749, 3.383192089201624}}, {{
       3.014967129662749, 3.383192089201624}, {2.926095159575864, 
       3.403431354178486}, {2.926095159575864, 3.403431354178486}, {
       3.014967129662749, 3.383192089201624}, {3.014967129662749, 
       3.383192089201624}}, {{3.014967129662749, 3.383192089201624}, {
       2.926095159575864, 3.403431354178486}, {2.926095159575864, 
       3.403431354178486}, {3.014967129662749, 3.383192089201624}, {
       3.014967129662749, 3.383192089201624}}, {{2.926095159575864, 
       3.670814359343214}, {3.014967129662749, 3.6910536243200758`}, {
       3.014967129662749, 3.6910536243200758`}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}}, {{
       2.926095159575864, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.014967129662749, 3.6910536243200758`}, {
       2.926095159575864, 3.670814359343214}, {2.926095159575864, 
       3.670814359343214}}, {{2.926095159575864, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}, {2.926095159575864, 3.670814359343214}, {
       2.926095159575864, 3.670814359343214}}, {{2.926095159575864, 
       3.670814359343214}, {3.014967129662749, 3.6910536243200758`}, {
       3.014967129662749, 3.6910536243200758`}, {2.926095159575864, 
       3.670814359343214}, {2.926095159575864, 3.670814359343214}}, {{
       3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}}, {{3.014967129662749, 3.6910536243200758`}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}, {3.014967129662749, 3.6910536243200758`}, {
       3.014967129662749, 3.6910536243200758`}}, {{3.014967129662749, 
       3.6910536243200758`}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}, {3.014967129662749, 
       3.6910536243200758`}, {3.014967129662749, 3.6910536243200758`}}, {{
       3.014967129662749, 3.6910536243200758`}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}, {
       3.014967129662749, 3.6910536243200758`}, {3.014967129662749, 
       3.6910536243200758`}}, {{3.0804688095844512`, 3.670814359343214}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}}, {{3.0804688095844512`, 
       3.670814359343214}, {3.130747367169189, 3.624207873028894}, {
       3.130747367169189, 3.624207873028894}, {3.0804688095844512`, 
       3.670814359343214}, {3.0804688095844512`, 3.670814359343214}}, {{
       3.0804688095844512`, 3.670814359343214}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}, {
       3.0804688095844512`, 3.670814359343214}, {3.0804688095844512`, 
       3.670814359343214}}, {{3.0804688095844512`, 3.670814359343214}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}, {3.0804688095844512`, 3.670814359343214}, {
       3.0804688095844512`, 3.670814359343214}}, {{3.130747367169189, 
       3.624207873028894}, {3.1576556345887448`, 3.53712285676085}, {
       3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}}, {{
       3.130747367169189, 3.624207873028894}, {3.1576556345887448`, 
       3.53712285676085}, {3.1576556345887448`, 3.53712285676085}, {
       3.130747367169189, 3.624207873028894}, {3.130747367169189, 
       3.624207873028894}}, {{3.130747367169189, 3.624207873028894}, {
       3.1576556345887448`, 3.53712285676085}, {3.1576556345887448`, 
       3.53712285676085}, {3.130747367169189, 3.624207873028894}, {
       3.130747367169189, 3.624207873028894}}, {{3.130747367169189, 
       3.624207873028894}, {3.1576556345887448`, 3.53712285676085}, {
       3.1576556345887448`, 3.53712285676085}, {3.130747367169189, 
       3.624207873028894}, {3.130747367169189, 3.624207873028894}}, {{
       3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}, {{
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}, {{
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}, {{
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}, {{
       3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}, {{
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}, {{
       3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}, {{
       3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}, {{
       3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}, {{
       3.2174898936099963`, -4.3792413400072085`}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}}, {{
       3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}, {{
       3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}, {{
       3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}, {{
       3.153242159283202, -4.309931600838002}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.309931600838002}, {
       3.153242159283202, -4.309931600838002}}, {{
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}, {{
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}, {{
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}, {{
       3.137457900476389, -4.240621861668797}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}, {
       3.137457900476389, -4.240621861668797}, {
       3.137457900476389, -4.240621861668797}}, {{
       3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}, {{
       3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}, {{
       3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}, {{
       3.153242159283202, -4.171312122499591}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.153242159283202, -4.171312122499591}, {
       3.153242159283202, -4.171312122499591}}, {{
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}, {{
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}, {{
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}, {{
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}}, {{
       3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}, {{
       3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}, {{
       3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}, {{
       3.42968574532401, -4.330916901315997}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.42968574532401, -4.330916901315997}, {
       3.42968574532401, -4.330916901315997}}, {{
       3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}, {{
       3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}, {{
       3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}, {{
       3.377553879877211, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.377553879877211, -4.3792413400072085`}, {
       3.377553879877211, -4.3792413400072085`}}, {{
       3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}, {{
       3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}, {{
       3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}, {{
       3.3096377556235987`, -4.400226640485203}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.2174898936099963`, -4.3792413400072085`}, {
       3.3096377556235987`, -4.400226640485203}, {
       3.3096377556235987`, -4.400226640485203}}, {{
       3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}, {{
       3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}, {{
       3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}, {{
       3.2174898936099963`, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.2174898936099963`, -4.102002383330385}, {
       3.2174898936099963`, -4.102002383330385}}, {{
       3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}, {{
       3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}, {{
       3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}, {{
       3.3096377556235987`, -4.081017082852391}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}, {
       3.3096377556235987`, -4.081017082852391}, {
       3.3096377556235987`, -4.081017082852391}}, {{
       3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}, {{
       3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}, {{
       3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}, {{
       3.377553879877211, -4.102002383330385}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}, {
       3.377553879877211, -4.102002383330385}, {
       3.377553879877211, -4.102002383330385}}, {{
       3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}, {{
       3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}, {{
       3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}, {{
       3.42968574532401, -4.150326822021596}, {
       3.457585873010818, -4.240621861668797}, {
       3.457585873010818, -4.240621861668797}, {
       3.42968574532401, -4.150326822021596}, {
       3.42968574532401, -4.150326822021596}}, {{
       3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}, {{
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}, {{
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}, {{
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}, {{
       3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3014538080137714`, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}, {{
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}, {{
       3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}, {{
       3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}, {{
       3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}, {{
       3.2014288512154763`, -3.9042208209282308`}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}}, {{
       3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}, {{
       3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}, {{
       3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}, {{
       3.1316890145008998`, -3.828986262962279}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.828986262962279}, {
       3.1316890145008998`, -3.828986262962279}}, {{
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}, {{
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}, {{
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}, {{
       3.1145554666274666`, -3.753751704996327}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1145554666274666`, -3.753751704996327}, {
       3.1145554666274666`, -3.753751704996327}}, {{
       3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}, {{
       3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}, {{
       3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}, {{
       3.1316890145008998`, -3.678517147030375}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.1316890145008998`, -3.678517147030375}, {
       3.1316890145008998`, -3.678517147030375}}, {{
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}, {{
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}, {{
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}, {{
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}}, {{
       3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}, {{
       3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}, {{
       3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}, {{
       3.431763884895786, -3.8517654542299047`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.431763884895786, -3.8517654542299047`}, {
       3.431763884895786, -3.8517654542299047`}}, {{
       3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}, {{
       3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}, {{
       3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}, {{
       3.3751756203914955`, -3.9042208209282308`}, {
       3.301453808013772, -3.927000012195857}, {
       3.301453808013772, -3.927000012195857}, {
       3.3751756203914955`, -3.9042208209282308`}, {
       3.3751756203914955`, -3.9042208209282308`}}, {{
       3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}, {{
       3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}, {{
       3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}, {{
       3.3014538080137714`, -3.927000012195857}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.2014288512154763`, -3.9042208209282308`}, {
       3.3014538080137714`, -3.927000012195857}, {
       3.3014538080137714`, -3.927000012195857}}, {{
       3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}, {{
       3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}, {{
       3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}, {{
       3.2014288512154763`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}, {
       3.2014288512154763`, -3.603282589064423}, {
       3.2014288512154763`, -3.603282589064423}}, {{
       3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}, {{
       3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}, {{
       3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}, {{
       3.301453808013772, -3.580503397796797}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.301453808013772, -3.580503397796797}, {
       3.301453808013772, -3.580503397796797}}, {{
       3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}, {{
       3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}, {{
       3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}, {{
       3.3751756203914955`, -3.603282589064423}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}, {
       3.3751756203914955`, -3.603282589064423}, {
       3.3751756203914955`, -3.603282589064423}}, {{
       3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}, {{
       3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}, {{
       3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}, {{
       3.431763884895786, -3.655737955762749}, {
       3.462049004979505, -3.753751704996327}, {
       3.462049004979505, -3.753751704996327}, {
       3.431763884895786, -3.655737955762749}, {
       3.431763884895786, -3.655737955762749}}, {{
       3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}, {{
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}, {{
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}, {{
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}, {{
       3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}, {{
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}, {{
       3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}, {{
       3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}, {{
       3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}, {{
       3.198394214339006, -3.4313136853136466`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}}, {{
       3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}, {{
       3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}, {{
       3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}, {{
       3.135953703297818, -3.3639535584670908`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.3639535584670908`}, {
       3.135953703297818, -3.3639535584670908`}}, {{
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}, {{
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}, {{
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}, {{
       3.1206134396039937`, -3.2965934316205354`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}, {
       3.1206134396039937`, -3.2965934316205354`}, {
       3.1206134396039937`, -3.2965934316205354`}}, {{
       3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}, {{
       3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}, {{
       3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}, {{
       3.135953703297818, -3.22923330477398}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.135953703297818, -3.22923330477398}, {
       3.135953703297818, -3.22923330477398}}, {{
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}, {{
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}, {{
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}, {{
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}}, {{
       3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}, {{
       3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}, {{
       3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}, {{
       3.404621213013378, -3.384348563830765}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.404621213013378, -3.384348563830765}, {
       3.404621213013378, -3.384348563830765}}, {{
       3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}, {{
       3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}, {{
       3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}, {{
       3.3539557638090307`, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.3539557638090307`, -3.4313136853136466`}, {
       3.3539557638090307`, -3.4313136853136466`}}, {{
       3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}, {{
       3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}, {{
       3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}, {{
       3.2879500509108595`, -3.4517086906773207`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.198394214339006, -3.4313136853136466`}, {
       3.2879500509108595`, -3.4517086906773207`}, {
       3.2879500509108595`, -3.4517086906773207`}}, {{
       3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}, {{
       3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}, {{
       3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}, {{
       3.198394214339006, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.198394214339006, -3.1618731779274243`}, {
       3.198394214339006, -3.1618731779274243`}}, {{
       3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}, {{
       3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}, {{
       3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}, {{
       3.2879500509108595`, -3.14147817256375}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.2879500509108595`, -3.14147817256375}, {
       3.2879500509108595`, -3.14147817256375}}, {{
       3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}, {{
       3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}, {{
       3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}, {{
       3.3539557638090307`, -3.1618731779274243`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}, {
       3.3539557638090307`, -3.1618731779274243`}, {
       3.3539557638090307`, -3.1618731779274243`}}, {{
       3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}, {{
       3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}, {{
       3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}, {{
       3.404621213013378, -3.208838299410306}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.431736538544043, -3.2965934316205354`}, {
       3.404621213013378, -3.208838299410306}, {
       3.404621213013378, -3.208838299410306}}, {{
       3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}, {{
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}, {{
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}, {{
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}, {{
       3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}, {{
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}, {{
       3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}, {{
       3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}, {{
       3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}, {{
       3.154331769703739, -2.8863682512352375`}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}}, {{
       3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}, {{
       3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}, {{
       3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}, {{
       3.087777329919981, -2.814570063948171}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.814570063948171}, {
       3.087777329919981, -2.814570063948171}}, {{
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}, {{
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}, {{
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}, {{
       3.071426364188709, -2.742771876661105}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}, {
       3.071426364188709, -2.742771876661105}, {
       3.071426364188709, -2.742771876661105}}, {{
       3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}, {{
       3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}, {{
       3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}, {{
       3.087777329919981, -2.670973689374039}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.087777329919981, -2.670973689374039}, {
       3.087777329919981, -2.670973689374039}}, {{
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}, {{
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}, {{
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}, {{
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}}, {{
       3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}, {{
       3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}, {{
       3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}, {{
       3.374146152004435, -2.836308805892014}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.374146152004435, -2.836308805892014}, {
       3.374146152004435, -2.836308805892014}}, {{
       3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}, {{
       3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}, {{
       3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}, {{
       3.3201425807337985`, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.3201425807337985`, -2.8863682512352375`}, {
       3.3201425807337985`, -2.8863682512352375`}}, {{
       3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}, {{
       3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}, {{
       3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}, {{
       3.2497880437318902`, -2.9081069931790804`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.154331769703739, -2.8863682512352375`}, {
       3.2497880437318902`, -2.9081069931790804`}, {
       3.2497880437318902`, -2.9081069931790804`}}, {{
       3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}, {{
       3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}, {{
       3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}, {{
       3.154331769703739, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.154331769703739, -2.5991755020869722`}, {
       3.154331769703739, -2.5991755020869722`}}, {{
       3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}, {{
       3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}, {{
       3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}, {{
       3.2497880437318902`, -2.5774367601431294`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.2497880437318902`, -2.5774367601431294`}, {
       3.2497880437318902`, -2.5774367601431294`}}, {{
       3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}, {{
       3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}, {{
       3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}, {{
       3.3201425807337985`, -2.5991755020869722`}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}, {
       3.3201425807337985`, -2.5991755020869722`}, {
       3.3201425807337985`, -2.5991755020869722`}}, {{
       3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}, {{
       3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}, {{
       3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}, {{
       3.374146152004435, -2.649234947430196}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.4030479862488283`, -2.742771876661105}, {
       3.374146152004435, -2.649234947430196}, {
       3.374146152004435, -2.649234947430196}}, {{
       3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}, {{
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}, {{
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}, {{
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}, {{
       3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}, {{
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}, {{
       3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}, {{
       3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}, {{
       3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}, {{
       3.2090324546266045`, -2.3312398933186684`}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}}, {{
       3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}, {{
       3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}, {{
       3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}, {{
       3.1488205972146472`, -2.26628401314881}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.26628401314881}, {
       3.1488205972146472`, -2.26628401314881}}, {{
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}, {{
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}, {{
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}, {{
       3.1340278648235707`, -2.201328132978951}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1340278648235707`, -2.201328132978951}, {
       3.1340278648235707`, -2.201328132978951}}, {{
       3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}, {{
       3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}, {{
       3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}, {{
       3.1488205972146472`, -2.1363722528090925`}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.1488205972146472`, -2.1363722528090925`}, {
       3.1488205972146472`, -2.1363722528090925`}}, {{
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}, {{
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}, {{
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}, {{
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}}, {{
       3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}, {{
       3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}, {{
       3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}, {{
       3.407898710389409, -2.2859510711916817`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.407898710389409, -2.2859510711916817`}, {
       3.407898710389409, -2.2859510711916817`}}, {{
       3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}, {{
       3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}, {{
       3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}, {{
       3.359041634232672, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.359041634232672, -2.3312398933186684`}, {
       3.359041634232672, -2.3312398933186684`}}, {{
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}, {{
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}, {{
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}, {{
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2090324546266045`, -2.3312398933186684`}, {
       3.2953918256848582`, -2.3509069513615404`}, {
       3.2953918256848582`, -2.3509069513615404`}}, {{
       3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}, {{
       3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}, {{
       3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}, {{
       3.2090324546266045`, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2090324546266045`, -2.071416372639234}, {
       3.2090324546266045`, -2.071416372639234}}, {{
       3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}, {{
       3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}, {{
       3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}, {{
       3.2953918256848582`, -2.051749314596362}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}, {
       3.2953918256848582`, -2.051749314596362}, {
       3.2953918256848582`, -2.051749314596362}}, {{
       3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}, {{
       3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}, {{
       3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}, {{
       3.359041634232672, -2.071416372639234}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.359041634232672, -2.071416372639234}, {
       3.359041634232672, -2.071416372639234}}, {{
       3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}, {{
       3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}, {{
       3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}, {{
       3.407898710389409, -2.1167051947662205`}, {
       3.434046224035706, -2.201328132978951}, {
       3.434046224035706, -2.201328132978951}, {
       3.407898710389409, -2.1167051947662205`}, {
       3.407898710389409, -2.1167051947662205`}}, {{
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}, {{
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}, {{
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}, {{
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}, {{
       3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}, {{
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}, {{
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}, {{
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}, {{
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}, {{
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}}, {{
       3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}, {{
       3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}, {{
       3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}, {{
       3.1057141552471172`, -1.8016044859555185`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.8016044859555185`}, {
       3.1057141552471172`, -1.8016044859555185`}}, {{
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}, {{
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}, {{
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}, {{
       3.0896916770913907`, -1.7312487096463796`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.0896916770913907`, -1.7312487096463796`}, {
       3.0896916770913907`, -1.7312487096463796`}}, {{
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}, {{
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}, {{
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}, {{
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1057141552471172`, -1.6608929333372406`}, {
       3.1057141552471172`, -1.6608929333372406`}}, {{
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}, {{
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}, {{
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}, {{
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}}, {{
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}, {{
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}, {{
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}, {{
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3863298859469757`, -1.8229065009956475`}, {
       3.3863298859469757`, -1.8229065009956475`}}, {{
       3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}, {{
       3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}, {{
       3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}, {{
       3.3334112354381493`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.3334112354381493`, -1.8719602622646574`}, {
       3.3334112354381493`, -1.8719602622646574`}}, {{
       3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}, {{
       3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}, {{
       3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}, {{
       3.2644701067735964`, -1.8932622773047865`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.1709315298736436`, -1.8719602622646574`}, {
       3.2644701067735964`, -1.8932622773047865`}, {
       3.2644701067735964`, -1.8932622773047865`}}, {{
       3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}, {{
       3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}, {{
       3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}, {{
       3.1709315298736436`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.1709315298736436`, -1.5905371570281017`}, {
       3.1709315298736436`, -1.5905371570281017`}}, {{
       3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}, {{
       3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}, {{
       3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}, {{
       3.2644701067735964`, -1.5692351419879726`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.2644701067735964`, -1.5692351419879726`}, {
       3.2644701067735964`, -1.5692351419879726`}}, {{
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}, {{
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}, {{
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}, {{
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3334112354381493`, -1.5905371570281017`}, {
       3.3334112354381493`, -1.5905371570281017`}}, {{
       3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}, {{
       3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}, {{
       3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}, {{
       3.3863298859469757`, -1.6395909182971116`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.414651088220402, -1.7312487096463796`}, {
       3.3863298859469757`, -1.6395909182971116`}, {
       3.3863298859469757`, -1.6395909182971116`}}, {{
       3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}, {{
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}, {{
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}, {{
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}, {{
       3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}, {{
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}, {{
       3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}, {{
       3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}, {{
       3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}, {{
       3.1285909019734612`, -1.3852184519474506`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}}, {{
       3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}, {{
       3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}, {{
       3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}, {{
       3.061913858003313, -1.3132880006316399`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.3132880006316399`}, {
       3.061913858003313, -1.3132880006316399`}}, {{
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}, {{
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}, {{
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}, {{
       3.045532771113232, -1.241357549315829}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.045532771113232, -1.241357549315829}, {
       3.045532771113232, -1.241357549315829}}, {{
       3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}, {{
       3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}, {{
       3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}, {{
       3.061913858003313, -1.1694270980000183`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.061913858003313, -1.1694270980000183`}, {
       3.061913858003313, -1.1694270980000183`}}, {{
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}, {{
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}, {{
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}, {{
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}}, {{
       3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}, {{
       3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}, {{
       3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}, {{
       3.348810218394051, -1.3350667889011347`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.348810218394051, -1.3350667889011347`}, {
       3.348810218394051, -1.3350667889011347`}}, {{
       3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}, {{
       3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}, {{
       3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}, {{
       3.2947071636939196`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.2947071636939196`, -1.3852184519474506`}, {
       3.2947071636939196`, -1.3852184519474506`}}, {{
       3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}, {{
       3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}, {{
       3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}, {{
       3.224223022103707, -1.4069972402169455`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.1285909019734612`, -1.3852184519474506`}, {
       3.224223022103707, -1.4069972402169455`}, {
       3.224223022103707, -1.4069972402169455`}}, {{
       3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}, {{
       3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}, {{
       3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}, {{
       3.1285909019734612`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.1285909019734612`, -1.0974966466842075`}, {
       3.1285909019734612`, -1.0974966466842075`}}, {{
       3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}, {{
       3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}, {{
       3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}, {{
       3.224223022103707, -1.0757178584147127`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.224223022103707, -1.0757178584147127`}, {
       3.224223022103707, -1.0757178584147127`}}, {{
       3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}, {{
       3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}, {{
       3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}, {{
       3.2947071636939196`, -1.0974966466842075`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.2947071636939196`, -1.0974966466842075`}, {
       3.2947071636939196`, -1.0974966466842075`}}, {{
       3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}, {{
       3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}, {{
       3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}, {{
       3.348810218394051, -1.1476483097305235`}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.3777652945541488`, -1.241357549315829}, {
       3.348810218394051, -1.1476483097305235`}, {
       3.348810218394051, -1.1476483097305235`}}, {{
       3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}, {{
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}, {{
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}, {{
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}, {{
       3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}, {{
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}, {{
       3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}, {{
       3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}, {{
       3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}, {{
       3.1343770950791097`, -0.9243754838349624}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}}, {{
       3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}, {{
       3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}, {{
       3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}, {{
       3.0701443623878952`, -0.8550819282628911}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.8550819282628911}, {
       3.0701443623878952`, -0.8550819282628911}}, {{
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}, {{
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}, {{
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}, {{
       3.0543637891538267`, -0.7857883726908198}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0543637891538267`, -0.7857883726908198}, {
       3.0543637891538267`, -0.7857883726908198}}, {{
       3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}, {{
       3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}, {{
       3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}, {{
       3.0701443623878952`, -0.7164948171187485}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.0701443623878952`, -0.7164948171187485}, {
       3.0701443623878952`, -0.7164948171187485}}, {{
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}, {{
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}, {{
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}, {{
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}}, {{
       3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}, {{
       3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}, {{
       3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}, {{
       3.3465233997566046`, -0.8760623287419423}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.3465233997566046`, -0.8760623287419423}, {
       3.3465233997566046`, -0.8760623287419423}}, {{
       3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}, {{
       3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}, {{
       3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}, {{
       3.2944037069296765`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2944037069296765`, -0.9243754838349624}, {
       3.2944037069296765`, -0.9243754838349624}}, {{
       3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}, {{
       3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}, {{
       3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}, {{
       3.2265034408686795`, -0.9453558843140136}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.1343770950791097`, -0.9243754838349624}, {
       3.2265034408686795`, -0.9453558843140136}, {
       3.2265034408686795`, -0.9453558843140136}}, {{
       3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}, {{
       3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}, {{
       3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}, {{
       3.1343770950791097`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.1343770950791097`, -0.6472012615466772}, {
       3.1343770950791097`, -0.6472012615466772}}, {{
       3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}, {{
       3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}, {{
       3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}, {{
       3.2265034408686795`, -0.626220861067626}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2265034408686795`, -0.626220861067626}, {
       3.2265034408686795`, -0.626220861067626}}, {{
       3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}, {{
       3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}, {{
       3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}, {{
       3.2944037069296765`, -0.6472012615466772}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.2944037069296765`, -0.6472012615466772}, {
       3.2944037069296765`, -0.6472012615466772}}, {{
       3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}, {{
       3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}, {{
       3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}, {{
       3.3465233997566046`, -0.6955144166396973}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3744170128549595`, -0.7857883726908198}, {
       3.3465233997566046`, -0.6955144166396973}, {
       3.3465233997566046`, -0.6955144166396973}}, {{
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.1449202032691863}, {
       3.1836394581301835`, -0.1449202032691863}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.35084787490958663`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}, {{
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}, {{
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}, {{
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}, {{
       3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}, {{
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}, {{
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}, {{
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}, {{
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}, {{
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}}, {{
       3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}, {{
       3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}, {{
       3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}, {{
       3.1200101784326195`, -0.3508478749095866}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.3508478749095866}, {
       3.1200101784326195`, -0.3508478749095866}}, {{
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}, {{
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}, {{
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}, {{
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1200101784326195`, -0.21356276048265307`}, {
       3.1043778603600645`, -0.28220531769611984`}, {
       3.1043778603600645`, -0.28220531769611984`}}, {{
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}, {{
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}, {{
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}, {{
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1200101784326195`, -0.21356276048265305`}, {
       3.1200101784326195`, -0.21356276048265305`}}, {{
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}, {{
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}, {{
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}, {{
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}}, {{
       3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}, {{
       3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}, {{
       3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}, {{
       3.3937926929617324`, -0.3716311689454489}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3937926929617324`, -0.3716311689454489}, {
       3.3937926929617324`, -0.3716311689454489}}, {{
       3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}, {{
       3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}, {{
       3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}, {{
       3.3421626536704205`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}, {
       3.3421626536704205`, -0.41949043212305337`}, {
       3.3421626536704205`, -0.41949043212305337`}}, {{
       3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}, {{
       3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}, {{
       3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}, {{
       3.274900296306554, -0.4402737261589157}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.1836394581301835`, -0.41949043212305337`}, {
       3.274900296306554, -0.4402737261589157}, {
       3.274900296306554, -0.4402737261589157}}, {{
       3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}, {{
       3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}, {{
       3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}, {{
       3.1836394581301835`, -0.14492020326918628`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.1836394581301835`, -0.14492020326918628`}, {
       3.1836394581301835`, -0.14492020326918628`}}, {{
       3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}, {{
       3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}, {{
       3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}, {{
       3.274900296306554, -0.12413690923332399`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.274900296306554, -0.12413690923332399`}, {
       3.274900296306554, -0.12413690923332399`}}, {{
       3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}, {{
       3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}, {{
       3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}, {{
       3.3421626536704205`, -0.1449202032691863}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3421626536704205`, -0.1449202032691863}, {
       3.3421626536704205`, -0.1449202032691863}}, {{
       3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}, {{
       3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}, {{
       3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}, {{
       3.3937926929617324`, -0.19277946644679078`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.4214242514405395`, -0.28220531769611984`}, {
       3.3937926929617324`, -0.19277946644679078`}, {
       3.3937926929617324`, -0.19277946644679078`}}, {{3.1543700209256644`, 
       0.1216113847941172}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.072253336609394, 0.26384165417899186`}, {3.0884487473052338`, 
       0.3349567888714292}, {3.1543700209256644`, 0.4060719235638665}, {
       3.1543700209256644`, 0.4060719235638665}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.1927265194865545}, {3.1543700209256644`, 
       0.1216113847941172}, {3.1543700209256644`, 0.1216113847941172}}, {{
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}}, {{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.12161138479411718`}, {3.1543700209256644`, 
       0.12161138479411718`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}, {{3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}}, {{
       3.1543700209256644`, 0.40607192356386657`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.318603389558205, 0.4060719235638665}, {
       3.372093197447488, 0.3564887191303286}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.3564887191303286}, {3.318603389558205, 
       0.4060719235638665}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}}, {{3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}}, {{3.1543700209256644`, 
       0.1216113847941172}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.1543700209256644`, 
       0.1216113847941172}, {3.1543700209256644`, 0.1216113847941172}}, {{
       3.1543700209256644`, 0.1216113847941172}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.1543700209256644`, 0.1216113847941172}, {3.1543700209256644`, 
       0.1216113847941172}}, {{3.1543700209256644`, 0.1216113847941172}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}}, {{3.1543700209256644`, 
       0.1216113847941172}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.1543700209256644`, 
       0.1216113847941172}, {3.1543700209256644`, 0.1216113847941172}}, {{
       3.0884487473052338`, 0.19272651948655453`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}}, {{3.0884487473052338`, 0.19272651948655453`}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.19272651948655453`}, {
       3.0884487473052338`, 0.19272651948655453`}}, {{3.0884487473052338`, 
       0.19272651948655453`}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}, {3.0884487473052338`, 
       0.19272651948655453`}, {3.0884487473052338`, 0.19272651948655453`}}, {{
       3.0884487473052338`, 0.19272651948655453`}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.19272651948655453`}, {3.0884487473052338`, 
       0.19272651948655453`}}, {{3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}}, {{3.072253336609394, 
       0.26384165417899186`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.0884487473052338`, 0.3349567888714292}, {3.072253336609394, 
       0.26384165417899186`}, {3.072253336609394, 0.26384165417899186`}}, {{
       3.072253336609394, 0.26384165417899186`}, {3.0884487473052338`, 
       0.3349567888714292}, {3.0884487473052338`, 0.3349567888714292}, {
       3.072253336609394, 0.26384165417899186`}, {3.072253336609394, 
       0.26384165417899186`}}, {{3.072253336609394, 0.26384165417899186`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}, {3.072253336609394, 0.26384165417899186`}, {
       3.072253336609394, 0.26384165417899186`}}, {{3.0884487473052338`, 
       0.3349567888714292}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.0884487473052338`, 
       0.3349567888714292}, {3.0884487473052338`, 0.3349567888714292}}, {{
       3.0884487473052338`, 0.3349567888714292}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.0884487473052338`, 0.3349567888714292}, {3.0884487473052338`, 
       0.3349567888714292}}, {{3.0884487473052338`, 0.3349567888714292}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.0884487473052338`, 0.3349567888714292}, {
       3.0884487473052338`, 0.3349567888714292}}, {{3.0884487473052338`, 
       0.3349567888714292}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.0884487473052338`, 
       0.3349567888714292}, {3.0884487473052338`, 0.3349567888714292}}, {{
       3.4007200738744756`, 0.26384165417899186`}, {3.372093197447488, 
       0.17119458922765513`}, {3.372093197447488, 0.17119458922765513`}, {
       3.4007200738744756`, 0.26384165417899186`}, {3.4007200738744756`, 
       0.26384165417899186`}}, {{3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}}, {{3.4007200738744756`, 
       0.26384165417899186`}, {3.372093197447488, 0.17119458922765513`}, {
       3.372093197447488, 0.17119458922765513`}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}}, {{
       3.4007200738744756`, 0.26384165417899186`}, {3.372093197447488, 
       0.17119458922765513`}, {3.372093197447488, 0.17119458922765513`}, {
       3.4007200738744756`, 0.26384165417899186`}, {3.4007200738744756`, 
       0.26384165417899186`}}, {{3.372093197447488, 0.17119458922765513`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.372093197447488, 0.17119458922765513`}, {
       3.372093197447488, 0.17119458922765513`}}, {{3.372093197447488, 
       0.17119458922765513`}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}, {3.372093197447488, 
       0.17119458922765513`}, {3.372093197447488, 0.17119458922765513`}}, {{
       3.372093197447488, 0.17119458922765513`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}, {
       3.372093197447488, 0.17119458922765513`}, {3.372093197447488, 
       0.17119458922765513`}}, {{3.372093197447488, 0.17119458922765513`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}, {3.372093197447488, 0.17119458922765513`}, {
       3.372093197447488, 0.17119458922765513`}}, {{3.318603389558205, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}}, {{
       3.318603389558205, 0.1216113847941172}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.318603389558205, 0.1216113847941172}, {3.318603389558205, 
       0.1216113847941172}}, {{3.318603389558205, 0.1216113847941172}, {
       3.2489181709730826`, 0.10007945453521777`}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.318603389558205, 0.1216113847941172}, {
       3.318603389558205, 0.1216113847941172}}, {{3.318603389558205, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}, {3.318603389558205, 
       0.1216113847941172}, {3.318603389558205, 0.1216113847941172}}, {{
       3.2489181709730826`, 0.10007945453521777`}, {3.1543700209256644`, 
       0.1216113847941172}, {3.1543700209256644`, 0.1216113847941172}, {
       3.2489181709730826`, 0.10007945453521777`}, {3.2489181709730826`, 
       0.10007945453521777`}}, {{3.2489181709730826`, 0.10007945453521777`}, {
       3.1543700209256644`, 0.1216113847941172}, {3.1543700209256644`, 
       0.1216113847941172}, {3.2489181709730826`, 0.10007945453521777`}, {
       3.2489181709730826`, 0.10007945453521777`}}, {{3.2489181709730826`, 
       0.10007945453521777`}, {3.1543700209256644`, 0.1216113847941172}, {
       3.1543700209256644`, 0.1216113847941172}, {3.2489181709730826`, 
       0.10007945453521777`}, {3.2489181709730826`, 0.10007945453521777`}}, {{
       3.2489181709730826`, 0.10007945453521777`}, {3.1543700209256644`, 
       0.1216113847941172}, {3.1543700209256644`, 0.1216113847941172}, {
       3.2489181709730826`, 0.10007945453521777`}, {3.2489181709730826`, 
       0.10007945453521777`}}, {{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}, {{3.1543700209256644`, 
       0.40607192356386657`}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.1543700209256644`, 
       0.40607192356386657`}, {3.1543700209256644`, 0.40607192356386657`}}, {{
       3.1543700209256644`, 0.40607192356386657`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.1543700209256644`, 0.40607192356386657`}, {3.1543700209256644`, 
       0.40607192356386657`}}, {{3.1543700209256644`, 0.40607192356386657`}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.1543700209256644`, 0.40607192356386657`}, {
       3.1543700209256644`, 0.40607192356386657`}}, {{3.2489181709730826`, 
       0.42760385382276594`}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.2489181709730826`, 0.42760385382276594`}}, {{
       3.2489181709730826`, 0.42760385382276594`}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}, {
       3.2489181709730826`, 0.42760385382276594`}, {3.2489181709730826`, 
       0.42760385382276594`}}, {{3.2489181709730826`, 0.42760385382276594`}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}, {3.2489181709730826`, 0.42760385382276594`}, {
       3.2489181709730826`, 0.42760385382276594`}}, {{3.2489181709730826`, 
       0.42760385382276594`}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}, {3.2489181709730826`, 
       0.42760385382276594`}, {3.2489181709730826`, 0.42760385382276594`}}, {{
       3.318603389558205, 0.4060719235638665}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}, {{3.318603389558205, 0.4060719235638665}, {
       3.372093197447488, 0.3564887191303286}, {3.372093197447488, 
       0.3564887191303286}, {3.318603389558205, 0.4060719235638665}, {
       3.318603389558205, 0.4060719235638665}}, {{3.318603389558205, 
       0.4060719235638665}, {3.372093197447488, 0.3564887191303286}, {
       3.372093197447488, 0.3564887191303286}, {3.318603389558205, 
       0.4060719235638665}, {3.318603389558205, 0.4060719235638665}}, {{
       3.318603389558205, 0.4060719235638665}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}, {
       3.318603389558205, 0.4060719235638665}, {3.318603389558205, 
       0.4060719235638665}}, {{3.372093197447488, 0.3564887191303286}, {
       3.4007200738744756`, 0.26384165417899186`}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.372093197447488, 0.3564887191303286}, {
       3.372093197447488, 0.3564887191303286}}, {{3.372093197447488, 
       0.3564887191303286}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.4007200738744756`, 0.26384165417899186`}, {3.372093197447488, 
       0.3564887191303286}, {3.372093197447488, 0.3564887191303286}}, {{
       3.372093197447488, 0.3564887191303286}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.4007200738744756`, 0.26384165417899186`}, {
       3.372093197447488, 0.3564887191303286}, {3.372093197447488, 
       0.3564887191303286}}, {{3.372093197447488, 0.3564887191303286}, {
       3.4007200738744756`, 0.26384165417899186`}, {3.4007200738744756`, 
       0.26384165417899186`}, {3.372093197447488, 0.3564887191303286}, {
       3.372093197447488, 0.3564887191303286}}, {{3.1939818044282577`, 
       0.5966727036078434}, {3.133712121157488, 0.6616909656691962}, {
       3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.7917274897919017}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}, {3.133712121157488, 
       0.7917274897919017}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.1939818044282577`, 
       0.5966727036078434}, {3.1939818044282577`, 0.5966727036078434}}, {{
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}}, {{3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.6420050199093441}, {3.344135048841712, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.344135048841712, 0.5966727036078434}, {3.393039046028779, 
       0.6420050199093441}, {3.4192116710484393`, 0.7267092277305489}, {
       3.4192116710484393`, 0.7267092277305489}}, {{3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}}, {{
       3.1939818044282577`, 0.8567457518532544}, {3.2804241127186877`, 
       0.8764316976131064}, {3.344135048841712, 0.8567457518532544}, {
       3.393039046028779, 0.8114134355517537}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.8114134355517537}, {3.344135048841712, 
       0.8567457518532544}, {3.2804241127186877`, 0.8764316976131064}, {
       3.1939818044282577`, 0.8567457518532544}, {3.1939818044282577`, 
       0.8567457518532544}}, {{3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}}, {{3.1939818044282577`, 
       0.5966727036078434}, {3.133712121157488, 0.6616909656691962}, {
       3.133712121157488, 0.6616909656691962}, {3.1939818044282577`, 
       0.5966727036078434}, {3.1939818044282577`, 0.5966727036078434}}, {{
       3.1939818044282577`, 0.5966727036078434}, {3.133712121157488, 
       0.6616909656691962}, {3.133712121157488, 0.6616909656691962}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}}, {{3.1939818044282577`, 0.5966727036078434}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}, {3.1939818044282577`, 0.5966727036078434}, {
       3.1939818044282577`, 0.5966727036078434}}, {{3.1939818044282577`, 
       0.5966727036078434}, {3.133712121157488, 0.6616909656691962}, {
       3.133712121157488, 0.6616909656691962}, {3.1939818044282577`, 
       0.5966727036078434}, {3.1939818044282577`, 0.5966727036078434}}, {{
       3.133712121157488, 0.6616909656691962}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}}, {{3.133712121157488, 0.6616909656691962}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}, {3.133712121157488, 0.6616909656691962}, {
       3.133712121157488, 0.6616909656691962}}, {{3.133712121157488, 
       0.6616909656691962}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.6616909656691962}, {3.133712121157488, 0.6616909656691962}}, {{
       3.133712121157488, 0.6616909656691962}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.6616909656691962}, {3.133712121157488, 
       0.6616909656691962}}, {{3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}}, {{3.1189051822215306`, 
       0.7267092277305489}, {3.133712121157488, 0.7917274897919017}, {
       3.133712121157488, 0.7917274897919017}, {3.1189051822215306`, 
       0.7267092277305489}, {3.1189051822215306`, 0.7267092277305489}}, {{
       3.1189051822215306`, 0.7267092277305489}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}, {
       3.1189051822215306`, 0.7267092277305489}, {3.1189051822215306`, 
       0.7267092277305489}}, {{3.1189051822215306`, 0.7267092277305489}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}, {3.1189051822215306`, 0.7267092277305489}, {
       3.1189051822215306`, 0.7267092277305489}}, {{3.133712121157488, 
       0.7917274897919017}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}}, {{
       3.133712121157488, 0.7917274897919017}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}, {
       3.133712121157488, 0.7917274897919017}, {3.133712121157488, 
       0.7917274897919017}}, {{3.133712121157488, 0.7917274897919017}, {
       3.1939818044282577`, 0.8567457518532544}, {3.1939818044282577`, 
       0.8567457518532544}, {3.133712121157488, 0.7917274897919017}, {
       3.133712121157488, 0.7917274897919017}}, {{3.133712121157488, 
       0.7917274897919017}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}, {3.133712121157488, 
       0.7917274897919017}, {3.133712121157488, 0.7917274897919017}}, {{
       3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}, {{3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.6420050199093441}, {3.393039046028779, 
       0.6420050199093441}, {3.4192116710484393`, 0.7267092277305489}, {
       3.4192116710484393`, 0.7267092277305489}}, {{3.4192116710484393`, 
       0.7267092277305489}, {3.393039046028779, 0.6420050199093441}, {
       3.393039046028779, 0.6420050199093441}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}}, {{
       3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}}, {{3.393039046028779, 0.6420050199093441}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.393039046028779, 0.6420050199093441}, {
       3.393039046028779, 0.6420050199093441}}, {{3.393039046028779, 
       0.6420050199093441}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}, {3.393039046028779, 
       0.6420050199093441}, {3.393039046028779, 0.6420050199093441}}, {{
       3.393039046028779, 0.6420050199093441}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}, {
       3.393039046028779, 0.6420050199093441}, {3.393039046028779, 
       0.6420050199093441}}, {{3.393039046028779, 0.6420050199093441}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}, {3.393039046028779, 0.6420050199093441}, {
       3.393039046028779, 0.6420050199093441}}, {{3.344135048841712, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}}, {{
       3.344135048841712, 0.5966727036078434}, {3.2804241127186877`, 
       0.5769867578479915}, {3.2804241127186877`, 0.5769867578479915}, {
       3.344135048841712, 0.5966727036078434}, {3.344135048841712, 
       0.5966727036078434}}, {{3.344135048841712, 0.5966727036078434}, {
       3.2804241127186877`, 0.5769867578479915}, {3.2804241127186877`, 
       0.5769867578479915}, {3.344135048841712, 0.5966727036078434}, {
       3.344135048841712, 0.5966727036078434}}, {{3.344135048841712, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}, {3.344135048841712, 
       0.5966727036078434}, {3.344135048841712, 0.5966727036078434}}, {{
       3.2804241127186877`, 0.5769867578479915}, {3.1939818044282577`, 
       0.5966727036078434}, {3.1939818044282577`, 0.5966727036078434}, {
       3.2804241127186877`, 0.5769867578479915}, {3.2804241127186877`, 
       0.5769867578479915}}, {{3.2804241127186877`, 0.5769867578479915}, {
       3.1939818044282577`, 0.5966727036078434}, {3.1939818044282577`, 
       0.5966727036078434}, {3.2804241127186877`, 0.5769867578479915}, {
       3.2804241127186877`, 0.5769867578479915}}, {{3.2804241127186877`, 
       0.5769867578479915}, {3.1939818044282577`, 0.5966727036078434}, {
       3.1939818044282577`, 0.5966727036078434}, {3.2804241127186877`, 
       0.5769867578479915}, {3.2804241127186877`, 0.5769867578479915}}, {{
       3.2804241127186877`, 0.5769867578479915}, {3.1939818044282577`, 
       0.5966727036078434}, {3.1939818044282577`, 0.5966727036078434}, {
       3.2804241127186877`, 0.5769867578479915}, {3.2804241127186877`, 
       0.5769867578479915}}, {{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}, {{3.1939818044282577`, 
       0.8567457518532544}, {3.2804241127186877`, 0.8764316976131064}, {
       3.2804241127186877`, 0.8764316976131064}, {3.1939818044282577`, 
       0.8567457518532544}, {3.1939818044282577`, 0.8567457518532544}}, {{
       3.1939818044282577`, 0.8567457518532544}, {3.2804241127186877`, 
       0.8764316976131064}, {3.2804241127186877`, 0.8764316976131064}, {
       3.1939818044282577`, 0.8567457518532544}, {3.1939818044282577`, 
       0.8567457518532544}}, {{3.1939818044282577`, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}, {3.1939818044282577`, 0.8567457518532544}, {
       3.1939818044282577`, 0.8567457518532544}}, {{3.2804241127186877`, 
       0.8764316976131064}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.2804241127186877`, 
       0.8764316976131064}, {3.2804241127186877`, 0.8764316976131064}}, {{
       3.2804241127186877`, 0.8764316976131064}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}, {
       3.2804241127186877`, 0.8764316976131064}, {3.2804241127186877`, 
       0.8764316976131064}}, {{3.2804241127186877`, 0.8764316976131064}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}, {3.2804241127186877`, 0.8764316976131064}, {
       3.2804241127186877`, 0.8764316976131064}}, {{3.2804241127186877`, 
       0.8764316976131064}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}, {3.2804241127186877`, 
       0.8764316976131064}, {3.2804241127186877`, 0.8764316976131064}}, {{
       3.344135048841712, 0.8567457518532544}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}, {{3.344135048841712, 0.8567457518532544}, {
       3.393039046028779, 0.8114134355517537}, {3.393039046028779, 
       0.8114134355517537}, {3.344135048841712, 0.8567457518532544}, {
       3.344135048841712, 0.8567457518532544}}, {{3.344135048841712, 
       0.8567457518532544}, {3.393039046028779, 0.8114134355517537}, {
       3.393039046028779, 0.8114134355517537}, {3.344135048841712, 
       0.8567457518532544}, {3.344135048841712, 0.8567457518532544}}, {{
       3.344135048841712, 0.8567457518532544}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}, {
       3.344135048841712, 0.8567457518532544}, {3.344135048841712, 
       0.8567457518532544}}, {{3.393039046028779, 0.8114134355517537}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}, {3.393039046028779, 0.8114134355517537}, {
       3.393039046028779, 0.8114134355517537}}, {{3.393039046028779, 
       0.8114134355517537}, {3.4192116710484393`, 0.7267092277305489}, {
       3.4192116710484393`, 0.7267092277305489}, {3.393039046028779, 
       0.8114134355517537}, {3.393039046028779, 0.8114134355517537}}, {{
       3.393039046028779, 0.8114134355517537}, {3.4192116710484393`, 
       0.7267092277305489}, {3.4192116710484393`, 0.7267092277305489}, {
       3.393039046028779, 0.8114134355517537}, {3.393039046028779, 
       0.8114134355517537}}, {{3.393039046028779, 0.8114134355517537}, {
       3.4192116710484393`, 0.7267092277305489}, {3.4192116710484393`, 
       0.7267092277305489}, {3.393039046028779, 0.8114134355517537}, {
       3.393039046028779, 0.8114134355517537}}, {{3.2131200024055504`, 
       1.155328504564207}, {3.156857698012141, 1.2160236509911746`}, {
       3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.3374139438451094`}, {3.2131200024055504`, 1.398109090272077}, {
       3.2131200024055504`, 1.398109090272077}, {3.156857698012141, 
       1.3374139438451094`}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.2131200024055504`, 
       1.155328504564207}, {3.2131200024055504`, 1.155328504564207}}, {{
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}, {{3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.1976466393245127`}, {3.3532894389180044`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.3532894389180044`, 1.155328504564207}, {3.398941770678766, 
       1.1976466393245127`}, {3.423374157174231, 1.276718797418142}, {
       3.423374157174231, 1.276718797418142}}, {{3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}}, {{
       3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`, 
       1.4164861019387387`}, {3.3532894389180044`, 1.398109090272077}, {
       3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}, {{3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}}, {{3.2131200024055504`, 
       1.155328504564207}, {3.156857698012141, 1.2160236509911746`}, {
       3.156857698012141, 1.2160236509911746`}, {3.2131200024055504`, 
       1.155328504564207}, {3.2131200024055504`, 1.155328504564207}}, {{
       3.2131200024055504`, 1.155328504564207}, {3.156857698012141, 
       1.2160236509911746`}, {3.156857698012141, 1.2160236509911746`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}}, {{3.2131200024055504`, 1.155328504564207}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}, {3.2131200024055504`, 1.155328504564207}, {
       3.2131200024055504`, 1.155328504564207}}, {{3.2131200024055504`, 
       1.155328504564207}, {3.156857698012141, 1.2160236509911746`}, {
       3.156857698012141, 1.2160236509911746`}, {3.2131200024055504`, 
       1.155328504564207}, {3.2131200024055504`, 1.155328504564207}}, {{
       3.156857698012141, 1.2160236509911746`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}}, {{3.156857698012141, 1.2160236509911746`}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}, {3.156857698012141, 1.2160236509911746`}, {
       3.156857698012141, 1.2160236509911746`}}, {{3.156857698012141, 
       1.2160236509911746`}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.2160236509911746`}, {3.156857698012141, 1.2160236509911746`}}, {{
       3.156857698012141, 1.2160236509911746`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.2160236509911746`}, {3.156857698012141, 
       1.2160236509911746`}}, {{3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}}, {{3.143035284149324, 
       1.276718797418142}, {3.156857698012141, 1.3374139438451094`}, {
       3.156857698012141, 1.3374139438451094`}, {3.143035284149324, 
       1.276718797418142}, {3.143035284149324, 1.276718797418142}}, {{
       3.143035284149324, 1.276718797418142}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}, {
       3.143035284149324, 1.276718797418142}, {3.143035284149324, 
       1.276718797418142}}, {{3.143035284149324, 1.276718797418142}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}, {3.143035284149324, 1.276718797418142}, {
       3.143035284149324, 1.276718797418142}}, {{3.156857698012141, 
       1.3374139438451094`}, {3.2131200024055504`, 1.398109090272077}, {
       3.2131200024055504`, 1.398109090272077}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}}, {{
       3.156857698012141, 1.3374139438451094`}, {3.2131200024055504`, 
       1.398109090272077}, {3.2131200024055504`, 1.398109090272077}, {
       3.156857698012141, 1.3374139438451094`}, {3.156857698012141, 
       1.3374139438451094`}}, {{3.156857698012141, 1.3374139438451094`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}, {3.156857698012141, 1.3374139438451094`}, {
       3.156857698012141, 1.3374139438451094`}}, {{3.156857698012141, 
       1.3374139438451094`}, {3.2131200024055504`, 1.398109090272077}, {
       3.2131200024055504`, 1.398109090272077}, {3.156857698012141, 
       1.3374139438451094`}, {3.156857698012141, 1.3374139438451094`}}, {{
       3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}, {{3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.1976466393245127`}, {3.398941770678766, 
       1.1976466393245127`}, {3.423374157174231, 1.276718797418142}, {
       3.423374157174231, 1.276718797418142}}, {{3.423374157174231, 
       1.276718797418142}, {3.398941770678766, 1.1976466393245127`}, {
       3.398941770678766, 1.1976466393245127`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}}, {{
       3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}}, {{3.398941770678766, 1.1976466393245127`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.398941770678766, 1.1976466393245127`}, {
       3.398941770678766, 1.1976466393245127`}}, {{3.398941770678766, 
       1.1976466393245127`}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}, {3.398941770678766, 
       1.1976466393245127`}, {3.398941770678766, 1.1976466393245127`}}, {{
       3.398941770678766, 1.1976466393245127`}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}, {
       3.398941770678766, 1.1976466393245127`}, {3.398941770678766, 
       1.1976466393245127`}}, {{3.398941770678766, 1.1976466393245127`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}, {3.398941770678766, 1.1976466393245127`}, {
       3.398941770678766, 1.1976466393245127`}}, {{3.3532894389180044`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}}, {{
       3.3532894389180044`, 1.155328504564207}, {3.2938146932944257`, 
       1.1369514928975453`}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.3532894389180044`, 1.155328504564207}, {3.3532894389180044`, 
       1.155328504564207}}, {{3.3532894389180044`, 1.155328504564207}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.2938146932944257`, 
       1.1369514928975453`}, {3.3532894389180044`, 1.155328504564207}, {
       3.3532894389180044`, 1.155328504564207}}, {{3.3532894389180044`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.3532894389180044`, 
       1.155328504564207}, {3.3532894389180044`, 1.155328504564207}}, {{
       3.2938146932944257`, 1.1369514928975453`}, {3.2131200024055504`, 
       1.155328504564207}, {3.2131200024055504`, 1.155328504564207}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.2938146932944257`, 
       1.1369514928975453`}}, {{3.2938146932944257`, 1.1369514928975453`}, {
       3.2131200024055504`, 1.155328504564207}, {3.2131200024055504`, 
       1.155328504564207}, {3.2938146932944257`, 1.1369514928975453`}, {
       3.2938146932944257`, 1.1369514928975453`}}, {{3.2938146932944257`, 
       1.1369514928975453`}, {3.2131200024055504`, 1.155328504564207}, {
       3.2131200024055504`, 1.155328504564207}, {3.2938146932944257`, 
       1.1369514928975453`}, {3.2938146932944257`, 1.1369514928975453`}}, {{
       3.2938146932944257`, 1.1369514928975453`}, {3.2131200024055504`, 
       1.155328504564207}, {3.2131200024055504`, 1.155328504564207}, {
       3.2938146932944257`, 1.1369514928975453`}, {3.2938146932944257`, 
       1.1369514928975453`}}, {{3.2131200024055504`, 1.398109090272077}, {
       3.2938146932944257`, 1.4164861019387387`}, {3.2938146932944257`, 
       1.4164861019387387`}, {3.2131200024055504`, 1.398109090272077}, {
       3.2131200024055504`, 1.398109090272077}}, {{3.2131200024055504`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2938146932944257`, 1.4164861019387387`}, {3.2131200024055504`, 
       1.398109090272077}, {3.2131200024055504`, 1.398109090272077}}, {{
       3.2131200024055504`, 1.398109090272077}, {3.2938146932944257`, 
       1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2131200024055504`, 1.398109090272077}, {3.2131200024055504`, 
       1.398109090272077}}, {{3.2131200024055504`, 1.398109090272077}, {
       3.2938146932944257`, 1.4164861019387387`}, {3.2938146932944257`, 
       1.4164861019387387`}, {3.2131200024055504`, 1.398109090272077}, {
       3.2131200024055504`, 1.398109090272077}}, {{3.2938146932944257`, 
       1.4164861019387387`}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.2938146932944257`, 
       1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}}, {{
       3.2938146932944257`, 1.4164861019387387`}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}, {
       3.2938146932944257`, 1.4164861019387387`}, {3.2938146932944257`, 
       1.4164861019387387`}}, {{3.2938146932944257`, 1.4164861019387387`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}, {3.2938146932944257`, 1.4164861019387387`}, {
       3.2938146932944257`, 1.4164861019387387`}}, {{3.2938146932944257`, 
       1.4164861019387387`}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}, {3.2938146932944257`, 
       1.4164861019387387`}, {3.2938146932944257`, 1.4164861019387387`}}, {{
       3.3532894389180044`, 1.398109090272077}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}, {{3.3532894389180044`, 1.398109090272077}, {
       3.398941770678766, 1.3557909555117713`}, {3.398941770678766, 
       1.3557909555117713`}, {3.3532894389180044`, 1.398109090272077}, {
       3.3532894389180044`, 1.398109090272077}}, {{3.3532894389180044`, 
       1.398109090272077}, {3.398941770678766, 1.3557909555117713`}, {
       3.398941770678766, 1.3557909555117713`}, {3.3532894389180044`, 
       1.398109090272077}, {3.3532894389180044`, 1.398109090272077}}, {{
       3.3532894389180044`, 1.398109090272077}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}, {
       3.3532894389180044`, 1.398109090272077}, {3.3532894389180044`, 
       1.398109090272077}}, {{3.398941770678766, 1.3557909555117713`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}, {3.398941770678766, 1.3557909555117713`}, {
       3.398941770678766, 1.3557909555117713`}}, {{3.398941770678766, 
       1.3557909555117713`}, {3.423374157174231, 1.276718797418142}, {
       3.423374157174231, 1.276718797418142}, {3.398941770678766, 
       1.3557909555117713`}, {3.398941770678766, 1.3557909555117713`}}, {{
       3.398941770678766, 1.3557909555117713`}, {3.423374157174231, 
       1.276718797418142}, {3.423374157174231, 1.276718797418142}, {
       3.398941770678766, 1.3557909555117713`}, {3.398941770678766, 
       1.3557909555117713`}}, {{3.398941770678766, 1.3557909555117713`}, {
       3.423374157174231, 1.276718797418142}, {3.423374157174231, 
       1.276718797418142}, {3.398941770678766, 1.3557909555117713`}, {
       3.398941770678766, 1.3557909555117713`}}, {{3.187547313631859, 
       1.6218574822294558`}, {3.120122808958755, 1.694594285814401}, {
       3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.8400678929842909`}, {3.187547313631859, 1.912804696569236}, {
       3.187547313631859, 1.912804696569236}, {3.120122808958755, 
       1.8400678929842909`}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.187547313631859, 
       1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}}, {{
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}, {{3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.6725713537223823`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.2842514856630527`, 1.5998345501374374`}, {
       3.1875473136318595`, 1.6218574822294558`}, {3.1875473136318595`, 
       1.6218574822294558`}, {3.284251485663053, 1.5998345501374374`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.410235325052336, 
       1.6725713537223823`}, {3.439514992410425, 1.767331089399346}, {
       3.439514992410425, 1.767331089399346}}, {{3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}}, {{
       3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.3555257661509033`, 1.912804696569236}, {
       3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.3555257661509033`, 
       1.912804696569236}, {3.2842514856630527`, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}, {{3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}}, {{3.187547313631859, 
       1.6218574822294558`}, {3.120122808958755, 1.694594285814401}, {
       3.120122808958755, 1.694594285814401}, {3.187547313631859, 
       1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}}, {{
       3.187547313631859, 1.6218574822294558`}, {3.120122808958755, 
       1.694594285814401}, {3.120122808958755, 1.694594285814401}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}}, {{3.187547313631859, 1.6218574822294558`}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}, {3.187547313631859, 1.6218574822294558`}, {
       3.187547313631859, 1.6218574822294558`}}, {{3.187547313631859, 
       1.6218574822294558`}, {3.120122808958755, 1.694594285814401}, {
       3.120122808958755, 1.694594285814401}, {3.187547313631859, 
       1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}}, {{
       3.120122808958755, 1.694594285814401}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}}, {{3.120122808958755, 1.694594285814401}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}, {3.120122808958755, 1.694594285814401}, {
       3.120122808958755, 1.694594285814401}}, {{3.120122808958755, 
       1.694594285814401}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.694594285814401}, {3.120122808958755, 1.694594285814401}}, {{
       3.120122808958755, 1.694594285814401}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.694594285814401}, {3.120122808958755, 
       1.694594285814401}}, {{3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}}, {{3.1035580873723374`, 
       1.767331089399346}, {3.120122808958755, 1.8400678929842909`}, {
       3.120122808958755, 1.8400678929842909`}, {3.1035580873723374`, 
       1.767331089399346}, {3.1035580873723374`, 1.767331089399346}}, {{
       3.1035580873723374`, 1.767331089399346}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}, {
       3.1035580873723374`, 1.767331089399346}, {3.1035580873723374`, 
       1.767331089399346}}, {{3.1035580873723374`, 1.767331089399346}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}, {3.1035580873723374`, 1.767331089399346}, {
       3.1035580873723374`, 1.767331089399346}}, {{3.120122808958755, 
       1.8400678929842909`}, {3.1875473136318595`, 1.912804696569236}, {
       3.1875473136318595`, 1.912804696569236}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}}, {{
       3.120122808958755, 1.8400678929842909`}, {3.1875473136318595`, 
       1.912804696569236}, {3.1875473136318595`, 1.912804696569236}, {
       3.120122808958755, 1.8400678929842909`}, {3.120122808958755, 
       1.8400678929842909`}}, {{3.120122808958755, 1.8400678929842909`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}, {3.120122808958755, 1.8400678929842909`}, {
       3.120122808958755, 1.8400678929842909`}}, {{3.120122808958755, 
       1.8400678929842909`}, {3.1875473136318595`, 1.912804696569236}, {
       3.1875473136318595`, 1.912804696569236}, {3.120122808958755, 
       1.8400678929842909`}, {3.120122808958755, 1.8400678929842909`}}, {{
       3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}, {{3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.6725713537223823`}, {3.410235325052336, 
       1.6725713537223823`}, {3.439514992410425, 1.767331089399346}, {
       3.439514992410425, 1.767331089399346}}, {{3.439514992410425, 
       1.767331089399346}, {3.410235325052336, 1.6725713537223823`}, {
       3.410235325052336, 1.6725713537223823`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}}, {{
       3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}}, {{3.410235325052336, 1.6725713537223823`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.410235325052336, 1.6725713537223823`}, {
       3.410235325052336, 1.6725713537223823`}}, {{3.410235325052336, 
       1.6725713537223823`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.410235325052336, 
       1.6725713537223823`}, {3.410235325052336, 1.6725713537223823`}}, {{
       3.410235325052336, 1.6725713537223823`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.410235325052336, 1.6725713537223823`}, {3.410235325052336, 
       1.6725713537223823`}}, {{3.410235325052336, 1.6725713537223823`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.410235325052336, 1.6725713537223823`}, {
       3.410235325052336, 1.6725713537223823`}}, {{3.3555257661509033`, 
       1.6218574822294558`}, {3.284251485663053, 1.5998345501374374`}, {
       3.284251485663053, 1.5998345501374374`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}}, {{
       3.3555257661509033`, 1.6218574822294558`}, {3.284251485663053, 
       1.5998345501374374`}, {3.284251485663053, 1.5998345501374374`}, {
       3.3555257661509033`, 1.6218574822294558`}, {3.3555257661509033`, 
       1.6218574822294558`}}, {{3.3555257661509033`, 1.6218574822294558`}, {
       3.284251485663053, 1.5998345501374374`}, {3.284251485663053, 
       1.5998345501374374`}, {3.3555257661509033`, 1.6218574822294558`}, {
       3.3555257661509033`, 1.6218574822294558`}}, {{3.3555257661509033`, 
       1.6218574822294558`}, {3.284251485663053, 1.5998345501374374`}, {
       3.284251485663053, 1.5998345501374374`}, {3.3555257661509033`, 
       1.6218574822294558`}, {3.3555257661509033`, 1.6218574822294558`}}, {{
       3.2842514856630527`, 1.5998345501374374`}, {3.187547313631859, 
       1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.2842514856630527`, 
       1.5998345501374374`}}, {{3.2842514856630527`, 1.5998345501374374`}, {
       3.187547313631859, 1.6218574822294558`}, {3.187547313631859, 
       1.6218574822294558`}, {3.2842514856630527`, 1.5998345501374374`}, {
       3.2842514856630527`, 1.5998345501374374`}}, {{3.2842514856630527`, 
       1.5998345501374374`}, {3.187547313631859, 1.6218574822294558`}, {
       3.187547313631859, 1.6218574822294558`}, {3.2842514856630527`, 
       1.5998345501374374`}, {3.2842514856630527`, 1.5998345501374374`}}, {{
       3.2842514856630527`, 1.5998345501374374`}, {3.187547313631859, 
       1.6218574822294558`}, {3.187547313631859, 1.6218574822294558`}, {
       3.2842514856630527`, 1.5998345501374374`}, {3.2842514856630527`, 
       1.5998345501374374`}}, {{3.1875473136318595`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}, {3.1875473136318595`, 1.912804696569236}, {
       3.1875473136318595`, 1.912804696569236}}, {{3.1875473136318595`, 
       1.912804696569236}, {3.284251485663053, 1.9348276286612545`}, {
       3.284251485663053, 1.9348276286612545`}, {3.1875473136318595`, 
       1.912804696569236}, {3.1875473136318595`, 1.912804696569236}}, {{
       3.1875473136318595`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}, {
       3.1875473136318595`, 1.912804696569236}, {3.1875473136318595`, 
       1.912804696569236}}, {{3.1875473136318595`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}, {3.1875473136318595`, 1.912804696569236}, {
       3.1875473136318595`, 1.912804696569236}}, {{3.284251485663053, 
       1.9348276286612545`}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}}, {{
       3.284251485663053, 1.9348276286612545`}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}, {
       3.284251485663053, 1.9348276286612545`}, {3.284251485663053, 
       1.9348276286612545`}}, {{3.284251485663053, 1.9348276286612545`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}, {3.284251485663053, 1.9348276286612545`}, {
       3.284251485663053, 1.9348276286612545`}}, {{3.284251485663053, 
       1.9348276286612545`}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}, {3.284251485663053, 
       1.9348276286612545`}, {3.284251485663053, 1.9348276286612545`}}, {{
       3.3555257661509033`, 1.912804696569236}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}, {{3.3555257661509033`, 1.912804696569236}, {
       3.410235325052336, 1.8620908250763095`}, {3.410235325052336, 
       1.8620908250763095`}, {3.3555257661509033`, 1.912804696569236}, {
       3.3555257661509033`, 1.912804696569236}}, {{3.3555257661509033`, 
       1.912804696569236}, {3.410235325052336, 1.8620908250763095`}, {
       3.410235325052336, 1.8620908250763095`}, {3.3555257661509033`, 
       1.912804696569236}, {3.3555257661509033`, 1.912804696569236}}, {{
       3.3555257661509033`, 1.912804696569236}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}, {
       3.3555257661509033`, 1.912804696569236}, {3.3555257661509033`, 
       1.912804696569236}}, {{3.410235325052336, 1.8620908250763095`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}, {3.410235325052336, 1.8620908250763095`}, {
       3.410235325052336, 1.8620908250763095`}}, {{3.410235325052336, 
       1.8620908250763095`}, {3.439514992410425, 1.767331089399346}, {
       3.439514992410425, 1.767331089399346}, {3.410235325052336, 
       1.8620908250763095`}, {3.410235325052336, 1.8620908250763095`}}, {{
       3.410235325052336, 1.8620908250763095`}, {3.439514992410425, 
       1.767331089399346}, {3.439514992410425, 1.767331089399346}, {
       3.410235325052336, 1.8620908250763095`}, {3.410235325052336, 
       1.8620908250763095`}}, {{3.410235325052336, 1.8620908250763095`}, {
       3.439514992410425, 1.767331089399346}, {3.439514992410425, 
       1.767331089399346}, {3.410235325052336, 1.8620908250763095`}, {
       3.410235325052336, 1.8620908250763095`}}, {{3.2139840262737485`, 
       2.0903156208758826`}, {3.1490246590792523`, 2.1603930616451756`}, {
       3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}}, {{
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}, {{3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.139175319825627}, {3.375820943442834, 
       2.0903156208758826`}, {3.3071525538094035`, 2.069097879056334}, {
       3.2139840262737485`, 2.0903156208758826`}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.3071525538094035`, 2.069097879056334}, {
       3.375820943442834, 2.0903156208758826`}, {3.428530241686218, 
       2.139175319825627}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.4567394020273765`, 2.2304705024144686`}}, {{3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}}, {{
       3.2139840262737485`, 2.3706253839530547`}, {3.3071525538094035`, 
       2.391843125772603}, {3.375820943442834, 2.3706253839530547`}, {
       3.428530241686218, 2.32176568500331}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.32176568500331}, {3.375820943442834, 
       2.3706253839530547`}, {3.3071525538094035`, 2.391843125772603}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}}, {{3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}}, {{3.2139840262737485`, 
       2.0903156208758826`}, {3.1490246590792523`, 2.1603930616451756`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}}, {{
       3.2139840262737485`, 2.0903156208758826`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.1490246590792523`, 2.1603930616451756`}, {
       3.2139840262737485`, 2.0903156208758826`}, {3.2139840262737485`, 
       2.0903156208758826`}}, {{3.2139840262737485`, 2.0903156208758826`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}}, {{3.2139840262737485`, 
       2.0903156208758826`}, {3.1490246590792523`, 2.1603930616451756`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}}, {{
       3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}}, {{3.1490246590792523`, 2.1603930616451756`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}, {3.1490246590792523`, 2.1603930616451756`}, {
       3.1490246590792523`, 2.1603930616451756`}}, {{3.1490246590792523`, 
       2.1603930616451756`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`, 
       2.1603930616451756`}, {3.1490246590792523`, 2.1603930616451756`}}, {{
       3.1490246590792523`, 2.1603930616451756`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.1603930616451756`}, {3.1490246590792523`, 
       2.1603930616451756`}}, {{3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.3005479431837617`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}}, {{3.133065567689206, 
       2.2304705024144686`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.1490246590792523`, 2.3005479431837617`}, {3.133065567689206, 
       2.2304705024144686`}, {3.133065567689206, 2.2304705024144686`}}, {{
       3.133065567689206, 2.2304705024144686`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.133065567689206, 2.2304705024144686`}, {3.133065567689206, 
       2.2304705024144686`}}, {{3.133065567689206, 2.2304705024144686`}, {
       3.1490246590792523`, 2.3005479431837617`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.133065567689206, 2.2304705024144686`}, {
       3.133065567689206, 2.2304705024144686`}}, {{3.1490246590792523`, 
       2.3005479431837617`}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}}, {{
       3.1490246590792523`, 2.3005479431837617`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.1490246590792523`, 2.3005479431837617`}, {3.1490246590792523`, 
       2.3005479431837617`}}, {{3.1490246590792523`, 2.3005479431837617`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.1490246590792523`, 2.3005479431837617`}, {
       3.1490246590792523`, 2.3005479431837617`}}, {{3.1490246590792523`, 
       2.3005479431837617`}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.1490246590792523`, 
       2.3005479431837617`}, {3.1490246590792523`, 2.3005479431837617`}}, {{
       3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218, 
       2.139175319825627}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}, {{3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.139175319825627}, {3.428530241686218, 
       2.139175319825627}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.4567394020273765`, 2.2304705024144686`}}, {{3.4567394020273765`, 
       2.2304705024144686`}, {3.428530241686218, 2.139175319825627}, {
       3.428530241686218, 2.139175319825627}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}}, {{
       3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218, 
       2.139175319825627}, {3.428530241686218, 2.139175319825627}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}}, {{3.428530241686218, 2.139175319825627}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.428530241686218, 2.139175319825627}, {
       3.428530241686218, 2.139175319825627}}, {{3.428530241686218, 
       2.139175319825627}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}, {3.428530241686218, 
       2.139175319825627}, {3.428530241686218, 2.139175319825627}}, {{
       3.428530241686218, 2.139175319825627}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}, {
       3.428530241686218, 2.139175319825627}, {3.428530241686218, 
       2.139175319825627}}, {{3.428530241686218, 2.139175319825627}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}, {3.428530241686218, 2.139175319825627}, {
       3.428530241686218, 2.139175319825627}}, {{3.375820943442834, 
       2.0903156208758826`}, {3.3071525538094035`, 2.069097879056334}, {
       3.3071525538094035`, 2.069097879056334}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}}, {{
       3.375820943442834, 2.0903156208758826`}, {3.3071525538094035`, 
       2.069097879056334}, {3.3071525538094035`, 2.069097879056334}, {
       3.375820943442834, 2.0903156208758826`}, {3.375820943442834, 
       2.0903156208758826`}}, {{3.375820943442834, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}, {3.375820943442834, 2.0903156208758826`}, {
       3.375820943442834, 2.0903156208758826`}}, {{3.375820943442834, 
       2.0903156208758826`}, {3.3071525538094035`, 2.069097879056334}, {
       3.3071525538094035`, 2.069097879056334}, {3.375820943442834, 
       2.0903156208758826`}, {3.375820943442834, 2.0903156208758826`}}, {{
       3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}}, {{3.3071525538094035`, 2.069097879056334}, {
       3.2139840262737485`, 2.0903156208758826`}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.3071525538094035`, 2.069097879056334}, {
       3.3071525538094035`, 2.069097879056334}}, {{3.3071525538094035`, 
       2.069097879056334}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.2139840262737485`, 2.0903156208758826`}, {3.3071525538094035`, 
       2.069097879056334}, {3.3071525538094035`, 2.069097879056334}}, {{
       3.3071525538094035`, 2.069097879056334}, {3.2139840262737485`, 
       2.0903156208758826`}, {3.2139840262737485`, 2.0903156208758826`}, {
       3.3071525538094035`, 2.069097879056334}, {3.3071525538094035`, 
       2.069097879056334}}, {{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}, {{3.2139840262737485`, 
       2.3706253839530547`}, {3.3071525538094035`, 2.391843125772603}, {
       3.3071525538094035`, 2.391843125772603}, {3.2139840262737485`, 
       2.3706253839530547`}, {3.2139840262737485`, 2.3706253839530547`}}, {{
       3.2139840262737485`, 2.3706253839530547`}, {3.3071525538094035`, 
       2.391843125772603}, {3.3071525538094035`, 2.391843125772603}, {
       3.2139840262737485`, 2.3706253839530547`}, {3.2139840262737485`, 
       2.3706253839530547`}}, {{3.2139840262737485`, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}, {3.2139840262737485`, 2.3706253839530547`}, {
       3.2139840262737485`, 2.3706253839530547`}}, {{3.3071525538094035`, 
       2.391843125772603}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.3071525538094035`, 
       2.391843125772603}, {3.3071525538094035`, 2.391843125772603}}, {{
       3.3071525538094035`, 2.391843125772603}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}, {
       3.3071525538094035`, 2.391843125772603}, {3.3071525538094035`, 
       2.391843125772603}}, {{3.3071525538094035`, 2.391843125772603}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}, {3.3071525538094035`, 2.391843125772603}, {
       3.3071525538094035`, 2.391843125772603}}, {{3.3071525538094035`, 
       2.391843125772603}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}, {3.3071525538094035`, 
       2.391843125772603}, {3.3071525538094035`, 2.391843125772603}}, {{
       3.375820943442834, 2.3706253839530547`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}, {{3.375820943442834, 2.3706253839530547`}, {
       3.428530241686218, 2.32176568500331}, {3.428530241686218, 
       2.32176568500331}, {3.375820943442834, 2.3706253839530547`}, {
       3.375820943442834, 2.3706253839530547`}}, {{3.375820943442834, 
       2.3706253839530547`}, {3.428530241686218, 2.32176568500331}, {
       3.428530241686218, 2.32176568500331}, {3.375820943442834, 
       2.3706253839530547`}, {3.375820943442834, 2.3706253839530547`}}, {{
       3.375820943442834, 2.3706253839530547`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}, {
       3.375820943442834, 2.3706253839530547`}, {3.375820943442834, 
       2.3706253839530547`}}, {{3.428530241686218, 2.32176568500331}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.428530241686218, 2.32176568500331}, {
       3.428530241686218, 2.32176568500331}}, {{3.428530241686218, 
       2.32176568500331}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.428530241686218, 
       2.32176568500331}, {3.428530241686218, 2.32176568500331}}, {{
       3.428530241686218, 2.32176568500331}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.4567394020273765`, 2.2304705024144686`}, {
       3.428530241686218, 2.32176568500331}, {3.428530241686218, 
       2.32176568500331}}, {{3.428530241686218, 2.32176568500331}, {
       3.4567394020273765`, 2.2304705024144686`}, {3.4567394020273765`, 
       2.2304705024144686`}, {3.428530241686218, 2.32176568500331}, {
       3.428530241686218, 2.32176568500331}}, {{3.2161885240513723`, 
       2.626792816072176}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1526303469981327`, 
       2.832490373493734}, {3.2161885240513723`, 2.9010562259675865`}, {
       3.2161885240513723`, 2.9010562259675865`}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.6953586685460285`}, {3.2161885240513723`, 
       2.626792816072176}, {3.2161885240513723`, 2.626792816072176}}, {{
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}}, {{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.216188524051373, 2.626792816072176}, {3.216188524051373, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}, {{3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}}, {{
       3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.374534577583353, 2.9010562259675865`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.374534577583353, 
       2.9010562259675865`}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}, {{3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}}, {{3.2161885240513723`, 
       2.626792816072176}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}, {3.2161885240513723`, 
       2.626792816072176}, {3.2161885240513723`, 2.626792816072176}}, {{
       3.2161885240513723`, 2.626792816072176}, {3.1526303469981327`, 
       2.6953586685460285`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}}, {{3.2161885240513723`, 2.626792816072176}, {
       3.1526303469981327`, 2.6953586685460285`}, {3.1526303469981327`, 
       2.6953586685460285`}, {3.2161885240513723`, 2.626792816072176}, {
       3.2161885240513723`, 2.626792816072176}}, {{3.2161885240513723`, 
       2.626792816072176}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}, {3.2161885240513723`, 
       2.626792816072176}, {3.2161885240513723`, 2.626792816072176}}, {{
       3.1526303469981327`, 2.6953586685460285`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.6953586685460285`}, {3.1526303469981327`, 
       2.6953586685460285`}}, {{3.1526303469981327`, 2.6953586685460285`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.6953586685460285`}, {
       3.1526303469981327`, 2.6953586685460285`}}, {{3.1526303469981327`, 
       2.6953586685460285`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1526303469981327`, 
       2.6953586685460285`}, {3.1526303469981327`, 2.6953586685460285`}}, {{
       3.1526303469981327`, 2.6953586685460285`}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.6953586685460285`}, {3.1526303469981327`, 
       2.6953586685460285`}}, {{3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}, {{3.1370154972853825`, 
       2.7639245210198813`}, {3.1526303469981327`, 2.832490373493734}, {
       3.1526303469981327`, 2.832490373493734}, {3.1370154972853825`, 
       2.7639245210198813`}, {3.1370154972853825`, 2.7639245210198813`}}, {{
       3.1370154972853825`, 2.7639245210198813`}, {3.1526303469981327`, 
       2.832490373493734}, {3.1526303469981327`, 2.832490373493734}, {
       3.1370154972853825`, 2.7639245210198813`}, {3.1370154972853825`, 
       2.7639245210198813`}}, {{3.1370154972853825`, 2.7639245210198813`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}, {3.1370154972853825`, 2.7639245210198813`}, {
       3.1370154972853825`, 2.7639245210198813`}}, {{3.1526303469981327`, 
       2.832490373493734}, {3.216188524051373, 2.9010562259675865`}, {
       3.216188524051373, 2.9010562259675865`}, {3.1526303469981327`, 
       2.832490373493734}, {3.1526303469981327`, 2.832490373493734}}, {{
       3.1526303469981327`, 2.832490373493734}, {3.216188524051373, 
       2.9010562259675865`}, {3.216188524051373, 2.9010562259675865`}, {
       3.1526303469981327`, 2.832490373493734}, {3.1526303469981327`, 
       2.832490373493734}}, {{3.1526303469981327`, 2.832490373493734}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}, {3.1526303469981327`, 2.832490373493734}, {
       3.1526303469981327`, 2.832490373493734}}, {{3.1526303469981327`, 
       2.832490373493734}, {3.216188524051373, 2.9010562259675865`}, {
       3.216188524051373, 2.9010562259675865`}, {3.1526303469981327`, 
       2.832490373493734}, {3.1526303469981327`, 2.832490373493734}}, {{
       3.4537076043493427`, 2.7639245210198813`}, {3.4261069228014702`, 
       2.67459859883662}, {3.4261069228014702`, 2.67459859883662}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}}, {{3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}}, {{3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.67459859883662}, {
       3.4261069228014702`, 2.67459859883662}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4537076043493427`, 2.7639245210198813`}}, {{
       3.4537076043493427`, 2.7639245210198813`}, {3.4261069228014702`, 
       2.67459859883662}, {3.4261069228014702`, 2.67459859883662}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}}, {{3.4261069228014702`, 2.67459859883662}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.4261069228014702`, 2.67459859883662}, {
       3.4261069228014702`, 2.67459859883662}}, {{3.4261069228014702`, 
       2.67459859883662}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}, {3.4261069228014702`, 
       2.67459859883662}, {3.4261069228014702`, 2.67459859883662}}, {{
       3.4261069228014702`, 2.67459859883662}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}, {
       3.4261069228014702`, 2.67459859883662}, {3.4261069228014702`, 
       2.67459859883662}}, {{3.4261069228014702`, 2.67459859883662}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}, {3.4261069228014702`, 2.67459859883662}, {
       3.4261069228014702`, 2.67459859883662}}, {{3.374534577583353, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.307347382652485, 2.6060327463627675`}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}}, {{
       3.374534577583353, 2.626792816072176}, {3.307347382652485, 
       2.6060327463627675`}, {3.307347382652485, 2.6060327463627675`}, {
       3.374534577583353, 2.626792816072176}, {3.374534577583353, 
       2.626792816072176}}, {{3.374534577583353, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}, {3.374534577583353, 2.626792816072176}, {
       3.374534577583353, 2.626792816072176}}, {{3.374534577583353, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.307347382652485, 2.6060327463627675`}, {3.374534577583353, 
       2.626792816072176}, {3.374534577583353, 2.626792816072176}}, {{
       3.307347382652485, 2.6060327463627675`}, {3.2161885240513723`, 
       2.626792816072176}, {3.2161885240513723`, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}}, {{3.307347382652485, 2.6060327463627675`}, {
       3.2161885240513723`, 2.626792816072176}, {3.2161885240513723`, 
       2.626792816072176}, {3.307347382652485, 2.6060327463627675`}, {
       3.307347382652485, 2.6060327463627675`}}, {{3.307347382652485, 
       2.6060327463627675`}, {3.2161885240513723`, 2.626792816072176}, {
       3.2161885240513723`, 2.626792816072176}, {3.307347382652485, 
       2.6060327463627675`}, {3.307347382652485, 2.6060327463627675`}}, {{
       3.307347382652485, 2.6060327463627675`}, {3.2161885240513723`, 
       2.626792816072176}, {3.2161885240513723`, 2.626792816072176}, {
       3.307347382652485, 2.6060327463627675`}, {3.307347382652485, 
       2.6060327463627675`}}, {{3.216188524051373, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}, {3.216188524051373, 2.9010562259675865`}, {
       3.216188524051373, 2.9010562259675865`}}, {{3.216188524051373, 
       2.9010562259675865`}, {3.307347382652485, 2.921816295676995}, {
       3.307347382652485, 2.921816295676995}, {3.216188524051373, 
       2.9010562259675865`}, {3.216188524051373, 2.9010562259675865`}}, {{
       3.216188524051373, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}, {
       3.216188524051373, 2.9010562259675865`}, {3.216188524051373, 
       2.9010562259675865`}}, {{3.216188524051373, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}, {3.216188524051373, 2.9010562259675865`}, {
       3.216188524051373, 2.9010562259675865`}}, {{3.307347382652485, 
       2.921816295676995}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}}, {{
       3.307347382652485, 2.921816295676995}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}, {
       3.307347382652485, 2.921816295676995}, {3.307347382652485, 
       2.921816295676995}}, {{3.307347382652485, 2.921816295676995}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}, {3.307347382652485, 2.921816295676995}, {
       3.307347382652485, 2.921816295676995}}, {{3.307347382652485, 
       2.921816295676995}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}, {3.307347382652485, 
       2.921816295676995}, {3.307347382652485, 2.921816295676995}}, {{
       3.374534577583353, 2.9010562259675865`}, {3.4261069228014702`, 
       2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}, {{3.374534577583353, 2.9010562259675865`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.4261069228014702`, 
       2.8532504432031427`}, {3.374534577583353, 2.9010562259675865`}, {
       3.374534577583353, 2.9010562259675865`}}, {{3.374534577583353, 
       2.9010562259675865`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.374534577583353, 
       2.9010562259675865`}, {3.374534577583353, 2.9010562259675865`}}, {{
       3.374534577583353, 2.9010562259675865`}, {3.4261069228014702`, 
       2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.374534577583353, 2.9010562259675865`}, {3.374534577583353, 
       2.9010562259675865`}}, {{3.4261069228014702`, 2.8532504432031427`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}}, {{3.4261069228014702`, 
       2.8532504432031427`}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4261069228014702`, 
       2.8532504432031427`}, {3.4261069228014702`, 2.8532504432031427`}}, {{
       3.4261069228014702`, 2.8532504432031427`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4537076043493427`, 2.7639245210198813`}, {
       3.4261069228014702`, 2.8532504432031427`}, {3.4261069228014702`, 
       2.8532504432031427`}}, {{3.4261069228014702`, 2.8532504432031427`}, {
       3.4537076043493427`, 2.7639245210198813`}, {3.4537076043493427`, 
       2.7639245210198813`}, {3.4261069228014702`, 2.8532504432031427`}, {
       3.4261069228014702`, 2.8532504432031427`}}, {{3.1787599168276444`, 
       3.13657422973422}, {3.115416589792595, 3.204908304404897}, {
       3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.3415764537462507`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.115416589792595, 
       3.3415764537462507`}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.1787599168276444`, 
       3.13657422973422}, {3.1787599168276444`, 3.13657422973422}}, {{
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}, {{3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.336570702451401, 
       3.13657422973422}, {3.269610624954078, 3.1158843366969804`}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}, {3.269610624954078, 3.1158843366969804`}, {
       3.336570702451401, 3.13657422973422}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.41547609526328, 3.273242379075574}, {
       3.41547609526328, 3.273242379075574}}, {{3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}}, {{
       3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078, 
       3.430600421454167}, {3.336570702451401, 3.4099105284169275`}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.336570702451401, 
       3.4099105284169275`}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}, {{3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}}, {{3.1787599168276444`, 
       3.13657422973422}, {3.115416589792595, 3.204908304404897}, {
       3.115416589792595, 3.204908304404897}, {3.1787599168276444`, 
       3.13657422973422}, {3.1787599168276444`, 3.13657422973422}}, {{
       3.1787599168276444`, 3.13657422973422}, {3.115416589792595, 
       3.204908304404897}, {3.115416589792595, 3.204908304404897}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}}, {{3.1787599168276444`, 3.13657422973422}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}, {3.1787599168276444`, 3.13657422973422}, {
       3.1787599168276444`, 3.13657422973422}}, {{3.1787599168276444`, 
       3.13657422973422}, {3.115416589792595, 3.204908304404897}, {
       3.115416589792595, 3.204908304404897}, {3.1787599168276444`, 
       3.13657422973422}, {3.1787599168276444`, 3.13657422973422}}, {{
       3.115416589792595, 3.204908304404897}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}}, {{3.115416589792595, 3.204908304404897}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}, {3.115416589792595, 3.204908304404897}, {
       3.115416589792595, 3.204908304404897}}, {{3.115416589792595, 
       3.204908304404897}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.204908304404897}, {3.115416589792595, 3.204908304404897}}, {{
       3.115416589792595, 3.204908304404897}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.204908304404897}, {3.115416589792595, 
       3.204908304404897}}, {{3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}}, {{3.0998545240157656`, 
       3.273242379075574}, {3.115416589792595, 3.3415764537462507`}, {
       3.115416589792595, 3.3415764537462507`}, {3.0998545240157656`, 
       3.273242379075574}, {3.0998545240157656`, 3.273242379075574}}, {{
       3.0998545240157656`, 3.273242379075574}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}, {
       3.0998545240157656`, 3.273242379075574}, {3.0998545240157656`, 
       3.273242379075574}}, {{3.0998545240157656`, 3.273242379075574}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}, {3.0998545240157656`, 3.273242379075574}, {
       3.0998545240157656`, 3.273242379075574}}, {{3.115416589792595, 
       3.3415764537462507`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}}, {{
       3.115416589792595, 3.3415764537462507`}, {3.1787599168276444`, 
       3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.115416589792595, 3.3415764537462507`}, {3.115416589792595, 
       3.3415764537462507`}}, {{3.115416589792595, 3.3415764537462507`}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}, {3.115416589792595, 3.3415764537462507`}, {
       3.115416589792595, 3.3415764537462507`}}, {{3.115416589792595, 
       3.3415764537462507`}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.115416589792595, 
       3.3415764537462507`}, {3.115416589792595, 3.3415764537462507`}}, {{
       3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}, {{3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.41547609526328, 3.273242379075574}, {
       3.41547609526328, 3.273242379075574}}, {{3.41547609526328, 
       3.273242379075574}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}}, {{
       3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}}, {{3.3879687141718957`, 3.1842184113676573`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.3879687141718957`, 3.1842184113676573`}}, {{3.3879687141718957`, 
       3.1842184113676573`}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}, {3.3879687141718957`, 
       3.1842184113676573`}, {3.3879687141718957`, 3.1842184113676573`}}, {{
       3.3879687141718957`, 3.1842184113676573`}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}, {
       3.3879687141718957`, 3.1842184113676573`}, {3.3879687141718957`, 
       3.1842184113676573`}}, {{3.3879687141718957`, 3.1842184113676573`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}, {3.3879687141718957`, 3.1842184113676573`}, {
       3.3879687141718957`, 3.1842184113676573`}}, {{3.336570702451401, 
       3.13657422973422}, {3.269610624954078, 3.1158843366969804`}, {
       3.269610624954078, 3.1158843366969804`}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}}, {{
       3.336570702451401, 3.13657422973422}, {3.269610624954078, 
       3.1158843366969804`}, {3.269610624954078, 3.1158843366969804`}, {
       3.336570702451401, 3.13657422973422}, {3.336570702451401, 
       3.13657422973422}}, {{3.336570702451401, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}, {3.336570702451401, 3.13657422973422}, {
       3.336570702451401, 3.13657422973422}}, {{3.336570702451401, 
       3.13657422973422}, {3.269610624954078, 3.1158843366969804`}, {
       3.269610624954078, 3.1158843366969804`}, {3.336570702451401, 
       3.13657422973422}, {3.336570702451401, 3.13657422973422}}, {{
       3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`, 
       3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}}, {{3.269610624954078, 3.1158843366969804`}, {
       3.1787599168276444`, 3.13657422973422}, {3.1787599168276444`, 
       3.13657422973422}, {3.269610624954078, 3.1158843366969804`}, {
       3.269610624954078, 3.1158843366969804`}}, {{3.269610624954078, 
       3.1158843366969804`}, {3.1787599168276444`, 3.13657422973422}, {
       3.1787599168276444`, 3.13657422973422}, {3.269610624954078, 
       3.1158843366969804`}, {3.269610624954078, 3.1158843366969804`}}, {{
       3.269610624954078, 3.1158843366969804`}, {3.1787599168276444`, 
       3.13657422973422}, {3.1787599168276444`, 3.13657422973422}, {
       3.269610624954078, 3.1158843366969804`}, {3.269610624954078, 
       3.1158843366969804`}}, {{3.1787599168276444`, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.1787599168276444`, 3.4099105284169275`}}, {{3.1787599168276444`, 
       3.4099105284169275`}, {3.269610624954078, 3.430600421454167}, {
       3.269610624954078, 3.430600421454167}, {3.1787599168276444`, 
       3.4099105284169275`}, {3.1787599168276444`, 3.4099105284169275`}}, {{
       3.1787599168276444`, 3.4099105284169275`}, {3.269610624954078, 
       3.430600421454167}, {3.269610624954078, 3.430600421454167}, {
       3.1787599168276444`, 3.4099105284169275`}, {3.1787599168276444`, 
       3.4099105284169275`}}, {{3.1787599168276444`, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}, {3.1787599168276444`, 3.4099105284169275`}, {
       3.1787599168276444`, 3.4099105284169275`}}, {{3.269610624954078, 
       3.430600421454167}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.269610624954078, 
       3.430600421454167}, {3.269610624954078, 3.430600421454167}}, {{
       3.269610624954078, 3.430600421454167}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}, {
       3.269610624954078, 3.430600421454167}, {3.269610624954078, 
       3.430600421454167}}, {{3.269610624954078, 3.430600421454167}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}, {3.269610624954078, 3.430600421454167}, {
       3.269610624954078, 3.430600421454167}}, {{3.269610624954078, 
       3.430600421454167}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}, {3.269610624954078, 
       3.430600421454167}, {3.269610624954078, 3.430600421454167}}, {{
       3.336570702451401, 3.4099105284169275`}, {3.3879687141718957`, 
       3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}, {{3.336570702451401, 3.4099105284169275`}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.3879687141718957`, 
       3.3622663467834903`}, {3.336570702451401, 3.4099105284169275`}, {
       3.336570702451401, 3.4099105284169275`}}, {{3.336570702451401, 
       3.4099105284169275`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.336570702451401, 
       3.4099105284169275`}, {3.336570702451401, 3.4099105284169275`}}, {{
       3.336570702451401, 3.4099105284169275`}, {3.3879687141718957`, 
       3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.336570702451401, 3.4099105284169275`}, {3.336570702451401, 
       3.4099105284169275`}}, {{3.3879687141718957`, 3.3622663467834903`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.3879687141718957`, 3.3622663467834903`}}, {{3.3879687141718957`, 
       3.3622663467834903`}, {3.41547609526328, 3.273242379075574}, {
       3.41547609526328, 3.273242379075574}, {3.3879687141718957`, 
       3.3622663467834903`}, {3.3879687141718957`, 3.3622663467834903`}}, {{
       3.3879687141718957`, 3.3622663467834903`}, {3.41547609526328, 
       3.273242379075574}, {3.41547609526328, 3.273242379075574}, {
       3.3879687141718957`, 3.3622663467834903`}, {3.3879687141718957`, 
       3.3622663467834903`}}, {{3.3879687141718957`, 3.3622663467834903`}, {
       3.41547609526328, 3.273242379075574}, {3.41547609526328, 
       3.273242379075574}, {3.3879687141718957`, 3.3622663467834903`}, {
       3.3879687141718957`, 3.3622663467834903`}}, {{3.134137681383431, 
       3.6315611514164683`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0721739787161013`, 
       3.832098405290014}, {3.134137681383431, 3.898944156581196}, {
       3.134137681383431, 3.898944156581196}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.6984069027076503`}, {3.134137681383431, 
       3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}}, {{
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}}, {{3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.6781676377307884`}, {3.288511331392018, 
       3.6315611514164683`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.288511331392018, 3.6315611514164683`}, {3.338789888976756, 
       3.6781676377307884`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.3656981563963115`, 3.7652526539988322`}}, {{3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}}, {{
       3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.288511331392018, 3.898944156581196}, {
       3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.288511331392018, 
       3.898944156581196}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}, {{3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}}, {{3.134137681383431, 
       3.6315611514164683`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}, {3.134137681383431, 
       3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}}, {{
       3.134137681383431, 3.6315611514164683`}, {3.0721739787161013`, 
       3.6984069027076503`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}}, {{3.134137681383431, 3.6315611514164683`}, {
       3.0721739787161013`, 3.6984069027076503`}, {3.0721739787161013`, 
       3.6984069027076503`}, {3.134137681383431, 3.6315611514164683`}, {
       3.134137681383431, 3.6315611514164683`}}, {{3.134137681383431, 
       3.6315611514164683`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}, {3.134137681383431, 
       3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}}, {{
       3.0721739787161013`, 3.6984069027076503`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.6984069027076503`}, {3.0721739787161013`, 
       3.6984069027076503`}}, {{3.0721739787161013`, 3.6984069027076503`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.6984069027076503`}, {
       3.0721739787161013`, 3.6984069027076503`}}, {{3.0721739787161013`, 
       3.6984069027076503`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0721739787161013`, 
       3.6984069027076503`}, {3.0721739787161013`, 3.6984069027076503`}}, {{
       3.0721739787161013`, 3.6984069027076503`}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.6984069027076503`}, {3.0721739787161013`, 
       3.6984069027076503`}}, {{3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}, {{3.0569508563791374`, 
       3.7652526539988322`}, {3.0721739787161013`, 3.832098405290014}, {
       3.0721739787161013`, 3.832098405290014}, {3.0569508563791374`, 
       3.7652526539988322`}, {3.0569508563791374`, 3.7652526539988322`}}, {{
       3.0569508563791374`, 3.7652526539988322`}, {3.0721739787161013`, 
       3.832098405290014}, {3.0721739787161013`, 3.832098405290014}, {
       3.0569508563791374`, 3.7652526539988322`}, {3.0569508563791374`, 
       3.7652526539988322`}}, {{3.0569508563791374`, 3.7652526539988322`}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}, {3.0569508563791374`, 3.7652526539988322`}, {
       3.0569508563791374`, 3.7652526539988322`}}, {{3.0721739787161013`, 
       3.832098405290014}, {3.134137681383431, 3.898944156581196}, {
       3.134137681383431, 3.898944156581196}, {3.0721739787161013`, 
       3.832098405290014}, {3.0721739787161013`, 3.832098405290014}}, {{
       3.0721739787161013`, 3.832098405290014}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}, {
       3.0721739787161013`, 3.832098405290014}, {3.0721739787161013`, 
       3.832098405290014}}, {{3.0721739787161013`, 3.832098405290014}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}, {3.0721739787161013`, 3.832098405290014}, {
       3.0721739787161013`, 3.832098405290014}}, {{3.0721739787161013`, 
       3.832098405290014}, {3.134137681383431, 3.898944156581196}, {
       3.134137681383431, 3.898944156581196}, {3.0721739787161013`, 
       3.832098405290014}, {3.0721739787161013`, 3.832098405290014}}, {{
       3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756, 
       3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}, {{3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.6781676377307884`}, {3.338789888976756, 
       3.6781676377307884`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.3656981563963115`, 3.7652526539988322`}}, {{3.3656981563963115`, 
       3.7652526539988322`}, {3.338789888976756, 3.6781676377307884`}, {
       3.338789888976756, 3.6781676377307884`}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}}, {{
       3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756, 
       3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}}, {{3.338789888976756, 3.6781676377307884`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.338789888976756, 3.6781676377307884`}, {
       3.338789888976756, 3.6781676377307884`}}, {{3.338789888976756, 
       3.6781676377307884`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}, {3.338789888976756, 
       3.6781676377307884`}, {3.338789888976756, 3.6781676377307884`}}, {{
       3.338789888976756, 3.6781676377307884`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}, {
       3.338789888976756, 3.6781676377307884`}, {3.338789888976756, 
       3.6781676377307884`}}, {{3.338789888976756, 3.6781676377307884`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}, {3.338789888976756, 3.6781676377307884`}, {
       3.338789888976756, 3.6781676377307884`}}, {{3.288511331392018, 
       3.6315611514164683`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}}, {{
       3.288511331392018, 3.6315611514164683`}, {3.2230096514703157`, 
       3.6113218864396064`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.288511331392018, 3.6315611514164683`}, {3.288511331392018, 
       3.6315611514164683`}}, {{3.288511331392018, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}, {3.288511331392018, 3.6315611514164683`}, {
       3.288511331392018, 3.6315611514164683`}}, {{3.288511331392018, 
       3.6315611514164683`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.288511331392018, 
       3.6315611514164683`}, {3.288511331392018, 3.6315611514164683`}}, {{
       3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431, 
       3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}}, {{3.2230096514703157`, 3.6113218864396064`}, {
       3.134137681383431, 3.6315611514164683`}, {3.134137681383431, 
       3.6315611514164683`}, {3.2230096514703157`, 3.6113218864396064`}, {
       3.2230096514703157`, 3.6113218864396064`}}, {{3.2230096514703157`, 
       3.6113218864396064`}, {3.134137681383431, 3.6315611514164683`}, {
       3.134137681383431, 3.6315611514164683`}, {3.2230096514703157`, 
       3.6113218864396064`}, {3.2230096514703157`, 3.6113218864396064`}}, {{
       3.2230096514703157`, 3.6113218864396064`}, {3.134137681383431, 
       3.6315611514164683`}, {3.134137681383431, 3.6315611514164683`}, {
       3.2230096514703157`, 3.6113218864396064`}, {3.2230096514703157`, 
       3.6113218864396064`}}, {{3.134137681383431, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}, {3.134137681383431, 3.898944156581196}, {
       3.134137681383431, 3.898944156581196}}, {{3.134137681383431, 
       3.898944156581196}, {3.2230096514703157`, 3.919183421558058}, {
       3.2230096514703157`, 3.919183421558058}, {3.134137681383431, 
       3.898944156581196}, {3.134137681383431, 3.898944156581196}}, {{
       3.134137681383431, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}, {
       3.134137681383431, 3.898944156581196}, {3.134137681383431, 
       3.898944156581196}}, {{3.134137681383431, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}, {3.134137681383431, 3.898944156581196}, {
       3.134137681383431, 3.898944156581196}}, {{3.2230096514703157`, 
       3.919183421558058}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}}, {{
       3.2230096514703157`, 3.919183421558058}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}, {
       3.2230096514703157`, 3.919183421558058}, {3.2230096514703157`, 
       3.919183421558058}}, {{3.2230096514703157`, 3.919183421558058}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}, {3.2230096514703157`, 3.919183421558058}, {
       3.2230096514703157`, 3.919183421558058}}, {{3.2230096514703157`, 
       3.919183421558058}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}, {3.2230096514703157`, 
       3.919183421558058}, {3.2230096514703157`, 3.919183421558058}}, {{
       3.288511331392018, 3.898944156581196}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}, {{3.288511331392018, 3.898944156581196}, {
       3.338789888976756, 3.852337670266876}, {3.338789888976756, 
       3.852337670266876}, {3.288511331392018, 3.898944156581196}, {
       3.288511331392018, 3.898944156581196}}, {{3.288511331392018, 
       3.898944156581196}, {3.338789888976756, 3.852337670266876}, {
       3.338789888976756, 3.852337670266876}, {3.288511331392018, 
       3.898944156581196}, {3.288511331392018, 3.898944156581196}}, {{
       3.288511331392018, 3.898944156581196}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}, {
       3.288511331392018, 3.898944156581196}, {3.288511331392018, 
       3.898944156581196}}, {{3.338789888976756, 3.852337670266876}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.338789888976756, 3.852337670266876}, {
       3.338789888976756, 3.852337670266876}}, {{3.338789888976756, 
       3.852337670266876}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.338789888976756, 
       3.852337670266876}, {3.338789888976756, 3.852337670266876}}, {{
       3.338789888976756, 3.852337670266876}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.3656981563963115`, 3.7652526539988322`}, {
       3.338789888976756, 3.852337670266876}, {3.338789888976756, 
       3.852337670266876}}, {{3.338789888976756, 3.852337670266876}, {
       3.3656981563963115`, 3.7652526539988322`}, {3.3656981563963115`, 
       3.7652526539988322`}, {3.338789888976756, 3.852337670266876}, {
       3.338789888976756, 3.852337670266876}}, {{
       3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}, {{
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}, {{
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}, {{
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}, {{
       3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}, {{
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}, {{
       3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}, {{
       3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}, {{
       3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}, {{
       3.3696483976456677`, -4.694197729694035}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}}, {{
       3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}, {{
       3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}, {{
       3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}, {{
       3.3007336980849473`, -4.619853320486041}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.619853320486041}, {
       3.3007336980849473`, -4.619853320486041}}, {{
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}, {{
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}, {{
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}, {{
       3.283802868307709, -4.545508911278047}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.283802868307709, -4.545508911278047}, {
       3.283802868307709, -4.545508911278047}}, {{
       3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}, {{
       3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}, {{
       3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}, {{
       3.3007336980849473`, -4.471164502070052}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3007336980849473`, -4.471164502070052}, {
       3.3007336980849473`, -4.471164502070052}}, {{
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}, {{
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}, {{
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}, {{
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}}, {{
       3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}, {{
       3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}, {{
       3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}, {{
       3.597258188436434, -4.6423629963958}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.597258188436434, -4.6423629963958}, {
       3.597258188436434, -4.6423629963958}}, {{
       3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}, {{
       3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}, {{
       3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}, {{
       3.5413394563215843`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.5413394563215843`, -4.694197729694035}, {
       3.5413394563215843`, -4.694197729694035}}, {{
       3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}, {{
       3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}, {{
       3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}, {{
       3.4684898944294966`, -4.7167074056037945`}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.3696483976456677`, -4.694197729694035}, {
       3.4684898944294966`, -4.7167074056037945`}, {
       3.4684898944294966`, -4.7167074056037945`}}, {{
       3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}, {{
       3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}, {{
       3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}, {{
       3.3696483976456677`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.3696483976456677`, -4.396820092862058}, {
       3.3696483976456677`, -4.396820092862058}}, {{
       3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}, {{
       3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}, {{
       3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}, {{
       3.4684898944294966`, -4.374310416952299}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.4684898944294966`, -4.374310416952299}, {
       3.4684898944294966`, -4.374310416952299}}, {{
       3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}, {{
       3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}, {{
       3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}, {{
       3.5413394563215843`, -4.396820092862058}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}, {
       3.5413394563215843`, -4.396820092862058}, {
       3.5413394563215843`, -4.396820092862058}}, {{
       3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}, {{
       3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}, {{
       3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}, {{
       3.597258188436434, -4.448654826160293}, {
       3.627184985659543, -4.545508911278047}, {
       3.627184985659543, -4.545508911278047}, {
       3.597258188436434, -4.448654826160293}, {
       3.597258188436434, -4.448654826160293}}, {{
       3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}, {{
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}, {{
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}, {{
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}, {{
       3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}, {{
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}, {{
       3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}, {{
       3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}, {{
       3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}, {{
       3.469643480420427, -4.18200927502375}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}}, {{
       3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}, {{
       3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}, {{
       3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}, {{
       3.4053957460936326`, -4.112699535854544}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -4.112699535854544}, {
       3.4053957460936326`, -4.112699535854544}}, {{
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}, {{
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}, {{
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}, {{
       3.3896114872868197`, -4.0433897966853385`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.3896114872868197`, -4.0433897966853385`}, {
       3.3896114872868197`, -4.0433897966853385`}}, {{
       3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}, {{
       3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}, {{
       3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}, {{
       3.4053957460936326`, -3.9740800575161326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}, {
       3.4053957460936326`, -3.9740800575161326`}, {
       3.4053957460936326`, -3.9740800575161326`}}, {{
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}, {{
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}, {{
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}, {{
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}}, {{
       3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}, {{
       3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}, {{
       3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}, {{
       3.681839332134441, -4.133684836332539}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.681839332134441, -4.133684836332539}, {
       3.681839332134441, -4.133684836332539}}, {{
       3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}, {{
       3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}, {{
       3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}, {{
       3.6297074666876417`, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.6297074666876417`, -4.18200927502375}, {
       3.6297074666876417`, -4.18200927502375}}, {{
       3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}, {{
       3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}, {{
       3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}, {{
       3.5617913424340295`, -4.202994575501744}, {
       3.469643480420427, -4.18200927502375}, {
       3.469643480420427, -4.18200927502375}, {
       3.5617913424340295`, -4.202994575501744}, {
       3.5617913424340295`, -4.202994575501744}}, {{
       3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}, {{
       3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}, {{
       3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}, {{
       3.469643480420427, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.469643480420427, -3.904770318346927}, {
       3.469643480420427, -3.904770318346927}}, {{
       3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}, {{
       3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}, {{
       3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}, {{
       3.5617913424340295`, -3.8837850178689326`}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.5617913424340295`, -3.8837850178689326`}, {
       3.5617913424340295`, -3.8837850178689326`}}, {{
       3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}, {{
       3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}, {{
       3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}, {{
       3.6297074666876417`, -3.904770318346927}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}, {
       3.6297074666876417`, -3.904770318346927}, {
       3.6297074666876417`, -3.904770318346927}}, {{
       3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}, {{
       3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}, {{
       3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}, {{
       3.681839332134441, -3.953094757038138}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.709739459821249, -4.0433897966853385`}, {
       3.681839332134441, -3.953094757038138}, {
       3.681839332134441, -3.953094757038138}}, {{
       3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}, {{
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}, {{
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}, {{
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}, {{
       3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}, {{
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}, {{
       3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}, {{
       3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}, {{
       3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}, {{
       3.4654980462789204`, -3.590673070758785}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}}, {{
       3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}, {{
       3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}, {{
       3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}, {{
       3.404803809096469, -3.525196804673006}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.525196804673006}, {
       3.404803809096469, -3.525196804673006}}, {{
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}, {{
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}, {{
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}, {{
       3.3898925665786086`, -3.4597205385872267`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.3898925665786086`, -3.4597205385872267`}, {
       3.3898925665786086`, -3.4597205385872267`}}, {{
       3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}, {{
       3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}, {{
       3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}, {{
       3.404803809096469, -3.3942442725014477`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.404803809096469, -3.3942442725014477`}, {
       3.404803809096469, -3.3942442725014477`}}, {{
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}, {{
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}, {{
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}, {{
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}}, {{
       3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}, {{
       3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}, {{
       3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}, {{
       3.665957494195849, -3.5450214228934374`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}, {
       3.665957494195849, -3.5450214228934374`}, {
       3.665957494195849, -3.5450214228934374`}}, {{
       3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}, {{
       3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}, {{
       3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}, {{
       3.616709005679545, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.616709005679545, -3.590673070758785}, {
       3.616709005679545, -3.590673070758785}}, {{
       3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}, {{
       3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}, {{
       3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}, {{
       3.5525492746453806`, -3.6104976889792164`}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.4654980462789204`, -3.590673070758785}, {
       3.5525492746453806`, -3.6104976889792164`}, {
       3.5525492746453806`, -3.6104976889792164`}}, {{
       3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}, {{
       3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}, {{
       3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}, {{
       3.4654980462789204`, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.4654980462789204`, -3.3287680064156686`}, {
       3.4654980462789204`, -3.3287680064156686`}}, {{
       3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}, {{
       3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}, {{
       3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}, {{
       3.5525492746453806`, -3.308943388195237}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.5525492746453806`, -3.308943388195237}, {
       3.5525492746453806`, -3.308943388195237}}, {{
       3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}, {{
       3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}, {{
       3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}, {{
       3.616709005679545, -3.3287680064156686`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}, {
       3.616709005679545, -3.3287680064156686`}, {
       3.616709005679545, -3.3287680064156686`}}, {{
       3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}, {{
       3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}, {{
       3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}, {{
       3.665957494195849, -3.374419654281016}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.692314485379857, -3.4597205385872267`}, {
       3.665957494195849, -3.374419654281016}, {
       3.665957494195849, -3.374419654281016}}, {{
       3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}, {{
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}, {{
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}, {{
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}, {{
       3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}, {{
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}, {{
       3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}, {{
       3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}, {{
       3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}, {{
       3.407184219021581, -3.0990387468046037`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}}, {{
       3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}, {{
       3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}, {{
       3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}, {{
       3.3432911465574398`, -3.030111612896911}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -3.030111612896911}, {
       3.3432911465574398`, -3.030111612896911}}, {{
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}, {{
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}, {{
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}, {{
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3275940203894296`, -2.9611844789892188`}, {
       3.3275940203894296`, -2.9611844789892188`}}, {{
       3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}, {{
       3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}, {{
       3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}, {{
       3.3432911465574398`, -2.8922573450815263`}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}, {
       3.3432911465574398`, -2.8922573450815263`}, {
       3.3432911465574398`, -2.8922573450815263`}}, {{
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}, {{
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}, {{
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}, {{
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}}, {{
       3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}, {{
       3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}, {{
       3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}, {{
       3.6182087021759917`, -3.050981069822851}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.6182087021759917`, -3.050981069822851}, {
       3.6182087021759917`, -3.050981069822851}}, {{
       3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}, {{
       3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}, {{
       3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}, {{
       3.5663646162858833`, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.5663646162858833`, -3.0990387468046037`}, {
       3.5663646162858833`, -3.0990387468046037`}}, {{
       3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}, {{
       3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}, {{
       3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}, {{
       3.498823404227765, -3.1199082037305437`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.407184219021581, -3.0990387468046037`}, {
       3.498823404227765, -3.1199082037305437`}, {
       3.498823404227765, -3.1199082037305437`}}, {{
       3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}, {{
       3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}, {{
       3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}, {{
       3.407184219021581, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}, {
       3.407184219021581, -2.823330211173834}, {
       3.407184219021581, -2.823330211173834}}, {{
       3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}, {{
       3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}, {{
       3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}, {{
       3.498823404227765, -2.802460754247894}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.498823404227765, -2.802460754247894}, {
       3.498823404227765, -2.802460754247894}}, {{
       3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}, {{
       3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}, {{
       3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}, {{
       3.5663646162858833`, -2.823330211173834}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.5663646162858833`, -2.823330211173834}, {
       3.5663646162858833`, -2.823330211173834}}, {{
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}, {{
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}, {{
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}, {{
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6459548149180345`, -2.9611844789892188`}, {
       3.6182087021759917`, -2.8713878881555863`}, {
       3.6182087021759917`, -2.8713878881555863`}}, {{
       3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}, {{
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}, {{
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}, {{
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}, {{
       3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}, {{
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}, {{
       3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}, {{
       3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}, {{
       3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}, {{
       3.427589210328633, -2.6569779275796472`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}}, {{
       3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}, {{
       3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}, {{
       3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}, {{
       3.365753321259845, -2.590270060172933}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.590270060172933}, {
       3.365753321259845, -2.590270060172933}}, {{
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}, {{
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}, {{
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}, {{
       3.350561599919968, -2.5235621927662186`}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}, {
       3.350561599919968, -2.5235621927662186`}, {
       3.350561599919968, -2.5235621927662186`}}, {{
       3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}, {{
       3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}, {{
       3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}, {{
       3.365753321259845, -2.456854325359504}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}, {
       3.365753321259845, -2.456854325359504}, {
       3.365753321259845, -2.456854325359504}}, {{
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}, {{
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}, {{
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}, {{
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}}, {{
       3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}, {{
       3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}, {{
       3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}, {{
       3.6318192782825225`, -2.6104675772687425`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.6318192782825225`, -2.6104675772687425`}, {
       3.6318192782825225`, -2.6104675772687425`}}, {{
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}, {{
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}, {{
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}, {{
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5816444311459623`, -2.6569779275796472`}, {
       3.5816444311459623`, -2.6569779275796472`}}, {{
       3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}, {{
       3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}, {{
       3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}, {{
       3.5162778626695252`, -2.6771754446754565`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.427589210328633, -2.6569779275796472`}, {
       3.5162778626695252`, -2.6771754446754565`}, {
       3.5162778626695252`, -2.6771754446754565`}}, {{
       3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}, {{
       3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}, {{
       3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}, {{
       3.427589210328633, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.427589210328633, -2.39014645795279}, {
       3.427589210328633, -2.39014645795279}}, {{
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}, {{
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}, {{
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}, {{
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5162778626695252`, -2.3699489408569807`}, {
       3.5162778626695252`, -2.3699489408569807`}}, {{
       3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}, {{
       3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}, {{
       3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}, {{
       3.5816444311459623`, -2.39014645795279}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.5816444311459623`, -2.39014645795279}, {
       3.5816444311459623`, -2.39014645795279}}, {{
       3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}, {{
       3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}, {{
       3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}, {{
       3.6318192782825225`, -2.436656808263695}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6586720415546274`, -2.5235621927662186`}, {
       3.6318192782825225`, -2.436656808263695}, {
       3.6318192782825225`, -2.436656808263695}}, {{
       3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}, {{
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}, {{
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}, {{
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}, {{
       3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}, {{
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}, {{
       3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}, {{
       3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}, {{
       3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}, {{
       3.450338538201801, -2.104594878283294}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}}, {{
       3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}, {{
       3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}, {{
       3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}, {{
       3.396249560547919, -2.046244292501531}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -2.046244292501531}, {
       3.396249560547919, -2.046244292501531}}, {{
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}, {{
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}, {{
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}, {{
       3.382961085384854, -1.9878937067197677`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.382961085384854, -1.9878937067197677`}, {
       3.382961085384854, -1.9878937067197677`}}, {{
       3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}, {{
       3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}, {{
       3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}, {{
       3.396249560547919, -1.9295431209380045`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.396249560547919, -1.9295431209380045`}, {
       3.396249560547919, -1.9295431209380045`}}, {{
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}, {{
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}, {{
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}, {{
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}}, {{
       3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}, {{
       3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}, {{
       3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}, {{
       3.6289822958668716`, -2.0639114283236397`}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}, {
       3.6289822958668716`, -2.0639114283236397`}, {
       3.6289822958668716`, -2.0639114283236397`}}, {{
       3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}, {{
       3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}, {{
       3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}, {{
       3.585093443835694, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.585093443835694, -2.104594878283294}, {
       3.585093443835694, -2.104594878283294}}, {{
       3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}, {{
       3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}, {{
       3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}, {{
       3.5279161166414514`, -2.122262014105403}, {
       3.450338538201801, -2.104594878283294}, {
       3.450338538201801, -2.104594878283294}, {
       3.5279161166414514`, -2.122262014105403}, {
       3.5279161166414514`, -2.122262014105403}}, {{
       3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}, {{
       3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}, {{
       3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}, {{
       3.450338538201801, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.450338538201801, -1.8711925351562413`}, {
       3.450338538201801, -1.8711925351562413`}}, {{
       3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}, {{
       3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}, {{
       3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}, {{
       3.5279161166414514`, -1.8535253993341325`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.5279161166414514`, -1.8535253993341325`}, {
       3.5279161166414514`, -1.8535253993341325`}}, {{
       3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}, {{
       3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}, {{
       3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}, {{
       3.585093443835694, -1.8711925351562413`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.585093443835694, -1.8711925351562413`}, {
       3.585093443835694, -1.8711925351562413`}}, {{
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}, {{
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}, {{
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}, {{
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6524708966526407`, -1.9878937067197677`}, {
       3.6289822958668716`, -1.9118759851158957`}, {
       3.6289822958668716`, -1.9118759851158957`}}, {{
       3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}, {{
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}, {{
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}, {{
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}, {{
       3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}, {{
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}, {{
       3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}, {{
       3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}, {{
       3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}, {{
       3.43617638560572, -1.6479135782654888`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}}, {{
       3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}, {{
       3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}, {{
       3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}, {{
       3.367751230564684, -1.5740972842249246`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.5740972842249246`}, {
       3.367751230564684, -1.5740972842249246`}}, {{
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}, {{
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}, {{
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}, {{
       3.3509406711359198`, -1.5002809901843606`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.3509406711359198`, -1.5002809901843606`}, {
       3.3509406711359198`, -1.5002809901843606`}}, {{
       3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}, {{
       3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}, {{
       3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}, {{
       3.367751230564684, -1.4264646961437966`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.367751230564684, -1.4264646961437966`}, {
       3.367751230564684, -1.4264646961437966`}}, {{
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}, {{
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}, {{
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}, {{
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}}, {{
       3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}, {{
       3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}, {{
       3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}, {{
       3.6621693206832893`, -1.5964470597280689`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.6621693206832893`, -1.5964470597280689`}, {
       3.6621693206832893`, -1.5964470597280689`}}, {{
       3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}, {{
       3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}, {{
       3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}, {{
       3.606647814545321, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.606647814545321, -1.6479135782654888`}, {
       3.606647814545321, -1.6479135782654888`}}, {{
       3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}, {{
       3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}, {{
       3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}, {{
       3.5343157489785884`, -1.6702633537686329`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.43617638560572, -1.6479135782654888`}, {
       3.5343157489785884`, -1.6702633537686329`}, {
       3.5343157489785884`, -1.6702633537686329`}}, {{
       3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}, {{
       3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}, {{
       3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}, {{
       3.43617638560572, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.43617638560572, -1.3526484021032323`}, {
       3.43617638560572, -1.3526484021032323`}}, {{
       3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}, {{
       3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}, {{
       3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}, {{
       3.5343157489785884`, -1.3302986266000882`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.5343157489785884`, -1.3302986266000882`}, {
       3.5343157489785884`, -1.3302986266000882`}}, {{
       3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}, {{
       3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}, {{
       3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}, {{
       3.606647814545321, -1.3526484021032323`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.606647814545321, -1.3526484021032323`}, {
       3.606647814545321, -1.3526484021032323`}}, {{
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}, {{
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}, {{
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}, {{
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6918835290151213`, -1.5002809901843606`}, {
       3.6621693206832893`, -1.4041149206406522`}, {
       3.6621693206832893`, -1.4041149206406522`}}, {{
       3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}, {{
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}, {{
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}, {{
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}, {{
       3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}, {{
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}, {{
       3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}, {{
       3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}, {{
       3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}, {{
       3.4639413883813144`, -1.0976652991113123`}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}}, {{
       3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}, {{
       3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}, {{
       3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}, {{
       3.397922675114509, -1.026445047615213}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -1.026445047615213}, {
       3.397922675114509, -1.026445047615213}}, {{
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}, {{
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}, {{
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}, {{
       3.3817033256352627`, -0.9552247961191136}, {
       3.397922675114509, -0.8840045446230143}, {
       3.397922675114509, -0.8840045446230143}, {
       3.3817033256352627`, -0.9552247961191136}, {
       3.3817033256352627`, -0.9552247961191136}}, {{
       3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}, {{
       3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}, {{
       3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}, {{
       3.397922675114509, -0.8840045446230141}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.397922675114509, -0.8840045446230141}, {
       3.397922675114509, -0.8840045446230141}}, {{
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}, {{
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}, {{
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}, {{
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}}, {{
       3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}, {{
       3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}, {{
       3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}, {{
       3.6819863861933335`, -1.0480088046813776`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.6819863861933335`, -1.0480088046813776`}, {
       3.6819863861933335`, -1.0480088046813776`}}, {{
       3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}, {{
       3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}, {{
       3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}, {{
       3.628417513873418, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.628417513873418, -1.0976652991113123`}, {
       3.628417513873418, -1.0976652991113123`}}, {{
       3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}, {{
       3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}, {{
       3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}, {{
       3.5586292920742557`, -1.119229056177477}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.4639413883813144`, -1.0976652991113123`}, {
       3.5586292920742557`, -1.119229056177477}, {
       3.5586292920742557`, -1.119229056177477}}, {{
       3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}, {{
       3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}, {{
       3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}, {{
       3.4639413883813144`, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.4639413883813144`, -0.8127842931269148}, {
       3.4639413883813144`, -0.8127842931269148}}, {{
       3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}, {{
       3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}, {{
       3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}, {{
       3.5586292920742557`, -0.7912205360607503}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}, {
       3.5586292920742557`, -0.7912205360607503}, {
       3.5586292920742557`, -0.7912205360607503}}, {{
       3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}, {{
       3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}, {{
       3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}, {{
       3.628417513873418, -0.8127842931269148}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.628417513873418, -0.8127842931269148}, {
       3.628417513873418, -0.8127842931269148}}, {{
       3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}, {{
       3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}, {{
       3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}, {{
       3.6819863861933335`, -0.8624407875568497}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.7106555766194695`, -0.9552247961191136}, {
       3.6819863861933335`, -0.8624407875568497}, {
       3.6819863861933335`, -0.8624407875568497}}, {{
       3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}, {{
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}, {{
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}, {{
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}, {{
       3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}, {{
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}, {{
       3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}, {{
       3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}, {{
       3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}, {{
       3.444161365333992, -0.6733828453109744}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}}, {{
       3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}, {{
       3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}, {{
       3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}, {{
       3.3780541965178625`, -0.6020671689549019}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.6020671689549019}, {
       3.3780541965178625`, -0.6020671689549019}}, {{
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}, {{
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}, {{
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}, {{
       3.361813115450755, -0.5307514925988294}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.361813115450755, -0.5307514925988294}, {
       3.361813115450755, -0.5307514925988294}}, {{
       3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}, {{
       3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}, {{
       3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}, {{
       3.3780541965178625`, -0.45943581624275687`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.3780541965178625`, -0.45943581624275687`}, {
       3.3780541965178625`, -0.45943581624275687`}}, {{
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}, {{
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}, {{
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}, {{
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}}, {{
       3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}, {{
       3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}, {{
       3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}, {{
       3.662498511979341, -0.6236598183439002}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}, {
       3.662498511979341, -0.6236598183439002}, {
       3.662498511979341, -0.6236598183439002}}, {{
       3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}, {{
       3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}, {{
       3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}, {{
       3.608857865100467, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}, {
       3.608857865100467, -0.6733828453109744}, {
       3.608857865100467, -0.6733828453109744}}, {{
       3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}, {{
       3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}, {{
       3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}, {{
       3.538976137154485, -0.6949754946999727}, {
       3.444161365333992, -0.6733828453109744}, {
       3.444161365333992, -0.6733828453109744}, {
       3.538976137154485, -0.6949754946999727}, {
       3.538976137154485, -0.6949754946999727}}, {{
       3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}, {{
       3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}, {{
       3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}, {{
       3.444161365333992, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}, {
       3.444161365333992, -0.38812013988668437`}, {
       3.444161365333992, -0.38812013988668437`}}, {{
       3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}, {{
       3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}, {{
       3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}, {{
       3.538976137154485, -0.366527490497686}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.538976137154485, -0.366527490497686}, {
       3.538976137154485, -0.366527490497686}}, {{
       3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}, {{
       3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}, {{
       3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}, {{
       3.608857865100467, -0.38812013988668437`}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}, {
       3.608857865100467, -0.38812013988668437`}, {
       3.608857865100467, -0.38812013988668437`}}, {{
       3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}, {{
       3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}, {{
       3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}, {{
       3.662498511979341, -0.4378431668537585}, {
       3.691206114983704, -0.5307514925988294}, {
       3.691206114983704, -0.5307514925988294}, {
       3.662498511979341, -0.4378431668537585}, {
       3.662498511979341, -0.4378431668537585}}, {{
       3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.050843271701497675`}, {3.3699974202933296`, 0.1208358605419901}, {
       3.3699974202933296`, 0.1208358605419901}, {3.305116707906138, 
       0.05084327170149765}, {3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948728}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}, {{
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}, {{
       3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}, {{
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}, {{3.3699974202933296`, 
       0.12083586054199012`}, {3.463053136499431, 0.1420279112646835}, {
       3.5316383803266778`, 0.1208358605419901}, {3.584283856524442, 
       0.07203532242419103}, {3.6124588603433523`, -0.019149317138994783`}, {
       3.6124588603433523`, -0.019149317138994783`}, {3.584283856524442, 
       0.07203532242419103}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.3699974202933296`, 0.12083586054199012`}}, {{
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}}, {{3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}, {{
       3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}, {{
       3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}, {{
       3.3699974202933296`, -0.1591344948199797}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}}, {{
       3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}, {{
       3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}, {{
       3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}, {{
       3.305116707906138, -0.08914190597948725}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}, {
       3.305116707906138, -0.08914190597948725}, {
       3.305116707906138, -0.08914190597948725}}, {{
       3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}, {{
       3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}, {{
       3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}, {{
       3.289176940276655, -0.0191493171389948}, {3.305116707906138, 
       0.05084327170149765}, {3.305116707906138, 0.05084327170149765}, {
       3.289176940276655, -0.0191493171389948}, {
       3.289176940276655, -0.0191493171389948}}, {{3.305116707906138, 
       0.050843271701497675`}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.305116707906138, 
       0.050843271701497675`}, {3.305116707906138, 0.050843271701497675`}}, {{
       3.305116707906138, 0.050843271701497675`}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.305116707906138, 0.050843271701497675`}, {3.305116707906138, 
       0.050843271701497675`}}, {{3.305116707906138, 0.050843271701497675`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.305116707906138, 0.050843271701497675`}, {
       3.305116707906138, 0.050843271701497675`}}, {{3.305116707906138, 
       0.050843271701497675`}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.305116707906138, 
       0.050843271701497675`}, {3.305116707906138, 0.050843271701497675`}}, {{
       3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}, {{
       3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}, {{
       3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}, {{
       3.6124588603433523`, -0.019149317138994818`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.6124588603433523`, -0.019149317138994818`}, {
       3.6124588603433523`, -0.019149317138994818`}}, {{
       3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}, {{
       3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}, {{
       3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}, {{
       3.584283856524442, -0.11033395670218063`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.584283856524442, -0.11033395670218063`}, {
       3.584283856524442, -0.11033395670218063`}}, {{
       3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}, {{
       3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}, {{
       3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}, {{
       3.5316383803266778`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.5316383803266778`, -0.1591344948199797}, {
       3.5316383803266778`, -0.1591344948199797}}, {{
       3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}, {{
       3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}, {{
       3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}, {{
       3.463053136499431, -0.18032654554267308`}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.3699974202933296`, -0.1591344948199797}, {
       3.463053136499431, -0.18032654554267308`}, {
       3.463053136499431, -0.18032654554267308`}}, {{3.3699974202933296`, 
       0.12083586054199012`}, {3.463053136499431, 0.1420279112646835}, {
       3.463053136499431, 0.1420279112646835}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.3699974202933296`, 0.12083586054199012`}}, {{
       3.3699974202933296`, 0.12083586054199012`}, {3.463053136499431, 
       0.1420279112646835}, {3.463053136499431, 0.1420279112646835}, {
       3.3699974202933296`, 0.12083586054199012`}, {3.3699974202933296`, 
       0.12083586054199012`}}, {{3.3699974202933296`, 0.12083586054199012`}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}, {3.3699974202933296`, 0.12083586054199012`}, {
       3.3699974202933296`, 0.12083586054199012`}}, {{3.3699974202933296`, 
       0.12083586054199012`}, {3.463053136499431, 0.1420279112646835}, {
       3.463053136499431, 0.1420279112646835}, {3.3699974202933296`, 
       0.12083586054199012`}, {3.3699974202933296`, 0.12083586054199012`}}, {{
       3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}}, {{3.463053136499431, 0.1420279112646835}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}, {3.463053136499431, 0.1420279112646835}, {
       3.463053136499431, 0.1420279112646835}}, {{3.463053136499431, 
       0.1420279112646835}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}, {3.463053136499431, 
       0.1420279112646835}, {3.463053136499431, 0.1420279112646835}}, {{
       3.463053136499431, 0.1420279112646835}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}, {
       3.463053136499431, 0.1420279112646835}, {3.463053136499431, 
       0.1420279112646835}}, {{3.5316383803266778`, 0.1208358605419901}, {
       3.584283856524442, 0.07203532242419103}, {3.584283856524442, 
       0.07203532242419103}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}}, {{3.5316383803266778`, 
       0.1208358605419901}, {3.584283856524442, 0.07203532242419103}, {
       3.584283856524442, 0.07203532242419103}, {3.5316383803266778`, 
       0.1208358605419901}, {3.5316383803266778`, 0.1208358605419901}}, {{
       3.5316383803266778`, 0.1208358605419901}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}, {
       3.5316383803266778`, 0.1208358605419901}, {3.5316383803266778`, 
       0.1208358605419901}}, {{3.5316383803266778`, 0.1208358605419901}, {
       3.584283856524442, 0.07203532242419103}, {3.584283856524442, 
       0.07203532242419103}, {3.5316383803266778`, 0.1208358605419901}, {
       3.5316383803266778`, 0.1208358605419901}}, {{3.584283856524442, 
       0.07203532242419103}, {3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}, {{
       3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}, {{
       3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}, {{
       3.584283856524442, 0.07203532242419103}, {
       3.6124588603433523`, -0.01914931713899483}, {
       3.6124588603433523`, -0.01914931713899483}, {3.584283856524442, 
       0.07203532242419103}, {3.584283856524442, 0.07203532242419103}}, {{
       3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.3162514506499883`, 0.496006128325597}, {
       3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289947}, {3.392547878113848, 0.6281554171289947}, {
       3.331298964899875, 0.5620807727272958}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.4299314839238981}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}, {{3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}}, {{3.6214371605054256`, 
       0.496006128325597}, {3.5948392965145173`, 0.409925691327259}, {
       3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.392547878113848, 0.36385683952219916`}, {
       3.392547878113848, 0.36385683952219916`}, {3.4803946553187286`, 
       0.34385104692556}, {3.545140733041566, 0.3638568395221992}, {
       3.5948392965145173`, 0.409925691327259}, {3.6214371605054256`, 
       0.496006128325597}, {3.6214371605054256`, 0.496006128325597}}, {{
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}, {{3.392547878113848, 0.6281554171289948}, {
       3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.5948392965145173`, 0.582086565323935}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}, {3.5948392965145173`, 0.582086565323935}, {
       3.545140733041566, 0.6281554171289947}, {3.4803946553187286`, 
       0.648161209725634}, {3.392547878113848, 0.6281554171289948}, {
       3.392547878113848, 0.6281554171289948}}, {{3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}}, {{
       3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}, {{3.392547878113848, 0.3638568395221992}, {
       3.331298964899875, 0.42993148392389813`}, {3.331298964899875, 
       0.42993148392389813`}, {3.392547878113848, 0.3638568395221992}, {
       3.392547878113848, 0.3638568395221992}}, {{3.392547878113848, 
       0.3638568395221992}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}, {3.392547878113848, 
       0.3638568395221992}, {3.392547878113848, 0.3638568395221992}}, {{
       3.392547878113848, 0.3638568395221992}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}}, {{3.331298964899875, 0.42993148392389813`}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}}, {{3.331298964899875, 
       0.42993148392389813`}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}, {3.331298964899875, 
       0.42993148392389813`}, {3.331298964899875, 0.42993148392389813`}}, {{
       3.331298964899875, 0.42993148392389813`}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}, {
       3.331298964899875, 0.42993148392389813`}, {3.331298964899875, 
       0.42993148392389813`}}, {{3.331298964899875, 0.42993148392389813`}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.42993148392389813`}, {
       3.331298964899875, 0.42993148392389813`}}, {{3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.5620807727272958}, {
       3.331298964899875, 0.5620807727272958}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}}, {{
       3.3162514506499883`, 0.496006128325597}, {3.331298964899875, 
       0.5620807727272958}, {3.331298964899875, 0.5620807727272958}, {
       3.3162514506499883`, 0.496006128325597}, {3.3162514506499883`, 
       0.496006128325597}}, {{3.3162514506499883`, 0.496006128325597}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}, {3.3162514506499883`, 0.496006128325597}, {
       3.3162514506499883`, 0.496006128325597}}, {{3.3162514506499883`, 
       0.496006128325597}, {3.331298964899875, 0.5620807727272958}, {
       3.331298964899875, 0.5620807727272958}, {3.3162514506499883`, 
       0.496006128325597}, {3.3162514506499883`, 0.496006128325597}}, {{
       3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}}, {{3.331298964899875, 0.5620807727272958}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}, {3.331298964899875, 0.5620807727272958}, {
       3.331298964899875, 0.5620807727272958}}, {{3.331298964899875, 
       0.5620807727272958}, {3.392547878113848, 0.6281554171289948}, {
       3.392547878113848, 0.6281554171289948}, {3.331298964899875, 
       0.5620807727272958}, {3.331298964899875, 0.5620807727272958}}, {{
       3.331298964899875, 0.5620807727272958}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}, {
       3.331298964899875, 0.5620807727272958}, {3.331298964899875, 
       0.5620807727272958}}, {{3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}, {3.6214371605054256`, 0.496006128325597}, {
       3.6214371605054256`, 0.496006128325597}}, {{3.6214371605054256`, 
       0.496006128325597}, {3.5948392965145173`, 0.409925691327259}, {
       3.5948392965145173`, 0.409925691327259}, {3.6214371605054256`, 
       0.496006128325597}, {3.6214371605054256`, 0.496006128325597}}, {{
       3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`, 
       0.409925691327259}, {3.5948392965145173`, 0.409925691327259}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}}, {{3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}, {3.6214371605054256`, 0.496006128325597}, {
       3.6214371605054256`, 0.496006128325597}}, {{3.5948392965145173`, 
       0.409925691327259}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.5948392965145173`, 
       0.409925691327259}, {3.5948392965145173`, 0.409925691327259}}, {{
       3.5948392965145173`, 0.409925691327259}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}, {
       3.5948392965145173`, 0.409925691327259}, {3.5948392965145173`, 
       0.409925691327259}}, {{3.5948392965145173`, 0.409925691327259}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}, {3.5948392965145173`, 0.409925691327259}, {
       3.5948392965145173`, 0.409925691327259}}, {{3.5948392965145173`, 
       0.409925691327259}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}, {3.5948392965145173`, 
       0.409925691327259}, {3.5948392965145173`, 0.409925691327259}}, {{
       3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}, {{3.545140733041566, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.4803946553187286`, 
       0.34385104692556}, {3.545140733041566, 0.3638568395221992}, {
       3.545140733041566, 0.3638568395221992}}, {{3.545140733041566, 
       0.3638568395221992}, {3.4803946553187286`, 0.34385104692556}, {
       3.4803946553187286`, 0.34385104692556}, {3.545140733041566, 
       0.3638568395221992}, {3.545140733041566, 0.3638568395221992}}, {{
       3.545140733041566, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}, {
       3.545140733041566, 0.3638568395221992}, {3.545140733041566, 
       0.3638568395221992}}, {{3.4803946553187286`, 0.34385104692556}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}, {3.4803946553187286`, 0.34385104692556}, {
       3.4803946553187286`, 0.34385104692556}}, {{3.4803946553187286`, 
       0.34385104692556}, {3.392547878113848, 0.3638568395221992}, {
       3.392547878113848, 0.3638568395221992}, {3.4803946553187286`, 
       0.34385104692556}, {3.4803946553187286`, 0.34385104692556}}, {{
       3.4803946553187286`, 0.34385104692556}, {3.392547878113848, 
       0.3638568395221992}, {3.392547878113848, 0.3638568395221992}, {
       3.4803946553187286`, 0.34385104692556}, {3.4803946553187286`, 
       0.34385104692556}}, {{3.4803946553187286`, 0.34385104692556}, {
       3.392547878113848, 0.3638568395221992}, {3.392547878113848, 
       0.3638568395221992}, {3.4803946553187286`, 0.34385104692556}, {
       3.4803946553187286`, 0.34385104692556}}, {{3.392547878113848, 
       0.6281554171289948}, {3.4803946553187286`, 0.648161209725634}, {
       3.4803946553187286`, 0.648161209725634}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}}, {{
       3.392547878113848, 0.6281554171289948}, {3.4803946553187286`, 
       0.648161209725634}, {3.4803946553187286`, 0.648161209725634}, {
       3.392547878113848, 0.6281554171289948}, {3.392547878113848, 
       0.6281554171289948}}, {{3.392547878113848, 0.6281554171289948}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}, {3.392547878113848, 0.6281554171289948}, {
       3.392547878113848, 0.6281554171289948}}, {{3.392547878113848, 
       0.6281554171289948}, {3.4803946553187286`, 0.648161209725634}, {
       3.4803946553187286`, 0.648161209725634}, {3.392547878113848, 
       0.6281554171289948}, {3.392547878113848, 0.6281554171289948}}, {{
       3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}}, {{3.4803946553187286`, 0.648161209725634}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}, {3.4803946553187286`, 0.648161209725634}, {
       3.4803946553187286`, 0.648161209725634}}, {{3.4803946553187286`, 
       0.648161209725634}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}, {3.4803946553187286`, 
       0.648161209725634}, {3.4803946553187286`, 0.648161209725634}}, {{
       3.4803946553187286`, 0.648161209725634}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}, {
       3.4803946553187286`, 0.648161209725634}, {3.4803946553187286`, 
       0.648161209725634}}, {{3.545140733041566, 0.6281554171289947}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}}, {{3.545140733041566, 
       0.6281554171289947}, {3.5948392965145173`, 0.582086565323935}, {
       3.5948392965145173`, 0.582086565323935}, {3.545140733041566, 
       0.6281554171289947}, {3.545140733041566, 0.6281554171289947}}, {{
       3.545140733041566, 0.6281554171289947}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}, {
       3.545140733041566, 0.6281554171289947}, {3.545140733041566, 
       0.6281554171289947}}, {{3.545140733041566, 0.6281554171289947}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}, {3.545140733041566, 0.6281554171289947}, {
       3.545140733041566, 0.6281554171289947}}, {{3.5948392965145173`, 
       0.582086565323935}, {3.6214371605054256`, 0.496006128325597}, {
       3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}}, {{
       3.5948392965145173`, 0.582086565323935}, {3.6214371605054256`, 
       0.496006128325597}, {3.6214371605054256`, 0.496006128325597}, {
       3.5948392965145173`, 0.582086565323935}, {3.5948392965145173`, 
       0.582086565323935}}, {{3.5948392965145173`, 0.582086565323935}, {
       3.6214371605054256`, 0.496006128325597}, {3.6214371605054256`, 
       0.496006128325597}, {3.5948392965145173`, 0.582086565323935}, {
       3.5948392965145173`, 0.582086565323935}}, {{3.5948392965145173`, 
       0.582086565323935}, {3.6214371605054256`, 0.496006128325597}, {
       3.6214371605054256`, 0.496006128325597}, {3.5948392965145173`, 
       0.582086565323935}, {3.5948392965145173`, 0.582086565323935}}, {{
       3.4609081828876924`, 0.8794844506267455}, {3.3978218899830983`, 
       0.9475412397444591}, {3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.382322971853105, 
       1.0155980288621729`}, {3.3978218899830983`, 0.9475412397444591}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}}, {{3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}}, {{3.696663815991454, 
       1.0155980288621729`}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6180786049568665`, 0.8794844506267455}, {3.5513902376159296`, 
       0.8588785128996379}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}, {3.5513902376159296`, 
       0.8588785128996379}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6692680541678104`, 0.9269353020173516}, {3.696663815991454, 
       1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}}, {{
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}}, {{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}, {{3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}}, {{
       3.4609081828876924`, 0.8794844506267455}, {3.3978218899830983`, 
       0.9475412397444591}, {3.3978218899830983`, 0.9475412397444591}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}}, {{3.4609081828876924`, 0.8794844506267455}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}}, {{3.4609081828876924`, 
       0.8794844506267455}, {3.3978218899830983`, 0.9475412397444591}, {
       3.3978218899830983`, 0.9475412397444591}, {3.4609081828876924`, 
       0.8794844506267455}, {3.4609081828876924`, 0.8794844506267455}}, {{
       3.4609081828876924`, 0.8794844506267455}, {3.3978218899830983`, 
       0.9475412397444591}, {3.3978218899830983`, 0.9475412397444591}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}}, {{3.3978218899830983`, 0.9475412397444591}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.3978218899830983`, 0.9475412397444591}, {
       3.3978218899830983`, 0.9475412397444591}}, {{3.3978218899830983`, 
       0.9475412397444591}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`, 
       0.9475412397444591}, {3.3978218899830983`, 0.9475412397444591}}, {{
       3.3978218899830983`, 0.9475412397444591}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 0.9475412397444591}, {3.3978218899830983`, 
       0.9475412397444591}}, {{3.3978218899830983`, 0.9475412397444591}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}, {3.3978218899830983`, 0.9475412397444591}, {
       3.3978218899830983`, 0.9475412397444591}}, {{3.382322971853105, 
       1.0155980288621729`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}}, {{
       3.382322971853105, 1.0155980288621729`}, {3.3978218899830983`, 
       1.0836548179798866`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.382322971853105, 1.0155980288621729`}, {3.382322971853105, 
       1.0155980288621729`}}, {{3.382322971853105, 1.0155980288621729`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.3978218899830983`, 
       1.0836548179798866`}, {3.382322971853105, 1.0155980288621729`}, {
       3.382322971853105, 1.0155980288621729`}}, {{3.382322971853105, 
       1.0155980288621729`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.382322971853105, 
       1.0155980288621729`}, {3.382322971853105, 1.0155980288621729`}}, {{
       3.3978218899830983`, 1.0836548179798866`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.3978218899830983`, 
       1.0836548179798866`}}, {{3.3978218899830983`, 1.0836548179798866`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.3978218899830983`, 1.0836548179798866`}, {
       3.3978218899830983`, 1.0836548179798866`}}, {{3.3978218899830983`, 
       1.0836548179798866`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.3978218899830983`, 
       1.0836548179798866`}, {3.3978218899830983`, 1.0836548179798866`}}, {{
       3.3978218899830983`, 1.0836548179798866`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.3978218899830983`, 1.0836548179798866`}, {3.3978218899830983`, 
       1.0836548179798866`}}, {{3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 0.9269353020173516}, {3.6692680541678104`, 
       0.9269353020173516}, {3.696663815991454, 1.0155980288621729`}, {
       3.696663815991454, 1.0155980288621729`}}, {{3.696663815991454, 
       1.0155980288621729`}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6692680541678104`, 0.9269353020173516}, {3.696663815991454, 
       1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}}, {{
       3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`, 
       0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}}, {{3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 0.9269353020173516}, {3.6692680541678104`, 
       0.9269353020173516}, {3.696663815991454, 1.0155980288621729`}, {
       3.696663815991454, 1.0155980288621729`}}, {{3.6692680541678104`, 
       0.9269353020173516}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6692680541678104`, 
       0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}}, {{
       3.6692680541678104`, 0.9269353020173516}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6692680541678104`, 0.9269353020173516}, {3.6692680541678104`, 
       0.9269353020173516}}, {{3.6692680541678104`, 0.9269353020173516}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6692680541678104`, 0.9269353020173516}, {
       3.6692680541678104`, 0.9269353020173516}}, {{3.6692680541678104`, 
       0.9269353020173516}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6692680541678104`, 
       0.9269353020173516}, {3.6692680541678104`, 0.9269353020173516}}, {{
       3.6180786049568665`, 0.8794844506267455}, {3.5513902376159296`, 
       0.8588785128996379}, {3.5513902376159296`, 0.8588785128996379}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}}, {{3.6180786049568665`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.5513902376159296`, 
       0.8588785128996379}, {3.6180786049568665`, 0.8794844506267455}, {
       3.6180786049568665`, 0.8794844506267455}}, {{3.6180786049568665`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}, {3.6180786049568665`, 
       0.8794844506267455}, {3.6180786049568665`, 0.8794844506267455}}, {{
       3.6180786049568665`, 0.8794844506267455}, {3.5513902376159296`, 
       0.8588785128996379}, {3.5513902376159296`, 0.8588785128996379}, {
       3.6180786049568665`, 0.8794844506267455}, {3.6180786049568665`, 
       0.8794844506267455}}, {{3.5513902376159296`, 0.8588785128996379}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}}, {{3.5513902376159296`, 
       0.8588785128996379}, {3.4609081828876924`, 0.8794844506267455}, {
       3.4609081828876924`, 0.8794844506267455}, {3.5513902376159296`, 
       0.8588785128996379}, {3.5513902376159296`, 0.8588785128996379}}, {{
       3.5513902376159296`, 0.8588785128996379}, {3.4609081828876924`, 
       0.8794844506267455}, {3.4609081828876924`, 0.8794844506267455}, {
       3.5513902376159296`, 0.8588785128996379}, {3.5513902376159296`, 
       0.8588785128996379}}, {{3.5513902376159296`, 0.8588785128996379}, {
       3.4609081828876924`, 0.8794844506267455}, {3.4609081828876924`, 
       0.8794844506267455}, {3.5513902376159296`, 0.8588785128996379}, {
       3.5513902376159296`, 0.8588785128996379}}, {{3.4609081828876924`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.4609081828876924`, 1.1517116070976003`}}, {{
       3.4609081828876924`, 1.1517116070976003`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.4609081828876924`, 1.1517116070976003`}, {3.4609081828876924`, 
       1.1517116070976003`}}, {{3.4609081828876924`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.4609081828876924`, 1.1517116070976003`}, {
       3.4609081828876924`, 1.1517116070976003`}}, {{3.4609081828876924`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.4609081828876924`, 
       1.1517116070976003`}, {3.4609081828876924`, 1.1517116070976003`}}, {{
       3.5513902376159296`, 1.1723175448247078`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}}, {{3.5513902376159296`, 1.1723175448247078`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.5513902376159296`, 1.1723175448247078`}, {
       3.5513902376159296`, 1.1723175448247078`}}, {{3.5513902376159296`, 
       1.1723175448247078`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.5513902376159296`, 
       1.1723175448247078`}, {3.5513902376159296`, 1.1723175448247078`}}, {{
       3.5513902376159296`, 1.1723175448247078`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.5513902376159296`, 1.1723175448247078`}, {3.5513902376159296`, 
       1.1723175448247078`}}, {{3.6180786049568665`, 1.1517116070976003`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}, {{3.6180786049568665`, 
       1.1517116070976003`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6180786049568665`, 
       1.1517116070976003`}, {3.6180786049568665`, 1.1517116070976003`}}, {{
       3.6180786049568665`, 1.1517116070976003`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.6180786049568665`, 1.1517116070976003`}, {3.6180786049568665`, 
       1.1517116070976003`}}, {{3.6180786049568665`, 1.1517116070976003`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6180786049568665`, 1.1517116070976003`}, {
       3.6180786049568665`, 1.1517116070976003`}}, {{3.6692680541678104`, 
       1.1042607557069941`}, {3.696663815991454, 1.0155980288621729`}, {
       3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6692680541678104`, 1.1042607557069941`}}, {{
       3.6692680541678104`, 1.1042607557069941`}, {3.696663815991454, 
       1.0155980288621729`}, {3.696663815991454, 1.0155980288621729`}, {
       3.6692680541678104`, 1.1042607557069941`}, {3.6692680541678104`, 
       1.1042607557069941`}}, {{3.6692680541678104`, 1.1042607557069941`}, {
       3.696663815991454, 1.0155980288621729`}, {3.696663815991454, 
       1.0155980288621729`}, {3.6692680541678104`, 1.1042607557069941`}, {
       3.6692680541678104`, 1.1042607557069941`}}, {{3.6692680541678104`, 
       1.1042607557069941`}, {3.696663815991454, 1.0155980288621729`}, {
       3.696663815991454, 1.0155980288621729`}, {3.6692680541678104`, 
       1.1042607557069941`}, {3.6692680541678104`, 1.1042607557069941`}}, {{
       3.3932656603378537`, 1.3701247467497086`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.323180942081627, 
       1.4915150396036436`}, {3.3370033559444443`, 1.4308198931766762`}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.3932656603378537`, 
       1.3701247467497086`}}, {{3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}}, {{3.603519815106534, 
       1.4915150396036436`}, {3.579087428611069, 1.4124428815100143`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729, 
       1.351747735083047}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.473960351226729, 
       1.351747735083047}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.579087428611069, 1.4124428815100143`}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}}, {{
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}, {{3.3932656603378537`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.579087428611069, 1.570587197697273}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}, {3.579087428611069, 1.570587197697273}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.473960351226729, 
       1.6312823441242403`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3932656603378537`, 1.6129053324575786`}}, {{3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}}, {{
       3.3932656603378537`, 1.3701247467497086`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3370033559444443`, 1.4308198931766762`}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.3932656603378537`, 
       1.3701247467497086`}}, {{3.3932656603378537`, 1.3701247467497086`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}}, {{3.3932656603378537`, 
       1.3701247467497086`}, {3.3370033559444443`, 1.4308198931766762`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}}, {{
       3.3932656603378537`, 1.3701247467497086`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3370033559444443`, 1.4308198931766762`}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.3932656603378537`, 
       1.3701247467497086`}}, {{3.3370033559444443`, 1.4308198931766762`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.3370033559444443`, 1.4308198931766762`}, {
       3.3370033559444443`, 1.4308198931766762`}}, {{3.3370033559444443`, 
       1.4308198931766762`}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`, 
       1.4308198931766762`}, {3.3370033559444443`, 1.4308198931766762`}}, {{
       3.3370033559444443`, 1.4308198931766762`}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.4308198931766762`}, {3.3370033559444443`, 
       1.4308198931766762`}}, {{3.3370033559444443`, 1.4308198931766762`}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}, {3.3370033559444443`, 1.4308198931766762`}, {
       3.3370033559444443`, 1.4308198931766762`}}, {{3.323180942081627, 
       1.4915150396036436`}, {3.3370033559444443`, 1.552210186030611}, {
       3.3370033559444443`, 1.552210186030611}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}}, {{
       3.323180942081627, 1.4915150396036436`}, {3.3370033559444443`, 
       1.552210186030611}, {3.3370033559444443`, 1.552210186030611}, {
       3.323180942081627, 1.4915150396036436`}, {3.323180942081627, 
       1.4915150396036436`}}, {{3.323180942081627, 1.4915150396036436`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}, {3.323180942081627, 1.4915150396036436`}, {
       3.323180942081627, 1.4915150396036436`}}, {{3.323180942081627, 
       1.4915150396036436`}, {3.3370033559444443`, 1.552210186030611}, {
       3.3370033559444443`, 1.552210186030611}, {3.323180942081627, 
       1.4915150396036436`}, {3.323180942081627, 1.4915150396036436`}}, {{
       3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}}, {{3.3370033559444443`, 1.552210186030611}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3370033559444443`, 1.552210186030611}, {
       3.3370033559444443`, 1.552210186030611}}, {{3.3370033559444443`, 
       1.552210186030611}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3370033559444443`, 
       1.552210186030611}, {3.3370033559444443`, 1.552210186030611}}, {{
       3.3370033559444443`, 1.552210186030611}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3370033559444443`, 1.552210186030611}, {3.3370033559444443`, 
       1.552210186030611}}, {{3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}, {3.603519815106534, 1.4915150396036436`}, {
       3.603519815106534, 1.4915150396036436`}}, {{3.603519815106534, 
       1.4915150396036436`}, {3.579087428611069, 1.4124428815100143`}, {
       3.579087428611069, 1.4124428815100143`}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}}, {{
       3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}}, {{3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}, {3.603519815106534, 1.4915150396036436`}, {
       3.603519815106534, 1.4915150396036436`}}, {{3.579087428611069, 
       1.4124428815100143`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}}, {{
       3.579087428611069, 1.4124428815100143`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.579087428611069, 1.4124428815100143`}, {3.579087428611069, 
       1.4124428815100143`}}, {{3.579087428611069, 1.4124428815100143`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.579087428611069, 1.4124428815100143`}, {
       3.579087428611069, 1.4124428815100143`}}, {{3.579087428611069, 
       1.4124428815100143`}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.579087428611069, 
       1.4124428815100143`}, {3.579087428611069, 1.4124428815100143`}}, {{
       3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729, 
       1.351747735083047}, {3.473960351226729, 1.351747735083047}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}, {{3.5334350968503077`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.473960351226729, 
       1.351747735083047}, {3.5334350968503077`, 1.3701247467497086`}, {
       3.5334350968503077`, 1.3701247467497086`}}, {{3.5334350968503077`, 
       1.3701247467497086`}, {3.473960351226729, 1.351747735083047}, {
       3.473960351226729, 1.351747735083047}, {3.5334350968503077`, 
       1.3701247467497086`}, {3.5334350968503077`, 1.3701247467497086`}}, {{
       3.5334350968503077`, 1.3701247467497086`}, {3.473960351226729, 
       1.351747735083047}, {3.473960351226729, 1.351747735083047}, {
       3.5334350968503077`, 1.3701247467497086`}, {3.5334350968503077`, 
       1.3701247467497086`}}, {{3.473960351226729, 1.351747735083047}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.473960351226729, 1.351747735083047}, {
       3.473960351226729, 1.351747735083047}}, {{3.473960351226729, 
       1.351747735083047}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.473960351226729, 
       1.351747735083047}, {3.473960351226729, 1.351747735083047}}, {{
       3.473960351226729, 1.351747735083047}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.3932656603378537`, 1.3701247467497086`}, {
       3.473960351226729, 1.351747735083047}, {3.473960351226729, 
       1.351747735083047}}, {{3.473960351226729, 1.351747735083047}, {
       3.3932656603378537`, 1.3701247467497086`}, {3.3932656603378537`, 
       1.3701247467497086`}, {3.473960351226729, 1.351747735083047}, {
       3.473960351226729, 1.351747735083047}}, {{3.3932656603378537`, 
       1.6129053324575786`}, {3.473960351226729, 1.6312823441242403`}, {
       3.473960351226729, 1.6312823441242403`}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}}, {{
       3.3932656603378537`, 1.6129053324575786`}, {3.473960351226729, 
       1.6312823441242403`}, {3.473960351226729, 1.6312823441242403`}, {
       3.3932656603378537`, 1.6129053324575786`}, {3.3932656603378537`, 
       1.6129053324575786`}}, {{3.3932656603378537`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}, {3.3932656603378537`, 1.6129053324575786`}, {
       3.3932656603378537`, 1.6129053324575786`}}, {{3.3932656603378537`, 
       1.6129053324575786`}, {3.473960351226729, 1.6312823441242403`}, {
       3.473960351226729, 1.6312823441242403`}, {3.3932656603378537`, 
       1.6129053324575786`}, {3.3932656603378537`, 1.6129053324575786`}}, {{
       3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}}, {{3.473960351226729, 1.6312823441242403`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.473960351226729, 1.6312823441242403`}, {
       3.473960351226729, 1.6312823441242403`}}, {{3.473960351226729, 
       1.6312823441242403`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.473960351226729, 
       1.6312823441242403`}, {3.473960351226729, 1.6312823441242403`}}, {{
       3.473960351226729, 1.6312823441242403`}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.473960351226729, 1.6312823441242403`}, {3.473960351226729, 
       1.6312823441242403`}}, {{3.5334350968503077`, 1.6129053324575786`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}}, {{3.5334350968503077`, 
       1.6129053324575786`}, {3.579087428611069, 1.570587197697273}, {
       3.579087428611069, 1.570587197697273}, {3.5334350968503077`, 
       1.6129053324575786`}, {3.5334350968503077`, 1.6129053324575786`}}, {{
       3.5334350968503077`, 1.6129053324575786`}, {3.579087428611069, 
       1.570587197697273}, {3.579087428611069, 1.570587197697273}, {
       3.5334350968503077`, 1.6129053324575786`}, {3.5334350968503077`, 
       1.6129053324575786`}}, {{3.5334350968503077`, 1.6129053324575786`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}, {3.5334350968503077`, 1.6129053324575786`}, {
       3.5334350968503077`, 1.6129053324575786`}}, {{3.579087428611069, 
       1.570587197697273}, {3.603519815106534, 1.4915150396036436`}, {
       3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.570587197697273}, {3.579087428611069, 1.570587197697273}}, {{
       3.579087428611069, 1.570587197697273}, {3.603519815106534, 
       1.4915150396036436`}, {3.603519815106534, 1.4915150396036436`}, {
       3.579087428611069, 1.570587197697273}, {3.579087428611069, 
       1.570587197697273}}, {{3.579087428611069, 1.570587197697273}, {
       3.603519815106534, 1.4915150396036436`}, {3.603519815106534, 
       1.4915150396036436`}, {3.579087428611069, 1.570587197697273}, {
       3.579087428611069, 1.570587197697273}}, {{3.579087428611069, 
       1.570587197697273}, {3.603519815106534, 1.4915150396036436`}, {
       3.603519815106534, 1.4915150396036436`}, {3.579087428611069, 
       1.570587197697273}, {3.579087428611069, 1.570587197697273}}, {{
       3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 2.0660510715613603`}, {3.4739269594743862`, 
       2.1231143175752094`}, {3.4739269594743862`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}, {{3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}}, {{3.6715998421559632`, 
       2.0089878255475115`}, {3.6486294505617396`, 1.934647218830762}, {
       3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.4739269594743867`, 1.894861333519814}, {
       3.4739269594743867`, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.605708881262104, 1.894861333519814}, {
       3.6486294505617396`, 1.934647218830762}, {3.6715998421559632`, 
       2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}}, {{
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}, {{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.6486294505617396`, 2.083328432264261}, {
       3.6715998421559632`, 2.0089878255475115`}, {3.6715998421559632`, 
       2.0089878255475115`}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}, {{3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}}, {{
       3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}, {{3.4739269594743862`, 1.894861333519814}, {
       3.421031301322045, 1.9519245795336626`}, {3.421031301322045, 
       1.9519245795336626`}, {3.4739269594743862`, 1.894861333519814}, {
       3.4739269594743862`, 1.894861333519814}}, {{3.4739269594743862`, 
       1.894861333519814}, {3.421031301322045, 1.9519245795336626`}, {
       3.421031301322045, 1.9519245795336626`}, {3.4739269594743862`, 
       1.894861333519814}, {3.4739269594743862`, 1.894861333519814}}, {{
       3.4739269594743862`, 1.894861333519814}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}, {
       3.4739269594743862`, 1.894861333519814}, {3.4739269594743862`, 
       1.894861333519814}}, {{3.421031301322045, 1.9519245795336626`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.421031301322045, 1.9519245795336626`}, {
       3.421031301322045, 1.9519245795336626`}}, {{3.421031301322045, 
       1.9519245795336626`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.421031301322045, 
       1.9519245795336626`}, {3.421031301322045, 1.9519245795336626`}}, {{
       3.421031301322045, 1.9519245795336626`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 1.9519245795336626`}, {3.421031301322045, 
       1.9519245795336626`}}, {{3.421031301322045, 1.9519245795336626`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.421031301322045, 1.9519245795336626`}, {
       3.421031301322045, 1.9519245795336626`}}, {{3.4080359985805275`, 
       2.0089878255475115`}, {3.421031301322045, 2.0660510715613603`}, {
       3.421031301322045, 2.0660510715613603`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}}, {{
       3.4080359985805275`, 2.0089878255475115`}, {3.421031301322045, 
       2.0660510715613603`}, {3.421031301322045, 2.0660510715613603`}, {
       3.4080359985805275`, 2.0089878255475115`}, {3.4080359985805275`, 
       2.0089878255475115`}}, {{3.4080359985805275`, 2.0089878255475115`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}, {3.4080359985805275`, 2.0089878255475115`}, {
       3.4080359985805275`, 2.0089878255475115`}}, {{3.4080359985805275`, 
       2.0089878255475115`}, {3.421031301322045, 2.0660510715613603`}, {
       3.421031301322045, 2.0660510715613603`}, {3.4080359985805275`, 
       2.0089878255475115`}, {3.4080359985805275`, 2.0089878255475115`}}, {{
       3.421031301322045, 2.0660510715613603`}, {3.4739269594743867`, 
       2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}}, {{3.421031301322045, 2.0660510715613603`}, {
       3.4739269594743867`, 2.1231143175752094`}, {3.4739269594743867`, 
       2.1231143175752094`}, {3.421031301322045, 2.0660510715613603`}, {
       3.421031301322045, 2.0660510715613603`}}, {{3.421031301322045, 
       2.0660510715613603`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}, {3.421031301322045, 
       2.0660510715613603`}, {3.421031301322045, 2.0660510715613603`}}, {{
       3.421031301322045, 2.0660510715613603`}, {3.4739269594743867`, 
       2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.421031301322045, 2.0660510715613603`}, {3.421031301322045, 
       2.0660510715613603`}}, {{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}, {{3.6715998421559632`, 
       2.0089878255475115`}, {3.6486294505617396`, 1.934647218830762}, {
       3.6486294505617396`, 1.934647218830762}, {3.6715998421559632`, 
       2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}}, {{
       3.6715998421559632`, 2.0089878255475115`}, {3.6486294505617396`, 
       1.934647218830762}, {3.6486294505617396`, 1.934647218830762}, {
       3.6715998421559632`, 2.0089878255475115`}, {3.6715998421559632`, 
       2.0089878255475115`}}, {{3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}}, {{3.6486294505617396`, 
       1.934647218830762}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.6486294505617396`, 
       1.934647218830762}, {3.6486294505617396`, 1.934647218830762}}, {{
       3.6486294505617396`, 1.934647218830762}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}, {
       3.6486294505617396`, 1.934647218830762}, {3.6486294505617396`, 
       1.934647218830762}}, {{3.6486294505617396`, 1.934647218830762}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}, {3.6486294505617396`, 1.934647218830762}, {
       3.6486294505617396`, 1.934647218830762}}, {{3.6486294505617396`, 
       1.934647218830762}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}, {3.6486294505617396`, 
       1.934647218830762}, {3.6486294505617396`, 1.934647218830762}}, {{
       3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}, {{3.605708881262104, 1.894861333519814}, {
       3.5497930092209513`, 1.877583972816913}, {3.5497930092209513`, 
       1.877583972816913}, {3.605708881262104, 1.894861333519814}, {
       3.605708881262104, 1.894861333519814}}, {{3.605708881262104, 
       1.894861333519814}, {3.5497930092209513`, 1.877583972816913}, {
       3.5497930092209513`, 1.877583972816913}, {3.605708881262104, 
       1.894861333519814}, {3.605708881262104, 1.894861333519814}}, {{
       3.605708881262104, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}, {
       3.605708881262104, 1.894861333519814}, {3.605708881262104, 
       1.894861333519814}}, {{3.5497930092209513`, 1.877583972816913}, {
       3.4739269594743867`, 1.894861333519814}, {3.4739269594743867`, 
       1.894861333519814}, {3.5497930092209513`, 1.877583972816913}, {
       3.5497930092209513`, 1.877583972816913}}, {{3.5497930092209513`, 
       1.877583972816913}, {3.4739269594743867`, 1.894861333519814}, {
       3.4739269594743867`, 1.894861333519814}, {3.5497930092209513`, 
       1.877583972816913}, {3.5497930092209513`, 1.877583972816913}}, {{
       3.5497930092209513`, 1.877583972816913}, {3.4739269594743867`, 
       1.894861333519814}, {3.4739269594743867`, 1.894861333519814}, {
       3.5497930092209513`, 1.877583972816913}, {3.5497930092209513`, 
       1.877583972816913}}, {{3.5497930092209513`, 1.877583972816913}, {
       3.4739269594743867`, 1.894861333519814}, {3.4739269594743867`, 
       1.894861333519814}, {3.5497930092209513`, 1.877583972816913}, {
       3.5497930092209513`, 1.877583972816913}}, {{3.4739269594743867`, 
       2.1231143175752094`}, {3.5497930092209513`, 2.14039167827811}, {
       3.5497930092209513`, 2.14039167827811}, {3.4739269594743867`, 
       2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}}, {{
       3.4739269594743867`, 2.1231143175752094`}, {3.5497930092209513`, 
       2.14039167827811}, {3.5497930092209513`, 2.14039167827811}, {
       3.4739269594743867`, 2.1231143175752094`}, {3.4739269594743867`, 
       2.1231143175752094`}}, {{3.4739269594743867`, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}, {3.4739269594743867`, 2.1231143175752094`}, {
       3.4739269594743867`, 2.1231143175752094`}}, {{3.4739269594743867`, 
       2.1231143175752094`}, {3.5497930092209513`, 2.14039167827811}, {
       3.5497930092209513`, 2.14039167827811}, {3.4739269594743867`, 
       2.1231143175752094`}, {3.4739269594743867`, 2.1231143175752094`}}, {{
       3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}}, {{3.5497930092209513`, 2.14039167827811}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}, {3.5497930092209513`, 2.14039167827811}, {
       3.5497930092209513`, 2.14039167827811}}, {{3.5497930092209513`, 
       2.14039167827811}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}, {3.5497930092209513`, 
       2.14039167827811}, {3.5497930092209513`, 2.14039167827811}}, {{
       3.5497930092209513`, 2.14039167827811}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}, {
       3.5497930092209513`, 2.14039167827811}, {3.5497930092209513`, 
       2.14039167827811}}, {{3.605708881262104, 2.1231143175752094`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}}, {{3.605708881262104, 
       2.1231143175752094`}, {3.6486294505617396`, 2.083328432264261}, {
       3.6486294505617396`, 2.083328432264261}, {3.605708881262104, 
       2.1231143175752094`}, {3.605708881262104, 2.1231143175752094`}}, {{
       3.605708881262104, 2.1231143175752094`}, {3.6486294505617396`, 
       2.083328432264261}, {3.6486294505617396`, 2.083328432264261}, {
       3.605708881262104, 2.1231143175752094`}, {3.605708881262104, 
       2.1231143175752094`}}, {{3.605708881262104, 2.1231143175752094`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}, {3.605708881262104, 2.1231143175752094`}, {
       3.605708881262104, 2.1231143175752094`}}, {{3.6486294505617396`, 
       2.083328432264261}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}, {3.6486294505617396`, 
       2.083328432264261}, {3.6486294505617396`, 2.083328432264261}}, {{
       3.6486294505617396`, 2.083328432264261}, {3.6715998421559632`, 
       2.0089878255475115`}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6486294505617396`, 2.083328432264261}, {3.6486294505617396`, 
       2.083328432264261}}, {{3.6486294505617396`, 2.083328432264261}, {
       3.6715998421559632`, 2.0089878255475115`}, {3.6715998421559632`, 
       2.0089878255475115`}, {3.6486294505617396`, 2.083328432264261}, {
       3.6486294505617396`, 2.083328432264261}}, {{3.6486294505617396`, 
       2.083328432264261}, {3.6715998421559632`, 2.0089878255475115`}, {
       3.6715998421559632`, 2.0089878255475115`}, {3.6486294505617396`, 
       2.083328432264261}, {3.6486294505617396`, 2.083328432264261}}, {{
       3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`, 
       2.432669725717018}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858, 
       2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.313900799082868, 
       2.5012355781908706`}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}, {{3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}}, {{3.6305929061468283`, 
       2.5012355781908706`}, {3.602992224598956, 2.411909656007609}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.4842326844499705`, 
       2.343343803533757}, {3.3930738258488584`, 2.3641038732431654`}, {
       3.3930738258488584`, 2.3641038732431654`}, {3.4842326844499705`, 
       2.343343803533757}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.602992224598956, 2.411909656007609}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}}, {{
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}}, {{3.3930738258488584`, 2.638367283138576}, {
       3.4842326844499705`, 2.6591273528479844`}, {3.5514198793808385`, 
       2.638367283138576}, {3.602992224598956, 2.590561500374132}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.602992224598956, 2.590561500374132}, {
       3.5514198793808385`, 2.638367283138576}, {3.4842326844499705`, 
       2.6591273528479844`}, {3.3930738258488584`, 2.638367283138576}, {
       3.3930738258488584`, 2.638367283138576}}, {{3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}}, {{
       3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`, 
       2.432669725717018}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}, {{3.393073825848858, 2.3641038732431654`}, {
       3.3295156487956183`, 2.432669725717018}, {3.3295156487956183`, 
       2.432669725717018}, {3.393073825848858, 2.3641038732431654`}, {
       3.393073825848858, 2.3641038732431654`}}, {{3.393073825848858, 
       2.3641038732431654`}, {3.3295156487956183`, 2.432669725717018}, {
       3.3295156487956183`, 2.432669725717018}, {3.393073825848858, 
       2.3641038732431654`}, {3.393073825848858, 2.3641038732431654`}}, {{
       3.393073825848858, 2.3641038732431654`}, {3.3295156487956183`, 
       2.432669725717018}, {3.3295156487956183`, 2.432669725717018}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}}, {{3.3295156487956183`, 2.432669725717018}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.3295156487956183`, 2.432669725717018}, {
       3.3295156487956183`, 2.432669725717018}}, {{3.3295156487956183`, 
       2.432669725717018}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}, {3.3295156487956183`, 
       2.432669725717018}, {3.3295156487956183`, 2.432669725717018}}, {{
       3.3295156487956183`, 2.432669725717018}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.432669725717018}, {3.3295156487956183`, 
       2.432669725717018}}, {{3.3295156487956183`, 2.432669725717018}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}, {3.3295156487956183`, 2.432669725717018}, {
       3.3295156487956183`, 2.432669725717018}}, {{3.313900799082868, 
       2.5012355781908706`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}}, {{
       3.313900799082868, 2.5012355781908706`}, {3.3295156487956183`, 
       2.5698014306647234`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.313900799082868, 2.5012355781908706`}, {3.313900799082868, 
       2.5012355781908706`}}, {{3.313900799082868, 2.5012355781908706`}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}, {3.313900799082868, 2.5012355781908706`}, {
       3.313900799082868, 2.5012355781908706`}}, {{3.313900799082868, 
       2.5012355781908706`}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.313900799082868, 
       2.5012355781908706`}, {3.313900799082868, 2.5012355781908706`}}, {{
       3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858, 
       2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}}, {{3.3295156487956183`, 2.5698014306647234`}, {
       3.393073825848858, 2.638367283138576}, {3.393073825848858, 
       2.638367283138576}, {3.3295156487956183`, 2.5698014306647234`}, {
       3.3295156487956183`, 2.5698014306647234`}}, {{3.3295156487956183`, 
       2.5698014306647234`}, {3.393073825848858, 2.638367283138576}, {
       3.393073825848858, 2.638367283138576}, {3.3295156487956183`, 
       2.5698014306647234`}, {3.3295156487956183`, 2.5698014306647234`}}, {{
       3.3295156487956183`, 2.5698014306647234`}, {3.393073825848858, 
       2.638367283138576}, {3.393073825848858, 2.638367283138576}, {
       3.3295156487956183`, 2.5698014306647234`}, {3.3295156487956183`, 
       2.5698014306647234`}}, {{3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.6305929061468283`, 2.5012355781908706`}}, {{3.6305929061468283`, 
       2.5012355781908706`}, {3.602992224598956, 2.411909656007609}, {
       3.602992224598956, 2.411909656007609}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}}, {{
       3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956, 
       2.411909656007609}, {3.602992224598956, 2.411909656007609}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}}, {{3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.6305929061468283`, 2.5012355781908706`}}, {{3.602992224598956, 
       2.411909656007609}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.602992224598956, 
       2.411909656007609}, {3.602992224598956, 2.411909656007609}}, {{
       3.602992224598956, 2.411909656007609}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.602992224598956, 2.411909656007609}, {3.602992224598956, 
       2.411909656007609}}, {{3.602992224598956, 2.411909656007609}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.602992224598956, 2.411909656007609}, {
       3.602992224598956, 2.411909656007609}}, {{3.602992224598956, 
       2.411909656007609}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.602992224598956, 
       2.411909656007609}, {3.602992224598956, 2.411909656007609}}, {{
       3.5514198793808385`, 2.3641038732431654`}, {3.4842326844499705`, 
       2.343343803533757}, {3.4842326844499705`, 2.343343803533757}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}}, {{3.5514198793808385`, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}, {3.5514198793808385`, 2.3641038732431654`}, {
       3.5514198793808385`, 2.3641038732431654`}}, {{3.5514198793808385`, 
       2.3641038732431654`}, {3.4842326844499705`, 2.343343803533757}, {
       3.4842326844499705`, 2.343343803533757}, {3.5514198793808385`, 
       2.3641038732431654`}, {3.5514198793808385`, 2.3641038732431654`}}, {{
       3.5514198793808385`, 2.3641038732431654`}, {3.4842326844499705`, 
       2.343343803533757}, {3.4842326844499705`, 2.343343803533757}, {
       3.5514198793808385`, 2.3641038732431654`}, {3.5514198793808385`, 
       2.3641038732431654`}}, {{3.4842326844499705`, 2.343343803533757}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}, {3.4842326844499705`, 2.343343803533757}, {
       3.4842326844499705`, 2.343343803533757}}, {{3.4842326844499705`, 
       2.343343803533757}, {3.393073825848858, 2.3641038732431654`}, {
       3.393073825848858, 2.3641038732431654`}, {3.4842326844499705`, 
       2.343343803533757}, {3.4842326844499705`, 2.343343803533757}}, {{
       3.4842326844499705`, 2.343343803533757}, {3.393073825848858, 
       2.3641038732431654`}, {3.393073825848858, 2.3641038732431654`}, {
       3.4842326844499705`, 2.343343803533757}, {3.4842326844499705`, 
       2.343343803533757}}, {{3.4842326844499705`, 2.343343803533757}, {
       3.393073825848858, 2.3641038732431654`}, {3.393073825848858, 
       2.3641038732431654`}, {3.4842326844499705`, 2.343343803533757}, {
       3.4842326844499705`, 2.343343803533757}}, {{3.3930738258488584`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}, {3.3930738258488584`, 
       2.638367283138576}, {3.3930738258488584`, 2.638367283138576}}, {{
       3.3930738258488584`, 2.638367283138576}, {3.4842326844499705`, 
       2.6591273528479844`}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.3930738258488584`, 2.638367283138576}, {3.3930738258488584`, 
       2.638367283138576}}, {{3.3930738258488584`, 2.638367283138576}, {
       3.4842326844499705`, 2.6591273528479844`}, {3.4842326844499705`, 
       2.6591273528479844`}, {3.3930738258488584`, 2.638367283138576}, {
       3.3930738258488584`, 2.638367283138576}}, {{3.3930738258488584`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}, {3.3930738258488584`, 
       2.638367283138576}, {3.3930738258488584`, 2.638367283138576}}, {{
       3.4842326844499705`, 2.6591273528479844`}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.4842326844499705`, 2.6591273528479844`}, {3.4842326844499705`, 
       2.6591273528479844`}}, {{3.4842326844499705`, 2.6591273528479844`}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}, {3.4842326844499705`, 2.6591273528479844`}, {
       3.4842326844499705`, 2.6591273528479844`}}, {{3.4842326844499705`, 
       2.6591273528479844`}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}, {3.4842326844499705`, 
       2.6591273528479844`}, {3.4842326844499705`, 2.6591273528479844`}}, {{
       3.4842326844499705`, 2.6591273528479844`}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}, {
       3.4842326844499705`, 2.6591273528479844`}, {3.4842326844499705`, 
       2.6591273528479844`}}, {{3.5514198793808385`, 2.638367283138576}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}}, {{3.5514198793808385`, 
       2.638367283138576}, {3.602992224598956, 2.590561500374132}, {
       3.602992224598956, 2.590561500374132}, {3.5514198793808385`, 
       2.638367283138576}, {3.5514198793808385`, 2.638367283138576}}, {{
       3.5514198793808385`, 2.638367283138576}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}, {
       3.5514198793808385`, 2.638367283138576}, {3.5514198793808385`, 
       2.638367283138576}}, {{3.5514198793808385`, 2.638367283138576}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}, {3.5514198793808385`, 2.638367283138576}, {
       3.5514198793808385`, 2.638367283138576}}, {{3.602992224598956, 
       2.590561500374132}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}}, {{
       3.602992224598956, 2.590561500374132}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.602992224598956, 2.590561500374132}, {3.602992224598956, 
       2.590561500374132}}, {{3.602992224598956, 2.590561500374132}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.6305929061468283`, 
       2.5012355781908706`}, {3.602992224598956, 2.590561500374132}, {
       3.602992224598956, 2.590561500374132}}, {{3.602992224598956, 
       2.590561500374132}, {3.6305929061468283`, 2.5012355781908706`}, {
       3.6305929061468283`, 2.5012355781908706`}, {3.602992224598956, 
       2.590561500374132}, {3.602992224598956, 2.590561500374132}}, {{
       3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614, 
       3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.338123279802715, 
       3.02017230453673}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}, {{3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}}, {{3.667963725626311, 
       3.02017230453673}, {3.639217126315117, 2.927137772449133}, {
       3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.420583391258614, 2.877347201897321}, {
       3.420583391258614, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.585503614170412, 2.877347201897321}, {
       3.639217126315117, 2.927137772449133}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}}, {{
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}, {{3.420583391258614, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412, 
       3.1629974071761393`}, {3.639217126315117, 3.113206836624327}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}, {3.639217126315117, 3.113206836624327}, {
       3.585503614170412, 3.1629974071761393`}, {3.5155269591312686`, 
       3.1846193879440317`}, {3.420583391258614, 3.1629974071761393`}, {
       3.420583391258614, 3.1629974071761393`}}, {{3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}}, {{
       3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}, {{3.420583391258614, 2.877347201897321}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.420583391258614, 2.877347201897321}, {
       3.420583391258614, 2.877347201897321}}, {{3.420583391258614, 
       2.877347201897321}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.420583391258614, 
       2.877347201897321}, {3.420583391258614, 2.877347201897321}}, {{
       3.420583391258614, 2.877347201897321}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}}, {{3.3543864226971536`, 2.9487597532170255`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.3543864226971536`, 2.9487597532170255`}}, {{3.3543864226971536`, 
       2.9487597532170255`}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}, {3.3543864226971536`, 
       2.9487597532170255`}, {3.3543864226971536`, 2.9487597532170255`}}, {{
       3.3543864226971536`, 2.9487597532170255`}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 2.9487597532170255`}, {3.3543864226971536`, 
       2.9487597532170255`}}, {{3.3543864226971536`, 2.9487597532170255`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}, {3.3543864226971536`, 2.9487597532170255`}, {
       3.3543864226971536`, 2.9487597532170255`}}, {{3.338123279802715, 
       3.02017230453673}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}}, {{
       3.338123279802715, 3.02017230453673}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.338123279802715, 3.02017230453673}, {3.338123279802715, 
       3.02017230453673}}, {{3.338123279802715, 3.02017230453673}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.338123279802715, 3.02017230453673}, {
       3.338123279802715, 3.02017230453673}}, {{3.338123279802715, 
       3.02017230453673}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.338123279802715, 
       3.02017230453673}, {3.338123279802715, 3.02017230453673}}, {{
       3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614, 
       3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}}, {{3.3543864226971536`, 3.0915848558564347`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}, {3.3543864226971536`, 3.0915848558564347`}, {
       3.3543864226971536`, 3.0915848558564347`}}, {{3.3543864226971536`, 
       3.0915848558564347`}, {3.420583391258614, 3.1629974071761393`}, {
       3.420583391258614, 3.1629974071761393`}, {3.3543864226971536`, 
       3.0915848558564347`}, {3.3543864226971536`, 3.0915848558564347`}}, {{
       3.3543864226971536`, 3.0915848558564347`}, {3.420583391258614, 
       3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}, {
       3.3543864226971536`, 3.0915848558564347`}, {3.3543864226971536`, 
       3.0915848558564347`}}, {{3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}, {3.667963725626311, 3.02017230453673}, {
       3.667963725626311, 3.02017230453673}}, {{3.667963725626311, 
       3.02017230453673}, {3.639217126315117, 2.927137772449133}, {
       3.639217126315117, 2.927137772449133}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}}, {{
       3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}}, {{3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}, {3.667963725626311, 3.02017230453673}, {
       3.667963725626311, 3.02017230453673}}, {{3.639217126315117, 
       2.927137772449133}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}}, {{
       3.639217126315117, 2.927137772449133}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}, {
       3.639217126315117, 2.927137772449133}, {3.639217126315117, 
       2.927137772449133}}, {{3.639217126315117, 2.927137772449133}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}, {3.639217126315117, 2.927137772449133}, {
       3.639217126315117, 2.927137772449133}}, {{3.639217126315117, 
       2.927137772449133}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}, {3.639217126315117, 
       2.927137772449133}, {3.639217126315117, 2.927137772449133}}, {{
       3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}, {{3.585503614170412, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.585503614170412, 2.877347201897321}, {
       3.585503614170412, 2.877347201897321}}, {{3.585503614170412, 
       2.877347201897321}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.585503614170412, 
       2.877347201897321}, {3.585503614170412, 2.877347201897321}}, {{
       3.585503614170412, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.585503614170412, 2.877347201897321}, {3.585503614170412, 
       2.877347201897321}}, {{3.5155269591312686`, 2.8557252211294286`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.5155269591312686`, 2.8557252211294286`}}, {{3.5155269591312686`, 
       2.8557252211294286`}, {3.420583391258614, 2.877347201897321}, {
       3.420583391258614, 2.877347201897321}, {3.5155269591312686`, 
       2.8557252211294286`}, {3.5155269591312686`, 2.8557252211294286`}}, {{
       3.5155269591312686`, 2.8557252211294286`}, {3.420583391258614, 
       2.877347201897321}, {3.420583391258614, 2.877347201897321}, {
       3.5155269591312686`, 2.8557252211294286`}, {3.5155269591312686`, 
       2.8557252211294286`}}, {{3.5155269591312686`, 2.8557252211294286`}, {
       3.420583391258614, 2.877347201897321}, {3.420583391258614, 
       2.877347201897321}, {3.5155269591312686`, 2.8557252211294286`}, {
       3.5155269591312686`, 2.8557252211294286`}}, {{3.420583391258614, 
       3.1629974071761393`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.420583391258614, 
       3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}}, {{
       3.420583391258614, 3.1629974071761393`}, {3.5155269591312686`, 
       3.1846193879440317`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.420583391258614, 3.1629974071761393`}, {3.420583391258614, 
       3.1629974071761393`}}, {{3.420583391258614, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}, {3.420583391258614, 3.1629974071761393`}, {
       3.420583391258614, 3.1629974071761393`}}, {{3.420583391258614, 
       3.1629974071761393`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.420583391258614, 
       3.1629974071761393`}, {3.420583391258614, 3.1629974071761393`}}, {{
       3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}}, {{3.5155269591312686`, 3.1846193879440317`}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}, {3.5155269591312686`, 3.1846193879440317`}, {
       3.5155269591312686`, 3.1846193879440317`}}, {{3.5155269591312686`, 
       3.1846193879440317`}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}, {3.5155269591312686`, 
       3.1846193879440317`}, {3.5155269591312686`, 3.1846193879440317`}}, {{
       3.5155269591312686`, 3.1846193879440317`}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}, {
       3.5155269591312686`, 3.1846193879440317`}, {3.5155269591312686`, 
       3.1846193879440317`}}, {{3.585503614170412, 3.1629974071761393`}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}}, {{3.585503614170412, 
       3.1629974071761393`}, {3.639217126315117, 3.113206836624327}, {
       3.639217126315117, 3.113206836624327}, {3.585503614170412, 
       3.1629974071761393`}, {3.585503614170412, 3.1629974071761393`}}, {{
       3.585503614170412, 3.1629974071761393`}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}, {
       3.585503614170412, 3.1629974071761393`}, {3.585503614170412, 
       3.1629974071761393`}}, {{3.585503614170412, 3.1629974071761393`}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}, {3.585503614170412, 3.1629974071761393`}, {
       3.585503614170412, 3.1629974071761393`}}, {{3.639217126315117, 
       3.113206836624327}, {3.667963725626311, 3.02017230453673}, {
       3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}}, {{
       3.639217126315117, 3.113206836624327}, {3.667963725626311, 
       3.02017230453673}, {3.667963725626311, 3.02017230453673}, {
       3.639217126315117, 3.113206836624327}, {3.639217126315117, 
       3.113206836624327}}, {{3.639217126315117, 3.113206836624327}, {
       3.667963725626311, 3.02017230453673}, {3.667963725626311, 
       3.02017230453673}, {3.639217126315117, 3.113206836624327}, {
       3.639217126315117, 3.113206836624327}}, {{3.639217126315117, 
       3.113206836624327}, {3.667963725626311, 3.02017230453673}, {
       3.667963725626311, 3.02017230453673}, {3.639217126315117, 
       3.113206836624327}, {3.639217126315117, 3.113206836624327}}, {{
       3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.3531564528406683`, 
       3.474797770957089}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}, {{3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}}, {{3.6821036109144325`, 
       3.474797770957089}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.4353932423591096`, 3.3323594732598014`}, {
       3.4353932423591096`, 3.3323594732598014`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.653434864350951, 3.3820151988970673`}, {3.6821036109144325`, 
       3.474797770957089}, {3.6821036109144325`, 3.474797770957089}}, {{
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}}, {{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.653434864350951, 3.5675803430171107`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}, {3.6534348643509507`, 3.5675803430171107`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}, {{3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}}, {{
       3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}, {{3.435393242359109, 3.3323594732598014`}, {
       3.369375551208411, 3.403578622108445}, {3.369375551208411, 
       3.403578622108445}, {3.435393242359109, 3.3323594732598014`}, {
       3.435393242359109, 3.3323594732598014`}}, {{3.435393242359109, 
       3.3323594732598014`}, {3.369375551208411, 3.403578622108445}, {
       3.369375551208411, 3.403578622108445}, {3.435393242359109, 
       3.3323594732598014`}, {3.435393242359109, 3.3323594732598014`}}, {{
       3.435393242359109, 3.3323594732598014`}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}}, {{3.369375551208411, 3.403578622108445}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.369375551208411, 3.403578622108445}, {
       3.369375551208411, 3.403578622108445}}, {{3.369375551208411, 
       3.403578622108445}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}, {3.369375551208411, 
       3.403578622108445}, {3.369375551208411, 3.403578622108445}}, {{
       3.369375551208411, 3.403578622108445}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.403578622108445}, {3.369375551208411, 
       3.403578622108445}}, {{3.369375551208411, 3.403578622108445}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}, {3.369375551208411, 3.403578622108445}, {
       3.369375551208411, 3.403578622108445}}, {{3.3531564528406683`, 
       3.474797770957089}, {3.369375551208411, 3.5460169198057327`}, {
       3.369375551208411, 3.5460169198057327`}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}}, {{
       3.3531564528406683`, 3.474797770957089}, {3.369375551208411, 
       3.5460169198057327`}, {3.369375551208411, 3.5460169198057327`}, {
       3.3531564528406683`, 3.474797770957089}, {3.3531564528406683`, 
       3.474797770957089}}, {{3.3531564528406683`, 3.474797770957089}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}, {3.3531564528406683`, 3.474797770957089}, {
       3.3531564528406683`, 3.474797770957089}}, {{3.3531564528406683`, 
       3.474797770957089}, {3.369375551208411, 3.5460169198057327`}, {
       3.369375551208411, 3.5460169198057327`}, {3.3531564528406683`, 
       3.474797770957089}, {3.3531564528406683`, 3.474797770957089}}, {{
       3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}}, {{3.369375551208411, 3.5460169198057327`}, {
       3.435393242359109, 3.6172360686543765`}, {3.435393242359109, 
       3.6172360686543765`}, {3.369375551208411, 3.5460169198057327`}, {
       3.369375551208411, 3.5460169198057327`}}, {{3.369375551208411, 
       3.5460169198057327`}, {3.435393242359109, 3.6172360686543765`}, {
       3.435393242359109, 3.6172360686543765`}, {3.369375551208411, 
       3.5460169198057327`}, {3.369375551208411, 3.5460169198057327`}}, {{
       3.369375551208411, 3.5460169198057327`}, {3.435393242359109, 
       3.6172360686543765`}, {3.435393242359109, 3.6172360686543765`}, {
       3.369375551208411, 3.5460169198057327`}, {3.369375551208411, 
       3.5460169198057327`}}, {{3.6821036109144325`, 3.474797770957089}, {
       3.6534348643509507`, 3.3820151988970673`}, {3.6534348643509507`, 
       3.3820151988970673`}, {3.6821036109144325`, 3.474797770957089}, {
       3.6821036109144325`, 3.474797770957089}}, {{3.6821036109144325`, 
       3.474797770957089}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6534348643509507`, 3.3820151988970673`}, {3.6821036109144325`, 
       3.474797770957089}, {3.6821036109144325`, 3.474797770957089}}, {{
       3.6821036109144325`, 3.474797770957089}, {3.6534348643509507`, 
       3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}}, {{3.6821036109144325`, 3.474797770957089}, {
       3.6534348643509507`, 3.3820151988970673`}, {3.6534348643509507`, 
       3.3820151988970673`}, {3.6821036109144325`, 3.474797770957089}, {
       3.6821036109144325`, 3.474797770957089}}, {{3.6534348643509507`, 
       3.3820151988970673`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.6534348643509507`, 
       3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}}, {{
       3.6534348643509507`, 3.3820151988970673`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.6534348643509507`, 3.3820151988970673`}, {3.6534348643509507`, 
       3.3820151988970673`}}, {{3.6534348643509507`, 3.3820151988970673`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.6534348643509507`, 3.3820151988970673`}, {
       3.6534348643509507`, 3.3820151988970673`}}, {{3.6534348643509507`, 
       3.3820151988970673`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.6534348643509507`, 
       3.3820151988970673`}, {3.6534348643509507`, 3.3820151988970673`}}, {{
       3.5998668213959917`, 3.3323594732598014`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5300796800732894`, 3.3107960500484235`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}}, {{3.5998668213959917`, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5998668213959917`, 3.3323594732598014`}, {
       3.5998668213959917`, 3.3323594732598014`}}, {{3.5998668213959917`, 
       3.3323594732598014`}, {3.5300796800732894`, 3.3107960500484235`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5998668213959917`, 
       3.3323594732598014`}, {3.5998668213959917`, 3.3323594732598014`}}, {{
       3.5998668213959917`, 3.3323594732598014`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5300796800732894`, 3.3107960500484235`}, {
       3.5998668213959917`, 3.3323594732598014`}, {3.5998668213959917`, 
       3.3323594732598014`}}, {{3.5300796800732894`, 3.3107960500484235`}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}, {3.5300796800732894`, 3.3107960500484235`}, {
       3.5300796800732894`, 3.3107960500484235`}}, {{3.5300796800732894`, 
       3.3107960500484235`}, {3.435393242359109, 3.3323594732598014`}, {
       3.435393242359109, 3.3323594732598014`}, {3.5300796800732894`, 
       3.3107960500484235`}, {3.5300796800732894`, 3.3107960500484235`}}, {{
       3.5300796800732894`, 3.3107960500484235`}, {3.435393242359109, 
       3.3323594732598014`}, {3.435393242359109, 3.3323594732598014`}, {
       3.5300796800732894`, 3.3107960500484235`}, {3.5300796800732894`, 
       3.3107960500484235`}}, {{3.5300796800732894`, 3.3107960500484235`}, {
       3.435393242359109, 3.3323594732598014`}, {3.435393242359109, 
       3.3323594732598014`}, {3.5300796800732894`, 3.3107960500484235`}, {
       3.5300796800732894`, 3.3107960500484235`}}, {{3.4353932423591096`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.4353932423591096`, 
       3.6172360686543765`}, {3.4353932423591096`, 3.6172360686543765`}}, {{
       3.4353932423591096`, 3.6172360686543765`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.4353932423591096`, 3.6172360686543765`}, {3.4353932423591096`, 
       3.6172360686543765`}}, {{3.4353932423591096`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.4353932423591096`, 3.6172360686543765`}, {
       3.4353932423591096`, 3.6172360686543765`}}, {{3.4353932423591096`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.4353932423591096`, 
       3.6172360686543765`}, {3.4353932423591096`, 3.6172360686543765`}}, {{
       3.5300796800732894`, 3.6387994918657545`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}}, {{3.5300796800732894`, 3.6387994918657545`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5300796800732894`, 3.6387994918657545`}, {
       3.5300796800732894`, 3.6387994918657545`}}, {{3.5300796800732894`, 
       3.6387994918657545`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5300796800732894`, 
       3.6387994918657545`}, {3.5300796800732894`, 3.6387994918657545`}}, {{
       3.5300796800732894`, 3.6387994918657545`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5300796800732894`, 3.6387994918657545`}, {3.5300796800732894`, 
       3.6387994918657545`}}, {{3.5998668213959917`, 3.6172360686543765`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}, {{3.5998668213959917`, 
       3.6172360686543765`}, {3.6534348643509507`, 3.5675803430171107`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.5998668213959917`, 
       3.6172360686543765`}, {3.5998668213959917`, 3.6172360686543765`}}, {{
       3.5998668213959917`, 3.6172360686543765`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.6534348643509507`, 3.5675803430171107`}, {
       3.5998668213959917`, 3.6172360686543765`}, {3.5998668213959917`, 
       3.6172360686543765`}}, {{3.5998668213959917`, 3.6172360686543765`}, {
       3.6534348643509507`, 3.5675803430171107`}, {3.6534348643509507`, 
       3.5675803430171107`}, {3.5998668213959917`, 3.6172360686543765`}, {
       3.5998668213959917`, 3.6172360686543765`}}, {{3.653434864350951, 
       3.5675803430171107`}, {3.6821036109144325`, 3.474797770957089}, {
       3.6821036109144325`, 3.474797770957089}, {3.653434864350951, 
       3.5675803430171107`}, {3.653434864350951, 3.5675803430171107`}}, {{
       3.653434864350951, 3.5675803430171107`}, {3.6821036109144325`, 
       3.474797770957089}, {3.6821036109144325`, 3.474797770957089}, {
       3.653434864350951, 3.5675803430171107`}, {3.653434864350951, 
       3.5675803430171107`}}, {{3.653434864350951, 3.5675803430171107`}, {
       3.6821036109144325`, 3.474797770957089}, {3.6821036109144325`, 
       3.474797770957089}, {3.653434864350951, 3.5675803430171107`}, {
       3.653434864350951, 3.5675803430171107`}}, {{3.653434864350951, 
       3.5675803430171107`}, {3.6821036109144325`, 3.474797770957089}, {
       3.6821036109144325`, 3.474797770957089}, {3.653434864350951, 
       3.5675803430171107`}, {3.653434864350951, 3.5675803430171107`}}, {{
       3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}, {{
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}, {{
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}, {{
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}, {{
       3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}, {{
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}, {{
       3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}, {{
       3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}, {{
       3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}, {{
       3.705120167548759, -4.43085718394628}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}}, {{
       3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}, {{
       3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}, {{
       3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}, {{
       3.6407316657003563`, -4.361395586344891}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.361395586344891}, {
       3.6407316657003563`, -4.361395586344891}}, {{
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}, {{
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}, {{
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}, {{
       3.6249128234017527`, -4.291933988743502}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6249128234017527`, -4.291933988743502}, {
       3.6249128234017527`, -4.291933988743502}}, {{
       3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}, {{
       3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}, {{
       3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}, {{
       3.6407316657003563`, -4.222472391142114}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}, {
       3.6407316657003563`, -4.222472391142114}, {
       3.6407316657003563`, -4.222472391142114}}, {{
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}, {{
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}, {{
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}, {{
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}}, {{
       3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}, {{
       3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}, {{
       3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}, {{
       3.917780942803725, -4.382426865856535}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}, {
       3.917780942803725, -4.382426865856535}, {
       3.917780942803725, -4.382426865856535}}, {{
       3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}, {{
       3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}, {{
       3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}, {{
       3.865534855842772, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}, {
       3.865534855842772, -4.43085718394628}, {
       3.865534855842772, -4.43085718394628}}, {{
       3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}, {{
       3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}, {{
       3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}, {{
       3.797469926583215, -4.451888463457923}, {
       3.705120167548759, -4.43085718394628}, {
       3.705120167548759, -4.43085718394628}, {
       3.797469926583215, -4.451888463457923}, {
       3.797469926583215, -4.451888463457923}}, {{
       3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}, {{
       3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}, {{
       3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}, {{
       3.705120167548759, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}, {
       3.705120167548759, -4.153010793540725}, {
       3.705120167548759, -4.153010793540725}}, {{
       3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}, {{
       3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}, {{
       3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}, {{
       3.797469926583215, -4.131979514029082}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}, {
       3.797469926583215, -4.131979514029082}, {
       3.797469926583215, -4.131979514029082}}, {{
       3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}, {{
       3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}, {{
       3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}, {{
       3.865534855842772, -4.153010793540725}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}, {
       3.865534855842772, -4.153010793540725}, {
       3.865534855842772, -4.153010793540725}}, {{
       3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}, {{
       3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}, {{
       3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}, {{
       3.917780942803725, -4.20144111163047}, {
       3.945742199989778, -4.291933988743502}, {
       3.945742199989778, -4.291933988743502}, {
       3.917780942803725, -4.20144111163047}, {
       3.917780942803725, -4.20144111163047}}, {{
       3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}, {{
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}, {{
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}, {{
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}, {{
       3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}, {{
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}, {{
       3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}, {{
       3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}, {{
       3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}, {{
       3.706876710750851, -3.8796647729294342`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}}, {{
       3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}, {{
       3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}, {{
       3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}, {{
       3.6351557550457354`, -3.8022930058939926`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.8022930058939926`}, {
       3.6351557550457354`, -3.8022930058939926`}}, {{
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}, {{
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}, {{
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}, {{
       3.617535489699672, -3.7249212388585504`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.617535489699672, -3.7249212388585504`}, {
       3.617535489699672, -3.7249212388585504`}}, {{
       3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}, {{
       3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}, {{
       3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}, {{
       3.6351557550457354`, -3.6475494718231083`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.6351557550457354`, -3.6475494718231083`}, {
       3.6351557550457354`, -3.6475494718231083`}}, {{
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}, {{
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}, {{
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}, {{
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}}, {{
       3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}, {{
       3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}, {{
       3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}, {{
       3.943754935968561, -3.8257192920005996`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.943754935968561, -3.8257192920005996`}, {
       3.943754935968561, -3.8257192920005996`}}, {{
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}, {{
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}, {{
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}, {{
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8855591528532085`, -3.8796647729294342`}, {
       3.8855591528532085`, -3.8796647729294342`}}, {{
       3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}, {{
       3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}, {{
       3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}, {{
       3.8097431043917926`, -3.9030910590360417`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.706876710750851, -3.8796647729294342`}, {
       3.8097431043917926`, -3.9030910590360417`}, {
       3.8097431043917926`, -3.9030910590360417`}}, {{
       3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}, {{
       3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}, {{
       3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}, {{
       3.706876710750851, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.706876710750851, -3.5701777047876666`}, {
       3.706876710750851, -3.5701777047876666`}}, {{
       3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}, {{
       3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}, {{
       3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}, {{
       3.8097431043917926`, -3.546751418681059}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8097431043917926`, -3.546751418681059}, {
       3.8097431043917926`, -3.546751418681059}}, {{
       3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}, {{
       3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}, {{
       3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}, {{
       3.8855591528532085`, -3.5701777047876666`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.8855591528532085`, -3.5701777047876666`}, {
       3.8855591528532085`, -3.5701777047876666`}}, {{
       3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}, {{
       3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}, {{
       3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}, {{
       3.943754935968561, -3.6241231857165013`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.9749003739043873`, -3.7249212388585504`}, {
       3.943754935968561, -3.6241231857165013`}, {
       3.943754935968561, -3.6241231857165013`}}, {{
       3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}, {{
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}, {{
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}, {{
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}, {{
       3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}, {{
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}, {{
       3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}, {{
       3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}, {{
       3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}, {{
       3.713542580868087, -3.4176617247959467`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}}, {{
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}, {{
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}, {{
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}, {{
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.3521854587101676`}, {
       3.6528483436856356`, -3.3521854587101676`}}, {{
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}, {{
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}, {{
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}, {{
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6379371011677746`, -3.2867091926243885`}, {
       3.6379371011677746`, -3.2867091926243885`}}, {{
       3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}, {{
       3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}, {{
       3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}, {{
       3.6528483436856356`, -3.2212329265386095`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.6528483436856356`, -3.2212329265386095`}, {
       3.6528483436856356`, -3.2212329265386095`}}, {{
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}, {{
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}, {{
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}, {{
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}}, {{
       3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}, {{
       3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}, {{
       3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}, {{
       3.9140020287850152`, -3.372010076930599}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.9140020287850152`, -3.372010076930599}, {
       3.9140020287850152`, -3.372010076930599}}, {{
       3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}, {{
       3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}, {{
       3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}, {{
       3.8647535402687114`, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.8647535402687114`, -3.4176617247959467`}, {
       3.8647535402687114`, -3.4176617247959467`}}, {{
       3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}, {{
       3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}, {{
       3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}, {{
       3.800593809234547, -3.4374863430163782`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.713542580868087, -3.4176617247959467`}, {
       3.800593809234547, -3.4374863430163782`}, {
       3.800593809234547, -3.4374863430163782`}}, {{
       3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}, {{
       3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}, {{
       3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}, {{
       3.713542580868087, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}, {
       3.713542580868087, -3.1557566604528304`}, {
       3.713542580868087, -3.1557566604528304`}}, {{
       3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}, {{
       3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}, {{
       3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}, {{
       3.800593809234547, -3.135932042232399}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.800593809234547, -3.135932042232399}, {
       3.800593809234547, -3.135932042232399}}, {{
       3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}, {{
       3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}, {{
       3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}, {{
       3.8647535402687114`, -3.1557566604528304`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.8647535402687114`, -3.1557566604528304`}, {
       3.8647535402687114`, -3.1557566604528304`}}, {{
       3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}, {{
       3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}, {{
       3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}, {{
       3.9140020287850152`, -3.201408308318178}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9403590199690237`, -3.2867091926243885`}, {
       3.9140020287850152`, -3.201408308318178}, {
       3.9140020287850152`, -3.201408308318178}}, {{
       3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}, {{
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}, {{
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}, {{
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}, {{
       3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}, {{
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}, {{
       3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}, {{
       3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}, {{
       3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}, {{
       3.6426807061761357`, -2.8775854810731496`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}}, {{
       3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}, {{
       3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}, {{
       3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}, {{
       3.580844817107348, -2.8108776136664355`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.8108776136664355`}, {
       3.580844817107348, -2.8108776136664355`}}, {{
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}, {{
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}, {{
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}, {{
       3.5656530957674706`, -2.744169746259721}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.5656530957674706`, -2.744169746259721}, {
       3.5656530957674706`, -2.744169746259721}}, {{
       3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}, {{
       3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}, {{
       3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}, {{
       3.580844817107348, -2.6774618788530065`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.580844817107348, -2.6774618788530065`}, {
       3.580844817107348, -2.6774618788530065`}}, {{
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}, {{
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}, {{
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}, {{
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}}, {{
       3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}, {{
       3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}, {{
       3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}, {{
       3.8469107741300252`, -2.831075130762245}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.8469107741300252`, -2.831075130762245}, {
       3.8469107741300252`, -2.831075130762245}}, {{
       3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}, {{
       3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}, {{
       3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}, {{
       3.796735926993465, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}, {
       3.796735926993465, -2.8775854810731496`}, {
       3.796735926993465, -2.8775854810731496`}}, {{
       3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}, {{
       3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}, {{
       3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}, {{
       3.731369358517028, -2.897782998168959}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.6426807061761357`, -2.8775854810731496`}, {
       3.731369358517028, -2.897782998168959}, {
       3.731369358517028, -2.897782998168959}}, {{
       3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}, {{
       3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}, {{
       3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}, {{
       3.6426807061761357`, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}, {
       3.6426807061761357`, -2.6107540114462924`}, {
       3.6426807061761357`, -2.6107540114462924`}}, {{
       3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}, {{
       3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}, {{
       3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}, {{
       3.731369358517028, -2.590556494350483}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.731369358517028, -2.590556494350483}, {
       3.731369358517028, -2.590556494350483}}, {{
       3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}, {{
       3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}, {{
       3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}, {{
       3.796735926993465, -2.6107540114462924`}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.796735926993465, -2.6107540114462924`}, {
       3.796735926993465, -2.6107540114462924`}}, {{
       3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}, {{
       3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}, {{
       3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}, {{
       3.8469107741300252`, -2.657264361757197}, {
       3.87376353740213, -2.744169746259721}, {
       3.87376353740213, -2.744169746259721}, {
       3.8469107741300252`, -2.657264361757197}, {
       3.8469107741300252`, -2.657264361757197}}, {{
       3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}, {{
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}, {{
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}, {{
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}, {{
       3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}, {{
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}, {{
       3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}, {{
       3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}, {{
       3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}, {{
       3.721140869943381, -2.3339351400354946`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}}, {{
       3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}, {{
       3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}, {{
       3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}, {{
       3.667202944561985, -2.2757475077604443`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.2757475077604443`}, {
       3.667202944561985, -2.2757475077604443`}}, {{
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}, {{
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}, {{
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}, {{
       3.6539515796283664`, -2.217559875485394}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.6539515796283664`, -2.217559875485394}, {
       3.6539515796283664`, -2.217559875485394}}, {{
       3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}, {{
       3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}, {{
       3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}, {{
       3.667202944561985, -2.1593722432103437`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.667202944561985, -2.1593722432103437`}, {
       3.667202944561985, -2.1593722432103437`}}, {{
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}, {{
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}, {{
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}, {{
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}}, {{
       3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}, {{
       3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}, {{
       3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}, {{
       3.899285735842862, -2.2933653052306378`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.899285735842862, -2.2933653052306378`}, {
       3.899285735842862, -2.2933653052306378`}}, {{
       3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}, {{
       3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}, {{
       3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}, {{
       3.8555194505734103`, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}, {
       3.8555194505734103`, -2.3339351400354946`}, {
       3.8555194505734103`, -2.3339351400354946`}}, {{
       3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}, {{
       3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}, {{
       3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}, {{
       3.79850180037034, -2.351552937505688}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.721140869943381, -2.3339351400354946`}, {
       3.79850180037034, -2.351552937505688}, {
       3.79850180037034, -2.351552937505688}}, {{
       3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}, {{
       3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}, {{
       3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}, {{
       3.721140869943381, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}, {
       3.721140869943381, -2.1011846109352934`}, {
       3.721140869943381, -2.1011846109352934`}}, {{
       3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}, {{
       3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}, {{
       3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}, {{
       3.79850180037034, -2.0835668134651}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.79850180037034, -2.0835668134651}, {
       3.79850180037034, -2.0835668134651}}, {{
       3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}, {{
       3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}, {{
       3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}, {{
       3.8555194505734103`, -2.1011846109352934`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.8555194505734103`, -2.1011846109352934`}, {
       3.8555194505734103`, -2.1011846109352934`}}, {{
       3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}, {{
       3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}, {{
       3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}, {{
       3.899285735842862, -2.1417544457401503`}, {
       3.922708740888425, -2.217559875485394}, {
       3.922708740888425, -2.217559875485394}, {
       3.899285735842862, -2.1417544457401503`}, {
       3.899285735842862, -2.1417544457401503`}}, {{
       3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}, {{
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}, {{
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}, {{
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}, {{
       3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}, {{
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}, {{
       3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}, {{
       3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}, {{
       3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}, {{
       3.633486558190147, -1.9068770461488445`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}}, {{
       3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}, {{
       3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}, {{
       3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}, {{
       3.579397580536265, -1.8485264603670812`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.8485264603670812`}, {
       3.579397580536265, -1.8485264603670812`}}, {{
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}, {{
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}, {{
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}, {{
       3.5661091053732004`, -1.790175874585318}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.5661091053732004`, -1.790175874585318}, {
       3.5661091053732004`, -1.790175874585318}}, {{
       3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}, {{
       3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}, {{
       3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}, {{
       3.579397580536265, -1.7318252888035548`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.579397580536265, -1.7318252888035548`}, {
       3.579397580536265, -1.7318252888035548`}}, {{
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}, {{
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}, {{
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}, {{
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}}, {{
       3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}, {{
       3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}, {{
       3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}, {{
       3.8121303158552178`, -1.86619359618919}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.8121303158552178`, -1.86619359618919}, {
       3.8121303158552178`, -1.86619359618919}}, {{
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}, {{
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}, {{
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}, {{
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7682414638240402`, -1.9068770461488445`}, {
       3.7682414638240402`, -1.9068770461488445`}}, {{
       3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}, {{
       3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}, {{
       3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}, {{
       3.7110641366297976`, -1.9245441819709532`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.633486558190147, -1.9068770461488445`}, {
       3.7110641366297976`, -1.9245441819709532`}, {
       3.7110641366297976`, -1.9245441819709532`}}, {{
       3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}, {{
       3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}, {{
       3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}, {{
       3.633486558190147, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.633486558190147, -1.6734747030217916`}, {
       3.633486558190147, -1.6734747030217916`}}, {{
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}, {{
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}, {{
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}, {{
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7110641366297976`, -1.6558075671996828`}, {
       3.7110641366297976`, -1.6558075671996828`}}, {{
       3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}, {{
       3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}, {{
       3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}, {{
       3.7682414638240402`, -1.6734747030217916`}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.7682414638240402`, -1.6734747030217916`}, {
       3.7682414638240402`, -1.6734747030217916`}}, {{
       3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}, {{
       3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}, {{
       3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}, {{
       3.8121303158552178`, -1.714158152981446}, {
       3.835618916640987, -1.790175874585318}, {
       3.835618916640987, -1.790175874585318}, {
       3.8121303158552178`, -1.714158152981446}, {
       3.8121303158552178`, -1.714158152981446}}, {{
       3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}, {{
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}, {{
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.9082284200808335`, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}, {{
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}, {{
       3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}, {{
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}, {{
       3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}, {{
       3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}, {{
       3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}, {{
       3.7325945108858876`, -1.397892856395319}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}}, {{
       3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}, {{
       3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}, {{
       3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}, {{
       3.6794168420220243`, -1.340525380371443}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.340525380371443}, {
       3.6794168420220243`, -1.340525380371443}}, {{
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}, {{
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}, {{
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}, {{
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6663522554356587`, -1.2831579043475667`}, {
       3.6663522554356587`, -1.2831579043475667`}}, {{
       3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}, {{
       3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}, {{
       3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}, {{
       3.6794168420220243`, -1.2257904283236905`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.6794168420220243`, -1.2257904283236905`}, {
       3.6794168420220243`, -1.2257904283236905`}}, {{
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}, {{
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}, {{
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}, {{
       3.9313212772365733`, -1.2831579043475667`}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}}, {{
       3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}, {{
       3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}, {{
       3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}, {{
       3.908228420080833, -1.357894854509647}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.908228420080833, -1.357894854509647}, {
       3.908228420080833, -1.357894854509647}}, {{
       3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}, {{
       3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}, {{
       3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}, {{
       3.8650790217863444`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}, {
       3.8650790217863444`, -1.397892856395319}, {
       3.8650790217863444`, -1.397892856395319}}, {{
       3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}, {{
       3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}, {{
       3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}, {{
       3.80886503690549, -1.415262330533523}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.7325945108858876`, -1.397892856395319}, {
       3.80886503690549, -1.415262330533523}, {
       3.80886503690549, -1.415262330533523}}, {{
       3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}, {{
       3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}, {{
       3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}, {{
       3.7325945108858876`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.7325945108858876`, -1.1684229522998144`}, {
       3.7325945108858876`, -1.1684229522998144`}}, {{
       3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}, {{
       3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}, {{
       3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}, {{
       3.80886503690549, -1.1510534781616104`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.80886503690549, -1.1510534781616104`}, {
       3.80886503690549, -1.1510534781616104`}}, {{
       3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}, {{
       3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}, {{
       3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}, {{
       3.8650790217863444`, -1.1684229522998144`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.908228420080833, -1.2084209541854865`}, {
       3.8650790217863444`, -1.1684229522998144`}, {
       3.8650790217863444`, -1.1684229522998144`}}, {{
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}, {{
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}, {{
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}, {{
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9313212772365733`, -1.2831579043475667`}, {
       3.9082284200808335`, -1.2084209541854865`}, {
       3.9082284200808335`, -1.2084209541854865`}}, {{
       3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}, {{
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}, {{
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}, {{
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}, {{
       3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}, {{
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}, {{
       3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}, {{
       3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}, {{
       3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}, {{
       3.71107116074818, -0.8640931589685963}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}}, {{
       3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}, {{
       3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}, {{
       3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}, {{
       3.649705006807634, -0.7978920365787789}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.7978920365787789}, {
       3.649705006807634, -0.7978920365787789}}, {{
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}, {{
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}, {{
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}, {{
       3.634628689083347, -0.7316909141889616}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}, {
       3.634628689083347, -0.7316909141889616}, {
       3.634628689083347, -0.7316909141889616}}, {{
       3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}, {{
       3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}, {{
       3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}, {{
       3.649705006807634, -0.6654897917991442}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}, {
       3.649705006807634, -0.6654897917991442}, {
       3.649705006807634, -0.6654897917991442}}, {{
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}, {{
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}, {{
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}, {{
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}}, {{
       3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}, {{
       3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}, {{
       3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}, {{
       3.913749798964327, -0.8179361236289298}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.913749798964327, -0.8179361236289298}, {
       3.913749798964327, -0.8179361236289298}}, {{
       3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}, {{
       3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}, {{
       3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}, {{
       3.8639561040778454`, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.8639561040778454`, -0.8640931589685963}, {
       3.8639561040778454`, -0.8640931589685963}}, {{
       3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}, {{
       3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}, {{
       3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}, {{
       3.7990860914670774`, -0.8841372460187471}, {
       3.71107116074818, -0.8640931589685963}, {
       3.71107116074818, -0.8640931589685963}, {
       3.7990860914670774`, -0.8841372460187471}, {
       3.7990860914670774`, -0.8841372460187471}}, {{
       3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}, {{
       3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}, {{
       3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}, {{
       3.71107116074818, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.71107116074818, -0.5992886694093269}, {
       3.71107116074818, -0.5992886694093269}}, {{
       3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}, {{
       3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}, {{
       3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}, {{
       3.7990860914670774`, -0.5792445823591761}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.7990860914670774`, -0.5792445823591761}, {
       3.7990860914670774`, -0.5792445823591761}}, {{
       3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}, {{
       3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}, {{
       3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}, {{
       3.8639561040778454`, -0.5992886694093269}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}, {
       3.8639561040778454`, -0.5992886694093269}, {
       3.8639561040778454`, -0.5992886694093269}}, {{
       3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}, {{
       3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}, {{
       3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}, {{
       3.913749798964327, -0.6454457047489934}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.9403985757426785`, -0.7316909141889616}, {
       3.913749798964327, -0.6454457047489934}, {
       3.913749798964327, -0.6454457047489934}}, {{
       3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989236}, {
       3.623727020289535, -0.09441595434989236}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.3160106176676708}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}, {{
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}, {{
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.3898755054402636}, {
       3.623727020289535, -0.3898755054402636}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}, {{
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}, {{
       3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.24214572989507793`}, {
       3.8796024973245427`, -0.24214572989507793`}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}, {{
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}, {{
       3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}, {{
       3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}, {{
       3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}, {{
       3.623727020289535, -0.38987550544026356`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}}, {{
       3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}, {{
       3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}, {{
       3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}, {{
       3.5552568205372825`, -0.31601061766767075`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.31601061766767075`}, {
       3.5552568205372825`, -0.31601061766767075`}}, {{
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}, {{
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}, {{
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}, {{
       3.538435194611199, -0.24214572989507796`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.5552568205372825`, -0.16828084212248517`}, {
       3.538435194611199, -0.24214572989507796`}, {
       3.538435194611199, -0.24214572989507796`}}, {{
       3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}, {{
       3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}, {{
       3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}, {{
       3.5552568205372825`, -0.16828084212248515`}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}, {
       3.5552568205372825`, -0.16828084212248515`}, {
       3.5552568205372825`, -0.16828084212248515`}}, {{
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}, {{
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}, {{
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}, {{
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}}, {{
       3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}, {{
       3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}, {{
       3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}, {{
       3.849868727941917, -0.3383751061690197}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.849868727941917, -0.3383751061690197}, {
       3.849868727941917, -0.3383751061690197}}, {{
       3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}, {{
       3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}, {{
       3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}, {{
       3.7943106716462065`, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}, {
       3.7943106716462065`, -0.38987550544026356`}, {
       3.7943106716462065`, -0.38987550544026356`}}, {{
       3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}, {{
       3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}, {{
       3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}, {{
       3.721930989424413, -0.4122399939416126}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.623727020289535, -0.38987550544026356`}, {
       3.721930989424413, -0.4122399939416126}, {
       3.721930989424413, -0.4122399939416126}}, {{
       3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}, {{
       3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}, {{
       3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}, {{
       3.623727020289535, -0.09441595434989233}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}, {
       3.623727020289535, -0.09441595434989233}, {
       3.623727020289535, -0.09441595434989233}}, {{
       3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}, {{
       3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}, {{
       3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}, {{
       3.721930989424413, -0.07205146584854336}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.721930989424413, -0.07205146584854336}, {
       3.721930989424413, -0.07205146584854336}}, {{
       3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}, {{
       3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}, {{
       3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}, {{
       3.7943106716462065`, -0.09441595434989236}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}, {
       3.7943106716462065`, -0.09441595434989236}, {
       3.7943106716462065`, -0.09441595434989236}}, {{
       3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}, {{
       3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}, {{
       3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}, {{
       3.849868727941917, -0.1459163536211362}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.8796024973245427`, -0.242145729895078}, {
       3.849868727941917, -0.1459163536211362}, {
       3.849868727941917, -0.1459163536211362}}, {{3.6841497319344017`, 
       0.07657465936013377}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`, 
       0.28732293175018514`}, {3.6841497319344017`, 0.3575723558802022}, {
       3.6841497319344017`, 0.3575723558802022}, {3.6190309421046325`, 
       0.2873229317501851}, {3.6030326840706386`, 0.217073507620168}, {
       3.6190309421046325`, 0.14682408349015086`}, {3.6841497319344017`, 
       0.07657465936013377}, {3.6841497319344017`, 0.07657465936013377}}, {{
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}, {{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8463838276619278`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013375}, {3.6841497319344017`, 
       0.07657465936013375}, {3.7775469127471086`, 0.05530484516886244}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}, {{3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}}, {{
       3.6841497319344017`, 0.35757235588020225`}, {3.7775469127471086`, 
       0.3788421700714736}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8992224845427534`, 0.3085927459414564}, {3.927500875525691, 
       0.21707350762016803`}, {3.927500875525691, 0.21707350762016803`}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8463838276619278`, 
       0.3575723558802022}, {3.7775469127471086`, 0.3788421700714736}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}}, {{3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}, {{3.6841497319344017`, 
       0.07657465936013377}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6841497319344017`, 
       0.07657465936013377}, {3.6841497319344017`, 0.07657465936013377}}, {{
       3.6841497319344017`, 0.07657465936013377}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6841497319344017`, 0.07657465936013377}, {3.6841497319344017`, 
       0.07657465936013377}}, {{3.6841497319344017`, 0.07657465936013377}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}}, {{3.6841497319344017`, 
       0.07657465936013377}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6841497319344017`, 
       0.07657465936013377}, {3.6841497319344017`, 0.07657465936013377}}, {{
       3.6190309421046325`, 0.1468240834901509}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}}, {{3.6190309421046325`, 0.1468240834901509}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.1468240834901509}, {
       3.6190309421046325`, 0.1468240834901509}}, {{3.6190309421046325`, 
       0.1468240834901509}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`, 
       0.1468240834901509}, {3.6190309421046325`, 0.1468240834901509}}, {{
       3.6190309421046325`, 0.1468240834901509}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}, {
       3.6190309421046325`, 0.1468240834901509}, {3.6190309421046325`, 
       0.1468240834901509}}, {{3.6030326840706386`, 0.217073507620168}, {
       3.6190309421046325`, 0.2873229317501851}, {3.6190309421046325`, 
       0.2873229317501851}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}}, {{3.6030326840706386`, 
       0.217073507620168}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6190309421046325`, 0.2873229317501851}, {3.6030326840706386`, 
       0.217073507620168}, {3.6030326840706386`, 0.217073507620168}}, {{
       3.6030326840706386`, 0.217073507620168}, {3.6190309421046325`, 
       0.2873229317501851}, {3.6190309421046325`, 0.2873229317501851}, {
       3.6030326840706386`, 0.217073507620168}, {3.6030326840706386`, 
       0.217073507620168}}, {{3.6030326840706386`, 0.217073507620168}, {
       3.6190309421046325`, 0.2873229317501851}, {3.6190309421046325`, 
       0.2873229317501851}, {3.6030326840706386`, 0.217073507620168}, {
       3.6030326840706386`, 0.217073507620168}}, {{3.6190309421046325`, 
       0.28732293175018514`}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6190309421046325`, 
       0.28732293175018514`}, {3.6190309421046325`, 0.28732293175018514`}}, {{
       3.6190309421046325`, 0.28732293175018514`}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6190309421046325`, 0.28732293175018514`}, {3.6190309421046325`, 
       0.28732293175018514`}}, {{3.6190309421046325`, 0.28732293175018514`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6190309421046325`, 0.28732293175018514`}, {
       3.6190309421046325`, 0.28732293175018514`}}, {{3.6190309421046325`, 
       0.28732293175018514`}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6190309421046325`, 
       0.28732293175018514`}, {3.6190309421046325`, 0.28732293175018514`}}, {{
       3.927500875525691, 0.21707350762016797`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.927500875525691, 0.21707350762016797`}, {3.927500875525691, 
       0.21707350762016797`}}, {{3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}}, {{3.927500875525691, 
       0.21707350762016797`}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.927500875525691, 
       0.21707350762016797`}, {3.927500875525691, 0.21707350762016797`}}, {{
       3.927500875525691, 0.21707350762016797`}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.927500875525691, 0.21707350762016797`}, {3.927500875525691, 
       0.21707350762016797`}}, {{3.8992224845427534`, 0.12555426929887958`}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}}, {{3.8992224845427534`, 
       0.12555426929887958`}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8992224845427534`, 
       0.12555426929887958`}, {3.8992224845427534`, 0.12555426929887958`}}, {{
       3.8992224845427534`, 0.12555426929887958`}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8992224845427534`, 0.12555426929887958`}, {3.8992224845427534`, 
       0.12555426929887958`}}, {{3.8992224845427534`, 0.12555426929887958`}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8992224845427534`, 0.12555426929887958`}, {
       3.8992224845427534`, 0.12555426929887958`}}, {{3.8463838276619278`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}}, {{
       3.8463838276619278`, 0.07657465936013377}, {3.7775469127471086`, 
       0.05530484516886244}, {3.7775469127471086`, 0.05530484516886244}, {
       3.8463838276619278`, 0.07657465936013377}, {3.8463838276619278`, 
       0.07657465936013377}}, {{3.8463838276619278`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}, {3.8463838276619278`, 0.07657465936013377}, {
       3.8463838276619278`, 0.07657465936013377}}, {{3.8463838276619278`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}, {3.8463838276619278`, 
       0.07657465936013377}, {3.8463838276619278`, 0.07657465936013377}}, {{
       3.7775469127471086`, 0.05530484516886244}, {3.6841497319344017`, 
       0.07657465936013377}, {3.6841497319344017`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}}, {{3.7775469127471086`, 0.05530484516886244}, {
       3.6841497319344017`, 0.07657465936013377}, {3.6841497319344017`, 
       0.07657465936013377}, {3.7775469127471086`, 0.05530484516886244}, {
       3.7775469127471086`, 0.05530484516886244}}, {{3.7775469127471086`, 
       0.05530484516886244}, {3.6841497319344017`, 0.07657465936013377}, {
       3.6841497319344017`, 0.07657465936013377}, {3.7775469127471086`, 
       0.05530484516886244}, {3.7775469127471086`, 0.05530484516886244}}, {{
       3.7775469127471086`, 0.05530484516886244}, {3.6841497319344017`, 
       0.07657465936013377}, {3.6841497319344017`, 0.07657465936013377}, {
       3.7775469127471086`, 0.05530484516886244}, {3.7775469127471086`, 
       0.05530484516886244}}, {{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}, {{3.6841497319344017`, 
       0.35757235588020225`}, {3.7775469127471086`, 0.3788421700714736}, {
       3.7775469127471086`, 0.3788421700714736}, {3.6841497319344017`, 
       0.35757235588020225`}, {3.6841497319344017`, 0.35757235588020225`}}, {{
       3.6841497319344017`, 0.35757235588020225`}, {3.7775469127471086`, 
       0.3788421700714736}, {3.7775469127471086`, 0.3788421700714736}, {
       3.6841497319344017`, 0.35757235588020225`}, {3.6841497319344017`, 
       0.35757235588020225`}}, {{3.6841497319344017`, 0.35757235588020225`}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}, {3.6841497319344017`, 0.35757235588020225`}, {
       3.6841497319344017`, 0.35757235588020225`}}, {{3.7775469127471086`, 
       0.3788421700714736}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.7775469127471086`, 
       0.3788421700714736}, {3.7775469127471086`, 0.3788421700714736}}, {{
       3.7775469127471086`, 0.3788421700714736}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}, {
       3.7775469127471086`, 0.3788421700714736}, {3.7775469127471086`, 
       0.3788421700714736}}, {{3.7775469127471086`, 0.3788421700714736}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}, {3.7775469127471086`, 0.3788421700714736}, {
       3.7775469127471086`, 0.3788421700714736}}, {{3.7775469127471086`, 
       0.3788421700714736}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}, {3.7775469127471086`, 
       0.3788421700714736}, {3.7775469127471086`, 0.3788421700714736}}, {{
       3.8463838276619278`, 0.3575723558802022}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8992224845427534`, 0.3085927459414564}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}}, {{3.8463838276619278`, 0.3575723558802022}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8463838276619278`, 0.3575723558802022}, {
       3.8463838276619278`, 0.3575723558802022}}, {{3.8463838276619278`, 
       0.3575723558802022}, {3.8992224845427534`, 0.3085927459414564}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8463838276619278`, 
       0.3575723558802022}, {3.8463838276619278`, 0.3575723558802022}}, {{
       3.8463838276619278`, 0.3575723558802022}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8992224845427534`, 0.3085927459414564}, {
       3.8463838276619278`, 0.3575723558802022}, {3.8463838276619278`, 
       0.3575723558802022}}, {{3.8992224845427534`, 0.3085927459414564}, {
       3.927500875525691, 0.21707350762016797`}, {3.927500875525691, 
       0.21707350762016797`}, {3.8992224845427534`, 0.3085927459414564}, {
       3.8992224845427534`, 0.3085927459414564}}, {{3.8992224845427534`, 
       0.3085927459414564}, {3.927500875525691, 0.21707350762016797`}, {
       3.927500875525691, 0.21707350762016797`}, {3.8992224845427534`, 
       0.3085927459414564}, {3.8992224845427534`, 0.3085927459414564}}, {{
       3.8992224845427534`, 0.3085927459414564}, {3.927500875525691, 
       0.21707350762016797`}, {3.927500875525691, 0.21707350762016797`}, {
       3.8992224845427534`, 0.3085927459414564}, {3.8992224845427534`, 
       0.3085927459414564}}, {{3.8992224845427534`, 0.3085927459414564}, {
       3.927500875525691, 0.21707350762016797`}, {3.927500875525691, 
       0.21707350762016797`}, {3.8992224845427534`, 0.3085927459414564}, {
       3.8992224845427534`, 0.3085927459414564}}, {{3.677390132218771, 
       0.6515683873327646}, {3.614303839314177, 0.7196251764504782}, {
       3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.8557387546859057}, {3.677390132218771, 0.9237955438036193}, {
       3.677390132218771, 0.9237955438036193}, {3.614303839314177, 
       0.8557387546859057}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}}, {{
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}}, {{3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.6990192387233707}, {3.834560554287945, 
       0.6515683873327646}, {3.767872186947008, 0.630962449605657}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}, {3.767872186947008, 0.630962449605657}, {
       3.834560554287945, 0.6515683873327646}, {3.885750003498889, 
       0.6990192387233707}, {3.9131457653225326`, 0.7876819655681919}, {
       3.9131457653225326`, 0.7876819655681919}}, {{3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}}, {{
       3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.834560554287945, 0.9237955438036193}, {
       3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.834560554287945, 
       0.9237955438036193}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}, {{3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}}, {{3.677390132218771, 
       0.6515683873327646}, {3.614303839314177, 0.7196251764504782}, {
       3.614303839314177, 0.7196251764504782}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}}, {{
       3.677390132218771, 0.6515683873327646}, {3.614303839314177, 
       0.7196251764504782}, {3.614303839314177, 0.7196251764504782}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}}, {{3.677390132218771, 0.6515683873327646}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}, {3.677390132218771, 0.6515683873327646}, {
       3.677390132218771, 0.6515683873327646}}, {{3.677390132218771, 
       0.6515683873327646}, {3.614303839314177, 0.7196251764504782}, {
       3.614303839314177, 0.7196251764504782}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}}, {{
       3.614303839314177, 0.7196251764504782}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}}, {{3.614303839314177, 0.7196251764504782}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}, {3.614303839314177, 0.7196251764504782}, {
       3.614303839314177, 0.7196251764504782}}, {{3.614303839314177, 
       0.7196251764504782}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.7196251764504782}, {3.614303839314177, 0.7196251764504782}}, {{
       3.614303839314177, 0.7196251764504782}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.7196251764504782}, {3.614303839314177, 
       0.7196251764504782}}, {{3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}}, {{3.5988049211841835`, 
       0.7876819655681919}, {3.614303839314177, 0.8557387546859057}, {
       3.614303839314177, 0.8557387546859057}, {3.5988049211841835`, 
       0.7876819655681919}, {3.5988049211841835`, 0.7876819655681919}}, {{
       3.5988049211841835`, 0.7876819655681919}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}, {
       3.5988049211841835`, 0.7876819655681919}, {3.5988049211841835`, 
       0.7876819655681919}}, {{3.5988049211841835`, 0.7876819655681919}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}, {3.5988049211841835`, 0.7876819655681919}, {
       3.5988049211841835`, 0.7876819655681919}}, {{3.614303839314177, 
       0.8557387546859057}, {3.677390132218771, 0.9237955438036193}, {
       3.677390132218771, 0.9237955438036193}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}}, {{
       3.614303839314177, 0.8557387546859057}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}, {
       3.614303839314177, 0.8557387546859057}, {3.614303839314177, 
       0.8557387546859057}}, {{3.614303839314177, 0.8557387546859057}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}, {3.614303839314177, 0.8557387546859057}, {
       3.614303839314177, 0.8557387546859057}}, {{3.614303839314177, 
       0.8557387546859057}, {3.677390132218771, 0.9237955438036193}, {
       3.677390132218771, 0.9237955438036193}, {3.614303839314177, 
       0.8557387546859057}, {3.614303839314177, 0.8557387546859057}}, {{
       3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}, {{3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.6990192387233707}, {3.885750003498889, 
       0.6990192387233707}, {3.9131457653225326`, 0.7876819655681919}, {
       3.9131457653225326`, 0.7876819655681919}}, {{3.9131457653225326`, 
       0.7876819655681919}, {3.885750003498889, 0.6990192387233707}, {
       3.885750003498889, 0.6990192387233707}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}}, {{
       3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}}, {{3.885750003498889, 0.6990192387233707}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.885750003498889, 0.6990192387233707}, {
       3.885750003498889, 0.6990192387233707}}, {{3.885750003498889, 
       0.6990192387233707}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}, {3.885750003498889, 
       0.6990192387233707}, {3.885750003498889, 0.6990192387233707}}, {{
       3.885750003498889, 0.6990192387233707}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}, {
       3.885750003498889, 0.6990192387233707}, {3.885750003498889, 
       0.6990192387233707}}, {{3.885750003498889, 0.6990192387233707}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}, {3.885750003498889, 0.6990192387233707}, {
       3.885750003498889, 0.6990192387233707}}, {{3.834560554287945, 
       0.6515683873327646}, {3.767872186947008, 0.630962449605657}, {
       3.767872186947008, 0.630962449605657}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}}, {{
       3.834560554287945, 0.6515683873327646}, {3.767872186947008, 
       0.630962449605657}, {3.767872186947008, 0.630962449605657}, {
       3.834560554287945, 0.6515683873327646}, {3.834560554287945, 
       0.6515683873327646}}, {{3.834560554287945, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}, {3.834560554287945, 0.6515683873327646}, {
       3.834560554287945, 0.6515683873327646}}, {{3.834560554287945, 
       0.6515683873327646}, {3.767872186947008, 0.630962449605657}, {
       3.767872186947008, 0.630962449605657}, {3.834560554287945, 
       0.6515683873327646}, {3.834560554287945, 0.6515683873327646}}, {{
       3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}}, {{3.767872186947008, 0.630962449605657}, {
       3.677390132218771, 0.6515683873327646}, {3.677390132218771, 
       0.6515683873327646}, {3.767872186947008, 0.630962449605657}, {
       3.767872186947008, 0.630962449605657}}, {{3.767872186947008, 
       0.630962449605657}, {3.677390132218771, 0.6515683873327646}, {
       3.677390132218771, 0.6515683873327646}, {3.767872186947008, 
       0.630962449605657}, {3.767872186947008, 0.630962449605657}}, {{
       3.767872186947008, 0.630962449605657}, {3.677390132218771, 
       0.6515683873327646}, {3.677390132218771, 0.6515683873327646}, {
       3.767872186947008, 0.630962449605657}, {3.767872186947008, 
       0.630962449605657}}, {{3.677390132218771, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}, {3.677390132218771, 0.9237955438036193}, {
       3.677390132218771, 0.9237955438036193}}, {{3.677390132218771, 
       0.9237955438036193}, {3.767872186947008, 0.9444014815307269}, {
       3.767872186947008, 0.9444014815307269}, {3.677390132218771, 
       0.9237955438036193}, {3.677390132218771, 0.9237955438036193}}, {{
       3.677390132218771, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}, {
       3.677390132218771, 0.9237955438036193}, {3.677390132218771, 
       0.9237955438036193}}, {{3.677390132218771, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}, {3.677390132218771, 0.9237955438036193}, {
       3.677390132218771, 0.9237955438036193}}, {{3.767872186947008, 
       0.9444014815307269}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}}, {{
       3.767872186947008, 0.9444014815307269}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}, {
       3.767872186947008, 0.9444014815307269}, {3.767872186947008, 
       0.9444014815307269}}, {{3.767872186947008, 0.9444014815307269}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}, {3.767872186947008, 0.9444014815307269}, {
       3.767872186947008, 0.9444014815307269}}, {{3.767872186947008, 
       0.9444014815307269}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}, {3.767872186947008, 
       0.9444014815307269}, {3.767872186947008, 0.9444014815307269}}, {{
       3.834560554287945, 0.9237955438036193}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}, {{3.834560554287945, 0.9237955438036193}, {
       3.885750003498889, 0.8763446924130132}, {3.885750003498889, 
       0.8763446924130132}, {3.834560554287945, 0.9237955438036193}, {
       3.834560554287945, 0.9237955438036193}}, {{3.834560554287945, 
       0.9237955438036193}, {3.885750003498889, 0.8763446924130132}, {
       3.885750003498889, 0.8763446924130132}, {3.834560554287945, 
       0.9237955438036193}, {3.834560554287945, 0.9237955438036193}}, {{
       3.834560554287945, 0.9237955438036193}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}, {
       3.834560554287945, 0.9237955438036193}, {3.834560554287945, 
       0.9237955438036193}}, {{3.885750003498889, 0.8763446924130132}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}, {3.885750003498889, 0.8763446924130132}, {
       3.885750003498889, 0.8763446924130132}}, {{3.885750003498889, 
       0.8763446924130132}, {3.9131457653225326`, 0.7876819655681919}, {
       3.9131457653225326`, 0.7876819655681919}, {3.885750003498889, 
       0.8763446924130132}, {3.885750003498889, 0.8763446924130132}}, {{
       3.885750003498889, 0.8763446924130132}, {3.9131457653225326`, 
       0.7876819655681919}, {3.9131457653225326`, 0.7876819655681919}, {
       3.885750003498889, 0.8763446924130132}, {3.885750003498889, 
       0.8763446924130132}}, {{3.885750003498889, 0.8763446924130132}, {
       3.9131457653225326`, 0.7876819655681919}, {3.9131457653225326`, 
       0.7876819655681919}, {3.885750003498889, 0.8763446924130132}, {
       3.885750003498889, 0.8763446924130132}}, {{3.723271125538312, 
       1.1634707003604499`}, {3.663572215605023, 1.2278732185117645`}, {
       3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.3566782548143932`}, {3.723271125538312, 1.4210807729657078`}, {
       3.723271125538312, 1.4210807729657078`}, {3.663572215605023, 
       1.3566782548143932`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}}, {{
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}, {{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}, {{3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}}, {{
       3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.872002370302917, 1.4210807729657078`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.872002370302917, 
       1.4210807729657078`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}, {{3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}}, {{3.723271125538312, 
       1.1634707003604499`}, {3.663572215605023, 1.2278732185117645`}, {
       3.663572215605023, 1.2278732185117645`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}}, {{
       3.723271125538312, 1.1634707003604499`}, {3.663572215605023, 
       1.2278732185117645`}, {3.663572215605023, 1.2278732185117645`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}}, {{3.723271125538312, 1.1634707003604499`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}, {3.723271125538312, 1.1634707003604499`}, {
       3.723271125538312, 1.1634707003604499`}}, {{3.723271125538312, 
       1.1634707003604499`}, {3.663572215605023, 1.2278732185117645`}, {
       3.663572215605023, 1.2278732185117645`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}}, {{
       3.663572215605023, 1.2278732185117645`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}}, {{3.663572215605023, 1.2278732185117645`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}, {3.663572215605023, 1.2278732185117645`}, {
       3.663572215605023, 1.2278732185117645`}}, {{3.663572215605023, 
       1.2278732185117645`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.2278732185117645`}, {3.663572215605023, 1.2278732185117645`}}, {{
       3.663572215605023, 1.2278732185117645`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.2278732185117645`}, {3.663572215605023, 
       1.2278732185117645`}}, {{3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}}, {{3.64890550315601, 
       1.2922757366630788`}, {3.663572215605023, 1.3566782548143932`}, {
       3.663572215605023, 1.3566782548143932`}, {3.64890550315601, 
       1.2922757366630788`}, {3.64890550315601, 1.2922757366630788`}}, {{
       3.64890550315601, 1.2922757366630788`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}, {
       3.64890550315601, 1.2922757366630788`}, {3.64890550315601, 
       1.2922757366630788`}}, {{3.64890550315601, 1.2922757366630788`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}, {3.64890550315601, 1.2922757366630788`}, {
       3.64890550315601, 1.2922757366630788`}}, {{3.663572215605023, 
       1.3566782548143932`}, {3.723271125538312, 1.4210807729657078`}, {
       3.723271125538312, 1.4210807729657078`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}}, {{
       3.663572215605023, 1.3566782548143932`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}, {
       3.663572215605023, 1.3566782548143932`}, {3.663572215605023, 
       1.3566782548143932`}}, {{3.663572215605023, 1.3566782548143932`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}, {3.663572215605023, 1.3566782548143932`}, {
       3.663572215605023, 1.3566782548143932`}}, {{3.663572215605023, 
       1.3566782548143932`}, {3.723271125538312, 1.4210807729657078`}, {
       3.723271125538312, 1.4210807729657078`}, {3.663572215605023, 
       1.3566782548143932`}, {3.663572215605023, 1.3566782548143932`}}, {{
       3.9463679926852193`, 1.2922757366630788`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9204432308651374`, 1.2083737050069538`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}}, {{3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}}, {{3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.2083737050069538`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9463679926852193`, 1.2922757366630788`}}, {{
       3.9463679926852193`, 1.2922757366630788`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9204432308651374`, 1.2083737050069538`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}}, {{3.9204432308651374`, 1.2083737050069538`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.9204432308651374`, 1.2083737050069538`}, {
       3.9204432308651374`, 1.2083737050069538`}}, {{3.9204432308651374`, 
       1.2083737050069538`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}, {3.9204432308651374`, 
       1.2083737050069538`}, {3.9204432308651374`, 1.2083737050069538`}}, {{
       3.9204432308651374`, 1.2083737050069538`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}, {
       3.9204432308651374`, 1.2083737050069538`}, {3.9204432308651374`, 
       1.2083737050069538`}}, {{3.9204432308651374`, 1.2083737050069538`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}, {3.9204432308651374`, 1.2083737050069538`}, {
       3.9204432308651374`, 1.2083737050069538`}}, {{3.872002370302917, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.808894797291684, 1.1439711868556393`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}}, {{
       3.872002370302917, 1.1634707003604499`}, {3.808894797291684, 
       1.1439711868556393`}, {3.808894797291684, 1.1439711868556393`}, {
       3.872002370302917, 1.1634707003604499`}, {3.872002370302917, 
       1.1634707003604499`}}, {{3.872002370302917, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}, {3.872002370302917, 1.1634707003604499`}, {
       3.872002370302917, 1.1634707003604499`}}, {{3.872002370302917, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.808894797291684, 1.1439711868556393`}, {3.872002370302917, 
       1.1634707003604499`}, {3.872002370302917, 1.1634707003604499`}}, {{
       3.808894797291684, 1.1439711868556393`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}}, {{3.808894797291684, 1.1439711868556393`}, {
       3.723271125538312, 1.1634707003604499`}, {3.723271125538312, 
       1.1634707003604499`}, {3.808894797291684, 1.1439711868556393`}, {
       3.808894797291684, 1.1439711868556393`}}, {{3.808894797291684, 
       1.1439711868556393`}, {3.723271125538312, 1.1634707003604499`}, {
       3.723271125538312, 1.1634707003604499`}, {3.808894797291684, 
       1.1439711868556393`}, {3.808894797291684, 1.1439711868556393`}}, {{
       3.808894797291684, 1.1439711868556393`}, {3.723271125538312, 
       1.1634707003604499`}, {3.723271125538312, 1.1634707003604499`}, {
       3.808894797291684, 1.1439711868556393`}, {3.808894797291684, 
       1.1439711868556393`}}, {{3.723271125538312, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}, {3.723271125538312, 1.4210807729657078`}, {
       3.723271125538312, 1.4210807729657078`}}, {{3.723271125538312, 
       1.4210807729657078`}, {3.808894797291684, 1.4405802864705184`}, {
       3.808894797291684, 1.4405802864705184`}, {3.723271125538312, 
       1.4210807729657078`}, {3.723271125538312, 1.4210807729657078`}}, {{
       3.723271125538312, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}, {
       3.723271125538312, 1.4210807729657078`}, {3.723271125538312, 
       1.4210807729657078`}}, {{3.723271125538312, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}, {3.723271125538312, 1.4210807729657078`}, {
       3.723271125538312, 1.4210807729657078`}}, {{3.808894797291684, 
       1.4405802864705184`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}}, {{
       3.808894797291684, 1.4405802864705184`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}, {
       3.808894797291684, 1.4405802864705184`}, {3.808894797291684, 
       1.4405802864705184`}}, {{3.808894797291684, 1.4405802864705184`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}, {3.808894797291684, 1.4405802864705184`}, {
       3.808894797291684, 1.4405802864705184`}}, {{3.808894797291684, 
       1.4405802864705184`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}, {3.808894797291684, 
       1.4405802864705184`}, {3.808894797291684, 1.4405802864705184`}}, {{
       3.872002370302917, 1.4210807729657078`}, {3.9204432308651374`, 
       1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}, {{3.872002370302917, 1.4210807729657078`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.9204432308651374`, 
       1.3761777683192038`}, {3.872002370302917, 1.4210807729657078`}, {
       3.872002370302917, 1.4210807729657078`}}, {{3.872002370302917, 
       1.4210807729657078`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.872002370302917, 
       1.4210807729657078`}, {3.872002370302917, 1.4210807729657078`}}, {{
       3.872002370302917, 1.4210807729657078`}, {3.9204432308651374`, 
       1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.872002370302917, 1.4210807729657078`}, {3.872002370302917, 
       1.4210807729657078`}}, {{3.9204432308651374`, 1.3761777683192038`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}}, {{3.9204432308651374`, 
       1.3761777683192038`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9204432308651374`, 
       1.3761777683192038`}, {3.9204432308651374`, 1.3761777683192038`}}, {{
       3.9204432308651374`, 1.3761777683192038`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9463679926852193`, 1.2922757366630788`}, {
       3.9204432308651374`, 1.3761777683192038`}, {3.9204432308651374`, 
       1.3761777683192038`}}, {{3.9204432308651374`, 1.3761777683192038`}, {
       3.9463679926852193`, 1.2922757366630788`}, {3.9463679926852193`, 
       1.2922757366630788`}, {3.9204432308651374`, 1.3761777683192038`}, {
       3.9204432308651374`, 1.3761777683192038`}}, {{3.6892944729860564`, 
       1.638707803899425}, {3.623985978677152, 1.7091618791055594`}, {
       3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.8500700295178287`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}, {3.623985978677152, 
       1.8500700295178287`}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.6892944729860564`, 
       1.638707803899425}, {3.6892944729860564`, 1.638707803899425}}, {{
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}, {{3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.687830101554204}, {3.8520011901291284`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.8520011901291284`, 1.638707803899425}, {3.9049937769264647`, 
       1.687830101554204}, {3.933354548700664, 1.779615954311694}, {
       3.933354548700664, 1.779615954311694}}, {{3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}}, {{
       3.6892944729860564`, 1.9205241047239632`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.9049937769264647`, 1.871401807069184}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.871401807069184}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.6892944729860564`, 1.9205241047239632`}, {3.6892944729860564`, 
       1.9205241047239632`}}, {{3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}, {{3.6892944729860564`, 
       1.638707803899425}, {3.623985978677152, 1.7091618791055594`}, {
       3.623985978677152, 1.7091618791055594`}, {3.6892944729860564`, 
       1.638707803899425}, {3.6892944729860564`, 1.638707803899425}}, {{
       3.6892944729860564`, 1.638707803899425}, {3.623985978677152, 
       1.7091618791055594`}, {3.623985978677152, 1.7091618791055594`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}}, {{3.6892944729860564`, 1.638707803899425}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}, {3.6892944729860564`, 1.638707803899425}, {
       3.6892944729860564`, 1.638707803899425}}, {{3.6892944729860564`, 
       1.638707803899425}, {3.623985978677152, 1.7091618791055594`}, {
       3.623985978677152, 1.7091618791055594`}, {3.6892944729860564`, 
       1.638707803899425}, {3.6892944729860564`, 1.638707803899425}}, {{
       3.623985978677152, 1.7091618791055594`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}}, {{3.623985978677152, 1.7091618791055594`}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}, {3.623985978677152, 1.7091618791055594`}, {
       3.623985978677152, 1.7091618791055594`}}, {{3.623985978677152, 
       1.7091618791055594`}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.7091618791055594`}, {3.623985978677152, 1.7091618791055594`}}, {{
       3.623985978677152, 1.7091618791055594`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.7091618791055594`}, {3.623985978677152, 
       1.7091618791055594`}}, {{3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}}, {{3.607941114414521, 
       1.779615954311694}, {3.623985978677152, 1.8500700295178287`}, {
       3.623985978677152, 1.8500700295178287`}, {3.607941114414521, 
       1.779615954311694}, {3.607941114414521, 1.779615954311694}}, {{
       3.607941114414521, 1.779615954311694}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}, {
       3.607941114414521, 1.779615954311694}, {3.607941114414521, 
       1.779615954311694}}, {{3.607941114414521, 1.779615954311694}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}, {3.607941114414521, 1.779615954311694}, {
       3.607941114414521, 1.779615954311694}}, {{3.623985978677152, 
       1.8500700295178287`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}}, {{
       3.623985978677152, 1.8500700295178287`}, {3.6892944729860564`, 
       1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.623985978677152, 1.8500700295178287`}, {3.623985978677152, 
       1.8500700295178287`}}, {{3.623985978677152, 1.8500700295178287`}, {
       3.6892944729860564`, 1.9205241047239632`}, {3.6892944729860564`, 
       1.9205241047239632`}, {3.623985978677152, 1.8500700295178287`}, {
       3.623985978677152, 1.8500700295178287`}}, {{3.623985978677152, 
       1.8500700295178287`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}, {3.623985978677152, 
       1.8500700295178287`}, {3.623985978677152, 1.8500700295178287`}}, {{
       3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}, {{3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.687830101554204}, {3.9049937769264647`, 
       1.687830101554204}, {3.933354548700664, 1.779615954311694}, {
       3.933354548700664, 1.779615954311694}}, {{3.933354548700664, 
       1.779615954311694}, {3.9049937769264647`, 1.687830101554204}, {
       3.9049937769264647`, 1.687830101554204}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}}, {{
       3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}}, {{3.9049937769264647`, 1.687830101554204}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.9049937769264647`, 1.687830101554204}, {
       3.9049937769264647`, 1.687830101554204}}, {{3.9049937769264647`, 
       1.687830101554204}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}, {3.9049937769264647`, 
       1.687830101554204}, {3.9049937769264647`, 1.687830101554204}}, {{
       3.9049937769264647`, 1.687830101554204}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}, {
       3.9049937769264647`, 1.687830101554204}, {3.9049937769264647`, 
       1.687830101554204}}, {{3.9049937769264647`, 1.687830101554204}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}, {3.9049937769264647`, 1.687830101554204}, {
       3.9049937769264647`, 1.687830101554204}}, {{3.8520011901291284`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}}, {{
       3.8520011901291284`, 1.638707803899425}, {3.7829637390691606`, 
       1.6173760263480697`}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.8520011901291284`, 1.638707803899425}, {3.8520011901291284`, 
       1.638707803899425}}, {{3.8520011901291284`, 1.638707803899425}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.7829637390691606`, 
       1.6173760263480697`}, {3.8520011901291284`, 1.638707803899425}, {
       3.8520011901291284`, 1.638707803899425}}, {{3.8520011901291284`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.8520011901291284`, 
       1.638707803899425}, {3.8520011901291284`, 1.638707803899425}}, {{
       3.7829637390691606`, 1.6173760263480697`}, {3.6892944729860564`, 
       1.638707803899425}, {3.6892944729860564`, 1.638707803899425}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.7829637390691606`, 
       1.6173760263480697`}}, {{3.7829637390691606`, 1.6173760263480697`}, {
       3.6892944729860564`, 1.638707803899425}, {3.6892944729860564`, 
       1.638707803899425}, {3.7829637390691606`, 1.6173760263480697`}, {
       3.7829637390691606`, 1.6173760263480697`}}, {{3.7829637390691606`, 
       1.6173760263480697`}, {3.6892944729860564`, 1.638707803899425}, {
       3.6892944729860564`, 1.638707803899425}, {3.7829637390691606`, 
       1.6173760263480697`}, {3.7829637390691606`, 1.6173760263480697`}}, {{
       3.7829637390691606`, 1.6173760263480697`}, {3.6892944729860564`, 
       1.638707803899425}, {3.6892944729860564`, 1.638707803899425}, {
       3.7829637390691606`, 1.6173760263480697`}, {3.7829637390691606`, 
       1.6173760263480697`}}, {{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}, {{3.6892944729860564`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.6892944729860564`, 
       1.9205241047239632`}, {3.6892944729860564`, 1.9205241047239632`}}, {{
       3.6892944729860564`, 1.9205241047239632`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.6892944729860564`, 1.9205241047239632`}, {3.6892944729860564`, 
       1.9205241047239632`}}, {{3.6892944729860564`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.6892944729860564`, 1.9205241047239632`}, {
       3.6892944729860564`, 1.9205241047239632`}}, {{3.7829637390691606`, 
       1.9418558822753185`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.7829637390691606`, 1.9418558822753185`}}, {{
       3.7829637390691606`, 1.9418558822753185`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.7829637390691606`, 1.9418558822753185`}, {3.7829637390691606`, 
       1.9418558822753185`}}, {{3.7829637390691606`, 1.9418558822753185`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.7829637390691606`, 1.9418558822753185`}, {
       3.7829637390691606`, 1.9418558822753185`}}, {{3.7829637390691606`, 
       1.9418558822753185`}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.7829637390691606`, 
       1.9418558822753185`}, {3.7829637390691606`, 1.9418558822753185`}}, {{
       3.8520011901291284`, 1.9205241047239632`}, {3.9049937769264647`, 
       1.871401807069184}, {3.9049937769264647`, 1.871401807069184}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}}, {{3.8520011901291284`, 1.9205241047239632`}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}, {3.8520011901291284`, 1.9205241047239632`}, {
       3.8520011901291284`, 1.9205241047239632`}}, {{3.8520011901291284`, 
       1.9205241047239632`}, {3.9049937769264647`, 1.871401807069184}, {
       3.9049937769264647`, 1.871401807069184}, {3.8520011901291284`, 
       1.9205241047239632`}, {3.8520011901291284`, 1.9205241047239632`}}, {{
       3.8520011901291284`, 1.9205241047239632`}, {3.9049937769264647`, 
       1.871401807069184}, {3.9049937769264647`, 1.871401807069184}, {
       3.8520011901291284`, 1.9205241047239632`}, {3.8520011901291284`, 
       1.9205241047239632`}}, {{3.9049937769264647`, 1.871401807069184}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}, {3.9049937769264647`, 1.871401807069184}, {
       3.9049937769264647`, 1.871401807069184}}, {{3.9049937769264647`, 
       1.871401807069184}, {3.933354548700664, 1.779615954311694}, {
       3.933354548700664, 1.779615954311694}, {3.9049937769264647`, 
       1.871401807069184}, {3.9049937769264647`, 1.871401807069184}}, {{
       3.9049937769264647`, 1.871401807069184}, {3.933354548700664, 
       1.779615954311694}, {3.933354548700664, 1.779615954311694}, {
       3.9049937769264647`, 1.871401807069184}, {3.9049937769264647`, 
       1.871401807069184}}, {{3.9049937769264647`, 1.871401807069184}, {
       3.933354548700664, 1.779615954311694}, {3.933354548700664, 
       1.779615954311694}, {3.9049937769264647`, 1.871401807069184}, {
       3.9049937769264647`, 1.871401807069184}}, {{3.635527855224726, 
       2.1030704834939313`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.274260221535478}, {3.635527855224726, 2.331323467549327}, {
       3.635527855224726, 2.331323467549327}, {3.5826321970723845`, 
       2.274260221535478}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.635527855224726, 
       2.1030704834939313`}, {3.635527855224726, 2.1030704834939313`}}, {{
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}, {{3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.1428563688048796`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.711393904971291, 2.085793122791031}, {
       3.6355278552247263`, 2.1030704834939313`}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.711393904971291, 2.085793122791031}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.833200737906303, 2.217196975521629}, {
       3.833200737906303, 2.217196975521629}}, {{3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}}, {{
       3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.7673097770124437`, 2.331323467549327}, {
       3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.7673097770124437`, 
       2.331323467549327}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}, {{3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}}, {{3.635527855224726, 
       2.1030704834939313`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.635527855224726, 
       2.1030704834939313`}, {3.635527855224726, 2.1030704834939313`}}, {{
       3.635527855224726, 2.1030704834939313`}, {3.5826321970723845`, 
       2.1601337295077805`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.635527855224726, 2.1030704834939313`}, {3.635527855224726, 
       2.1030704834939313`}}, {{3.635527855224726, 2.1030704834939313`}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}, {3.635527855224726, 2.1030704834939313`}, {
       3.635527855224726, 2.1030704834939313`}}, {{3.635527855224726, 
       2.1030704834939313`}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.635527855224726, 
       2.1030704834939313`}, {3.635527855224726, 2.1030704834939313`}}, {{
       3.5826321970723845`, 2.1601337295077805`}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}}, {{3.5826321970723845`, 2.1601337295077805`}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}, {3.5826321970723845`, 2.1601337295077805`}, {
       3.5826321970723845`, 2.1601337295077805`}}, {{3.5826321970723845`, 
       2.1601337295077805`}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.1601337295077805`}, {3.5826321970723845`, 2.1601337295077805`}}, {{
       3.5826321970723845`, 2.1601337295077805`}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.1601337295077805`}, {3.5826321970723845`, 
       2.1601337295077805`}}, {{3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}}, {{3.569636894330867, 
       2.217196975521629}, {3.5826321970723845`, 2.274260221535478}, {
       3.5826321970723845`, 2.274260221535478}, {3.569636894330867, 
       2.217196975521629}, {3.569636894330867, 2.217196975521629}}, {{
       3.569636894330867, 2.217196975521629}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}, {
       3.569636894330867, 2.217196975521629}, {3.569636894330867, 
       2.217196975521629}}, {{3.569636894330867, 2.217196975521629}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}, {3.569636894330867, 2.217196975521629}, {
       3.569636894330867, 2.217196975521629}}, {{3.5826321970723845`, 
       2.274260221535478}, {3.6355278552247263`, 2.331323467549327}, {
       3.6355278552247263`, 2.331323467549327}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}}, {{
       3.5826321970723845`, 2.274260221535478}, {3.6355278552247263`, 
       2.331323467549327}, {3.6355278552247263`, 2.331323467549327}, {
       3.5826321970723845`, 2.274260221535478}, {3.5826321970723845`, 
       2.274260221535478}}, {{3.5826321970723845`, 2.274260221535478}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}, {3.5826321970723845`, 2.274260221535478}, {
       3.5826321970723845`, 2.274260221535478}}, {{3.5826321970723845`, 
       2.274260221535478}, {3.6355278552247263`, 2.331323467549327}, {
       3.6355278552247263`, 2.331323467549327}, {3.5826321970723845`, 
       2.274260221535478}, {3.5826321970723845`, 2.274260221535478}}, {{
       3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}, {{3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.1428563688048796`}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.833200737906303, 2.217196975521629}, {
       3.833200737906303, 2.217196975521629}}, {{3.833200737906303, 
       2.217196975521629}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}}, {{
       3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}}, {{3.8102303463120792`, 2.1428563688048796`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}}, {{3.8102303463120792`, 
       2.1428563688048796`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.8102303463120792`, 
       2.1428563688048796`}, {3.8102303463120792`, 2.1428563688048796`}}, {{
       3.8102303463120792`, 2.1428563688048796`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.8102303463120792`, 2.1428563688048796`}, {3.8102303463120792`, 
       2.1428563688048796`}}, {{3.8102303463120792`, 2.1428563688048796`}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.8102303463120792`, 2.1428563688048796`}, {
       3.8102303463120792`, 2.1428563688048796`}}, {{3.7673097770124437`, 
       2.1030704834939313`}, {3.711393904971291, 2.085793122791031}, {
       3.711393904971291, 2.085793122791031}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}}, {{
       3.7673097770124437`, 2.1030704834939313`}, {3.711393904971291, 
       2.085793122791031}, {3.711393904971291, 2.085793122791031}, {
       3.7673097770124437`, 2.1030704834939313`}, {3.7673097770124437`, 
       2.1030704834939313`}}, {{3.7673097770124437`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}, {3.7673097770124437`, 2.1030704834939313`}, {
       3.7673097770124437`, 2.1030704834939313`}}, {{3.7673097770124437`, 
       2.1030704834939313`}, {3.711393904971291, 2.085793122791031}, {
       3.711393904971291, 2.085793122791031}, {3.7673097770124437`, 
       2.1030704834939313`}, {3.7673097770124437`, 2.1030704834939313`}}, {{
       3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}}, {{3.711393904971291, 2.085793122791031}, {
       3.6355278552247263`, 2.1030704834939313`}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.711393904971291, 2.085793122791031}, {
       3.711393904971291, 2.085793122791031}}, {{3.711393904971291, 
       2.085793122791031}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.6355278552247263`, 2.1030704834939313`}, {3.711393904971291, 
       2.085793122791031}, {3.711393904971291, 2.085793122791031}}, {{
       3.711393904971291, 2.085793122791031}, {3.6355278552247263`, 
       2.1030704834939313`}, {3.6355278552247263`, 2.1030704834939313`}, {
       3.711393904971291, 2.085793122791031}, {3.711393904971291, 
       2.085793122791031}}, {{3.6355278552247263`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}, {3.6355278552247263`, 2.331323467549327}, {
       3.6355278552247263`, 2.331323467549327}}, {{3.6355278552247263`, 
       2.331323467549327}, {3.711393904971291, 2.3486008282522275`}, {
       3.711393904971291, 2.3486008282522275`}, {3.6355278552247263`, 
       2.331323467549327}, {3.6355278552247263`, 2.331323467549327}}, {{
       3.6355278552247263`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}, {
       3.6355278552247263`, 2.331323467549327}, {3.6355278552247263`, 
       2.331323467549327}}, {{3.6355278552247263`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}, {3.6355278552247263`, 2.331323467549327}, {
       3.6355278552247263`, 2.331323467549327}}, {{3.711393904971291, 
       2.3486008282522275`}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}}, {{
       3.711393904971291, 2.3486008282522275`}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}, {
       3.711393904971291, 2.3486008282522275`}, {3.711393904971291, 
       2.3486008282522275`}}, {{3.711393904971291, 2.3486008282522275`}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}, {3.711393904971291, 2.3486008282522275`}, {
       3.711393904971291, 2.3486008282522275`}}, {{3.711393904971291, 
       2.3486008282522275`}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}, {3.711393904971291, 
       2.3486008282522275`}, {3.711393904971291, 2.3486008282522275`}}, {{
       3.7673097770124437`, 2.331323467549327}, {3.8102303463120792`, 
       2.291537582238379}, {3.8102303463120792`, 2.291537582238379}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}, {{3.7673097770124437`, 2.331323467549327}, {
       3.8102303463120792`, 2.291537582238379}, {3.8102303463120792`, 
       2.291537582238379}, {3.7673097770124437`, 2.331323467549327}, {
       3.7673097770124437`, 2.331323467549327}}, {{3.7673097770124437`, 
       2.331323467549327}, {3.8102303463120792`, 2.291537582238379}, {
       3.8102303463120792`, 2.291537582238379}, {3.7673097770124437`, 
       2.331323467549327}, {3.7673097770124437`, 2.331323467549327}}, {{
       3.7673097770124437`, 2.331323467549327}, {3.8102303463120792`, 
       2.291537582238379}, {3.8102303463120792`, 2.291537582238379}, {
       3.7673097770124437`, 2.331323467549327}, {3.7673097770124437`, 
       2.331323467549327}}, {{3.8102303463120792`, 2.291537582238379}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}, {3.8102303463120792`, 2.291537582238379}, {
       3.8102303463120792`, 2.291537582238379}}, {{3.8102303463120792`, 
       2.291537582238379}, {3.833200737906303, 2.217196975521629}, {
       3.833200737906303, 2.217196975521629}, {3.8102303463120792`, 
       2.291537582238379}, {3.8102303463120792`, 2.291537582238379}}, {{
       3.8102303463120792`, 2.291537582238379}, {3.833200737906303, 
       2.217196975521629}, {3.833200737906303, 2.217196975521629}, {
       3.8102303463120792`, 2.291537582238379}, {3.8102303463120792`, 
       2.291537582238379}}, {{3.8102303463120792`, 2.291537582238379}, {
       3.833200737906303, 2.217196975521629}, {3.833200737906303, 
       2.217196975521629}, {3.8102303463120792`, 2.291537582238379}, {
       3.8102303463120792`, 2.291537582238379}}, {{3.7155755679839824`, 
       2.6521410778825736`}, {3.6626532238745013`, 2.7092331124093283`}, {
       3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.7155755679839824`, 2.8805092159895924`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}}, {{
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}, {{3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.691947035246073}, {3.847423973994404, 
       2.6521410778825736`}, {3.791479892292631, 2.6348550007193183`}, {
       3.7155755679839824`, 2.6521410778825736`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.791479892292631, 2.6348550007193183`}, {
       3.847423973994404, 2.6521410778825736`}, {3.890366196800447, 
       2.691947035246073}, {3.913348176999614, 2.766325146936083}, {
       3.913348176999614, 2.766325146936083}}, {{3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}}, {{
       3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631, 
       2.8977952931528477`}, {3.847423973994404, 2.8805092159895924`}, {
       3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.847423973994404, 
       2.8805092159895924`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}, {{3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}}, {{3.7155755679839824`, 
       2.6521410778825736`}, {3.6626532238745013`, 2.7092331124093283`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}}, {{
       3.7155755679839824`, 2.6521410778825736`}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.6626532238745013`, 2.7092331124093283`}, {
       3.7155755679839824`, 2.6521410778825736`}, {3.7155755679839824`, 
       2.6521410778825736`}}, {{3.7155755679839824`, 2.6521410778825736`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}}, {{3.7155755679839824`, 
       2.6521410778825736`}, {3.6626532238745013`, 2.7092331124093283`}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}}, {{
       3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}}, {{3.6626532238745013`, 2.7092331124093283`}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}, {3.6626532238745013`, 2.7092331124093283`}, {
       3.6626532238745013`, 2.7092331124093283`}}, {{3.6626532238745013`, 
       2.7092331124093283`}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.7092331124093283`}, {3.6626532238745013`, 2.7092331124093283`}}, {{
       3.6626532238745013`, 2.7092331124093283`}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.7092331124093283`}, {3.6626532238745013`, 
       2.7092331124093283`}}, {{3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.8234171814628377`}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}}, {{3.649651364978772, 
       2.766325146936083}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.6626532238745013`, 2.8234171814628377`}, {3.649651364978772, 
       2.766325146936083}, {3.649651364978772, 2.766325146936083}}, {{
       3.649651364978772, 2.766325146936083}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.649651364978772, 2.766325146936083}, {3.649651364978772, 
       2.766325146936083}}, {{3.649651364978772, 2.766325146936083}, {
       3.6626532238745013`, 2.8234171814628377`}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.649651364978772, 2.766325146936083}, {
       3.649651364978772, 2.766325146936083}}, {{3.6626532238745013`, 
       2.8234171814628377`}, {3.7155755679839824`, 2.8805092159895924`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}}, {{
       3.6626532238745013`, 2.8234171814628377`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.7155755679839824`, 2.8805092159895924`}, {
       3.6626532238745013`, 2.8234171814628377`}, {3.6626532238745013`, 
       2.8234171814628377`}}, {{3.6626532238745013`, 2.8234171814628377`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.6626532238745013`, 2.8234171814628377`}, {
       3.6626532238745013`, 2.8234171814628377`}}, {{3.6626532238745013`, 
       2.8234171814628377`}, {3.7155755679839824`, 2.8805092159895924`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.6626532238745013`, 
       2.8234171814628377`}, {3.6626532238745013`, 2.8234171814628377`}}, {{
       3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}, {{3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.691947035246073}, {3.890366196800447, 
       2.691947035246073}, {3.913348176999614, 2.766325146936083}, {
       3.913348176999614, 2.766325146936083}}, {{3.913348176999614, 
       2.766325146936083}, {3.890366196800447, 2.691947035246073}, {
       3.890366196800447, 2.691947035246073}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}}, {{
       3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}}, {{3.890366196800447, 2.691947035246073}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.890366196800447, 2.691947035246073}, {
       3.890366196800447, 2.691947035246073}}, {{3.890366196800447, 
       2.691947035246073}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}, {3.890366196800447, 
       2.691947035246073}, {3.890366196800447, 2.691947035246073}}, {{
       3.890366196800447, 2.691947035246073}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}, {
       3.890366196800447, 2.691947035246073}, {3.890366196800447, 
       2.691947035246073}}, {{3.890366196800447, 2.691947035246073}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}, {3.890366196800447, 2.691947035246073}, {
       3.890366196800447, 2.691947035246073}}, {{3.847423973994404, 
       2.6521410778825736`}, {3.791479892292631, 2.6348550007193183`}, {
       3.791479892292631, 2.6348550007193183`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}}, {{
       3.847423973994404, 2.6521410778825736`}, {3.791479892292631, 
       2.6348550007193183`}, {3.791479892292631, 2.6348550007193183`}, {
       3.847423973994404, 2.6521410778825736`}, {3.847423973994404, 
       2.6521410778825736`}}, {{3.847423973994404, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}, {3.847423973994404, 2.6521410778825736`}, {
       3.847423973994404, 2.6521410778825736`}}, {{3.847423973994404, 
       2.6521410778825736`}, {3.791479892292631, 2.6348550007193183`}, {
       3.791479892292631, 2.6348550007193183`}, {3.847423973994404, 
       2.6521410778825736`}, {3.847423973994404, 2.6521410778825736`}}, {{
       3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}}, {{3.791479892292631, 2.6348550007193183`}, {
       3.7155755679839824`, 2.6521410778825736`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.791479892292631, 2.6348550007193183`}, {
       3.791479892292631, 2.6348550007193183`}}, {{3.791479892292631, 
       2.6348550007193183`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.7155755679839824`, 2.6521410778825736`}, {3.791479892292631, 
       2.6348550007193183`}, {3.791479892292631, 2.6348550007193183`}}, {{
       3.791479892292631, 2.6348550007193183`}, {3.7155755679839824`, 
       2.6521410778825736`}, {3.7155755679839824`, 2.6521410778825736`}, {
       3.791479892292631, 2.6348550007193183`}, {3.791479892292631, 
       2.6348550007193183`}}, {{3.7155755679839824`, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}, {3.7155755679839824`, 2.8805092159895924`}, {
       3.7155755679839824`, 2.8805092159895924`}}, {{3.7155755679839824`, 
       2.8805092159895924`}, {3.791479892292631, 2.8977952931528477`}, {
       3.791479892292631, 2.8977952931528477`}, {3.7155755679839824`, 
       2.8805092159895924`}, {3.7155755679839824`, 2.8805092159895924`}}, {{
       3.7155755679839824`, 2.8805092159895924`}, {3.791479892292631, 
       2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}, {
       3.7155755679839824`, 2.8805092159895924`}, {3.7155755679839824`, 
       2.8805092159895924`}}, {{3.7155755679839824`, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}, {3.7155755679839824`, 2.8805092159895924`}, {
       3.7155755679839824`, 2.8805092159895924`}}, {{3.791479892292631, 
       2.8977952931528477`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.791479892292631, 
       2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}}, {{
       3.791479892292631, 2.8977952931528477`}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}, {
       3.791479892292631, 2.8977952931528477`}, {3.791479892292631, 
       2.8977952931528477`}}, {{3.791479892292631, 2.8977952931528477`}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}, {3.791479892292631, 2.8977952931528477`}, {
       3.791479892292631, 2.8977952931528477`}}, {{3.791479892292631, 
       2.8977952931528477`}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}, {3.791479892292631, 
       2.8977952931528477`}, {3.791479892292631, 2.8977952931528477`}}, {{
       3.847423973994404, 2.8805092159895924`}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}, {{3.847423973994404, 2.8805092159895924`}, {
       3.890366196800447, 2.840703258626093}, {3.890366196800447, 
       2.840703258626093}, {3.847423973994404, 2.8805092159895924`}, {
       3.847423973994404, 2.8805092159895924`}}, {{3.847423973994404, 
       2.8805092159895924`}, {3.890366196800447, 2.840703258626093}, {
       3.890366196800447, 2.840703258626093}, {3.847423973994404, 
       2.8805092159895924`}, {3.847423973994404, 2.8805092159895924`}}, {{
       3.847423973994404, 2.8805092159895924`}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}, {
       3.847423973994404, 2.8805092159895924`}, {3.847423973994404, 
       2.8805092159895924`}}, {{3.890366196800447, 2.840703258626093}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}, {3.890366196800447, 2.840703258626093}, {
       3.890366196800447, 2.840703258626093}}, {{3.890366196800447, 
       2.840703258626093}, {3.913348176999614, 2.766325146936083}, {
       3.913348176999614, 2.766325146936083}, {3.890366196800447, 
       2.840703258626093}, {3.890366196800447, 2.840703258626093}}, {{
       3.890366196800447, 2.840703258626093}, {3.913348176999614, 
       2.766325146936083}, {3.913348176999614, 2.766325146936083}, {
       3.890366196800447, 2.840703258626093}, {3.890366196800447, 
       2.840703258626093}}, {{3.890366196800447, 2.840703258626093}, {
       3.913348176999614, 2.766325146936083}, {3.913348176999614, 
       2.766325146936083}, {3.890366196800447, 2.840703258626093}, {
       3.890366196800447, 2.840703258626093}}, {{3.696824065786324, 
       3.114339105657419}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.696824065786324, 3.408394337905281}, {
       3.696824065786324, 3.408394337905281}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6119376320388636`, 3.26136672178135}, {
       3.6286793047999115`, 3.1878529137193845`}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}}, {{
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}, {{3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.1655947236013153`}, {3.866596933281245, 
       3.114339105657419}, {3.7945612715901254`, 3.09208091553935}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}, {3.7945612715901254`, 3.09208091553935}, {
       3.866596933281245, 3.114339105657419}, {3.921890922211316, 
       3.1655947236013153`}, {3.9514833670287053`, 3.26136672178135}, {
       3.9514833670287053`, 3.26136672178135}}, {{3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}}, {{
       3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.866596933281245, 3.408394337905281}, {
       3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`, 
       3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.866596933281245, 
       3.408394337905281}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}, {{3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}}, {{3.696824065786324, 
       3.114339105657419}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}}, {{
       3.696824065786324, 3.114339105657419}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}}, {{3.696824065786324, 3.114339105657419}, {
       3.6286793047999115`, 3.1878529137193845`}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.696824065786324, 3.114339105657419}, {
       3.696824065786324, 3.114339105657419}}, {{3.696824065786324, 
       3.114339105657419}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}}, {{
       3.6286793047999115`, 3.1878529137193845`}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6286793047999115`, 3.1878529137193845`}, {3.6286793047999115`, 
       3.1878529137193845`}}, {{3.6286793047999115`, 3.1878529137193845`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.1878529137193845`}, {
       3.6286793047999115`, 3.1878529137193845`}}, {{3.6286793047999115`, 
       3.1878529137193845`}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.1878529137193845`}, {3.6286793047999115`, 3.1878529137193845`}}, {{
       3.6286793047999115`, 3.1878529137193845`}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}, {
       3.6286793047999115`, 3.1878529137193845`}, {3.6286793047999115`, 
       3.1878529137193845`}}, {{3.6119376320388636`, 3.26136672178135}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}}, {{3.6119376320388636`, 
       3.26136672178135}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6119376320388636`, 
       3.26136672178135}, {3.6119376320388636`, 3.26136672178135}}, {{
       3.6119376320388636`, 3.26136672178135}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6119376320388636`, 3.26136672178135}, {3.6119376320388636`, 
       3.26136672178135}}, {{3.6119376320388636`, 3.26136672178135}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6119376320388636`, 3.26136672178135}, {
       3.6119376320388636`, 3.26136672178135}}, {{3.6286793047999115`, 
       3.3348805298433155`}, {3.696824065786324, 3.408394337905281}, {
       3.696824065786324, 3.408394337905281}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}}, {{
       3.6286793047999115`, 3.3348805298433155`}, {3.696824065786324, 
       3.408394337905281}, {3.696824065786324, 3.408394337905281}, {
       3.6286793047999115`, 3.3348805298433155`}, {3.6286793047999115`, 
       3.3348805298433155`}}, {{3.6286793047999115`, 3.3348805298433155`}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}, {3.6286793047999115`, 3.3348805298433155`}, {
       3.6286793047999115`, 3.3348805298433155`}}, {{3.6286793047999115`, 
       3.3348805298433155`}, {3.696824065786324, 3.408394337905281}, {
       3.696824065786324, 3.408394337905281}, {3.6286793047999115`, 
       3.3348805298433155`}, {3.6286793047999115`, 3.3348805298433155`}}, {{
       3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}, {{3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.1655947236013153`}, {3.921890922211316, 
       3.1655947236013153`}, {3.9514833670287053`, 3.26136672178135}, {
       3.9514833670287053`, 3.26136672178135}}, {{3.9514833670287053`, 
       3.26136672178135}, {3.921890922211316, 3.1655947236013153`}, {
       3.921890922211316, 3.1655947236013153`}, {3.9514833670287053`, 
       3.26136672178135}, {3.9514833670287053`, 3.26136672178135}}, {{
       3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}}, {{3.921890922211316, 3.1655947236013153`}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.921890922211316, 3.1655947236013153`}, {
       3.921890922211316, 3.1655947236013153`}}, {{3.921890922211316, 
       3.1655947236013153`}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}, {3.921890922211316, 
       3.1655947236013153`}, {3.921890922211316, 3.1655947236013153`}}, {{
       3.921890922211316, 3.1655947236013153`}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}, {
       3.921890922211316, 3.1655947236013153`}, {3.921890922211316, 
       3.1655947236013153`}}, {{3.921890922211316, 3.1655947236013153`}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}, {3.921890922211316, 3.1655947236013153`}, {
       3.921890922211316, 3.1655947236013153`}}, {{3.866596933281245, 
       3.114339105657419}, {3.7945612715901254`, 3.09208091553935}, {
       3.7945612715901254`, 3.09208091553935}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}}, {{
       3.866596933281245, 3.114339105657419}, {3.7945612715901254`, 
       3.09208091553935}, {3.7945612715901254`, 3.09208091553935}, {
       3.866596933281245, 3.114339105657419}, {3.866596933281245, 
       3.114339105657419}}, {{3.866596933281245, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}, {3.866596933281245, 3.114339105657419}, {
       3.866596933281245, 3.114339105657419}}, {{3.866596933281245, 
       3.114339105657419}, {3.7945612715901254`, 3.09208091553935}, {
       3.7945612715901254`, 3.09208091553935}, {3.866596933281245, 
       3.114339105657419}, {3.866596933281245, 3.114339105657419}}, {{
       3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}}, {{3.7945612715901254`, 3.09208091553935}, {
       3.696824065786324, 3.114339105657419}, {3.696824065786324, 
       3.114339105657419}, {3.7945612715901254`, 3.09208091553935}, {
       3.7945612715901254`, 3.09208091553935}}, {{3.7945612715901254`, 
       3.09208091553935}, {3.696824065786324, 3.114339105657419}, {
       3.696824065786324, 3.114339105657419}, {3.7945612715901254`, 
       3.09208091553935}, {3.7945612715901254`, 3.09208091553935}}, {{
       3.7945612715901254`, 3.09208091553935}, {3.696824065786324, 
       3.114339105657419}, {3.696824065786324, 3.114339105657419}, {
       3.7945612715901254`, 3.09208091553935}, {3.7945612715901254`, 
       3.09208091553935}}, {{3.696824065786324, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}, {3.696824065786324, 3.408394337905281}, {
       3.696824065786324, 3.408394337905281}}, {{3.696824065786324, 
       3.408394337905281}, {3.7945612715901254`, 3.43065252802335}, {
       3.7945612715901254`, 3.43065252802335}, {3.696824065786324, 
       3.408394337905281}, {3.696824065786324, 3.408394337905281}}, {{
       3.696824065786324, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}, {
       3.696824065786324, 3.408394337905281}, {3.696824065786324, 
       3.408394337905281}}, {{3.696824065786324, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}, {3.696824065786324, 3.408394337905281}, {
       3.696824065786324, 3.408394337905281}}, {{3.7945612715901254`, 
       3.43065252802335}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}}, {{
       3.7945612715901254`, 3.43065252802335}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}, {
       3.7945612715901254`, 3.43065252802335}, {3.7945612715901254`, 
       3.43065252802335}}, {{3.7945612715901254`, 3.43065252802335}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}, {3.7945612715901254`, 3.43065252802335}, {
       3.7945612715901254`, 3.43065252802335}}, {{3.7945612715901254`, 
       3.43065252802335}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}, {3.7945612715901254`, 
       3.43065252802335}, {3.7945612715901254`, 3.43065252802335}}, {{
       3.866596933281245, 3.408394337905281}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}, {{3.866596933281245, 3.408394337905281}, {
       3.921890922211316, 3.3571387199613847`}, {3.921890922211316, 
       3.3571387199613847`}, {3.866596933281245, 3.408394337905281}, {
       3.866596933281245, 3.408394337905281}}, {{3.866596933281245, 
       3.408394337905281}, {3.921890922211316, 3.3571387199613847`}, {
       3.921890922211316, 3.3571387199613847`}, {3.866596933281245, 
       3.408394337905281}, {3.866596933281245, 3.408394337905281}}, {{
       3.866596933281245, 3.408394337905281}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}, {
       3.866596933281245, 3.408394337905281}, {3.866596933281245, 
       3.408394337905281}}, {{3.921890922211316, 3.3571387199613847`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}, {3.921890922211316, 3.3571387199613847`}, {
       3.921890922211316, 3.3571387199613847`}}, {{3.921890922211316, 
       3.3571387199613847`}, {3.9514833670287053`, 3.26136672178135}, {
       3.9514833670287053`, 3.26136672178135}, {3.921890922211316, 
       3.3571387199613847`}, {3.921890922211316, 3.3571387199613847`}}, {{
       3.921890922211316, 3.3571387199613847`}, {3.9514833670287053`, 
       3.26136672178135}, {3.9514833670287053`, 3.26136672178135}, {
       3.921890922211316, 3.3571387199613847`}, {3.921890922211316, 
       3.3571387199613847`}}, {{3.921890922211316, 3.3571387199613847`}, {
       3.9514833670287053`, 3.26136672178135}, {3.9514833670287053`, 
       3.26136672178135}, {3.921890922211316, 3.3571387199613847`}, {
       3.921890922211316, 3.3571387199613847`}}, {{3.7148601024473007`, 
       3.648248975358725}, {3.651995136994538, 3.716066998890101}, {
       3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.8517030459528527`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}, {3.651995136994538, 
       3.8517030459528527`}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.7148601024473007`, 
       3.648248975358725}, {3.7148601024473007`, 3.648248975358725}}, {{
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}, {{3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.6955333535656654`}, {3.871479119014294, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.871479119014294, 3.648248975358725}, {3.922488978811549, 
       3.6955333535656654`}, {3.9497886272977905`, 3.783885022421477}, {
       3.9497886272977905`, 3.783885022421477}}, {{3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}}, {{
       3.7148601024473007`, 3.9195210694842286`}, {3.8050247163863045`, 
       3.940054714808664}, {3.871479119014294, 3.9195210694842286`}, {
       3.922488978811549, 3.8722366912772883`}, {3.9497886272977905`, 
       3.783885022421477}, {3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.8722366912772883`}, {3.871479119014294, 
       3.9195210694842286`}, {3.8050247163863045`, 3.940054714808664}, {
       3.7148601024473007`, 3.9195210694842286`}, {3.7148601024473007`, 
       3.9195210694842286`}}, {{3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}}, {{3.7148601024473007`, 
       3.648248975358725}, {3.651995136994538, 3.716066998890101}, {
       3.651995136994538, 3.716066998890101}, {3.7148601024473007`, 
       3.648248975358725}, {3.7148601024473007`, 3.648248975358725}}, {{
       3.7148601024473007`, 3.648248975358725}, {3.651995136994538, 
       3.716066998890101}, {3.651995136994538, 3.716066998890101}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}}, {{3.7148601024473007`, 3.648248975358725}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}, {3.7148601024473007`, 3.648248975358725}, {
       3.7148601024473007`, 3.648248975358725}}, {{3.7148601024473007`, 
       3.648248975358725}, {3.651995136994538, 3.716066998890101}, {
       3.651995136994538, 3.716066998890101}, {3.7148601024473007`, 
       3.648248975358725}, {3.7148601024473007`, 3.648248975358725}}, {{
       3.651995136994538, 3.716066998890101}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}}, {{3.651995136994538, 3.716066998890101}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}, {3.651995136994538, 3.716066998890101}, {
       3.651995136994538, 3.716066998890101}}, {{3.651995136994538, 
       3.716066998890101}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.716066998890101}, {3.651995136994538, 3.716066998890101}}, {{
       3.651995136994538, 3.716066998890101}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.716066998890101}, {3.651995136994538, 
       3.716066998890101}}, {{3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}}, {{3.636550594163804, 
       3.783885022421477}, {3.651995136994538, 3.8517030459528527`}, {
       3.651995136994538, 3.8517030459528527`}, {3.636550594163804, 
       3.783885022421477}, {3.636550594163804, 3.783885022421477}}, {{
       3.636550594163804, 3.783885022421477}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}, {
       3.636550594163804, 3.783885022421477}, {3.636550594163804, 
       3.783885022421477}}, {{3.636550594163804, 3.783885022421477}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}, {3.636550594163804, 3.783885022421477}, {
       3.636550594163804, 3.783885022421477}}, {{3.651995136994538, 
       3.8517030459528527`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}}, {{
       3.651995136994538, 3.8517030459528527`}, {3.7148601024473007`, 
       3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.651995136994538, 3.8517030459528527`}, {3.651995136994538, 
       3.8517030459528527`}}, {{3.651995136994538, 3.8517030459528527`}, {
       3.7148601024473007`, 3.9195210694842286`}, {3.7148601024473007`, 
       3.9195210694842286`}, {3.651995136994538, 3.8517030459528527`}, {
       3.651995136994538, 3.8517030459528527`}}, {{3.651995136994538, 
       3.8517030459528527`}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}, {3.651995136994538, 
       3.8517030459528527`}, {3.651995136994538, 3.8517030459528527`}}, {{
       3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}, {{3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.6955333535656654`}, {3.922488978811549, 
       3.6955333535656654`}, {3.9497886272977905`, 3.783885022421477}, {
       3.9497886272977905`, 3.783885022421477}}, {{3.9497886272977905`, 
       3.783885022421477}, {3.922488978811549, 3.6955333535656654`}, {
       3.922488978811549, 3.6955333535656654`}, {3.9497886272977905`, 
       3.783885022421477}, {3.9497886272977905`, 3.783885022421477}}, {{
       3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}}, {{3.922488978811549, 3.6955333535656654`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.922488978811549, 3.6955333535656654`}, {
       3.922488978811549, 3.6955333535656654`}}, {{3.922488978811549, 
       3.6955333535656654`}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}, {3.922488978811549, 
       3.6955333535656654`}, {3.922488978811549, 3.6955333535656654`}}, {{
       3.922488978811549, 3.6955333535656654`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}, {
       3.922488978811549, 3.6955333535656654`}, {3.922488978811549, 
       3.6955333535656654`}}, {{3.922488978811549, 3.6955333535656654`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}, {3.922488978811549, 3.6955333535656654`}, {
       3.922488978811549, 3.6955333535656654`}}, {{3.871479119014294, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}}, {{
       3.871479119014294, 3.648248975358725}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.871479119014294, 3.648248975358725}, {3.871479119014294, 
       3.648248975358725}}, {{3.871479119014294, 3.648248975358725}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.871479119014294, 3.648248975358725}, {
       3.871479119014294, 3.648248975358725}}, {{3.871479119014294, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.871479119014294, 
       3.648248975358725}, {3.871479119014294, 3.648248975358725}}, {{
       3.8050247163863045`, 3.6277153300342895`}, {3.7148601024473007`, 
       3.648248975358725}, {3.7148601024473007`, 3.648248975358725}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.8050247163863045`, 
       3.6277153300342895`}}, {{3.8050247163863045`, 3.6277153300342895`}, {
       3.7148601024473007`, 3.648248975358725}, {3.7148601024473007`, 
       3.648248975358725}, {3.8050247163863045`, 3.6277153300342895`}, {
       3.8050247163863045`, 3.6277153300342895`}}, {{3.8050247163863045`, 
       3.6277153300342895`}, {3.7148601024473007`, 3.648248975358725}, {
       3.7148601024473007`, 3.648248975358725}, {3.8050247163863045`, 
       3.6277153300342895`}, {3.8050247163863045`, 3.6277153300342895`}}, {{
       3.8050247163863045`, 3.6277153300342895`}, {3.7148601024473007`, 
       3.648248975358725}, {3.7148601024473007`, 3.648248975358725}, {
       3.8050247163863045`, 3.6277153300342895`}, {3.8050247163863045`, 
       3.6277153300342895`}}, {{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}, {{3.7148601024473007`, 
       3.9195210694842286`}, {3.8050247163863045`, 3.940054714808664}, {
       3.8050247163863045`, 3.940054714808664}, {3.7148601024473007`, 
       3.9195210694842286`}, {3.7148601024473007`, 3.9195210694842286`}}, {{
       3.7148601024473007`, 3.9195210694842286`}, {3.8050247163863045`, 
       3.940054714808664}, {3.8050247163863045`, 3.940054714808664}, {
       3.7148601024473007`, 3.9195210694842286`}, {3.7148601024473007`, 
       3.9195210694842286`}}, {{3.7148601024473007`, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}, {3.7148601024473007`, 3.9195210694842286`}, {
       3.7148601024473007`, 3.9195210694842286`}}, {{3.8050247163863045`, 
       3.940054714808664}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.8050247163863045`, 
       3.940054714808664}, {3.8050247163863045`, 3.940054714808664}}, {{
       3.8050247163863045`, 3.940054714808664}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}, {
       3.8050247163863045`, 3.940054714808664}, {3.8050247163863045`, 
       3.940054714808664}}, {{3.8050247163863045`, 3.940054714808664}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}, {3.8050247163863045`, 3.940054714808664}, {
       3.8050247163863045`, 3.940054714808664}}, {{3.8050247163863045`, 
       3.940054714808664}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}, {3.8050247163863045`, 
       3.940054714808664}, {3.8050247163863045`, 3.940054714808664}}, {{
       3.871479119014294, 3.9195210694842286`}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}, {{3.871479119014294, 3.9195210694842286`}, {
       3.922488978811549, 3.8722366912772883`}, {3.922488978811549, 
       3.8722366912772883`}, {3.871479119014294, 3.9195210694842286`}, {
       3.871479119014294, 3.9195210694842286`}}, {{3.871479119014294, 
       3.9195210694842286`}, {3.922488978811549, 3.8722366912772883`}, {
       3.922488978811549, 3.8722366912772883`}, {3.871479119014294, 
       3.9195210694842286`}, {3.871479119014294, 3.9195210694842286`}}, {{
       3.871479119014294, 3.9195210694842286`}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}, {
       3.871479119014294, 3.9195210694842286`}, {3.871479119014294, 
       3.9195210694842286`}}, {{3.922488978811549, 3.8722366912772883`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}, {3.922488978811549, 3.8722366912772883`}, {
       3.922488978811549, 3.8722366912772883`}}, {{3.922488978811549, 
       3.8722366912772883`}, {3.9497886272977905`, 3.783885022421477}, {
       3.9497886272977905`, 3.783885022421477}, {3.922488978811549, 
       3.8722366912772883`}, {3.922488978811549, 3.8722366912772883`}}, {{
       3.922488978811549, 3.8722366912772883`}, {3.9497886272977905`, 
       3.783885022421477}, {3.9497886272977905`, 3.783885022421477}, {
       3.922488978811549, 3.8722366912772883`}, {3.922488978811549, 
       3.8722366912772883`}}, {{3.922488978811549, 3.8722366912772883`}, {
       3.9497886272977905`, 3.783885022421477}, {3.9497886272977905`, 
       3.783885022421477}, {3.922488978811549, 3.8722366912772883`}, {
       3.922488978811549, 3.8722366912772883`}}, {{
       3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}, {{
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}, {{
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}, {{
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}, {{
       3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}, {{
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}, {{
       3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}, {{
       3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}, {{
       3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}, {{
       3.950639144379684, -4.63738059883611}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}}, {{
       3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}, {{
       3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}, {{
       3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}, {{
       3.8862506425312815`, -4.567919001234721}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.567919001234721}, {
       3.8862506425312815`, -4.567919001234721}}, {{
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}, {{
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}, {{
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}, {{
       3.870431800232678, -4.498457403633332}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.870431800232678, -4.498457403633332}, {
       3.870431800232678, -4.498457403633332}}, {{
       3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}, {{
       3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}, {{
       3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}, {{
       3.8862506425312815`, -4.428995806031944}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}, {
       3.8862506425312815`, -4.428995806031944}, {
       3.8862506425312815`, -4.428995806031944}}, {{
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}, {{
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}, {{
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}, {{
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}}, {{
       4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}, {{
       4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}, {{
       4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}, {{
       4.16329991963465, -4.5889502807463645`}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}, {
       4.16329991963465, -4.5889502807463645`}, {
       4.16329991963465, -4.5889502807463645`}}, {{
       4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}, {{
       4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}, {{
       4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}, {{
       4.111053832673697, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}, {
       4.111053832673697, -4.63738059883611}, {
       4.111053832673697, -4.63738059883611}}, {{
       4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}, {{
       4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}, {{
       4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}, {{
       4.04298890341414, -4.658411878347753}, {
       3.950639144379684, -4.63738059883611}, {
       3.950639144379684, -4.63738059883611}, {
       4.04298890341414, -4.658411878347753}, {
       4.04298890341414, -4.658411878347753}}, {{
       3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}, {{
       3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}, {{
       3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}, {{
       3.950639144379684, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}, {
       3.950639144379684, -4.359534208430555}, {
       3.950639144379684, -4.359534208430555}}, {{
       4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}, {{
       4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}, {{
       4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}, {{
       4.04298890341414, -4.338502928918912}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}, {
       4.04298890341414, -4.338502928918912}, {
       4.04298890341414, -4.338502928918912}}, {{
       4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}, {{
       4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}, {{
       4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}, {{
       4.111053832673697, -4.359534208430555}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}, {
       4.111053832673697, -4.359534208430555}, {
       4.111053832673697, -4.359534208430555}}, {{
       4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}, {{
       4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}, {{
       4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}, {{
       4.16329991963465, -4.4079645265203}, {
       4.191261176820704, -4.498457403633332}, {
       4.191261176820704, -4.498457403633332}, {
       4.16329991963465, -4.4079645265203}, {
       4.16329991963465, -4.4079645265203}}, {{
       3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}, {{
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}, {{
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}, {{
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}, {{
       3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}, {{
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}, {{
       3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}, {{
       3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}, {{
       3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}, {{
       3.978003002371727, -4.09784372967273}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}}, {{
       3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}, {{
       3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}, {{
       3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}, {{
       3.9247550211410878`, -4.040400401451843}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -4.040400401451843}, {
       3.9247550211410878`, -4.040400401451843}}, {{
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}, {{
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}, {{
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}, {{
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9116731603487733`, -3.9829570732309567`}, {
       3.9116731603487733`, -3.9829570732309567`}}, {{
       3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}, {{
       3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}, {{
       3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}, {{
       3.9247550211410878`, -3.92551374501007}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}, {
       3.9247550211410878`, -3.92551374501007}, {
       3.9247550211410878`, -3.92551374501007}}, {{
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}, {{
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}, {{
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}, {{
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}}, {{
       4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}, {{
       4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}, {{
       4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}, {{
       4.153869137538694, -4.0577928417873705`}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}, {
       4.153869137538694, -4.0577928417873705`}, {
       4.153869137538694, -4.0577928417873705`}}, {{
       4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}, {{
       4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}, {{
       4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}, {{
       4.110662686417635, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}, {
       4.110662686417635, -4.09784372967273}, {
       4.110662686417635, -4.09784372967273}}, {{
       4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}, {{
       4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}, {{
       4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}, {{
       4.054374374504262, -4.115236170008258}, {
       3.978003002371727, -4.09784372967273}, {
       3.978003002371727, -4.09784372967273}, {
       4.054374374504262, -4.115236170008258}, {
       4.054374374504262, -4.115236170008258}}, {{
       3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}, {{
       3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}, {{
       3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}, {{
       3.978003002371727, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}, {
       3.978003002371727, -3.868070416789183}, {
       3.978003002371727, -3.868070416789183}}, {{
       4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}, {{
       4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}, {{
       4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}, {{
       4.054374374504262, -3.850677976453656}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}, {
       4.054374374504262, -3.850677976453656}, {
       4.054374374504262, -3.850677976453656}}, {{
       4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}, {{
       4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}, {{
       4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}, {{
       4.110662686417635, -3.868070416789183}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}, {
       4.110662686417635, -3.868070416789183}, {
       4.110662686417635, -3.868070416789183}}, {{
       4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}, {{
       4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}, {{
       4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}, {{
       4.153869137538694, -3.908121304674543}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.176992528440589, -3.9829570732309567`}, {
       4.153869137538694, -3.908121304674543}, {
       4.153869137538694, -3.908121304674543}}, {{
       3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}, {{
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}, {{
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}, {{
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}, {{
       3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}, {{
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}, {{
       3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}, {{
       3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}, {{
       3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}, {{
       3.973594693760035, -3.5875565298673675`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}}, {{
       3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}, {{
       3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}, {{
       3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}, {{
       3.9176105960023317`, -3.527161509655869}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.527161509655869}, {
       3.9176105960023317`, -3.527161509655869}}, {{
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}, {{
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}, {{
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}, {{
       3.903856531406392, -3.4667664894443706`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.903856531406392, -3.4667664894443706`}, {
       3.903856531406392, -3.4667664894443706`}}, {{
       3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}, {{
       3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}, {{
       3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}, {{
       3.9176105960023317`, -3.406371469232872}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.9176105960023317`, -3.406371469232872}, {
       3.9176105960023317`, -3.406371469232872}}, {{
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}, {{
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}, {{
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}, {{
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}}, {{
       4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}, {{
       4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}, {{
       4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}, {{
       4.158497607934583, -3.5454476504162424`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.158497607934583, -3.5454476504162424`}, {
       4.158497607934583, -3.5454476504162424`}}, {{
       4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}, {{
       4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}, {{
       4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}, {{
       4.113071018467322, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}, {
       4.113071018467322, -3.5875565298673675`}, {
       4.113071018467322, -3.5875565298673675`}}, {{
       4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}, {{
       4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}, {{
       4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}, {{
       4.053890364404119, -3.605842670627741}, {
       3.973594693760035, -3.5875565298673675`}, {
       3.973594693760035, -3.5875565298673675`}, {
       4.053890364404119, -3.605842670627741}, {
       4.053890364404119, -3.605842670627741}}, {{
       3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}, {{
       3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}, {{
       3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}, {{
       3.973594693760035, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}, {
       3.973594693760035, -3.3459764490213737`}, {
       3.973594693760035, -3.3459764490213737`}}, {{
       4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}, {{
       4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}, {{
       4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}, {{
       4.053890364404119, -3.3276903082610003`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.053890364404119, -3.3276903082610003`}, {
       4.053890364404119, -3.3276903082610003`}}, {{
       4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}, {{
       4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}, {{
       4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}, {{
       4.113071018467322, -3.3459764490213737`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.113071018467322, -3.3459764490213737`}, {
       4.113071018467322, -3.3459764490213737`}}, {{
       4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}, {{
       4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}, {{
       4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}, {{
       4.158497607934583, -3.3880853284724988`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.182809180820964, -3.4667664894443706`}, {
       4.158497607934583, -3.3880853284724988`}, {
       4.158497607934583, -3.3880853284724988`}}, {{
       3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}, {{
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}, {{
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}, {{
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}, {{
       3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}, {{
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}, {{
       3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}, {{
       3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}, {{
       3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}, {{
       3.966539891059902, -3.159931591540561}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}}, {{
       3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}, {{
       3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}, {{
       3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}, {{
       3.9113297131589833`, -3.1003714674382197`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -3.1003714674382197`}, {
       3.9113297131589833`, -3.1003714674382197`}}, {{
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}, {{
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}, {{
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}, {{
       3.8977657836929933`, -3.0408113433358785`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.8977657836929933`, -3.0408113433358785`}, {
       3.8977657836929933`, -3.0408113433358785`}}, {{
       3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}, {{
       3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}, {{
       3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}, {{
       3.9113297131589833`, -2.9812512192335374`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.9113297131589833`, -2.9812512192335374`}, {
       3.9113297131589833`, -2.9812512192335374`}}, {{
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}, {{
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}, {{
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}, {{
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}}, {{
       4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}, {{
       4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}, {{
       4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}, {{
       4.148886721585905, -3.1184048219967027`}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}, {
       4.148886721585905, -3.1184048219967027`}, {
       4.148886721585905, -3.1184048219967027`}}, {{
       4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}, {{
       4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}, {{
       4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}, {{
       4.104088105793719, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}, {
       4.104088105793719, -3.159931591540561}, {
       4.104088105793719, -3.159931591540561}}, {{
       4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}, {{
       4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}, {{
       4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}, {{
       4.045725560535542, -3.177964946099044}, {
       3.966539891059902, -3.159931591540561}, {
       3.966539891059902, -3.159931591540561}, {
       4.045725560535542, -3.177964946099044}, {
       4.045725560535542, -3.177964946099044}}, {{
       3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}, {{
       3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}, {{
       3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}, {{
       3.966539891059902, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}, {
       3.966539891059902, -2.9216910951311963`}, {
       3.966539891059902, -2.9216910951311963`}}, {{
       4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}, {{
       4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}, {{
       4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}, {{
       4.045725560535542, -2.9036577405727133`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.045725560535542, -2.9036577405727133`}, {
       4.045725560535542, -2.9036577405727133`}}, {{
       4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}, {{
       4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}, {{
       4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}, {{
       4.104088105793719, -2.9216910951311963`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.104088105793719, -2.9216910951311963`}, {
       4.104088105793719, -2.9216910951311963`}}, {{
       4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}, {{
       4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}, {{
       4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}, {{
       4.148886721585905, -2.9632178646750544`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.172862213160626, -3.0408113433358785`}, {
       4.148886721585905, -2.9632178646750544`}, {
       4.148886721585905, -2.9632178646750544`}}, {{
       3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.554629568923093}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}, {{
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}, {{
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}, {{
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}, {{
       3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}, {{
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}, {{
       3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}, {{
       3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}, {{
       3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}, {{
       3.896325319578804, -2.6254191407816467`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}}, {{
       3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}, {{
       3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}, {{
       3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}, {{
       3.8307058314607967`, -2.5546295689230925`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.5546295689230925`}, {
       3.8307058314607967`, -2.5546295689230925`}}, {{
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}, {{
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}, {{
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}, {{
       3.814584562842095, -2.4838399970645386`}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.8307058314607967`, -2.413050425205985}, {
       3.814584562842095, -2.4838399970645386`}, {
       3.814584562842095, -2.4838399970645386`}}, {{
       3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}, {{
       3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}, {{
       3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}, {{
       3.8307058314607967`, -2.4130504252059843`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.8307058314607967`, -2.4130504252059843`}, {
       3.8307058314607967`, -2.4130504252059843`}}, {{
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}, {{
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}, {{
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}, {{
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}}, {{
       4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}, {{
       4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}, {{
       4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}, {{
       4.113051766295404, -2.5760629266873414`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.113051766295404, -2.5760629266873414`}, {
       4.113051766295404, -2.5760629266873414`}}, {{
       4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}, {{
       4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}, {{
       4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}, {{
       4.059806833052222, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}, {
       4.059806833052222, -2.6254191407816467`}, {
       4.059806833052222, -2.6254191407816467`}}, {{
       3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}, {{
       3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}, {{
       3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}, {{
       3.9904406311903395`, -2.646852498545895}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.896325319578804, -2.6254191407816467`}, {
       3.9904406311903395`, -2.646852498545895}, {
       3.9904406311903395`, -2.646852498545895}}, {{
       3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}, {{
       3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}, {{
       3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}, {{
       3.896325319578804, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.896325319578804, -2.3422608533474305`}, {
       3.896325319578804, -2.3422608533474305`}}, {{
       3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}, {{
       3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}, {{
       3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}, {{
       3.9904406311903395`, -2.320827495583182}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}, {
       3.9904406311903395`, -2.320827495583182}, {
       3.9904406311903395`, -2.320827495583182}}, {{
       4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}, {{
       4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}, {{
       4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}, {{
       4.059806833052222, -2.3422608533474305`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}, {
       4.059806833052222, -2.3422608533474305`}, {
       4.059806833052222, -2.3422608533474305`}}, {{
       4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}, {{
       4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}, {{
       4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}, {{
       4.113051766295404, -2.391617067441736}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.141547589788932, -2.4838399970645386`}, {
       4.113051766295404, -2.391617067441736}, {
       4.113051766295404, -2.391617067441736}}, {{
       3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}, {{
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}, {{
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.144868573454172}, {
       3.9121493648584376`, -2.144868573454172}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}, {{
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}, {{
       3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}, {{
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}, {{
       3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}, {{
       3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}, {{
       3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}, {{
       3.9121493648584376`, -2.1448685734541715`}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}}, {{
       3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}, {{
       3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}, {{
       3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}, {{
       3.8582114394770417`, -2.086680941179121}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -2.086680941179121}, {
       3.8582114394770417`, -2.086680941179121}}, {{
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}, {{
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}, {{
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}, {{
       3.844960074543423, -2.028493308904071}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.8582114394770417`, -1.9703056766290206`}, {
       3.844960074543423, -2.028493308904071}, {
       3.844960074543423, -2.028493308904071}}, {{
       3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}, {{
       3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}, {{
       3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}, {{
       3.8582114394770417`, -1.9703056766290203`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.8582114394770417`, -1.9703056766290203`}, {
       3.8582114394770417`, -1.9703056766290203`}}, {{
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}, {{
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}, {{
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}, {{
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}}, {{
       4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}, {{
       4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}, {{
       4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}, {{
       4.090294230757919, -2.1042987386493146`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.090294230757919, -2.1042987386493146`}, {
       4.090294230757919, -2.1042987386493146`}}, {{
       4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}, {{
       4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}, {{
       4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}, {{
       4.046527945488466, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}, {
       4.046527945488466, -2.1448685734541715`}, {
       4.046527945488466, -2.1448685734541715`}}, {{
       3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}, {{
       3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}, {{
       3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}, {{
       3.9895102952853967`, -2.162486370924365}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9121493648584376`, -2.1448685734541715`}, {
       3.9895102952853967`, -2.162486370924365}, {
       3.9895102952853967`, -2.162486370924365}}, {{
       3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}, {{
       3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}, {{
       3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}, {{
       3.9121493648584376`, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9121493648584376`, -1.91211804435397}, {
       3.9121493648584376`, -1.91211804435397}}, {{
       3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}, {{
       3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}, {{
       3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}, {{
       3.9895102952853967`, -1.8945002468837768`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}, {
       3.9895102952853967`, -1.8945002468837768`}, {
       3.9895102952853967`, -1.8945002468837768`}}, {{
       4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}, {{
       4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}, {{
       4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}, {{
       4.046527945488466, -1.91211804435397}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.046527945488466, -1.91211804435397}, {
       4.046527945488466, -1.91211804435397}}, {{
       4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}, {{
       4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}, {{
       4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}, {{
       4.090294230757919, -1.9526878791588274`}, {
       4.113717235803481, -2.028493308904071}, {
       4.113717235803481, -2.028493308904071}, {
       4.090294230757919, -1.9526878791588274`}, {
       4.090294230757919, -1.9526878791588274`}}, {{
       3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}, {{
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}, {{
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}, {{
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}, {{
       3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}, {{
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}, {{
       3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}, {{
       3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}, {{
       3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}, {{
       3.91418707294467, -1.5908506857753697`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}}, {{
       3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}, {{
       3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}, {{
       3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}, {{
       3.8610094040808067`, -1.5334832097514937`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.5334832097514937`}, {
       3.8610094040808067`, -1.5334832097514937`}}, {{
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}, {{
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}, {{
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}, {{
       3.847944817494441, -1.4761157337276174`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.847944817494441, -1.4761157337276174`}, {
       3.847944817494441, -1.4761157337276174`}}, {{
       3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}, {{
       3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}, {{
       3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}, {{
       3.8610094040808067`, -1.4187482577037411`}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}, {
       3.8610094040808067`, -1.4187482577037411`}, {
       3.8610094040808067`, -1.4187482577037411`}}, {{
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}, {{
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}, {{
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}, {{
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}}, {{
       4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}, {{
       4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}, {{
       4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}, {{
       4.089820982139615, -1.5508526838896977`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.089820982139615, -1.5508526838896977`}, {
       4.089820982139615, -1.5508526838896977`}}, {{
       4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}, {{
       4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}, {{
       4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}, {{
       4.046671583845127, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       4.046671583845127, -1.5908506857753697`}, {
       4.046671583845127, -1.5908506857753697`}}, {{
       3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}, {{
       3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}, {{
       3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}, {{
       3.9904575989642725`, -1.6082201599135737`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.91418707294467, -1.5908506857753697`}, {
       3.9904575989642725`, -1.6082201599135737`}, {
       3.9904575989642725`, -1.6082201599135737`}}, {{
       3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}, {{
       3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}, {{
       3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}, {{
       3.91418707294467, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.91418707294467, -1.361380781679865}, {
       3.91418707294467, -1.361380781679865}}, {{
       3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}, {{
       3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}, {{
       3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}, {{
       3.9904575989642725`, -1.344011307541661}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}, {
       3.9904575989642725`, -1.344011307541661}, {
       3.9904575989642725`, -1.344011307541661}}, {{
       4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}, {{
       4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}, {{
       4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}, {{
       4.046671583845127, -1.361380781679865}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.046671583845127, -1.361380781679865}, {
       4.046671583845127, -1.361380781679865}}, {{
       4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}, {{
       4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}, {{
       4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}, {{
       4.089820982139615, -1.4013787835655371`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.112913839295356, -1.4761157337276174`}, {
       4.089820982139615, -1.4013787835655371`}, {
       4.089820982139615, -1.4013787835655371`}}, {{
       3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}, {{
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}, {{
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}, {{
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}, {{
       3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}, {{
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}, {{
       3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}, {{
       3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}, {{
       3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}, {{
       3.9282164880184975`, -1.147494901175745}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}}, {{
       3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}, {{
       3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}, {{
       3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}, {{
       3.8636136519382664`, -1.0778020821957548`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -1.0778020821957548`}, {
       3.8636136519382664`, -1.0778020821957548`}}, {{
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}, {{
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}, {{
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}, {{
       3.847742152421135, -1.0081092632157649`}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.847742152421135, -1.0081092632157649`}, {
       3.847742152421135, -1.0081092632157649`}}, {{
       3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}, {{
       3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}, {{
       3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}, {{
       3.8636136519382664`, -0.9384164442357749}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.8636136519382664`, -0.9384164442357749}, {
       3.8636136519382664`, -0.9384164442357749}}, {{
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}, {{
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}, {{
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}, {{
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}}, {{
       4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}, {{
       4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}, {{
       4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}, {{
       4.141585161152678, -1.0989033699077617`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}, {
       4.141585161152678, -1.0989033699077617`}, {
       4.141585161152678, -1.0989033699077617`}}, {{
       4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}, {{
       4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}, {{
       4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}, {{
       4.089165159213222, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.089165159213222, -1.147494901175745}, {
       4.089165159213222, -1.147494901175745}}, {{
       4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}, {{
       4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}, {{
       4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}, {{
       4.020873657756635, -1.1685961888877519`}, {
       3.9282164880184975`, -1.147494901175745}, {
       3.9282164880184975`, -1.147494901175745}, {
       4.020873657756635, -1.1685961888877519`}, {
       4.020873657756635, -1.1685961888877519`}}, {{
       3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}, {{
       3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}, {{
       3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}, {{
       3.9282164880184975`, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}, {
       3.9282164880184975`, -0.8687236252557848}, {
       3.9282164880184975`, -0.8687236252557848}}, {{
       4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}, {{
       4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}, {{
       4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}, {{
       4.020873657756635, -0.8476223375437779}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}, {
       4.020873657756635, -0.8476223375437779}, {
       4.020873657756635, -0.8476223375437779}}, {{
       4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}, {{
       4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}, {{
       4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}, {{
       4.089165159213222, -0.8687236252557848}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}, {
       4.089165159213222, -0.8687236252557848}, {
       4.089165159213222, -0.8687236252557848}}, {{
       4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}, {{
       4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}, {{
       4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}, {{
       4.141585161152678, -0.9173151565237679}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.169639494810584, -1.0081092632157649`}, {
       4.141585161152678, -0.9173151565237679}, {
       4.141585161152678, -0.9173151565237679}}, {{
       3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}, {{
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}, {{
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827628, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}, {{
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}, {{
       3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}, {{
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}, {{
       3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}, {{
       3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}, {{
       3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}, {{
       3.902568040611481, -0.6257149540288811}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}}, {{
       3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}, {{
       3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}, {{
       3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}, {{
       3.8412018866709348`, -0.5595138316390638}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.5595138316390638}, {
       3.8412018866709348`, -0.5595138316390638}}, {{
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}, {{
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}, {{
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}, {{
       3.826125568946648, -0.4933127092492464}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.826125568946648, -0.4933127092492464}, {
       3.826125568946648, -0.4933127092492464}}, {{
       3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}, {{
       3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}, {{
       3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}, {{
       3.8412018866709348`, -0.42711158685942907`}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}, {
       3.8412018866709348`, -0.42711158685942907`}, {
       3.8412018866709348`, -0.42711158685942907`}}, {{
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}, {{
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}, {{
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}, {{
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}}, {{
       4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}, {{
       4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}, {{
       4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}, {{
       4.105246678827627, -0.5795579186892146}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}, {
       4.105246678827627, -0.5795579186892146}, {
       4.105246678827627, -0.5795579186892146}}, {{
       4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}, {{
       4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}, {{
       4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}, {{
       4.055452983941146, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}, {
       4.055452983941146, -0.6257149540288811}, {
       4.055452983941146, -0.6257149540288811}}, {{
       3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}, {{
       3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}, {{
       3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}, {{
       3.990582971330378, -0.6457590410790319}, {
       3.902568040611481, -0.6257149540288811}, {
       3.902568040611481, -0.6257149540288811}, {
       3.990582971330378, -0.6457590410790319}, {
       3.990582971330378, -0.6457590410790319}}, {{
       3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}, {{
       3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}, {{
       3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}, {{
       3.902568040611481, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}, {
       3.902568040611481, -0.3609104644696117}, {
       3.902568040611481, -0.3609104644696117}}, {{
       3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}, {{
       3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}, {{
       3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}, {{
       3.990582971330378, -0.3408663774194609}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}, {
       3.990582971330378, -0.3408663774194609}, {
       3.990582971330378, -0.3408663774194609}}, {{
       4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}, {{
       4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}, {{
       4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}, {{
       4.055452983941146, -0.3609104644696117}, {
       4.105246678827627, -0.4070674998092783}, {
       4.105246678827627, -0.4070674998092783}, {
       4.055452983941146, -0.3609104644696117}, {
       4.055452983941146, -0.3609104644696117}}, {{
       4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}, {{
       4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}, {{
       4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}, {{
       4.105246678827628, -0.4070674998092783}, {
       4.131895455605979, -0.4933127092492464}, {
       4.131895455605979, -0.4933127092492464}, {
       4.105246678827628, -0.4070674998092783}, {
       4.105246678827628, -0.4070674998092783}}, {{
       3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.1660644381081866}, {3.9460740047629037`, 
       0.1660644381081866}, {3.8809552149331346`, 0.0958150139781695}, {
       3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, -0.04468383428186476}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}, {{3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}}, {{
       4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188187`}, {
       3.9460740047629037`, -0.11493325841188187`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}, {{
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}, {{3.9460740047629037`, 
       0.16606443810818663`}, {4.039471185575611, 0.18733425229945794`}, {
       4.10830810049043, 0.1660644381081866}, {4.161146757371255, 
       0.11708482816944078`}, {4.189425148354193, 0.0255655898481524}, {
       4.189425148354193, 0.0255655898481524}, {4.161146757371255, 
       0.11708482816944078`}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.9460740047629037`, 0.16606443810818663`}}, {{
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}, {{3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}, {{
       3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}, {{
       3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}, {{
       3.9460740047629037`, -0.11493325841188184`}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}}, {{
       3.8809552149331346`, -0.04468383428186473}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}, {{
       3.8809552149331346`, -0.04468383428186473}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}, {{
       3.8809552149331346`, -0.04468383428186473}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}, {{
       3.8809552149331346`, -0.04468383428186473}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, -0.04468383428186473}, {
       3.8809552149331346`, -0.04468383428186473}}, {{3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, 0.0958150139781695}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}}, {{
       3.8649569568991406`, 0.02556558984815238}, {3.8809552149331346`, 
       0.0958150139781695}, {3.8809552149331346`, 0.0958150139781695}, {
       3.8649569568991406`, 0.02556558984815238}, {3.8649569568991406`, 
       0.02556558984815238}}, {{3.8649569568991406`, 0.02556558984815238}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8809552149331346`, 
       0.0958150139781695}, {3.8649569568991406`, 0.02556558984815238}, {
       3.8649569568991406`, 0.02556558984815238}}, {{3.8649569568991406`, 
       0.02556558984815238}, {3.8809552149331346`, 0.0958150139781695}, {
       3.8809552149331346`, 0.0958150139781695}, {3.8649569568991406`, 
       0.02556558984815238}, {3.8649569568991406`, 0.02556558984815238}}, {{
       3.8809552149331346`, 0.09581501397816952}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.8809552149331346`, 0.09581501397816952}, {3.8809552149331346`, 
       0.09581501397816952}}, {{3.8809552149331346`, 0.09581501397816952}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.8809552149331346`, 0.09581501397816952}, {
       3.8809552149331346`, 0.09581501397816952}}, {{3.8809552149331346`, 
       0.09581501397816952}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.8809552149331346`, 
       0.09581501397816952}, {3.8809552149331346`, 0.09581501397816952}}, {{
       3.8809552149331346`, 0.09581501397816952}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.8809552149331346`, 0.09581501397816952}, {3.8809552149331346`, 
       0.09581501397816952}}, {{4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}, {{
       4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}, {{
       4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}, {{
       4.189425148354193, 0.025565589848152364`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}, {4.189425148354193, 
       0.025565589848152364`}, {4.189425148354193, 0.025565589848152364`}}, {{
       4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}, {{
       4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}, {{
       4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}, {{
       4.161146757371255, -0.06595364847313602}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.161146757371255, -0.06595364847313602}, {
       4.161146757371255, -0.06595364847313602}}, {{
       4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}, {{
       4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}, {{
       4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}, {{
       4.10830810049043, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.10830810049043, -0.11493325841188184`}, {
       4.10830810049043, -0.11493325841188184`}}, {{
       4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}, {{
       4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}, {{
       4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}, {{
       4.039471185575611, -0.13620307260315317`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       3.9460740047629037`, -0.11493325841188184`}, {
       4.039471185575611, -0.13620307260315317`}, {
       4.039471185575611, -0.13620307260315317`}}, {{3.9460740047629037`, 
       0.16606443810818663`}, {4.039471185575611, 0.18733425229945794`}, {
       4.039471185575611, 0.18733425229945794`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.9460740047629037`, 0.16606443810818663`}}, {{
       3.9460740047629037`, 0.16606443810818663`}, {4.039471185575611, 
       0.18733425229945794`}, {4.039471185575611, 0.18733425229945794`}, {
       3.9460740047629037`, 0.16606443810818663`}, {3.9460740047629037`, 
       0.16606443810818663`}}, {{3.9460740047629037`, 0.16606443810818663`}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}, {3.9460740047629037`, 0.16606443810818663`}, {
       3.9460740047629037`, 0.16606443810818663`}}, {{3.9460740047629037`, 
       0.16606443810818663`}, {4.039471185575611, 0.18733425229945794`}, {
       4.039471185575611, 0.18733425229945794`}, {3.9460740047629037`, 
       0.16606443810818663`}, {3.9460740047629037`, 0.16606443810818663`}}, {{
       4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}}, {{4.039471185575611, 0.18733425229945794`}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}, {4.039471185575611, 0.18733425229945794`}, {
       4.039471185575611, 0.18733425229945794`}}, {{4.039471185575611, 
       0.18733425229945794`}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}, {4.039471185575611, 
       0.18733425229945794`}, {4.039471185575611, 0.18733425229945794`}}, {{
       4.039471185575611, 0.18733425229945794`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}, {
       4.039471185575611, 0.18733425229945794`}, {4.039471185575611, 
       0.18733425229945794`}}, {{4.10830810049043, 0.1660644381081866}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}}, {{4.10830810049043, 
       0.1660644381081866}, {4.161146757371255, 0.11708482816944078`}, {
       4.161146757371255, 0.11708482816944078`}, {4.10830810049043, 
       0.1660644381081866}, {4.10830810049043, 0.1660644381081866}}, {{
       4.10830810049043, 0.1660644381081866}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}, {
       4.10830810049043, 0.1660644381081866}, {4.10830810049043, 
       0.1660644381081866}}, {{4.10830810049043, 0.1660644381081866}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}, {4.10830810049043, 0.1660644381081866}, {
       4.10830810049043, 0.1660644381081866}}, {{4.161146757371255, 
       0.11708482816944078`}, {4.189425148354193, 0.025565589848152354`}, {
       4.189425148354193, 0.025565589848152354`}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}}, {{
       4.161146757371255, 0.11708482816944078`}, {4.189425148354193, 
       0.025565589848152354`}, {4.189425148354193, 0.025565589848152354`}, {
       4.161146757371255, 0.11708482816944078`}, {4.161146757371255, 
       0.11708482816944078`}}, {{4.161146757371255, 0.11708482816944078`}, {
       4.189425148354193, 0.025565589848152354`}, {4.189425148354193, 
       0.025565589848152354`}, {4.161146757371255, 0.11708482816944078`}, {
       4.161146757371255, 0.11708482816944078`}}, {{4.161146757371255, 
       0.11708482816944078`}, {4.189425148354193, 0.025565589848152354`}, {
       4.189425148354193, 0.025565589848152354`}, {4.161146757371255, 
       0.11708482816944078`}, {4.161146757371255, 0.11708482816944078`}}, {{
       3.9146358014357365`, 0.40214195501842886`}, {3.848274986486314, 
       0.47373126199391613`}, {3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.831971590128944, 
       0.5453205689694034}, {3.848274986486314, 0.47373126199391613`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}}, {{3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}}, {{4.1626284353561145`, 
       0.5453205689694034}, {4.133810684350731, 0.45205576391962143`}, {
       4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.079964224049322, 0.40214195501842886`}, {
       4.133810684350731, 0.45205576391962143`}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}}, {{
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}, {{3.9146358014357365`, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.133810684350731, 0.6385853740191854}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}, {4.133810684350731, 0.6385853740191854}, {
       4.079964224049322, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {3.9146358014357365`, 0.6884991829203779}, {
       3.9146358014357365`, 0.6884991829203779}}, {{4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}}, {{
       3.9146358014357365`, 0.40214195501842886`}, {3.848274986486314, 
       0.47373126199391613`}, {3.848274986486314, 0.47373126199391613`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}}, {{3.9146358014357365`, 0.40214195501842886`}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}}, {{3.9146358014357365`, 
       0.40214195501842886`}, {3.848274986486314, 0.47373126199391613`}, {
       3.848274986486314, 0.47373126199391613`}, {3.9146358014357365`, 
       0.40214195501842886`}, {3.9146358014357365`, 0.40214195501842886`}}, {{
       3.9146358014357365`, 0.40214195501842886`}, {3.848274986486314, 
       0.47373126199391613`}, {3.848274986486314, 0.47373126199391613`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}}, {{3.848274986486314, 0.47373126199391613`}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.848274986486314, 0.47373126199391613`}, {
       3.848274986486314, 0.47373126199391613`}}, {{3.848274986486314, 
       0.47373126199391613`}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.47373126199391613`}, {3.848274986486314, 0.47373126199391613`}}, {{
       3.848274986486314, 0.47373126199391613`}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.47373126199391613`}, {3.848274986486314, 
       0.47373126199391613`}}, {{3.848274986486314, 0.47373126199391613`}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}, {3.848274986486314, 0.47373126199391613`}, {
       3.848274986486314, 0.47373126199391613`}}, {{3.831971590128944, 
       0.5453205689694034}, {3.848274986486314, 0.6169098759448907}, {
       3.848274986486314, 0.6169098759448907}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}}, {{
       3.831971590128944, 0.5453205689694034}, {3.848274986486314, 
       0.6169098759448907}, {3.848274986486314, 0.6169098759448907}, {
       3.831971590128944, 0.5453205689694034}, {3.831971590128944, 
       0.5453205689694034}}, {{3.831971590128944, 0.5453205689694034}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}, {3.831971590128944, 0.5453205689694034}, {
       3.831971590128944, 0.5453205689694034}}, {{3.831971590128944, 
       0.5453205689694034}, {3.848274986486314, 0.6169098759448907}, {
       3.848274986486314, 0.6169098759448907}, {3.831971590128944, 
       0.5453205689694034}, {3.831971590128944, 0.5453205689694034}}, {{
       3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}}, {{3.848274986486314, 0.6169098759448907}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}, {3.848274986486314, 0.6169098759448907}, {
       3.848274986486314, 0.6169098759448907}}, {{3.848274986486314, 
       0.6169098759448907}, {3.9146358014357365`, 0.6884991829203779}, {
       3.9146358014357365`, 0.6884991829203779}, {3.848274986486314, 
       0.6169098759448907}, {3.848274986486314, 0.6169098759448907}}, {{
       3.848274986486314, 0.6169098759448907}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}, {
       3.848274986486314, 0.6169098759448907}, {3.848274986486314, 
       0.6169098759448907}}, {{4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}, {4.1626284353561145`, 0.5453205689694034}, {
       4.1626284353561145`, 0.5453205689694034}}, {{4.1626284353561145`, 
       0.5453205689694034}, {4.133810684350731, 0.45205576391962143`}, {
       4.133810684350731, 0.45205576391962143`}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}}, {{
       4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}}, {{4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}, {4.1626284353561145`, 0.5453205689694034}, {
       4.1626284353561145`, 0.5453205689694034}}, {{4.133810684350731, 
       0.45205576391962143`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}}, {{
       4.133810684350731, 0.45205576391962143`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}, {
       4.133810684350731, 0.45205576391962143`}, {4.133810684350731, 
       0.45205576391962143`}}, {{4.133810684350731, 0.45205576391962143`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}, {4.133810684350731, 0.45205576391962143`}, {
       4.133810684350731, 0.45205576391962143`}}, {{4.133810684350731, 
       0.45205576391962143`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}, {4.133810684350731, 
       0.45205576391962143`}, {4.133810684350731, 0.45205576391962143`}}, {{
       4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}, {{4.079964224049322, 0.40214195501842886`}, {
       4.009814367390542, 0.38046645694413417`}, {4.009814367390542, 
       0.38046645694413417`}, {4.079964224049322, 0.40214195501842886`}, {
       4.079964224049322, 0.40214195501842886`}}, {{4.079964224049322, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}, {4.079964224049322, 
       0.40214195501842886`}, {4.079964224049322, 0.40214195501842886`}}, {{
       4.079964224049322, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}, {
       4.079964224049322, 0.40214195501842886`}, {4.079964224049322, 
       0.40214195501842886`}}, {{4.009814367390542, 0.38046645694413417`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}}, {{4.009814367390542, 
       0.38046645694413417`}, {3.9146358014357365`, 0.40214195501842886`}, {
       3.9146358014357365`, 0.40214195501842886`}, {4.009814367390542, 
       0.38046645694413417`}, {4.009814367390542, 0.38046645694413417`}}, {{
       4.009814367390542, 0.38046645694413417`}, {3.9146358014357365`, 
       0.40214195501842886`}, {3.9146358014357365`, 0.40214195501842886`}, {
       4.009814367390542, 0.38046645694413417`}, {4.009814367390542, 
       0.38046645694413417`}}, {{4.009814367390542, 0.38046645694413417`}, {
       3.9146358014357365`, 0.40214195501842886`}, {3.9146358014357365`, 
       0.40214195501842886`}, {4.009814367390542, 0.38046645694413417`}, {
       4.009814367390542, 0.38046645694413417`}}, {{3.9146358014357365`, 
       0.6884991829203779}, {4.009814367390542, 0.7101746809946726}, {
       4.009814367390542, 0.7101746809946726}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}}, {{
       3.9146358014357365`, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.009814367390542, 0.7101746809946726}, {
       3.9146358014357365`, 0.6884991829203779}, {3.9146358014357365`, 
       0.6884991829203779}}, {{3.9146358014357365`, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}, {3.9146358014357365`, 0.6884991829203779}, {
       3.9146358014357365`, 0.6884991829203779}}, {{3.9146358014357365`, 
       0.6884991829203779}, {4.009814367390542, 0.7101746809946726}, {
       4.009814367390542, 0.7101746809946726}, {3.9146358014357365`, 
       0.6884991829203779}, {3.9146358014357365`, 0.6884991829203779}}, {{
       4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}}, {{4.009814367390542, 0.7101746809946726}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}, {4.009814367390542, 0.7101746809946726}, {
       4.009814367390542, 0.7101746809946726}}, {{4.009814367390542, 
       0.7101746809946726}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}, {4.009814367390542, 
       0.7101746809946726}, {4.009814367390542, 0.7101746809946726}}, {{
       4.009814367390542, 0.7101746809946726}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}, {
       4.009814367390542, 0.7101746809946726}, {4.009814367390542, 
       0.7101746809946726}}, {{4.079964224049322, 0.6884991829203779}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}}, {{4.079964224049322, 
       0.6884991829203779}, {4.133810684350731, 0.6385853740191854}, {
       4.133810684350731, 0.6385853740191854}, {4.079964224049322, 
       0.6884991829203779}, {4.079964224049322, 0.6884991829203779}}, {{
       4.079964224049322, 0.6884991829203779}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}, {
       4.079964224049322, 0.6884991829203779}, {4.079964224049322, 
       0.6884991829203779}}, {{4.079964224049322, 0.6884991829203779}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}, {4.079964224049322, 0.6884991829203779}, {
       4.079964224049322, 0.6884991829203779}}, {{4.133810684350731, 
       0.6385853740191854}, {4.1626284353561145`, 0.5453205689694034}, {
       4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}}, {{
       4.133810684350731, 0.6385853740191854}, {4.1626284353561145`, 
       0.5453205689694034}, {4.1626284353561145`, 0.5453205689694034}, {
       4.133810684350731, 0.6385853740191854}, {4.133810684350731, 
       0.6385853740191854}}, {{4.133810684350731, 0.6385853740191854}, {
       4.1626284353561145`, 0.5453205689694034}, {4.1626284353561145`, 
       0.5453205689694034}, {4.133810684350731, 0.6385853740191854}, {
       4.133810684350731, 0.6385853740191854}}, {{4.133810684350731, 
       0.6385853740191854}, {4.1626284353561145`, 0.5453205689694034}, {
       4.1626284353561145`, 0.5453205689694034}, {4.133810684350731, 
       0.6385853740191854}, {4.133810684350731, 0.6385853740191854}}, {{
       3.9548521886333052`, 0.9045553983786268}, {3.8912970408566845`, 
       0.9731179829026513}, {3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.9548521886333052`, 1.1788057364747249`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.875682935370741, 
       1.0416805674266758`}, {3.8912970408566845`, 0.9731179829026513}, {
       3.9548521886333052`, 0.9045553983786268}, {3.9548521886333052`, 
       0.9045553983786268}}, {{3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}}, {{4.1923599484209975`, 
       1.0416805674266758`}, {4.164760582362384, 0.9523589026488359}, {
       4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.113190695158433, 0.9045553983786268}, {
       4.164760582362384, 0.9523589026488359}, {4.1923599484209975`, 
       1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}}, {{
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}, {{3.9548521886333052`, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.164760582362384, 1.1310022322045157`}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}, {4.164760582362384, 1.1310022322045157`}, {
       4.113190695158433, 1.1788057364747249`}, {4.046006702468539, 
       1.1995648167285402`}, {3.9548521886333052`, 1.1788057364747249`}, {
       3.9548521886333052`, 1.1788057364747249`}}, {{4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}}, {{
       3.9548521886333052`, 0.9045553983786268}, {3.8912970408566845`, 
       0.9731179829026513}, {3.8912970408566845`, 0.9731179829026513}, {
       3.9548521886333052`, 0.9045553983786268}, {3.9548521886333052`, 
       0.9045553983786268}}, {{3.9548521886333052`, 0.9045553983786268}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}}, {{3.9548521886333052`, 
       0.9045553983786268}, {3.8912970408566845`, 0.9731179829026513}, {
       3.8912970408566845`, 0.9731179829026513}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}}, {{
       3.9548521886333052`, 0.9045553983786268}, {3.8912970408566845`, 
       0.9731179829026513}, {3.8912970408566845`, 0.9731179829026513}, {
       3.9548521886333052`, 0.9045553983786268}, {3.9548521886333052`, 
       0.9045553983786268}}, {{3.8912970408566845`, 0.9731179829026513}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.8912970408566845`, 0.9731179829026513}, {
       3.8912970408566845`, 0.9731179829026513}}, {{3.8912970408566845`, 
       0.9731179829026513}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`, 
       0.9731179829026513}, {3.8912970408566845`, 0.9731179829026513}}, {{
       3.8912970408566845`, 0.9731179829026513}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 0.9731179829026513}, {3.8912970408566845`, 
       0.9731179829026513}}, {{3.8912970408566845`, 0.9731179829026513}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}, {3.8912970408566845`, 0.9731179829026513}, {
       3.8912970408566845`, 0.9731179829026513}}, {{3.875682935370741, 
       1.0416805674266758`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}}, {{
       3.875682935370741, 1.0416805674266758`}, {3.8912970408566845`, 
       1.1102431519507003`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.875682935370741, 1.0416805674266758`}, {3.875682935370741, 
       1.0416805674266758`}}, {{3.875682935370741, 1.0416805674266758`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.8912970408566845`, 
       1.1102431519507003`}, {3.875682935370741, 1.0416805674266758`}, {
       3.875682935370741, 1.0416805674266758`}}, {{3.875682935370741, 
       1.0416805674266758`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.875682935370741, 
       1.0416805674266758`}, {3.875682935370741, 1.0416805674266758`}}, {{
       3.8912970408566845`, 1.1102431519507003`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.9548521886333052`, 1.1788057364747249`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.8912970408566845`, 
       1.1102431519507003`}}, {{3.8912970408566845`, 1.1102431519507003`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.8912970408566845`, 1.1102431519507003`}, {
       3.8912970408566845`, 1.1102431519507003`}}, {{3.8912970408566845`, 
       1.1102431519507003`}, {3.9548521886333052`, 1.1788057364747249`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.8912970408566845`, 
       1.1102431519507003`}, {3.8912970408566845`, 1.1102431519507003`}}, {{
       3.8912970408566845`, 1.1102431519507003`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.9548521886333052`, 1.1788057364747249`}, {
       3.8912970408566845`, 1.1102431519507003`}, {3.8912970408566845`, 
       1.1102431519507003`}}, {{4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.1923599484209975`, 1.0416805674266758`}}, {{4.1923599484209975`, 
       1.0416805674266758`}, {4.164760582362384, 0.9523589026488359}, {
       4.164760582362384, 0.9523589026488359}, {4.1923599484209975`, 
       1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}}, {{
       4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384, 
       0.9523589026488359}, {4.164760582362384, 0.9523589026488359}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}}, {{4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.1923599484209975`, 1.0416805674266758`}}, {{4.164760582362384, 
       0.9523589026488359}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.164760582362384, 
       0.9523589026488359}, {4.164760582362384, 0.9523589026488359}}, {{
       4.164760582362384, 0.9523589026488359}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}, {
       4.164760582362384, 0.9523589026488359}, {4.164760582362384, 
       0.9523589026488359}}, {{4.164760582362384, 0.9523589026488359}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}, {4.164760582362384, 0.9523589026488359}, {
       4.164760582362384, 0.9523589026488359}}, {{4.164760582362384, 
       0.9523589026488359}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}, {4.164760582362384, 
       0.9523589026488359}, {4.164760582362384, 0.9523589026488359}}, {{
       4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}, {{4.113190695158433, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.046006702468539, 
       0.8837963181248114}, {4.113190695158433, 0.9045553983786268}, {
       4.113190695158433, 0.9045553983786268}}, {{4.113190695158433, 
       0.9045553983786268}, {4.046006702468539, 0.8837963181248114}, {
       4.046006702468539, 0.8837963181248114}, {4.113190695158433, 
       0.9045553983786268}, {4.113190695158433, 0.9045553983786268}}, {{
       4.113190695158433, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}, {
       4.113190695158433, 0.9045553983786268}, {4.113190695158433, 
       0.9045553983786268}}, {{4.046006702468539, 0.8837963181248114}, {
       3.9548521886333052`, 0.9045553983786268}, {3.9548521886333052`, 
       0.9045553983786268}, {4.046006702468539, 0.8837963181248114}, {
       4.046006702468539, 0.8837963181248114}}, {{4.046006702468539, 
       0.8837963181248114}, {3.9548521886333052`, 0.9045553983786268}, {
       3.9548521886333052`, 0.9045553983786268}, {4.046006702468539, 
       0.8837963181248114}, {4.046006702468539, 0.8837963181248114}}, {{
       4.046006702468539, 0.8837963181248114}, {3.9548521886333052`, 
       0.9045553983786268}, {3.9548521886333052`, 0.9045553983786268}, {
       4.046006702468539, 0.8837963181248114}, {4.046006702468539, 
       0.8837963181248114}}, {{4.046006702468539, 0.8837963181248114}, {
       3.9548521886333052`, 0.9045553983786268}, {3.9548521886333052`, 
       0.9045553983786268}, {4.046006702468539, 0.8837963181248114}, {
       4.046006702468539, 0.8837963181248114}}, {{3.9548521886333052`, 
       1.1788057364747249`}, {4.046006702468539, 1.1995648167285402`}, {
       4.046006702468539, 1.1995648167285402`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.9548521886333052`, 1.1788057364747249`}}, {{
       3.9548521886333052`, 1.1788057364747249`}, {4.046006702468539, 
       1.1995648167285402`}, {4.046006702468539, 1.1995648167285402`}, {
       3.9548521886333052`, 1.1788057364747249`}, {3.9548521886333052`, 
       1.1788057364747249`}}, {{3.9548521886333052`, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}, {3.9548521886333052`, 1.1788057364747249`}, {
       3.9548521886333052`, 1.1788057364747249`}}, {{3.9548521886333052`, 
       1.1788057364747249`}, {4.046006702468539, 1.1995648167285402`}, {
       4.046006702468539, 1.1995648167285402`}, {3.9548521886333052`, 
       1.1788057364747249`}, {3.9548521886333052`, 1.1788057364747249`}}, {{
       4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}}, {{4.046006702468539, 1.1995648167285402`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}, {4.046006702468539, 1.1995648167285402`}, {
       4.046006702468539, 1.1995648167285402`}}, {{4.046006702468539, 
       1.1995648167285402`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}, {4.046006702468539, 
       1.1995648167285402`}, {4.046006702468539, 1.1995648167285402`}}, {{
       4.046006702468539, 1.1995648167285402`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}, {
       4.046006702468539, 1.1995648167285402`}, {4.046006702468539, 
       1.1995648167285402`}}, {{4.113190695158433, 1.1788057364747249`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}}, {{4.113190695158433, 
       1.1788057364747249`}, {4.164760582362384, 1.1310022322045157`}, {
       4.164760582362384, 1.1310022322045157`}, {4.113190695158433, 
       1.1788057364747249`}, {4.113190695158433, 1.1788057364747249`}}, {{
       4.113190695158433, 1.1788057364747249`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}, {
       4.113190695158433, 1.1788057364747249`}, {4.113190695158433, 
       1.1788057364747249`}}, {{4.113190695158433, 1.1788057364747249`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}, {4.113190695158433, 1.1788057364747249`}, {
       4.113190695158433, 1.1788057364747249`}}, {{4.164760582362384, 
       1.1310022322045157`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}}, {{
       4.164760582362384, 1.1310022322045157`}, {4.1923599484209975`, 
       1.0416805674266758`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.164760582362384, 1.1310022322045157`}, {4.164760582362384, 
       1.1310022322045157`}}, {{4.164760582362384, 1.1310022322045157`}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.1923599484209975`, 
       1.0416805674266758`}, {4.164760582362384, 1.1310022322045157`}, {
       4.164760582362384, 1.1310022322045157`}}, {{4.164760582362384, 
       1.1310022322045157`}, {4.1923599484209975`, 1.0416805674266758`}, {
       4.1923599484209975`, 1.0416805674266758`}, {4.164760582362384, 
       1.1310022322045157`}, {4.164760582362384, 1.1310022322045157`}}, {{
       3.9420879018335357`, 1.3649729363001064`}, {3.8823889919002466`, 
       1.429375454451421}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.9420879018335357`, 1.6225830089053643`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8823889919002466`, 1.429375454451421}, {
       3.9420879018335357`, 1.3649729363001064`}, {3.9420879018335357`, 
       1.3649729363001064`}}, {{3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}, {{4.165184768980443, 
       1.4937779726027354`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907, 
       1.3454734227952958`}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}, {4.027711573586907, 
       1.3454734227952958`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.1392600071603605`, 1.4098759409466104`}, {4.165184768980443, 
       1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}}, {{
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}, {{3.9420879018335357`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.1392600071603605`, 1.5776800042588603`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}, {4.1392600071603605`, 1.5776800042588603`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.027711573586907, 
       1.642082522410175}, {3.9420879018335357`, 1.6225830089053643`}, {
       3.9420879018335357`, 1.6225830089053643`}}, {{4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}}, {{
       3.9420879018335357`, 1.3649729363001064`}, {3.8823889919002466`, 
       1.429375454451421}, {3.8823889919002466`, 1.429375454451421}, {
       3.9420879018335357`, 1.3649729363001064`}, {3.9420879018335357`, 
       1.3649729363001064`}}, {{3.9420879018335357`, 1.3649729363001064`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}}, {{3.9420879018335357`, 
       1.3649729363001064`}, {3.8823889919002466`, 1.429375454451421}, {
       3.8823889919002466`, 1.429375454451421}, {3.9420879018335357`, 
       1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}}, {{
       3.9420879018335357`, 1.3649729363001064`}, {3.8823889919002466`, 
       1.429375454451421}, {3.8823889919002466`, 1.429375454451421}, {
       3.9420879018335357`, 1.3649729363001064`}, {3.9420879018335357`, 
       1.3649729363001064`}}, {{3.8823889919002466`, 1.429375454451421}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8823889919002466`, 1.429375454451421}, {
       3.8823889919002466`, 1.429375454451421}}, {{3.8823889919002466`, 
       1.429375454451421}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8823889919002466`, 
       1.429375454451421}, {3.8823889919002466`, 1.429375454451421}}, {{
       3.8823889919002466`, 1.429375454451421}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.429375454451421}, {3.8823889919002466`, 
       1.429375454451421}}, {{3.8823889919002466`, 1.429375454451421}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8823889919002466`, 1.429375454451421}, {
       3.8823889919002466`, 1.429375454451421}}, {{3.8677222794512334`, 
       1.4937779726027354`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}}, {{
       3.8677222794512334`, 1.4937779726027354`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8677222794512334`, 1.4937779726027354`}, {3.8677222794512334`, 
       1.4937779726027354`}}, {{3.8677222794512334`, 1.4937779726027354`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8677222794512334`, 1.4937779726027354`}, {
       3.8677222794512334`, 1.4937779726027354`}}, {{3.8677222794512334`, 
       1.4937779726027354`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8677222794512334`, 
       1.4937779726027354`}, {3.8677222794512334`, 1.4937779726027354`}}, {{
       3.8823889919002466`, 1.5581804907540497`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.9420879018335357`, 1.6225830089053643`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}}, {{3.8823889919002466`, 1.5581804907540497`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.8823889919002466`, 1.5581804907540497`}, {
       3.8823889919002466`, 1.5581804907540497`}}, {{3.8823889919002466`, 
       1.5581804907540497`}, {3.9420879018335357`, 1.6225830089053643`}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.8823889919002466`, 
       1.5581804907540497`}, {3.8823889919002466`, 1.5581804907540497`}}, {{
       3.8823889919002466`, 1.5581804907540497`}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.9420879018335357`, 1.6225830089053643`}, {
       3.8823889919002466`, 1.5581804907540497`}, {3.8823889919002466`, 
       1.5581804907540497`}}, {{4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.4098759409466104`}, {4.1392600071603605`, 
       1.4098759409466104`}, {4.165184768980443, 1.4937779726027354`}, {
       4.165184768980443, 1.4937779726027354`}}, {{4.165184768980443, 
       1.4937779726027354`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.1392600071603605`, 1.4098759409466104`}, {4.165184768980443, 
       1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}}, {{
       4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`, 
       1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}}, {{4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.4098759409466104`}, {4.1392600071603605`, 
       1.4098759409466104`}, {4.165184768980443, 1.4937779726027354`}, {
       4.165184768980443, 1.4937779726027354`}}, {{4.1392600071603605`, 
       1.4098759409466104`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.1392600071603605`, 
       1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}}, {{
       4.1392600071603605`, 1.4098759409466104`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.1392600071603605`, 1.4098759409466104`}, {4.1392600071603605`, 
       1.4098759409466104`}}, {{4.1392600071603605`, 1.4098759409466104`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.1392600071603605`, 1.4098759409466104`}, {
       4.1392600071603605`, 1.4098759409466104`}}, {{4.1392600071603605`, 
       1.4098759409466104`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.1392600071603605`, 
       1.4098759409466104`}, {4.1392600071603605`, 1.4098759409466104`}}, {{
       4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907, 
       1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}, {{4.0908191465981405`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.027711573586907, 
       1.3454734227952958`}, {4.0908191465981405`, 1.3649729363001064`}, {
       4.0908191465981405`, 1.3649729363001064`}}, {{4.0908191465981405`, 
       1.3649729363001064`}, {4.027711573586907, 1.3454734227952958`}, {
       4.027711573586907, 1.3454734227952958`}, {4.0908191465981405`, 
       1.3649729363001064`}, {4.0908191465981405`, 1.3649729363001064`}}, {{
       4.0908191465981405`, 1.3649729363001064`}, {4.027711573586907, 
       1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}, {
       4.0908191465981405`, 1.3649729363001064`}, {4.0908191465981405`, 
       1.3649729363001064`}}, {{4.027711573586907, 1.3454734227952958`}, {
       3.9420879018335357`, 1.3649729363001064`}, {3.9420879018335357`, 
       1.3649729363001064`}, {4.027711573586907, 1.3454734227952958`}, {
       4.027711573586907, 1.3454734227952958`}}, {{4.027711573586907, 
       1.3454734227952958`}, {3.9420879018335357`, 1.3649729363001064`}, {
       3.9420879018335357`, 1.3649729363001064`}, {4.027711573586907, 
       1.3454734227952958`}, {4.027711573586907, 1.3454734227952958`}}, {{
       4.027711573586907, 1.3454734227952958`}, {3.9420879018335357`, 
       1.3649729363001064`}, {3.9420879018335357`, 1.3649729363001064`}, {
       4.027711573586907, 1.3454734227952958`}, {4.027711573586907, 
       1.3454734227952958`}}, {{4.027711573586907, 1.3454734227952958`}, {
       3.9420879018335357`, 1.3649729363001064`}, {3.9420879018335357`, 
       1.3649729363001064`}, {4.027711573586907, 1.3454734227952958`}, {
       4.027711573586907, 1.3454734227952958`}}, {{3.9420879018335357`, 
       1.6225830089053643`}, {4.027711573586907, 1.642082522410175}, {
       4.027711573586907, 1.642082522410175}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.9420879018335357`, 1.6225830089053643`}}, {{
       3.9420879018335357`, 1.6225830089053643`}, {4.027711573586907, 
       1.642082522410175}, {4.027711573586907, 1.642082522410175}, {
       3.9420879018335357`, 1.6225830089053643`}, {3.9420879018335357`, 
       1.6225830089053643`}}, {{3.9420879018335357`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}, {3.9420879018335357`, 1.6225830089053643`}, {
       3.9420879018335357`, 1.6225830089053643`}}, {{3.9420879018335357`, 
       1.6225830089053643`}, {4.027711573586907, 1.642082522410175}, {
       4.027711573586907, 1.642082522410175}, {3.9420879018335357`, 
       1.6225830089053643`}, {3.9420879018335357`, 1.6225830089053643`}}, {{
       4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}}, {{4.027711573586907, 1.642082522410175}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.027711573586907, 1.642082522410175}, {
       4.027711573586907, 1.642082522410175}}, {{4.027711573586907, 
       1.642082522410175}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.027711573586907, 
       1.642082522410175}, {4.027711573586907, 1.642082522410175}}, {{
       4.027711573586907, 1.642082522410175}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.027711573586907, 1.642082522410175}, {4.027711573586907, 
       1.642082522410175}}, {{4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}, {{4.0908191465981405`, 
       1.6225830089053643`}, {4.1392600071603605`, 1.5776800042588603`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.0908191465981405`, 
       1.6225830089053643`}, {4.0908191465981405`, 1.6225830089053643`}}, {{
       4.0908191465981405`, 1.6225830089053643`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.1392600071603605`, 1.5776800042588603`}, {
       4.0908191465981405`, 1.6225830089053643`}, {4.0908191465981405`, 
       1.6225830089053643`}}, {{4.0908191465981405`, 1.6225830089053643`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.0908191465981405`, 1.6225830089053643`}, {
       4.0908191465981405`, 1.6225830089053643`}}, {{4.1392600071603605`, 
       1.5776800042588603`}, {4.165184768980443, 1.4937779726027354`}, {
       4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.1392600071603605`, 1.5776800042588603`}}, {{
       4.1392600071603605`, 1.5776800042588603`}, {4.165184768980443, 
       1.4937779726027354`}, {4.165184768980443, 1.4937779726027354`}, {
       4.1392600071603605`, 1.5776800042588603`}, {4.1392600071603605`, 
       1.5776800042588603`}}, {{4.1392600071603605`, 1.5776800042588603`}, {
       4.165184768980443, 1.4937779726027354`}, {4.165184768980443, 
       1.4937779726027354`}, {4.1392600071603605`, 1.5776800042588603`}, {
       4.1392600071603605`, 1.5776800042588603`}}, {{4.1392600071603605`, 
       1.5776800042588603`}, {4.165184768980443, 1.4937779726027354`}, {
       4.165184768980443, 1.4937779726027354`}, {4.1392600071603605`, 
       1.5776800042588603`}, {4.1392600071603605`, 1.5776800042588603`}}, {{
       3.9566161923789354`, 1.8307520142789462`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.9566161923789354`, 
       2.118523267036319}, {3.9566161923789354`, 2.118523267036319}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.873543787256683, 
       1.9746376406576325`}, {3.8899276893789887`, 1.9026948274682893`}, {
       3.9566161923789354`, 1.8307520142789462`}, {3.9566161923789354`, 
       1.8307520142789462`}}, {{3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}}, {{4.205833407745693, 
       1.9746376406576325`}, {4.176873355403977, 1.8809122963246523`}, {
       4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {3.956616192378936, 1.8307520142789462`}, {
       3.956616192378936, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.122761002623441, 1.8307520142789462`}, {
       4.176873355403977, 1.8809122963246523`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}}, {{
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}, {{3.956616192378936, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.176873355403977, 2.0683629849906127`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}, {4.176873355403977, 2.0683629849906127`}, {
       4.122761002623441, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {3.956616192378936, 2.118523267036319}, {
       3.956616192378936, 2.118523267036319}}, {{4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}}, {{
       3.9566161923789354`, 1.8307520142789462`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.8899276893789887`, 1.9026948274682893`}, {
       3.9566161923789354`, 1.8307520142789462`}, {3.9566161923789354`, 
       1.8307520142789462`}}, {{3.9566161923789354`, 1.8307520142789462`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}}, {{3.9566161923789354`, 
       1.8307520142789462`}, {3.8899276893789887`, 1.9026948274682893`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.9566161923789354`, 
       1.8307520142789462`}, {3.9566161923789354`, 1.8307520142789462`}}, {{
       3.9566161923789354`, 1.8307520142789462`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.8899276893789887`, 1.9026948274682893`}, {
       3.9566161923789354`, 1.8307520142789462`}, {3.9566161923789354`, 
       1.8307520142789462`}}, {{3.8899276893789887`, 1.9026948274682893`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.8899276893789887`, 1.9026948274682893`}, {
       3.8899276893789887`, 1.9026948274682893`}}, {{3.8899276893789887`, 
       1.9026948274682893`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`, 
       1.9026948274682893`}, {3.8899276893789887`, 1.9026948274682893`}}, {{
       3.8899276893789887`, 1.9026948274682893`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 1.9026948274682893`}, {3.8899276893789887`, 
       1.9026948274682893`}}, {{3.8899276893789887`, 1.9026948274682893`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}, {3.8899276893789887`, 1.9026948274682893`}, {
       3.8899276893789887`, 1.9026948274682893`}}, {{3.873543787256683, 
       1.9746376406576325`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}}, {{
       3.873543787256683, 1.9746376406576325`}, {3.8899276893789887`, 
       2.0465804538469756`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.873543787256683, 1.9746376406576325`}, {3.873543787256683, 
       1.9746376406576325`}}, {{3.873543787256683, 1.9746376406576325`}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.8899276893789887`, 
       2.0465804538469756`}, {3.873543787256683, 1.9746376406576325`}, {
       3.873543787256683, 1.9746376406576325`}}, {{3.873543787256683, 
       1.9746376406576325`}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.873543787256683, 
       1.9746376406576325`}, {3.873543787256683, 1.9746376406576325`}}, {{
       3.8899276893789887`, 2.0465804538469756`}, {3.9566161923789354`, 
       2.118523267036319}, {3.9566161923789354`, 2.118523267036319}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.8899276893789887`, 
       2.0465804538469756`}}, {{3.8899276893789887`, 2.0465804538469756`}, {
       3.9566161923789354`, 2.118523267036319}, {3.9566161923789354`, 
       2.118523267036319}, {3.8899276893789887`, 2.0465804538469756`}, {
       3.8899276893789887`, 2.0465804538469756`}}, {{3.8899276893789887`, 
       2.0465804538469756`}, {3.9566161923789354`, 2.118523267036319}, {
       3.9566161923789354`, 2.118523267036319}, {3.8899276893789887`, 
       2.0465804538469756`}, {3.8899276893789887`, 2.0465804538469756`}}, {{
       3.8899276893789887`, 2.0465804538469756`}, {3.9566161923789354`, 
       2.118523267036319}, {3.9566161923789354`, 2.118523267036319}, {
       3.8899276893789887`, 2.0465804538469756`}, {3.8899276893789887`, 
       2.0465804538469756`}}, {{4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}, {4.205833407745693, 1.9746376406576325`}, {
       4.205833407745693, 1.9746376406576325`}}, {{4.205833407745693, 
       1.9746376406576325`}, {4.176873355403977, 1.8809122963246523`}, {
       4.176873355403977, 1.8809122963246523`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}}, {{
       4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}}, {{4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}, {4.205833407745693, 1.9746376406576325`}, {
       4.205833407745693, 1.9746376406576325`}}, {{4.176873355403977, 
       1.8809122963246523`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}}, {{
       4.176873355403977, 1.8809122963246523`}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}, {
       4.176873355403977, 1.8809122963246523`}, {4.176873355403977, 
       1.8809122963246523`}}, {{4.176873355403977, 1.8809122963246523`}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}, {4.176873355403977, 1.8809122963246523`}, {
       4.176873355403977, 1.8809122963246523`}}, {{4.176873355403977, 
       1.8809122963246523`}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}, {4.176873355403977, 
       1.8809122963246523`}, {4.176873355403977, 1.8809122963246523`}}, {{
       4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}, {{4.122761002623441, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.052264747720598, 
       1.808969483135309}, {4.122761002623441, 1.8307520142789462`}, {
       4.122761002623441, 1.8307520142789462`}}, {{4.122761002623441, 
       1.8307520142789462`}, {4.052264747720598, 1.808969483135309}, {
       4.052264747720598, 1.808969483135309}, {4.122761002623441, 
       1.8307520142789462`}, {4.122761002623441, 1.8307520142789462`}}, {{
       4.122761002623441, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}, {
       4.122761002623441, 1.8307520142789462`}, {4.122761002623441, 
       1.8307520142789462`}}, {{4.052264747720598, 1.808969483135309}, {
       3.9566161923789354`, 1.8307520142789462`}, {3.9566161923789354`, 
       1.8307520142789462`}, {4.052264747720598, 1.808969483135309}, {
       4.052264747720598, 1.808969483135309}}, {{4.052264747720598, 
       1.808969483135309}, {3.9566161923789354`, 1.8307520142789462`}, {
       3.9566161923789354`, 1.8307520142789462`}, {4.052264747720598, 
       1.808969483135309}, {4.052264747720598, 1.808969483135309}}, {{
       4.052264747720598, 1.808969483135309}, {3.9566161923789354`, 
       1.8307520142789462`}, {3.9566161923789354`, 1.8307520142789462`}, {
       4.052264747720598, 1.808969483135309}, {4.052264747720598, 
       1.808969483135309}}, {{4.052264747720598, 1.808969483135309}, {
       3.9566161923789354`, 1.8307520142789462`}, {3.9566161923789354`, 
       1.8307520142789462`}, {4.052264747720598, 1.808969483135309}, {
       4.052264747720598, 1.808969483135309}}, {{3.956616192378936, 
       2.118523267036319}, {4.052264747720598, 2.140305798179956}, {
       4.052264747720598, 2.140305798179956}, {3.956616192378936, 
       2.118523267036319}, {3.956616192378936, 2.118523267036319}}, {{
       3.956616192378936, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.052264747720598, 2.140305798179956}, {
       3.956616192378936, 2.118523267036319}, {3.956616192378936, 
       2.118523267036319}}, {{3.956616192378936, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}, {3.956616192378936, 2.118523267036319}, {
       3.956616192378936, 2.118523267036319}}, {{3.956616192378936, 
       2.118523267036319}, {4.052264747720598, 2.140305798179956}, {
       4.052264747720598, 2.140305798179956}, {3.956616192378936, 
       2.118523267036319}, {3.956616192378936, 2.118523267036319}}, {{
       4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}}, {{4.052264747720598, 2.140305798179956}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}, {4.052264747720598, 2.140305798179956}, {
       4.052264747720598, 2.140305798179956}}, {{4.052264747720598, 
       2.140305798179956}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}, {4.052264747720598, 
       2.140305798179956}, {4.052264747720598, 2.140305798179956}}, {{
       4.052264747720598, 2.140305798179956}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}, {
       4.052264747720598, 2.140305798179956}, {4.052264747720598, 
       2.140305798179956}}, {{4.122761002623441, 2.118523267036319}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}}, {{4.122761002623441, 
       2.118523267036319}, {4.176873355403977, 2.0683629849906127`}, {
       4.176873355403977, 2.0683629849906127`}, {4.122761002623441, 
       2.118523267036319}, {4.122761002623441, 2.118523267036319}}, {{
       4.122761002623441, 2.118523267036319}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}, {
       4.122761002623441, 2.118523267036319}, {4.122761002623441, 
       2.118523267036319}}, {{4.122761002623441, 2.118523267036319}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}, {4.122761002623441, 2.118523267036319}, {
       4.122761002623441, 2.118523267036319}}, {{4.176873355403977, 
       2.0683629849906127`}, {4.205833407745693, 1.9746376406576325`}, {
       4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}}, {{
       4.176873355403977, 2.0683629849906127`}, {4.205833407745693, 
       1.9746376406576325`}, {4.205833407745693, 1.9746376406576325`}, {
       4.176873355403977, 2.0683629849906127`}, {4.176873355403977, 
       2.0683629849906127`}}, {{4.176873355403977, 2.0683629849906127`}, {
       4.205833407745693, 1.9746376406576325`}, {4.205833407745693, 
       1.9746376406576325`}, {4.176873355403977, 2.0683629849906127`}, {
       4.176873355403977, 2.0683629849906127`}}, {{4.176873355403977, 
       2.0683629849906127`}, {4.205833407745693, 1.9746376406576325`}, {
       4.205833407745693, 1.9746376406576325`}, {4.176873355403977, 
       2.0683629849906127`}, {4.176873355403977, 2.0683629849906127`}}, {{
       3.9383834009412166`, 2.3637752100298126`}, {3.8703583872564233`, 
       2.437159836038459}, {3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.9383834009412166`, 
       2.657313714064399}, {3.9383834009412166`, 2.657313714064399}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.8536461337802725`, 
       2.510544462047106}, {3.8703583872564233`, 2.437159836038459}, {
       3.9383834009412166`, 2.3637752100298126`}, {3.9383834009412166`, 
       2.3637752100298126`}}, {{3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}}, {{4.192595202424049, 
       2.510544462047106}, {4.163054758895738, 2.4149407590989673`}, {
       4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.107857935263105, 2.3637752100298126`}, {
       4.163054758895738, 2.4149407590989673`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}}, {{
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}, {{3.9383834009412166`, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.163054758895738, 2.6061481649952443`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}, {4.163054758895738, 2.6061481649952443`}, {
       4.107857935263105, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {3.9383834009412166`, 2.657313714064399}, {
       3.9383834009412166`, 2.657313714064399}}, {{4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}}, {{
       3.9383834009412166`, 2.3637752100298126`}, {3.8703583872564233`, 
       2.437159836038459}, {3.8703583872564233`, 2.437159836038459}, {
       3.9383834009412166`, 2.3637752100298126`}, {3.9383834009412166`, 
       2.3637752100298126`}}, {{3.9383834009412166`, 2.3637752100298126`}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}}, {{3.9383834009412166`, 
       2.3637752100298126`}, {3.8703583872564233`, 2.437159836038459}, {
       3.8703583872564233`, 2.437159836038459}, {3.9383834009412166`, 
       2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}}, {{
       3.9383834009412166`, 2.3637752100298126`}, {3.8703583872564233`, 
       2.437159836038459}, {3.8703583872564233`, 2.437159836038459}, {
       3.9383834009412166`, 2.3637752100298126`}, {3.9383834009412166`, 
       2.3637752100298126`}}, {{3.8703583872564233`, 2.437159836038459}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8703583872564233`, 2.437159836038459}, {
       3.8703583872564233`, 2.437159836038459}}, {{3.8703583872564233`, 
       2.437159836038459}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`, 
       2.437159836038459}, {3.8703583872564233`, 2.437159836038459}}, {{
       3.8703583872564233`, 2.437159836038459}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.437159836038459}, {3.8703583872564233`, 
       2.437159836038459}}, {{3.8703583872564233`, 2.437159836038459}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}, {3.8703583872564233`, 2.437159836038459}, {
       3.8703583872564233`, 2.437159836038459}}, {{3.8536461337802725`, 
       2.510544462047106}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}}, {{
       3.8536461337802725`, 2.510544462047106}, {3.8703583872564233`, 
       2.5839290880557524`}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8536461337802725`, 2.510544462047106}, {3.8536461337802725`, 
       2.510544462047106}}, {{3.8536461337802725`, 2.510544462047106}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.8703583872564233`, 
       2.5839290880557524`}, {3.8536461337802725`, 2.510544462047106}, {
       3.8536461337802725`, 2.510544462047106}}, {{3.8536461337802725`, 
       2.510544462047106}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.8536461337802725`, 
       2.510544462047106}, {3.8536461337802725`, 2.510544462047106}}, {{
       3.8703583872564233`, 2.5839290880557524`}, {3.9383834009412166`, 
       2.657313714064399}, {3.9383834009412166`, 2.657313714064399}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.8703583872564233`, 
       2.5839290880557524`}}, {{3.8703583872564233`, 2.5839290880557524`}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}, {3.8703583872564233`, 2.5839290880557524`}, {
       3.8703583872564233`, 2.5839290880557524`}}, {{3.8703583872564233`, 
       2.5839290880557524`}, {3.9383834009412166`, 2.657313714064399}, {
       3.9383834009412166`, 2.657313714064399}, {3.8703583872564233`, 
       2.5839290880557524`}, {3.8703583872564233`, 2.5839290880557524`}}, {{
       3.8703583872564233`, 2.5839290880557524`}, {3.9383834009412166`, 
       2.657313714064399}, {3.9383834009412166`, 2.657313714064399}, {
       3.8703583872564233`, 2.5839290880557524`}, {3.8703583872564233`, 
       2.5839290880557524`}}, {{4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}, {4.192595202424049, 2.510544462047106}, {
       4.192595202424049, 2.510544462047106}}, {{4.192595202424049, 
       2.510544462047106}, {4.163054758895738, 2.4149407590989673`}, {
       4.163054758895738, 2.4149407590989673`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}}, {{
       4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}}, {{4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}, {4.192595202424049, 2.510544462047106}, {
       4.192595202424049, 2.510544462047106}}, {{4.163054758895738, 
       2.4149407590989673`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}}, {{
       4.163054758895738, 2.4149407590989673`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}, {
       4.163054758895738, 2.4149407590989673`}, {4.163054758895738, 
       2.4149407590989673`}}, {{4.163054758895738, 2.4149407590989673`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}, {4.163054758895738, 2.4149407590989673`}, {
       4.163054758895738, 2.4149407590989673`}}, {{4.163054758895738, 
       2.4149407590989673`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}, {4.163054758895738, 
       2.4149407590989673`}, {4.163054758895738, 2.4149407590989673`}}, {{
       4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}, {{4.107857935263105, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.035948858154321, 
       2.3415561330903207`}, {4.107857935263105, 2.3637752100298126`}, {
       4.107857935263105, 2.3637752100298126`}}, {{4.107857935263105, 
       2.3637752100298126`}, {4.035948858154321, 2.3415561330903207`}, {
       4.035948858154321, 2.3415561330903207`}, {4.107857935263105, 
       2.3637752100298126`}, {4.107857935263105, 2.3637752100298126`}}, {{
       4.107857935263105, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}, {
       4.107857935263105, 2.3637752100298126`}, {4.107857935263105, 
       2.3637752100298126`}}, {{4.035948858154321, 2.3415561330903207`}, {
       3.9383834009412166`, 2.3637752100298126`}, {3.9383834009412166`, 
       2.3637752100298126`}, {4.035948858154321, 2.3415561330903207`}, {
       4.035948858154321, 2.3415561330903207`}}, {{4.035948858154321, 
       2.3415561330903207`}, {3.9383834009412166`, 2.3637752100298126`}, {
       3.9383834009412166`, 2.3637752100298126`}, {4.035948858154321, 
       2.3415561330903207`}, {4.035948858154321, 2.3415561330903207`}}, {{
       4.035948858154321, 2.3415561330903207`}, {3.9383834009412166`, 
       2.3637752100298126`}, {3.9383834009412166`, 2.3637752100298126`}, {
       4.035948858154321, 2.3415561330903207`}, {4.035948858154321, 
       2.3415561330903207`}}, {{4.035948858154321, 2.3415561330903207`}, {
       3.9383834009412166`, 2.3637752100298126`}, {3.9383834009412166`, 
       2.3637752100298126`}, {4.035948858154321, 2.3415561330903207`}, {
       4.035948858154321, 2.3415561330903207`}}, {{3.9383834009412166`, 
       2.657313714064399}, {4.035948858154321, 2.679532791003891}, {
       4.035948858154321, 2.679532791003891}, {3.9383834009412166`, 
       2.657313714064399}, {3.9383834009412166`, 2.657313714064399}}, {{
       3.9383834009412166`, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.035948858154321, 2.679532791003891}, {
       3.9383834009412166`, 2.657313714064399}, {3.9383834009412166`, 
       2.657313714064399}}, {{3.9383834009412166`, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}, {3.9383834009412166`, 2.657313714064399}, {
       3.9383834009412166`, 2.657313714064399}}, {{3.9383834009412166`, 
       2.657313714064399}, {4.035948858154321, 2.679532791003891}, {
       4.035948858154321, 2.679532791003891}, {3.9383834009412166`, 
       2.657313714064399}, {3.9383834009412166`, 2.657313714064399}}, {{
       4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}}, {{4.035948858154321, 2.679532791003891}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}, {4.035948858154321, 2.679532791003891}, {
       4.035948858154321, 2.679532791003891}}, {{4.035948858154321, 
       2.679532791003891}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}, {4.035948858154321, 
       2.679532791003891}, {4.035948858154321, 2.679532791003891}}, {{
       4.035948858154321, 2.679532791003891}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}, {
       4.035948858154321, 2.679532791003891}, {4.035948858154321, 
       2.679532791003891}}, {{4.107857935263105, 2.657313714064399}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}}, {{4.107857935263105, 
       2.657313714064399}, {4.163054758895738, 2.6061481649952443`}, {
       4.163054758895738, 2.6061481649952443`}, {4.107857935263105, 
       2.657313714064399}, {4.107857935263105, 2.657313714064399}}, {{
       4.107857935263105, 2.657313714064399}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}, {
       4.107857935263105, 2.657313714064399}, {4.107857935263105, 
       2.657313714064399}}, {{4.107857935263105, 2.657313714064399}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}, {4.107857935263105, 2.657313714064399}, {
       4.107857935263105, 2.657313714064399}}, {{4.163054758895738, 
       2.6061481649952443`}, {4.192595202424049, 2.510544462047106}, {
       4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}}, {{
       4.163054758895738, 2.6061481649952443`}, {4.192595202424049, 
       2.510544462047106}, {4.192595202424049, 2.510544462047106}, {
       4.163054758895738, 2.6061481649952443`}, {4.163054758895738, 
       2.6061481649952443`}}, {{4.163054758895738, 2.6061481649952443`}, {
       4.192595202424049, 2.510544462047106}, {4.192595202424049, 
       2.510544462047106}, {4.163054758895738, 2.6061481649952443`}, {
       4.163054758895738, 2.6061481649952443`}}, {{4.163054758895738, 
       2.6061481649952443`}, {4.192595202424049, 2.510544462047106}, {
       4.192595202424049, 2.510544462047106}, {4.163054758895738, 
       2.6061481649952443`}, {4.163054758895738, 2.6061481649952443`}}, {{
       3.8884503960691674`, 2.8512649149400016`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8884503960691674`, 3.0796330530470204`}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.822526193063957, 
       2.965448983993511}, {3.8355280519596864`, 2.9083569494667563`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.8884503960691674`, 
       2.8512649149400016`}}, {{3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}}, {{4.0862230050848, 
       2.965448983993511}, {4.063241024885632, 2.891070872303501}, {
       4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {4.020298802079589, 2.8512649149400016`}, {
       4.063241024885632, 2.891070872303501}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}}, {{
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}, {{3.8884503960691674`, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.063241024885632, 3.039827095683521}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}, {4.063241024885632, 3.039827095683521}, {
       4.020298802079589, 3.0796330530470204`}, {3.964354720377816, 
       3.0969191302102757`}, {3.8884503960691674`, 3.0796330530470204`}, {
       3.8884503960691674`, 3.0796330530470204`}}, {{4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}}, {{
       3.8884503960691674`, 2.8512649149400016`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8355280519596864`, 2.9083569494667563`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.8884503960691674`, 
       2.8512649149400016`}}, {{3.8884503960691674`, 2.8512649149400016`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}}, {{3.8884503960691674`, 
       2.8512649149400016`}, {3.8355280519596864`, 2.9083569494667563`}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8884503960691674`, 
       2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}}, {{
       3.8884503960691674`, 2.8512649149400016`}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8355280519596864`, 2.9083569494667563`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.8884503960691674`, 
       2.8512649149400016`}}, {{3.8355280519596864`, 2.9083569494667563`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.8355280519596864`, 2.9083569494667563`}, {
       3.8355280519596864`, 2.9083569494667563`}}, {{3.8355280519596864`, 
       2.9083569494667563`}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       2.9083569494667563`}, {3.8355280519596864`, 2.9083569494667563`}}, {{
       3.8355280519596864`, 2.9083569494667563`}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 2.9083569494667563`}, {3.8355280519596864`, 
       2.9083569494667563`}}, {{3.8355280519596864`, 2.9083569494667563`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}, {3.8355280519596864`, 2.9083569494667563`}, {
       3.8355280519596864`, 2.9083569494667563`}}, {{3.822526193063957, 
       2.965448983993511}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}}, {{
       3.822526193063957, 2.965448983993511}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.822526193063957, 2.965448983993511}, {3.822526193063957, 
       2.965448983993511}}, {{3.822526193063957, 2.965448983993511}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.822526193063957, 2.965448983993511}, {
       3.822526193063957, 2.965448983993511}}, {{3.822526193063957, 
       2.965448983993511}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.822526193063957, 
       2.965448983993511}, {3.822526193063957, 2.965448983993511}}, {{
       3.8355280519596864`, 3.0225410185202657`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8884503960691674`, 3.0796330530470204`}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.8355280519596864`, 
       3.0225410185202657`}}, {{3.8355280519596864`, 3.0225410185202657`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8355280519596864`, 3.0225410185202657`}, {
       3.8355280519596864`, 3.0225410185202657`}}, {{3.8355280519596864`, 
       3.0225410185202657`}, {3.8884503960691674`, 3.0796330530470204`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8355280519596864`, 
       3.0225410185202657`}, {3.8355280519596864`, 3.0225410185202657`}}, {{
       3.8355280519596864`, 3.0225410185202657`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8884503960691674`, 3.0796330530470204`}, {
       3.8355280519596864`, 3.0225410185202657`}, {3.8355280519596864`, 
       3.0225410185202657`}}, {{4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}, {4.0862230050848, 2.965448983993511}, {
       4.0862230050848, 2.965448983993511}}, {{4.0862230050848, 
       2.965448983993511}, {4.063241024885632, 2.891070872303501}, {
       4.063241024885632, 2.891070872303501}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}}, {{
       4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}}, {{4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}, {4.0862230050848, 2.965448983993511}, {
       4.0862230050848, 2.965448983993511}}, {{4.063241024885632, 
       2.891070872303501}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}}, {{
       4.063241024885632, 2.891070872303501}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}, {
       4.063241024885632, 2.891070872303501}, {4.063241024885632, 
       2.891070872303501}}, {{4.063241024885632, 2.891070872303501}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}, {4.063241024885632, 2.891070872303501}, {
       4.063241024885632, 2.891070872303501}}, {{4.063241024885632, 
       2.891070872303501}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}, {4.063241024885632, 
       2.891070872303501}, {4.063241024885632, 2.891070872303501}}, {{
       4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}, {{4.020298802079589, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.964354720377816, 
       2.8339788377767463`}, {4.020298802079589, 2.8512649149400016`}, {
       4.020298802079589, 2.8512649149400016`}}, {{4.020298802079589, 
       2.8512649149400016`}, {3.964354720377816, 2.8339788377767463`}, {
       3.964354720377816, 2.8339788377767463`}, {4.020298802079589, 
       2.8512649149400016`}, {4.020298802079589, 2.8512649149400016`}}, {{
       4.020298802079589, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}, {
       4.020298802079589, 2.8512649149400016`}, {4.020298802079589, 
       2.8512649149400016`}}, {{3.964354720377816, 2.8339788377767463`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.8884503960691674`, 
       2.8512649149400016`}, {3.964354720377816, 2.8339788377767463`}, {
       3.964354720377816, 2.8339788377767463`}}, {{3.964354720377816, 
       2.8339788377767463`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.964354720377816, 
       2.8339788377767463`}, {3.964354720377816, 2.8339788377767463`}}, {{
       3.964354720377816, 2.8339788377767463`}, {3.8884503960691674`, 
       2.8512649149400016`}, {3.8884503960691674`, 2.8512649149400016`}, {
       3.964354720377816, 2.8339788377767463`}, {3.964354720377816, 
       2.8339788377767463`}}, {{3.964354720377816, 2.8339788377767463`}, {
       3.8884503960691674`, 2.8512649149400016`}, {3.8884503960691674`, 
       2.8512649149400016`}, {3.964354720377816, 2.8339788377767463`}, {
       3.964354720377816, 2.8339788377767463`}}, {{3.8884503960691674`, 
       3.0796330530470204`}, {3.964354720377816, 3.0969191302102757`}, {
       3.964354720377816, 3.0969191302102757`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8884503960691674`, 3.0796330530470204`}}, {{
       3.8884503960691674`, 3.0796330530470204`}, {3.964354720377816, 
       3.0969191302102757`}, {3.964354720377816, 3.0969191302102757`}, {
       3.8884503960691674`, 3.0796330530470204`}, {3.8884503960691674`, 
       3.0796330530470204`}}, {{3.8884503960691674`, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}, {3.8884503960691674`, 3.0796330530470204`}, {
       3.8884503960691674`, 3.0796330530470204`}}, {{3.8884503960691674`, 
       3.0796330530470204`}, {3.964354720377816, 3.0969191302102757`}, {
       3.964354720377816, 3.0969191302102757`}, {3.8884503960691674`, 
       3.0796330530470204`}, {3.8884503960691674`, 3.0796330530470204`}}, {{
       3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}}, {{3.964354720377816, 3.0969191302102757`}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}, {3.964354720377816, 3.0969191302102757`}, {
       3.964354720377816, 3.0969191302102757`}}, {{3.964354720377816, 
       3.0969191302102757`}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}, {3.964354720377816, 
       3.0969191302102757`}, {3.964354720377816, 3.0969191302102757`}}, {{
       3.964354720377816, 3.0969191302102757`}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}, {
       3.964354720377816, 3.0969191302102757`}, {3.964354720377816, 
       3.0969191302102757`}}, {{4.020298802079589, 3.0796330530470204`}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}}, {{4.020298802079589, 
       3.0796330530470204`}, {4.063241024885632, 3.039827095683521}, {
       4.063241024885632, 3.039827095683521}, {4.020298802079589, 
       3.0796330530470204`}, {4.020298802079589, 3.0796330530470204`}}, {{
       4.020298802079589, 3.0796330530470204`}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}, {
       4.020298802079589, 3.0796330530470204`}, {4.020298802079589, 
       3.0796330530470204`}}, {{4.020298802079589, 3.0796330530470204`}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}, {4.020298802079589, 3.0796330530470204`}, {
       4.020298802079589, 3.0796330530470204`}}, {{4.063241024885632, 
       3.039827095683521}, {4.0862230050848, 2.965448983993511}, {
       4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}}, {{
       4.063241024885632, 3.039827095683521}, {4.0862230050848, 
       2.965448983993511}, {4.0862230050848, 2.965448983993511}, {
       4.063241024885632, 3.039827095683521}, {4.063241024885632, 
       3.039827095683521}}, {{4.063241024885632, 3.039827095683521}, {
       4.0862230050848, 2.965448983993511}, {4.0862230050848, 
       2.965448983993511}, {4.063241024885632, 3.039827095683521}, {
       4.063241024885632, 3.039827095683521}}, {{4.063241024885632, 
       3.039827095683521}, {4.0862230050848, 2.965448983993511}, {
       4.0862230050848, 2.965448983993511}, {4.063241024885632, 
       3.039827095683521}, {4.063241024885632, 3.039827095683521}}, {{
       3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084, 
       3.4804938366968705`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}, {{3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}}, {{4.1426036639860975`, 
       3.5443844591116442`}, {4.116884962044223, 3.461149312750143}, {
       4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`, 
       3.397258690335369}, {3.9212800556869225`, 3.4166032142820963`}, {
       3.9212800556869225`, 3.4166032142820963`}, {4.0062231578946355`, 
       3.397258690335369}, {4.068829127886373, 3.4166032142820963`}, {
       4.116884962044223, 3.461149312750143}, {4.1426036639860975`, 
       3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}}, {{
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}, {{3.9212800556869225`, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373, 
       3.672165703941192}, {4.116884962044223, 3.6276196054731455`}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}, {4.116884962044223, 3.6276196054731455`}, {
       4.068829127886373, 3.672165703941192}, {4.0062231578946355`, 
       3.6915102278879193`}, {3.9212800556869225`, 3.672165703941192}, {
       3.9212800556869225`, 3.672165703941192}}, {{4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}}, {{
       3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084, 
       3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}, {{3.9212800556869225`, 3.4166032142820963`}, {
       3.862055655421084, 3.4804938366968705`}, {3.862055655421084, 
       3.4804938366968705`}, {3.9212800556869225`, 3.4166032142820963`}, {
       3.9212800556869225`, 3.4166032142820963`}}, {{3.9212800556869225`, 
       3.4166032142820963`}, {3.862055655421084, 3.4804938366968705`}, {
       3.862055655421084, 3.4804938366968705`}, {3.9212800556869225`, 
       3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}}, {{
       3.9212800556869225`, 3.4166032142820963`}, {3.862055655421084, 
       3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}}, {{3.862055655421084, 3.4804938366968705`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.862055655421084, 3.4804938366968705`}, {
       3.862055655421084, 3.4804938366968705`}}, {{3.862055655421084, 
       3.4804938366968705`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.862055655421084, 
       3.4804938366968705`}, {3.862055655421084, 3.4804938366968705`}}, {{
       3.862055655421084, 3.4804938366968705`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.4804938366968705`}, {3.862055655421084, 
       3.4804938366968705`}}, {{3.862055655421084, 3.4804938366968705`}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.862055655421084, 3.4804938366968705`}, {
       3.862055655421084, 3.4804938366968705`}}, {{3.8475055195871977`, 
       3.5443844591116442`}, {3.862055655421084, 3.608275081526418}, {
       3.862055655421084, 3.608275081526418}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}}, {{
       3.8475055195871977`, 3.5443844591116442`}, {3.862055655421084, 
       3.608275081526418}, {3.862055655421084, 3.608275081526418}, {
       3.8475055195871977`, 3.5443844591116442`}, {3.8475055195871977`, 
       3.5443844591116442`}}, {{3.8475055195871977`, 3.5443844591116442`}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}, {3.8475055195871977`, 3.5443844591116442`}, {
       3.8475055195871977`, 3.5443844591116442`}}, {{3.8475055195871977`, 
       3.5443844591116442`}, {3.862055655421084, 3.608275081526418}, {
       3.862055655421084, 3.608275081526418}, {3.8475055195871977`, 
       3.5443844591116442`}, {3.8475055195871977`, 3.5443844591116442`}}, {{
       3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}}, {{3.862055655421084, 3.608275081526418}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}, {3.862055655421084, 3.608275081526418}, {
       3.862055655421084, 3.608275081526418}}, {{3.862055655421084, 
       3.608275081526418}, {3.9212800556869225`, 3.672165703941192}, {
       3.9212800556869225`, 3.672165703941192}, {3.862055655421084, 
       3.608275081526418}, {3.862055655421084, 3.608275081526418}}, {{
       3.862055655421084, 3.608275081526418}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}, {
       3.862055655421084, 3.608275081526418}, {3.862055655421084, 
       3.608275081526418}}, {{4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.1426036639860975`, 3.5443844591116442`}}, {{4.1426036639860975`, 
       3.5443844591116442`}, {4.116884962044223, 3.461149312750143}, {
       4.116884962044223, 3.461149312750143}, {4.1426036639860975`, 
       3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}}, {{
       4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223, 
       3.461149312750143}, {4.116884962044223, 3.461149312750143}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}}, {{4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.1426036639860975`, 3.5443844591116442`}}, {{4.116884962044223, 
       3.461149312750143}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.116884962044223, 
       3.461149312750143}, {4.116884962044223, 3.461149312750143}}, {{
       4.116884962044223, 3.461149312750143}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}, {
       4.116884962044223, 3.461149312750143}, {4.116884962044223, 
       3.461149312750143}}, {{4.116884962044223, 3.461149312750143}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}, {4.116884962044223, 3.461149312750143}, {
       4.116884962044223, 3.461149312750143}}, {{4.116884962044223, 
       3.461149312750143}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}, {4.116884962044223, 
       3.461149312750143}, {4.116884962044223, 3.461149312750143}}, {{
       4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`, 
       3.397258690335369}, {4.0062231578946355`, 3.397258690335369}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}, {{4.068829127886373, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.0062231578946355`, 
       3.397258690335369}, {4.068829127886373, 3.4166032142820963`}, {
       4.068829127886373, 3.4166032142820963`}}, {{4.068829127886373, 
       3.4166032142820963`}, {4.0062231578946355`, 3.397258690335369}, {
       4.0062231578946355`, 3.397258690335369}, {4.068829127886373, 
       3.4166032142820963`}, {4.068829127886373, 3.4166032142820963`}}, {{
       4.068829127886373, 3.4166032142820963`}, {4.0062231578946355`, 
       3.397258690335369}, {4.0062231578946355`, 3.397258690335369}, {
       4.068829127886373, 3.4166032142820963`}, {4.068829127886373, 
       3.4166032142820963`}}, {{4.0062231578946355`, 3.397258690335369}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}, {4.0062231578946355`, 3.397258690335369}, {
       4.0062231578946355`, 3.397258690335369}}, {{4.0062231578946355`, 
       3.397258690335369}, {3.9212800556869225`, 3.4166032142820963`}, {
       3.9212800556869225`, 3.4166032142820963`}, {4.0062231578946355`, 
       3.397258690335369}, {4.0062231578946355`, 3.397258690335369}}, {{
       4.0062231578946355`, 3.397258690335369}, {3.9212800556869225`, 
       3.4166032142820963`}, {3.9212800556869225`, 3.4166032142820963`}, {
       4.0062231578946355`, 3.397258690335369}, {4.0062231578946355`, 
       3.397258690335369}}, {{4.0062231578946355`, 3.397258690335369}, {
       3.9212800556869225`, 3.4166032142820963`}, {3.9212800556869225`, 
       3.4166032142820963`}, {4.0062231578946355`, 3.397258690335369}, {
       4.0062231578946355`, 3.397258690335369}}, {{3.9212800556869225`, 
       3.672165703941192}, {4.0062231578946355`, 3.6915102278879193`}, {
       4.0062231578946355`, 3.6915102278879193`}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}}, {{
       3.9212800556869225`, 3.672165703941192}, {4.0062231578946355`, 
       3.6915102278879193`}, {4.0062231578946355`, 3.6915102278879193`}, {
       3.9212800556869225`, 3.672165703941192}, {3.9212800556869225`, 
       3.672165703941192}}, {{3.9212800556869225`, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}, {3.9212800556869225`, 3.672165703941192}, {
       3.9212800556869225`, 3.672165703941192}}, {{3.9212800556869225`, 
       3.672165703941192}, {4.0062231578946355`, 3.6915102278879193`}, {
       4.0062231578946355`, 3.6915102278879193`}, {3.9212800556869225`, 
       3.672165703941192}, {3.9212800556869225`, 3.672165703941192}}, {{
       4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}}, {{4.0062231578946355`, 3.6915102278879193`}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}, {4.0062231578946355`, 3.6915102278879193`}, {
       4.0062231578946355`, 3.6915102278879193`}}, {{4.0062231578946355`, 
       3.6915102278879193`}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}, {4.0062231578946355`, 
       3.6915102278879193`}, {4.0062231578946355`, 3.6915102278879193`}}, {{
       4.0062231578946355`, 3.6915102278879193`}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}, {
       4.0062231578946355`, 3.6915102278879193`}, {4.0062231578946355`, 
       3.6915102278879193`}}, {{4.068829127886373, 3.672165703941192}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}}, {{4.068829127886373, 
       3.672165703941192}, {4.116884962044223, 3.6276196054731455`}, {
       4.116884962044223, 3.6276196054731455`}, {4.068829127886373, 
       3.672165703941192}, {4.068829127886373, 3.672165703941192}}, {{
       4.068829127886373, 3.672165703941192}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}, {
       4.068829127886373, 3.672165703941192}, {4.068829127886373, 
       3.672165703941192}}, {{4.068829127886373, 3.672165703941192}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}, {4.068829127886373, 3.672165703941192}, {
       4.068829127886373, 3.672165703941192}}, {{4.116884962044223, 
       3.6276196054731455`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}}, {{
       4.116884962044223, 3.6276196054731455`}, {4.1426036639860975`, 
       3.5443844591116442`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.116884962044223, 3.6276196054731455`}, {4.116884962044223, 
       3.6276196054731455`}}, {{4.116884962044223, 3.6276196054731455`}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.1426036639860975`, 
       3.5443844591116442`}, {4.116884962044223, 3.6276196054731455`}, {
       4.116884962044223, 3.6276196054731455`}}, {{4.116884962044223, 
       3.6276196054731455`}, {4.1426036639860975`, 3.5443844591116442`}, {
       4.1426036639860975`, 3.5443844591116442`}, {4.116884962044223, 
       3.6276196054731455`}, {4.116884962044223, 3.6276196054731455`}}, {{
       4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768254}, {
       4.195930844480385, -4.069043655768254}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}, {{
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}, {{
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436583}, {
       4.195930844480385, -4.343071758436583}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}, {{
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}, {{
       4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}, {{
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}, {{
       4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}, {{
       4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}, {{
       4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}, {{
       4.195930844480385, -4.343071758436582}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}}, {{
       4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}, {{
       4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}, {{
       4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}, {{
       4.132427197845208, -4.2745647327695}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.2745647327695}, {
       4.132427197845208, -4.2745647327695}}, {{
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}, {{
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}, {{
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}, {{
       4.1168257450598436`, -4.206057707102418}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}, {
       4.1168257450598436`, -4.206057707102418}, {
       4.1168257450598436`, -4.206057707102418}}, {{
       4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}, {{
       4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}, {{
       4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}, {{
       4.132427197845208, -4.137550681435336}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}, {
       4.132427197845208, -4.137550681435336}, {
       4.132427197845208, -4.137550681435336}}, {{
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}, {{
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}, {{
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}, {{
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}}, {{
       4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}, {{
       4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}, {{
       4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}, {{
       4.405669141494192, -4.295306991154973}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}, {
       4.405669141494192, -4.295306991154973}, {
       4.405669141494192, -4.295306991154973}}, {{
       4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}, {{
       4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}, {{
       4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}, {{
       4.354141043321468, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}, {
       4.354141043321468, -4.343071758436582}, {
       4.354141043321468, -4.343071758436582}}, {{
       4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}, {{
       4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}, {{
       4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}, {{
       4.28701149236338, -4.363814016822055}, {
       4.195930844480385, -4.343071758436582}, {
       4.195930844480385, -4.343071758436582}, {
       4.28701149236338, -4.363814016822055}, {
       4.28701149236338, -4.363814016822055}}, {{
       4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}, {{
       4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}, {{
       4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}, {{
       4.195930844480385, -4.069043655768253}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}, {
       4.195930844480385, -4.069043655768253}, {
       4.195930844480385, -4.069043655768253}}, {{
       4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}, {{
       4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}, {{
       4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}, {{
       4.28701149236338, -4.04830139738278}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}, {
       4.28701149236338, -4.04830139738278}, {
       4.28701149236338, -4.04830139738278}}, {{
       4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}, {{
       4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}, {{
       4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}, {{
       4.354141043321468, -4.069043655768254}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.354141043321468, -4.069043655768254}, {
       4.354141043321468, -4.069043655768254}}, {{
       4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}, {{
       4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}, {{
       4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}, {{
       4.405669141494192, -4.1168084230498625`}, {
       4.433246142742009, -4.206057707102418}, {
       4.433246142742009, -4.206057707102418}, {
       4.405669141494192, -4.1168084230498625`}, {
       4.405669141494192, -4.1168084230498625`}}, {{
       4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}, {{
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}, {{
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}, {{
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}, {{
       4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}, {{
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}, {{
       4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}, {{
       4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}, {{
       4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}, {{
       4.148295421368795, -3.8943864636025123`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}}, {{
       4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}, {{
       4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}, {{
       4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}, {{
       4.095047440138156, -3.8369431353816252`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.8369431353816252`}, {
       4.095047440138156, -3.8369431353816252`}}, {{
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}, {{
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}, {{
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}, {{
       4.081965579345841, -3.7794998071607386`}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}, {
       4.081965579345841, -3.7794998071607386`}, {
       4.081965579345841, -3.7794998071607386`}}, {{
       4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}, {{
       4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}, {{
       4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}, {{
       4.095047440138156, -3.722056478939852}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}, {
       4.095047440138156, -3.722056478939852}, {
       4.095047440138156, -3.722056478939852}}, {{
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}, {{
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}, {{
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}, {{
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}}, {{
       4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}, {{
       4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}, {{
       4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}, {{
       4.324161556535762, -3.8543355757171525`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.324161556535762, -3.8543355757171525`}, {
       4.324161556535762, -3.8543355757171525`}}, {{
       4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}, {{
       4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}, {{
       4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}, {{
       4.280955105414703, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.280955105414703, -3.8943864636025123`}, {
       4.280955105414703, -3.8943864636025123`}}, {{
       4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}, {{
       4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}, {{
       4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}, {{
       4.2246667935013305`, -3.9117789039380395`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.148295421368795, -3.8943864636025123`}, {
       4.2246667935013305`, -3.9117789039380395`}, {
       4.2246667935013305`, -3.9117789039380395`}}, {{
       4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}, {{
       4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}, {{
       4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}, {{
       4.148295421368795, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.148295421368795, -3.664613150718965}, {
       4.148295421368795, -3.664613150718965}}, {{
       4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}, {{
       4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}, {{
       4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}, {{
       4.2246667935013305`, -3.6472207103834378`}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}, {
       4.2246667935013305`, -3.6472207103834378`}, {
       4.2246667935013305`, -3.6472207103834378`}}, {{
       4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}, {{
       4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}, {{
       4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}, {{
       4.280955105414703, -3.664613150718965}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}, {
       4.280955105414703, -3.664613150718965}, {
       4.280955105414703, -3.664613150718965}}, {{
       4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}, {{
       4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}, {{
       4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}, {{
       4.324161556535762, -3.704664038604325}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.347284947437657, -3.7794998071607386`}, {
       4.324161556535762, -3.704664038604325}, {
       4.324161556535762, -3.704664038604325}}, {{
       4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}, {{
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}, {{
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}, {{
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}, {{
       4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}, {{
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}, {{
       4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}, {{
       4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}, {{
       4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}, {{
       4.147571012918157, -3.3670686920913355`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}}, {{
       4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}, {{
       4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}, {{
       4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}, {{
       4.09236083501724, -3.3075085679889944`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.3075085679889944`}, {
       4.09236083501724, -3.3075085679889944`}}, {{
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}, {{
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}, {{
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}, {{
       4.07879690555125, -3.2479484438866533`}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}, {
       4.07879690555125, -3.2479484438866533`}, {
       4.07879690555125, -3.2479484438866533`}}, {{
       4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}, {{
       4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}, {{
       4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}, {{
       4.09236083501724, -3.188388319784312}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}, {
       4.09236083501724, -3.188388319784312}, {
       4.09236083501724, -3.188388319784312}}, {{
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}, {{
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}, {{
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}, {{
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}}, {{
       4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}, {{
       4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}, {{
       4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}, {{
       4.329917843444161, -3.3255419225474774`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.329917843444161, -3.3255419225474774`}, {
       4.329917843444161, -3.3255419225474774`}}, {{
       4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}, {{
       4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}, {{
       4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}, {{
       4.2851192276519745`, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.2851192276519745`, -3.3670686920913355`}, {
       4.2851192276519745`, -3.3670686920913355`}}, {{
       4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}, {{
       4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}, {{
       4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}, {{
       4.226756682393798, -3.3851020466498185`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.147571012918157, -3.3670686920913355`}, {
       4.226756682393798, -3.3851020466498185`}, {
       4.226756682393798, -3.3851020466498185`}}, {{
       4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}, {{
       4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}, {{
       4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}, {{
       4.147571012918157, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}, {
       4.147571012918157, -3.128828195681971}, {
       4.147571012918157, -3.128828195681971}}, {{
       4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}, {{
       4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}, {{
       4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}, {{
       4.226756682393798, -3.110794841123488}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.226756682393798, -3.110794841123488}, {
       4.226756682393798, -3.110794841123488}}, {{
       4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}, {{
       4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}, {{
       4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}, {{
       4.2851192276519745`, -3.128828195681971}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}, {
       4.2851192276519745`, -3.128828195681971}, {
       4.2851192276519745`, -3.128828195681971}}, {{
       4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}, {{
       4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}, {{
       4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}, {{
       4.329917843444161, -3.170354965225829}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.353893335018882, -3.2479484438866533`}, {
       4.329917843444161, -3.170354965225829}, {
       4.329917843444161, -3.170354965225829}}, {{
       4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}, {{
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}, {{
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}, {{
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}, {{
       4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}, {{
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}, {{
       4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}, {{
       4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}, {{
       4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}, {{
       4.212151335614398, -2.8634294660568314`}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}}, {{
       4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}, {{
       4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}, {{
       4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}, {{
       4.153176695385582, -2.799808281984162}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.799808281984162}, {
       4.153176695385582, -2.799808281984162}}, {{
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}, {{
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}, {{
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}, {{
       4.138687920113361, -2.736187097911492}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}, {
       4.138687920113361, -2.736187097911492}, {
       4.138687920113361, -2.736187097911492}}, {{
       4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}, {{
       4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}, {{
       4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}, {{
       4.153176695385582, -2.672565913838822}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.153176695385582, -2.672565913838822}, {
       4.153176695385582, -2.672565913838822}}, {{
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}, {{
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}, {{
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}, {{
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}}, {{
       4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}, {{
       4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}, {{
       4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}, {{
       4.40693134060614, -2.819071226565029}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.40693134060614, -2.819071226565029}, {
       4.40693134060614, -2.819071226565029}}, {{
       4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}, {{
       4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}, {{
       4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}, {{
       4.359078166616473, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.359078166616473, -2.8634294660568314`}, {
       4.359078166616473, -2.8634294660568314`}}, {{
       4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}, {{
       4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}, {{
       4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}, {{
       4.296736217354584, -2.8826924106376985`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.212151335614398, -2.8634294660568314`}, {
       4.296736217354584, -2.8826924106376985`}, {
       4.296736217354584, -2.8826924106376985`}}, {{
       4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}, {{
       4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}, {{
       4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}, {{
       4.212151335614398, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.212151335614398, -2.6089447297661525`}, {
       4.212151335614398, -2.6089447297661525`}}, {{
       4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}, {{
       4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}, {{
       4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}, {{
       4.296736217354584, -2.5896817851852854`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.296736217354584, -2.5896817851852854`}, {
       4.296736217354584, -2.5896817851852854`}}, {{
       4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}, {{
       4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}, {{
       4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}, {{
       4.359078166616473, -2.6089447297661525`}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}, {
       4.359078166616473, -2.6089447297661525`}, {
       4.359078166616473, -2.6089447297661525`}}, {{
       4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}, {{
       4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}, {{
       4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}, {{
       4.40693134060614, -2.653302969257955}, {
       4.43254158211751, -2.736187097911492}, {
       4.43254158211751, -2.736187097911492}, {
       4.40693134060614, -2.653302969257955}, {
       4.40693134060614, -2.653302969257955}}, {{
       4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}, {{
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}, {{
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}, {{
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}, {{
       4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}, {{
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}, {{
       4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}, {{
       4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}, {{
       4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}, {{
       4.1579378701982295`, -2.3641846141333662`}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}}, {{
       4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}, {{
       4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}, {{
       4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}, {{
       4.092739485487974, -2.293849323934086}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.293849323934086}, {
       4.092739485487974, -2.293849323934086}}, {{
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}, {{
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}, {{
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}, {{
       4.07672167273806, -2.223514033734806}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.07672167273806, -2.223514033734806}, {
       4.07672167273806, -2.223514033734806}}, {{
       4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}, {{
       4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}, {{
       4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}, {{
       4.092739485487974, -2.1531787435355256`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.092739485487974, -2.1531787435355256`}, {
       4.092739485487974, -2.1531787435355256`}}, {{
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}, {{
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}, {{
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}, {{
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}}, {{
       4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}, {{
       4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}, {{
       4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}, {{
       4.373273506838738, -2.315145136279238}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.373273506838738, -2.315145136279238}, {
       4.373273506838738, -2.315145136279238}}, {{
       4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}, {{
       4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}, {{
       4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}, {{
       4.3203702651185685`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.3203702651185685`, -2.3641846141333662`}, {
       4.3203702651185685`, -2.3641846141333662`}}, {{
       4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}, {{
       4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}, {{
       4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}, {{
       4.2514492106484845`, -2.385480426478518}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.1579378701982295`, -2.3641846141333662`}, {
       4.2514492106484845`, -2.385480426478518}, {
       4.2514492106484845`, -2.385480426478518}}, {{
       4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}, {{
       4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}, {{
       4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}, {{
       4.1579378701982295`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.1579378701982295`, -2.0828434533362454`}, {
       4.1579378701982295`, -2.0828434533362454`}}, {{
       4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}, {{
       4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}, {{
       4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}, {{
       4.2514492106484845`, -2.0615476409910936`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.2514492106484845`, -2.0615476409910936`}, {
       4.2514492106484845`, -2.0615476409910936`}}, {{
       4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}, {{
       4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}, {{
       4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}, {{
       4.3203702651185685`, -2.0828434533362454`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.3203702651185685`, -2.0828434533362454`}, {
       4.3203702651185685`, -2.0828434533362454`}}, {{
       4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}, {{
       4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}, {{
       4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}, {{
       4.373273506838738, -2.1318829311903738`}, {
       4.401586462578738, -2.223514033734806}, {
       4.401586462578738, -2.223514033734806}, {
       4.373273506838738, -2.1318829311903738`}, {
       4.373273506838738, -2.1318829311903738`}}, {{
       4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}, {{
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}, {{
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}, {{
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}, {{
       4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}, {{
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}, {{
       4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}, {{
       4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}, {{
       4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}, {{
       4.147578195224868, -1.888667969716464}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}}, {{
       4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}, {{
       4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}, {{
       4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}, {{
       4.074737108933604, -1.8100878182986797`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.8100878182986797`}, {
       4.074737108933604, -1.8100878182986797`}}, {{
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}, {{
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}, {{
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}, {{
       4.056841652076829, -1.7315076668808955`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.056841652076829, -1.7315076668808955`}, {
       4.056841652076829, -1.7315076668808955`}}, {{
       4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}, {{
       4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}, {{
       4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}, {{
       4.074737108933604, -1.6529275154631113`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.074737108933604, -1.6529275154631113`}, {
       4.074737108933604, -1.6529275154631113`}}, {{
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}, {{
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}, {{
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}, {{
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}}, {{
       4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}, {{
       4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}, {{
       4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}, {{
       4.388155960453585, -1.833879973757276}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}, {
       4.388155960453585, -1.833879973757276}, {
       4.388155960453585, -1.833879973757276}}, {{
       4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}, {{
       4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}, {{
       4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}, {{
       4.329051281520944, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.329051281520944, -1.888667969716464}, {
       4.329051281520944, -1.888667969716464}}, {{
       4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}, {{
       4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}, {{
       4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}, {{
       4.252051145731528, -1.9124601251750601`}, {
       4.147578195224868, -1.888667969716464}, {
       4.147578195224868, -1.888667969716464}, {
       4.252051145731528, -1.9124601251750601`}, {
       4.252051145731528, -1.9124601251750601`}}, {{
       4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}, {{
       4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}, {{
       4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}, {{
       4.147578195224868, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}, {
       4.147578195224868, -1.5743473640453272`}, {
       4.147578195224868, -1.5743473640453272`}}, {{
       4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}, {{
       4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}, {{
       4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}, {{
       4.252051145731528, -1.550555208586731}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.252051145731528, -1.550555208586731}, {
       4.252051145731528, -1.550555208586731}}, {{
       4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}, {{
       4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}, {{
       4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}, {{
       4.329051281520944, -1.5743473640453272`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}, {
       4.329051281520944, -1.5743473640453272`}, {
       4.329051281520944, -1.5743473640453272`}}, {{
       4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}, {{
       4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}, {{
       4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}, {{
       4.388155960453585, -1.629135360004515}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.419787824668982, -1.7315076668808955`}, {
       4.388155960453585, -1.629135360004515}, {
       4.388155960453585, -1.629135360004515}}, {{
       4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}, {{
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}, {{
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}, {{
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}, {{
       4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}, {{
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}, {{
       4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}, {{
       4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}, {{
       4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}, {{
       4.174658290165167, -1.3545802391214614`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}}, {{
       4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}, {{
       4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}, {{
       4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}, {{
       4.110055454084936, -1.2848874201414713`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.2848874201414713`}, {
       4.110055454084936, -1.2848874201414713`}}, {{
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}, {{
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}, {{
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}, {{
       4.094183954567805, -1.2151946011614814`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.094183954567805, -1.2151946011614814`}, {
       4.094183954567805, -1.2151946011614814`}}, {{
       4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}, {{
       4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}, {{
       4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}, {{
       4.110055454084936, -1.1455017821814915`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.110055454084936, -1.1455017821814915`}, {
       4.110055454084936, -1.1455017821814915`}}, {{
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}, {{
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}, {{
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}, {{
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}}, {{
       4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}, {{
       4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}, {{
       4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}, {{
       4.388026963299348, -1.3059887078534782`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.388026963299348, -1.3059887078534782`}, {
       4.388026963299348, -1.3059887078534782`}}, {{
       4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}, {{
       4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}, {{
       4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}, {{
       4.3356069613598915`, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.3356069613598915`, -1.3545802391214614`}, {
       4.3356069613598915`, -1.3545802391214614`}}, {{
       4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}, {{
       4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}, {{
       4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}, {{
       4.267315459903305, -1.3756815268334683`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.174658290165167, -1.3545802391214614`}, {
       4.267315459903305, -1.3756815268334683`}, {
       4.267315459903305, -1.3756815268334683`}}, {{
       4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}, {{
       4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}, {{
       4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}, {{
       4.174658290165167, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.174658290165167, -1.0758089632015013`}, {
       4.174658290165167, -1.0758089632015013`}}, {{
       4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}, {{
       4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}, {{
       4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}, {{
       4.267315459903305, -1.0547076754894944`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.267315459903305, -1.0547076754894944`}, {
       4.267315459903305, -1.0547076754894944`}}, {{
       4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}, {{
       4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}, {{
       4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}, {{
       4.3356069613598915`, -1.0758089632015013`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.3356069613598915`, -1.0758089632015013`}, {
       4.3356069613598915`, -1.0758089632015013`}}, {{
       4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}, {{
       4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}, {{
       4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}, {{
       4.388026963299348, -1.1244004944694845`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.416081296957254, -1.2151946011614814`}, {
       4.388026963299348, -1.1244004944694845`}, {
       4.388026963299348, -1.1244004944694845`}}, {{
       4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978406}, {
       4.194682367669636, -0.6416079560978406}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}, {{
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}, {{
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.9089633228694212}, {
       4.194682367669636, -0.9089633228694212}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}, {{
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}, {{
       4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}, {{
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}, {{
       4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}, {{
       4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}, {{
       4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}, {{
       4.194682367669636, -0.908963322869421}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}}, {{
       4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}, {{
       4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}, {{
       4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}, {{
       4.1327250699612685`, -0.8421244811765259}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.8421244811765259}, {
       4.1327250699612685`, -0.8421244811765259}}, {{
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}, {{
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}, {{
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}, {{
       4.117503521182204, -0.7752856394836308}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.117503521182204, -0.7752856394836308}, {
       4.117503521182204, -0.7752856394836308}}, {{
       4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}, {{
       4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}, {{
       4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}, {{
       4.1327250699612685`, -0.7084467977907357}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}, {
       4.1327250699612685`, -0.7084467977907357}, {
       4.1327250699612685`, -0.7084467977907357}}, {{
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}, {{
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}, {{
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}, {{
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}}, {{
       4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}, {{
       4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}, {{
       4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}, {{
       4.3993134211205405`, -0.8623616540953601}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}, {
       4.3993134211205405`, -0.8623616540953601}, {
       4.3993134211205405`, -0.8623616540953601}}, {{
       4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}, {{
       4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}, {{
       4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}, {{
       4.349040060644499, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}, {
       4.349040060644499, -0.908963322869421}, {
       4.349040060644499, -0.908963322869421}}, {{
       4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}, {{
       4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}, {{
       4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}, {{
       4.283545151389394, -0.9292004957882553}, {
       4.194682367669636, -0.908963322869421}, {
       4.194682367669636, -0.908963322869421}, {
       4.283545151389394, -0.9292004957882553}, {
       4.283545151389394, -0.9292004957882553}}, {{
       4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}, {{
       4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}, {{
       4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}, {{
       4.194682367669636, -0.6416079560978405}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}, {
       4.194682367669636, -0.6416079560978405}, {
       4.194682367669636, -0.6416079560978405}}, {{
       4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}, {{
       4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}, {{
       4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}, {{
       4.283545151389394, -0.6213707831790064}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}, {
       4.283545151389394, -0.6213707831790064}, {
       4.283545151389394, -0.6213707831790064}}, {{
       4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}, {{
       4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}, {{
       4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}, {{
       4.349040060644499, -0.6416079560978406}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.349040060644499, -0.6416079560978406}, {
       4.349040060644499, -0.6416079560978406}}, {{
       4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}, {{
       4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}, {{
       4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}, {{
       4.3993134211205405`, -0.6882096248719015}, {
       4.426218907131931, -0.7752856394836308}, {
       4.426218907131931, -0.7752856394836308}, {
       4.3993134211205405`, -0.6882096248719015}, {
       4.3993134211205405`, -0.6882096248719015}}, {{
       4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}, {{
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}, {{
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}, {{
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}, {{
       4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.23983224181911383`}, {
       4.443769916351422, -0.23983224181911383`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}, {{
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}, {{
       4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}, {{
       4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}, {{
       4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}, {{
       4.176281084216301, -0.3942669910575443}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}}, {{
       4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}, {{
       4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}, {{
       4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}, {{
       4.104703244948482, -0.3170496164383291}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.3170496164383291}, {
       4.104703244948482, -0.3170496164383291}}, {{
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}, {{
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}, {{
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}, {{
       4.087118140171261, -0.23983224181911386`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.104703244948482, -0.16261486719989865`}, {
       4.087118140171261, -0.23983224181911386`}, {
       4.087118140171261, -0.23983224181911386`}}, {{
       4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}, {{
       4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}, {{
       4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}, {{
       4.104703244948482, -0.16261486719989862`}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}, {
       4.104703244948482, -0.16261486719989862`}, {
       4.104703244948482, -0.16261486719989862`}}, {{
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}, {{
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}, {{
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}, {{
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}}, {{
       4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}, {{
       4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}, {{
       4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}, {{
       4.412686627951551, -0.3404291562826523}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}, {
       4.412686627951551, -0.3404291562826523}, {
       4.412686627951551, -0.3404291562826523}}, {{
       4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}, {{
       4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}, {{
       4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}, {{
       4.354606972306382, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.354606972306382, -0.3942669910575443}, {
       4.354606972306382, -0.3942669910575443}}, {{
       4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}, {{
       4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}, {{
       4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}, {{
       4.278942211883991, -0.41764653090186754`}, {
       4.176281084216301, -0.3942669910575443}, {
       4.176281084216301, -0.3942669910575443}, {
       4.278942211883991, -0.41764653090186754`}, {
       4.278942211883991, -0.41764653090186754`}}, {{
       4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}, {{
       4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}, {{
       4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}, {{
       4.176281084216301, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}, {
       4.176281084216301, -0.08539749258068341}, {
       4.176281084216301, -0.08539749258068341}}, {{
       4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}, {{
       4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}, {{
       4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}, {{
       4.278942211883991, -0.06201795273636018}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}, {
       4.278942211883991, -0.06201795273636018}, {
       4.278942211883991, -0.06201795273636018}}, {{
       4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}, {{
       4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}, {{
       4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}, {{
       4.354606972306382, -0.08539749258068341}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.354606972306382, -0.08539749258068341}, {
       4.354606972306382, -0.08539749258068341}}, {{
       4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}, {{
       4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}, {{
       4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}, {{
       4.412686627951551, -0.13923532735557542`}, {
       4.443769916351422, -0.2398322418191139}, {
       4.443769916351422, -0.2398322418191139}, {
       4.412686627951551, -0.13923532735557542`}, {
       4.412686627951551, -0.13923532735557542`}}, {{4.21729290763344, 
       0.1230984505667839}, {4.151908727757882, 0.19363417451802362`}, {
       4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.33470562242050306`}, {4.21729290763344, 0.4052413463717427}, {
       4.21729290763344, 0.4052413463717427}, {4.151908727757882, 
       0.334705622420503}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.1936341745180236}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}}, {{
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}, {{4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.1722776757157991}, {4.380188184476373, 
       0.1230984505667839}, {4.311070726387319, 0.10174195176455939`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}, {4.311070726387319, 0.10174195176455939`}, {
       4.380188184476373, 0.1230984505667839}, {4.433242184019519, 
       0.1722776757157991}, {4.46163582289784, 0.2641698984692633}, {
       4.46163582289784, 0.2641698984692633}}, {{4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}}, {{
       4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.380188184476373, 0.4052413463717427}, {
       4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.380188184476373, 
       0.4052413463717427}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}, {{4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}}, {{4.21729290763344, 
       0.1230984505667839}, {4.151908727757882, 0.19363417451802362`}, {
       4.151908727757882, 0.19363417451802362`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}}, {{
       4.21729290763344, 0.1230984505667839}, {4.151908727757882, 
       0.19363417451802362`}, {4.151908727757882, 0.19363417451802362`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}}, {{4.21729290763344, 0.1230984505667839}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}, {4.21729290763344, 0.1230984505667839}, {
       4.21729290763344, 0.1230984505667839}}, {{4.21729290763344, 
       0.1230984505667839}, {4.151908727757882, 0.19363417451802362`}, {
       4.151908727757882, 0.19363417451802362`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}}, {{
       4.151908727757882, 0.19363417451802362`}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}}, {{4.151908727757882, 0.19363417451802362`}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}, {4.151908727757882, 0.19363417451802362`}, {
       4.151908727757882, 0.19363417451802362`}}, {{4.151908727757882, 
       0.19363417451802362`}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.19363417451802362`}, {4.151908727757882, 0.19363417451802362`}}, {{
       4.151908727757882, 0.19363417451802362`}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.19363417451802362`}, {4.151908727757882, 
       0.19363417451802362`}}, {{4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.334705622420503}, {4.151908727757882, 
       0.334705622420503}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}}, {{4.135845269211973, 
       0.2641698984692633}, {4.151908727757882, 0.334705622420503}, {
       4.151908727757882, 0.334705622420503}, {4.135845269211973, 
       0.2641698984692633}, {4.135845269211973, 0.2641698984692633}}, {{
       4.135845269211973, 0.2641698984692633}, {4.151908727757882, 
       0.334705622420503}, {4.151908727757882, 0.334705622420503}, {
       4.135845269211973, 0.2641698984692633}, {4.135845269211973, 
       0.2641698984692633}}, {{4.135845269211973, 0.2641698984692633}, {
       4.151908727757882, 0.334705622420503}, {4.151908727757882, 
       0.334705622420503}, {4.135845269211973, 0.2641698984692633}, {
       4.135845269211973, 0.2641698984692633}}, {{4.151908727757882, 
       0.33470562242050306`}, {4.21729290763344, 0.4052413463717427}, {
       4.21729290763344, 0.4052413463717427}, {4.151908727757882, 
       0.33470562242050306`}, {4.151908727757882, 0.33470562242050306`}}, {{
       4.151908727757882, 0.33470562242050306`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}, {
       4.151908727757882, 0.33470562242050306`}, {4.151908727757882, 
       0.33470562242050306`}}, {{4.151908727757882, 0.33470562242050306`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}, {4.151908727757882, 0.33470562242050306`}, {
       4.151908727757882, 0.33470562242050306`}}, {{4.151908727757882, 
       0.33470562242050306`}, {4.21729290763344, 0.4052413463717427}, {
       4.21729290763344, 0.4052413463717427}, {4.151908727757882, 
       0.33470562242050306`}, {4.151908727757882, 0.33470562242050306`}}, {{
       4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}, {{4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.1722776757157991}, {4.433242184019519, 
       0.1722776757157991}, {4.46163582289784, 0.2641698984692633}, {
       4.46163582289784, 0.2641698984692633}}, {{4.46163582289784, 
       0.2641698984692633}, {4.433242184019519, 0.1722776757157991}, {
       4.433242184019519, 0.1722776757157991}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}}, {{
       4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}}, {{4.433242184019519, 0.1722776757157991}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.433242184019519, 0.1722776757157991}, {
       4.433242184019519, 0.1722776757157991}}, {{4.433242184019519, 
       0.1722776757157991}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}, {4.433242184019519, 
       0.1722776757157991}, {4.433242184019519, 0.1722776757157991}}, {{
       4.433242184019519, 0.1722776757157991}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}, {
       4.433242184019519, 0.1722776757157991}, {4.433242184019519, 
       0.1722776757157991}}, {{4.433242184019519, 0.1722776757157991}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}, {4.433242184019519, 0.1722776757157991}, {
       4.433242184019519, 0.1722776757157991}}, {{4.380188184476373, 
       0.1230984505667839}, {4.311070726387319, 0.10174195176455939`}, {
       4.311070726387319, 0.10174195176455939`}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}}, {{
       4.380188184476373, 0.1230984505667839}, {4.311070726387319, 
       0.10174195176455939`}, {4.311070726387319, 0.10174195176455939`}, {
       4.380188184476373, 0.1230984505667839}, {4.380188184476373, 
       0.1230984505667839}}, {{4.380188184476373, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}, {4.380188184476373, 0.1230984505667839}, {
       4.380188184476373, 0.1230984505667839}}, {{4.380188184476373, 
       0.1230984505667839}, {4.311070726387319, 0.10174195176455939`}, {
       4.311070726387319, 0.10174195176455939`}, {4.380188184476373, 
       0.1230984505667839}, {4.380188184476373, 0.1230984505667839}}, {{
       4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}}, {{4.311070726387319, 0.10174195176455939`}, {
       4.21729290763344, 0.1230984505667839}, {4.21729290763344, 
       0.1230984505667839}, {4.311070726387319, 0.10174195176455939`}, {
       4.311070726387319, 0.10174195176455939`}}, {{4.311070726387319, 
       0.10174195176455939`}, {4.21729290763344, 0.1230984505667839}, {
       4.21729290763344, 0.1230984505667839}, {4.311070726387319, 
       0.10174195176455939`}, {4.311070726387319, 0.10174195176455939`}}, {{
       4.311070726387319, 0.10174195176455939`}, {4.21729290763344, 
       0.1230984505667839}, {4.21729290763344, 0.1230984505667839}, {
       4.311070726387319, 0.10174195176455939`}, {4.311070726387319, 
       0.10174195176455939`}}, {{4.21729290763344, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}, {4.21729290763344, 0.4052413463717427}, {
       4.21729290763344, 0.4052413463717427}}, {{4.21729290763344, 
       0.4052413463717427}, {4.311070726387319, 0.42659784517396726`}, {
       4.311070726387319, 0.42659784517396726`}, {4.21729290763344, 
       0.4052413463717427}, {4.21729290763344, 0.4052413463717427}}, {{
       4.21729290763344, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}, {
       4.21729290763344, 0.4052413463717427}, {4.21729290763344, 
       0.4052413463717427}}, {{4.21729290763344, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}, {4.21729290763344, 0.4052413463717427}, {
       4.21729290763344, 0.4052413463717427}}, {{4.311070726387319, 
       0.42659784517396726`}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}}, {{
       4.311070726387319, 0.42659784517396726`}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}, {
       4.311070726387319, 0.42659784517396726`}, {4.311070726387319, 
       0.42659784517396726`}}, {{4.311070726387319, 0.42659784517396726`}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}, {4.311070726387319, 0.42659784517396726`}, {
       4.311070726387319, 0.42659784517396726`}}, {{4.311070726387319, 
       0.42659784517396726`}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}, {4.311070726387319, 
       0.42659784517396726`}, {4.311070726387319, 0.42659784517396726`}}, {{
       4.380188184476373, 0.4052413463717427}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}, {{4.380188184476373, 0.4052413463717427}, {
       4.433242184019519, 0.3560621212227275}, {4.433242184019519, 
       0.3560621212227275}, {4.380188184476373, 0.4052413463717427}, {
       4.380188184476373, 0.4052413463717427}}, {{4.380188184476373, 
       0.4052413463717427}, {4.433242184019519, 0.3560621212227275}, {
       4.433242184019519, 0.3560621212227275}, {4.380188184476373, 
       0.4052413463717427}, {4.380188184476373, 0.4052413463717427}}, {{
       4.380188184476373, 0.4052413463717427}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}, {
       4.380188184476373, 0.4052413463717427}, {4.380188184476373, 
       0.4052413463717427}}, {{4.433242184019519, 0.3560621212227275}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}, {4.433242184019519, 0.3560621212227275}, {
       4.433242184019519, 0.3560621212227275}}, {{4.433242184019519, 
       0.3560621212227275}, {4.46163582289784, 0.2641698984692633}, {
       4.46163582289784, 0.2641698984692633}, {4.433242184019519, 
       0.3560621212227275}, {4.433242184019519, 0.3560621212227275}}, {{
       4.433242184019519, 0.3560621212227275}, {4.46163582289784, 
       0.2641698984692633}, {4.46163582289784, 0.2641698984692633}, {
       4.433242184019519, 0.3560621212227275}, {4.433242184019519, 
       0.3560621212227275}}, {{4.433242184019519, 0.3560621212227275}, {
       4.46163582289784, 0.2641698984692633}, {4.46163582289784, 
       0.2641698984692633}, {4.433242184019519, 0.3560621212227275}, {
       4.433242184019519, 0.3560621212227275}}, {{4.17840521788017, 
       0.6015401602364004}, {4.112044402930747, 0.6731294672118877}, {
       4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.8163080811628622}, {4.17840521788017, 0.8878973881383495}, {
       4.17840521788017, 0.8878973881383495}, {4.112044402930747, 
       0.8163080811628622}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}}, {{
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}, {{4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.651453969137593}, {4.343733640493755, 
       0.6015401602364004}, {4.273583783834976, 0.5798646621621057}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}, {4.273583783834976, 0.5798646621621057}, {
       4.343733640493755, 0.6015401602364004}, {4.397580100795165, 
       0.651453969137593}, {4.426397851800548, 0.744718774187375}, {
       4.426397851800548, 0.744718774187375}}, {{4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}}, {{
       4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.343733640493755, 0.8878973881383495}, {
       4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.343733640493755, 
       0.8878973881383495}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}, {{4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}}, {{4.17840521788017, 
       0.6015401602364004}, {4.112044402930747, 0.6731294672118877}, {
       4.112044402930747, 0.6731294672118877}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}}, {{
       4.17840521788017, 0.6015401602364004}, {4.112044402930747, 
       0.6731294672118877}, {4.112044402930747, 0.6731294672118877}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}}, {{4.17840521788017, 0.6015401602364004}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}, {4.17840521788017, 0.6015401602364004}, {
       4.17840521788017, 0.6015401602364004}}, {{4.17840521788017, 
       0.6015401602364004}, {4.112044402930747, 0.6731294672118877}, {
       4.112044402930747, 0.6731294672118877}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}}, {{
       4.112044402930747, 0.6731294672118877}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}}, {{4.112044402930747, 0.6731294672118877}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}, {4.112044402930747, 0.6731294672118877}, {
       4.112044402930747, 0.6731294672118877}}, {{4.112044402930747, 
       0.6731294672118877}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.6731294672118877}, {4.112044402930747, 0.6731294672118877}}, {{
       4.112044402930747, 0.6731294672118877}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.6731294672118877}, {4.112044402930747, 
       0.6731294672118877}}, {{4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}}, {{4.095741006573377, 
       0.744718774187375}, {4.112044402930747, 0.8163080811628622}, {
       4.112044402930747, 0.8163080811628622}, {4.095741006573377, 
       0.744718774187375}, {4.095741006573377, 0.744718774187375}}, {{
       4.095741006573377, 0.744718774187375}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}, {
       4.095741006573377, 0.744718774187375}, {4.095741006573377, 
       0.744718774187375}}, {{4.095741006573377, 0.744718774187375}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}, {4.095741006573377, 0.744718774187375}, {
       4.095741006573377, 0.744718774187375}}, {{4.112044402930747, 
       0.8163080811628622}, {4.17840521788017, 0.8878973881383495}, {
       4.17840521788017, 0.8878973881383495}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}}, {{
       4.112044402930747, 0.8163080811628622}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}, {
       4.112044402930747, 0.8163080811628622}, {4.112044402930747, 
       0.8163080811628622}}, {{4.112044402930747, 0.8163080811628622}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}, {4.112044402930747, 0.8163080811628622}, {
       4.112044402930747, 0.8163080811628622}}, {{4.112044402930747, 
       0.8163080811628622}, {4.17840521788017, 0.8878973881383495}, {
       4.17840521788017, 0.8878973881383495}, {4.112044402930747, 
       0.8163080811628622}, {4.112044402930747, 0.8163080811628622}}, {{
       4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}, {{4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.651453969137593}, {4.397580100795165, 
       0.651453969137593}, {4.426397851800548, 0.744718774187375}, {
       4.426397851800548, 0.744718774187375}}, {{4.426397851800548, 
       0.744718774187375}, {4.397580100795165, 0.651453969137593}, {
       4.397580100795165, 0.651453969137593}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}}, {{
       4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}}, {{4.397580100795165, 0.651453969137593}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.397580100795165, 0.651453969137593}, {
       4.397580100795165, 0.651453969137593}}, {{4.397580100795165, 
       0.651453969137593}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}, {4.397580100795165, 
       0.651453969137593}, {4.397580100795165, 0.651453969137593}}, {{
       4.397580100795165, 0.651453969137593}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}, {
       4.397580100795165, 0.651453969137593}, {4.397580100795165, 
       0.651453969137593}}, {{4.397580100795165, 0.651453969137593}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}, {4.397580100795165, 0.651453969137593}, {
       4.397580100795165, 0.651453969137593}}, {{4.343733640493755, 
       0.6015401602364004}, {4.273583783834976, 0.5798646621621057}, {
       4.273583783834976, 0.5798646621621057}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}}, {{
       4.343733640493755, 0.6015401602364004}, {4.273583783834976, 
       0.5798646621621057}, {4.273583783834976, 0.5798646621621057}, {
       4.343733640493755, 0.6015401602364004}, {4.343733640493755, 
       0.6015401602364004}}, {{4.343733640493755, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}, {4.343733640493755, 0.6015401602364004}, {
       4.343733640493755, 0.6015401602364004}}, {{4.343733640493755, 
       0.6015401602364004}, {4.273583783834976, 0.5798646621621057}, {
       4.273583783834976, 0.5798646621621057}, {4.343733640493755, 
       0.6015401602364004}, {4.343733640493755, 0.6015401602364004}}, {{
       4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}}, {{4.273583783834976, 0.5798646621621057}, {
       4.17840521788017, 0.6015401602364004}, {4.17840521788017, 
       0.6015401602364004}, {4.273583783834976, 0.5798646621621057}, {
       4.273583783834976, 0.5798646621621057}}, {{4.273583783834976, 
       0.5798646621621057}, {4.17840521788017, 0.6015401602364004}, {
       4.17840521788017, 0.6015401602364004}, {4.273583783834976, 
       0.5798646621621057}, {4.273583783834976, 0.5798646621621057}}, {{
       4.273583783834976, 0.5798646621621057}, {4.17840521788017, 
       0.6015401602364004}, {4.17840521788017, 0.6015401602364004}, {
       4.273583783834976, 0.5798646621621057}, {4.273583783834976, 
       0.5798646621621057}}, {{4.17840521788017, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}, {4.17840521788017, 0.8878973881383495}, {
       4.17840521788017, 0.8878973881383495}}, {{4.17840521788017, 
       0.8878973881383495}, {4.273583783834976, 0.9095728862126442}, {
       4.273583783834976, 0.9095728862126442}, {4.17840521788017, 
       0.8878973881383495}, {4.17840521788017, 0.8878973881383495}}, {{
       4.17840521788017, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}, {
       4.17840521788017, 0.8878973881383495}, {4.17840521788017, 
       0.8878973881383495}}, {{4.17840521788017, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}, {4.17840521788017, 0.8878973881383495}, {
       4.17840521788017, 0.8878973881383495}}, {{4.273583783834976, 
       0.9095728862126442}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}}, {{
       4.273583783834976, 0.9095728862126442}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}, {
       4.273583783834976, 0.9095728862126442}, {4.273583783834976, 
       0.9095728862126442}}, {{4.273583783834976, 0.9095728862126442}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}, {4.273583783834976, 0.9095728862126442}, {
       4.273583783834976, 0.9095728862126442}}, {{4.273583783834976, 
       0.9095728862126442}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}, {4.273583783834976, 
       0.9095728862126442}, {4.273583783834976, 0.9095728862126442}}, {{
       4.343733640493755, 0.8878973881383495}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}, {{4.343733640493755, 0.8878973881383495}, {
       4.397580100795165, 0.8379835792371569}, {4.397580100795165, 
       0.8379835792371569}, {4.343733640493755, 0.8878973881383495}, {
       4.343733640493755, 0.8878973881383495}}, {{4.343733640493755, 
       0.8878973881383495}, {4.397580100795165, 0.8379835792371569}, {
       4.397580100795165, 0.8379835792371569}, {4.343733640493755, 
       0.8878973881383495}, {4.343733640493755, 0.8878973881383495}}, {{
       4.343733640493755, 0.8878973881383495}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}, {
       4.343733640493755, 0.8878973881383495}, {4.343733640493755, 
       0.8878973881383495}}, {{4.397580100795165, 0.8379835792371569}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}, {4.397580100795165, 0.8379835792371569}, {
       4.397580100795165, 0.8379835792371569}}, {{4.397580100795165, 
       0.8379835792371569}, {4.426397851800548, 0.744718774187375}, {
       4.426397851800548, 0.744718774187375}, {4.397580100795165, 
       0.8379835792371569}, {4.397580100795165, 0.8379835792371569}}, {{
       4.397580100795165, 0.8379835792371569}, {4.426397851800548, 
       0.744718774187375}, {4.426397851800548, 0.744718774187375}, {
       4.397580100795165, 0.8379835792371569}, {4.397580100795165, 
       0.8379835792371569}}, {{4.397580100795165, 0.8379835792371569}, {
       4.426397851800548, 0.744718774187375}, {4.426397851800548, 
       0.744718774187375}, {4.397580100795165, 0.8379835792371569}, {
       4.397580100795165, 0.8379835792371569}}, {{4.174516701005696, 
       1.13266027030957}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.174516701005696, 1.4069106084056682`}, {
       4.174516701005696, 1.4069106084056682`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}}, {{
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}, {{4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.1804637745797792`}, {4.332855207530824, 
       1.13266027030957}, {4.265671214840929, 1.1119011900557547`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}, {4.265671214840929, 1.1119011900557547`}, {
       4.332855207530824, 1.13266027030957}, {4.384425094734775, 
       1.1804637745797792`}, {4.412024460793388, 1.2697854393576191`}, {
       4.412024460793388, 1.2697854393576191`}}, {{4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}}, {{
       4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.332855207530824, 1.4069106084056682`}, {
       4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.332855207530824, 
       1.4069106084056682`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}, {{4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}}, {{4.174516701005696, 
       1.13266027030957}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}}, {{
       4.174516701005696, 1.13266027030957}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}}, {{4.174516701005696, 1.13266027030957}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.174516701005696, 1.13266027030957}, {
       4.174516701005696, 1.13266027030957}}, {{4.174516701005696, 
       1.13266027030957}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}}, {{
       4.1109615532290755`, 1.2012228548335946`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}}, {{4.1109615532290755`, 1.2012228548335946`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}, {4.1109615532290755`, 1.2012228548335946`}, {
       4.1109615532290755`, 1.2012228548335946`}}, {{4.1109615532290755`, 
       1.2012228548335946`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`, 
       1.2012228548335946`}, {4.1109615532290755`, 1.2012228548335946`}}, {{
       4.1109615532290755`, 1.2012228548335946`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.2012228548335946`}, {4.1109615532290755`, 
       1.2012228548335946`}}, {{4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}}, {{4.095347447743132, 
       1.2697854393576191`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.095347447743132, 
       1.2697854393576191`}, {4.095347447743132, 1.2697854393576191`}}, {{
       4.095347447743132, 1.2697854393576191`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.095347447743132, 1.2697854393576191`}, {4.095347447743132, 
       1.2697854393576191`}}, {{4.095347447743132, 1.2697854393576191`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.095347447743132, 1.2697854393576191`}, {
       4.095347447743132, 1.2697854393576191`}}, {{4.1109615532290755`, 
       1.3383480238816436`}, {4.174516701005696, 1.4069106084056682`}, {
       4.174516701005696, 1.4069106084056682`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}}, {{
       4.1109615532290755`, 1.3383480238816436`}, {4.174516701005696, 
       1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}, {
       4.1109615532290755`, 1.3383480238816436`}, {4.1109615532290755`, 
       1.3383480238816436`}}, {{4.1109615532290755`, 1.3383480238816436`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}, {4.1109615532290755`, 1.3383480238816436`}, {
       4.1109615532290755`, 1.3383480238816436`}}, {{4.1109615532290755`, 
       1.3383480238816436`}, {4.174516701005696, 1.4069106084056682`}, {
       4.174516701005696, 1.4069106084056682`}, {4.1109615532290755`, 
       1.3383480238816436`}, {4.1109615532290755`, 1.3383480238816436`}}, {{
       4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}, {{4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.1804637745797792`}, {4.384425094734775, 
       1.1804637745797792`}, {4.412024460793388, 1.2697854393576191`}, {
       4.412024460793388, 1.2697854393576191`}}, {{4.412024460793388, 
       1.2697854393576191`}, {4.384425094734775, 1.1804637745797792`}, {
       4.384425094734775, 1.1804637745797792`}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}}, {{
       4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}}, {{4.384425094734775, 1.1804637745797792`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.384425094734775, 1.1804637745797792`}, {
       4.384425094734775, 1.1804637745797792`}}, {{4.384425094734775, 
       1.1804637745797792`}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}, {4.384425094734775, 
       1.1804637745797792`}, {4.384425094734775, 1.1804637745797792`}}, {{
       4.384425094734775, 1.1804637745797792`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}, {
       4.384425094734775, 1.1804637745797792`}, {4.384425094734775, 
       1.1804637745797792`}}, {{4.384425094734775, 1.1804637745797792`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}, {4.384425094734775, 1.1804637745797792`}, {
       4.384425094734775, 1.1804637745797792`}}, {{4.332855207530824, 
       1.13266027030957}, {4.265671214840929, 1.1119011900557547`}, {
       4.265671214840929, 1.1119011900557547`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}}, {{
       4.332855207530824, 1.13266027030957}, {4.265671214840929, 
       1.1119011900557547`}, {4.265671214840929, 1.1119011900557547`}, {
       4.332855207530824, 1.13266027030957}, {4.332855207530824, 
       1.13266027030957}}, {{4.332855207530824, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}, {4.332855207530824, 1.13266027030957}, {
       4.332855207530824, 1.13266027030957}}, {{4.332855207530824, 
       1.13266027030957}, {4.265671214840929, 1.1119011900557547`}, {
       4.265671214840929, 1.1119011900557547`}, {4.332855207530824, 
       1.13266027030957}, {4.332855207530824, 1.13266027030957}}, {{
       4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}}, {{4.265671214840929, 1.1119011900557547`}, {
       4.174516701005696, 1.13266027030957}, {4.174516701005696, 
       1.13266027030957}, {4.265671214840929, 1.1119011900557547`}, {
       4.265671214840929, 1.1119011900557547`}}, {{4.265671214840929, 
       1.1119011900557547`}, {4.174516701005696, 1.13266027030957}, {
       4.174516701005696, 1.13266027030957}, {4.265671214840929, 
       1.1119011900557547`}, {4.265671214840929, 1.1119011900557547`}}, {{
       4.265671214840929, 1.1119011900557547`}, {4.174516701005696, 
       1.13266027030957}, {4.174516701005696, 1.13266027030957}, {
       4.265671214840929, 1.1119011900557547`}, {4.265671214840929, 
       1.1119011900557547`}}, {{4.174516701005696, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}, {4.174516701005696, 1.4069106084056682`}, {
       4.174516701005696, 1.4069106084056682`}}, {{4.174516701005696, 
       1.4069106084056682`}, {4.265671214840929, 1.4276696886594835`}, {
       4.265671214840929, 1.4276696886594835`}, {4.174516701005696, 
       1.4069106084056682`}, {4.174516701005696, 1.4069106084056682`}}, {{
       4.174516701005696, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}, {
       4.174516701005696, 1.4069106084056682`}, {4.174516701005696, 
       1.4069106084056682`}}, {{4.174516701005696, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}, {4.174516701005696, 1.4069106084056682`}, {
       4.174516701005696, 1.4069106084056682`}}, {{4.265671214840929, 
       1.4276696886594835`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}}, {{
       4.265671214840929, 1.4276696886594835`}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}, {
       4.265671214840929, 1.4276696886594835`}, {4.265671214840929, 
       1.4276696886594835`}}, {{4.265671214840929, 1.4276696886594835`}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}, {4.265671214840929, 1.4276696886594835`}, {
       4.265671214840929, 1.4276696886594835`}}, {{4.265671214840929, 
       1.4276696886594835`}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}, {4.265671214840929, 
       1.4276696886594835`}, {4.265671214840929, 1.4276696886594835`}}, {{
       4.332855207530824, 1.4069106084056682`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}, {{4.332855207530824, 1.4069106084056682`}, {
       4.384425094734775, 1.359107104135459}, {4.384425094734775, 
       1.359107104135459}, {4.332855207530824, 1.4069106084056682`}, {
       4.332855207530824, 1.4069106084056682`}}, {{4.332855207530824, 
       1.4069106084056682`}, {4.384425094734775, 1.359107104135459}, {
       4.384425094734775, 1.359107104135459}, {4.332855207530824, 
       1.4069106084056682`}, {4.332855207530824, 1.4069106084056682`}}, {{
       4.332855207530824, 1.4069106084056682`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}, {
       4.332855207530824, 1.4069106084056682`}, {4.332855207530824, 
       1.4069106084056682`}}, {{4.384425094734775, 1.359107104135459}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}, {4.384425094734775, 1.359107104135459}, {
       4.384425094734775, 1.359107104135459}}, {{4.384425094734775, 
       1.359107104135459}, {4.412024460793388, 1.2697854393576191`}, {
       4.412024460793388, 1.2697854393576191`}, {4.384425094734775, 
       1.359107104135459}, {4.384425094734775, 1.359107104135459}}, {{
       4.384425094734775, 1.359107104135459}, {4.412024460793388, 
       1.2697854393576191`}, {4.412024460793388, 1.2697854393576191`}, {
       4.384425094734775, 1.359107104135459}, {4.384425094734775, 
       1.359107104135459}}, {{4.384425094734775, 1.359107104135459}, {
       4.412024460793388, 1.2697854393576191`}, {4.412024460793388, 
       1.2697854393576191`}, {4.384425094734775, 1.359107104135459}, {
       4.384425094734775, 1.359107104135459}}, {{4.202817042195127, 
       1.6066413738311724`}, {4.136012909023033, 1.6787089275604827`}, {
       4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.8228440350191033`}, {4.202817042195127, 1.8949115887484136`}, {
       4.202817042195127, 1.8949115887484136`}, {4.136012909023033, 
       1.8228440350191033`}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.202817042195127, 
       1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}}, {{
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}, {{4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.6568886280203061`}, {4.369249928376947, 
       1.6066413738311724`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.369249928376947, 1.6066413738311724`}, {4.423456105735721, 
       1.6568886280203061`}, {4.452466371467858, 1.750776481289793}, {
       4.452466371467858, 1.750776481289793}}, {{4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}}, {{
       4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`, 
       1.9167318882885902`}, {4.369249928376947, 1.8949115887484136`}, {
       4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.369249928376947, 
       1.8949115887484136`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}, {{4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}}, {{4.202817042195127, 
       1.6066413738311724`}, {4.136012909023033, 1.6787089275604827`}, {
       4.136012909023033, 1.6787089275604827`}, {4.202817042195127, 
       1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}}, {{
       4.202817042195127, 1.6066413738311724`}, {4.136012909023033, 
       1.6787089275604827`}, {4.136012909023033, 1.6787089275604827`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}}, {{4.202817042195127, 1.6066413738311724`}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}, {4.202817042195127, 1.6066413738311724`}, {
       4.202817042195127, 1.6066413738311724`}}, {{4.202817042195127, 
       1.6066413738311724`}, {4.136012909023033, 1.6787089275604827`}, {
       4.136012909023033, 1.6787089275604827`}, {4.202817042195127, 
       1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}}, {{
       4.136012909023033, 1.6787089275604827`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}}, {{4.136012909023033, 1.6787089275604827`}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}, {4.136012909023033, 1.6787089275604827`}, {
       4.136012909023033, 1.6787089275604827`}}, {{4.136012909023033, 
       1.6787089275604827`}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.6787089275604827`}, {4.136012909023033, 1.6787089275604827`}}, {{
       4.136012909023033, 1.6787089275604827`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.6787089275604827`}, {4.136012909023033, 
       1.6787089275604827`}}, {{4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}}, {{4.119600599104216, 
       1.750776481289793}, {4.136012909023033, 1.8228440350191033`}, {
       4.136012909023033, 1.8228440350191033`}, {4.119600599104216, 
       1.750776481289793}, {4.119600599104216, 1.750776481289793}}, {{
       4.119600599104216, 1.750776481289793}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}, {
       4.119600599104216, 1.750776481289793}, {4.119600599104216, 
       1.750776481289793}}, {{4.119600599104216, 1.750776481289793}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}, {4.119600599104216, 1.750776481289793}, {
       4.119600599104216, 1.750776481289793}}, {{4.136012909023033, 
       1.8228440350191033`}, {4.202817042195127, 1.8949115887484136`}, {
       4.202817042195127, 1.8949115887484136`}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}}, {{
       4.136012909023033, 1.8228440350191033`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}, {
       4.136012909023033, 1.8228440350191033`}, {4.136012909023033, 
       1.8228440350191033`}}, {{4.136012909023033, 1.8228440350191033`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}, {4.136012909023033, 1.8228440350191033`}, {
       4.136012909023033, 1.8228440350191033`}}, {{4.136012909023033, 
       1.8228440350191033`}, {4.202817042195127, 1.8949115887484136`}, {
       4.202817042195127, 1.8949115887484136`}, {4.136012909023033, 
       1.8228440350191033`}, {4.136012909023033, 1.8228440350191033`}}, {{
       4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}, {{4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.6568886280203061`}, {4.423456105735721, 
       1.6568886280203061`}, {4.452466371467858, 1.750776481289793}, {
       4.452466371467858, 1.750776481289793}}, {{4.452466371467858, 
       1.750776481289793}, {4.423456105735721, 1.6568886280203061`}, {
       4.423456105735721, 1.6568886280203061`}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}}, {{
       4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}}, {{4.423456105735721, 1.6568886280203061`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.423456105735721, 1.6568886280203061`}, {
       4.423456105735721, 1.6568886280203061`}}, {{4.423456105735721, 
       1.6568886280203061`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}, {4.423456105735721, 
       1.6568886280203061`}, {4.423456105735721, 1.6568886280203061`}}, {{
       4.423456105735721, 1.6568886280203061`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}, {
       4.423456105735721, 1.6568886280203061`}, {4.423456105735721, 
       1.6568886280203061`}}, {{4.423456105735721, 1.6568886280203061`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}, {4.423456105735721, 1.6568886280203061`}, {
       4.423456105735721, 1.6568886280203061`}}, {{4.369249928376947, 
       1.6066413738311724`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}}, {{
       4.369249928376947, 1.6066413738311724`}, {4.2986314410993565`, 
       1.5848210742909958`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.369249928376947, 1.6066413738311724`}, {4.369249928376947, 
       1.6066413738311724`}}, {{4.369249928376947, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}, {4.369249928376947, 1.6066413738311724`}, {
       4.369249928376947, 1.6066413738311724`}}, {{4.369249928376947, 
       1.6066413738311724`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.369249928376947, 
       1.6066413738311724`}, {4.369249928376947, 1.6066413738311724`}}, {{
       4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127, 
       1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}}, {{4.2986314410993565`, 1.5848210742909958`}, {
       4.202817042195127, 1.6066413738311724`}, {4.202817042195127, 
       1.6066413738311724`}, {4.2986314410993565`, 1.5848210742909958`}, {
       4.2986314410993565`, 1.5848210742909958`}}, {{4.2986314410993565`, 
       1.5848210742909958`}, {4.202817042195127, 1.6066413738311724`}, {
       4.202817042195127, 1.6066413738311724`}, {4.2986314410993565`, 
       1.5848210742909958`}, {4.2986314410993565`, 1.5848210742909958`}}, {{
       4.2986314410993565`, 1.5848210742909958`}, {4.202817042195127, 
       1.6066413738311724`}, {4.202817042195127, 1.6066413738311724`}, {
       4.2986314410993565`, 1.5848210742909958`}, {4.2986314410993565`, 
       1.5848210742909958`}}, {{4.202817042195127, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}, {4.202817042195127, 1.8949115887484136`}, {
       4.202817042195127, 1.8949115887484136`}}, {{4.202817042195127, 
       1.8949115887484136`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.202817042195127, 
       1.8949115887484136`}, {4.202817042195127, 1.8949115887484136`}}, {{
       4.202817042195127, 1.8949115887484136`}, {4.2986314410993565`, 
       1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.202817042195127, 1.8949115887484136`}, {4.202817042195127, 
       1.8949115887484136`}}, {{4.202817042195127, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}, {4.202817042195127, 1.8949115887484136`}, {
       4.202817042195127, 1.8949115887484136`}}, {{4.2986314410993565`, 
       1.9167318882885902`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.2986314410993565`, 
       1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}}, {{
       4.2986314410993565`, 1.9167318882885902`}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}, {
       4.2986314410993565`, 1.9167318882885902`}, {4.2986314410993565`, 
       1.9167318882885902`}}, {{4.2986314410993565`, 1.9167318882885902`}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}, {4.2986314410993565`, 1.9167318882885902`}, {
       4.2986314410993565`, 1.9167318882885902`}}, {{4.2986314410993565`, 
       1.9167318882885902`}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}, {4.2986314410993565`, 
       1.9167318882885902`}, {4.2986314410993565`, 1.9167318882885902`}}, {{
       4.369249928376947, 1.8949115887484136`}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}, {{4.369249928376947, 1.8949115887484136`}, {
       4.423456105735721, 1.84466433455928}, {4.423456105735721, 
       1.84466433455928}, {4.369249928376947, 1.8949115887484136`}, {
       4.369249928376947, 1.8949115887484136`}}, {{4.369249928376947, 
       1.8949115887484136`}, {4.423456105735721, 1.84466433455928}, {
       4.423456105735721, 1.84466433455928}, {4.369249928376947, 
       1.8949115887484136`}, {4.369249928376947, 1.8949115887484136`}}, {{
       4.369249928376947, 1.8949115887484136`}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}, {
       4.369249928376947, 1.8949115887484136`}, {4.369249928376947, 
       1.8949115887484136`}}, {{4.423456105735721, 1.84466433455928}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}, {4.423456105735721, 1.84466433455928}, {
       4.423456105735721, 1.84466433455928}}, {{4.423456105735721, 
       1.84466433455928}, {4.452466371467858, 1.750776481289793}, {
       4.452466371467858, 1.750776481289793}, {4.423456105735721, 
       1.84466433455928}, {4.423456105735721, 1.84466433455928}}, {{
       4.423456105735721, 1.84466433455928}, {4.452466371467858, 
       1.750776481289793}, {4.452466371467858, 1.750776481289793}, {
       4.423456105735721, 1.84466433455928}, {4.423456105735721, 
       1.84466433455928}}, {{4.423456105735721, 1.84466433455928}, {
       4.452466371467858, 1.750776481289793}, {4.452466371467858, 
       1.750776481289793}, {4.423456105735721, 1.84466433455928}, {
       4.423456105735721, 1.84466433455928}}, {{4.156457484897694, 
       2.1062122968949697`}, {4.090145643539342, 2.1777487717066637`}, {
       4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.3208217213300517`}, {4.156457484897694, 2.3923581961417457`}, {
       4.156457484897694, 2.3923581961417457`}, {4.090145643539342, 
       2.3208217213300517`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}}, {{
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}, {{4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.156089269924454}, {4.321663896855328, 
       2.1062122968949697`}, {4.251565810060983, 2.08455279511276}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}, {4.251565810060983, 2.08455279511276}, {
       4.321663896855328, 2.1062122968949697`}, {4.375470619029208, 
       2.156089269924454}, {4.404267102834145, 2.2492852465183577`}, {
       4.404267102834145, 2.2492852465183577`}}, {{4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}}, {{
       4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.321663896855328, 2.3923581961417457`}, {
       4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.321663896855328, 
       2.3923581961417457`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}, {{4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}}, {{4.156457484897694, 
       2.1062122968949697`}, {4.090145643539342, 2.1777487717066637`}, {
       4.090145643539342, 2.1777487717066637`}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}}, {{
       4.156457484897694, 2.1062122968949697`}, {4.090145643539342, 
       2.1777487717066637`}, {4.090145643539342, 2.1777487717066637`}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}}, {{4.156457484897694, 2.1062122968949697`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}, {4.156457484897694, 2.1062122968949697`}, {
       4.156457484897694, 2.1062122968949697`}}, {{4.156457484897694, 
       2.1062122968949697`}, {4.090145643539342, 2.1777487717066637`}, {
       4.090145643539342, 2.1777487717066637`}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}}, {{
       4.090145643539342, 2.1777487717066637`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}}, {{4.090145643539342, 2.1777487717066637`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}, {4.090145643539342, 2.1777487717066637`}, {
       4.090145643539342, 2.1777487717066637`}}, {{4.090145643539342, 
       2.1777487717066637`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.1777487717066637`}, {4.090145643539342, 2.1777487717066637`}}, {{
       4.090145643539342, 2.1777487717066637`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.1777487717066637`}, {4.090145643539342, 
       2.1777487717066637`}}, {{4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}}, {{4.073854278918877, 
       2.2492852465183577`}, {4.090145643539342, 2.3208217213300517`}, {
       4.090145643539342, 2.3208217213300517`}, {4.073854278918877, 
       2.2492852465183577`}, {4.073854278918877, 2.2492852465183577`}}, {{
       4.073854278918877, 2.2492852465183577`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}, {
       4.073854278918877, 2.2492852465183577`}, {4.073854278918877, 
       2.2492852465183577`}}, {{4.073854278918877, 2.2492852465183577`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}, {4.073854278918877, 2.2492852465183577`}, {
       4.073854278918877, 2.2492852465183577`}}, {{4.090145643539342, 
       2.3208217213300517`}, {4.156457484897694, 2.3923581961417457`}, {
       4.156457484897694, 2.3923581961417457`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}}, {{
       4.090145643539342, 2.3208217213300517`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}, {
       4.090145643539342, 2.3208217213300517`}, {4.090145643539342, 
       2.3208217213300517`}}, {{4.090145643539342, 2.3208217213300517`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}, {4.090145643539342, 2.3208217213300517`}, {
       4.090145643539342, 2.3208217213300517`}}, {{4.090145643539342, 
       2.3208217213300517`}, {4.156457484897694, 2.3923581961417457`}, {
       4.156457484897694, 2.3923581961417457`}, {4.090145643539342, 
       2.3208217213300517`}, {4.090145643539342, 2.3208217213300517`}}, {{
       4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}, {{4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.156089269924454}, {4.375470619029208, 
       2.156089269924454}, {4.404267102834145, 2.2492852465183577`}, {
       4.404267102834145, 2.2492852465183577`}}, {{4.404267102834145, 
       2.2492852465183577`}, {4.375470619029208, 2.156089269924454}, {
       4.375470619029208, 2.156089269924454}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}}, {{
       4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}}, {{4.375470619029208, 2.156089269924454}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.375470619029208, 2.156089269924454}, {
       4.375470619029208, 2.156089269924454}}, {{4.375470619029208, 
       2.156089269924454}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}, {4.375470619029208, 
       2.156089269924454}, {4.375470619029208, 2.156089269924454}}, {{
       4.375470619029208, 2.156089269924454}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}, {
       4.375470619029208, 2.156089269924454}, {4.375470619029208, 
       2.156089269924454}}, {{4.375470619029208, 2.156089269924454}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}, {4.375470619029208, 2.156089269924454}, {
       4.375470619029208, 2.156089269924454}}, {{4.321663896855328, 
       2.1062122968949697`}, {4.251565810060983, 2.08455279511276}, {
       4.251565810060983, 2.08455279511276}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}}, {{
       4.321663896855328, 2.1062122968949697`}, {4.251565810060983, 
       2.08455279511276}, {4.251565810060983, 2.08455279511276}, {
       4.321663896855328, 2.1062122968949697`}, {4.321663896855328, 
       2.1062122968949697`}}, {{4.321663896855328, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}, {4.321663896855328, 2.1062122968949697`}, {
       4.321663896855328, 2.1062122968949697`}}, {{4.321663896855328, 
       2.1062122968949697`}, {4.251565810060983, 2.08455279511276}, {
       4.251565810060983, 2.08455279511276}, {4.321663896855328, 
       2.1062122968949697`}, {4.321663896855328, 2.1062122968949697`}}, {{
       4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}}, {{4.251565810060983, 2.08455279511276}, {
       4.156457484897694, 2.1062122968949697`}, {4.156457484897694, 
       2.1062122968949697`}, {4.251565810060983, 2.08455279511276}, {
       4.251565810060983, 2.08455279511276}}, {{4.251565810060983, 
       2.08455279511276}, {4.156457484897694, 2.1062122968949697`}, {
       4.156457484897694, 2.1062122968949697`}, {4.251565810060983, 
       2.08455279511276}, {4.251565810060983, 2.08455279511276}}, {{
       4.251565810060983, 2.08455279511276}, {4.156457484897694, 
       2.1062122968949697`}, {4.156457484897694, 2.1062122968949697`}, {
       4.251565810060983, 2.08455279511276}, {4.251565810060983, 
       2.08455279511276}}, {{4.156457484897694, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}, {4.156457484897694, 2.3923581961417457`}, {
       4.156457484897694, 2.3923581961417457`}}, {{4.156457484897694, 
       2.3923581961417457`}, {4.251565810060983, 2.4140176979239554`}, {
       4.251565810060983, 2.4140176979239554`}, {4.156457484897694, 
       2.3923581961417457`}, {4.156457484897694, 2.3923581961417457`}}, {{
       4.156457484897694, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}, {
       4.156457484897694, 2.3923581961417457`}, {4.156457484897694, 
       2.3923581961417457`}}, {{4.156457484897694, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}, {4.156457484897694, 2.3923581961417457`}, {
       4.156457484897694, 2.3923581961417457`}}, {{4.251565810060983, 
       2.4140176979239554`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}}, {{
       4.251565810060983, 2.4140176979239554`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}, {
       4.251565810060983, 2.4140176979239554`}, {4.251565810060983, 
       2.4140176979239554`}}, {{4.251565810060983, 2.4140176979239554`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}, {4.251565810060983, 2.4140176979239554`}, {
       4.251565810060983, 2.4140176979239554`}}, {{4.251565810060983, 
       2.4140176979239554`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}, {4.251565810060983, 
       2.4140176979239554`}, {4.251565810060983, 2.4140176979239554`}}, {{
       4.321663896855328, 2.3923581961417457`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}, {{4.321663896855328, 2.3923581961417457`}, {
       4.375470619029208, 2.3424812231122614`}, {4.375470619029208, 
       2.3424812231122614`}, {4.321663896855328, 2.3923581961417457`}, {
       4.321663896855328, 2.3923581961417457`}}, {{4.321663896855328, 
       2.3923581961417457`}, {4.375470619029208, 2.3424812231122614`}, {
       4.375470619029208, 2.3424812231122614`}, {4.321663896855328, 
       2.3923581961417457`}, {4.321663896855328, 2.3923581961417457`}}, {{
       4.321663896855328, 2.3923581961417457`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}, {
       4.321663896855328, 2.3923581961417457`}, {4.321663896855328, 
       2.3923581961417457`}}, {{4.375470619029208, 2.3424812231122614`}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}, {4.375470619029208, 2.3424812231122614`}, {
       4.375470619029208, 2.3424812231122614`}}, {{4.375470619029208, 
       2.3424812231122614`}, {4.404267102834145, 2.2492852465183577`}, {
       4.404267102834145, 2.2492852465183577`}, {4.375470619029208, 
       2.3424812231122614`}, {4.375470619029208, 2.3424812231122614`}}, {{
       4.375470619029208, 2.3424812231122614`}, {4.404267102834145, 
       2.2492852465183577`}, {4.404267102834145, 2.2492852465183577`}, {
       4.375470619029208, 2.3424812231122614`}, {4.375470619029208, 
       2.3424812231122614`}}, {{4.375470619029208, 2.3424812231122614`}, {
       4.404267102834145, 2.2492852465183577`}, {4.404267102834145, 
       2.2492852465183577`}, {4.375470619029208, 2.3424812231122614`}, {
       4.375470619029208, 2.3424812231122614`}}, {{4.188559794873285, 
       2.65820611976988}, {4.123431755250747, 2.7284655224731633`}, {
       4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.86898432787973}, {4.188559794873285, 2.939243730583013}, {
       4.188559794873285, 2.939243730583013}, {4.123431755250747, 
       2.86898432787973}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}}, {{
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}, {{4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.707192687013008}, {4.350816935128657, 
       2.65820611976988}, {4.281970242280319, 2.6369332843097246`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}, {4.281970242280319, 2.6369332843097246`}, {
       4.350816935128657, 2.65820611976988}, {4.403663097471847, 
       2.707192687013008}, {4.431945505256342, 2.7987249251764466`}, {
       4.431945505256342, 2.7987249251764466`}}, {{4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}}, {{
       4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.350816935128657, 2.939243730583013}, {
       4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.350816935128657, 
       2.939243730583013}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}, {{4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}}, {{4.188559794873285, 
       2.65820611976988}, {4.123431755250747, 2.7284655224731633`}, {
       4.123431755250747, 2.7284655224731633`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}}, {{
       4.188559794873285, 2.65820611976988}, {4.123431755250747, 
       2.7284655224731633`}, {4.123431755250747, 2.7284655224731633`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}}, {{4.188559794873285, 2.65820611976988}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}, {4.188559794873285, 2.65820611976988}, {
       4.188559794873285, 2.65820611976988}}, {{4.188559794873285, 
       2.65820611976988}, {4.123431755250747, 2.7284655224731633`}, {
       4.123431755250747, 2.7284655224731633`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}}, {{
       4.123431755250747, 2.7284655224731633`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}}, {{4.123431755250747, 2.7284655224731633`}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}, {4.123431755250747, 2.7284655224731633`}, {
       4.123431755250747, 2.7284655224731633`}}, {{4.123431755250747, 
       2.7284655224731633`}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.7284655224731633`}, {4.123431755250747, 2.7284655224731633`}}, {{
       4.123431755250747, 2.7284655224731633`}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.7284655224731633`}, {4.123431755250747, 
       2.7284655224731633`}}, {{4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}}, {{4.1074312247456, 
       2.7987249251764466`}, {4.123431755250747, 2.86898432787973}, {
       4.123431755250747, 2.86898432787973}, {4.1074312247456, 
       2.7987249251764466`}, {4.1074312247456, 2.7987249251764466`}}, {{
       4.1074312247456, 2.7987249251764466`}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}, {
       4.1074312247456, 2.7987249251764466`}, {4.1074312247456, 
       2.7987249251764466`}}, {{4.1074312247456, 2.7987249251764466`}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}, {4.1074312247456, 2.7987249251764466`}, {
       4.1074312247456, 2.7987249251764466`}}, {{4.123431755250747, 
       2.86898432787973}, {4.188559794873285, 2.939243730583013}, {
       4.188559794873285, 2.939243730583013}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}}, {{
       4.123431755250747, 2.86898432787973}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}, {
       4.123431755250747, 2.86898432787973}, {4.123431755250747, 
       2.86898432787973}}, {{4.123431755250747, 2.86898432787973}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}, {4.123431755250747, 2.86898432787973}, {
       4.123431755250747, 2.86898432787973}}, {{4.123431755250747, 
       2.86898432787973}, {4.188559794873285, 2.939243730583013}, {
       4.188559794873285, 2.939243730583013}, {4.123431755250747, 
       2.86898432787973}, {4.123431755250747, 2.86898432787973}}, {{
       4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}, {{4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.707192687013008}, {4.403663097471847, 
       2.707192687013008}, {4.431945505256342, 2.7987249251764466`}, {
       4.431945505256342, 2.7987249251764466`}}, {{4.431945505256342, 
       2.7987249251764466`}, {4.403663097471847, 2.707192687013008}, {
       4.403663097471847, 2.707192687013008}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}}, {{
       4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}}, {{4.403663097471847, 2.707192687013008}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.403663097471847, 2.707192687013008}, {
       4.403663097471847, 2.707192687013008}}, {{4.403663097471847, 
       2.707192687013008}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}, {4.403663097471847, 
       2.707192687013008}, {4.403663097471847, 2.707192687013008}}, {{
       4.403663097471847, 2.707192687013008}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}, {
       4.403663097471847, 2.707192687013008}, {4.403663097471847, 
       2.707192687013008}}, {{4.403663097471847, 2.707192687013008}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}, {4.403663097471847, 2.707192687013008}, {
       4.403663097471847, 2.707192687013008}}, {{4.350816935128657, 
       2.65820611976988}, {4.281970242280319, 2.6369332843097246`}, {
       4.281970242280319, 2.6369332843097246`}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}}, {{
       4.350816935128657, 2.65820611976988}, {4.281970242280319, 
       2.6369332843097246`}, {4.281970242280319, 2.6369332843097246`}, {
       4.350816935128657, 2.65820611976988}, {4.350816935128657, 
       2.65820611976988}}, {{4.350816935128657, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}, {4.350816935128657, 2.65820611976988}, {
       4.350816935128657, 2.65820611976988}}, {{4.350816935128657, 
       2.65820611976988}, {4.281970242280319, 2.6369332843097246`}, {
       4.281970242280319, 2.6369332843097246`}, {4.350816935128657, 
       2.65820611976988}, {4.350816935128657, 2.65820611976988}}, {{
       4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}}, {{4.281970242280319, 2.6369332843097246`}, {
       4.188559794873285, 2.65820611976988}, {4.188559794873285, 
       2.65820611976988}, {4.281970242280319, 2.6369332843097246`}, {
       4.281970242280319, 2.6369332843097246`}}, {{4.281970242280319, 
       2.6369332843097246`}, {4.188559794873285, 2.65820611976988}, {
       4.188559794873285, 2.65820611976988}, {4.281970242280319, 
       2.6369332843097246`}, {4.281970242280319, 2.6369332843097246`}}, {{
       4.281970242280319, 2.6369332843097246`}, {4.188559794873285, 
       2.65820611976988}, {4.188559794873285, 2.65820611976988}, {
       4.281970242280319, 2.6369332843097246`}, {4.281970242280319, 
       2.6369332843097246`}}, {{4.188559794873285, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}, {4.188559794873285, 2.939243730583013}, {
       4.188559794873285, 2.939243730583013}}, {{4.188559794873285, 
       2.939243730583013}, {4.281970242280319, 2.9605165660431685`}, {
       4.281970242280319, 2.9605165660431685`}, {4.188559794873285, 
       2.939243730583013}, {4.188559794873285, 2.939243730583013}}, {{
       4.188559794873285, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}, {
       4.188559794873285, 2.939243730583013}, {4.188559794873285, 
       2.939243730583013}}, {{4.188559794873285, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}, {4.188559794873285, 2.939243730583013}, {
       4.188559794873285, 2.939243730583013}}, {{4.281970242280319, 
       2.9605165660431685`}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}}, {{
       4.281970242280319, 2.9605165660431685`}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}, {
       4.281970242280319, 2.9605165660431685`}, {4.281970242280319, 
       2.9605165660431685`}}, {{4.281970242280319, 2.9605165660431685`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}, {4.281970242280319, 2.9605165660431685`}, {
       4.281970242280319, 2.9605165660431685`}}, {{4.281970242280319, 
       2.9605165660431685`}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}, {4.281970242280319, 
       2.9605165660431685`}, {4.281970242280319, 2.9605165660431685`}}, {{
       4.350816935128657, 2.939243730583013}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}, {{4.350816935128657, 2.939243730583013}, {
       4.403663097471847, 2.8902571633398852`}, {4.403663097471847, 
       2.8902571633398852`}, {4.350816935128657, 2.939243730583013}, {
       4.350816935128657, 2.939243730583013}}, {{4.350816935128657, 
       2.939243730583013}, {4.403663097471847, 2.8902571633398852`}, {
       4.403663097471847, 2.8902571633398852`}, {4.350816935128657, 
       2.939243730583013}, {4.350816935128657, 2.939243730583013}}, {{
       4.350816935128657, 2.939243730583013}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}, {
       4.350816935128657, 2.939243730583013}, {4.350816935128657, 
       2.939243730583013}}, {{4.403663097471847, 2.8902571633398852`}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}, {4.403663097471847, 2.8902571633398852`}, {
       4.403663097471847, 2.8902571633398852`}}, {{4.403663097471847, 
       2.8902571633398852`}, {4.431945505256342, 2.7987249251764466`}, {
       4.431945505256342, 2.7987249251764466`}, {4.403663097471847, 
       2.8902571633398852`}, {4.403663097471847, 2.8902571633398852`}}, {{
       4.403663097471847, 2.8902571633398852`}, {4.431945505256342, 
       2.7987249251764466`}, {4.431945505256342, 2.7987249251764466`}, {
       4.403663097471847, 2.8902571633398852`}, {4.403663097471847, 
       2.8902571633398852`}}, {{4.403663097471847, 2.8902571633398852`}, {
       4.431945505256342, 2.7987249251764466`}, {4.431945505256342, 
       2.7987249251764466`}, {4.403663097471847, 2.8902571633398852`}, {
       4.403663097471847, 2.8902571633398852`}}, {{4.161998696829344, 
       3.127081073459997}, {4.088587078065991, 3.2062767089449236`}, {
       4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.3646679799147754`}, {4.161998696829344, 3.4438636153997018`}, {
       4.161998696829344, 3.4438636153997018`}, {4.088587078065991, 
       3.3646679799147754`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}}, {{
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}, {{4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.182298199905384}, {4.3448931826928066`, 
       3.127081073459997}, {4.267289938409819, 3.103102564420458}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}, {4.267289938409819, 3.103102564420458}, {
       4.3448931826928066`, 3.127081073459997}, {4.4044608028074155`, 
       3.182298199905384}, {4.436340425624538, 3.2854723444298495`}, {
       4.436340425624538, 3.2854723444298495`}}, {{4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}}, {{
       4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}, {{4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}, {{4.161998696829344, 
       3.127081073459997}, {4.088587078065991, 3.2062767089449236`}, {
       4.088587078065991, 3.2062767089449236`}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}}, {{
       4.161998696829344, 3.127081073459997}, {4.088587078065991, 
       3.2062767089449236`}, {4.088587078065991, 3.2062767089449236`}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}}, {{4.161998696829344, 3.127081073459997}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}, {4.161998696829344, 3.127081073459997}, {
       4.161998696829344, 3.127081073459997}}, {{4.161998696829344, 
       3.127081073459997}, {4.088587078065991, 3.2062767089449236`}, {
       4.088587078065991, 3.2062767089449236`}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}}, {{
       4.088587078065991, 3.2062767089449236`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}}, {{4.088587078065991, 3.2062767089449236`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}, {4.088587078065991, 3.2062767089449236`}, {
       4.088587078065991, 3.2062767089449236`}}, {{4.088587078065991, 
       3.2062767089449236`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.2062767089449236`}, {4.088587078065991, 3.2062767089449236`}}, {{
       4.088587078065991, 3.2062767089449236`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.2062767089449236`}, {4.088587078065991, 
       3.2062767089449236`}}, {{4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}}, {{4.070551453897613, 
       3.2854723444298495`}, {4.088587078065991, 3.3646679799147754`}, {
       4.088587078065991, 3.3646679799147754`}, {4.070551453897613, 
       3.2854723444298495`}, {4.070551453897613, 3.2854723444298495`}}, {{
       4.070551453897613, 3.2854723444298495`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}, {
       4.070551453897613, 3.2854723444298495`}, {4.070551453897613, 
       3.2854723444298495`}}, {{4.070551453897613, 3.2854723444298495`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}, {4.070551453897613, 3.2854723444298495`}, {
       4.070551453897613, 3.2854723444298495`}}, {{4.088587078065991, 
       3.3646679799147754`}, {4.161998696829344, 3.4438636153997018`}, {
       4.161998696829344, 3.4438636153997018`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}}, {{
       4.088587078065991, 3.3646679799147754`}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}, {
       4.088587078065991, 3.3646679799147754`}, {4.088587078065991, 
       3.3646679799147754`}}, {{4.088587078065991, 3.3646679799147754`}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}, {4.088587078065991, 3.3646679799147754`}, {
       4.088587078065991, 3.3646679799147754`}}, {{4.088587078065991, 
       3.3646679799147754`}, {4.161998696829344, 3.4438636153997018`}, {
       4.161998696829344, 3.4438636153997018`}, {4.088587078065991, 
       3.3646679799147754`}, {4.088587078065991, 3.3646679799147754`}}, {{
       4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`, 
       3.182298199905384}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}, {{4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.182298199905384}, {4.4044608028074155`, 
       3.182298199905384}, {4.436340425624538, 3.2854723444298495`}, {
       4.436340425624538, 3.2854723444298495`}}, {{4.436340425624538, 
       3.2854723444298495`}, {4.4044608028074155`, 3.182298199905384}, {
       4.4044608028074155`, 3.182298199905384}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}}, {{
       4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`, 
       3.182298199905384}, {4.4044608028074155`, 3.182298199905384}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}}, {{4.4044608028074155`, 3.182298199905384}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.4044608028074155`, 3.182298199905384}, {
       4.4044608028074155`, 3.182298199905384}}, {{4.4044608028074155`, 
       3.182298199905384}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}, {4.4044608028074155`, 
       3.182298199905384}, {4.4044608028074155`, 3.182298199905384}}, {{
       4.4044608028074155`, 3.182298199905384}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}, {
       4.4044608028074155`, 3.182298199905384}, {4.4044608028074155`, 
       3.182298199905384}}, {{4.4044608028074155`, 3.182298199905384}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}, {4.4044608028074155`, 3.182298199905384}, {
       4.4044608028074155`, 3.182298199905384}}, {{4.3448931826928066`, 
       3.127081073459997}, {4.267289938409819, 3.103102564420458}, {
       4.267289938409819, 3.103102564420458}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}}, {{
       4.3448931826928066`, 3.127081073459997}, {4.267289938409819, 
       3.103102564420458}, {4.267289938409819, 3.103102564420458}, {
       4.3448931826928066`, 3.127081073459997}, {4.3448931826928066`, 
       3.127081073459997}}, {{4.3448931826928066`, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}, {4.3448931826928066`, 3.127081073459997}, {
       4.3448931826928066`, 3.127081073459997}}, {{4.3448931826928066`, 
       3.127081073459997}, {4.267289938409819, 3.103102564420458}, {
       4.267289938409819, 3.103102564420458}, {4.3448931826928066`, 
       3.127081073459997}, {4.3448931826928066`, 3.127081073459997}}, {{
       4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}}, {{4.267289938409819, 3.103102564420458}, {
       4.161998696829344, 3.127081073459997}, {4.161998696829344, 
       3.127081073459997}, {4.267289938409819, 3.103102564420458}, {
       4.267289938409819, 3.103102564420458}}, {{4.267289938409819, 
       3.103102564420458}, {4.161998696829344, 3.127081073459997}, {
       4.161998696829344, 3.127081073459997}, {4.267289938409819, 
       3.103102564420458}, {4.267289938409819, 3.103102564420458}}, {{
       4.267289938409819, 3.103102564420458}, {4.161998696829344, 
       3.127081073459997}, {4.161998696829344, 3.127081073459997}, {
       4.267289938409819, 3.103102564420458}, {4.267289938409819, 
       3.103102564420458}}, {{4.161998696829344, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}, {4.161998696829344, 3.4438636153997018`}, {
       4.161998696829344, 3.4438636153997018`}}, {{4.161998696829344, 
       3.4438636153997018`}, {4.267289938409819, 3.467842124439241}, {
       4.267289938409819, 3.467842124439241}, {4.161998696829344, 
       3.4438636153997018`}, {4.161998696829344, 3.4438636153997018`}}, {{
       4.161998696829344, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}, {
       4.161998696829344, 3.4438636153997018`}, {4.161998696829344, 
       3.4438636153997018`}}, {{4.161998696829344, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}, {4.161998696829344, 3.4438636153997018`}, {
       4.161998696829344, 3.4438636153997018`}}, {{4.267289938409819, 
       3.467842124439241}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}}, {{
       4.267289938409819, 3.467842124439241}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.267289938409819, 3.467842124439241}, {4.267289938409819, 
       3.467842124439241}}, {{4.267289938409819, 3.467842124439241}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.267289938409819, 3.467842124439241}, {
       4.267289938409819, 3.467842124439241}}, {{4.267289938409819, 
       3.467842124439241}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.267289938409819, 
       3.467842124439241}, {4.267289938409819, 3.467842124439241}}, {{
       4.3448931826928066`, 3.4438636153997018`}, {4.4044608028074155`, 
       3.388646488954315}, {4.4044608028074155`, 3.388646488954315}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}}, {{4.3448931826928066`, 3.4438636153997018`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}, {4.3448931826928066`, 3.4438636153997018`}, {
       4.3448931826928066`, 3.4438636153997018`}}, {{4.3448931826928066`, 
       3.4438636153997018`}, {4.4044608028074155`, 3.388646488954315}, {
       4.4044608028074155`, 3.388646488954315}, {4.3448931826928066`, 
       3.4438636153997018`}, {4.3448931826928066`, 3.4438636153997018`}}, {{
       4.3448931826928066`, 3.4438636153997018`}, {4.4044608028074155`, 
       3.388646488954315}, {4.4044608028074155`, 3.388646488954315}, {
       4.3448931826928066`, 3.4438636153997018`}, {4.3448931826928066`, 
       3.4438636153997018`}}, {{4.4044608028074155`, 3.388646488954315}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}, {4.4044608028074155`, 3.388646488954315}, {
       4.4044608028074155`, 3.388646488954315}}, {{4.4044608028074155`, 
       3.388646488954315}, {4.436340425624538, 3.2854723444298495`}, {
       4.436340425624538, 3.2854723444298495`}, {4.4044608028074155`, 
       3.388646488954315}, {4.4044608028074155`, 3.388646488954315}}, {{
       4.4044608028074155`, 3.388646488954315}, {4.436340425624538, 
       3.2854723444298495`}, {4.436340425624538, 3.2854723444298495`}, {
       4.4044608028074155`, 3.388646488954315}, {4.4044608028074155`, 
       3.388646488954315}}, {{4.4044608028074155`, 3.388646488954315}, {
       4.436340425624538, 3.2854723444298495`}, {4.436340425624538, 
       3.2854723444298495`}, {4.4044608028074155`, 3.388646488954315}, {
       4.4044608028074155`, 3.388646488954315}}, {{4.1567597612428475`, 
       3.5944577140817042`}, {4.097535360977009, 3.6583483364964784`}, {
       4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.786129581326026}, {4.1567597612428475`, 3.8500202037408}, {
       4.1567597612428475`, 3.8500202037408}, {4.097535360977009, 
       3.786129581326026}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}}, {{
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}, {{4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.639003812549751}, {4.304308833442297, 
       3.5944577140817042`}, {4.241702863450561, 3.575113190134977}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.241702863450561, 3.575113190134977}, {
       4.304308833442297, 3.5944577140817042`}, {4.352364667600148, 
       3.639003812549751}, {4.378083369542022, 3.722238958911252}, {
       4.378083369542022, 3.722238958911252}}, {{4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}}, {{
       4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.304308833442297, 3.8500202037408}, {
       4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.304308833442297, 
       3.8500202037408}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}, {{4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}}, {{4.1567597612428475`, 
       3.5944577140817042`}, {4.097535360977009, 3.6583483364964784`}, {
       4.097535360977009, 3.6583483364964784`}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}}, {{
       4.1567597612428475`, 3.5944577140817042`}, {4.097535360977009, 
       3.6583483364964784`}, {4.097535360977009, 3.6583483364964784`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}}, {{4.1567597612428475`, 3.5944577140817042`}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.1567597612428475`, 3.5944577140817042`}}, {{4.1567597612428475`, 
       3.5944577140817042`}, {4.097535360977009, 3.6583483364964784`}, {
       4.097535360977009, 3.6583483364964784`}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}}, {{
       4.097535360977009, 3.6583483364964784`}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}}, {{4.097535360977009, 3.6583483364964784`}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}, {4.097535360977009, 3.6583483364964784`}, {
       4.097535360977009, 3.6583483364964784`}}, {{4.097535360977009, 
       3.6583483364964784`}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.6583483364964784`}, {4.097535360977009, 3.6583483364964784`}}, {{
       4.097535360977009, 3.6583483364964784`}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.6583483364964784`}, {4.097535360977009, 
       3.6583483364964784`}}, {{4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}}, {{4.082985225143123, 
       3.722238958911252}, {4.097535360977009, 3.786129581326026}, {
       4.097535360977009, 3.786129581326026}, {4.082985225143123, 
       3.722238958911252}, {4.082985225143123, 3.722238958911252}}, {{
       4.082985225143123, 3.722238958911252}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}, {
       4.082985225143123, 3.722238958911252}, {4.082985225143123, 
       3.722238958911252}}, {{4.082985225143123, 3.722238958911252}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}, {4.082985225143123, 3.722238958911252}, {
       4.082985225143123, 3.722238958911252}}, {{4.097535360977009, 
       3.786129581326026}, {4.1567597612428475`, 3.8500202037408}, {
       4.1567597612428475`, 3.8500202037408}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}}, {{
       4.097535360977009, 3.786129581326026}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}, {
       4.097535360977009, 3.786129581326026}, {4.097535360977009, 
       3.786129581326026}}, {{4.097535360977009, 3.786129581326026}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}, {4.097535360977009, 3.786129581326026}, {
       4.097535360977009, 3.786129581326026}}, {{4.097535360977009, 
       3.786129581326026}, {4.1567597612428475`, 3.8500202037408}, {
       4.1567597612428475`, 3.8500202037408}, {4.097535360977009, 
       3.786129581326026}, {4.097535360977009, 3.786129581326026}}, {{
       4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}, {{4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.639003812549751}, {4.352364667600148, 
       3.639003812549751}, {4.378083369542022, 3.722238958911252}, {
       4.378083369542022, 3.722238958911252}}, {{4.378083369542022, 
       3.722238958911252}, {4.352364667600148, 3.639003812549751}, {
       4.352364667600148, 3.639003812549751}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}}, {{
       4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}}, {{4.352364667600148, 3.639003812549751}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.352364667600148, 3.639003812549751}, {
       4.352364667600148, 3.639003812549751}}, {{4.352364667600148, 
       3.639003812549751}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}, {4.352364667600148, 
       3.639003812549751}, {4.352364667600148, 3.639003812549751}}, {{
       4.352364667600148, 3.639003812549751}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}, {
       4.352364667600148, 3.639003812549751}, {4.352364667600148, 
       3.639003812549751}}, {{4.352364667600148, 3.639003812549751}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}, {4.352364667600148, 3.639003812549751}, {
       4.352364667600148, 3.639003812549751}}, {{4.304308833442297, 
       3.5944577140817042`}, {4.241702863450561, 3.575113190134977}, {
       4.241702863450561, 3.575113190134977}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}}, {{
       4.304308833442297, 3.5944577140817042`}, {4.241702863450561, 
       3.575113190134977}, {4.241702863450561, 3.575113190134977}, {
       4.304308833442297, 3.5944577140817042`}, {4.304308833442297, 
       3.5944577140817042`}}, {{4.304308833442297, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}, {4.304308833442297, 3.5944577140817042`}, {
       4.304308833442297, 3.5944577140817042`}}, {{4.304308833442297, 
       3.5944577140817042`}, {4.241702863450561, 3.575113190134977}, {
       4.241702863450561, 3.575113190134977}, {4.304308833442297, 
       3.5944577140817042`}, {4.304308833442297, 3.5944577140817042`}}, {{
       4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}}, {{4.241702863450561, 3.575113190134977}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.241702863450561, 3.575113190134977}, {
       4.241702863450561, 3.575113190134977}}, {{4.241702863450561, 
       3.575113190134977}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.1567597612428475`, 3.5944577140817042`}, {4.241702863450561, 
       3.575113190134977}, {4.241702863450561, 3.575113190134977}}, {{
       4.241702863450561, 3.575113190134977}, {4.1567597612428475`, 
       3.5944577140817042`}, {4.1567597612428475`, 3.5944577140817042`}, {
       4.241702863450561, 3.575113190134977}, {4.241702863450561, 
       3.575113190134977}}, {{4.1567597612428475`, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}, {4.1567597612428475`, 3.8500202037408}, {
       4.1567597612428475`, 3.8500202037408}}, {{4.1567597612428475`, 
       3.8500202037408}, {4.241702863450561, 3.869364727687527}, {
       4.241702863450561, 3.869364727687527}, {4.1567597612428475`, 
       3.8500202037408}, {4.1567597612428475`, 3.8500202037408}}, {{
       4.1567597612428475`, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}, {
       4.1567597612428475`, 3.8500202037408}, {4.1567597612428475`, 
       3.8500202037408}}, {{4.1567597612428475`, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}, {4.1567597612428475`, 3.8500202037408}, {
       4.1567597612428475`, 3.8500202037408}}, {{4.241702863450561, 
       3.869364727687527}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}}, {{
       4.241702863450561, 3.869364727687527}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}, {
       4.241702863450561, 3.869364727687527}, {4.241702863450561, 
       3.869364727687527}}, {{4.241702863450561, 3.869364727687527}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}, {4.241702863450561, 3.869364727687527}, {
       4.241702863450561, 3.869364727687527}}, {{4.241702863450561, 
       3.869364727687527}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}, {4.241702863450561, 
       3.869364727687527}, {4.241702863450561, 3.869364727687527}}, {{
       4.304308833442297, 3.8500202037408}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}, {{4.304308833442297, 3.8500202037408}, {
       4.352364667600148, 3.8054741052727534`}, {4.352364667600148, 
       3.8054741052727534`}, {4.304308833442297, 3.8500202037408}, {
       4.304308833442297, 3.8500202037408}}, {{4.304308833442297, 
       3.8500202037408}, {4.352364667600148, 3.8054741052727534`}, {
       4.352364667600148, 3.8054741052727534`}, {4.304308833442297, 
       3.8500202037408}, {4.304308833442297, 3.8500202037408}}, {{
       4.304308833442297, 3.8500202037408}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}, {
       4.304308833442297, 3.8500202037408}, {4.304308833442297, 
       3.8500202037408}}, {{4.352364667600148, 3.8054741052727534`}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}, {4.352364667600148, 3.8054741052727534`}, {
       4.352364667600148, 3.8054741052727534`}}, {{4.352364667600148, 
       3.8054741052727534`}, {4.378083369542022, 3.722238958911252}, {
       4.378083369542022, 3.722238958911252}, {4.352364667600148, 
       3.8054741052727534`}, {4.352364667600148, 3.8054741052727534`}}, {{
       4.352364667600148, 3.8054741052727534`}, {4.378083369542022, 
       3.722238958911252}, {4.378083369542022, 3.722238958911252}, {
       4.352364667600148, 3.8054741052727534`}, {4.352364667600148, 
       3.8054741052727534`}}, {{4.352364667600148, 3.8054741052727534`}, {
       4.378083369542022, 3.722238958911252}, {4.378083369542022, 
       3.722238958911252}, {4.352364667600148, 3.8054741052727534`}, {
       4.352364667600148, 3.8054741052727534`}}, {{
       4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}, {{
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}, {{
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}, {{
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}, {{
       4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}, {{
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}, {{
       4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}, {{
       4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}, {{
       4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}, {{
       4.374956321209035, -4.6892074627259515`}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}}, {{
       4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}, {{
       4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}, {{
       4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}, {{
       4.302566124265825, -4.611113725707604}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.611113725707604}, {
       4.302566124265825, -4.611113725707604}}, {{
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}, {{
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}, {{
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}, {{
       4.284781441029901, -4.533019988689255}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}, {
       4.284781441029901, -4.533019988689255}, {
       4.284781441029901, -4.533019988689255}}, {{
       4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}, {{
       4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}, {{
       4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}, {{
       4.302566124265825, -4.454926251670907}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}, {
       4.302566124265825, -4.454926251670907}, {
       4.302566124265825, -4.454926251670907}}, {{
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}, {{
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}, {{
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}, {{
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}}, {{
       4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}, {{
       4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}, {{
       4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}, {{
       4.614044900083693, -4.6347586067362085`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.614044900083693, -4.6347586067362085`}, {
       4.614044900083693, -4.6347586067362085`}}, {{
       4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}, {{
       4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}, {{
       4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}, {{
       4.555306081567304, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}, {
       4.555306081567304, -4.6892074627259515`}, {
       4.555306081567304, -4.6892074627259515`}}, {{
       4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}, {{
       4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}, {{
       4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}, {{
       4.478782579814991, -4.712852343754557}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.374956321209035, -4.6892074627259515`}, {
       4.478782579814991, -4.712852343754557}, {
       4.478782579814991, -4.712852343754557}}, {{
       4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}, {{
       4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}, {{
       4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}, {{
       4.374956321209035, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.374956321209035, -4.376832514652559}, {
       4.374956321209035, -4.376832514652559}}, {{
       4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}, {{
       4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}, {{
       4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}, {{
       4.478782579814991, -4.3531876336239534`}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}, {
       4.478782579814991, -4.3531876336239534`}, {
       4.478782579814991, -4.3531876336239534`}}, {{
       4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}, {{
       4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}, {{
       4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}, {{
       4.555306081567304, -4.376832514652559}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}, {
       4.555306081567304, -4.376832514652559}, {
       4.555306081567304, -4.376832514652559}}, {{
       4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}, {{
       4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}, {{
       4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}, {{
       4.614044900083693, -4.431281370642302}, {
       4.645480961746438, -4.533019988689255}, {
       4.645480961746438, -4.533019988689255}, {
       4.614044900083693, -4.431281370642302}, {
       4.614044900083693, -4.431281370642302}}, {{
       4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.450433646995931, -3.882718012404513}, {
       4.450433646995931, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}, {{
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}, {{
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.450433646995932, -4.14241486745002}, {
       4.450433646995932, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}, {{
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}, {{
       4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}, {{
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}, {{
       4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}, {{
       4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}, {{
       4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}, {{
       4.450433646995931, -4.14241486745002}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}}, {{
       4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}, {{
       4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}, {{
       4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}, {{
       4.3902511432509135`, -4.077490653688644}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -4.077490653688644}, {
       4.3902511432509135`, -4.077490653688644}}, {{
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}, {{
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}, {{
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}, {{
       4.37546562241182, -4.012566439927267}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.37546562241182, -4.012566439927267}, {
       4.37546562241182, -4.012566439927267}}, {{
       4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}, {{
       4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}, {{
       4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}, {{
       4.3902511432509135`, -3.94764222616589}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}, {
       4.3902511432509135`, -3.94764222616589}, {
       4.3902511432509135`, -3.94764222616589}}, {{
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}, {{
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}, {{
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}, {{
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}}, {{
       4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}, {{
       4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}, {{
       4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}, {{
       4.649202954182691, -4.097148123914493}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.649202954182691, -4.097148123914493}, {
       4.649202954182691, -4.097148123914493}}, {{
       4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}, {{
       4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}, {{
       4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}, {{
       4.6003696961641545`, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}, {
       4.6003696961641545`, -4.14241486745002}, {
       4.6003696961641545`, -4.14241486745002}}, {{
       4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}, {{
       4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}, {{
       4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}, {{
       4.536750917306524, -4.16207233767587}, {
       4.450433646995931, -4.14241486745002}, {
       4.450433646995931, -4.14241486745002}, {
       4.536750917306524, -4.16207233767587}, {
       4.536750917306524, -4.16207233767587}}, {{
       4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}, {{
       4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}, {{
       4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}, {{
       4.450433646995932, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}, {
       4.450433646995932, -3.882718012404513}, {
       4.450433646995932, -3.882718012404513}}, {{
       4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}, {{
       4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}, {{
       4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}, {{
       4.536750917306524, -3.863060542178664}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.536750917306524, -3.863060542178664}, {
       4.536750917306524, -3.863060542178664}}, {{
       4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}, {{
       4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}, {{
       4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}, {{
       4.6003696961641545`, -3.882718012404513}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.6003696961641545`, -3.882718012404513}, {
       4.6003696961641545`, -3.882718012404513}}, {{
       4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}, {{
       4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}, {{
       4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}, {{
       4.649202954182691, -3.9279847559400407`}, {
       4.675337720748265, -4.012566439927267}, {
       4.675337720748265, -4.012566439927267}, {
       4.649202954182691, -3.9279847559400407`}, {
       4.649202954182691, -3.9279847559400407`}}, {{
       4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}, {{
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}, {{
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}, {{
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}, {{
       4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}, {{
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}, {{
       4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}, {{
       4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}, {{
       4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}, {{
       4.410337490011708, -3.6013776479881794`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}}, {{
       4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}, {{
       4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}, {{
       4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}, {{
       4.343761301667702, -3.529555998596902}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.529555998596902}, {
       4.343761301667702, -3.529555998596902}}, {{
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}, {{
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}, {{
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}, {{
       4.327404992792314, -3.4577343492056243`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.327404992792314, -3.4577343492056243`}, {
       4.327404992792314, -3.4577343492056243`}}, {{
       4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}, {{
       4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}, {{
       4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}, {{
       4.343761301667702, -3.3859126998143467`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}, {
       4.343761301667702, -3.3859126998143467`}, {
       4.343761301667702, -3.3859126998143467`}}, {{
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}, {{
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}, {{
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}, {{
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}}, {{
       4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}, {{
       4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}, {{
       4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}, {{
       4.630223702927347, -3.5513018442943096`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.630223702927347, -3.5513018442943096`}, {
       4.630223702927347, -3.5513018442943096`}}, {{
       4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}, {{
       4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}, {{
       4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}, {{
       4.576202484450496, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}, {
       4.576202484450496, -3.6013776479881794`}, {
       4.576202484450496, -3.6013776479881794`}}, {{
       4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}, {{
       4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}, {{
       4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}, {{
       4.505824957098256, -3.623123493685587}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.410337490011708, -3.6013776479881794`}, {
       4.505824957098256, -3.623123493685587}, {
       4.505824957098256, -3.623123493685587}}, {{
       4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}, {{
       4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}, {{
       4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}, {{
       4.410337490011708, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.410337490011708, -3.314091050423069}, {
       4.410337490011708, -3.314091050423069}}, {{
       4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}, {{
       4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}, {{
       4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}, {{
       4.505824957098256, -3.2923452047256614`}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}, {
       4.505824957098256, -3.2923452047256614`}, {
       4.505824957098256, -3.2923452047256614`}}, {{
       4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}, {{
       4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}, {{
       4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}, {{
       4.576202484450496, -3.314091050423069}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}, {
       4.576202484450496, -3.314091050423069}, {
       4.576202484450496, -3.314091050423069}}, {{
       4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}, {{
       4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}, {{
       4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}, {{
       4.630223702927347, -3.364166854116939}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.65913498166989, -3.4577343492056243`}, {
       4.630223702927347, -3.364166854116939}, {
       4.630223702927347, -3.364166854116939}}, {{
       4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}, {{
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}, {{
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}, {{
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}, {{
       4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}, {{
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}, {{
       4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}, {{
       4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}, {{
       4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}, {{
       4.386494227817664, -3.099976566253492}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}}, {{
       4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}, {{
       4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}, {{
       4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}, {{
       4.327519587588848, -3.0363553821808225`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -3.0363553821808225`}, {
       4.327519587588848, -3.0363553821808225`}}, {{
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}, {{
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}, {{
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}, {{
       4.313030812316627, -2.9727341981081525`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.313030812316627, -2.9727341981081525`}, {
       4.313030812316627, -2.9727341981081525`}}, {{
       4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}, {{
       4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}, {{
       4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}, {{
       4.327519587588848, -2.9091130140354826`}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}, {
       4.327519587588848, -2.9091130140354826`}, {
       4.327519587588848, -2.9091130140354826`}}, {{
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}, {{
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}, {{
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}, {{
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}}, {{
       4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}, {{
       4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}, {{
       4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}, {{
       4.581274232809406, -3.0556183267616897`}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}, {
       4.581274232809406, -3.0556183267616897`}, {
       4.581274232809406, -3.0556183267616897`}}, {{
       4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}, {{
       4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}, {{
       4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}, {{
       4.533421058819739, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}, {
       4.533421058819739, -3.099976566253492}, {
       4.533421058819739, -3.099976566253492}}, {{
       4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}, {{
       4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}, {{
       4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}, {{
       4.47107910955785, -3.119239510834359}, {
       4.386494227817664, -3.099976566253492}, {
       4.386494227817664, -3.099976566253492}, {
       4.47107910955785, -3.119239510834359}, {
       4.47107910955785, -3.119239510834359}}, {{
       4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}, {{
       4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}, {{
       4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}, {{
       4.386494227817664, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}, {
       4.386494227817664, -2.845491829962813}, {
       4.386494227817664, -2.845491829962813}}, {{
       4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}, {{
       4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}, {{
       4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}, {{
       4.47107910955785, -2.826228885381946}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}, {
       4.47107910955785, -2.826228885381946}, {
       4.47107910955785, -2.826228885381946}}, {{
       4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}, {{
       4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}, {{
       4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}, {{
       4.533421058819739, -2.845491829962813}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.533421058819739, -2.845491829962813}, {
       4.533421058819739, -2.845491829962813}}, {{
       4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}, {{
       4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}, {{
       4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}, {{
       4.581274232809406, -2.8898500694546154`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.606884474320776, -2.9727341981081525`}, {
       4.581274232809406, -2.8898500694546154`}, {
       4.581274232809406, -2.8898500694546154`}}, {{
       4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}, {{
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}, {{
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}, {{
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}, {{
       4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}, {{
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}, {{
       4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}, {{
       4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}, {{
       4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}, {{
       4.419711960085248, -2.65149192621873}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}}, {{
       4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}, {{
       4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}, {{
       4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}, {{
       4.359650308988962, -2.586698086946809}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.586698086946809}, {
       4.359650308988962, -2.586698086946809}}, {{
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}, {{
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}, {{
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}, {{
       4.344894478994301, -2.5219042476748874`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}, {
       4.344894478994301, -2.5219042476748874`}, {
       4.344894478994301, -2.5219042476748874`}}, {{
       4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}, {{
       4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}, {{
       4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}, {{
       4.359650308988962, -2.457110408402966}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.359650308988962, -2.457110408402966}, {
       4.359650308988962, -2.457110408402966}}, {{
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}, {{
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}, {{
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}, {{
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}}, {{
       4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}, {{
       4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}, {{
       4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}, {{
       4.6180821180880205`, -2.606316082953469}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}, {
       4.6180821180880205`, -2.606316082953469}, {
       4.6180821180880205`, -2.606316082953469}}, {{
       4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}, {{
       4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}, {{
       4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}, {{
       4.56934692226714, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.56934692226714, -2.65149192621873}, {
       4.56934692226714, -2.65149192621873}}, {{
       4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}, {{
       4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}, {{
       4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}, {{
       4.5058558964516005`, -2.6711099222253907`}, {
       4.419711960085248, -2.65149192621873}, {
       4.419711960085248, -2.65149192621873}, {
       4.5058558964516005`, -2.6711099222253907`}, {
       4.5058558964516005`, -2.6711099222253907`}}, {{
       4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}, {{
       4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}, {{
       4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}, {{
       4.419711960085248, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.419711960085248, -2.3923165691310446`}, {
       4.419711960085248, -2.3923165691310446`}}, {{
       4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}, {{
       4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}, {{
       4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}, {{
       4.5058558964516005`, -2.372698573124384}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.5058558964516005`, -2.372698573124384}, {
       4.5058558964516005`, -2.372698573124384}}, {{
       4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}, {{
       4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}, {{
       4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}, {{
       4.56934692226714, -2.3923165691310446`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.56934692226714, -2.3923165691310446`}, {
       4.56934692226714, -2.3923165691310446`}}, {{
       4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}, {{
       4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}, {{
       4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}, {{
       4.6180821180880205`, -2.4374924123963058`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.644164403358087, -2.5219042476748874`}, {
       4.6180821180880205`, -2.4374924123963058`}, {
       4.6180821180880205`, -2.4374924123963058`}}, {{
       4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.8738891877655433`}, {
       4.416001624487471, -1.8738891877655433`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}, {{
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}, {{
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}, {{
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}, {{
       4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}, {{
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}, {{
       4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}, {{
       4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}, {{
       4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}, {{
       4.416001624487471, -2.161016756825512}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}}, {{
       4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}, {{
       4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}, {{
       4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}, {{
       4.349462289626364, -2.08923486456052}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -2.08923486456052}, {
       4.349462289626364, -2.08923486456052}}, {{
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}, {{
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}, {{
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}, {{
       4.333115034843203, -2.0174529722955277`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.333115034843203, -2.0174529722955277`}, {
       4.333115034843203, -2.0174529722955277`}}, {{
       4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}, {{
       4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}, {{
       4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}, {{
       4.349462289626364, -1.9456710800305355`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}, {
       4.349462289626364, -1.9456710800305355`}, {
       4.349462289626364, -1.9456710800305355`}}, {{
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}, {{
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}, {{
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}, {{
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}}, {{
       4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}, {{
       4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}, {{
       4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}, {{
       4.635766118617628, -2.1109686727686623`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}, {
       4.635766118617628, -2.1109686727686623`}, {
       4.635766118617628, -2.1109686727686623`}}, {{
       4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}, {{
       4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}, {{
       4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}, {{
       4.581774803776007, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.581774803776007, -2.161016756825512}, {
       4.581774803776007, -2.161016756825512}}, {{
       4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}, {{
       4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}, {{
       4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}, {{
       4.511436234151225, -2.1827505650336545`}, {
       4.416001624487471, -2.161016756825512}, {
       4.416001624487471, -2.161016756825512}, {
       4.511436234151225, -2.1827505650336545`}, {
       4.511436234151225, -2.1827505650336545`}}, {{
       4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}, {{
       4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}, {{
       4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}, {{
       4.416001624487471, -1.873889187765543}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.416001624487471, -1.873889187765543}, {
       4.416001624487471, -1.873889187765543}}, {{
       4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}, {{
       4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}, {{
       4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}, {{
       4.511436234151225, -1.8521553795574008`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.511436234151225, -1.8521553795574008`}, {
       4.511436234151225, -1.8521553795574008`}}, {{
       4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}, {{
       4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}, {{
       4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}, {{
       4.581774803776007, -1.8738891877655433`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}, {
       4.581774803776007, -1.8738891877655433`}, {
       4.581774803776007, -1.8738891877655433`}}, {{
       4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}, {{
       4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}, {{
       4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}, {{
       4.635766118617628, -1.923937271822393}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.664661393420275, -2.0174529722955277`}, {
       4.635766118617628, -1.923937271822393}, {
       4.635766118617628, -1.923937271822393}}, {{
       4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826337, -1.361074581946569}, {
       4.465432820826337, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}, {{
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}, {{
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.465432820826338, -1.622304792118444}, {
       4.465432820826338, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}, {{
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}, {{
       4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}, {{
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}, {{
       4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}, {{
       4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}, {{
       4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}, {{
       4.465432820826337, -1.622304792118444}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}}, {{
       4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}, {{
       4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}, {{
       4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}, {{
       4.4048949752708895`, -1.5569972395754752`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.5569972395754752`}, {
       4.4048949752708895`, -1.5569972395754752`}}, {{
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}, {{
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}, {{
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}, {{
       4.390022154744741, -1.4916896870325065`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.390022154744741, -1.4916896870325065`}, {
       4.390022154744741, -1.4916896870325065`}}, {{
       4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}, {{
       4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}, {{
       4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}, {{
       4.4048949752708895`, -1.4263821344895378`}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}, {
       4.4048949752708895`, -1.4263821344895378`}, {
       4.4048949752708895`, -1.4263821344895378`}}, {{
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}, {{
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}, {{
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}, {{
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}}, {{
       4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}, {{
       4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}, {{
       4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}, {{
       4.665375742287656, -1.5767707754453881`}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}, {
       4.665375742287656, -1.5767707754453881`}, {
       4.665375742287656, -1.5767707754453881`}}, {{
       4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}, {{
       4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}, {{
       4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}, {{
       4.616254152989533, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}, {
       4.616254152989533, -1.622304792118444}, {
       4.616254152989533, -1.622304792118444}}, {{
       4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}, {{
       4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}, {{
       4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}, {{
       4.55225974316526, -1.642078327988357}, {
       4.465432820826337, -1.622304792118444}, {
       4.465432820826337, -1.622304792118444}, {
       4.55225974316526, -1.642078327988357}, {
       4.55225974316526, -1.642078327988357}}, {{
       4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}, {{
       4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}, {{
       4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}, {{
       4.465432820826338, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}, {
       4.465432820826338, -1.361074581946569}, {
       4.465432820826338, -1.361074581946569}}, {{
       4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}, {{
       4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}, {{
       4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}, {{
       4.55225974316526, -1.341301046076656}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}, {
       4.55225974316526, -1.341301046076656}, {
       4.55225974316526, -1.341301046076656}}, {{
       4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}, {{
       4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}, {{
       4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}, {{
       4.616254152989533, -1.361074581946569}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.616254152989533, -1.361074581946569}, {
       4.616254152989533, -1.361074581946569}}, {{
       4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}, {{
       4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}, {{
       4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}, {{
       4.665375742287656, -1.4066085986196248`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.691664819071129, -1.4916896870325065`}, {
       4.665375742287656, -1.4066085986196248`}, {
       4.665375742287656, -1.4066085986196248`}}, {{
       4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}, {{
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}, {{
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}, {{
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}, {{
       4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}, {{
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}, {{
       4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}, {{
       4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}, {{
       4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}, {{
       4.435675882358271, -1.1019071369711109`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}}, {{
       4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}, {{
       4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}, {{
       4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}, {{
       4.373718584649903, -1.0350682952782158`}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -1.0350682952782158`}, {
       4.373718584649903, -1.0350682952782158`}}, {{
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}, {{
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}, {{
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}, {{
       4.358497035870839, -0.9682294535853206}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}, {
       4.358497035870839, -0.9682294535853206}, {
       4.358497035870839, -0.9682294535853206}}, {{
       4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}, {{
       4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}, {{
       4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}, {{
       4.373718584649903, -0.9013906118924255}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}, {
       4.373718584649903, -0.9013906118924255}, {
       4.373718584649903, -0.9013906118924255}}, {{
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}, {{
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}, {{
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}, {{
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}}, {{
       4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}, {{
       4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}, {{
       4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}, {{
       4.640306935809175, -1.05530546819705}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.640306935809175, -1.05530546819705}, {
       4.640306935809175, -1.05530546819705}}, {{
       4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}, {{
       4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}, {{
       4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}, {{
       4.590033575333133, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}, {
       4.590033575333133, -1.1019071369711109`}, {
       4.590033575333133, -1.1019071369711109`}}, {{
       4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}, {{
       4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}, {{
       4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}, {{
       4.524538666078028, -1.122144309889945}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.435675882358271, -1.1019071369711109`}, {
       4.524538666078028, -1.122144309889945}, {
       4.524538666078028, -1.122144309889945}}, {{
       4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}, {{
       4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}, {{
       4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}, {{
       4.435675882358271, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}, {
       4.435675882358271, -0.8345517701995304}, {
       4.435675882358271, -0.8345517701995304}}, {{
       4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}, {{
       4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}, {{
       4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}, {{
       4.524538666078028, -0.8143145972806962}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}, {
       4.524538666078028, -0.8143145972806962}, {
       4.524538666078028, -0.8143145972806962}}, {{
       4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}, {{
       4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}, {{
       4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}, {{
       4.590033575333133, -0.8345517701995304}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}, {
       4.590033575333133, -0.8345517701995304}, {
       4.590033575333133, -0.8345517701995304}}, {{
       4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}, {{
       4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}, {{
       4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}, {{
       4.640306935809175, -0.8811534389735913}, {
       4.667212421820565, -0.9682294535853206}, {
       4.667212421820565, -0.9682294535853206}, {
       4.640306935809175, -0.8811534389735913}, {
       4.640306935809175, -0.8811534389735913}}, {{
       4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}, {{
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}, {{
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}, {{
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}, {{
       4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}, {{
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}, {{
       4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}, {{
       4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}, {{
       4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}, {{
       4.4220962105142645`, -0.6789961483482665}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}}, {{
       4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}, {{
       4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}, {{
       4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}, {{
       4.358125761007042, -0.6099855409495653}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.6099855409495653}, {
       4.358125761007042, -0.6099855409495653}}, {{
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}, {{
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}, {{
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}, {{
       4.342409624997106, -0.540974933550864}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.342409624997106, -0.540974933550864}, {
       4.342409624997106, -0.540974933550864}}, {{
       4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}, {{
       4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}, {{
       4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}, {{
       4.358125761007042, -0.47196432615216277`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.358125761007042, -0.47196432615216277`}, {
       4.358125761007042, -0.47196432615216277`}}, {{
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}, {{
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}, {{
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}, {{
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}}, {{
       4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}, {{
       4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}, {{
       4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}, {{
       4.633376252681485, -0.6308802716149793}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}, {
       4.633376252681485, -0.6308802716149793}, {
       4.633376252681485, -0.6308802716149793}}, {{
       4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}, {{
       4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}, {{
       4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}, {{
       4.581469381548584, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.581469381548584, -0.6789961483482665}, {
       4.581469381548584, -0.6789961483482665}}, {{
       4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}, {{
       4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}, {{
       4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}, {{
       4.5138463744057455`, -0.6998908790136805}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.4220962105142645`, -0.6789961483482665}, {
       4.5138463744057455`, -0.6998908790136805}, {
       4.5138463744057455`, -0.6998908790136805}}, {{
       4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}, {{
       4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}, {{
       4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}, {{
       4.4220962105142645`, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.4220962105142645`, -0.40295371875346153`}, {
       4.4220962105142645`, -0.40295371875346153`}}, {{
       4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}, {{
       4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}, {{
       4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}, {{
       4.5138463744057455`, -0.3820589880880475}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.5138463744057455`, -0.3820589880880475}, {
       4.5138463744057455`, -0.3820589880880475}}, {{
       4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}, {{
       4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}, {{
       4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}, {{
       4.581469381548584, -0.40295371875346153`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.581469381548584, -0.40295371875346153`}, {
       4.581469381548584, -0.40295371875346153`}}, {{
       4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}, {{
       4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}, {{
       4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}, {{
       4.633376252681485, -0.45106959548674874`}, {
       4.661155967065743, -0.540974933550864}, {
       4.661155967065743, -0.540974933550864}, {
       4.633376252681485, -0.45106959548674874`}, {
       4.633376252681485, -0.45106959548674874`}}, {{
       4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.405230586241278, 0.09930782547216266}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.033216582995696686`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}, {{4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}}, {{
       4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}, {{
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}, {{4.466653360941616, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.619679366747845, 0.1655700297060923}, {4.669519004823792, 
       0.11937040661661835`}, {4.6961923696509595`, 0.033045621238233}, {
       4.6961923696509595`, 0.033045621238233}, {4.669519004823792, 
       0.11937040661661835`}, {4.619679366747845, 0.1655700297060923}, {
       4.5547495004691205`, 0.18563261085054802`}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}}, {{
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}, {{4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}, {{
       4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}, {{
       4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}, {{
       4.466653360941616, -0.09947878722962633}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}}, {{
       4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}, {{
       4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}, {{
       4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}, {{
       4.405230586241278, -0.03321658299569667}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, -0.03321658299569667}, {
       4.405230586241278, -0.03321658299569667}}, {{4.390140358038502, 
       0.033045621238232986`}, {4.405230586241278, 0.09930782547216264}, {
       4.405230586241278, 0.09930782547216264}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}}, {{
       4.390140358038502, 0.033045621238232986`}, {4.405230586241278, 
       0.09930782547216264}, {4.405230586241278, 0.09930782547216264}, {
       4.390140358038502, 0.033045621238232986`}, {4.390140358038502, 
       0.033045621238232986`}}, {{4.390140358038502, 0.033045621238232986`}, {
       4.405230586241278, 0.09930782547216264}, {4.405230586241278, 
       0.09930782547216264}, {4.390140358038502, 0.033045621238232986`}, {
       4.390140358038502, 0.033045621238232986`}}, {{4.390140358038502, 
       0.033045621238232986`}, {4.405230586241278, 0.09930782547216264}, {
       4.405230586241278, 0.09930782547216264}, {4.390140358038502, 
       0.033045621238232986`}, {4.390140358038502, 0.033045621238232986`}}, {{
       4.405230586241278, 0.09930782547216266}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}, {
       4.405230586241278, 0.09930782547216266}, {4.405230586241278, 
       0.09930782547216266}}, {{4.405230586241278, 0.09930782547216266}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}, {4.405230586241278, 0.09930782547216266}, {
       4.405230586241278, 0.09930782547216266}}, {{4.405230586241278, 
       0.09930782547216266}, {4.466653360941616, 0.1655700297060923}, {
       4.466653360941616, 0.1655700297060923}, {4.405230586241278, 
       0.09930782547216266}, {4.405230586241278, 0.09930782547216266}}, {{
       4.405230586241278, 0.09930782547216266}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}, {
       4.405230586241278, 0.09930782547216266}, {4.405230586241278, 
       0.09930782547216266}}, {{4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}, {{
       4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}, {{
       4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}, {{
       4.6961923696509595`, 0.03304562123823297}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}, {4.6961923696509595`, 
       0.03304562123823297}, {4.6961923696509595`, 0.03304562123823297}}, {{
       4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}, {{
       4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}, {{
       4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}, {{
       4.669519004823792, -0.05327916414015238}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}, {
       4.669519004823792, -0.05327916414015238}, {
       4.669519004823792, -0.05327916414015238}}, {{
       4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}, {{
       4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}, {{
       4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}, {{
       4.619679366747845, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.619679366747845, -0.09947878722962633}, {
       4.619679366747845, -0.09947878722962633}}, {{
       4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}, {{
       4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}, {{
       4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}, {{
       4.5547495004691205`, -0.11954136837408205`}, {
       4.466653360941616, -0.09947878722962633}, {
       4.466653360941616, -0.09947878722962633}, {
       4.5547495004691205`, -0.11954136837408205`}, {
       4.5547495004691205`, -0.11954136837408205`}}, {{4.466653360941616, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}}, {{
       4.466653360941616, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.466653360941616, 0.1655700297060923}, {4.466653360941616, 
       0.1655700297060923}}, {{4.466653360941616, 0.1655700297060923}, {
       4.5547495004691205`, 0.18563261085054802`}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.466653360941616, 0.1655700297060923}, {
       4.466653360941616, 0.1655700297060923}}, {{4.466653360941616, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}, {4.466653360941616, 
       0.1655700297060923}, {4.466653360941616, 0.1655700297060923}}, {{
       4.5547495004691205`, 0.18563261085054802`}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.5547495004691205`, 0.18563261085054802`}, {4.5547495004691205`, 
       0.18563261085054802`}}, {{4.5547495004691205`, 0.18563261085054802`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}, {4.5547495004691205`, 0.18563261085054802`}, {
       4.5547495004691205`, 0.18563261085054802`}}, {{4.5547495004691205`, 
       0.18563261085054802`}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}, {4.5547495004691205`, 
       0.18563261085054802`}, {4.5547495004691205`, 0.18563261085054802`}}, {{
       4.5547495004691205`, 0.18563261085054802`}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}, {
       4.5547495004691205`, 0.18563261085054802`}, {4.5547495004691205`, 
       0.18563261085054802`}}, {{4.619679366747845, 0.1655700297060923}, {
       4.669519004823792, 0.11937040661661835`}, {4.669519004823792, 
       0.11937040661661835`}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}}, {{4.619679366747845, 
       0.1655700297060923}, {4.669519004823792, 0.11937040661661835`}, {
       4.669519004823792, 0.11937040661661835`}, {4.619679366747845, 
       0.1655700297060923}, {4.619679366747845, 0.1655700297060923}}, {{
       4.619679366747845, 0.1655700297060923}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}, {
       4.619679366747845, 0.1655700297060923}, {4.619679366747845, 
       0.1655700297060923}}, {{4.619679366747845, 0.1655700297060923}, {
       4.669519004823792, 0.11937040661661835`}, {4.669519004823792, 
       0.11937040661661835`}, {4.619679366747845, 0.1655700297060923}, {
       4.619679366747845, 0.1655700297060923}}, {{4.669519004823792, 
       0.11937040661661835`}, {4.6961923696509595`, 0.03304562123823296}, {
       4.6961923696509595`, 0.03304562123823296}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}}, {{
       4.669519004823792, 0.11937040661661835`}, {4.6961923696509595`, 
       0.03304562123823296}, {4.6961923696509595`, 0.03304562123823296}, {
       4.669519004823792, 0.11937040661661835`}, {4.669519004823792, 
       0.11937040661661835`}}, {{4.669519004823792, 0.11937040661661835`}, {
       4.6961923696509595`, 0.03304562123823296}, {4.6961923696509595`, 
       0.03304562123823296}, {4.669519004823792, 0.11937040661661835`}, {
       4.669519004823792, 0.11937040661661835`}}, {{4.669519004823792, 
       0.11937040661661835`}, {4.6961923696509595`, 0.03304562123823296}, {
       4.6961923696509595`, 0.03304562123823296}, {4.669519004823792, 
       0.11937040661661835`}, {4.669519004823792, 0.11937040661661835`}}, {{
       4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176955}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}, {{4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}, {{4.683541021973973, 
       0.47355272201928644`}, {4.659974112421801, 0.3972815645442097}, {
       4.615938939122161, 0.35646247982246826`}, {4.5585709881440835`, 
       0.3387364434458006}, {4.480734773418538, 0.35646247982246826`}, {
       4.480734773418538, 0.35646247982246826`}, {4.5585709881440835`, 
       0.3387364434458006}, {4.615938939122161, 0.35646247982246826`}, {
       4.659974112421801, 0.3972815645442097}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}}, {{
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}}, {{4.480734773418538, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.659974112421801, 0.5498238794943632}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}, {4.659974112421801, 0.5498238794943632}, {
       4.615938939122161, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.480734773418538, 0.5906429642161046}, {
       4.480734773418538, 0.5906429642161046}}, {{4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}}, {{
       4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}, {{4.480734773418538, 0.35646247982246826`}, {
       4.426465468245164, 0.41500760092087735`}, {4.426465468245164, 
       0.41500760092087735`}, {4.480734773418538, 0.35646247982246826`}, {
       4.480734773418538, 0.35646247982246826`}}, {{4.480734773418538, 
       0.35646247982246826`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}}, {{
       4.480734773418538, 0.35646247982246826`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}}, {{4.426465468245164, 0.41500760092087735`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}}, {{4.426465468245164, 
       0.41500760092087735`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.426465468245164, 
       0.41500760092087735`}, {4.426465468245164, 0.41500760092087735`}}, {{
       4.426465468245164, 0.41500760092087735`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.41500760092087735`}, {4.426465468245164, 
       0.41500760092087735`}}, {{4.426465468245164, 0.41500760092087735`}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.41500760092087735`}, {
       4.426465468245164, 0.41500760092087735`}}, {{4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.5320978431176955}, {
       4.426465468245164, 0.5320978431176955}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}}, {{
       4.4131326905667265`, 0.47355272201928644`}, {4.426465468245164, 
       0.5320978431176955}, {4.426465468245164, 0.5320978431176955}, {
       4.4131326905667265`, 0.47355272201928644`}, {4.4131326905667265`, 
       0.47355272201928644`}}, {{4.4131326905667265`, 0.47355272201928644`}, {
       4.426465468245164, 0.5320978431176955}, {4.426465468245164, 
       0.5320978431176955}, {4.4131326905667265`, 0.47355272201928644`}, {
       4.4131326905667265`, 0.47355272201928644`}}, {{4.4131326905667265`, 
       0.47355272201928644`}, {4.426465468245164, 0.5320978431176955}, {
       4.426465468245164, 0.5320978431176955}, {4.4131326905667265`, 
       0.47355272201928644`}, {4.4131326905667265`, 0.47355272201928644`}}, {{
       4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176956}, {4.426465468245164, 
       0.5320978431176956}}, {{4.426465468245164, 0.5320978431176956}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}, {4.426465468245164, 0.5320978431176956}, {
       4.426465468245164, 0.5320978431176956}}, {{4.426465468245164, 
       0.5320978431176956}, {4.480734773418538, 0.5906429642161046}, {
       4.480734773418538, 0.5906429642161046}, {4.426465468245164, 
       0.5320978431176956}, {4.426465468245164, 0.5320978431176956}}, {{
       4.426465468245164, 0.5320978431176956}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}, {
       4.426465468245164, 0.5320978431176956}, {4.426465468245164, 
       0.5320978431176956}}, {{4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}, {4.683541021973973, 0.47355272201928644`}, {
       4.683541021973973, 0.47355272201928644`}}, {{4.683541021973973, 
       0.47355272201928644`}, {4.659974112421801, 0.3972815645442097}, {
       4.659974112421801, 0.3972815645442097}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}}, {{
       4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}}, {{4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}, {4.683541021973973, 0.47355272201928644`}, {
       4.683541021973973, 0.47355272201928644`}}, {{4.659974112421801, 
       0.3972815645442097}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}}, {{
       4.659974112421801, 0.3972815645442097}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}, {
       4.659974112421801, 0.3972815645442097}, {4.659974112421801, 
       0.3972815645442097}}, {{4.659974112421801, 0.3972815645442097}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}, {4.659974112421801, 0.3972815645442097}, {
       4.659974112421801, 0.3972815645442097}}, {{4.659974112421801, 
       0.3972815645442097}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}, {4.659974112421801, 
       0.3972815645442097}, {4.659974112421801, 0.3972815645442097}}, {{
       4.615938939122161, 0.35646247982246826`}, {4.5585709881440835`, 
       0.3387364434458006}, {4.5585709881440835`, 0.3387364434458006}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}}, {{4.615938939122161, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}, {4.615938939122161, 0.35646247982246826`}, {
       4.615938939122161, 0.35646247982246826`}}, {{4.615938939122161, 
       0.35646247982246826`}, {4.5585709881440835`, 0.3387364434458006}, {
       4.5585709881440835`, 0.3387364434458006}, {4.615938939122161, 
       0.35646247982246826`}, {4.615938939122161, 0.35646247982246826`}}, {{
       4.615938939122161, 0.35646247982246826`}, {4.5585709881440835`, 
       0.3387364434458006}, {4.5585709881440835`, 0.3387364434458006}, {
       4.615938939122161, 0.35646247982246826`}, {4.615938939122161, 
       0.35646247982246826`}}, {{4.5585709881440835`, 0.3387364434458006}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}, {4.5585709881440835`, 0.3387364434458006}, {
       4.5585709881440835`, 0.3387364434458006}}, {{4.5585709881440835`, 
       0.3387364434458006}, {4.480734773418538, 0.35646247982246826`}, {
       4.480734773418538, 0.35646247982246826`}, {4.5585709881440835`, 
       0.3387364434458006}, {4.5585709881440835`, 0.3387364434458006}}, {{
       4.5585709881440835`, 0.3387364434458006}, {4.480734773418538, 
       0.35646247982246826`}, {4.480734773418538, 0.35646247982246826`}, {
       4.5585709881440835`, 0.3387364434458006}, {4.5585709881440835`, 
       0.3387364434458006}}, {{4.5585709881440835`, 0.3387364434458006}, {
       4.480734773418538, 0.35646247982246826`}, {4.480734773418538, 
       0.35646247982246826`}, {4.5585709881440835`, 0.3387364434458006}, {
       4.5585709881440835`, 0.3387364434458006}}, {{4.480734773418538, 
       0.5906429642161046}, {4.5585709881440835`, 0.6083690005927722}, {
       4.5585709881440835`, 0.6083690005927722}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}}, {{
       4.480734773418538, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.5585709881440835`, 0.6083690005927722}, {
       4.480734773418538, 0.5906429642161046}, {4.480734773418538, 
       0.5906429642161046}}, {{4.480734773418538, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}, {4.480734773418538, 0.5906429642161046}, {
       4.480734773418538, 0.5906429642161046}}, {{4.480734773418538, 
       0.5906429642161046}, {4.5585709881440835`, 0.6083690005927722}, {
       4.5585709881440835`, 0.6083690005927722}, {4.480734773418538, 
       0.5906429642161046}, {4.480734773418538, 0.5906429642161046}}, {{
       4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}}, {{4.5585709881440835`, 0.6083690005927722}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}, {4.5585709881440835`, 0.6083690005927722}, {
       4.5585709881440835`, 0.6083690005927722}}, {{4.5585709881440835`, 
       0.6083690005927722}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}, {4.5585709881440835`, 
       0.6083690005927722}, {4.5585709881440835`, 0.6083690005927722}}, {{
       4.5585709881440835`, 0.6083690005927722}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}, {
       4.5585709881440835`, 0.6083690005927722}, {4.5585709881440835`, 
       0.6083690005927722}}, {{4.615938939122161, 0.5906429642161046}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}}, {{4.615938939122161, 
       0.5906429642161046}, {4.659974112421801, 0.5498238794943632}, {
       4.659974112421801, 0.5498238794943632}, {4.615938939122161, 
       0.5906429642161046}, {4.615938939122161, 0.5906429642161046}}, {{
       4.615938939122161, 0.5906429642161046}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}, {
       4.615938939122161, 0.5906429642161046}, {4.615938939122161, 
       0.5906429642161046}}, {{4.615938939122161, 0.5906429642161046}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}, {4.615938939122161, 0.5906429642161046}, {
       4.615938939122161, 0.5906429642161046}}, {{4.659974112421801, 
       0.5498238794943632}, {4.683541021973973, 0.47355272201928644`}, {
       4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}}, {{
       4.659974112421801, 0.5498238794943632}, {4.683541021973973, 
       0.47355272201928644`}, {4.683541021973973, 0.47355272201928644`}, {
       4.659974112421801, 0.5498238794943632}, {4.659974112421801, 
       0.5498238794943632}}, {{4.659974112421801, 0.5498238794943632}, {
       4.683541021973973, 0.47355272201928644`}, {4.683541021973973, 
       0.47355272201928644`}, {4.659974112421801, 0.5498238794943632}, {
       4.659974112421801, 0.5498238794943632}}, {{4.659974112421801, 
       0.5498238794943632}, {4.683541021973973, 0.47355272201928644`}, {
       4.683541021973973, 0.47355272201928644`}, {4.659974112421801, 
       0.5498238794943632}, {4.659974112421801, 0.5498238794943632}}, {{
       4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.334579078046893, 
       1.010806662326981}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}, {{4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}}, {{4.690685054957424, 
       1.010806662326981}, {4.659649334626015, 0.910363695568482}, {
       4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.423605572274526, 0.8566082511049836}, {
       4.423605572274526, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.601658560729791, 0.8566082511049836}, {
       4.659649334626015, 0.910363695568482}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}}, {{
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}, {{4.423605572274526, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.659649334626015, 1.1112496290854799`}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}, {4.659649334626015, 1.1112496290854799`}, {
       4.601658560729791, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.423605572274526, 1.1650050735489783`}, {
       4.423605572274526, 1.1650050735489783`}}, {{4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}}, {{
       4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}, {{4.423605572274526, 0.8566082511049836}, {
       4.352137271595894, 0.9337074567159822}, {4.352137271595894, 
       0.9337074567159822}, {4.423605572274526, 0.8566082511049836}, {
       4.423605572274526, 0.8566082511049836}}, {{4.423605572274526, 
       0.8566082511049836}, {4.352137271595894, 0.9337074567159822}, {
       4.352137271595894, 0.9337074567159822}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}}, {{
       4.423605572274526, 0.8566082511049836}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}}, {{4.352137271595894, 0.9337074567159822}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.352137271595894, 0.9337074567159822}, {
       4.352137271595894, 0.9337074567159822}}, {{4.352137271595894, 
       0.9337074567159822}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}, {4.352137271595894, 
       0.9337074567159822}, {4.352137271595894, 0.9337074567159822}}, {{
       4.352137271595894, 0.9337074567159822}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 0.9337074567159822}, {4.352137271595894, 
       0.9337074567159822}}, {{4.352137271595894, 0.9337074567159822}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}, {4.352137271595894, 0.9337074567159822}, {
       4.352137271595894, 0.9337074567159822}}, {{4.334579078046893, 
       1.010806662326981}, {4.352137271595894, 1.0879058679379796`}, {
       4.352137271595894, 1.0879058679379796`}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}}, {{
       4.334579078046893, 1.010806662326981}, {4.352137271595894, 
       1.0879058679379796`}, {4.352137271595894, 1.0879058679379796`}, {
       4.334579078046893, 1.010806662326981}, {4.334579078046893, 
       1.010806662326981}}, {{4.334579078046893, 1.010806662326981}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}, {4.334579078046893, 1.010806662326981}, {
       4.334579078046893, 1.010806662326981}}, {{4.334579078046893, 
       1.010806662326981}, {4.352137271595894, 1.0879058679379796`}, {
       4.352137271595894, 1.0879058679379796`}, {4.334579078046893, 
       1.010806662326981}, {4.334579078046893, 1.010806662326981}}, {{
       4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}}, {{4.352137271595894, 1.0879058679379796`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}, {4.352137271595894, 1.0879058679379796`}, {
       4.352137271595894, 1.0879058679379796`}}, {{4.352137271595894, 
       1.0879058679379796`}, {4.423605572274526, 1.1650050735489783`}, {
       4.423605572274526, 1.1650050735489783`}, {4.352137271595894, 
       1.0879058679379796`}, {4.352137271595894, 1.0879058679379796`}}, {{
       4.352137271595894, 1.0879058679379796`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}, {
       4.352137271595894, 1.0879058679379796`}, {4.352137271595894, 
       1.0879058679379796`}}, {{4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}, {4.690685054957424, 1.010806662326981}, {
       4.690685054957424, 1.010806662326981}}, {{4.690685054957424, 
       1.010806662326981}, {4.659649334626015, 0.910363695568482}, {
       4.659649334626015, 0.910363695568482}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}}, {{
       4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}}, {{4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}, {4.690685054957424, 1.010806662326981}, {
       4.690685054957424, 1.010806662326981}}, {{4.659649334626015, 
       0.910363695568482}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}}, {{
       4.659649334626015, 0.910363695568482}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}, {
       4.659649334626015, 0.910363695568482}, {4.659649334626015, 
       0.910363695568482}}, {{4.659649334626015, 0.910363695568482}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}, {4.659649334626015, 0.910363695568482}, {
       4.659649334626015, 0.910363695568482}}, {{4.659649334626015, 
       0.910363695568482}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}, {4.659649334626015, 
       0.910363695568482}, {4.659649334626015, 0.910363695568482}}, {{
       4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}, {{4.601658560729791, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.526109593284566, 
       0.8332644899574833}, {4.601658560729791, 0.8566082511049836}, {
       4.601658560729791, 0.8566082511049836}}, {{4.601658560729791, 
       0.8566082511049836}, {4.526109593284566, 0.8332644899574833}, {
       4.526109593284566, 0.8332644899574833}, {4.601658560729791, 
       0.8566082511049836}, {4.601658560729791, 0.8566082511049836}}, {{
       4.601658560729791, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}, {
       4.601658560729791, 0.8566082511049836}, {4.601658560729791, 
       0.8566082511049836}}, {{4.526109593284566, 0.8332644899574833}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}, {4.526109593284566, 0.8332644899574833}, {
       4.526109593284566, 0.8332644899574833}}, {{4.526109593284566, 
       0.8332644899574833}, {4.423605572274526, 0.8566082511049836}, {
       4.423605572274526, 0.8566082511049836}, {4.526109593284566, 
       0.8332644899574833}, {4.526109593284566, 0.8332644899574833}}, {{
       4.526109593284566, 0.8332644899574833}, {4.423605572274526, 
       0.8566082511049836}, {4.423605572274526, 0.8566082511049836}, {
       4.526109593284566, 0.8332644899574833}, {4.526109593284566, 
       0.8332644899574833}}, {{4.526109593284566, 0.8332644899574833}, {
       4.423605572274526, 0.8566082511049836}, {4.423605572274526, 
       0.8566082511049836}, {4.526109593284566, 0.8332644899574833}, {
       4.526109593284566, 0.8332644899574833}}, {{4.423605572274526, 
       1.1650050735489783`}, {4.526109593284566, 1.1883488346964786`}, {
       4.526109593284566, 1.1883488346964786`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}}, {{
       4.423605572274526, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.526109593284566, 1.1883488346964786`}, {
       4.423605572274526, 1.1650050735489783`}, {4.423605572274526, 
       1.1650050735489783`}}, {{4.423605572274526, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}, {4.423605572274526, 1.1650050735489783`}, {
       4.423605572274526, 1.1650050735489783`}}, {{4.423605572274526, 
       1.1650050735489783`}, {4.526109593284566, 1.1883488346964786`}, {
       4.526109593284566, 1.1883488346964786`}, {4.423605572274526, 
       1.1650050735489783`}, {4.423605572274526, 1.1650050735489783`}}, {{
       4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}}, {{4.526109593284566, 1.1883488346964786`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}, {4.526109593284566, 1.1883488346964786`}, {
       4.526109593284566, 1.1883488346964786`}}, {{4.526109593284566, 
       1.1883488346964786`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}, {4.526109593284566, 
       1.1883488346964786`}, {4.526109593284566, 1.1883488346964786`}}, {{
       4.526109593284566, 1.1883488346964786`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}, {
       4.526109593284566, 1.1883488346964786`}, {4.526109593284566, 
       1.1883488346964786`}}, {{4.601658560729791, 1.1650050735489783`}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}}, {{4.601658560729791, 
       1.1650050735489783`}, {4.659649334626015, 1.1112496290854799`}, {
       4.659649334626015, 1.1112496290854799`}, {4.601658560729791, 
       1.1650050735489783`}, {4.601658560729791, 1.1650050735489783`}}, {{
       4.601658560729791, 1.1650050735489783`}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}, {
       4.601658560729791, 1.1650050735489783`}, {4.601658560729791, 
       1.1650050735489783`}}, {{4.601658560729791, 1.1650050735489783`}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}, {4.601658560729791, 1.1650050735489783`}, {
       4.601658560729791, 1.1650050735489783`}}, {{4.659649334626015, 
       1.1112496290854799`}, {4.690685054957424, 1.010806662326981}, {
       4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}}, {{
       4.659649334626015, 1.1112496290854799`}, {4.690685054957424, 
       1.010806662326981}, {4.690685054957424, 1.010806662326981}, {
       4.659649334626015, 1.1112496290854799`}, {4.659649334626015, 
       1.1112496290854799`}}, {{4.659649334626015, 1.1112496290854799`}, {
       4.690685054957424, 1.010806662326981}, {4.690685054957424, 
       1.010806662326981}, {4.659649334626015, 1.1112496290854799`}, {
       4.659649334626015, 1.1112496290854799`}}, {{4.659649334626015, 
       1.1112496290854799`}, {4.690685054957424, 1.010806662326981}, {
       4.690685054957424, 1.010806662326981}, {4.659649334626015, 
       1.1112496290854799`}, {4.659649334626015, 1.1112496290854799`}}, {{
       4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.401465626199836, 
       1.4565727107085416`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}, {{4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}}, {{4.664945683564524, 
       1.4565727107085416`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.467335640541008, 1.3424824991743407`}, {
       4.467335640541008, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.599075669223352, 1.3424824991743407`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.664945683564524, 
       1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}}, {{
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}, {{4.467335640541008, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.599075669223352, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.467335640541008, 1.5706629222427424`}, {
       4.467335640541008, 1.5706629222427424`}}, {{4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}}, {{
       4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}, {{4.467335640541008, 1.3424824991743407`}, {
       4.414456797770858, 1.3995276049414411`}, {4.414456797770858, 
       1.3995276049414411`}, {4.467335640541008, 1.3424824991743407`}, {
       4.467335640541008, 1.3424824991743407`}}, {{4.467335640541008, 
       1.3424824991743407`}, {4.414456797770858, 1.3995276049414411`}, {
       4.414456797770858, 1.3995276049414411`}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}}, {{
       4.467335640541008, 1.3424824991743407`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}}, {{4.414456797770858, 1.3995276049414411`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.414456797770858, 1.3995276049414411`}, {
       4.414456797770858, 1.3995276049414411`}}, {{4.414456797770858, 
       1.3995276049414411`}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}, {4.414456797770858, 
       1.3995276049414411`}, {4.414456797770858, 1.3995276049414411`}}, {{
       4.414456797770858, 1.3995276049414411`}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.3995276049414411`}, {4.414456797770858, 
       1.3995276049414411`}}, {{4.414456797770858, 1.3995276049414411`}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}, {4.414456797770858, 1.3995276049414411`}, {
       4.414456797770858, 1.3995276049414411`}}, {{4.401465626199836, 
       1.4565727107085416`}, {4.414456797770858, 1.513617816475642}, {
       4.414456797770858, 1.513617816475642}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}}, {{
       4.401465626199836, 1.4565727107085416`}, {4.414456797770858, 
       1.513617816475642}, {4.414456797770858, 1.513617816475642}, {
       4.401465626199836, 1.4565727107085416`}, {4.401465626199836, 
       1.4565727107085416`}}, {{4.401465626199836, 1.4565727107085416`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}, {4.401465626199836, 1.4565727107085416`}, {
       4.401465626199836, 1.4565727107085416`}}, {{4.401465626199836, 
       1.4565727107085416`}, {4.414456797770858, 1.513617816475642}, {
       4.414456797770858, 1.513617816475642}, {4.401465626199836, 
       1.4565727107085416`}, {4.401465626199836, 1.4565727107085416`}}, {{
       4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}}, {{4.414456797770858, 1.513617816475642}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}, {4.414456797770858, 1.513617816475642}, {
       4.414456797770858, 1.513617816475642}}, {{4.414456797770858, 
       1.513617816475642}, {4.467335640541008, 1.5706629222427424`}, {
       4.467335640541008, 1.5706629222427424`}, {4.414456797770858, 
       1.513617816475642}, {4.414456797770858, 1.513617816475642}}, {{
       4.414456797770858, 1.513617816475642}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}, {
       4.414456797770858, 1.513617816475642}, {4.414456797770858, 
       1.513617816475642}}, {{4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}, {4.664945683564524, 1.4565727107085416`}, {
       4.664945683564524, 1.4565727107085416`}}, {{4.664945683564524, 
       1.4565727107085416`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.664945683564524, 
       1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}}, {{
       4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`, 
       1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}}, {{4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}, {4.664945683564524, 1.4565727107085416`}, {
       4.664945683564524, 1.4565727107085416`}}, {{4.6419825941937205`, 
       1.3822557366633184`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.6419825941937205`, 
       1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}}, {{
       4.6419825941937205`, 1.3822557366633184`}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}, {
       4.6419825941937205`, 1.3822557366633184`}, {4.6419825941937205`, 
       1.3822557366633184`}}, {{4.6419825941937205`, 1.3822557366633184`}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}, {4.6419825941937205`, 1.3822557366633184`}, {
       4.6419825941937205`, 1.3822557366633184`}}, {{4.6419825941937205`, 
       1.3822557366633184`}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}, {4.6419825941937205`, 
       1.3822557366633184`}, {4.6419825941937205`, 1.3822557366633184`}}, {{
       4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}, {{4.599075669223352, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.543177572681962, 
       1.325210630896218}, {4.599075669223352, 1.3424824991743407`}, {
       4.599075669223352, 1.3424824991743407`}}, {{4.599075669223352, 
       1.3424824991743407`}, {4.543177572681962, 1.325210630896218}, {
       4.543177572681962, 1.325210630896218}, {4.599075669223352, 
       1.3424824991743407`}, {4.599075669223352, 1.3424824991743407`}}, {{
       4.599075669223352, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}, {
       4.599075669223352, 1.3424824991743407`}, {4.599075669223352, 
       1.3424824991743407`}}, {{4.543177572681962, 1.325210630896218}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}, {4.543177572681962, 1.325210630896218}, {
       4.543177572681962, 1.325210630896218}}, {{4.543177572681962, 
       1.325210630896218}, {4.467335640541008, 1.3424824991743407`}, {
       4.467335640541008, 1.3424824991743407`}, {4.543177572681962, 
       1.325210630896218}, {4.543177572681962, 1.325210630896218}}, {{
       4.543177572681962, 1.325210630896218}, {4.467335640541008, 
       1.3424824991743407`}, {4.467335640541008, 1.3424824991743407`}, {
       4.543177572681962, 1.325210630896218}, {4.543177572681962, 
       1.325210630896218}}, {{4.543177572681962, 1.325210630896218}, {
       4.467335640541008, 1.3424824991743407`}, {4.467335640541008, 
       1.3424824991743407`}, {4.543177572681962, 1.325210630896218}, {
       4.543177572681962, 1.325210630896218}}, {{4.467335640541008, 
       1.5706629222427424`}, {4.543177572681962, 1.5879347905208652`}, {
       4.543177572681962, 1.5879347905208652`}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}}, {{
       4.467335640541008, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.543177572681962, 1.5879347905208652`}, {
       4.467335640541008, 1.5706629222427424`}, {4.467335640541008, 
       1.5706629222427424`}}, {{4.467335640541008, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}, {4.467335640541008, 1.5706629222427424`}, {
       4.467335640541008, 1.5706629222427424`}}, {{4.467335640541008, 
       1.5706629222427424`}, {4.543177572681962, 1.5879347905208652`}, {
       4.543177572681962, 1.5879347905208652`}, {4.467335640541008, 
       1.5706629222427424`}, {4.467335640541008, 1.5706629222427424`}}, {{
       4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}}, {{4.543177572681962, 1.5879347905208652`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}, {4.543177572681962, 1.5879347905208652`}, {
       4.543177572681962, 1.5879347905208652`}}, {{4.543177572681962, 
       1.5879347905208652`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}, {4.543177572681962, 
       1.5879347905208652`}, {4.543177572681962, 1.5879347905208652`}}, {{
       4.543177572681962, 1.5879347905208652`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}, {
       4.543177572681962, 1.5879347905208652`}, {4.543177572681962, 
       1.5879347905208652`}}, {{4.599075669223352, 1.5706629222427424`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}}, {{4.599075669223352, 
       1.5706629222427424`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.599075669223352, 
       1.5706629222427424`}, {4.599075669223352, 1.5706629222427424`}}, {{
       4.599075669223352, 1.5706629222427424`}, {4.6419825941937205`, 
       1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.599075669223352, 1.5706629222427424`}, {4.599075669223352, 
       1.5706629222427424`}}, {{4.599075669223352, 1.5706629222427424`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}, {4.599075669223352, 1.5706629222427424`}, {
       4.599075669223352, 1.5706629222427424`}}, {{4.6419825941937205`, 
       1.5308896847537647`}, {4.664945683564524, 1.4565727107085416`}, {
       4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`, 
       1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}}, {{
       4.6419825941937205`, 1.5308896847537647`}, {4.664945683564524, 
       1.4565727107085416`}, {4.664945683564524, 1.4565727107085416`}, {
       4.6419825941937205`, 1.5308896847537647`}, {4.6419825941937205`, 
       1.5308896847537647`}}, {{4.6419825941937205`, 1.5308896847537647`}, {
       4.664945683564524, 1.4565727107085416`}, {4.664945683564524, 
       1.4565727107085416`}, {4.6419825941937205`, 1.5308896847537647`}, {
       4.6419825941937205`, 1.5308896847537647`}}, {{4.6419825941937205`, 
       1.5308896847537647`}, {4.664945683564524, 1.4565727107085416`}, {
       4.664945683564524, 1.4565727107085416`}, {4.6419825941937205`, 
       1.5308896847537647`}, {4.6419825941937205`, 1.5308896847537647`}}, {{
       4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.375721509963879, 
       1.9733731022542473`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}, {{4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}}, {{4.6987392798803524`, 
       1.9733731022542473`}, {4.670587297551447, 1.8822629686709618`}, {
       4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`, 
       1.8123275700155959`}, {4.456475952442997, 1.8335023049435155`}, {
       4.456475952442997, 1.8335023049435155`}, {4.5494556338327685`, 
       1.8123275700155959`}, {4.617984837401234, 1.8335023049435157`}, {
       4.670587297551447, 1.8822629686709618`}, {4.6987392798803524`, 
       1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}}, {{
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}, {{4.456475952442997, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.670587297551447, 2.0644832358375327`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}, {4.670587297551447, 2.0644832358375327`}, {
       4.617984837401234, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.456475952442997, 2.113243899564979}, {
       4.456475952442997, 2.113243899564979}}, {{4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}}, {{
       4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}, {{4.456475952442997, 1.8335023049435157`}, {
       4.391648253382131, 1.9034377035988814`}, {4.391648253382131, 
       1.9034377035988814`}, {4.456475952442997, 1.8335023049435157`}, {
       4.456475952442997, 1.8335023049435157`}}, {{4.456475952442997, 
       1.8335023049435157`}, {4.391648253382131, 1.9034377035988814`}, {
       4.391648253382131, 1.9034377035988814`}, {4.456475952442997, 
       1.8335023049435157`}, {4.456475952442997, 1.8335023049435157`}}, {{
       4.456475952442997, 1.8335023049435157`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}}, {{4.391648253382131, 1.9034377035988814`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.391648253382131, 1.9034377035988814`}, {
       4.391648253382131, 1.9034377035988814`}}, {{4.391648253382131, 
       1.9034377035988814`}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}, {4.391648253382131, 
       1.9034377035988814`}, {4.391648253382131, 1.9034377035988814`}}, {{
       4.391648253382131, 1.9034377035988814`}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 1.9034377035988814`}, {4.391648253382131, 
       1.9034377035988814`}}, {{4.391648253382131, 1.9034377035988814`}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}, {4.391648253382131, 1.9034377035988814`}, {
       4.391648253382131, 1.9034377035988814`}}, {{4.375721509963879, 
       1.9733731022542473`}, {4.391648253382131, 2.043308500909613}, {
       4.391648253382131, 2.043308500909613}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}}, {{
       4.375721509963879, 1.9733731022542473`}, {4.391648253382131, 
       2.043308500909613}, {4.391648253382131, 2.043308500909613}, {
       4.375721509963879, 1.9733731022542473`}, {4.375721509963879, 
       1.9733731022542473`}}, {{4.375721509963879, 1.9733731022542473`}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}, {4.375721509963879, 1.9733731022542473`}, {
       4.375721509963879, 1.9733731022542473`}}, {{4.375721509963879, 
       1.9733731022542473`}, {4.391648253382131, 2.043308500909613}, {
       4.391648253382131, 2.043308500909613}, {4.375721509963879, 
       1.9733731022542473`}, {4.375721509963879, 1.9733731022542473`}}, {{
       4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}}, {{4.391648253382131, 2.043308500909613}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}, {4.391648253382131, 2.043308500909613}, {
       4.391648253382131, 2.043308500909613}}, {{4.391648253382131, 
       2.043308500909613}, {4.456475952442997, 2.113243899564979}, {
       4.456475952442997, 2.113243899564979}, {4.391648253382131, 
       2.043308500909613}, {4.391648253382131, 2.043308500909613}}, {{
       4.391648253382131, 2.043308500909613}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}, {
       4.391648253382131, 2.043308500909613}, {4.391648253382131, 
       2.043308500909613}}, {{4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.6987392798803524`, 1.9733731022542473`}}, {{4.6987392798803524`, 
       1.9733731022542473`}, {4.670587297551447, 1.8822629686709618`}, {
       4.670587297551447, 1.8822629686709618`}, {4.6987392798803524`, 
       1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}}, {{
       4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447, 
       1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}}, {{4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.6987392798803524`, 1.9733731022542473`}}, {{4.670587297551447, 
       1.8822629686709618`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.670587297551447, 
       1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}}, {{
       4.670587297551447, 1.8822629686709618`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}, {
       4.670587297551447, 1.8822629686709618`}, {4.670587297551447, 
       1.8822629686709618`}}, {{4.670587297551447, 1.8822629686709618`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}, {4.670587297551447, 1.8822629686709618`}, {
       4.670587297551447, 1.8822629686709618`}}, {{4.670587297551447, 
       1.8822629686709618`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}, {4.670587297551447, 
       1.8822629686709618`}, {4.670587297551447, 1.8822629686709618`}}, {{
       4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`, 
       1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}, {{4.617984837401234, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.5494556338327685`, 
       1.8123275700155959`}, {4.617984837401234, 1.8335023049435157`}, {
       4.617984837401234, 1.8335023049435157`}}, {{4.617984837401234, 
       1.8335023049435157`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.617984837401234, 
       1.8335023049435157`}, {4.617984837401234, 1.8335023049435157`}}, {{
       4.617984837401234, 1.8335023049435157`}, {4.5494556338327685`, 
       1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.617984837401234, 1.8335023049435157`}, {4.617984837401234, 
       1.8335023049435157`}}, {{4.5494556338327685`, 1.8123275700155959`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.5494556338327685`, 1.8123275700155959`}}, {{4.5494556338327685`, 
       1.8123275700155959`}, {4.456475952442997, 1.8335023049435157`}, {
       4.456475952442997, 1.8335023049435157`}, {4.5494556338327685`, 
       1.8123275700155959`}, {4.5494556338327685`, 1.8123275700155959`}}, {{
       4.5494556338327685`, 1.8123275700155959`}, {4.456475952442997, 
       1.8335023049435157`}, {4.456475952442997, 1.8335023049435157`}, {
       4.5494556338327685`, 1.8123275700155959`}, {4.5494556338327685`, 
       1.8123275700155959`}}, {{4.5494556338327685`, 1.8123275700155959`}, {
       4.456475952442997, 1.8335023049435157`}, {4.456475952442997, 
       1.8335023049435157`}, {4.5494556338327685`, 1.8123275700155959`}, {
       4.5494556338327685`, 1.8123275700155959`}}, {{4.456475952442997, 
       2.113243899564979}, {4.5494556338327685`, 2.134418634492899}, {
       4.5494556338327685`, 2.134418634492899}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}}, {{
       4.456475952442997, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.5494556338327685`, 2.134418634492899}, {
       4.456475952442997, 2.113243899564979}, {4.456475952442997, 
       2.113243899564979}}, {{4.456475952442997, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}, {4.456475952442997, 2.113243899564979}, {
       4.456475952442997, 2.113243899564979}}, {{4.456475952442997, 
       2.113243899564979}, {4.5494556338327685`, 2.134418634492899}, {
       4.5494556338327685`, 2.134418634492899}, {4.456475952442997, 
       2.113243899564979}, {4.456475952442997, 2.113243899564979}}, {{
       4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}}, {{4.5494556338327685`, 2.134418634492899}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}, {4.5494556338327685`, 2.134418634492899}, {
       4.5494556338327685`, 2.134418634492899}}, {{4.5494556338327685`, 
       2.134418634492899}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}, {4.5494556338327685`, 
       2.134418634492899}, {4.5494556338327685`, 2.134418634492899}}, {{
       4.5494556338327685`, 2.134418634492899}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}, {
       4.5494556338327685`, 2.134418634492899}, {4.5494556338327685`, 
       2.134418634492899}}, {{4.617984837401234, 2.113243899564979}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}}, {{4.617984837401234, 
       2.113243899564979}, {4.670587297551447, 2.0644832358375327`}, {
       4.670587297551447, 2.0644832358375327`}, {4.617984837401234, 
       2.113243899564979}, {4.617984837401234, 2.113243899564979}}, {{
       4.617984837401234, 2.113243899564979}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}, {
       4.617984837401234, 2.113243899564979}, {4.617984837401234, 
       2.113243899564979}}, {{4.617984837401234, 2.113243899564979}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}, {4.617984837401234, 2.113243899564979}, {
       4.617984837401234, 2.113243899564979}}, {{4.670587297551447, 
       2.0644832358375327`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}}, {{
       4.670587297551447, 2.0644832358375327`}, {4.6987392798803524`, 
       1.9733731022542473`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.670587297551447, 2.0644832358375327`}, {4.670587297551447, 
       2.0644832358375327`}}, {{4.670587297551447, 2.0644832358375327`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.6987392798803524`, 
       1.9733731022542473`}, {4.670587297551447, 2.0644832358375327`}, {
       4.670587297551447, 2.0644832358375327`}}, {{4.670587297551447, 
       2.0644832358375327`}, {4.6987392798803524`, 1.9733731022542473`}, {
       4.6987392798803524`, 1.9733731022542473`}, {4.670587297551447, 
       2.0644832358375327`}, {4.670587297551447, 2.0644832358375327`}}, {{
       4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.33191766748663, 
       2.464307059914166}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}, {{4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}}, {{4.647953667815527, 
       2.464307059914166}, {4.620410167967646, 2.3751661986713355`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.410926667568854, 2.3274594575165404`}, {
       4.410926667568854, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.620410167967646, 2.3751661986713355`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}}, {{
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}, {{4.410926667568854, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.620410167967646, 2.5534479211569963`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}, {4.620410167967646, 2.5534479211569963`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.410926667568854, 2.6011546623117914`}, {
       4.410926667568854, 2.6011546623117914`}}, {{4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}}, {{
       4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}, {{4.410926667568854, 2.3274594575165404`}, {
       4.34750016714128, 2.395883258715353}, {4.34750016714128, 
       2.395883258715353}, {4.410926667568854, 2.3274594575165404`}, {
       4.410926667568854, 2.3274594575165404`}}, {{4.410926667568854, 
       2.3274594575165404`}, {4.34750016714128, 2.395883258715353}, {
       4.34750016714128, 2.395883258715353}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}}, {{
       4.410926667568854, 2.3274594575165404`}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}}, {{4.34750016714128, 2.395883258715353}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.34750016714128, 2.395883258715353}, {
       4.34750016714128, 2.395883258715353}}, {{4.34750016714128, 
       2.395883258715353}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}, {4.34750016714128, 
       2.395883258715353}, {4.34750016714128, 2.395883258715353}}, {{
       4.34750016714128, 2.395883258715353}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.395883258715353}, {4.34750016714128, 
       2.395883258715353}}, {{4.34750016714128, 2.395883258715353}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}, {4.34750016714128, 2.395883258715353}, {
       4.34750016714128, 2.395883258715353}}, {{4.33191766748663, 
       2.464307059914166}, {4.34750016714128, 2.5327308611129786`}, {
       4.34750016714128, 2.5327308611129786`}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}}, {{
       4.33191766748663, 2.464307059914166}, {4.34750016714128, 
       2.5327308611129786`}, {4.34750016714128, 2.5327308611129786`}, {
       4.33191766748663, 2.464307059914166}, {4.33191766748663, 
       2.464307059914166}}, {{4.33191766748663, 2.464307059914166}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}, {4.33191766748663, 2.464307059914166}, {
       4.33191766748663, 2.464307059914166}}, {{4.33191766748663, 
       2.464307059914166}, {4.34750016714128, 2.5327308611129786`}, {
       4.34750016714128, 2.5327308611129786`}, {4.33191766748663, 
       2.464307059914166}, {4.33191766748663, 2.464307059914166}}, {{
       4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}}, {{4.34750016714128, 2.5327308611129786`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}, {4.34750016714128, 2.5327308611129786`}, {
       4.34750016714128, 2.5327308611129786`}}, {{4.34750016714128, 
       2.5327308611129786`}, {4.410926667568854, 2.6011546623117914`}, {
       4.410926667568854, 2.6011546623117914`}, {4.34750016714128, 
       2.5327308611129786`}, {4.34750016714128, 2.5327308611129786`}}, {{
       4.34750016714128, 2.5327308611129786`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}, {
       4.34750016714128, 2.5327308611129786`}, {4.34750016714128, 
       2.5327308611129786`}}, {{4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}, {4.647953667815527, 2.464307059914166}, {
       4.647953667815527, 2.464307059914166}}, {{4.647953667815527, 
       2.464307059914166}, {4.620410167967646, 2.3751661986713355`}, {
       4.620410167967646, 2.3751661986713355`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}}, {{
       4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}}, {{4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}, {4.647953667815527, 2.464307059914166}, {
       4.647953667815527, 2.464307059914166}}, {{4.620410167967646, 
       2.3751661986713355`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}}, {{
       4.620410167967646, 2.3751661986713355`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.620410167967646, 2.3751661986713355`}, {4.620410167967646, 
       2.3751661986713355`}}, {{4.620410167967646, 2.3751661986713355`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.620410167967646, 2.3751661986713355`}, {
       4.620410167967646, 2.3751661986713355`}}, {{4.620410167967646, 
       2.3751661986713355`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.620410167967646, 
       2.3751661986713355`}, {4.620410167967646, 2.3751661986713355`}}, {{
       4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}, {{4.5689446677333025`, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.50189666784431, 
       2.3067423974725223`}, {4.5689446677333025`, 2.3274594575165404`}, {
       4.5689446677333025`, 2.3274594575165404`}}, {{4.5689446677333025`, 
       2.3274594575165404`}, {4.50189666784431, 2.3067423974725223`}, {
       4.50189666784431, 2.3067423974725223`}, {4.5689446677333025`, 
       2.3274594575165404`}, {4.5689446677333025`, 2.3274594575165404`}}, {{
       4.5689446677333025`, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}, {
       4.5689446677333025`, 2.3274594575165404`}, {4.5689446677333025`, 
       2.3274594575165404`}}, {{4.50189666784431, 2.3067423974725223`}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}, {4.50189666784431, 2.3067423974725223`}, {
       4.50189666784431, 2.3067423974725223`}}, {{4.50189666784431, 
       2.3067423974725223`}, {4.410926667568854, 2.3274594575165404`}, {
       4.410926667568854, 2.3274594575165404`}, {4.50189666784431, 
       2.3067423974725223`}, {4.50189666784431, 2.3067423974725223`}}, {{
       4.50189666784431, 2.3067423974725223`}, {4.410926667568854, 
       2.3274594575165404`}, {4.410926667568854, 2.3274594575165404`}, {
       4.50189666784431, 2.3067423974725223`}, {4.50189666784431, 
       2.3067423974725223`}}, {{4.50189666784431, 2.3067423974725223`}, {
       4.410926667568854, 2.3274594575165404`}, {4.410926667568854, 
       2.3274594575165404`}, {4.50189666784431, 2.3067423974725223`}, {
       4.50189666784431, 2.3067423974725223`}}, {{4.410926667568854, 
       2.6011546623117914`}, {4.50189666784431, 2.6218717223558095`}, {
       4.50189666784431, 2.6218717223558095`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}}, {{
       4.410926667568854, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.50189666784431, 2.6218717223558095`}, {
       4.410926667568854, 2.6011546623117914`}, {4.410926667568854, 
       2.6011546623117914`}}, {{4.410926667568854, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}, {4.410926667568854, 2.6011546623117914`}, {
       4.410926667568854, 2.6011546623117914`}}, {{4.410926667568854, 
       2.6011546623117914`}, {4.50189666784431, 2.6218717223558095`}, {
       4.50189666784431, 2.6218717223558095`}, {4.410926667568854, 
       2.6011546623117914`}, {4.410926667568854, 2.6011546623117914`}}, {{
       4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}}, {{4.50189666784431, 2.6218717223558095`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.50189666784431, 2.6218717223558095`}, {
       4.50189666784431, 2.6218717223558095`}}, {{4.50189666784431, 
       2.6218717223558095`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.50189666784431, 
       2.6218717223558095`}, {4.50189666784431, 2.6218717223558095`}}, {{
       4.50189666784431, 2.6218717223558095`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.50189666784431, 2.6218717223558095`}, {4.50189666784431, 
       2.6218717223558095`}}, {{4.5689446677333025`, 2.6011546623117914`}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}}, {{4.5689446677333025`, 
       2.6011546623117914`}, {4.620410167967646, 2.5534479211569963`}, {
       4.620410167967646, 2.5534479211569963`}, {4.5689446677333025`, 
       2.6011546623117914`}, {4.5689446677333025`, 2.6011546623117914`}}, {{
       4.5689446677333025`, 2.6011546623117914`}, {4.620410167967646, 
       2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}, {
       4.5689446677333025`, 2.6011546623117914`}, {4.5689446677333025`, 
       2.6011546623117914`}}, {{4.5689446677333025`, 2.6011546623117914`}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}, {4.5689446677333025`, 2.6011546623117914`}, {
       4.5689446677333025`, 2.6011546623117914`}}, {{4.620410167967646, 
       2.5534479211569963`}, {4.647953667815527, 2.464307059914166}, {
       4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}}, {{
       4.620410167967646, 2.5534479211569963`}, {4.647953667815527, 
       2.464307059914166}, {4.647953667815527, 2.464307059914166}, {
       4.620410167967646, 2.5534479211569963`}, {4.620410167967646, 
       2.5534479211569963`}}, {{4.620410167967646, 2.5534479211569963`}, {
       4.647953667815527, 2.464307059914166}, {4.647953667815527, 
       2.464307059914166}, {4.620410167967646, 2.5534479211569963`}, {
       4.620410167967646, 2.5534479211569963`}}, {{4.620410167967646, 
       2.5534479211569963`}, {4.647953667815527, 2.464307059914166}, {
       4.647953667815527, 2.464307059914166}, {4.620410167967646, 
       2.5534479211569963`}, {4.620410167967646, 2.5534479211569963`}}, {{
       4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 3.0645464425864537`}, {4.448246037231085, 
       3.132985584810507}, {4.448246037231085, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.369219322858757, 
       2.9961073003624}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}, {{4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}}, {{4.6853261803480715`, 
       2.9961073003624}, {4.6577765050828805`, 2.906946453205628}, {
       4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.448246037231086, 2.8592290159142935`}, {
       4.448246037231086, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.606299465975743, 2.8592290159142935`}, {
       4.6577765050828805`, 2.906946453205628}, {4.6853261803480715`, 
       2.9961073003624}, {4.6853261803480715`, 2.9961073003624}}, {{
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}, {{4.448246037231086, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.6577765050828805`, 3.085268147519172}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}, {4.6577765050828805`, 3.085268147519172}, {
       4.606299465975743, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.448246037231086, 3.132985584810507}, {
       4.448246037231086, 3.132985584810507}}, {{4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}}, {{
       4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}, {{4.448246037231085, 2.8592290159142935`}, {
       4.384805316202975, 2.9276681581383466`}, {4.384805316202975, 
       2.9276681581383466`}, {4.448246037231085, 2.8592290159142935`}, {
       4.448246037231085, 2.8592290159142935`}}, {{4.448246037231085, 
       2.8592290159142935`}, {4.384805316202975, 2.9276681581383466`}, {
       4.384805316202975, 2.9276681581383466`}, {4.448246037231085, 
       2.8592290159142935`}, {4.448246037231085, 2.8592290159142935`}}, {{
       4.448246037231085, 2.8592290159142935`}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}}, {{4.384805316202975, 2.9276681581383466`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.384805316202975, 2.9276681581383466`}, {
       4.384805316202975, 2.9276681581383466`}}, {{4.384805316202975, 
       2.9276681581383466`}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}, {4.384805316202975, 
       2.9276681581383466`}, {4.384805316202975, 2.9276681581383466`}}, {{
       4.384805316202975, 2.9276681581383466`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 2.9276681581383466`}, {4.384805316202975, 
       2.9276681581383466`}}, {{4.384805316202975, 2.9276681581383466`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}, {4.384805316202975, 2.9276681581383466`}, {
       4.384805316202975, 2.9276681581383466`}}, {{4.369219322858757, 
       2.9961073003624}, {4.384805316202975, 3.0645464425864537`}, {
       4.384805316202975, 3.0645464425864537`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}}, {{
       4.369219322858757, 2.9961073003624}, {4.384805316202975, 
       3.0645464425864537`}, {4.384805316202975, 3.0645464425864537`}, {
       4.369219322858757, 2.9961073003624}, {4.369219322858757, 
       2.9961073003624}}, {{4.369219322858757, 2.9961073003624}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}, {4.369219322858757, 2.9961073003624}, {
       4.369219322858757, 2.9961073003624}}, {{4.369219322858757, 
       2.9961073003624}, {4.384805316202975, 3.0645464425864537`}, {
       4.384805316202975, 3.0645464425864537`}, {4.369219322858757, 
       2.9961073003624}, {4.369219322858757, 2.9961073003624}}, {{
       4.384805316202975, 3.0645464425864537`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}}, {{4.384805316202975, 3.0645464425864537`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}, {4.384805316202975, 3.0645464425864537`}, {
       4.384805316202975, 3.0645464425864537`}}, {{4.384805316202975, 
       3.0645464425864537`}, {4.448246037231086, 3.132985584810507}, {
       4.448246037231086, 3.132985584810507}, {4.384805316202975, 
       3.0645464425864537`}, {4.384805316202975, 3.0645464425864537`}}, {{
       4.384805316202975, 3.0645464425864537`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}, {
       4.384805316202975, 3.0645464425864537`}, {4.384805316202975, 
       3.0645464425864537`}}, {{4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}, {4.6853261803480715`, 2.9961073003624}, {
       4.6853261803480715`, 2.9961073003624}}, {{4.6853261803480715`, 
       2.9961073003624}, {4.6577765050828805`, 2.906946453205628}, {
       4.6577765050828805`, 2.906946453205628}, {4.6853261803480715`, 
       2.9961073003624}, {4.6853261803480715`, 2.9961073003624}}, {{
       4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}}, {{4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}, {4.6853261803480715`, 2.9961073003624}, {
       4.6853261803480715`, 2.9961073003624}}, {{4.6577765050828805`, 
       2.906946453205628}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}}, {{
       4.6577765050828805`, 2.906946453205628}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}, {
       4.6577765050828805`, 2.906946453205628}, {4.6577765050828805`, 
       2.906946453205628}}, {{4.6577765050828805`, 2.906946453205628}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}, {4.6577765050828805`, 2.906946453205628}, {
       4.6577765050828805`, 2.906946453205628}}, {{4.6577765050828805`, 
       2.906946453205628}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}, {4.6577765050828805`, 
       2.906946453205628}, {4.6577765050828805`, 2.906946453205628}}, {{
       4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}, {{4.606299465975743, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.539236433524387, 
       2.8385073109815746`}, {4.606299465975743, 2.8592290159142935`}, {
       4.606299465975743, 2.8592290159142935`}}, {{4.606299465975743, 
       2.8592290159142935`}, {4.539236433524387, 2.8385073109815746`}, {
       4.539236433524387, 2.8385073109815746`}, {4.606299465975743, 
       2.8592290159142935`}, {4.606299465975743, 2.8592290159142935`}}, {{
       4.606299465975743, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}, {
       4.606299465975743, 2.8592290159142935`}, {4.606299465975743, 
       2.8592290159142935`}}, {{4.539236433524387, 2.8385073109815746`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}, {4.539236433524387, 2.8385073109815746`}, {
       4.539236433524387, 2.8385073109815746`}}, {{4.539236433524387, 
       2.8385073109815746`}, {4.448246037231085, 2.8592290159142935`}, {
       4.448246037231085, 2.8592290159142935`}, {4.539236433524387, 
       2.8385073109815746`}, {4.539236433524387, 2.8385073109815746`}}, {{
       4.539236433524387, 2.8385073109815746`}, {4.448246037231085, 
       2.8592290159142935`}, {4.448246037231085, 2.8592290159142935`}, {
       4.539236433524387, 2.8385073109815746`}, {4.539236433524387, 
       2.8385073109815746`}}, {{4.539236433524387, 2.8385073109815746`}, {
       4.448246037231085, 2.8592290159142935`}, {4.448246037231085, 
       2.8592290159142935`}, {4.539236433524387, 2.8385073109815746`}, {
       4.539236433524387, 2.8385073109815746`}}, {{4.448246037231086, 
       3.132985584810507}, {4.539236433524387, 3.1537072897432257`}, {
       4.539236433524387, 3.1537072897432257`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}}, {{
       4.448246037231086, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.539236433524387, 3.1537072897432257`}, {
       4.448246037231086, 3.132985584810507}, {4.448246037231086, 
       3.132985584810507}}, {{4.448246037231086, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}, {4.448246037231086, 3.132985584810507}, {
       4.448246037231086, 3.132985584810507}}, {{4.448246037231086, 
       3.132985584810507}, {4.539236433524387, 3.1537072897432257`}, {
       4.539236433524387, 3.1537072897432257`}, {4.448246037231086, 
       3.132985584810507}, {4.448246037231086, 3.132985584810507}}, {{
       4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}}, {{4.539236433524387, 3.1537072897432257`}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}, {4.539236433524387, 3.1537072897432257`}, {
       4.539236433524387, 3.1537072897432257`}}, {{4.539236433524387, 
       3.1537072897432257`}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}, {4.539236433524387, 
       3.1537072897432257`}, {4.539236433524387, 3.1537072897432257`}}, {{
       4.539236433524387, 3.1537072897432257`}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}, {
       4.539236433524387, 3.1537072897432257`}, {4.539236433524387, 
       3.1537072897432257`}}, {{4.606299465975743, 3.132985584810507}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}}, {{4.606299465975743, 
       3.132985584810507}, {4.6577765050828805`, 3.085268147519172}, {
       4.6577765050828805`, 3.085268147519172}, {4.606299465975743, 
       3.132985584810507}, {4.606299465975743, 3.132985584810507}}, {{
       4.606299465975743, 3.132985584810507}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}, {
       4.606299465975743, 3.132985584810507}, {4.606299465975743, 
       3.132985584810507}}, {{4.606299465975743, 3.132985584810507}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}, {4.606299465975743, 3.132985584810507}, {
       4.606299465975743, 3.132985584810507}}, {{4.6577765050828805`, 
       3.085268147519172}, {4.6853261803480715`, 2.9961073003624}, {
       4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}}, {{
       4.6577765050828805`, 3.085268147519172}, {4.6853261803480715`, 
       2.9961073003624}, {4.6853261803480715`, 2.9961073003624}, {
       4.6577765050828805`, 3.085268147519172}, {4.6577765050828805`, 
       3.085268147519172}}, {{4.6577765050828805`, 3.085268147519172}, {
       4.6853261803480715`, 2.9961073003624}, {4.6853261803480715`, 
       2.9961073003624}, {4.6577765050828805`, 3.085268147519172}, {
       4.6577765050828805`, 3.085268147519172}}, {{4.6577765050828805`, 
       3.085268147519172}, {4.6853261803480715`, 2.9961073003624}, {
       4.6853261803480715`, 2.9961073003624}, {4.6577765050828805`, 
       3.085268147519172}, {4.6577765050828805`, 3.085268147519172}}, {{
       4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.395452954243414, 
       3.536211307589053}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}, {{4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}}, {{4.695359498706354, 
       3.536211307589053}, {4.669221730055957, 3.4516199077549645`}, {
       4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.470429590359148, 3.406347964455996}, {
       4.470429590359148, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.62038286259062, 3.406347964455996}, {
       4.669221730055957, 3.4516199077549645`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}}, {{
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}, {{4.470429590359148, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.669221730055957, 3.6208027074231417`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}, {4.669221730055957, 3.6208027074231417`}, {
       4.62038286259062, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.470429590359148, 3.66607465072211}, {
       4.470429590359148, 3.66607465072211}}, {{4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}}, {{
       4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}, {{4.470429590359148, 3.406347964455996}, {
       4.41024017348634, 3.4712796360225244`}, {4.41024017348634, 
       3.4712796360225244`}, {4.470429590359148, 3.406347964455996}, {
       4.470429590359148, 3.406347964455996}}, {{4.470429590359148, 
       3.406347964455996}, {4.41024017348634, 3.4712796360225244`}, {
       4.41024017348634, 3.4712796360225244`}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}}, {{
       4.470429590359148, 3.406347964455996}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}}, {{4.41024017348634, 3.4712796360225244`}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.41024017348634, 3.4712796360225244`}, {
       4.41024017348634, 3.4712796360225244`}}, {{4.41024017348634, 
       3.4712796360225244`}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}, {4.41024017348634, 
       3.4712796360225244`}, {4.41024017348634, 3.4712796360225244`}}, {{
       4.41024017348634, 3.4712796360225244`}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.4712796360225244`}, {4.41024017348634, 
       3.4712796360225244`}}, {{4.41024017348634, 3.4712796360225244`}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}, {4.41024017348634, 3.4712796360225244`}, {
       4.41024017348634, 3.4712796360225244`}}, {{4.395452954243414, 
       3.536211307589053}, {4.41024017348634, 3.601142979155582}, {
       4.41024017348634, 3.601142979155582}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}}, {{
       4.395452954243414, 3.536211307589053}, {4.41024017348634, 
       3.601142979155582}, {4.41024017348634, 3.601142979155582}, {
       4.395452954243414, 3.536211307589053}, {4.395452954243414, 
       3.536211307589053}}, {{4.395452954243414, 3.536211307589053}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}, {4.395452954243414, 3.536211307589053}, {
       4.395452954243414, 3.536211307589053}}, {{4.395452954243414, 
       3.536211307589053}, {4.41024017348634, 3.601142979155582}, {
       4.41024017348634, 3.601142979155582}, {4.395452954243414, 
       3.536211307589053}, {4.395452954243414, 3.536211307589053}}, {{
       4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}}, {{4.41024017348634, 3.601142979155582}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}, {4.41024017348634, 3.601142979155582}, {
       4.41024017348634, 3.601142979155582}}, {{4.41024017348634, 
       3.601142979155582}, {4.470429590359148, 3.66607465072211}, {
       4.470429590359148, 3.66607465072211}, {4.41024017348634, 
       3.601142979155582}, {4.41024017348634, 3.601142979155582}}, {{
       4.41024017348634, 3.601142979155582}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}, {
       4.41024017348634, 3.601142979155582}, {4.41024017348634, 
       3.601142979155582}}, {{4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}, {4.695359498706354, 3.536211307589053}, {
       4.695359498706354, 3.536211307589053}}, {{4.695359498706354, 
       3.536211307589053}, {4.669221730055957, 3.4516199077549645`}, {
       4.669221730055957, 3.4516199077549645`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}}, {{
       4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}}, {{4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}, {4.695359498706354, 3.536211307589053}, {
       4.695359498706354, 3.536211307589053}}, {{4.669221730055957, 
       3.4516199077549645`}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}}, {{
       4.669221730055957, 3.4516199077549645`}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}, {
       4.669221730055957, 3.4516199077549645`}, {4.669221730055957, 
       3.4516199077549645`}}, {{4.669221730055957, 3.4516199077549645`}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}, {4.669221730055957, 3.4516199077549645`}, {
       4.669221730055957, 3.4516199077549645`}}, {{4.669221730055957, 
       3.4516199077549645`}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}, {4.669221730055957, 
       3.4516199077549645`}, {4.669221730055957, 3.4516199077549645`}}, {{
       4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}, {{4.62038286259062, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.556756775882355, 
       3.386688236188436}, {4.62038286259062, 3.406347964455996}, {
       4.62038286259062, 3.406347964455996}}, {{4.62038286259062, 
       3.406347964455996}, {4.556756775882355, 3.386688236188436}, {
       4.556756775882355, 3.386688236188436}, {4.62038286259062, 
       3.406347964455996}, {4.62038286259062, 3.406347964455996}}, {{
       4.62038286259062, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}, {
       4.62038286259062, 3.406347964455996}, {4.62038286259062, 
       3.406347964455996}}, {{4.556756775882355, 3.386688236188436}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}, {4.556756775882355, 3.386688236188436}, {
       4.556756775882355, 3.386688236188436}}, {{4.556756775882355, 
       3.386688236188436}, {4.470429590359148, 3.406347964455996}, {
       4.470429590359148, 3.406347964455996}, {4.556756775882355, 
       3.386688236188436}, {4.556756775882355, 3.386688236188436}}, {{
       4.556756775882355, 3.386688236188436}, {4.470429590359148, 
       3.406347964455996}, {4.470429590359148, 3.406347964455996}, {
       4.556756775882355, 3.386688236188436}, {4.556756775882355, 
       3.386688236188436}}, {{4.556756775882355, 3.386688236188436}, {
       4.470429590359148, 3.406347964455996}, {4.470429590359148, 
       3.406347964455996}, {4.556756775882355, 3.386688236188436}, {
       4.556756775882355, 3.386688236188436}}, {{4.470429590359148, 
       3.66607465072211}, {4.556756775882355, 3.6857343789896704`}, {
       4.556756775882355, 3.6857343789896704`}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}}, {{
       4.470429590359148, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.556756775882355, 3.6857343789896704`}, {
       4.470429590359148, 3.66607465072211}, {4.470429590359148, 
       3.66607465072211}}, {{4.470429590359148, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}, {4.470429590359148, 3.66607465072211}, {
       4.470429590359148, 3.66607465072211}}, {{4.470429590359148, 
       3.66607465072211}, {4.556756775882355, 3.6857343789896704`}, {
       4.556756775882355, 3.6857343789896704`}, {4.470429590359148, 
       3.66607465072211}, {4.470429590359148, 3.66607465072211}}, {{
       4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}}, {{4.556756775882355, 3.6857343789896704`}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}, {4.556756775882355, 3.6857343789896704`}, {
       4.556756775882355, 3.6857343789896704`}}, {{4.556756775882355, 
       3.6857343789896704`}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}, {4.556756775882355, 
       3.6857343789896704`}, {4.556756775882355, 3.6857343789896704`}}, {{
       4.556756775882355, 3.6857343789896704`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}, {
       4.556756775882355, 3.6857343789896704`}, {4.556756775882355, 
       3.6857343789896704`}}, {{4.62038286259062, 3.66607465072211}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}}, {{4.62038286259062, 
       3.66607465072211}, {4.669221730055957, 3.6208027074231417`}, {
       4.669221730055957, 3.6208027074231417`}, {4.62038286259062, 
       3.66607465072211}, {4.62038286259062, 3.66607465072211}}, {{
       4.62038286259062, 3.66607465072211}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}, {
       4.62038286259062, 3.66607465072211}, {4.62038286259062, 
       3.66607465072211}}, {{4.62038286259062, 3.66607465072211}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}, {4.62038286259062, 3.66607465072211}, {
       4.62038286259062, 3.66607465072211}}, {{4.669221730055957, 
       3.6208027074231417`}, {4.695359498706354, 3.536211307589053}, {
       4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}}, {{
       4.669221730055957, 3.6208027074231417`}, {4.695359498706354, 
       3.536211307589053}, {4.695359498706354, 3.536211307589053}, {
       4.669221730055957, 3.6208027074231417`}, {4.669221730055957, 
       3.6208027074231417`}}, {{4.669221730055957, 3.6208027074231417`}, {
       4.695359498706354, 3.536211307589053}, {4.695359498706354, 
       3.536211307589053}, {4.669221730055957, 3.6208027074231417`}, {
       4.669221730055957, 3.6208027074231417`}}, {{4.669221730055957, 
       3.6208027074231417`}, {4.695359498706354, 3.536211307589053}, {
       4.695359498706354, 3.536211307589053}, {4.669221730055957, 
       3.6208027074231417`}, {4.669221730055957, 3.6208027074231417`}}, {{
       4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}, {{
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}, {{
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}, {{
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}, {{
       4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}, {{
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}, {{
       4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}, {{
       4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}, {{
       4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}, {{
       4.646357124732014, -4.428515373820587}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}}, {{
       4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}, {{
       4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}, {{
       4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}, {{
       4.580507516158428, -4.35747755058133}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.35747755058133}, {
       4.580507516158428, -4.35747755058133}}, {{
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}, {{
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}, {{
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}, {{
       4.564329711992354, -4.2864397273420725`}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}, {
       4.564329711992354, -4.2864397273420725`}, {
       4.564329711992354, -4.2864397273420725`}}, {{
       4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}, {{
       4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}, {{
       4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}, {{
       4.580507516158428, -4.215401904102815}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}, {
       4.580507516158428, -4.215401904102815}, {
       4.580507516158428, -4.215401904102815}}, {{
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}, {{
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}, {{
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}, {{
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}}, {{
       4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}, {{
       4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}, {{
       4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}, {{
       4.863843607683044, -4.378986072815689}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}, {
       4.863843607683044, -4.378986072815689}, {
       4.863843607683044, -4.378986072815689}}, {{
       4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}, {{
       4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}, {{
       4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}, {{
       4.810411950211335, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}, {
       4.810411950211335, -4.428515373820587}, {
       4.810411950211335, -4.428515373820587}}, {{
       4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}, {{
       4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}, {{
       4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}, {{
       4.740802488573553, -4.450023896054946}, {
       4.646357124732014, -4.428515373820587}, {
       4.646357124732014, -4.428515373820587}, {
       4.740802488573553, -4.450023896054946}, {
       4.740802488573553, -4.450023896054946}}, {{
       4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}, {{
       4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}, {{
       4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}, {{
       4.646357124732014, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}, {
       4.646357124732014, -4.144364080863558}, {
       4.646357124732014, -4.144364080863558}}, {{
       4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}, {{
       4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}, {{
       4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}, {{
       4.740802488573553, -4.122855558629199}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}, {
       4.740802488573553, -4.122855558629199}, {
       4.740802488573553, -4.122855558629199}}, {{
       4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}, {{
       4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}, {{
       4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}, {{
       4.810411950211335, -4.144364080863558}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}, {
       4.810411950211335, -4.144364080863558}, {
       4.810411950211335, -4.144364080863558}}, {{
       4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}, {{
       4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}, {{
       4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}, {{
       4.863843607683044, -4.193893381868456}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.892439362950995, -4.2864397273420725`}, {
       4.863843607683044, -4.193893381868456}, {
       4.863843607683044, -4.193893381868456}}, {{
       4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.6295947149828365`, -3.6422505778556866`}, {
       4.6295947149828365`, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}, {{
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}, {{
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.629594714982837, -3.901947432901194}, {
       4.629594714982837, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}, {{
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}, {{
       4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}, {{
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}, {{
       4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}, {{
       4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}, {{
       4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}, {{
       4.6295947149828365`, -3.901947432901194}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}}, {{
       4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}, {{
       4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}, {{
       4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}, {{
       4.569412211237819, -3.837023219139817}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.837023219139817}, {
       4.569412211237819, -3.837023219139817}}, {{
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}, {{
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}, {{
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}, {{
       4.554626690398726, -3.7720990053784402`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.554626690398726, -3.7720990053784402`}, {
       4.554626690398726, -3.7720990053784402`}}, {{
       4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}, {{
       4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}, {{
       4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}, {{
       4.569412211237819, -3.7071747916170636`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.569412211237819, -3.7071747916170636`}, {
       4.569412211237819, -3.7071747916170636`}}, {{
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}, {{
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}, {{
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}, {{
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}}, {{
       4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}, {{
       4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}, {{
       4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}, {{
       4.8283640221695965`, -3.856680689365666}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}, {
       4.8283640221695965`, -3.856680689365666}, {
       4.8283640221695965`, -3.856680689365666}}, {{
       4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}, {{
       4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}, {{
       4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}, {{
       4.77953076415106, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}, {
       4.77953076415106, -3.901947432901194}, {
       4.77953076415106, -3.901947432901194}}, {{
       4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}, {{
       4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}, {{
       4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}, {{
       4.715911985293429, -3.921604903127043}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.6295947149828365`, -3.901947432901194}, {
       4.715911985293429, -3.921604903127043}, {
       4.715911985293429, -3.921604903127043}}, {{
       4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}, {{
       4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}, {{
       4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}, {{
       4.629594714982837, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.629594714982837, -3.6422505778556866`}, {
       4.629594714982837, -3.6422505778556866`}}, {{
       4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}, {{
       4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}, {{
       4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}, {{
       4.715911985293429, -3.6225931076298377`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.715911985293429, -3.6225931076298377`}, {
       4.715911985293429, -3.6225931076298377`}}, {{
       4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}, {{
       4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}, {{
       4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}, {{
       4.77953076415106, -3.6422505778556866`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.77953076415106, -3.6422505778556866`}, {
       4.77953076415106, -3.6422505778556866`}}, {{
       4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}, {{
       4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}, {{
       4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}, {{
       4.8283640221695965`, -3.6875173213912142`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.854498788735171, -3.7720990053784402`}, {
       4.8283640221695965`, -3.6875173213912142`}, {
       4.8283640221695965`, -3.6875173213912142`}}, {{
       4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}, {{
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}, {{
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}, {{
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}, {{
       4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}, {{
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}, {{
       4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}, {{
       4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}, {{
       4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}, {{
       4.683871019494582, -3.409647445416873}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}}, {{
       4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}, {{
       4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}, {{
       4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}, {{
       4.618317332973208, -3.338928859586812}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.338928859586812}, {
       4.618317332973208, -3.338928859586812}}, {{
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}, {{
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}, {{
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}, {{
       4.602212230363192, -3.2682102737567518`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.602212230363192, -3.2682102737567518`}, {
       4.602212230363192, -3.2682102737567518`}}, {{
       4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}, {{
       4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}, {{
       4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}, {{
       4.618317332973208, -3.1974916879266915`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.618317332973208, -3.1974916879266915`}, {
       4.618317332973208, -3.1974916879266915`}}, {{
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}, {{
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}, {{
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}, {{
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}}, {{
       4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}, {{
       4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}, {{
       4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}, {{
       4.900380138300897, -3.3603407245110137`}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}, {
       4.900380138300897, -3.3603407245110137`}, {
       4.900380138300897, -3.3603407245110137`}}, {{
       4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}, {{
       4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}, {{
       4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}, {{
       4.847188597757363, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}, {
       4.847188597757363, -3.409647445416873}, {
       4.847188597757363, -3.409647445416873}}, {{
       4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}, {{
       4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}, {{
       4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}, {{
       4.777891954603811, -3.431059310341074}, {
       4.683871019494582, -3.409647445416873}, {
       4.683871019494582, -3.409647445416873}, {
       4.777891954603811, -3.431059310341074}, {
       4.777891954603811, -3.431059310341074}}, {{
       4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}, {{
       4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}, {{
       4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}, {{
       4.683871019494582, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.683871019494582, -3.1267731020966307`}, {
       4.683871019494582, -3.1267731020966307`}}, {{
       4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}, {{
       4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}, {{
       4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}, {{
       4.777891954603811, -3.1053612371724295`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.777891954603811, -3.1053612371724295`}, {
       4.777891954603811, -3.1053612371724295`}}, {{
       4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}, {{
       4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}, {{
       4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}, {{
       4.847188597757363, -3.1267731020966307`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}, {
       4.847188597757363, -3.1267731020966307`}, {
       4.847188597757363, -3.1267731020966307`}}, {{
       4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}, {{
       4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}, {{
       4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}, {{
       4.900380138300897, -3.17607982300249}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.928847386888752, -3.2682102737567518`}, {
       4.900380138300897, -3.17607982300249}, {
       4.900380138300897, -3.17607982300249}}, {{
       4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}, {{
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}, {{
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}, {{
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}, {{
       4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}, {{
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}, {{
       4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}, {{
       4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}, {{
       4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}, {{
       4.674389639740384, -2.916900060821517}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}}, {{
       4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}, {{
       4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}, {{
       4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}, {{
       4.611459813619236, -2.849012066324547}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.849012066324547}, {
       4.611459813619236, -2.849012066324547}}, {{
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}, {{
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}, {{
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}, {{
       4.595999335945244, -2.781124071827576}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.595999335945244, -2.781124071827576}, {
       4.595999335945244, -2.781124071827576}}, {{
       4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}, {{
       4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}, {{
       4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}, {{
       4.611459813619236, -2.7132360773306052`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}, {
       4.611459813619236, -2.7132360773306052`}, {
       4.611459813619236, -2.7132360773306052`}}, {{
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}, {{
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}, {{
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}, {{
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}}, {{
       4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}, {{
       4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}, {{
       4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}, {{
       4.882232736340023, -2.8695668971527133`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}, {
       4.882232736340023, -2.8695668971527133`}, {
       4.882232736340023, -2.8695668971527133`}}, {{
       4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}, {{
       4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}, {{
       4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}, {{
       4.831170247330664, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.831170247330664, -2.916900060821517}, {
       4.831170247330664, -2.916900060821517}}, {{
       4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}, {{
       4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}, {{
       4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}, {{
       4.764647280647313, -2.9374548916496837`}, {
       4.674389639740384, -2.916900060821517}, {
       4.674389639740384, -2.916900060821517}, {
       4.764647280647313, -2.9374548916496837`}, {
       4.764647280647313, -2.9374548916496837`}}, {{
       4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}, {{
       4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}, {{
       4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}, {{
       4.674389639740384, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.674389639740384, -2.645348082833635}, {
       4.674389639740384, -2.645348082833635}}, {{
       4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}, {{
       4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}, {{
       4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}, {{
       4.764647280647313, -2.6247932520054684`}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}, {
       4.764647280647313, -2.6247932520054684`}, {
       4.764647280647313, -2.6247932520054684`}}, {{
       4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}, {{
       4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}, {{
       4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}, {{
       4.831170247330664, -2.645348082833635}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}, {
       4.831170247330664, -2.645348082833635}, {
       4.831170247330664, -2.645348082833635}}, {{
       4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}, {{
       4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}, {{
       4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}, {{
       4.882232736340023, -2.692681246502439}, {
       4.909560551125804, -2.781124071827576}, {
       4.909560551125804, -2.781124071827576}, {
       4.882232736340023, -2.692681246502439}, {
       4.882232736340023, -2.692681246502439}}, {{
       4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.1240829876163936`}, {
       4.698940132472584, -2.1240829876163936`}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}, {{
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}, {{
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.3784288023735765`}, {
       4.698940132472584, -2.3784288023735765`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}, {{
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}, {{
       4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}, {{
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}, {{
       4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}, {{
       4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}, {{
       4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}, {{
       4.698940132472584, -2.378428802373576}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}}, {{
       4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}, {{
       4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}, {{
       4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}, {{
       4.639997686109607, -2.3148423486842806`}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.3148423486842806`}, {
       4.639997686109607, -2.3148423486842806`}}, {{
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}, {{
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}, {{
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}, {{
       4.625516820163927, -2.251255894994985}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}, {
       4.625516820163927, -2.251255894994985}, {
       4.625516820163927, -2.251255894994985}}, {{
       4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}, {{
       4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}, {{
       4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}, {{
       4.639997686109607, -2.187669441305689}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}, {
       4.639997686109607, -2.187669441305689}, {
       4.639997686109607, -2.187669441305689}}, {{
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}, {{
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}, {{
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}, {{
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}}, {{
       4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}, {{
       4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}, {{
       4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}, {{
       4.893613808348552, -2.334094777751173}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}, {
       4.893613808348552, -2.334094777751173}, {
       4.893613808348552, -2.334094777751173}}, {{
       4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}, {{
       4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}, {{
       4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}, {{
       4.845786757089899, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.845786757089899, -2.378428802373576}, {
       4.845786757089899, -2.378428802373576}}, {{
       4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}, {{
       4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}, {{
       4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}, {{
       4.783478839885566, -2.3976812314404685`}, {
       4.698940132472584, -2.378428802373576}, {
       4.698940132472584, -2.378428802373576}, {
       4.783478839885566, -2.3976812314404685`}, {
       4.783478839885566, -2.3976812314404685`}}, {{
       4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}, {{
       4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}, {{
       4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}, {{
       4.698940132472584, -2.124082987616393}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}, {
       4.698940132472584, -2.124082987616393}, {
       4.698940132472584, -2.124082987616393}}, {{
       4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}, {{
       4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}, {{
       4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}, {{
       4.783478839885566, -2.104830558549501}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.783478839885566, -2.104830558549501}, {
       4.783478839885566, -2.104830558549501}}, {{
       4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}, {{
       4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}, {{
       4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}, {{
       4.845786757089899, -2.1240829876163936`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.845786757089899, -2.1240829876163936`}, {
       4.845786757089899, -2.1240829876163936`}}, {{
       4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}, {{
       4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}, {{
       4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}, {{
       4.893613808348552, -2.1684170122387965`}, {
       4.919210069398556, -2.251255894994985}, {
       4.919210069398556, -2.251255894994985}, {
       4.893613808348552, -2.1684170122387965`}, {
       4.893613808348552, -2.1684170122387965`}}, {{
       4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.679032421183577, -1.5740616887609251`}, {
       4.679032421183577, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}, {{
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}, {{
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.679032421183578, -1.8352918989328}, {
       4.679032421183578, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}, {{
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}, {{
       4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}, {{
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}, {{
       4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}, {{
       4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}, {{
       4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}, {{
       4.679032421183577, -1.8352918989328}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}}, {{
       4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}, {{
       4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}, {{
       4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}, {{
       4.618494575628129, -1.7699843463898313`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.7699843463898313`}, {
       4.618494575628129, -1.7699843463898313`}}, {{
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}, {{
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}, {{
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}, {{
       4.6036217551019805`, -1.7046767938468625`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.6036217551019805`, -1.7046767938468625`}, {
       4.6036217551019805`, -1.7046767938468625`}}, {{
       4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}, {{
       4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}, {{
       4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}, {{
       4.618494575628129, -1.6393692413038938`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.618494575628129, -1.6393692413038938`}, {
       4.618494575628129, -1.6393692413038938`}}, {{
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}, {{
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}, {{
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}, {{
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}}, {{
       4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}, {{
       4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}, {{
       4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}, {{
       4.878975342644896, -1.7897578822597442`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.878975342644896, -1.7897578822597442`}, {
       4.878975342644896, -1.7897578822597442`}}, {{
       4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}, {{
       4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}, {{
       4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}, {{
       4.8298537533467725`, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.8298537533467725`, -1.8352918989328}, {
       4.8298537533467725`, -1.8352918989328}}, {{
       4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}, {{
       4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}, {{
       4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}, {{
       4.7658593435225, -1.8550654348027131`}, {
       4.679032421183577, -1.8352918989328}, {
       4.679032421183577, -1.8352918989328}, {
       4.7658593435225, -1.8550654348027131`}, {
       4.7658593435225, -1.8550654348027131`}}, {{
       4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}, {{
       4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}, {{
       4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}, {{
       4.679032421183578, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}, {
       4.679032421183578, -1.5740616887609251`}, {
       4.679032421183578, -1.5740616887609251`}}, {{
       4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}, {{
       4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}, {{
       4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}, {{
       4.7658593435225, -1.554288152891012}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.7658593435225, -1.554288152891012}, {
       4.7658593435225, -1.554288152891012}}, {{
       4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}, {{
       4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}, {{
       4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}, {{
       4.8298537533467725`, -1.5740616887609251`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}, {
       4.8298537533467725`, -1.5740616887609251`}, {
       4.8298537533467725`, -1.5740616887609251`}}, {{
       4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}, {{
       4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}, {{
       4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}, {{
       4.878975342644896, -1.619595705433981}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.905264419428369, -1.7046767938468625`}, {
       4.878975342644896, -1.619595705433981}, {
       4.878975342644896, -1.619595705433981}}, {{
       4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.2799140717567363`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}, {{
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}, {{
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}, {{
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}, {{
       4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}, {{
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}, {{
       4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}, {{
       4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}, {{
       4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}, {{
       4.631383198031406, -1.3477655861915068`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}}, {{
       4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}, {{
       4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}, {{
       4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}, {{
       4.568487187667936, -1.279914071756736}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.279914071756736}, {
       4.568487187667936, -1.279914071756736}}, {{
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}, {{
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}, {{
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}, {{
       4.553035017783729, -1.2120625573219657`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.568487187667936, -1.1442110428871952`}, {
       4.553035017783729, -1.2120625573219657`}, {
       4.553035017783729, -1.2120625573219657`}}, {{
       4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}, {{
       4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}, {{
       4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}, {{
       4.568487187667936, -1.144211042887195}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.568487187667936, -1.144211042887195}, {
       4.568487187667936, -1.144211042887195}}, {{
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}, {{
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}, {{
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}, {{
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}}, {{
       4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}, {{
       4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}, {{
       4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}, {{
       4.839114608770415, -1.3004578573108054`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.839114608770415, -1.3004578573108054`}, {
       4.839114608770415, -1.3004578573108054`}}, {{
       4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}, {{
       4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}, {{
       4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}, {{
       4.788079558526761, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}, {
       4.788079558526761, -1.3477655861915068`}, {
       4.788079558526761, -1.3477655861915068`}}, {{
       4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}, {{
       4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}, {{
       4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}, {{
       4.721592338398899, -1.368309371745576}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.631383198031406, -1.3477655861915068`}, {
       4.721592338398899, -1.368309371745576}, {
       4.721592338398899, -1.368309371745576}}, {{
       4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}, {{
       4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}, {{
       4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}, {{
       4.631383198031406, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.631383198031406, -1.0763595284524246`}, {
       4.631383198031406, -1.0763595284524246`}}, {{
       4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}, {{
       4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}, {{
       4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}, {{
       4.721592338398899, -1.0558157428983552`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.721592338398899, -1.0558157428983552`}, {
       4.721592338398899, -1.0558157428983552`}}, {{
       4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}, {{
       4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}, {{
       4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}, {{
       4.788079558526761, -1.0763595284524246`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}, {
       4.788079558526761, -1.0763595284524246`}, {
       4.788079558526761, -1.0763595284524246`}}, {{
       4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}, {{
       4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}, {{
       4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}, {{
       4.839114608770415, -1.123667257333126}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.866427738774438, -1.2120625573219657`}, {
       4.839114608770415, -1.123667257333126}, {
       4.839114608770415, -1.123667257333126}}, {{
       4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}, {{
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}, {{
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}, {{
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}, {{
       4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}, {{
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}, {{
       4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}, {{
       4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}, {{
       4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}, {{
       4.69515905189892, -0.8430211249113777}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}}, {{
       4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}, {{
       4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}, {{
       4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}, {{
       4.634085181488199, -0.7771353147333909}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.7771353147333909}, {
       4.634085181488199, -0.7771353147333909}}, {{
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}, {{
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}, {{
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}, {{
       4.619080671414846, -0.7112495045554041}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}, {
       4.619080671414846, -0.7112495045554041}, {
       4.619080671414846, -0.7112495045554041}}, {{
       4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}, {{
       4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}, {{
       4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}, {{
       4.634085181488199, -0.6453636943774174}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}, {
       4.634085181488199, -0.6453636943774174}, {
       4.634085181488199, -0.6453636943774174}}, {{
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}, {{
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}, {{
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}, {{
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}}, {{
       4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}, {{
       4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}, {{
       4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}, {{
       4.896872343193448, -0.79708393292752}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}, {
       4.896872343193448, -0.79708393292752}, {
       4.896872343193448, -0.79708393292752}}, {{
       4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}, {{
       4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}, {{
       4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}, {{
       4.847315812867069, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}, {
       4.847315812867069, -0.8430211249113777}, {
       4.847315812867069, -0.8430211249113777}}, {{
       4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}, {{
       4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}, {{
       4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}, {{
       4.782754772467336, -0.8629697431055068}, {
       4.69515905189892, -0.8430211249113777}, {
       4.69515905189892, -0.8430211249113777}, {
       4.782754772467336, -0.8629697431055068}, {
       4.782754772467336, -0.8629697431055068}}, {{
       4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}, {{
       4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}, {{
       4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}, {{
       4.69515905189892, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}, {
       4.69515905189892, -0.5794778841994306}, {
       4.69515905189892, -0.5794778841994306}}, {{
       4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}, {{
       4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}, {{
       4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}, {{
       4.782754772467336, -0.5595292660053015}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}, {
       4.782754772467336, -0.5595292660053015}, {
       4.782754772467336, -0.5595292660053015}}, {{
       4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}, {{
       4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}, {{
       4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}, {{
       4.847315812867069, -0.5794778841994306}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}, {
       4.847315812867069, -0.5794778841994306}, {
       4.847315812867069, -0.5794778841994306}}, {{
       4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}, {{
       4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}, {{
       4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}, {{
       4.896872343193448, -0.6254150761832883}, {
       4.923394193351143, -0.7112495045554041}, {
       4.923394193351143, -0.7112495045554041}, {
       4.896872343193448, -0.6254150761832883}, {
       4.896872343193448, -0.6254150761832883}}, {{
       4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833331}, {
       4.6417842317253495`, -0.09563014472833331}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}, {{
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}, {{
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240929}, {
       4.6417842317253495`, -0.3752411744240929}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}, {{
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}, {{
       4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.23543565957621304`}, {
       4.883934486620202, -0.23543565957621304`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}, {{
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}, {{
       4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}, {{
       4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}, {{
       4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}, {{
       4.6417842317253495`, -0.3752411744240928}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}}, {{
       4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}, {{
       4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}, {{
       4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}, {{
       4.576986789958622, -0.30533841700015296`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.30533841700015296`}, {
       4.576986789958622, -0.30533841700015296`}}, {{
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}, {{
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}, {{
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}, {{
       4.561067480093731, -0.23543565957621307`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.561067480093731, -0.23543565957621307`}, {
       4.561067480093731, -0.23543565957621307`}}, {{
       4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}, {{
       4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}, {{
       4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}, {{
       4.576986789958622, -0.16553290215227318`}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.576986789958622, -0.16553290215227318`}, {
       4.576986789958622, -0.16553290215227318`}}, {{
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}, {{
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}, {{
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}, {{
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}}, {{
       4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}, {{
       4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}, {{
       4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}, {{
       4.855795643779852, -0.32650326895841125`}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}, {
       4.855795643779852, -0.32650326895841125`}, {
       4.855795643779852, -0.32650326895841125`}}, {{
       4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}, {{
       4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}, {{
       4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}, {{
       4.803217734988584, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}, {
       4.803217734988584, -0.3752411744240928}, {
       4.803217734988584, -0.3752411744240928}}, {{
       4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}, {{
       4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}, {{
       4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}, {{
       4.734720516332426, -0.3964060263823511}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.6417842317253495`, -0.3752411744240928}, {
       4.734720516332426, -0.3964060263823511}, {
       4.734720516332426, -0.3964060263823511}}, {{
       4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}, {{
       4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}, {{
       4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}, {{
       4.6417842317253495`, -0.09563014472833328}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}, {
       4.6417842317253495`, -0.09563014472833328}, {
       4.6417842317253495`, -0.09563014472833328}}, {{
       4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}, {{
       4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}, {{
       4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}, {{
       4.734720516332426, -0.07446529277007499}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}, {
       4.734720516332426, -0.07446529277007499}, {
       4.734720516332426, -0.07446529277007499}}, {{
       4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}, {{
       4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}, {{
       4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}, {{
       4.803217734988584, -0.09563014472833331}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.803217734988584, -0.09563014472833331}, {
       4.803217734988584, -0.09563014472833331}}, {{
       4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}, {{
       4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}, {{
       4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}, {{
       4.855795643779852, -0.14436805019401489`}, {
       4.883934486620202, -0.2354356595762131}, {
       4.883934486620202, -0.2354356595762131}, {
       4.855795643779852, -0.14436805019401489`}, {
       4.855795643779852, -0.14436805019401489`}}, {{4.663699681880105, 
       0.15735319333361192`}, {4.60943037670673, 0.215898314432021}, {
       4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.3329885566288392}, {4.663699681880105, 0.3915336777272483}, {
       4.663699681880105, 0.3915336777272483}, {4.60943037670673, 
       0.3329885566288392}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}}, {{
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}, {{4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.19817227805535337`}, {4.798903847583728, 
       0.15735319333361192`}, {4.74153589660565, 0.13962715695694428`}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}, {4.74153589660565, 0.13962715695694428`}, {
       4.798903847583728, 0.15735319333361192`}, {4.842939020883367, 
       0.19817227805535337`}, {4.866505930435539, 0.2744434355304301}, {
       4.866505930435539, 0.2744434355304301}}, {{4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}}, {{
       4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.798903847583728, 0.3915336777272483}, {
       4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.798903847583728, 
       0.3915336777272483}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}, {{4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}}, {{4.663699681880105, 
       0.15735319333361192`}, {4.60943037670673, 0.215898314432021}, {
       4.60943037670673, 0.215898314432021}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}}, {{
       4.663699681880105, 0.15735319333361192`}, {4.60943037670673, 
       0.215898314432021}, {4.60943037670673, 0.215898314432021}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}}, {{4.663699681880105, 0.15735319333361192`}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}, {4.663699681880105, 0.15735319333361192`}, {
       4.663699681880105, 0.15735319333361192`}}, {{4.663699681880105, 
       0.15735319333361192`}, {4.60943037670673, 0.215898314432021}, {
       4.60943037670673, 0.215898314432021}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}}, {{
       4.60943037670673, 0.215898314432021}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}}, {{4.60943037670673, 0.215898314432021}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}, {4.60943037670673, 0.215898314432021}, {
       4.60943037670673, 0.215898314432021}}, {{4.60943037670673, 
       0.215898314432021}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.215898314432021}, {4.60943037670673, 0.215898314432021}}, {{
       4.60943037670673, 0.215898314432021}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.215898314432021}, {4.60943037670673, 
       0.215898314432021}}, {{4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}}, {{4.596097599028293, 
       0.2744434355304301}, {4.60943037670673, 0.3329885566288392}, {
       4.60943037670673, 0.3329885566288392}, {4.596097599028293, 
       0.2744434355304301}, {4.596097599028293, 0.2744434355304301}}, {{
       4.596097599028293, 0.2744434355304301}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}, {
       4.596097599028293, 0.2744434355304301}, {4.596097599028293, 
       0.2744434355304301}}, {{4.596097599028293, 0.2744434355304301}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}, {4.596097599028293, 0.2744434355304301}, {
       4.596097599028293, 0.2744434355304301}}, {{4.60943037670673, 
       0.3329885566288392}, {4.663699681880105, 0.3915336777272483}, {
       4.663699681880105, 0.3915336777272483}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}}, {{
       4.60943037670673, 0.3329885566288392}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}, {
       4.60943037670673, 0.3329885566288392}, {4.60943037670673, 
       0.3329885566288392}}, {{4.60943037670673, 0.3329885566288392}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}, {4.60943037670673, 0.3329885566288392}, {
       4.60943037670673, 0.3329885566288392}}, {{4.60943037670673, 
       0.3329885566288392}, {4.663699681880105, 0.3915336777272483}, {
       4.663699681880105, 0.3915336777272483}, {4.60943037670673, 
       0.3329885566288392}, {4.60943037670673, 0.3329885566288392}}, {{
       4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}, {{4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.19817227805535337`}, {4.842939020883367, 
       0.19817227805535337`}, {4.866505930435539, 0.2744434355304301}, {
       4.866505930435539, 0.2744434355304301}}, {{4.866505930435539, 
       0.2744434355304301}, {4.842939020883367, 0.19817227805535337`}, {
       4.842939020883367, 0.19817227805535337`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}}, {{
       4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}}, {{4.842939020883367, 0.19817227805535337`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.842939020883367, 0.19817227805535337`}, {
       4.842939020883367, 0.19817227805535337`}}, {{4.842939020883367, 
       0.19817227805535337`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}, {4.842939020883367, 
       0.19817227805535337`}, {4.842939020883367, 0.19817227805535337`}}, {{
       4.842939020883367, 0.19817227805535337`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}, {
       4.842939020883367, 0.19817227805535337`}, {4.842939020883367, 
       0.19817227805535337`}}, {{4.842939020883367, 0.19817227805535337`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}, {4.842939020883367, 0.19817227805535337`}, {
       4.842939020883367, 0.19817227805535337`}}, {{4.798903847583728, 
       0.15735319333361192`}, {4.74153589660565, 0.13962715695694428`}, {
       4.74153589660565, 0.13962715695694428`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}}, {{
       4.798903847583728, 0.15735319333361192`}, {4.74153589660565, 
       0.13962715695694428`}, {4.74153589660565, 0.13962715695694428`}, {
       4.798903847583728, 0.15735319333361192`}, {4.798903847583728, 
       0.15735319333361192`}}, {{4.798903847583728, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}, {4.798903847583728, 0.15735319333361192`}, {
       4.798903847583728, 0.15735319333361192`}}, {{4.798903847583728, 
       0.15735319333361192`}, {4.74153589660565, 0.13962715695694428`}, {
       4.74153589660565, 0.13962715695694428`}, {4.798903847583728, 
       0.15735319333361192`}, {4.798903847583728, 0.15735319333361192`}}, {{
       4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}}, {{4.74153589660565, 0.13962715695694428`}, {
       4.663699681880105, 0.15735319333361192`}, {4.663699681880105, 
       0.15735319333361192`}, {4.74153589660565, 0.13962715695694428`}, {
       4.74153589660565, 0.13962715695694428`}}, {{4.74153589660565, 
       0.13962715695694428`}, {4.663699681880105, 0.15735319333361192`}, {
       4.663699681880105, 0.15735319333361192`}, {4.74153589660565, 
       0.13962715695694428`}, {4.74153589660565, 0.13962715695694428`}}, {{
       4.74153589660565, 0.13962715695694428`}, {4.663699681880105, 
       0.15735319333361192`}, {4.663699681880105, 0.15735319333361192`}, {
       4.74153589660565, 0.13962715695694428`}, {4.74153589660565, 
       0.13962715695694428`}}, {{4.663699681880105, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}, {4.663699681880105, 0.3915336777272483}, {
       4.663699681880105, 0.3915336777272483}}, {{4.663699681880105, 
       0.3915336777272483}, {4.74153589660565, 0.40925971410391593`}, {
       4.74153589660565, 0.40925971410391593`}, {4.663699681880105, 
       0.3915336777272483}, {4.663699681880105, 0.3915336777272483}}, {{
       4.663699681880105, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}, {
       4.663699681880105, 0.3915336777272483}, {4.663699681880105, 
       0.3915336777272483}}, {{4.663699681880105, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}, {4.663699681880105, 0.3915336777272483}, {
       4.663699681880105, 0.3915336777272483}}, {{4.74153589660565, 
       0.40925971410391593`}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}}, {{
       4.74153589660565, 0.40925971410391593`}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}, {
       4.74153589660565, 0.40925971410391593`}, {4.74153589660565, 
       0.40925971410391593`}}, {{4.74153589660565, 0.40925971410391593`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}, {4.74153589660565, 0.40925971410391593`}, {
       4.74153589660565, 0.40925971410391593`}}, {{4.74153589660565, 
       0.40925971410391593`}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}, {4.74153589660565, 
       0.40925971410391593`}, {4.74153589660565, 0.40925971410391593`}}, {{
       4.798903847583728, 0.3915336777272483}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}, {{4.798903847583728, 0.3915336777272483}, {
       4.842939020883367, 0.35071459300550684`}, {4.842939020883367, 
       0.35071459300550684`}, {4.798903847583728, 0.3915336777272483}, {
       4.798903847583728, 0.3915336777272483}}, {{4.798903847583728, 
       0.3915336777272483}, {4.842939020883367, 0.35071459300550684`}, {
       4.842939020883367, 0.35071459300550684`}, {4.798903847583728, 
       0.3915336777272483}, {4.798903847583728, 0.3915336777272483}}, {{
       4.798903847583728, 0.3915336777272483}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}, {
       4.798903847583728, 0.3915336777272483}, {4.798903847583728, 
       0.3915336777272483}}, {{4.842939020883367, 0.35071459300550684`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}, {4.842939020883367, 0.35071459300550684`}, {
       4.842939020883367, 0.35071459300550684`}}, {{4.842939020883367, 
       0.35071459300550684`}, {4.866505930435539, 0.2744434355304301}, {
       4.866505930435539, 0.2744434355304301}, {4.842939020883367, 
       0.35071459300550684`}, {4.842939020883367, 0.35071459300550684`}}, {{
       4.842939020883367, 0.35071459300550684`}, {4.866505930435539, 
       0.2744434355304301}, {4.866505930435539, 0.2744434355304301}, {
       4.842939020883367, 0.35071459300550684`}, {4.842939020883367, 
       0.35071459300550684`}}, {{4.842939020883367, 0.35071459300550684`}, {
       4.866505930435539, 0.2744434355304301}, {4.866505930435539, 
       0.2744434355304301}, {4.842939020883367, 0.35071459300550684`}, {
       4.842939020883367, 0.35071459300550684`}}, {{4.666669201903647, 
       0.58238880896803}, {4.603603926616283, 0.6504229245147085}, {
       4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.7864911556080653}, {4.666669201903647, 0.8545252711547437}, {
       4.666669201903647, 0.8545252711547437}, {4.603603926616283, 
       0.7864911556080653}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}}, {{
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}, {{4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.6298238517925308}, {4.823787261603459, 
       0.58238880896803}, {4.757121111934759, 0.5617897362458524}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}, {4.757121111934759, 0.5617897362458524}, {
       4.823787261603459, 0.58238880896803}, {4.874959656709618, 
       0.6298238517925308}, {4.902346291453365, 0.7184570400613869}, {
       4.902346291453365, 0.7184570400613869}}, {{4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}}, {{
       4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.823787261603459, 0.8545252711547437}, {
       4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.823787261603459, 
       0.8545252711547437}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}, {{4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}}, {{4.666669201903647, 
       0.58238880896803}, {4.603603926616283, 0.6504229245147085}, {
       4.603603926616283, 0.6504229245147085}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}}, {{
       4.666669201903647, 0.58238880896803}, {4.603603926616283, 
       0.6504229245147085}, {4.603603926616283, 0.6504229245147085}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}}, {{4.666669201903647, 0.58238880896803}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}, {4.666669201903647, 0.58238880896803}, {
       4.666669201903647, 0.58238880896803}}, {{4.666669201903647, 
       0.58238880896803}, {4.603603926616283, 0.6504229245147085}, {
       4.603603926616283, 0.6504229245147085}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}}, {{
       4.603603926616283, 0.6504229245147085}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}}, {{4.603603926616283, 0.6504229245147085}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}, {4.603603926616283, 0.6504229245147085}, {
       4.603603926616283, 0.6504229245147085}}, {{4.603603926616283, 
       0.6504229245147085}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.6504229245147085}, {4.603603926616283, 0.6504229245147085}}, {{
       4.603603926616283, 0.6504229245147085}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.6504229245147085}, {4.603603926616283, 
       0.6504229245147085}}, {{4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}}, {{4.588110172053741, 
       0.7184570400613869}, {4.603603926616283, 0.7864911556080653}, {
       4.603603926616283, 0.7864911556080653}, {4.588110172053741, 
       0.7184570400613869}, {4.588110172053741, 0.7184570400613869}}, {{
       4.588110172053741, 0.7184570400613869}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}, {
       4.588110172053741, 0.7184570400613869}, {4.588110172053741, 
       0.7184570400613869}}, {{4.588110172053741, 0.7184570400613869}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}, {4.588110172053741, 0.7184570400613869}, {
       4.588110172053741, 0.7184570400613869}}, {{4.603603926616283, 
       0.7864911556080653}, {4.666669201903647, 0.8545252711547437}, {
       4.666669201903647, 0.8545252711547437}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}}, {{
       4.603603926616283, 0.7864911556080653}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}, {
       4.603603926616283, 0.7864911556080653}, {4.603603926616283, 
       0.7864911556080653}}, {{4.603603926616283, 0.7864911556080653}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}, {4.603603926616283, 0.7864911556080653}, {
       4.603603926616283, 0.7864911556080653}}, {{4.603603926616283, 
       0.7864911556080653}, {4.666669201903647, 0.8545252711547437}, {
       4.666669201903647, 0.8545252711547437}, {4.603603926616283, 
       0.7864911556080653}, {4.603603926616283, 0.7864911556080653}}, {{
       4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}, {{4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.6298238517925308}, {4.874959656709618, 
       0.6298238517925308}, {4.902346291453365, 0.7184570400613869}, {
       4.902346291453365, 0.7184570400613869}}, {{4.902346291453365, 
       0.7184570400613869}, {4.874959656709618, 0.6298238517925308}, {
       4.874959656709618, 0.6298238517925308}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}}, {{
       4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}}, {{4.874959656709618, 0.6298238517925308}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.874959656709618, 0.6298238517925308}, {
       4.874959656709618, 0.6298238517925308}}, {{4.874959656709618, 
       0.6298238517925308}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}, {4.874959656709618, 
       0.6298238517925308}, {4.874959656709618, 0.6298238517925308}}, {{
       4.874959656709618, 0.6298238517925308}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}, {
       4.874959656709618, 0.6298238517925308}, {4.874959656709618, 
       0.6298238517925308}}, {{4.874959656709618, 0.6298238517925308}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}, {4.874959656709618, 0.6298238517925308}, {
       4.874959656709618, 0.6298238517925308}}, {{4.823787261603459, 
       0.58238880896803}, {4.757121111934759, 0.5617897362458524}, {
       4.757121111934759, 0.5617897362458524}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}}, {{
       4.823787261603459, 0.58238880896803}, {4.757121111934759, 
       0.5617897362458524}, {4.757121111934759, 0.5617897362458524}, {
       4.823787261603459, 0.58238880896803}, {4.823787261603459, 
       0.58238880896803}}, {{4.823787261603459, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}, {4.823787261603459, 0.58238880896803}, {
       4.823787261603459, 0.58238880896803}}, {{4.823787261603459, 
       0.58238880896803}, {4.757121111934759, 0.5617897362458524}, {
       4.757121111934759, 0.5617897362458524}, {4.823787261603459, 
       0.58238880896803}, {4.823787261603459, 0.58238880896803}}, {{
       4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}}, {{4.757121111934759, 0.5617897362458524}, {
       4.666669201903647, 0.58238880896803}, {4.666669201903647, 
       0.58238880896803}, {4.757121111934759, 0.5617897362458524}, {
       4.757121111934759, 0.5617897362458524}}, {{4.757121111934759, 
       0.5617897362458524}, {4.666669201903647, 0.58238880896803}, {
       4.666669201903647, 0.58238880896803}, {4.757121111934759, 
       0.5617897362458524}, {4.757121111934759, 0.5617897362458524}}, {{
       4.757121111934759, 0.5617897362458524}, {4.666669201903647, 
       0.58238880896803}, {4.666669201903647, 0.58238880896803}, {
       4.757121111934759, 0.5617897362458524}, {4.757121111934759, 
       0.5617897362458524}}, {{4.666669201903647, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}, {4.666669201903647, 0.8545252711547437}, {
       4.666669201903647, 0.8545252711547437}}, {{4.666669201903647, 
       0.8545252711547437}, {4.757121111934759, 0.8751243438769214}, {
       4.757121111934759, 0.8751243438769214}, {4.666669201903647, 
       0.8545252711547437}, {4.666669201903647, 0.8545252711547437}}, {{
       4.666669201903647, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}, {
       4.666669201903647, 0.8545252711547437}, {4.666669201903647, 
       0.8545252711547437}}, {{4.666669201903647, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}, {4.666669201903647, 0.8545252711547437}, {
       4.666669201903647, 0.8545252711547437}}, {{4.757121111934759, 
       0.8751243438769214}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}}, {{
       4.757121111934759, 0.8751243438769214}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}, {
       4.757121111934759, 0.8751243438769214}, {4.757121111934759, 
       0.8751243438769214}}, {{4.757121111934759, 0.8751243438769214}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}, {4.757121111934759, 0.8751243438769214}, {
       4.757121111934759, 0.8751243438769214}}, {{4.757121111934759, 
       0.8751243438769214}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}, {4.757121111934759, 
       0.8751243438769214}, {4.757121111934759, 0.8751243438769214}}, {{
       4.823787261603459, 0.8545252711547437}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}, {{4.823787261603459, 0.8545252711547437}, {
       4.874959656709618, 0.807090228330243}, {4.874959656709618, 
       0.807090228330243}, {4.823787261603459, 0.8545252711547437}, {
       4.823787261603459, 0.8545252711547437}}, {{4.823787261603459, 
       0.8545252711547437}, {4.874959656709618, 0.807090228330243}, {
       4.874959656709618, 0.807090228330243}, {4.823787261603459, 
       0.8545252711547437}, {4.823787261603459, 0.8545252711547437}}, {{
       4.823787261603459, 0.8545252711547437}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}, {
       4.823787261603459, 0.8545252711547437}, {4.823787261603459, 
       0.8545252711547437}}, {{4.874959656709618, 0.807090228330243}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}, {4.874959656709618, 0.807090228330243}, {
       4.874959656709618, 0.807090228330243}}, {{4.874959656709618, 
       0.807090228330243}, {4.902346291453365, 0.7184570400613869}, {
       4.902346291453365, 0.7184570400613869}, {4.874959656709618, 
       0.807090228330243}, {4.874959656709618, 0.807090228330243}}, {{
       4.874959656709618, 0.807090228330243}, {4.902346291453365, 
       0.7184570400613869}, {4.902346291453365, 0.7184570400613869}, {
       4.874959656709618, 0.807090228330243}, {4.874959656709618, 
       0.807090228330243}}, {{4.874959656709618, 0.807090228330243}, {
       4.902346291453365, 0.7184570400613869}, {4.902346291453365, 
       0.7184570400613869}, {4.874959656709618, 0.807090228330243}, {
       4.874959656709618, 0.807090228330243}}, {{4.67002552391586, 
       1.174141916407176}, {4.61714668114571, 1.2311870221742764`}, {
       4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.3452772337084773`}, {4.67002552391586, 1.4023223394755777`}, {
       4.67002552391586, 1.4023223394755777`}, {4.61714668114571, 
       1.3452772337084773`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}}, {{
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}, {{4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.2139151538961537`}, {4.801765552598204, 
       1.174141916407176}, {4.745867456056814, 1.1568700481290533`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}, {4.745867456056814, 1.1568700481290533`}, {
       4.801765552598204, 1.174141916407176}, {4.844672477568572, 
       1.2139151538961537`}, {4.867635566939376, 1.2882321279413769`}, {
       4.867635566939376, 1.2882321279413769`}}, {{4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}}, {{
       4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.801765552598204, 1.4023223394755777`}, {
       4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.801765552598204, 
       1.4023223394755777`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}, {{4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}}, {{4.67002552391586, 
       1.174141916407176}, {4.61714668114571, 1.2311870221742764`}, {
       4.61714668114571, 1.2311870221742764`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}}, {{
       4.67002552391586, 1.174141916407176}, {4.61714668114571, 
       1.2311870221742764`}, {4.61714668114571, 1.2311870221742764`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}}, {{4.67002552391586, 1.174141916407176}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}, {4.67002552391586, 1.174141916407176}, {
       4.67002552391586, 1.174141916407176}}, {{4.67002552391586, 
       1.174141916407176}, {4.61714668114571, 1.2311870221742764`}, {
       4.61714668114571, 1.2311870221742764`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}}, {{
       4.61714668114571, 1.2311870221742764`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}}, {{4.61714668114571, 1.2311870221742764`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}, {4.61714668114571, 1.2311870221742764`}, {
       4.61714668114571, 1.2311870221742764`}}, {{4.61714668114571, 
       1.2311870221742764`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.2311870221742764`}, {4.61714668114571, 1.2311870221742764`}}, {{
       4.61714668114571, 1.2311870221742764`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.2311870221742764`}, {4.61714668114571, 
       1.2311870221742764`}}, {{4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}}, {{4.604155509574688, 
       1.2882321279413769`}, {4.61714668114571, 1.3452772337084773`}, {
       4.61714668114571, 1.3452772337084773`}, {4.604155509574688, 
       1.2882321279413769`}, {4.604155509574688, 1.2882321279413769`}}, {{
       4.604155509574688, 1.2882321279413769`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}, {
       4.604155509574688, 1.2882321279413769`}, {4.604155509574688, 
       1.2882321279413769`}}, {{4.604155509574688, 1.2882321279413769`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}, {4.604155509574688, 1.2882321279413769`}, {
       4.604155509574688, 1.2882321279413769`}}, {{4.61714668114571, 
       1.3452772337084773`}, {4.67002552391586, 1.4023223394755777`}, {
       4.67002552391586, 1.4023223394755777`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}}, {{
       4.61714668114571, 1.3452772337084773`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}, {
       4.61714668114571, 1.3452772337084773`}, {4.61714668114571, 
       1.3452772337084773`}}, {{4.61714668114571, 1.3452772337084773`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}, {4.61714668114571, 1.3452772337084773`}, {
       4.61714668114571, 1.3452772337084773`}}, {{4.61714668114571, 
       1.3452772337084773`}, {4.67002552391586, 1.4023223394755777`}, {
       4.67002552391586, 1.4023223394755777`}, {4.61714668114571, 
       1.3452772337084773`}, {4.61714668114571, 1.3452772337084773`}}, {{
       4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}, {{4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.2139151538961537`}, {4.844672477568572, 
       1.2139151538961537`}, {4.867635566939376, 1.2882321279413769`}, {
       4.867635566939376, 1.2882321279413769`}}, {{4.867635566939376, 
       1.2882321279413769`}, {4.844672477568572, 1.2139151538961537`}, {
       4.844672477568572, 1.2139151538961537`}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}}, {{
       4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}}, {{4.844672477568572, 1.2139151538961537`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.844672477568572, 1.2139151538961537`}, {
       4.844672477568572, 1.2139151538961537`}}, {{4.844672477568572, 
       1.2139151538961537`}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}, {4.844672477568572, 
       1.2139151538961537`}, {4.844672477568572, 1.2139151538961537`}}, {{
       4.844672477568572, 1.2139151538961537`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}, {
       4.844672477568572, 1.2139151538961537`}, {4.844672477568572, 
       1.2139151538961537`}}, {{4.844672477568572, 1.2139151538961537`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}, {4.844672477568572, 1.2139151538961537`}, {
       4.844672477568572, 1.2139151538961537`}}, {{4.801765552598204, 
       1.174141916407176}, {4.745867456056814, 1.1568700481290533`}, {
       4.745867456056814, 1.1568700481290533`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}}, {{
       4.801765552598204, 1.174141916407176}, {4.745867456056814, 
       1.1568700481290533`}, {4.745867456056814, 1.1568700481290533`}, {
       4.801765552598204, 1.174141916407176}, {4.801765552598204, 
       1.174141916407176}}, {{4.801765552598204, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}, {4.801765552598204, 1.174141916407176}, {
       4.801765552598204, 1.174141916407176}}, {{4.801765552598204, 
       1.174141916407176}, {4.745867456056814, 1.1568700481290533`}, {
       4.745867456056814, 1.1568700481290533`}, {4.801765552598204, 
       1.174141916407176}, {4.801765552598204, 1.174141916407176}}, {{
       4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}}, {{4.745867456056814, 1.1568700481290533`}, {
       4.67002552391586, 1.174141916407176}, {4.67002552391586, 
       1.174141916407176}, {4.745867456056814, 1.1568700481290533`}, {
       4.745867456056814, 1.1568700481290533`}}, {{4.745867456056814, 
       1.1568700481290533`}, {4.67002552391586, 1.174141916407176}, {
       4.67002552391586, 1.174141916407176}, {4.745867456056814, 
       1.1568700481290533`}, {4.745867456056814, 1.1568700481290533`}}, {{
       4.745867456056814, 1.1568700481290533`}, {4.67002552391586, 
       1.174141916407176}, {4.67002552391586, 1.174141916407176}, {
       4.745867456056814, 1.1568700481290533`}, {4.745867456056814, 
       1.1568700481290533`}}, {{4.67002552391586, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}, {4.67002552391586, 1.4023223394755777`}, {
       4.67002552391586, 1.4023223394755777`}}, {{4.67002552391586, 
       1.4023223394755777`}, {4.745867456056814, 1.4195942077537005`}, {
       4.745867456056814, 1.4195942077537005`}, {4.67002552391586, 
       1.4023223394755777`}, {4.67002552391586, 1.4023223394755777`}}, {{
       4.67002552391586, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}, {
       4.67002552391586, 1.4023223394755777`}, {4.67002552391586, 
       1.4023223394755777`}}, {{4.67002552391586, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}, {4.67002552391586, 1.4023223394755777`}, {
       4.67002552391586, 1.4023223394755777`}}, {{4.745867456056814, 
       1.4195942077537005`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}}, {{
       4.745867456056814, 1.4195942077537005`}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}, {
       4.745867456056814, 1.4195942077537005`}, {4.745867456056814, 
       1.4195942077537005`}}, {{4.745867456056814, 1.4195942077537005`}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}, {4.745867456056814, 1.4195942077537005`}, {
       4.745867456056814, 1.4195942077537005`}}, {{4.745867456056814, 
       1.4195942077537005`}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}, {4.745867456056814, 
       1.4195942077537005`}, {4.745867456056814, 1.4195942077537005`}}, {{
       4.801765552598204, 1.4023223394755777`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}, {{4.801765552598204, 1.4023223394755777`}, {
       4.844672477568572, 1.3625491019866}, {4.844672477568572, 
       1.3625491019866}, {4.801765552598204, 1.4023223394755777`}, {
       4.801765552598204, 1.4023223394755777`}}, {{4.801765552598204, 
       1.4023223394755777`}, {4.844672477568572, 1.3625491019866}, {
       4.844672477568572, 1.3625491019866}, {4.801765552598204, 
       1.4023223394755777`}, {4.801765552598204, 1.4023223394755777`}}, {{
       4.801765552598204, 1.4023223394755777`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}, {
       4.801765552598204, 1.4023223394755777`}, {4.801765552598204, 
       1.4023223394755777`}}, {{4.844672477568572, 1.3625491019866}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}, {4.844672477568572, 1.3625491019866}, {
       4.844672477568572, 1.3625491019866}}, {{4.844672477568572, 
       1.3625491019866}, {4.867635566939376, 1.2882321279413769`}, {
       4.867635566939376, 1.2882321279413769`}, {4.844672477568572, 
       1.3625491019866}, {4.844672477568572, 1.3625491019866}}, {{
       4.844672477568572, 1.3625491019866}, {4.867635566939376, 
       1.2882321279413769`}, {4.867635566939376, 1.2882321279413769`}, {
       4.844672477568572, 1.3625491019866}, {4.844672477568572, 
       1.3625491019866}}, {{4.844672477568572, 1.3625491019866}, {
       4.867635566939376, 1.2882321279413769`}, {4.867635566939376, 
       1.2882321279413769`}, {4.844672477568572, 1.3625491019866}, {
       4.844672477568572, 1.3625491019866}}, {{4.639631419250643, 
       1.571161184081378}, {4.577647285921705, 1.6380289757424187`}, {
       4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.7717645590644997`}, {4.639631419250643, 1.8386323507255404`}, {
       4.639631419250643, 1.8386323507255404`}, {4.577647285921705, 
       1.7717645590644997`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}}, {{
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}, {{4.871268244344349, 1.7048967674034592`}, {
       4.844351104735391, 1.617783037478517}, {4.7940559693131135`, 
       1.571161184081378}, {4.728532692188538, 1.5509152458174764`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}, {4.728532692188538, 1.5509152458174764`}, {
       4.7940559693131135`, 1.571161184081378}, {4.8443511047353915`, 
       1.617783037478517}, {4.871268244344349, 1.7048967674034592`}, {
       4.871268244344349, 1.7048967674034592`}}, {{4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}}, {{
       4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349, 
       1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.844351104735391, 1.7920104973284015`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}, {{4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}}, {{4.639631419250643, 
       1.571161184081378}, {4.577647285921705, 1.6380289757424187`}, {
       4.577647285921705, 1.6380289757424187`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}}, {{
       4.639631419250643, 1.571161184081378}, {4.577647285921705, 
       1.6380289757424187`}, {4.577647285921705, 1.6380289757424187`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}}, {{4.639631419250643, 1.571161184081378}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}, {4.639631419250643, 1.571161184081378}, {
       4.639631419250643, 1.571161184081378}}, {{4.639631419250643, 
       1.571161184081378}, {4.577647285921705, 1.6380289757424187`}, {
       4.577647285921705, 1.6380289757424187`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}}, {{
       4.577647285921705, 1.6380289757424187`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}}, {{4.577647285921705, 1.6380289757424187`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}, {4.577647285921705, 1.6380289757424187`}, {
       4.577647285921705, 1.6380289757424187`}}, {{4.577647285921705, 
       1.6380289757424187`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.6380289757424187`}, {4.577647285921705, 1.6380289757424187`}}, {{
       4.577647285921705, 1.6380289757424187`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.6380289757424187`}, {4.577647285921705, 
       1.6380289757424187`}}, {{4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}}, {{4.562419144219407, 
       1.7048967674034592`}, {4.577647285921705, 1.7717645590644997`}, {
       4.577647285921705, 1.7717645590644997`}, {4.562419144219407, 
       1.7048967674034592`}, {4.562419144219407, 1.7048967674034592`}}, {{
       4.562419144219407, 1.7048967674034592`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}, {
       4.562419144219407, 1.7048967674034592`}, {4.562419144219407, 
       1.7048967674034592`}}, {{4.562419144219407, 1.7048967674034592`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}, {4.562419144219407, 1.7048967674034592`}, {
       4.562419144219407, 1.7048967674034592`}}, {{4.577647285921705, 
       1.7717645590644997`}, {4.639631419250643, 1.8386323507255404`}, {
       4.639631419250643, 1.8386323507255404`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}}, {{
       4.577647285921705, 1.7717645590644997`}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}, {
       4.577647285921705, 1.7717645590644997`}, {4.577647285921705, 
       1.7717645590644997`}}, {{4.577647285921705, 1.7717645590644997`}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}, {4.577647285921705, 1.7717645590644997`}, {
       4.577647285921705, 1.7717645590644997`}}, {{4.577647285921705, 
       1.7717645590644997`}, {4.639631419250643, 1.8386323507255404`}, {
       4.639631419250643, 1.8386323507255404`}, {4.577647285921705, 
       1.7717645590644997`}, {4.577647285921705, 1.7717645590644997`}}, {{
       4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}, {{4.871268244344349, 1.7048967674034592`}, {
       4.844351104735391, 1.617783037478517}, {4.844351104735391, 
       1.617783037478517}, {4.871268244344349, 1.7048967674034592`}, {
       4.871268244344349, 1.7048967674034592`}}, {{4.871268244344349, 
       1.7048967674034592`}, {4.844351104735391, 1.617783037478517}, {
       4.844351104735391, 1.617783037478517}, {4.871268244344349, 
       1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}}, {{
       4.871268244344349, 1.7048967674034592`}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}}, {{4.844351104735391, 1.617783037478517}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.844351104735391, 1.617783037478517}, {
       4.844351104735391, 1.617783037478517}}, {{4.844351104735391, 
       1.617783037478517}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}, {4.844351104735391, 
       1.617783037478517}, {4.844351104735391, 1.617783037478517}}, {{
       4.844351104735391, 1.617783037478517}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}, {
       4.844351104735391, 1.617783037478517}, {4.844351104735391, 
       1.617783037478517}}, {{4.844351104735391, 1.617783037478517}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}, {4.844351104735391, 1.617783037478517}, {
       4.844351104735391, 1.617783037478517}}, {{4.7940559693131135`, 
       1.571161184081378}, {4.728532692188538, 1.5509152458174764`}, {
       4.728532692188538, 1.5509152458174764`}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}}, {{
       4.7940559693131135`, 1.571161184081378}, {4.728532692188538, 
       1.5509152458174764`}, {4.728532692188538, 1.5509152458174764`}, {
       4.7940559693131135`, 1.571161184081378}, {4.7940559693131135`, 
       1.571161184081378}}, {{4.7940559693131135`, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}, {4.7940559693131135`, 1.571161184081378}, {
       4.7940559693131135`, 1.571161184081378}}, {{4.7940559693131135`, 
       1.571161184081378}, {4.728532692188538, 1.5509152458174764`}, {
       4.728532692188538, 1.5509152458174764`}, {4.7940559693131135`, 
       1.571161184081378}, {4.7940559693131135`, 1.571161184081378}}, {{
       4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}}, {{4.728532692188538, 1.5509152458174764`}, {
       4.639631419250643, 1.571161184081378}, {4.639631419250643, 
       1.571161184081378}, {4.728532692188538, 1.5509152458174764`}, {
       4.728532692188538, 1.5509152458174764`}}, {{4.728532692188538, 
       1.5509152458174764`}, {4.639631419250643, 1.571161184081378}, {
       4.639631419250643, 1.571161184081378}, {4.728532692188538, 
       1.5509152458174764`}, {4.728532692188538, 1.5509152458174764`}}, {{
       4.728532692188538, 1.5509152458174764`}, {4.639631419250643, 
       1.571161184081378}, {4.639631419250643, 1.571161184081378}, {
       4.728532692188538, 1.5509152458174764`}, {4.728532692188538, 
       1.5509152458174764`}}, {{4.639631419250643, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}, {4.639631419250643, 1.8386323507255404`}, {
       4.639631419250643, 1.8386323507255404`}}, {{4.639631419250643, 
       1.8386323507255404`}, {4.728532692188538, 1.858878288989442}, {
       4.728532692188538, 1.858878288989442}, {4.639631419250643, 
       1.8386323507255404`}, {4.639631419250643, 1.8386323507255404`}}, {{
       4.639631419250643, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}, {
       4.639631419250643, 1.8386323507255404`}, {4.639631419250643, 
       1.8386323507255404`}}, {{4.639631419250643, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}, {4.639631419250643, 1.8386323507255404`}, {
       4.639631419250643, 1.8386323507255404`}}, {{4.728532692188538, 
       1.858878288989442}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}}, {{
       4.728532692188538, 1.858878288989442}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.728532692188538, 1.858878288989442}, {4.728532692188538, 
       1.858878288989442}}, {{4.728532692188538, 1.858878288989442}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.728532692188538, 1.858878288989442}, {
       4.728532692188538, 1.858878288989442}}, {{4.728532692188538, 
       1.858878288989442}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.728532692188538, 
       1.858878288989442}, {4.728532692188538, 1.858878288989442}}, {{
       4.7940559693131135`, 1.8386323507255404`}, {4.844351104735391, 
       1.7920104973284015`}, {4.844351104735391, 1.7920104973284015`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}}, {{4.7940559693131135`, 1.8386323507255404`}, {
       4.844351104735391, 1.7920104973284015`}, {4.844351104735391, 
       1.7920104973284015`}, {4.7940559693131135`, 1.8386323507255404`}, {
       4.7940559693131135`, 1.8386323507255404`}}, {{4.7940559693131135`, 
       1.8386323507255404`}, {4.844351104735391, 1.7920104973284015`}, {
       4.844351104735391, 1.7920104973284015`}, {4.7940559693131135`, 
       1.8386323507255404`}, {4.7940559693131135`, 1.8386323507255404`}}, {{
       4.7940559693131135`, 1.8386323507255404`}, {4.844351104735391, 
       1.7920104973284015`}, {4.844351104735391, 1.7920104973284015`}, {
       4.7940559693131135`, 1.8386323507255404`}, {4.7940559693131135`, 
       1.8386323507255404`}}, {{4.8443511047353915`, 1.7920104973284015`}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}, {4.8443511047353915`, 1.7920104973284015`}, {
       4.8443511047353915`, 1.7920104973284015`}}, {{4.8443511047353915`, 
       1.7920104973284015`}, {4.871268244344349, 1.7048967674034592`}, {
       4.871268244344349, 1.7048967674034592`}, {4.8443511047353915`, 
       1.7920104973284015`}, {4.8443511047353915`, 1.7920104973284015`}}, {{
       4.8443511047353915`, 1.7920104973284015`}, {4.871268244344349, 
       1.7048967674034592`}, {4.871268244344349, 1.7048967674034592`}, {
       4.8443511047353915`, 1.7920104973284015`}, {4.8443511047353915`, 
       1.7920104973284015`}}, {{4.8443511047353915`, 1.7920104973284015`}, {
       4.871268244344349, 1.7048967674034592`}, {4.871268244344349, 
       1.7048967674034592`}, {4.8443511047353915`, 1.7920104973284015`}, {
       4.8443511047353915`, 1.7920104973284015`}}, {{4.65232379860786, 
       2.1234835309221913`}, {4.588897298180285, 2.191907332121004}, {
       4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.3287549345186296`}, {4.65232379860786, 2.3971787357174423`}, {
       4.65232379860786, 2.3971787357174423`}, {4.588897298180285, 
       2.3287549345186296`}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}}, {{
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}, {{4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.1711902720769864`}, {4.810341798772308, 
       2.1234835309221913`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.810341798772308, 2.1234835309221913`}, {4.861807299006651, 
       2.1711902720769864`}, {4.889350798854532, 2.260331133319817}, {
       4.889350798854532, 2.260331133319817}}, {{4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}}, {{
       4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.810341798772308, 2.3971787357174423`}, {
       4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.810341798772308, 
       2.3971787357174423`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}, {{4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}}, {{4.65232379860786, 
       2.1234835309221913`}, {4.588897298180285, 2.191907332121004}, {
       4.588897298180285, 2.191907332121004}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}}, {{
       4.65232379860786, 2.1234835309221913`}, {4.588897298180285, 
       2.191907332121004}, {4.588897298180285, 2.191907332121004}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}}, {{4.65232379860786, 2.1234835309221913`}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}, {4.65232379860786, 2.1234835309221913`}, {
       4.65232379860786, 2.1234835309221913`}}, {{4.65232379860786, 
       2.1234835309221913`}, {4.588897298180285, 2.191907332121004}, {
       4.588897298180285, 2.191907332121004}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}}, {{
       4.588897298180285, 2.191907332121004}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}}, {{4.588897298180285, 2.191907332121004}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}, {4.588897298180285, 2.191907332121004}, {
       4.588897298180285, 2.191907332121004}}, {{4.588897298180285, 
       2.191907332121004}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.191907332121004}, {4.588897298180285, 2.191907332121004}}, {{
       4.588897298180285, 2.191907332121004}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.191907332121004}, {4.588897298180285, 
       2.191907332121004}}, {{4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}}, {{4.573314798525636, 
       2.260331133319817}, {4.588897298180285, 2.3287549345186296`}, {
       4.588897298180285, 2.3287549345186296`}, {4.573314798525636, 
       2.260331133319817}, {4.573314798525636, 2.260331133319817}}, {{
       4.573314798525636, 2.260331133319817}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}, {
       4.573314798525636, 2.260331133319817}, {4.573314798525636, 
       2.260331133319817}}, {{4.573314798525636, 2.260331133319817}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}, {4.573314798525636, 2.260331133319817}, {
       4.573314798525636, 2.260331133319817}}, {{4.588897298180285, 
       2.3287549345186296`}, {4.65232379860786, 2.3971787357174423`}, {
       4.65232379860786, 2.3971787357174423`}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}}, {{
       4.588897298180285, 2.3287549345186296`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}, {
       4.588897298180285, 2.3287549345186296`}, {4.588897298180285, 
       2.3287549345186296`}}, {{4.588897298180285, 2.3287549345186296`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}, {4.588897298180285, 2.3287549345186296`}, {
       4.588897298180285, 2.3287549345186296`}}, {{4.588897298180285, 
       2.3287549345186296`}, {4.65232379860786, 2.3971787357174423`}, {
       4.65232379860786, 2.3971787357174423`}, {4.588897298180285, 
       2.3287549345186296`}, {4.588897298180285, 2.3287549345186296`}}, {{
       4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}, {{4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.1711902720769864`}, {4.861807299006651, 
       2.1711902720769864`}, {4.889350798854532, 2.260331133319817}, {
       4.889350798854532, 2.260331133319817}}, {{4.889350798854532, 
       2.260331133319817}, {4.861807299006651, 2.1711902720769864`}, {
       4.861807299006651, 2.1711902720769864`}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}}, {{
       4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}}, {{4.861807299006651, 2.1711902720769864`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.861807299006651, 2.1711902720769864`}, {
       4.861807299006651, 2.1711902720769864`}}, {{4.861807299006651, 
       2.1711902720769864`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}, {4.861807299006651, 
       2.1711902720769864`}, {4.861807299006651, 2.1711902720769864`}}, {{
       4.861807299006651, 2.1711902720769864`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}, {
       4.861807299006651, 2.1711902720769864`}, {4.861807299006651, 
       2.1711902720769864`}}, {{4.861807299006651, 2.1711902720769864`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}, {4.861807299006651, 2.1711902720769864`}, {
       4.861807299006651, 2.1711902720769864`}}, {{4.810341798772308, 
       2.1234835309221913`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}}, {{
       4.810341798772308, 2.1234835309221913`}, {4.7432937988833155`, 
       2.1027664708781733`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.810341798772308, 2.1234835309221913`}, {4.810341798772308, 
       2.1234835309221913`}}, {{4.810341798772308, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}, {4.810341798772308, 2.1234835309221913`}, {
       4.810341798772308, 2.1234835309221913`}}, {{4.810341798772308, 
       2.1234835309221913`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.810341798772308, 
       2.1234835309221913`}, {4.810341798772308, 2.1234835309221913`}}, {{
       4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}}, {{4.7432937988833155`, 2.1027664708781733`}, {
       4.65232379860786, 2.1234835309221913`}, {4.65232379860786, 
       2.1234835309221913`}, {4.7432937988833155`, 2.1027664708781733`}, {
       4.7432937988833155`, 2.1027664708781733`}}, {{4.7432937988833155`, 
       2.1027664708781733`}, {4.65232379860786, 2.1234835309221913`}, {
       4.65232379860786, 2.1234835309221913`}, {4.7432937988833155`, 
       2.1027664708781733`}, {4.7432937988833155`, 2.1027664708781733`}}, {{
       4.7432937988833155`, 2.1027664708781733`}, {4.65232379860786, 
       2.1234835309221913`}, {4.65232379860786, 2.1234835309221913`}, {
       4.7432937988833155`, 2.1027664708781733`}, {4.7432937988833155`, 
       2.1027664708781733`}}, {{4.65232379860786, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.65232379860786, 2.3971787357174423`}, {
       4.65232379860786, 2.3971787357174423`}}, {{4.65232379860786, 
       2.3971787357174423`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.65232379860786, 
       2.3971787357174423`}, {4.65232379860786, 2.3971787357174423`}}, {{
       4.65232379860786, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.65232379860786, 2.3971787357174423`}, {4.65232379860786, 
       2.3971787357174423`}}, {{4.65232379860786, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.65232379860786, 2.3971787357174423`}, {
       4.65232379860786, 2.3971787357174423`}}, {{4.7432937988833155`, 
       2.4178957957614604`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}}, {{
       4.7432937988833155`, 2.4178957957614604`}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}, {
       4.7432937988833155`, 2.4178957957614604`}, {4.7432937988833155`, 
       2.4178957957614604`}}, {{4.7432937988833155`, 2.4178957957614604`}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}, {4.7432937988833155`, 2.4178957957614604`}, {
       4.7432937988833155`, 2.4178957957614604`}}, {{4.7432937988833155`, 
       2.4178957957614604`}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}, {4.7432937988833155`, 
       2.4178957957614604`}, {4.7432937988833155`, 2.4178957957614604`}}, {{
       4.810341798772308, 2.3971787357174423`}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}, {{4.810341798772308, 2.3971787357174423`}, {
       4.861807299006651, 2.349471994562647}, {4.861807299006651, 
       2.349471994562647}, {4.810341798772308, 2.3971787357174423`}, {
       4.810341798772308, 2.3971787357174423`}}, {{4.810341798772308, 
       2.3971787357174423`}, {4.861807299006651, 2.349471994562647}, {
       4.861807299006651, 2.349471994562647}, {4.810341798772308, 
       2.3971787357174423`}, {4.810341798772308, 2.3971787357174423`}}, {{
       4.810341798772308, 2.3971787357174423`}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}, {
       4.810341798772308, 2.3971787357174423`}, {4.810341798772308, 
       2.3971787357174423`}}, {{4.861807299006651, 2.349471994562647}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}, {4.861807299006651, 2.349471994562647}, {
       4.861807299006651, 2.349471994562647}}, {{4.861807299006651, 
       2.349471994562647}, {4.889350798854532, 2.260331133319817}, {
       4.889350798854532, 2.260331133319817}, {4.861807299006651, 
       2.349471994562647}, {4.861807299006651, 2.349471994562647}}, {{
       4.861807299006651, 2.349471994562647}, {4.889350798854532, 
       2.260331133319817}, {4.889350798854532, 2.260331133319817}, {
       4.861807299006651, 2.349471994562647}, {4.861807299006651, 
       2.349471994562647}}, {{4.861807299006651, 2.349471994562647}, {
       4.889350798854532, 2.260331133319817}, {4.889350798854532, 
       2.260331133319817}, {4.861807299006651, 2.349471994562647}, {
       4.861807299006651, 2.349471994562647}}, {{4.6722871712835765`, 
       2.6362287567121045`}, {4.6088464502554665`, 2.7046678989361577`}, {
       4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`, 
       2.841546183384265}, {4.6722871712835765`, 2.909985325608318}, {
       4.6722871712835765`, 2.909985325608318}, {4.6088464502554665`, 
       2.841546183384265}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}}, {{
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}, {{4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.6839461940034393`}, {4.830340600028235, 
       2.6362287567121045`}, {4.763277567576878, 2.615507051779386}, {
       4.672287171283577, 2.6362287567121045`}, {4.672287171283577, 
       2.6362287567121045`}, {4.763277567576878, 2.615507051779386}, {
       4.830340600028235, 2.6362287567121045`}, {4.881817639135372, 
       2.6839461940034393`}, {4.909367314400563, 2.7731070411602112`}, {
       4.909367314400563, 2.7731070411602112`}}, {{4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}}, {{
       4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.830340600028235, 2.909985325608318}, {
       4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.830340600028235, 
       2.909985325608318}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}, {{4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}}, {{4.6722871712835765`, 
       2.6362287567121045`}, {4.6088464502554665`, 2.7046678989361577`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}}, {{
       4.6722871712835765`, 2.6362287567121045`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6088464502554665`, 2.7046678989361577`}, {
       4.6722871712835765`, 2.6362287567121045`}, {4.6722871712835765`, 
       2.6362287567121045`}}, {{4.6722871712835765`, 2.6362287567121045`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}}, {{4.6722871712835765`, 
       2.6362287567121045`}, {4.6088464502554665`, 2.7046678989361577`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}}, {{
       4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}}, {{4.6088464502554665`, 2.7046678989361577`}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}, {4.6088464502554665`, 2.7046678989361577`}, {
       4.6088464502554665`, 2.7046678989361577`}}, {{4.6088464502554665`, 
       2.7046678989361577`}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`, 
       2.7046678989361577`}, {4.6088464502554665`, 2.7046678989361577`}}, {{
       4.6088464502554665`, 2.7046678989361577`}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.7046678989361577`}, {4.6088464502554665`, 
       2.7046678989361577`}}, {{4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}}, {{4.593260456911248, 
       2.7731070411602112`}, {4.6088464502554665`, 2.841546183384265}, {
       4.6088464502554665`, 2.841546183384265}, {4.593260456911248, 
       2.7731070411602112`}, {4.593260456911248, 2.7731070411602112`}}, {{
       4.593260456911248, 2.7731070411602112`}, {4.6088464502554665`, 
       2.841546183384265}, {4.6088464502554665`, 2.841546183384265}, {
       4.593260456911248, 2.7731070411602112`}, {4.593260456911248, 
       2.7731070411602112`}}, {{4.593260456911248, 2.7731070411602112`}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}, {4.593260456911248, 2.7731070411602112`}, {
       4.593260456911248, 2.7731070411602112`}}, {{4.6088464502554665`, 
       2.841546183384265}, {4.672287171283577, 2.909985325608318}, {
       4.672287171283577, 2.909985325608318}, {4.6088464502554665`, 
       2.841546183384265}, {4.6088464502554665`, 2.841546183384265}}, {{
       4.6088464502554665`, 2.841546183384265}, {4.672287171283577, 
       2.909985325608318}, {4.672287171283577, 2.909985325608318}, {
       4.6088464502554665`, 2.841546183384265}, {4.6088464502554665`, 
       2.841546183384265}}, {{4.6088464502554665`, 2.841546183384265}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}, {4.6088464502554665`, 2.841546183384265}, {
       4.6088464502554665`, 2.841546183384265}}, {{4.6088464502554665`, 
       2.841546183384265}, {4.672287171283577, 2.909985325608318}, {
       4.672287171283577, 2.909985325608318}, {4.6088464502554665`, 
       2.841546183384265}, {4.6088464502554665`, 2.841546183384265}}, {{
       4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}, {{4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.6839461940034393`}, {4.881817639135372, 
       2.6839461940034393`}, {4.909367314400563, 2.7731070411602112`}, {
       4.909367314400563, 2.7731070411602112`}}, {{4.909367314400563, 
       2.7731070411602112`}, {4.881817639135372, 2.6839461940034393`}, {
       4.881817639135372, 2.6839461940034393`}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}}, {{
       4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}}, {{4.881817639135372, 2.6839461940034393`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.881817639135372, 2.6839461940034393`}, {
       4.881817639135372, 2.6839461940034393`}}, {{4.881817639135372, 
       2.6839461940034393`}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}, {4.881817639135372, 
       2.6839461940034393`}, {4.881817639135372, 2.6839461940034393`}}, {{
       4.881817639135372, 2.6839461940034393`}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}, {
       4.881817639135372, 2.6839461940034393`}, {4.881817639135372, 
       2.6839461940034393`}}, {{4.881817639135372, 2.6839461940034393`}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}, {4.881817639135372, 2.6839461940034393`}, {
       4.881817639135372, 2.6839461940034393`}}, {{4.830340600028235, 
       2.6362287567121045`}, {4.763277567576878, 2.615507051779386}, {
       4.763277567576878, 2.615507051779386}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}}, {{
       4.830340600028235, 2.6362287567121045`}, {4.763277567576878, 
       2.615507051779386}, {4.763277567576878, 2.615507051779386}, {
       4.830340600028235, 2.6362287567121045`}, {4.830340600028235, 
       2.6362287567121045`}}, {{4.830340600028235, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}, {4.830340600028235, 2.6362287567121045`}, {
       4.830340600028235, 2.6362287567121045`}}, {{4.830340600028235, 
       2.6362287567121045`}, {4.763277567576878, 2.615507051779386}, {
       4.763277567576878, 2.615507051779386}, {4.830340600028235, 
       2.6362287567121045`}, {4.830340600028235, 2.6362287567121045`}}, {{
       4.763277567576878, 2.615507051779386}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}}, {{4.763277567576878, 2.615507051779386}, {
       4.6722871712835765`, 2.6362287567121045`}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.763277567576878, 2.615507051779386}, {
       4.763277567576878, 2.615507051779386}}, {{4.763277567576878, 
       2.615507051779386}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.6722871712835765`, 2.6362287567121045`}, {4.763277567576878, 
       2.615507051779386}, {4.763277567576878, 2.615507051779386}}, {{
       4.763277567576878, 2.615507051779386}, {4.6722871712835765`, 
       2.6362287567121045`}, {4.6722871712835765`, 2.6362287567121045`}, {
       4.763277567576878, 2.615507051779386}, {4.763277567576878, 
       2.615507051779386}}, {{4.672287171283577, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}, {4.672287171283577, 2.909985325608318}, {
       4.672287171283577, 2.909985325608318}}, {{4.672287171283577, 
       2.909985325608318}, {4.763277567576878, 2.9307070305410363`}, {
       4.763277567576878, 2.9307070305410363`}, {4.672287171283577, 
       2.909985325608318}, {4.672287171283577, 2.909985325608318}}, {{
       4.672287171283577, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}, {
       4.672287171283577, 2.909985325608318}, {4.672287171283577, 
       2.909985325608318}}, {{4.672287171283577, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}, {4.672287171283577, 2.909985325608318}, {
       4.672287171283577, 2.909985325608318}}, {{4.763277567576878, 
       2.9307070305410363`}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}}, {{
       4.763277567576878, 2.9307070305410363`}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}, {
       4.763277567576878, 2.9307070305410363`}, {4.763277567576878, 
       2.9307070305410363`}}, {{4.763277567576878, 2.9307070305410363`}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}, {4.763277567576878, 2.9307070305410363`}, {
       4.763277567576878, 2.9307070305410363`}}, {{4.763277567576878, 
       2.9307070305410363`}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}, {4.763277567576878, 
       2.9307070305410363`}, {4.763277567576878, 2.9307070305410363`}}, {{
       4.830340600028235, 2.909985325608318}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}, {{4.830340600028235, 2.909985325608318}, {
       4.881817639135372, 2.862267888316983}, {4.881817639135372, 
       2.862267888316983}, {4.830340600028235, 2.909985325608318}, {
       4.830340600028235, 2.909985325608318}}, {{4.830340600028235, 
       2.909985325608318}, {4.881817639135372, 2.862267888316983}, {
       4.881817639135372, 2.862267888316983}, {4.830340600028235, 
       2.909985325608318}, {4.830340600028235, 2.909985325608318}}, {{
       4.830340600028235, 2.909985325608318}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}, {
       4.830340600028235, 2.909985325608318}, {4.830340600028235, 
       2.909985325608318}}, {{4.881817639135372, 2.862267888316983}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}, {4.881817639135372, 2.862267888316983}, {
       4.881817639135372, 2.862267888316983}}, {{4.881817639135372, 
       2.862267888316983}, {4.909367314400563, 2.7731070411602112`}, {
       4.909367314400563, 2.7731070411602112`}, {4.881817639135372, 
       2.862267888316983}, {4.881817639135372, 2.862267888316983}}, {{
       4.881817639135372, 2.862267888316983}, {4.909367314400563, 
       2.7731070411602112`}, {4.909367314400563, 2.7731070411602112`}, {
       4.881817639135372, 2.862267888316983}, {4.881817639135372, 
       2.862267888316983}}, {{4.881817639135372, 2.862267888316983}, {
       4.909367314400563, 2.7731070411602112`}, {4.909367314400563, 
       2.7731070411602112`}, {4.881817639135372, 2.862267888316983}, {
       4.881817639135372, 2.862267888316983}}, {{4.6971938896706895`, 
       3.100537343278087}, {4.63188089426916, 3.1709962742127398`}, {
       4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.3119141360820463`}, {4.6971938896706895`, 3.382373067016699}, {
       4.6971938896706895`, 3.382373067016699}, {4.63188089426916, 
       3.3119141360820463`}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.6971938896706895`, 
       3.100537343278087}, {4.6971938896706895`, 3.100537343278087}}, {{
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}, {{4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.1496630264650856`}, {4.85991182063843, 
       3.100537343278087}, {4.790869611484357, 3.0792040955304327`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}, {4.790869611484357, 3.0792040955304327`}, {
       4.85991182063843, 3.100537343278087}, {4.912908059710163, 
       3.1496630264650856`}, {4.941270786122301, 3.241455205147393}, {
       4.941270786122301, 3.241455205147393}}, {{4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}}, {{
       4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.85991182063843, 3.382373067016699}, {
       4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.85991182063843, 
       3.382373067016699}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}, {{4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}}, {{4.6971938896706895`, 
       3.100537343278087}, {4.63188089426916, 3.1709962742127398`}, {
       4.63188089426916, 3.1709962742127398`}, {4.6971938896706895`, 
       3.100537343278087}, {4.6971938896706895`, 3.100537343278087}}, {{
       4.6971938896706895`, 3.100537343278087}, {4.63188089426916, 
       3.1709962742127398`}, {4.63188089426916, 3.1709962742127398`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}}, {{4.6971938896706895`, 3.100537343278087}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}, {4.6971938896706895`, 3.100537343278087}, {
       4.6971938896706895`, 3.100537343278087}}, {{4.6971938896706895`, 
       3.100537343278087}, {4.63188089426916, 3.1709962742127398`}, {
       4.63188089426916, 3.1709962742127398`}, {4.6971938896706895`, 
       3.100537343278087}, {4.6971938896706895`, 3.100537343278087}}, {{
       4.63188089426916, 3.1709962742127398`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}}, {{4.63188089426916, 3.1709962742127398`}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}, {4.63188089426916, 3.1709962742127398`}, {
       4.63188089426916, 3.1709962742127398`}}, {{4.63188089426916, 
       3.1709962742127398`}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.1709962742127398`}, {4.63188089426916, 3.1709962742127398`}}, {{
       4.63188089426916, 3.1709962742127398`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.1709962742127398`}, {4.63188089426916, 
       3.1709962742127398`}}, {{4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}}, {{4.615834924186819, 
       3.241455205147393}, {4.63188089426916, 3.3119141360820463`}, {
       4.63188089426916, 3.3119141360820463`}, {4.615834924186819, 
       3.241455205147393}, {4.615834924186819, 3.241455205147393}}, {{
       4.615834924186819, 3.241455205147393}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}, {
       4.615834924186819, 3.241455205147393}, {4.615834924186819, 
       3.241455205147393}}, {{4.615834924186819, 3.241455205147393}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}, {4.615834924186819, 3.241455205147393}, {
       4.615834924186819, 3.241455205147393}}, {{4.63188089426916, 
       3.3119141360820463`}, {4.6971938896706895`, 3.382373067016699}, {
       4.6971938896706895`, 3.382373067016699}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}}, {{
       4.63188089426916, 3.3119141360820463`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}, {
       4.63188089426916, 3.3119141360820463`}, {4.63188089426916, 
       3.3119141360820463`}}, {{4.63188089426916, 3.3119141360820463`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}, {4.63188089426916, 3.3119141360820463`}, {
       4.63188089426916, 3.3119141360820463`}}, {{4.63188089426916, 
       3.3119141360820463`}, {4.6971938896706895`, 3.382373067016699}, {
       4.6971938896706895`, 3.382373067016699}, {4.63188089426916, 
       3.3119141360820463`}, {4.63188089426916, 3.3119141360820463`}}, {{
       4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}, {{4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.1496630264650856`}, {4.912908059710163, 
       3.1496630264650856`}, {4.941270786122301, 3.241455205147393}, {
       4.941270786122301, 3.241455205147393}}, {{4.941270786122301, 
       3.241455205147393}, {4.912908059710163, 3.1496630264650856`}, {
       4.912908059710163, 3.1496630264650856`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}}, {{
       4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}}, {{4.912908059710163, 3.1496630264650856`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.912908059710163, 3.1496630264650856`}, {
       4.912908059710163, 3.1496630264650856`}}, {{4.912908059710163, 
       3.1496630264650856`}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}, {4.912908059710163, 
       3.1496630264650856`}, {4.912908059710163, 3.1496630264650856`}}, {{
       4.912908059710163, 3.1496630264650856`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}, {
       4.912908059710163, 3.1496630264650856`}, {4.912908059710163, 
       3.1496630264650856`}}, {{4.912908059710163, 3.1496630264650856`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}, {4.912908059710163, 3.1496630264650856`}, {
       4.912908059710163, 3.1496630264650856`}}, {{4.85991182063843, 
       3.100537343278087}, {4.790869611484357, 3.0792040955304327`}, {
       4.790869611484357, 3.0792040955304327`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}}, {{
       4.85991182063843, 3.100537343278087}, {4.790869611484357, 
       3.0792040955304327`}, {4.790869611484357, 3.0792040955304327`}, {
       4.85991182063843, 3.100537343278087}, {4.85991182063843, 
       3.100537343278087}}, {{4.85991182063843, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}, {4.85991182063843, 3.100537343278087}, {
       4.85991182063843, 3.100537343278087}}, {{4.85991182063843, 
       3.100537343278087}, {4.790869611484357, 3.0792040955304327`}, {
       4.790869611484357, 3.0792040955304327`}, {4.85991182063843, 
       3.100537343278087}, {4.85991182063843, 3.100537343278087}}, {{
       4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`, 
       3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}}, {{4.790869611484357, 3.0792040955304327`}, {
       4.6971938896706895`, 3.100537343278087}, {4.6971938896706895`, 
       3.100537343278087}, {4.790869611484357, 3.0792040955304327`}, {
       4.790869611484357, 3.0792040955304327`}}, {{4.790869611484357, 
       3.0792040955304327`}, {4.6971938896706895`, 3.100537343278087}, {
       4.6971938896706895`, 3.100537343278087}, {4.790869611484357, 
       3.0792040955304327`}, {4.790869611484357, 3.0792040955304327`}}, {{
       4.790869611484357, 3.0792040955304327`}, {4.6971938896706895`, 
       3.100537343278087}, {4.6971938896706895`, 3.100537343278087}, {
       4.790869611484357, 3.0792040955304327`}, {4.790869611484357, 
       3.0792040955304327`}}, {{4.6971938896706895`, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}, {4.6971938896706895`, 3.382373067016699}, {
       4.6971938896706895`, 3.382373067016699}}, {{4.6971938896706895`, 
       3.382373067016699}, {4.790869611484357, 3.4037063147643534`}, {
       4.790869611484357, 3.4037063147643534`}, {4.6971938896706895`, 
       3.382373067016699}, {4.6971938896706895`, 3.382373067016699}}, {{
       4.6971938896706895`, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}, {
       4.6971938896706895`, 3.382373067016699}, {4.6971938896706895`, 
       3.382373067016699}}, {{4.6971938896706895`, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}, {4.6971938896706895`, 3.382373067016699}, {
       4.6971938896706895`, 3.382373067016699}}, {{4.790869611484357, 
       3.4037063147643534`}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}}, {{
       4.790869611484357, 3.4037063147643534`}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}, {
       4.790869611484357, 3.4037063147643534`}, {4.790869611484357, 
       3.4037063147643534`}}, {{4.790869611484357, 3.4037063147643534`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}, {4.790869611484357, 3.4037063147643534`}, {
       4.790869611484357, 3.4037063147643534`}}, {{4.790869611484357, 
       3.4037063147643534`}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}, {4.790869611484357, 
       3.4037063147643534`}, {4.790869611484357, 3.4037063147643534`}}, {{
       4.85991182063843, 3.382373067016699}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}, {{4.85991182063843, 3.382373067016699}, {
       4.912908059710163, 3.3332473838297005`}, {4.912908059710163, 
       3.3332473838297005`}, {4.85991182063843, 3.382373067016699}, {
       4.85991182063843, 3.382373067016699}}, {{4.85991182063843, 
       3.382373067016699}, {4.912908059710163, 3.3332473838297005`}, {
       4.912908059710163, 3.3332473838297005`}, {4.85991182063843, 
       3.382373067016699}, {4.85991182063843, 3.382373067016699}}, {{
       4.85991182063843, 3.382373067016699}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}, {
       4.85991182063843, 3.382373067016699}, {4.85991182063843, 
       3.382373067016699}}, {{4.912908059710163, 3.3332473838297005`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}, {4.912908059710163, 3.3332473838297005`}, {
       4.912908059710163, 3.3332473838297005`}}, {{4.912908059710163, 
       3.3332473838297005`}, {4.941270786122301, 3.241455205147393}, {
       4.941270786122301, 3.241455205147393}, {4.912908059710163, 
       3.3332473838297005`}, {4.912908059710163, 3.3332473838297005`}}, {{
       4.912908059710163, 3.3332473838297005`}, {4.941270786122301, 
       3.241455205147393}, {4.941270786122301, 3.241455205147393}, {
       4.912908059710163, 3.3332473838297005`}, {4.912908059710163, 
       3.3332473838297005`}}, {{4.912908059710163, 3.3332473838297005`}, {
       4.941270786122301, 3.241455205147393}, {4.941270786122301, 
       3.241455205147393}, {4.912908059710163, 3.3332473838297005`}, {
       4.912908059710163, 3.3332473838297005`}}, {{4.703973804758928, 
       3.594499593022139}, {4.64378438788612, 3.659431264588667}, {
       4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.7892946077217244`}, {4.703973804758928, 3.8542262792882527`}, {
       4.703973804758928, 3.8542262792882527`}, {4.64378438788612, 
       3.7892946077217244`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}}, {{
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}, {{4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.639771536321107}, {4.8539270769903995`, 
       3.594499593022139}, {4.790300990282135, 3.5748398647545785`}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}, {4.790300990282135, 3.5748398647545785`}, {
       4.8539270769903995`, 3.594499593022139}, {4.902765944455737, 
       3.639771536321107}, {4.928903713106134, 3.7243629361551958`}, {
       4.928903713106134, 3.7243629361551958`}}, {{4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}}, {{
       4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}, {{4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}}, {{4.703973804758928, 
       3.594499593022139}, {4.64378438788612, 3.659431264588667}, {
       4.64378438788612, 3.659431264588667}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}}, {{
       4.703973804758928, 3.594499593022139}, {4.64378438788612, 
       3.659431264588667}, {4.64378438788612, 3.659431264588667}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}}, {{4.703973804758928, 3.594499593022139}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}, {4.703973804758928, 3.594499593022139}, {
       4.703973804758928, 3.594499593022139}}, {{4.703973804758928, 
       3.594499593022139}, {4.64378438788612, 3.659431264588667}, {
       4.64378438788612, 3.659431264588667}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}}, {{
       4.64378438788612, 3.659431264588667}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}}, {{4.64378438788612, 3.659431264588667}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}, {4.64378438788612, 3.659431264588667}, {
       4.64378438788612, 3.659431264588667}}, {{4.64378438788612, 
       3.659431264588667}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.659431264588667}, {4.64378438788612, 3.659431264588667}}, {{
       4.64378438788612, 3.659431264588667}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.659431264588667}, {4.64378438788612, 
       3.659431264588667}}, {{4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}}, {{4.628997168643194, 
       3.7243629361551958`}, {4.64378438788612, 3.7892946077217244`}, {
       4.64378438788612, 3.7892946077217244`}, {4.628997168643194, 
       3.7243629361551958`}, {4.628997168643194, 3.7243629361551958`}}, {{
       4.628997168643194, 3.7243629361551958`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}, {
       4.628997168643194, 3.7243629361551958`}, {4.628997168643194, 
       3.7243629361551958`}}, {{4.628997168643194, 3.7243629361551958`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}, {4.628997168643194, 3.7243629361551958`}, {
       4.628997168643194, 3.7243629361551958`}}, {{4.64378438788612, 
       3.7892946077217244`}, {4.703973804758928, 3.8542262792882527`}, {
       4.703973804758928, 3.8542262792882527`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}}, {{
       4.64378438788612, 3.7892946077217244`}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}, {
       4.64378438788612, 3.7892946077217244`}, {4.64378438788612, 
       3.7892946077217244`}}, {{4.64378438788612, 3.7892946077217244`}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}, {4.64378438788612, 3.7892946077217244`}, {
       4.64378438788612, 3.7892946077217244`}}, {{4.64378438788612, 
       3.7892946077217244`}, {4.703973804758928, 3.8542262792882527`}, {
       4.703973804758928, 3.8542262792882527`}, {4.64378438788612, 
       3.7892946077217244`}, {4.64378438788612, 3.7892946077217244`}}, {{
       4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}, {{4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.639771536321107}, {4.902765944455737, 
       3.639771536321107}, {4.928903713106134, 3.7243629361551958`}, {
       4.928903713106134, 3.7243629361551958`}}, {{4.928903713106134, 
       3.7243629361551958`}, {4.902765944455737, 3.639771536321107}, {
       4.902765944455737, 3.639771536321107}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}}, {{
       4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}}, {{4.902765944455737, 3.639771536321107}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.902765944455737, 3.639771536321107}, {
       4.902765944455737, 3.639771536321107}}, {{4.902765944455737, 
       3.639771536321107}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}, {4.902765944455737, 
       3.639771536321107}, {4.902765944455737, 3.639771536321107}}, {{
       4.902765944455737, 3.639771536321107}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}, {
       4.902765944455737, 3.639771536321107}, {4.902765944455737, 
       3.639771536321107}}, {{4.902765944455737, 3.639771536321107}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}, {4.902765944455737, 3.639771536321107}, {
       4.902765944455737, 3.639771536321107}}, {{4.8539270769903995`, 
       3.594499593022139}, {4.790300990282135, 3.5748398647545785`}, {
       4.790300990282135, 3.5748398647545785`}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}}, {{
       4.8539270769903995`, 3.594499593022139}, {4.790300990282135, 
       3.5748398647545785`}, {4.790300990282135, 3.5748398647545785`}, {
       4.8539270769903995`, 3.594499593022139}, {4.8539270769903995`, 
       3.594499593022139}}, {{4.8539270769903995`, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}, {4.8539270769903995`, 3.594499593022139}, {
       4.8539270769903995`, 3.594499593022139}}, {{4.8539270769903995`, 
       3.594499593022139}, {4.790300990282135, 3.5748398647545785`}, {
       4.790300990282135, 3.5748398647545785`}, {4.8539270769903995`, 
       3.594499593022139}, {4.8539270769903995`, 3.594499593022139}}, {{
       4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}}, {{4.790300990282135, 3.5748398647545785`}, {
       4.703973804758928, 3.594499593022139}, {4.703973804758928, 
       3.594499593022139}, {4.790300990282135, 3.5748398647545785`}, {
       4.790300990282135, 3.5748398647545785`}}, {{4.790300990282135, 
       3.5748398647545785`}, {4.703973804758928, 3.594499593022139}, {
       4.703973804758928, 3.594499593022139}, {4.790300990282135, 
       3.5748398647545785`}, {4.790300990282135, 3.5748398647545785`}}, {{
       4.790300990282135, 3.5748398647545785`}, {4.703973804758928, 
       3.594499593022139}, {4.703973804758928, 3.594499593022139}, {
       4.790300990282135, 3.5748398647545785`}, {4.790300990282135, 
       3.5748398647545785`}}, {{4.703973804758928, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}, {4.703973804758928, 3.8542262792882527`}, {
       4.703973804758928, 3.8542262792882527`}}, {{4.703973804758928, 
       3.8542262792882527`}, {4.790300990282135, 3.873886007555813}, {
       4.790300990282135, 3.873886007555813}, {4.703973804758928, 
       3.8542262792882527`}, {4.703973804758928, 3.8542262792882527`}}, {{
       4.703973804758928, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}, {
       4.703973804758928, 3.8542262792882527`}, {4.703973804758928, 
       3.8542262792882527`}}, {{4.703973804758928, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}, {4.703973804758928, 3.8542262792882527`}, {
       4.703973804758928, 3.8542262792882527`}}, {{4.790300990282135, 
       3.873886007555813}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}}, {{
       4.790300990282135, 3.873886007555813}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.790300990282135, 3.873886007555813}, {4.790300990282135, 
       3.873886007555813}}, {{4.790300990282135, 3.873886007555813}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.790300990282135, 3.873886007555813}, {
       4.790300990282135, 3.873886007555813}}, {{4.790300990282135, 
       3.873886007555813}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.790300990282135, 
       3.873886007555813}, {4.790300990282135, 3.873886007555813}}, {{
       4.8539270769903995`, 3.8542262792882527`}, {4.902765944455737, 
       3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}}, {{4.8539270769903995`, 3.8542262792882527`}, {
       4.902765944455737, 3.8089543359892843`}, {4.902765944455737, 
       3.8089543359892843`}, {4.8539270769903995`, 3.8542262792882527`}, {
       4.8539270769903995`, 3.8542262792882527`}}, {{4.8539270769903995`, 
       3.8542262792882527`}, {4.902765944455737, 3.8089543359892843`}, {
       4.902765944455737, 3.8089543359892843`}, {4.8539270769903995`, 
       3.8542262792882527`}, {4.8539270769903995`, 3.8542262792882527`}}, {{
       4.8539270769903995`, 3.8542262792882527`}, {4.902765944455737, 
       3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}, {
       4.8539270769903995`, 3.8542262792882527`}, {4.8539270769903995`, 
       3.8542262792882527`}}, {{4.902765944455737, 3.8089543359892843`}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}, {4.902765944455737, 3.8089543359892843`}, {
       4.902765944455737, 3.8089543359892843`}}, {{4.902765944455737, 
       3.8089543359892843`}, {4.928903713106134, 3.7243629361551958`}, {
       4.928903713106134, 3.7243629361551958`}, {4.902765944455737, 
       3.8089543359892843`}, {4.902765944455737, 3.8089543359892843`}}, {{
       4.902765944455737, 3.8089543359892843`}, {4.928903713106134, 
       3.7243629361551958`}, {4.928903713106134, 3.7243629361551958`}, {
       4.902765944455737, 3.8089543359892843`}, {4.902765944455737, 
       3.8089543359892843`}}, {{4.902765944455737, 3.8089543359892843`}, {
       4.928903713106134, 3.7243629361551958`}, {4.928903713106134, 
       3.7243629361551958`}, {4.902765944455737, 3.8089543359892843`}, {
       4.902765944455737, 3.8089543359892843`}}, {{
       4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}, {{
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}, {{
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}, {{
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}, {{
       4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}, {{
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}, {{
       4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}, {{
       4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}, {{
       4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}, {{
       4.892082355149725, -4.645943647484259}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}}, {{
       4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}, {{
       4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}, {{
       4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}, {{
       4.826232746576139, -4.574905824245002}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.574905824245002}, {
       4.826232746576139, -4.574905824245002}}, {{
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}, {{
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}, {{
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}, {{
       4.810054942410065, -4.503868001005745}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}, {
       4.810054942410065, -4.503868001005745}, {
       4.810054942410065, -4.503868001005745}}, {{
       4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}, {{
       4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}, {{
       4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}, {{
       4.826232746576139, -4.432830177766487}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}, {
       4.826232746576139, -4.432830177766487}, {
       4.826232746576139, -4.432830177766487}}, {{
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}, {{
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}, {{
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}, {{
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}}, {{
       5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}, {{
       5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}, {{
       5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}, {{
       5.1095688381007545`, -4.596414346479361}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}, {
       5.1095688381007545`, -4.596414346479361}, {
       5.1095688381007545`, -4.596414346479361}}, {{
       5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}, {{
       5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}, {{
       5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}, {{
       5.056137180629046, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}, {
       5.056137180629046, -4.645943647484259}, {
       5.056137180629046, -4.645943647484259}}, {{
       4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}, {{
       4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}, {{
       4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}, {{
       4.986527718991264, -4.667452169718618}, {
       4.892082355149725, -4.645943647484259}, {
       4.892082355149725, -4.645943647484259}, {
       4.986527718991264, -4.667452169718618}, {
       4.986527718991264, -4.667452169718618}}, {{
       4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}, {{
       4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}, {{
       4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}, {{
       4.892082355149725, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}, {
       4.892082355149725, -4.36179235452723}, {
       4.892082355149725, -4.36179235452723}}, {{
       4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}, {{
       4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}, {{
       4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}, {{
       4.986527718991264, -4.340283832292871}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}, {
       4.986527718991264, -4.340283832292871}, {
       4.986527718991264, -4.340283832292871}}, {{
       5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}, {{
       5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}, {{
       5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}, {{
       5.056137180629046, -4.36179235452723}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.056137180629046, -4.36179235452723}, {
       5.056137180629046, -4.36179235452723}}, {{
       5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}, {{
       5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}, {{
       5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}, {{
       5.1095688381007545`, -4.411321655532128}, {
       5.138164593368706, -4.503868001005745}, {
       5.138164593368706, -4.503868001005745}, {
       5.1095688381007545`, -4.411321655532128}, {
       5.1095688381007545`, -4.411321655532128}}, {{
       4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}, {{
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}, {{
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}, {{
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}, {{
       4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}, {{
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}, {{
       4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}, {{
       4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}, {{
       4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}, {{
       4.945798631849757, -4.140742422888196}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}}, {{
       4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}, {{
       4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}, {{
       4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}, {{
       4.886858498735221, -4.0771584647055175`}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -4.0771584647055175`}, {
       4.886858498735221, -4.0771584647055175`}}, {{
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}, {{
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}, {{
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}, {{
       4.872378201103934, -4.013574506522838}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}, {
       4.872378201103934, -4.013574506522838}, {
       4.872378201103934, -4.013574506522838}}, {{
       4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}, {{
       4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}, {{
       4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}, {{
       4.886858498735221, -3.949990548340159}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}, {
       4.886858498735221, -3.949990548340159}, {
       4.886858498735221, -3.949990548340159}}, {{
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}, {{
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}, {{
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}, {{
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}}, {{
       5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}, {{
       5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}, {{
       5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}, {{
       5.140464667585128, -4.096410138193803}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}, {
       5.140464667585128, -4.096410138193803}, {
       5.140464667585128, -4.096410138193803}}, {{
       5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}, {{
       5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}, {{
       5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}, {{
       5.092639493341404, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}, {
       5.092639493341404, -4.140742422888196}, {
       5.092639493341404, -4.140742422888196}}, {{
       5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}, {{
       5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}, {{
       5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}, {{
       5.030334021466393, -4.159994096376481}, {
       4.945798631849757, -4.140742422888196}, {
       4.945798631849757, -4.140742422888196}, {
       5.030334021466393, -4.159994096376481}, {
       5.030334021466393, -4.159994096376481}}, {{
       4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}, {{
       4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}, {{
       4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}, {{
       4.945798631849757, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}, {
       4.945798631849757, -3.88640659015748}, {
       4.945798631849757, -3.88640659015748}}, {{
       5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}, {{
       5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}, {{
       5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}, {{
       5.030334021466393, -3.8671549166691945`}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}, {
       5.030334021466393, -3.8671549166691945`}, {
       5.030334021466393, -3.8671549166691945`}}, {{
       5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}, {{
       5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}, {{
       5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}, {{
       5.092639493341404, -3.88640659015748}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}, {
       5.092639493341404, -3.88640659015748}, {
       5.092639493341404, -3.88640659015748}}, {{
       5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}, {{
       5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}, {{
       5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}, {{
       5.140464667585128, -3.930738874851874}, {
       5.166059924087228, -4.013574506522838}, {
       5.166059924087228, -4.013574506522838}, {
       5.140464667585128, -3.930738874851874}, {
       5.140464667585128, -3.930738874851874}}, {{
       4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}, {{
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}, {{
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}, {{
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}, {{
       4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}, {{
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}, {{
       4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}, {{
       4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}, {{
       4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}, {{
       4.921213546375, -3.634055668110461}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}}, {{
       4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}, {{
       4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}, {{
       4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}, {{
       4.855659859853627, -3.5633370822804005`}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.5633370822804005`}, {
       4.855659859853627, -3.5633370822804005`}}, {{
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}, {{
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}, {{
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}, {{
       4.839554757243611, -3.49261849645034}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}, {
       4.839554757243611, -3.49261849645034}, {
       4.839554757243611, -3.49261849645034}}, {{
       4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}, {{
       4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}, {{
       4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}, {{
       4.855659859853627, -3.42189991062028}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}, {
       4.855659859853627, -3.42189991062028}, {
       4.855659859853627, -3.42189991062028}}, {{
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}, {{
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}, {{
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}, {{
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}}, {{
       5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}, {{
       5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}, {{
       5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}, {{
       5.1377226651813155`, -3.584748947204602}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}, {
       5.1377226651813155`, -3.584748947204602}, {
       5.1377226651813155`, -3.584748947204602}}, {{
       5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}, {{
       5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}, {{
       5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}, {{
       5.084531124637781, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.084531124637781, -3.634055668110461}, {
       5.084531124637781, -3.634055668110461}}, {{
       5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}, {{
       5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}, {{
       5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}, {{
       5.01523448148423, -3.6554675330346624`}, {
       4.921213546375, -3.634055668110461}, {
       4.921213546375, -3.634055668110461}, {
       5.01523448148423, -3.6554675330346624`}, {
       5.01523448148423, -3.6554675330346624`}}, {{
       4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}, {{
       4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}, {{
       4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}, {{
       4.921213546375, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}, {
       4.921213546375, -3.351181324790219}, {
       4.921213546375, -3.351181324790219}}, {{
       5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}, {{
       5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}, {{
       5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}, {{
       5.01523448148423, -3.329769459866018}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}, {
       5.01523448148423, -3.329769459866018}, {
       5.01523448148423, -3.329769459866018}}, {{
       5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}, {{
       5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}, {{
       5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}, {{
       5.084531124637781, -3.351181324790219}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.084531124637781, -3.351181324790219}, {
       5.084531124637781, -3.351181324790219}}, {{
       5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}, {{
       5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}, {{
       5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}, {{
       5.1377226651813155`, -3.400488045696078}, {
       5.166189913769171, -3.49261849645034}, {
       5.166189913769171, -3.49261849645034}, {
       5.1377226651813155`, -3.400488045696078}, {
       5.1377226651813155`, -3.400488045696078}}, {{
       4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}, {{
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}, {{
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}, {{
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}, {{
       4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}, {{
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}, {{
       4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}, {{
       4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}, {{
       4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}, {{
       4.9183277754434735`, -3.113914835940567}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}}, {{
       4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}, {{
       4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}, {{
       4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}, {{
       4.855397949322326, -3.0460268414435965`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -3.0460268414435965`}, {
       4.855397949322326, -3.0460268414435965`}}, {{
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}, {{
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}, {{
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}, {{
       4.839937471648334, -2.9781388469466257`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}, {
       4.839937471648334, -2.9781388469466257`}, {
       4.839937471648334, -2.9781388469466257`}}, {{
       4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}, {{
       4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}, {{
       4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}, {{
       4.855397949322326, -2.910250852449655}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.855397949322326, -2.910250852449655}, {
       4.855397949322326, -2.910250852449655}}, {{
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}, {{
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}, {{
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}, {{
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}}, {{
       5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}, {{
       5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}, {{
       5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}, {{
       5.1261708720431125`, -3.066581672271763}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}, {
       5.1261708720431125`, -3.066581672271763}, {
       5.1261708720431125`, -3.066581672271763}}, {{
       5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}, {{
       5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}, {{
       5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}, {{
       5.075108383033753, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.075108383033753, -3.113914835940567}, {
       5.075108383033753, -3.113914835940567}}, {{
       5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}, {{
       5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}, {{
       5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}, {{
       5.008585416350402, -3.1344696667687333`}, {
       4.9183277754434735`, -3.113914835940567}, {
       4.9183277754434735`, -3.113914835940567}, {
       5.008585416350402, -3.1344696667687333`}, {
       5.008585416350402, -3.1344696667687333`}}, {{
       4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}, {{
       4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}, {{
       4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}, {{
       4.9183277754434735`, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}, {
       4.9183277754434735`, -2.8423628579526845`}, {
       4.9183277754434735`, -2.8423628579526845`}}, {{
       5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}, {{
       5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}, {{
       5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}, {{
       5.008585416350402, -2.821808027124518}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.008585416350402, -2.821808027124518}, {
       5.008585416350402, -2.821808027124518}}, {{
       5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}, {{
       5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}, {{
       5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}, {{
       5.075108383033753, -2.8423628579526845`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.075108383033753, -2.8423628579526845`}, {
       5.075108383033753, -2.8423628579526845`}}, {{
       5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}, {{
       5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}, {{
       5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}, {{
       5.1261708720431125`, -2.8896960216214884`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.153498686828893, -2.9781388469466257`}, {
       5.1261708720431125`, -2.8896960216214884`}, {
       5.1261708720431125`, -2.8896960216214884`}}, {{
       4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}, {{
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}, {{
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}, {{
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}, {{
       4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}, {{
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}, {{
       4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}, {{
       4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}, {{
       4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}, {{
       4.8981472584658166`, -2.5942348393593617`}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}}, {{
       4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}, {{
       4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}, {{
       4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}, {{
       4.839204812102839, -2.530648385670066}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.530648385670066}, {
       4.839204812102839, -2.530648385670066}}, {{
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}, {{
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}, {{
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}, {{
       4.824723946157159, -2.46706193198077}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.824723946157159, -2.46706193198077}, {
       4.824723946157159, -2.46706193198077}}, {{
       4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}, {{
       4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}, {{
       4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}, {{
       4.839204812102839, -2.4034754782914742`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.839204812102839, -2.4034754782914742`}, {
       4.839204812102839, -2.4034754782914742`}}, {{
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}, {{
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}, {{
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}, {{
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}}, {{
       5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}, {{
       5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}, {{
       5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}, {{
       5.092820934341784, -2.5499008147369584`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.092820934341784, -2.5499008147369584`}, {
       5.092820934341784, -2.5499008147369584`}}, {{
       5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}, {{
       5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}, {{
       5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}, {{
       5.044993883083131, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}, {
       5.044993883083131, -2.5942348393593617`}, {
       5.044993883083131, -2.5942348393593617`}}, {{
       4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}, {{
       4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}, {{
       4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}, {{
       4.982685965878798, -2.613487268426254}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.8981472584658166`, -2.5942348393593617`}, {
       4.982685965878798, -2.613487268426254}, {
       4.982685965878798, -2.613487268426254}}, {{
       4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}, {{
       4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}, {{
       4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}, {{
       4.8981472584658166`, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.8981472584658166`, -2.3398890246021784`}, {
       4.8981472584658166`, -2.3398890246021784`}}, {{
       4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}, {{
       4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}, {{
       4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}, {{
       4.982685965878798, -2.3206365955352863`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}, {
       4.982685965878798, -2.3206365955352863`}, {
       4.982685965878798, -2.3206365955352863`}}, {{
       5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}, {{
       5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}, {{
       5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}, {{
       5.044993883083131, -2.3398890246021784`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.044993883083131, -2.3398890246021784`}, {
       5.044993883083131, -2.3398890246021784`}}, {{
       5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}, {{
       5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}, {{
       5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}, {{
       5.092820934341784, -2.3842230492245817`}, {
       5.118417195391788, -2.46706193198077}, {
       5.118417195391788, -2.46706193198077}, {
       5.092820934341784, -2.3842230492245817`}, {
       5.092820934341784, -2.3842230492245817`}}, {{
       4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988245`}, {
       4.873652682593564, -1.8617779626988245`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}, {{
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}, {{
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}, {{
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}, {{
       4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}, {{
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}, {{
       4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}, {{
       4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}, {{
       4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}, {{
       4.873652682593564, -2.1314138113172003`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}}, {{
       4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}, {{
       4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}, {{
       4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}, {{
       4.811166902908543, -2.064004849162606}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -2.064004849162606}, {
       4.811166902908543, -2.064004849162606}}, {{
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}, {{
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}, {{
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}, {{
       4.795815517702068, -1.9965958870080123`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.795815517702068, -1.9965958870080123`}, {
       4.795815517702068, -1.9965958870080123`}}, {{
       4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}, {{
       4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}, {{
       4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}, {{
       4.811166902908543, -1.9291869248534184`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.811166902908543, -1.9291869248534184`}, {
       4.811166902908543, -1.9291869248534184`}}, {{
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}, {{
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}, {{
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}, {{
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}}, {{
       5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}, {{
       5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}, {{
       5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}, {{
       5.080029193441941, -2.0844146406678155`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.080029193441941, -2.0844146406678155`}, {
       5.080029193441941, -2.0844146406678155`}}, {{
       5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}, {{
       5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}, {{
       5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}, {{
       5.029327012376557, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}, {
       5.029327012376557, -2.1314138113172003`}, {
       5.029327012376557, -2.1314138113172003`}}, {{
       4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}, {{
       4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}, {{
       4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}, {{
       4.963273446104697, -2.151823602822409}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.873652682593564, -2.1314138113172003`}, {
       4.963273446104697, -2.151823602822409}, {
       4.963273446104697, -2.151823602822409}}, {{
       4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}, {{
       4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}, {{
       4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}, {{
       4.873652682593564, -1.8617779626988242`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.873652682593564, -1.8617779626988242`}, {
       4.873652682593564, -1.8617779626988242`}}, {{
       4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}, {{
       4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}, {{
       4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}, {{
       4.963273446104697, -1.8413681711936154`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}, {
       4.963273446104697, -1.8413681711936154`}, {
       4.963273446104697, -1.8413681711936154`}}, {{
       5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}, {{
       5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}, {{
       5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}, {{
       5.029327012376557, -1.8617779626988245`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.029327012376557, -1.8617779626988245`}, {
       5.029327012376557, -1.8617779626988245`}}, {{
       5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}, {{
       5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}, {{
       5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}, {{
       5.080029193441941, -1.9087771333482093`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.107164177268053, -1.9965958870080123`}, {
       5.080029193441941, -1.9087771333482093`}, {
       5.080029193441941, -1.9087771333482093`}}, {{
       4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}, {{
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}, {{
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}, {{
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}, {{
       4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}, {{
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}, {{
       4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}, {{
       4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}, {{
       4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}, {{
       4.964435657202186, -1.5786842774676382`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}}, {{
       4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}, {{
       4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}, {{
       4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}, {{
       4.907246422251852, -1.5169891686948926`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.5169891686948926`}, {
       4.907246422251852, -1.5169891686948926`}}, {{
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}, {{
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}, {{
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}, {{
       4.8931962818869295`, -1.4552940599221469`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.8931962818869295`, -1.4552940599221469`}, {
       4.8931962818869295`, -1.4552940599221469`}}, {{
       4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}, {{
       4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}, {{
       4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}, {{
       4.907246422251852, -1.3935989511494011`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.907246422251852, -1.3935989511494011`}, {
       4.907246422251852, -1.3935989511494011`}}, {{
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}, {{
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}, {{
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}, {{
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}}, {{
       5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}, {{
       5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}, {{
       5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}, {{
       5.153318869136678, -1.5356689445985054`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.153318869136678, -1.5356689445985054`}, {
       5.153318869136678, -1.5356689445985054`}}, {{
       5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}, {{
       5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}, {{
       5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}, {{
       5.106914407832697, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.106914407832697, -1.5786842774676382`}, {
       5.106914407832697, -1.5786842774676382`}}, {{
       5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}, {{
       5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}, {{
       5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}, {{
       5.046459806163794, -1.5973640533712512`}, {
       4.964435657202186, -1.5786842774676382`}, {
       4.964435657202186, -1.5786842774676382`}, {
       5.046459806163794, -1.5973640533712512`}, {
       5.046459806163794, -1.5973640533712512`}}, {{
       4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}, {{
       4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}, {{
       4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}, {{
       4.964435657202186, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}, {
       4.964435657202186, -1.3319038423766556`}, {
       4.964435657202186, -1.3319038423766556`}}, {{
       5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}, {{
       5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}, {{
       5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}, {{
       5.046459806163794, -1.3132240664730426`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.046459806163794, -1.3132240664730426`}, {
       5.046459806163794, -1.3132240664730426`}}, {{
       5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}, {{
       5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}, {{
       5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}, {{
       5.106914407832697, -1.3319038423766556`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.106914407832697, -1.3319038423766556`}, {
       5.106914407832697, -1.3319038423766556`}}, {{
       5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}, {{
       5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}, {{
       5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}, {{
       5.153318869136678, -1.3749191752457883`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.178153783147954, -1.4552940599221469`}, {
       5.153318869136678, -1.3749191752457883`}, {
       5.153318869136678, -1.3749191752457883`}}, {{
       4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}, {{
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}, {{
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}, {{
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}, {{
       4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}, {{
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}, {{
       4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}, {{
       4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}, {{
       4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}, {{
       4.96054102889468, -1.1298464948150062`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}}, {{
       4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}, {{
       4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}, {{
       4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}, {{
       4.901051240468712, -1.065669574613239}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -1.065669574613239}, {
       4.901051240468712, -1.065669574613239}}, {{
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}, {{
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}, {{
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}, {{
       4.886435904586176, -1.0014926544114717`}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}, {
       4.886435904586176, -1.0014926544114717`}, {
       4.886435904586176, -1.0014926544114717`}}, {{
       4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}, {{
       4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}, {{
       4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}, {{
       4.901051240468712, -0.9373157342097045}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}, {
       4.901051240468712, -0.9373157342097045}, {
       4.901051240468712, -0.9373157342097045}}, {{
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}, {{
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}, {{
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}, {{
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}}, {{
       5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}, {{
       5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}, {{
       5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}, {{
       5.157022452801794, -1.0851007825550043`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.157022452801794, -1.0851007825550043`}, {
       5.157022452801794, -1.0851007825550043`}}, {{
       5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}, {{
       5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}, {{
       5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}, {{
       5.108751277511685, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.108751277511685, -1.1298464948150062`}, {
       5.108751277511685, -1.1298464948150062`}}, {{
       5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}, {{
       5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}, {{
       5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}, {{
       5.04586476633904, -1.1492777027567715`}, {
       4.96054102889468, -1.1298464948150062`}, {
       4.96054102889468, -1.1298464948150062`}, {
       5.04586476633904, -1.1492777027567715`}, {
       5.04586476633904, -1.1492777027567715`}}, {{
       4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}, {{
       4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}, {{
       4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}, {{
       4.96054102889468, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}, {
       4.96054102889468, -0.8731388140079372}, {
       4.96054102889468, -0.8731388140079372}}, {{
       5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}, {{
       5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}, {{
       5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}, {{
       5.04586476633904, -0.8537076060661719}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}, {
       5.04586476633904, -0.8537076060661719}, {
       5.04586476633904, -0.8537076060661719}}, {{
       5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}, {{
       5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}, {{
       5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}, {{
       5.108751277511685, -0.8731388140079372}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}, {
       5.108751277511685, -0.8731388140079372}, {
       5.108751277511685, -0.8731388140079372}}, {{
       5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}, {{
       5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}, {{
       5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}, {{
       5.157022452801794, -0.9178845262679391}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.182856401820188, -1.0014926544114717`}, {
       5.157022452801794, -0.9178845262679391}, {
       5.157022452801794, -0.9178845262679391}}, {{
       4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.3838535728859904}, {
       4.928263853343283, -0.3838535728859904}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}, {{
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}, {{
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}, {{
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}, {{
       4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}, {{
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}, {{
       4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}, {{
       4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}, {{
       4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}, {{
       4.928263853343283, -0.6473968135979375}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}}, {{
       4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}, {{
       4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}, {{
       4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}, {{
       4.867189982932563, -0.5815110034199508}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.5815110034199508}, {
       4.867189982932563, -0.5815110034199508}}, {{
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}, {{
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}, {{
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}, {{
       4.852185472859209, -0.515625193241964}, {
       4.867189982932563, -0.4497393830639772}, {
       4.867189982932563, -0.4497393830639772}, {
       4.852185472859209, -0.515625193241964}, {
       4.852185472859209, -0.515625193241964}}, {{
       4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}, {{
       4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}, {{
       4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}, {{
       4.867189982932563, -0.44973938306397715`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.867189982932563, -0.44973938306397715`}, {
       4.867189982932563, -0.44973938306397715`}}, {{
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}, {{
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}, {{
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}, {{
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}}, {{
       5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}, {{
       5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}, {{
       5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}, {{
       5.129977144637811, -0.6014596216140798}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}, {
       5.129977144637811, -0.6014596216140798}, {
       5.129977144637811, -0.6014596216140798}}, {{
       5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}, {{
       5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}, {{
       5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}, {{
       5.080420614311432, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}, {
       5.080420614311432, -0.6473968135979375}, {
       5.080420614311432, -0.6473968135979375}}, {{
       5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}, {{
       5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}, {{
       5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}, {{
       5.015859573911699, -0.6673454317920666}, {
       4.928263853343283, -0.6473968135979375}, {
       4.928263853343283, -0.6473968135979375}, {
       5.015859573911699, -0.6673454317920666}, {
       5.015859573911699, -0.6673454317920666}}, {{
       4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}, {{
       4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}, {{
       4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}, {{
       4.928263853343283, -0.38385357288599037`}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}, {
       4.928263853343283, -0.38385357288599037`}, {
       4.928263853343283, -0.38385357288599037`}}, {{
       5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}, {{
       5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}, {{
       5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}, {{
       5.015859573911699, -0.3639049546918613}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}, {
       5.015859573911699, -0.3639049546918613}, {
       5.015859573911699, -0.3639049546918613}}, {{
       5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}, {{
       5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}, {{
       5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}, {{
       5.080420614311432, -0.3838535728859904}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.080420614311432, -0.3838535728859904}, {
       5.080420614311432, -0.3838535728859904}}, {{
       5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}, {{
       5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}, {{
       5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}, {{
       5.129977144637811, -0.42979076486984813`}, {
       5.156498994795506, -0.515625193241964}, {
       5.156498994795506, -0.515625193241964}, {
       5.129977144637811, -0.42979076486984813`}, {
       5.129977144637811, -0.42979076486984813`}}, {{
       4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, 0.09437020280328935}, {
       4.903692688761734, 0.1633401011782614}, {4.903692688761734, 
       0.1633401011782614}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, -0.04356959394665484}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}, {{4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}}, {{
       5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162691`}, {
       4.903692688761734, -0.11253949232162691`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 
       0.025400304428317238`}}, {{5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}, {{4.903692688761734, 
       0.16334010117826142`}, {4.995388729675026, 0.18422250614305444`}, {
       5.062971846332819, 0.1633401011782614}, {5.114848097853341, 
       0.11525260776808234`}, {5.1426114251183614`, 0.025400304428317273`}, {
       5.1426114251183614`, 0.025400304428317273`}, {5.114848097853341, 
       0.11525260776808234`}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}}, {{
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}, {{4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}, {{
       4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}, {{
       4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}, {{
       4.903692688761734, -0.11253949232162688`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}}, {{
       4.839759975113463, -0.043569593946654814`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}, {{
       4.839759975113463, -0.043569593946654814`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}, {{
       4.839759975113463, -0.043569593946654814`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}, {{
       4.839759975113463, -0.043569593946654814`}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, -0.043569593946654814`}, {
       4.839759975113463, -0.043569593946654814`}}, {{4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, 0.09437020280328932}, {
       4.839759975113463, 0.09437020280328932}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}}, {{
       4.824053109976192, 0.025400304428317255`}, {4.839759975113463, 
       0.09437020280328932}, {4.839759975113463, 0.09437020280328932}, {
       4.824053109976192, 0.025400304428317255`}, {4.824053109976192, 
       0.025400304428317255`}}, {{4.824053109976192, 0.025400304428317255`}, {
       4.839759975113463, 0.09437020280328932}, {4.839759975113463, 
       0.09437020280328932}, {4.824053109976192, 0.025400304428317255`}, {
       4.824053109976192, 0.025400304428317255`}}, {{4.824053109976192, 
       0.025400304428317255`}, {4.839759975113463, 0.09437020280328932}, {
       4.839759975113463, 0.09437020280328932}, {4.824053109976192, 
       0.025400304428317255`}, {4.824053109976192, 0.025400304428317255`}}, {{
       4.839759975113463, 0.09437020280328935}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}, {
       4.839759975113463, 0.09437020280328935}, {4.839759975113463, 
       0.09437020280328935}}, {{4.839759975113463, 0.09437020280328935}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}, {4.839759975113463, 0.09437020280328935}, {
       4.839759975113463, 0.09437020280328935}}, {{4.839759975113463, 
       0.09437020280328935}, {4.903692688761734, 0.16334010117826142`}, {
       4.903692688761734, 0.16334010117826142`}, {4.839759975113463, 
       0.09437020280328935}, {4.839759975113463, 0.09437020280328935}}, {{
       4.839759975113463, 0.09437020280328935}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}, {
       4.839759975113463, 0.09437020280328935}, {4.839759975113463, 
       0.09437020280328935}}, {{5.1426114251183614`, 0.025400304428317238`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 
       0.025400304428317238`}}, {{5.1426114251183614`, 
       0.025400304428317238`}, {5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 
       0.025400304428317238`}}, {{5.1426114251183614`, 
       0.025400304428317238`}, {5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 
       0.025400304428317238`}}, {{5.1426114251183614`, 
       0.025400304428317238`}, {5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}, {5.1426114251183614`, 
       0.025400304428317238`}, {5.1426114251183614`, 
       0.025400304428317238`}}, {{5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}, {{
       5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}, {{
       5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}, {{
       5.114848097853341, -0.06445199891144783}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.114848097853341, -0.06445199891144783}, {
       5.114848097853341, -0.06445199891144783}}, {{
       5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}, {{
       5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}, {{
       5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}, {{
       5.062971846332819, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}, {
       5.062971846332819, -0.11253949232162688`}, {
       5.062971846332819, -0.11253949232162688`}}, {{
       4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}, {{
       4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}, {{
       4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}, {{
       4.995388729675026, -0.13342189728641993`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.903692688761734, -0.11253949232162688`}, {
       4.995388729675026, -0.13342189728641993`}, {
       4.995388729675026, -0.13342189728641993`}}, {{4.903692688761734, 
       0.16334010117826142`}, {4.995388729675026, 0.18422250614305444`}, {
       4.995388729675026, 0.18422250614305444`}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}}, {{
       4.903692688761734, 0.16334010117826142`}, {4.995388729675026, 
       0.18422250614305444`}, {4.995388729675026, 0.18422250614305444`}, {
       4.903692688761734, 0.16334010117826142`}, {4.903692688761734, 
       0.16334010117826142`}}, {{4.903692688761734, 0.16334010117826142`}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}, {4.903692688761734, 0.16334010117826142`}, {
       4.903692688761734, 0.16334010117826142`}}, {{4.903692688761734, 
       0.16334010117826142`}, {4.995388729675026, 0.18422250614305444`}, {
       4.995388729675026, 0.18422250614305444`}, {4.903692688761734, 
       0.16334010117826142`}, {4.903692688761734, 0.16334010117826142`}}, {{
       4.995388729675026, 0.18422250614305444`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}}, {{4.995388729675026, 0.18422250614305444`}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}, {4.995388729675026, 0.18422250614305444`}, {
       4.995388729675026, 0.18422250614305444`}}, {{4.995388729675026, 
       0.18422250614305444`}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}, {4.995388729675026, 
       0.18422250614305444`}, {4.995388729675026, 0.18422250614305444`}}, {{
       4.995388729675026, 0.18422250614305444`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}, {
       4.995388729675026, 0.18422250614305444`}, {4.995388729675026, 
       0.18422250614305444`}}, {{5.062971846332819, 0.1633401011782614}, {
       5.114848097853341, 0.11525260776808234`}, {5.114848097853341, 
       0.11525260776808234`}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}}, {{5.062971846332819, 
       0.1633401011782614}, {5.114848097853341, 0.11525260776808234`}, {
       5.114848097853341, 0.11525260776808234`}, {5.062971846332819, 
       0.1633401011782614}, {5.062971846332819, 0.1633401011782614}}, {{
       5.062971846332819, 0.1633401011782614}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}, {
       5.062971846332819, 0.1633401011782614}, {5.062971846332819, 
       0.1633401011782614}}, {{5.062971846332819, 0.1633401011782614}, {
       5.114848097853341, 0.11525260776808234`}, {5.114848097853341, 
       0.11525260776808234`}, {5.062971846332819, 0.1633401011782614}, {
       5.062971846332819, 0.1633401011782614}}, {{5.114848097853341, 
       0.11525260776808234`}, {5.1426114251183614`, 0.025400304428317227`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}}, {{
       5.114848097853341, 0.11525260776808234`}, {5.1426114251183614`, 
       0.025400304428317227`}, {5.1426114251183614`, 0.025400304428317227`}, {
       5.114848097853341, 0.11525260776808234`}, {5.114848097853341, 
       0.11525260776808234`}}, {{5.114848097853341, 0.11525260776808234`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.1426114251183614`, 
       0.025400304428317227`}, {5.114848097853341, 0.11525260776808234`}, {
       5.114848097853341, 0.11525260776808234`}}, {{5.114848097853341, 
       0.11525260776808234`}, {5.1426114251183614`, 0.025400304428317227`}, {
       5.1426114251183614`, 0.025400304428317227`}, {5.114848097853341, 
       0.11525260776808234`}, {5.114848097853341, 0.11525260776808234`}}, {{
       4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.874002364174817, 
       0.5429196016106428}, {4.888970412742282, 0.47719389635071857`}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}, {{4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}}, {{5.17757639317078, 
       0.5429196016106428}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {4.949895871423808, 0.4114681910907944}, {
       4.949895871423808, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.101682885921789, 0.4114681910907944}, {
       5.1511189920747995`, 0.45729375402525996`}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}}, {{
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}, {{4.949895871423808, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.1511189920747995`, 0.6285454491960256}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}, {5.1511189920747995`, 0.6285454491960256}, {
       5.101682885921789, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {4.949895871423808, 0.6743710121304911}, {
       4.949895871423808, 0.6743710121304911}}, {{5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}}, {{
       4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}, {{4.949895871423808, 0.4114681910907944}, {
       4.888970412742282, 0.4771938963507186}, {4.888970412742282, 
       0.4771938963507186}, {4.949895871423808, 0.4114681910907944}, {
       4.949895871423808, 0.4114681910907944}}, {{4.949895871423808, 
       0.4114681910907944}, {4.888970412742282, 0.4771938963507186}, {
       4.888970412742282, 0.4771938963507186}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}}, {{
       4.949895871423808, 0.4114681910907944}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}}, {{4.888970412742282, 0.4771938963507186}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.888970412742282, 0.4771938963507186}, {
       4.888970412742282, 0.4771938963507186}}, {{4.888970412742282, 
       0.4771938963507186}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}, {4.888970412742282, 
       0.4771938963507186}, {4.888970412742282, 0.4771938963507186}}, {{
       4.888970412742282, 0.4771938963507186}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.4771938963507186}, {4.888970412742282, 
       0.4771938963507186}}, {{4.888970412742282, 0.4771938963507186}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}, {4.888970412742282, 0.4771938963507186}, {
       4.888970412742282, 0.4771938963507186}}, {{4.874002364174817, 
       0.5429196016106428}, {4.888970412742282, 0.608645306870567}, {
       4.888970412742282, 0.608645306870567}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}}, {{
       4.874002364174817, 0.5429196016106428}, {4.888970412742282, 
       0.608645306870567}, {4.888970412742282, 0.608645306870567}, {
       4.874002364174817, 0.5429196016106428}, {4.874002364174817, 
       0.5429196016106428}}, {{4.874002364174817, 0.5429196016106428}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}, {4.874002364174817, 0.5429196016106428}, {
       4.874002364174817, 0.5429196016106428}}, {{4.874002364174817, 
       0.5429196016106428}, {4.888970412742282, 0.608645306870567}, {
       4.888970412742282, 0.608645306870567}, {4.874002364174817, 
       0.5429196016106428}, {4.874002364174817, 0.5429196016106428}}, {{
       4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}}, {{4.888970412742282, 0.608645306870567}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}, {4.888970412742282, 0.608645306870567}, {
       4.888970412742282, 0.608645306870567}}, {{4.888970412742282, 
       0.608645306870567}, {4.949895871423808, 0.6743710121304911}, {
       4.949895871423808, 0.6743710121304911}, {4.888970412742282, 
       0.608645306870567}, {4.888970412742282, 0.608645306870567}}, {{
       4.888970412742282, 0.608645306870567}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}, {
       4.888970412742282, 0.608645306870567}, {4.888970412742282, 
       0.608645306870567}}, {{5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.45729375402525996`}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.17757639317078, 0.5429196016106428}, {
       5.17757639317078, 0.5429196016106428}}, {{5.17757639317078, 
       0.5429196016106428}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.1511189920747995`, 0.45729375402525996`}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}}, {{
       5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}}, {{5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.45729375402525996`}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.17757639317078, 0.5429196016106428}, {
       5.17757639317078, 0.5429196016106428}}, {{5.1511189920747995`, 
       0.45729375402525996`}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}}, {{
       5.1511189920747995`, 0.45729375402525996`}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}, {
       5.1511189920747995`, 0.45729375402525996`}, {5.1511189920747995`, 
       0.45729375402525996`}}, {{5.1511189920747995`, 0.45729375402525996`}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}, {5.1511189920747995`, 0.45729375402525996`}, {
       5.1511189920747995`, 0.45729375402525996`}}, {{5.1511189920747995`, 
       0.45729375402525996`}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}, {5.1511189920747995`, 
       0.45729375402525996`}, {5.1511189920747995`, 0.45729375402525996`}}, {{
       5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}, {{5.101682885921789, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.037278731201314, 
       0.3915680487653358}, {5.101682885921789, 0.4114681910907944}, {
       5.101682885921789, 0.4114681910907944}}, {{5.101682885921789, 
       0.4114681910907944}, {5.037278731201314, 0.3915680487653358}, {
       5.037278731201314, 0.3915680487653358}, {5.101682885921789, 
       0.4114681910907944}, {5.101682885921789, 0.4114681910907944}}, {{
       5.101682885921789, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}, {
       5.101682885921789, 0.4114681910907944}, {5.101682885921789, 
       0.4114681910907944}}, {{5.037278731201314, 0.3915680487653358}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}, {5.037278731201314, 0.3915680487653358}, {
       5.037278731201314, 0.3915680487653358}}, {{5.037278731201314, 
       0.3915680487653358}, {4.949895871423808, 0.4114681910907944}, {
       4.949895871423808, 0.4114681910907944}, {5.037278731201314, 
       0.3915680487653358}, {5.037278731201314, 0.3915680487653358}}, {{
       5.037278731201314, 0.3915680487653358}, {4.949895871423808, 
       0.4114681910907944}, {4.949895871423808, 0.4114681910907944}, {
       5.037278731201314, 0.3915680487653358}, {5.037278731201314, 
       0.3915680487653358}}, {{5.037278731201314, 0.3915680487653358}, {
       4.949895871423808, 0.4114681910907944}, {4.949895871423808, 
       0.4114681910907944}, {5.037278731201314, 0.3915680487653358}, {
       5.037278731201314, 0.3915680487653358}}, {{4.949895871423808, 
       0.6743710121304911}, {5.037278731201314, 0.6942711544559498}, {
       5.037278731201314, 0.6942711544559498}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}}, {{
       4.949895871423808, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.037278731201314, 0.6942711544559498}, {
       4.949895871423808, 0.6743710121304911}, {4.949895871423808, 
       0.6743710121304911}}, {{4.949895871423808, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}, {4.949895871423808, 0.6743710121304911}, {
       4.949895871423808, 0.6743710121304911}}, {{4.949895871423808, 
       0.6743710121304911}, {5.037278731201314, 0.6942711544559498}, {
       5.037278731201314, 0.6942711544559498}, {4.949895871423808, 
       0.6743710121304911}, {4.949895871423808, 0.6743710121304911}}, {{
       5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}}, {{5.037278731201314, 0.6942711544559498}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}, {5.037278731201314, 0.6942711544559498}, {
       5.037278731201314, 0.6942711544559498}}, {{5.037278731201314, 
       0.6942711544559498}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}, {5.037278731201314, 
       0.6942711544559498}, {5.037278731201314, 0.6942711544559498}}, {{
       5.037278731201314, 0.6942711544559498}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}, {
       5.037278731201314, 0.6942711544559498}, {5.037278731201314, 
       0.6942711544559498}}, {{5.101682885921789, 0.6743710121304911}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}}, {{5.101682885921789, 
       0.6743710121304911}, {5.1511189920747995`, 0.6285454491960256}, {
       5.1511189920747995`, 0.6285454491960256}, {5.101682885921789, 
       0.6743710121304911}, {5.101682885921789, 0.6743710121304911}}, {{
       5.101682885921789, 0.6743710121304911}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}, {
       5.101682885921789, 0.6743710121304911}, {5.101682885921789, 
       0.6743710121304911}}, {{5.101682885921789, 0.6743710121304911}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}, {5.101682885921789, 0.6743710121304911}, {
       5.101682885921789, 0.6743710121304911}}, {{5.1511189920747995`, 
       0.6285454491960256}, {5.17757639317078, 0.5429196016106428}, {
       5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}}, {{
       5.1511189920747995`, 0.6285454491960256}, {5.17757639317078, 
       0.5429196016106428}, {5.17757639317078, 0.5429196016106428}, {
       5.1511189920747995`, 0.6285454491960256}, {5.1511189920747995`, 
       0.6285454491960256}}, {{5.1511189920747995`, 0.6285454491960256}, {
       5.17757639317078, 0.5429196016106428}, {5.17757639317078, 
       0.5429196016106428}, {5.1511189920747995`, 0.6285454491960256}, {
       5.1511189920747995`, 0.6285454491960256}}, {{5.1511189920747995`, 
       0.6285454491960256}, {5.17757639317078, 0.5429196016106428}, {
       5.17757639317078, 0.5429196016106428}, {5.1511189920747995`, 
       0.6285454491960256}, {5.1511189920747995`, 0.6285454491960256}}, {{
       4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.838129532382327, 
       1.0010373682731215`}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}, {{4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}}, {{5.1706341209629, 
       1.0010373682731215`}, {5.141655333497366, 0.9072513902123325}, {
       5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {4.92125567952747, 0.8570586579802866}, {
       4.92125567952747, 0.8570586579802866}, {5.0169661127796505`, 
       0.835262035065915}, {5.087507973817757, 0.8570586579802867}, {
       5.141655333497366, 0.9072513902123325}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}}, {{
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}, {{4.92125567952747, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.141655333497366, 1.0948233463339105`}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}, {5.141655333497366, 1.0948233463339105`}, {
       5.087507973817757, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {4.92125567952747, 1.1450160785659564`}, {
       4.92125567952747, 1.1450160785659564`}}, {{5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}}, {{
       4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}, {{4.92125567952747, 0.8570586579802867}, {
       4.854524033740824, 0.929048013126704}, {4.854524033740824, 
       0.929048013126704}, {4.92125567952747, 0.8570586579802867}, {
       4.92125567952747, 0.8570586579802867}}, {{4.92125567952747, 
       0.8570586579802867}, {4.854524033740824, 0.929048013126704}, {
       4.854524033740824, 0.929048013126704}, {4.92125567952747, 
       0.8570586579802867}, {4.92125567952747, 0.8570586579802867}}, {{
       4.92125567952747, 0.8570586579802867}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}}, {{4.854524033740824, 0.929048013126704}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.854524033740824, 0.929048013126704}, {
       4.854524033740824, 0.929048013126704}}, {{4.854524033740824, 
       0.929048013126704}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}, {4.854524033740824, 
       0.929048013126704}, {4.854524033740824, 0.929048013126704}}, {{
       4.854524033740824, 0.929048013126704}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 0.929048013126704}, {4.854524033740824, 
       0.929048013126704}}, {{4.854524033740824, 0.929048013126704}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}, {4.854524033740824, 0.929048013126704}, {
       4.854524033740824, 0.929048013126704}}, {{4.838129532382327, 
       1.0010373682731215`}, {4.854524033740824, 1.073026723419539}, {
       4.854524033740824, 1.073026723419539}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}}, {{
       4.838129532382327, 1.0010373682731215`}, {4.854524033740824, 
       1.073026723419539}, {4.854524033740824, 1.073026723419539}, {
       4.838129532382327, 1.0010373682731215`}, {4.838129532382327, 
       1.0010373682731215`}}, {{4.838129532382327, 1.0010373682731215`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}, {4.838129532382327, 1.0010373682731215`}, {
       4.838129532382327, 1.0010373682731215`}}, {{4.838129532382327, 
       1.0010373682731215`}, {4.854524033740824, 1.073026723419539}, {
       4.854524033740824, 1.073026723419539}, {4.838129532382327, 
       1.0010373682731215`}, {4.838129532382327, 1.0010373682731215`}}, {{
       4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}}, {{4.854524033740824, 1.073026723419539}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}, {4.854524033740824, 1.073026723419539}, {
       4.854524033740824, 1.073026723419539}}, {{4.854524033740824, 
       1.073026723419539}, {4.92125567952747, 1.1450160785659564`}, {
       4.92125567952747, 1.1450160785659564`}, {4.854524033740824, 
       1.073026723419539}, {4.854524033740824, 1.073026723419539}}, {{
       4.854524033740824, 1.073026723419539}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}, {
       4.854524033740824, 1.073026723419539}, {4.854524033740824, 
       1.073026723419539}}, {{5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}, {5.1706341209629, 1.0010373682731215`}, {
       5.1706341209629, 1.0010373682731215`}}, {{5.1706341209629, 
       1.0010373682731215`}, {5.141655333497366, 0.9072513902123325}, {
       5.141655333497366, 0.9072513902123325}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}}, {{
       5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}}, {{5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}, {5.1706341209629, 1.0010373682731215`}, {
       5.1706341209629, 1.0010373682731215`}}, {{5.141655333497366, 
       0.9072513902123325}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}}, {{
       5.141655333497366, 0.9072513902123325}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}, {
       5.141655333497366, 0.9072513902123325}, {5.141655333497366, 
       0.9072513902123325}}, {{5.141655333497366, 0.9072513902123325}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}, {5.141655333497366, 0.9072513902123325}, {
       5.141655333497366, 0.9072513902123325}}, {{5.141655333497366, 
       0.9072513902123325}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}, {5.141655333497366, 
       0.9072513902123325}, {5.141655333497366, 0.9072513902123325}}, {{
       5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}, {{5.087507973817757, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {5.0169661127796505`, 
       0.835262035065915}, {5.087507973817757, 0.8570586579802867}, {
       5.087507973817757, 0.8570586579802867}}, {{5.087507973817757, 
       0.8570586579802867}, {5.0169661127796505`, 0.835262035065915}, {
       5.0169661127796505`, 0.835262035065915}, {5.087507973817757, 
       0.8570586579802867}, {5.087507973817757, 0.8570586579802867}}, {{
       5.087507973817757, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}, {
       5.087507973817757, 0.8570586579802867}, {5.087507973817757, 
       0.8570586579802867}}, {{5.0169661127796505`, 0.835262035065915}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}, {5.0169661127796505`, 0.835262035065915}, {
       5.0169661127796505`, 0.835262035065915}}, {{5.0169661127796505`, 
       0.835262035065915}, {4.92125567952747, 0.8570586579802867}, {
       4.92125567952747, 0.8570586579802867}, {5.0169661127796505`, 
       0.835262035065915}, {5.0169661127796505`, 0.835262035065915}}, {{
       5.0169661127796505`, 0.835262035065915}, {4.92125567952747, 
       0.8570586579802867}, {4.92125567952747, 0.8570586579802867}, {
       5.0169661127796505`, 0.835262035065915}, {5.0169661127796505`, 
       0.835262035065915}}, {{5.0169661127796505`, 0.835262035065915}, {
       4.92125567952747, 0.8570586579802867}, {4.92125567952747, 
       0.8570586579802867}, {5.0169661127796505`, 0.835262035065915}, {
       5.0169661127796505`, 0.835262035065915}}, {{4.92125567952747, 
       1.1450160785659564`}, {5.0169661127796505`, 1.166812701480328}, {
       5.0169661127796505`, 1.166812701480328}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}}, {{
       4.92125567952747, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.0169661127796505`, 1.166812701480328}, {
       4.92125567952747, 1.1450160785659564`}, {4.92125567952747, 
       1.1450160785659564`}}, {{4.92125567952747, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}, {4.92125567952747, 1.1450160785659564`}, {
       4.92125567952747, 1.1450160785659564`}}, {{4.92125567952747, 
       1.1450160785659564`}, {5.0169661127796505`, 1.166812701480328}, {
       5.0169661127796505`, 1.166812701480328}, {4.92125567952747, 
       1.1450160785659564`}, {4.92125567952747, 1.1450160785659564`}}, {{
       5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}}, {{5.0169661127796505`, 1.166812701480328}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}, {5.0169661127796505`, 1.166812701480328}, {
       5.0169661127796505`, 1.166812701480328}}, {{5.0169661127796505`, 
       1.166812701480328}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}, {5.0169661127796505`, 
       1.166812701480328}, {5.0169661127796505`, 1.166812701480328}}, {{
       5.0169661127796505`, 1.166812701480328}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}, {
       5.0169661127796505`, 1.166812701480328}, {5.0169661127796505`, 
       1.166812701480328}}, {{5.087507973817757, 1.1450160785659564`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}}, {{5.087507973817757, 
       1.1450160785659564`}, {5.141655333497366, 1.0948233463339105`}, {
       5.141655333497366, 1.0948233463339105`}, {5.087507973817757, 
       1.1450160785659564`}, {5.087507973817757, 1.1450160785659564`}}, {{
       5.087507973817757, 1.1450160785659564`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}, {
       5.087507973817757, 1.1450160785659564`}, {5.087507973817757, 
       1.1450160785659564`}}, {{5.087507973817757, 1.1450160785659564`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}, {5.087507973817757, 1.1450160785659564`}, {
       5.087507973817757, 1.1450160785659564`}}, {{5.141655333497366, 
       1.0948233463339105`}, {5.1706341209629, 1.0010373682731215`}, {
       5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}}, {{
       5.141655333497366, 1.0948233463339105`}, {5.1706341209629, 
       1.0010373682731215`}, {5.1706341209629, 1.0010373682731215`}, {
       5.141655333497366, 1.0948233463339105`}, {5.141655333497366, 
       1.0948233463339105`}}, {{5.141655333497366, 1.0948233463339105`}, {
       5.1706341209629, 1.0010373682731215`}, {5.1706341209629, 
       1.0010373682731215`}, {5.141655333497366, 1.0948233463339105`}, {
       5.141655333497366, 1.0948233463339105`}}, {{5.141655333497366, 
       1.0948233463339105`}, {5.1706341209629, 1.0010373682731215`}, {
       5.1706341209629, 1.0010373682731215`}, {5.141655333497366, 
       1.0948233463339105`}, {5.141655333497366, 1.0948233463339105`}}, {{
       4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.832759097504514, 
       1.496787602616387}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}, {{4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}}, {{5.170600124062313, 
       1.496787602616387}, {5.141156249776097, 1.4014964331319508`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0144658648169225`, 
       1.328351705272034}, {4.917219354143963, 1.3504981468965536`}, {
       4.917219354143963, 1.3504981468965536`}, {5.0144658648169225`, 
       1.328351705272034}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.141156249776097, 1.4014964331319508`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}}, {{
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}}, {{4.917219354143963, 1.6430770583362206`}, {
       5.0144658648169225`, 1.6652234999607403`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.141156249776097, 1.5920787721008234`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}, {5.141156249776097, 1.5920787721008234`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0144658648169225`, 
       1.6652234999607403`}, {4.917219354143963, 1.6430770583362206`}, {
       4.917219354143963, 1.6430770583362206`}}, {{5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}}, {{
       4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}, {{4.917219354143963, 1.3504981468965536`}, {
       4.849416717757221, 1.4236428747564702`}, {4.849416717757221, 
       1.4236428747564702`}, {4.917219354143963, 1.3504981468965536`}, {
       4.917219354143963, 1.3504981468965536`}}, {{4.917219354143963, 
       1.3504981468965536`}, {4.849416717757221, 1.4236428747564702`}, {
       4.849416717757221, 1.4236428747564702`}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}}, {{
       4.917219354143963, 1.3504981468965536`}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}}, {{4.849416717757221, 1.4236428747564702`}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.849416717757221, 1.4236428747564702`}, {
       4.849416717757221, 1.4236428747564702`}}, {{4.849416717757221, 
       1.4236428747564702`}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}, {4.849416717757221, 
       1.4236428747564702`}, {4.849416717757221, 1.4236428747564702`}}, {{
       4.849416717757221, 1.4236428747564702`}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.4236428747564702`}, {4.849416717757221, 
       1.4236428747564702`}}, {{4.849416717757221, 1.4236428747564702`}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}, {4.849416717757221, 1.4236428747564702`}, {
       4.849416717757221, 1.4236428747564702`}}, {{4.832759097504514, 
       1.496787602616387}, {4.849416717757221, 1.569932330476304}, {
       4.849416717757221, 1.569932330476304}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}}, {{
       4.832759097504514, 1.496787602616387}, {4.849416717757221, 
       1.569932330476304}, {4.849416717757221, 1.569932330476304}, {
       4.832759097504514, 1.496787602616387}, {4.832759097504514, 
       1.496787602616387}}, {{4.832759097504514, 1.496787602616387}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}, {4.832759097504514, 1.496787602616387}, {
       4.832759097504514, 1.496787602616387}}, {{4.832759097504514, 
       1.496787602616387}, {4.849416717757221, 1.569932330476304}, {
       4.849416717757221, 1.569932330476304}, {4.832759097504514, 
       1.496787602616387}, {4.832759097504514, 1.496787602616387}}, {{
       4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}}, {{4.849416717757221, 1.569932330476304}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}, {4.849416717757221, 1.569932330476304}, {
       4.849416717757221, 1.569932330476304}}, {{4.849416717757221, 
       1.569932330476304}, {4.917219354143963, 1.6430770583362206`}, {
       4.917219354143963, 1.6430770583362206`}, {4.849416717757221, 
       1.569932330476304}, {4.849416717757221, 1.569932330476304}}, {{
       4.849416717757221, 1.569932330476304}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}, {
       4.849416717757221, 1.569932330476304}, {4.849416717757221, 
       1.569932330476304}}, {{5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}, {5.170600124062313, 1.496787602616387}, {
       5.170600124062313, 1.496787602616387}}, {{5.170600124062313, 
       1.496787602616387}, {5.141156249776097, 1.4014964331319508`}, {
       5.141156249776097, 1.4014964331319508`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}}, {{
       5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}}, {{5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}, {5.170600124062313, 1.496787602616387}, {
       5.170600124062313, 1.496787602616387}}, {{5.141156249776097, 
       1.4014964331319508`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}}, {{
       5.141156249776097, 1.4014964331319508`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.141156249776097, 1.4014964331319508`}, {5.141156249776097, 
       1.4014964331319508`}}, {{5.141156249776097, 1.4014964331319508`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.141156249776097, 1.4014964331319508`}, {
       5.141156249776097, 1.4014964331319508`}}, {{5.141156249776097, 
       1.4014964331319508`}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.141156249776097, 
       1.4014964331319508`}, {5.141156249776097, 1.4014964331319508`}}, {{
       5.0861398674228635`, 1.3504981468965536`}, {5.0144658648169225`, 
       1.328351705272034}, {5.0144658648169225`, 1.328351705272034}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}}, {{5.0861398674228635`, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}, {5.0861398674228635`, 1.3504981468965536`}, {
       5.0861398674228635`, 1.3504981468965536`}}, {{5.0861398674228635`, 
       1.3504981468965536`}, {5.0144658648169225`, 1.328351705272034}, {
       5.0144658648169225`, 1.328351705272034}, {5.0861398674228635`, 
       1.3504981468965536`}, {5.0861398674228635`, 1.3504981468965536`}}, {{
       5.0861398674228635`, 1.3504981468965536`}, {5.0144658648169225`, 
       1.328351705272034}, {5.0144658648169225`, 1.328351705272034}, {
       5.0861398674228635`, 1.3504981468965536`}, {5.0861398674228635`, 
       1.3504981468965536`}}, {{5.0144658648169225`, 1.328351705272034}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}, {5.0144658648169225`, 1.328351705272034}, {
       5.0144658648169225`, 1.328351705272034}}, {{5.0144658648169225`, 
       1.328351705272034}, {4.917219354143963, 1.3504981468965536`}, {
       4.917219354143963, 1.3504981468965536`}, {5.0144658648169225`, 
       1.328351705272034}, {5.0144658648169225`, 1.328351705272034}}, {{
       5.0144658648169225`, 1.328351705272034}, {4.917219354143963, 
       1.3504981468965536`}, {4.917219354143963, 1.3504981468965536`}, {
       5.0144658648169225`, 1.328351705272034}, {5.0144658648169225`, 
       1.328351705272034}}, {{5.0144658648169225`, 1.328351705272034}, {
       4.917219354143963, 1.3504981468965536`}, {4.917219354143963, 
       1.3504981468965536`}, {5.0144658648169225`, 1.328351705272034}, {
       5.0144658648169225`, 1.328351705272034}}, {{4.917219354143963, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}}, {{
       4.917219354143963, 1.6430770583362206`}, {5.0144658648169225`, 
       1.6652234999607403`}, {5.0144658648169225`, 1.6652234999607403`}, {
       4.917219354143963, 1.6430770583362206`}, {4.917219354143963, 
       1.6430770583362206`}}, {{4.917219354143963, 1.6430770583362206`}, {
       5.0144658648169225`, 1.6652234999607403`}, {5.0144658648169225`, 
       1.6652234999607403`}, {4.917219354143963, 1.6430770583362206`}, {
       4.917219354143963, 1.6430770583362206`}}, {{4.917219354143963, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}, {4.917219354143963, 
       1.6430770583362206`}, {4.917219354143963, 1.6430770583362206`}}, {{
       5.0144658648169225`, 1.6652234999607403`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0144658648169225`, 1.6652234999607403`}, {5.0144658648169225`, 
       1.6652234999607403`}}, {{5.0144658648169225`, 1.6652234999607403`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0144658648169225`, 1.6652234999607403`}, {
       5.0144658648169225`, 1.6652234999607403`}}, {{5.0144658648169225`, 
       1.6652234999607403`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0144658648169225`, 
       1.6652234999607403`}, {5.0144658648169225`, 1.6652234999607403`}}, {{
       5.0144658648169225`, 1.6652234999607403`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0144658648169225`, 1.6652234999607403`}, {5.0144658648169225`, 
       1.6652234999607403`}}, {{5.0861398674228635`, 1.6430770583362206`}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}}, {{5.0861398674228635`, 
       1.6430770583362206`}, {5.141156249776097, 1.5920787721008234`}, {
       5.141156249776097, 1.5920787721008234`}, {5.0861398674228635`, 
       1.6430770583362206`}, {5.0861398674228635`, 1.6430770583362206`}}, {{
       5.0861398674228635`, 1.6430770583362206`}, {5.141156249776097, 
       1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}, {
       5.0861398674228635`, 1.6430770583362206`}, {5.0861398674228635`, 
       1.6430770583362206`}}, {{5.0861398674228635`, 1.6430770583362206`}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}, {5.0861398674228635`, 1.6430770583362206`}, {
       5.0861398674228635`, 1.6430770583362206`}}, {{5.141156249776097, 
       1.5920787721008234`}, {5.170600124062313, 1.496787602616387}, {
       5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}}, {{
       5.141156249776097, 1.5920787721008234`}, {5.170600124062313, 
       1.496787602616387}, {5.170600124062313, 1.496787602616387}, {
       5.141156249776097, 1.5920787721008234`}, {5.141156249776097, 
       1.5920787721008234`}}, {{5.141156249776097, 1.5920787721008234`}, {
       5.170600124062313, 1.496787602616387}, {5.170600124062313, 
       1.496787602616387}, {5.141156249776097, 1.5920787721008234`}, {
       5.141156249776097, 1.5920787721008234`}}, {{5.141156249776097, 
       1.5920787721008234`}, {5.170600124062313, 1.496787602616387}, {
       5.170600124062313, 1.496787602616387}, {5.141156249776097, 
       1.5920787721008234`}, {5.141156249776097, 1.5920787721008234`}}, {{
       4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.905457129279017, 
       1.96461187479596}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}, {{4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}}, {{5.164868398875048, 
       1.96461187479596}, {5.142259916748895, 1.8914425397714019`}, {
       5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {4.970309946678024, 1.8522835000468914`}, {
       4.970309946678024, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.100015581476041, 1.8522835000468914`}, {
       5.142259916748895, 1.8914425397714019`}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}}, {{
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}, {{4.970309946678024, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.142259916748895, 2.037781209820518}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}, {5.142259916748895, 2.037781209820518}, {
       5.100015581476041, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {4.970309946678024, 2.0769402495450286`}, {
       4.970309946678024, 2.0769402495450286`}}, {{5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}}, {{
       4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}, {{4.970309946678024, 1.8522835000468914`}, {
       4.91824768483182, 1.9084476874214258`}, {4.91824768483182, 
       1.9084476874214258`}, {4.970309946678024, 1.8522835000468914`}, {
       4.970309946678024, 1.8522835000468914`}}, {{4.970309946678024, 
       1.8522835000468914`}, {4.91824768483182, 1.9084476874214258`}, {
       4.91824768483182, 1.9084476874214258`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}}, {{
       4.970309946678024, 1.8522835000468914`}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}}, {{4.91824768483182, 1.9084476874214258`}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.91824768483182, 1.9084476874214258`}, {
       4.91824768483182, 1.9084476874214258`}}, {{4.91824768483182, 
       1.9084476874214258`}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}, {4.91824768483182, 
       1.9084476874214258`}, {4.91824768483182, 1.9084476874214258`}}, {{
       4.91824768483182, 1.9084476874214258`}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 1.9084476874214258`}, {4.91824768483182, 
       1.9084476874214258`}}, {{4.91824768483182, 1.9084476874214258`}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}, {4.91824768483182, 1.9084476874214258`}, {
       4.91824768483182, 1.9084476874214258`}}, {{4.905457129279017, 
       1.96461187479596}, {4.91824768483182, 2.020776062170494}, {
       4.91824768483182, 2.020776062170494}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}}, {{
       4.905457129279017, 1.96461187479596}, {4.91824768483182, 
       2.020776062170494}, {4.91824768483182, 2.020776062170494}, {
       4.905457129279017, 1.96461187479596}, {4.905457129279017, 
       1.96461187479596}}, {{4.905457129279017, 1.96461187479596}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}, {4.905457129279017, 1.96461187479596}, {
       4.905457129279017, 1.96461187479596}}, {{4.905457129279017, 
       1.96461187479596}, {4.91824768483182, 2.020776062170494}, {
       4.91824768483182, 2.020776062170494}, {4.905457129279017, 
       1.96461187479596}, {4.905457129279017, 1.96461187479596}}, {{
       4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}}, {{4.91824768483182, 2.020776062170494}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}, {4.91824768483182, 2.020776062170494}, {
       4.91824768483182, 2.020776062170494}}, {{4.91824768483182, 
       2.020776062170494}, {4.970309946678024, 2.0769402495450286`}, {
       4.970309946678024, 2.0769402495450286`}, {4.91824768483182, 
       2.020776062170494}, {4.91824768483182, 2.020776062170494}}, {{
       4.91824768483182, 2.020776062170494}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}, {
       4.91824768483182, 2.020776062170494}, {4.91824768483182, 
       2.020776062170494}}, {{5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}, {5.164868398875048, 1.96461187479596}, {
       5.164868398875048, 1.96461187479596}}, {{5.164868398875048, 
       1.96461187479596}, {5.142259916748895, 1.8914425397714019`}, {
       5.142259916748895, 1.8914425397714019`}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}}, {{
       5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}}, {{5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}, {5.164868398875048, 1.96461187479596}, {
       5.164868398875048, 1.96461187479596}}, {{5.142259916748895, 
       1.8914425397714019`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}}, {{
       5.142259916748895, 1.8914425397714019`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}, {
       5.142259916748895, 1.8914425397714019`}, {5.142259916748895, 
       1.8914425397714019`}}, {{5.142259916748895, 1.8914425397714019`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}, {5.142259916748895, 1.8914425397714019`}, {
       5.142259916748895, 1.8914425397714019`}}, {{5.142259916748895, 
       1.8914425397714019`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}, {5.142259916748895, 
       1.8914425397714019`}, {5.142259916748895, 1.8914425397714019`}}, {{
       5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}, {{5.100015581476041, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.044980690650383, 
       1.8352783523968677`}, {5.100015581476041, 1.8522835000468914`}, {
       5.100015581476041, 1.8522835000468914`}}, {{5.100015581476041, 
       1.8522835000468914`}, {5.044980690650383, 1.8352783523968677`}, {
       5.044980690650383, 1.8352783523968677`}, {5.100015581476041, 
       1.8522835000468914`}, {5.100015581476041, 1.8522835000468914`}}, {{
       5.100015581476041, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}, {
       5.100015581476041, 1.8522835000468914`}, {5.100015581476041, 
       1.8522835000468914`}}, {{5.044980690650383, 1.8352783523968677`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}, {5.044980690650383, 1.8352783523968677`}, {
       5.044980690650383, 1.8352783523968677`}}, {{5.044980690650383, 
       1.8352783523968677`}, {4.970309946678024, 1.8522835000468914`}, {
       4.970309946678024, 1.8522835000468914`}, {5.044980690650383, 
       1.8352783523968677`}, {5.044980690650383, 1.8352783523968677`}}, {{
       5.044980690650383, 1.8352783523968677`}, {4.970309946678024, 
       1.8522835000468914`}, {4.970309946678024, 1.8522835000468914`}, {
       5.044980690650383, 1.8352783523968677`}, {5.044980690650383, 
       1.8352783523968677`}}, {{5.044980690650383, 1.8352783523968677`}, {
       4.970309946678024, 1.8522835000468914`}, {4.970309946678024, 
       1.8522835000468914`}, {5.044980690650383, 1.8352783523968677`}, {
       5.044980690650383, 1.8352783523968677`}}, {{4.970309946678024, 
       2.0769402495450286`}, {5.044980690650383, 2.0939453971950526`}, {
       5.044980690650383, 2.0939453971950526`}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}}, {{
       4.970309946678024, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.044980690650383, 2.0939453971950526`}, {
       4.970309946678024, 2.0769402495450286`}, {4.970309946678024, 
       2.0769402495450286`}}, {{4.970309946678024, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}, {4.970309946678024, 2.0769402495450286`}, {
       4.970309946678024, 2.0769402495450286`}}, {{4.970309946678024, 
       2.0769402495450286`}, {5.044980690650383, 2.0939453971950526`}, {
       5.044980690650383, 2.0939453971950526`}, {4.970309946678024, 
       2.0769402495450286`}, {4.970309946678024, 2.0769402495450286`}}, {{
       5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}}, {{5.044980690650383, 2.0939453971950526`}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}, {5.044980690650383, 2.0939453971950526`}, {
       5.044980690650383, 2.0939453971950526`}}, {{5.044980690650383, 
       2.0939453971950526`}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}, {5.044980690650383, 
       2.0939453971950526`}, {5.044980690650383, 2.0939453971950526`}}, {{
       5.044980690650383, 2.0939453971950526`}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}, {
       5.044980690650383, 2.0939453971950526`}, {5.044980690650383, 
       2.0939453971950526`}}, {{5.100015581476041, 2.0769402495450286`}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}}, {{5.100015581476041, 
       2.0769402495450286`}, {5.142259916748895, 2.037781209820518}, {
       5.142259916748895, 2.037781209820518}, {5.100015581476041, 
       2.0769402495450286`}, {5.100015581476041, 2.0769402495450286`}}, {{
       5.100015581476041, 2.0769402495450286`}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}, {
       5.100015581476041, 2.0769402495450286`}, {5.100015581476041, 
       2.0769402495450286`}}, {{5.100015581476041, 2.0769402495450286`}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}, {5.100015581476041, 2.0769402495450286`}, {
       5.100015581476041, 2.0769402495450286`}}, {{5.142259916748895, 
       2.037781209820518}, {5.164868398875048, 1.96461187479596}, {
       5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}}, {{
       5.142259916748895, 2.037781209820518}, {5.164868398875048, 
       1.96461187479596}, {5.164868398875048, 1.96461187479596}, {
       5.142259916748895, 2.037781209820518}, {5.142259916748895, 
       2.037781209820518}}, {{5.142259916748895, 2.037781209820518}, {
       5.164868398875048, 1.96461187479596}, {5.164868398875048, 
       1.96461187479596}, {5.142259916748895, 2.037781209820518}, {
       5.142259916748895, 2.037781209820518}}, {{5.142259916748895, 
       2.037781209820518}, {5.164868398875048, 1.96461187479596}, {
       5.164868398875048, 1.96461187479596}, {5.142259916748895, 
       2.037781209820518}, {5.142259916748895, 2.037781209820518}}, {{
       4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.910684658403933, 
       2.539406099066727}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}, {{4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}}, {{5.186929892150114, 
       2.539406099066727}, {5.162854278784081, 2.4614885895907976`}, {
       5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {4.979745966840478, 2.4197884040174453`}, {
       4.979745966840478, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.117868583713569, 2.4197884040174453`}, {
       5.162854278784081, 2.4614885895907976`}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}}, {{
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}, {{4.979745966840478, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.162854278784081, 2.617323608542656}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}, {5.162854278784081, 2.617323608542656}, {
       5.117868583713569, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {4.979745966840478, 2.6590237941160084`}, {
       4.979745966840478, 2.6590237941160084`}}, {{5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}}, {{
       4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}, {{4.979745966840478, 2.4197884040174453`}, {
       4.924305230917724, 2.4795972515420863`}, {4.924305230917724, 
       2.4795972515420863`}, {4.979745966840478, 2.4197884040174453`}, {
       4.979745966840478, 2.4197884040174453`}}, {{4.979745966840478, 
       2.4197884040174453`}, {4.924305230917724, 2.4795972515420863`}, {
       4.924305230917724, 2.4795972515420863`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}}, {{
       4.979745966840478, 2.4197884040174453`}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}}, {{4.924305230917724, 2.4795972515420863`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.924305230917724, 2.4795972515420863`}, {
       4.924305230917724, 2.4795972515420863`}}, {{4.924305230917724, 
       2.4795972515420863`}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}, {4.924305230917724, 
       2.4795972515420863`}, {4.924305230917724, 2.4795972515420863`}}, {{
       4.924305230917724, 2.4795972515420863`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.4795972515420863`}, {4.924305230917724, 
       2.4795972515420863`}}, {{4.924305230917724, 2.4795972515420863`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}, {4.924305230917724, 2.4795972515420863`}, {
       4.924305230917724, 2.4795972515420863`}}, {{4.910684658403933, 
       2.539406099066727}, {4.924305230917724, 2.5992149465913674`}, {
       4.924305230917724, 2.5992149465913674`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}}, {{
       4.910684658403933, 2.539406099066727}, {4.924305230917724, 
       2.5992149465913674`}, {4.924305230917724, 2.5992149465913674`}, {
       4.910684658403933, 2.539406099066727}, {4.910684658403933, 
       2.539406099066727}}, {{4.910684658403933, 2.539406099066727}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}, {4.910684658403933, 2.539406099066727}, {
       4.910684658403933, 2.539406099066727}}, {{4.910684658403933, 
       2.539406099066727}, {4.924305230917724, 2.5992149465913674`}, {
       4.924305230917724, 2.5992149465913674`}, {4.910684658403933, 
       2.539406099066727}, {4.910684658403933, 2.539406099066727}}, {{
       4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}}, {{4.924305230917724, 2.5992149465913674`}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}, {4.924305230917724, 2.5992149465913674`}, {
       4.924305230917724, 2.5992149465913674`}}, {{4.924305230917724, 
       2.5992149465913674`}, {4.979745966840478, 2.6590237941160084`}, {
       4.979745966840478, 2.6590237941160084`}, {4.924305230917724, 
       2.5992149465913674`}, {4.924305230917724, 2.5992149465913674`}}, {{
       4.924305230917724, 2.5992149465913674`}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}, {
       4.924305230917724, 2.5992149465913674`}, {4.924305230917724, 
       2.5992149465913674`}}, {{5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}, {5.186929892150114, 2.539406099066727}, {
       5.186929892150114, 2.539406099066727}}, {{5.186929892150114, 
       2.539406099066727}, {5.162854278784081, 2.4614885895907976`}, {
       5.162854278784081, 2.4614885895907976`}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}}, {{
       5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}}, {{5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}, {5.186929892150114, 2.539406099066727}, {
       5.186929892150114, 2.539406099066727}}, {{5.162854278784081, 
       2.4614885895907976`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}}, {{
       5.162854278784081, 2.4614885895907976`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}, {
       5.162854278784081, 2.4614885895907976`}, {5.162854278784081, 
       2.4614885895907976`}}, {{5.162854278784081, 2.4614885895907976`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}, {5.162854278784081, 2.4614885895907976`}, {
       5.162854278784081, 2.4614885895907976`}}, {{5.162854278784081, 
       2.4614885895907976`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}, {5.162854278784081, 
       2.4614885895907976`}, {5.162854278784081, 2.4614885895907976`}}, {{
       5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}, {{5.117868583713569, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.059262316129264, 
       2.4016797420661566`}, {5.117868583713569, 2.4197884040174453`}, {
       5.117868583713569, 2.4197884040174453`}}, {{5.117868583713569, 
       2.4197884040174453`}, {5.059262316129264, 2.4016797420661566`}, {
       5.059262316129264, 2.4016797420661566`}, {5.117868583713569, 
       2.4197884040174453`}, {5.117868583713569, 2.4197884040174453`}}, {{
       5.117868583713569, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}, {
       5.117868583713569, 2.4197884040174453`}, {5.117868583713569, 
       2.4197884040174453`}}, {{5.059262316129264, 2.4016797420661566`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}, {5.059262316129264, 2.4016797420661566`}, {
       5.059262316129264, 2.4016797420661566`}}, {{5.059262316129264, 
       2.4016797420661566`}, {4.979745966840478, 2.4197884040174453`}, {
       4.979745966840478, 2.4197884040174453`}, {5.059262316129264, 
       2.4016797420661566`}, {5.059262316129264, 2.4016797420661566`}}, {{
       5.059262316129264, 2.4016797420661566`}, {4.979745966840478, 
       2.4197884040174453`}, {4.979745966840478, 2.4197884040174453`}, {
       5.059262316129264, 2.4016797420661566`}, {5.059262316129264, 
       2.4016797420661566`}}, {{5.059262316129264, 2.4016797420661566`}, {
       4.979745966840478, 2.4197884040174453`}, {4.979745966840478, 
       2.4197884040174453`}, {5.059262316129264, 2.4016797420661566`}, {
       5.059262316129264, 2.4016797420661566`}}, {{4.979745966840478, 
       2.6590237941160084`}, {5.059262316129264, 2.677132456067297}, {
       5.059262316129264, 2.677132456067297}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}}, {{
       4.979745966840478, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.059262316129264, 2.677132456067297}, {
       4.979745966840478, 2.6590237941160084`}, {4.979745966840478, 
       2.6590237941160084`}}, {{4.979745966840478, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}, {4.979745966840478, 2.6590237941160084`}, {
       4.979745966840478, 2.6590237941160084`}}, {{4.979745966840478, 
       2.6590237941160084`}, {5.059262316129264, 2.677132456067297}, {
       5.059262316129264, 2.677132456067297}, {4.979745966840478, 
       2.6590237941160084`}, {4.979745966840478, 2.6590237941160084`}}, {{
       5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}}, {{5.059262316129264, 2.677132456067297}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}, {5.059262316129264, 2.677132456067297}, {
       5.059262316129264, 2.677132456067297}}, {{5.059262316129264, 
       2.677132456067297}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}, {5.059262316129264, 
       2.677132456067297}, {5.059262316129264, 2.677132456067297}}, {{
       5.059262316129264, 2.677132456067297}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}, {
       5.059262316129264, 2.677132456067297}, {5.059262316129264, 
       2.677132456067297}}, {{5.117868583713569, 2.6590237941160084`}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}}, {{5.117868583713569, 
       2.6590237941160084`}, {5.162854278784081, 2.617323608542656}, {
       5.162854278784081, 2.617323608542656}, {5.117868583713569, 
       2.6590237941160084`}, {5.117868583713569, 2.6590237941160084`}}, {{
       5.117868583713569, 2.6590237941160084`}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}, {
       5.117868583713569, 2.6590237941160084`}, {5.117868583713569, 
       2.6590237941160084`}}, {{5.117868583713569, 2.6590237941160084`}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}, {5.117868583713569, 2.6590237941160084`}, {
       5.117868583713569, 2.6590237941160084`}}, {{5.162854278784081, 
       2.617323608542656}, {5.186929892150114, 2.539406099066727}, {
       5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}}, {{
       5.162854278784081, 2.617323608542656}, {5.186929892150114, 
       2.539406099066727}, {5.186929892150114, 2.539406099066727}, {
       5.162854278784081, 2.617323608542656}, {5.162854278784081, 
       2.617323608542656}}, {{5.162854278784081, 2.617323608542656}, {
       5.186929892150114, 2.539406099066727}, {5.186929892150114, 
       2.539406099066727}, {5.162854278784081, 2.617323608542656}, {
       5.162854278784081, 2.617323608542656}}, {{5.162854278784081, 
       2.617323608542656}, {5.186929892150114, 2.539406099066727}, {
       5.186929892150114, 2.539406099066727}, {5.162854278784081, 
       2.617323608542656}, {5.162854278784081, 2.617323608542656}}, {{
       4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 3.0627309742051247`}, {4.907638449644008, 
       3.1327112266676638`}, {4.907638449644008, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.826832214449598, 
       2.9927507217425853`}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}, {{4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}}, {{5.1500571552272385`, 
       2.9927507217425853`}, {5.121887117326888, 2.9015821537120545`}, {
       5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {4.907638449644009, 2.8527902168175068`}, {
       4.907638449644009, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.069250920032828, 2.8527902168175068`}, {
       5.121887117326888, 2.9015821537120545`}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}}, {{
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}, {{4.907638449644009, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.121887117326888, 3.083919289773116}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.121887117326888, 3.083919289773116}, {
       5.069250920032828, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {4.907638449644009, 3.1327112266676638`}, {
       4.907638449644009, 3.1327112266676638`}}, {{5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}}, {{
       4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}, {{4.907638449644008, 2.8527902168175068`}, {
       4.842769172653094, 2.922770469280046}, {4.842769172653094, 
       2.922770469280046}, {4.907638449644008, 2.8527902168175068`}, {
       4.907638449644008, 2.8527902168175068`}}, {{4.907638449644008, 
       2.8527902168175068`}, {4.842769172653094, 2.922770469280046}, {
       4.842769172653094, 2.922770469280046}, {4.907638449644008, 
       2.8527902168175068`}, {4.907638449644008, 2.8527902168175068`}}, {{
       4.907638449644008, 2.8527902168175068`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}, {
       4.907638449644008, 2.8527902168175068`}, {4.907638449644008, 
       2.8527902168175068`}}, {{4.842769172653094, 2.922770469280046}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.842769172653094, 2.922770469280046}, {
       4.842769172653094, 2.922770469280046}}, {{4.842769172653094, 
       2.922770469280046}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}, {4.842769172653094, 
       2.922770469280046}, {4.842769172653094, 2.922770469280046}}, {{
       4.842769172653094, 2.922770469280046}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 2.922770469280046}, {4.842769172653094, 
       2.922770469280046}}, {{4.842769172653094, 2.922770469280046}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}, {4.842769172653094, 2.922770469280046}, {
       4.842769172653094, 2.922770469280046}}, {{4.826832214449598, 
       2.9927507217425853`}, {4.842769172653094, 3.0627309742051247`}, {
       4.842769172653094, 3.0627309742051247`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}}, {{
       4.826832214449598, 2.9927507217425853`}, {4.842769172653094, 
       3.0627309742051247`}, {4.842769172653094, 3.0627309742051247`}, {
       4.826832214449598, 2.9927507217425853`}, {4.826832214449598, 
       2.9927507217425853`}}, {{4.826832214449598, 2.9927507217425853`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}, {4.826832214449598, 2.9927507217425853`}, {
       4.826832214449598, 2.9927507217425853`}}, {{4.826832214449598, 
       2.9927507217425853`}, {4.842769172653094, 3.0627309742051247`}, {
       4.842769172653094, 3.0627309742051247`}, {4.826832214449598, 
       2.9927507217425853`}, {4.826832214449598, 2.9927507217425853`}}, {{
       4.842769172653094, 3.0627309742051247`}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}}, {{4.842769172653094, 3.0627309742051247`}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}, {4.842769172653094, 3.0627309742051247`}, {
       4.842769172653094, 3.0627309742051247`}}, {{4.842769172653094, 
       3.0627309742051247`}, {4.907638449644009, 3.1327112266676638`}, {
       4.907638449644009, 3.1327112266676638`}, {4.842769172653094, 
       3.0627309742051247`}, {4.842769172653094, 3.0627309742051247`}}, {{
       4.842769172653094, 3.0627309742051247`}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}, {
       4.842769172653094, 3.0627309742051247`}, {4.842769172653094, 
       3.0627309742051247`}}, {{5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.1500571552272385`, 2.9927507217425853`}}, {{5.1500571552272385`, 
       2.9927507217425853`}, {5.121887117326888, 2.9015821537120545`}, {
       5.121887117326888, 2.9015821537120545`}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}}, {{
       5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888, 
       2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}}, {{5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.1500571552272385`, 2.9927507217425853`}}, {{5.121887117326888, 
       2.9015821537120545`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.121887117326888, 
       2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}}, {{
       5.121887117326888, 2.9015821537120545`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}, {
       5.121887117326888, 2.9015821537120545`}, {5.121887117326888, 
       2.9015821537120545`}}, {{5.121887117326888, 2.9015821537120545`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}, {5.121887117326888, 2.9015821537120545`}, {
       5.121887117326888, 2.9015821537120545`}}, {{5.121887117326888, 
       2.9015821537120545`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}, {5.121887117326888, 
       2.9015821537120545`}, {5.121887117326888, 2.9015821537120545`}}, {{
       5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}, {{5.069250920032828, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.000677764535273, 
       2.8316019012495155`}, {5.069250920032828, 2.8527902168175068`}, {
       5.069250920032828, 2.8527902168175068`}}, {{5.069250920032828, 
       2.8527902168175068`}, {5.000677764535273, 2.8316019012495155`}, {
       5.000677764535273, 2.8316019012495155`}, {5.069250920032828, 
       2.8527902168175068`}, {5.069250920032828, 2.8527902168175068`}}, {{
       5.069250920032828, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}, {
       5.069250920032828, 2.8527902168175068`}, {5.069250920032828, 
       2.8527902168175068`}}, {{5.000677764535273, 2.8316019012495155`}, {
       4.907638449644009, 2.8527902168175068`}, {4.907638449644009, 
       2.8527902168175068`}, {5.000677764535273, 2.8316019012495155`}, {
       5.000677764535273, 2.8316019012495155`}}, {{5.000677764535273, 
       2.8316019012495155`}, {4.907638449644009, 2.8527902168175068`}, {
       4.907638449644009, 2.8527902168175068`}, {5.000677764535273, 
       2.8316019012495155`}, {5.000677764535273, 2.8316019012495155`}}, {{
       5.000677764535273, 2.8316019012495155`}, {4.907638449644009, 
       2.8527902168175068`}, {4.907638449644009, 2.8527902168175068`}, {
       5.000677764535273, 2.8316019012495155`}, {5.000677764535273, 
       2.8316019012495155`}}, {{5.000677764535273, 2.8316019012495155`}, {
       4.907638449644009, 2.8527902168175068`}, {4.907638449644009, 
       2.8527902168175068`}, {5.000677764535273, 2.8316019012495155`}, {
       5.000677764535273, 2.8316019012495155`}}, {{4.907638449644009, 
       3.1327112266676638`}, {5.000677764535273, 3.153899542235655}, {
       5.000677764535273, 3.153899542235655}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}}, {{
       4.907638449644009, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.000677764535273, 3.153899542235655}, {
       4.907638449644009, 3.1327112266676638`}, {4.907638449644009, 
       3.1327112266676638`}}, {{4.907638449644009, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}, {4.907638449644009, 3.1327112266676638`}, {
       4.907638449644009, 3.1327112266676638`}}, {{4.907638449644009, 
       3.1327112266676638`}, {5.000677764535273, 3.153899542235655}, {
       5.000677764535273, 3.153899542235655}, {4.907638449644009, 
       3.1327112266676638`}, {4.907638449644009, 3.1327112266676638`}}, {{
       5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}}, {{5.000677764535273, 3.153899542235655}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}, {5.000677764535273, 3.153899542235655}, {
       5.000677764535273, 3.153899542235655}}, {{5.000677764535273, 
       3.153899542235655}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}, {5.000677764535273, 
       3.153899542235655}, {5.000677764535273, 3.153899542235655}}, {{
       5.000677764535273, 3.153899542235655}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}, {
       5.000677764535273, 3.153899542235655}, {5.000677764535273, 
       3.153899542235655}}, {{5.069250920032828, 3.1327112266676638`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}}, {{5.069250920032828, 
       3.1327112266676638`}, {5.121887117326888, 3.083919289773116}, {
       5.121887117326888, 3.083919289773116}, {5.069250920032828, 
       3.1327112266676638`}, {5.069250920032828, 3.1327112266676638`}}, {{
       5.069250920032828, 3.1327112266676638`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}, {
       5.069250920032828, 3.1327112266676638`}, {5.069250920032828, 
       3.1327112266676638`}}, {{5.069250920032828, 3.1327112266676638`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}, {5.069250920032828, 3.1327112266676638`}, {
       5.069250920032828, 3.1327112266676638`}}, {{5.121887117326888, 
       3.083919289773116}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}}, {{
       5.121887117326888, 3.083919289773116}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.121887117326888, 3.083919289773116}, {5.121887117326888, 
       3.083919289773116}}, {{5.121887117326888, 3.083919289773116}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.1500571552272385`, 
       2.9927507217425853`}, {5.121887117326888, 3.083919289773116}, {
       5.121887117326888, 3.083919289773116}}, {{5.121887117326888, 
       3.083919289773116}, {5.1500571552272385`, 2.9927507217425853`}, {
       5.1500571552272385`, 2.9927507217425853`}, {5.121887117326888, 
       3.083919289773116}, {5.121887117326888, 3.083919289773116}}, {{
       4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.89204021083357, 
       3.456468031047497}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}, {{4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}}, {{5.162433198171528, 
       3.456468031047497}, {5.138867625901722, 3.38020120150832}, {
       5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {4.95963845766806, 3.3393844330275795`}, {
       4.95963845766806, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.094834951337038, 3.3393844330275795`}, {
       5.138867625901722, 3.38020120150832}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}}, {{
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}, {{4.95963845766806, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.138867625901722, 3.5327348605866744`}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}, {5.138867625901722, 3.5327348605866744`}, {
       5.094834951337038, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {4.95963845766806, 3.5735516290674147`}, {
       4.95963845766806, 3.5735516290674147`}}, {{5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}}, {{
       4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}, {{4.95963845766806, 3.3393844330275795`}, {
       4.905372231955938, 3.3979262320375385`}, {4.905372231955938, 
       3.3979262320375385`}, {4.95963845766806, 3.3393844330275795`}, {
       4.95963845766806, 3.3393844330275795`}}, {{4.95963845766806, 
       3.3393844330275795`}, {4.905372231955938, 3.3979262320375385`}, {
       4.905372231955938, 3.3979262320375385`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}}, {{
       4.95963845766806, 3.3393844330275795`}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}}, {{4.905372231955938, 3.3979262320375385`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.905372231955938, 3.3979262320375385`}, {
       4.905372231955938, 3.3979262320375385`}}, {{4.905372231955938, 
       3.3979262320375385`}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}, {4.905372231955938, 
       3.3979262320375385`}, {4.905372231955938, 3.3979262320375385`}}, {{
       4.905372231955938, 3.3979262320375385`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.3979262320375385`}, {4.905372231955938, 
       3.3979262320375385`}}, {{4.905372231955938, 3.3979262320375385`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}, {4.905372231955938, 3.3979262320375385`}, {
       4.905372231955938, 3.3979262320375385`}}, {{4.89204021083357, 
       3.456468031047497}, {4.905372231955938, 3.5150098300574557`}, {
       4.905372231955938, 3.5150098300574557`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}}, {{
       4.89204021083357, 3.456468031047497}, {4.905372231955938, 
       3.5150098300574557`}, {4.905372231955938, 3.5150098300574557`}, {
       4.89204021083357, 3.456468031047497}, {4.89204021083357, 
       3.456468031047497}}, {{4.89204021083357, 3.456468031047497}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}, {4.89204021083357, 3.456468031047497}, {
       4.89204021083357, 3.456468031047497}}, {{4.89204021083357, 
       3.456468031047497}, {4.905372231955938, 3.5150098300574557`}, {
       4.905372231955938, 3.5150098300574557`}, {4.89204021083357, 
       3.456468031047497}, {4.89204021083357, 3.456468031047497}}, {{
       4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}}, {{4.905372231955938, 3.5150098300574557`}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}, {4.905372231955938, 3.5150098300574557`}, {
       4.905372231955938, 3.5150098300574557`}}, {{4.905372231955938, 
       3.5150098300574557`}, {4.95963845766806, 3.5735516290674147`}, {
       4.95963845766806, 3.5735516290674147`}, {4.905372231955938, 
       3.5150098300574557`}, {4.905372231955938, 3.5150098300574557`}}, {{
       4.905372231955938, 3.5150098300574557`}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}, {
       4.905372231955938, 3.5150098300574557`}, {4.905372231955938, 
       3.5150098300574557`}}, {{5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}, {5.162433198171528, 3.456468031047497}, {
       5.162433198171528, 3.456468031047497}}, {{5.162433198171528, 
       3.456468031047497}, {5.138867625901722, 3.38020120150832}, {
       5.138867625901722, 3.38020120150832}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}}, {{
       5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}}, {{5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}, {5.162433198171528, 3.456468031047497}, {
       5.162433198171528, 3.456468031047497}}, {{5.138867625901722, 
       3.38020120150832}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}}, {{
       5.138867625901722, 3.38020120150832}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}, {
       5.138867625901722, 3.38020120150832}, {5.138867625901722, 
       3.38020120150832}}, {{5.138867625901722, 3.38020120150832}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}, {5.138867625901722, 3.38020120150832}, {
       5.138867625901722, 3.38020120150832}}, {{5.138867625901722, 
       3.38020120150832}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}, {5.138867625901722, 
       3.38020120150832}, {5.138867625901722, 3.38020120150832}}, {{
       5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}, {{5.094834951337038, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.037470255649987, 
       3.3216594024983612`}, {5.094834951337038, 3.3393844330275795`}, {
       5.094834951337038, 3.3393844330275795`}}, {{5.094834951337038, 
       3.3393844330275795`}, {5.037470255649987, 3.3216594024983612`}, {
       5.037470255649987, 3.3216594024983612`}, {5.094834951337038, 
       3.3393844330275795`}, {5.094834951337038, 3.3393844330275795`}}, {{
       5.094834951337038, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}, {
       5.094834951337038, 3.3393844330275795`}, {5.094834951337038, 
       3.3393844330275795`}}, {{5.037470255649987, 3.3216594024983612`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}, {5.037470255649987, 3.3216594024983612`}, {
       5.037470255649987, 3.3216594024983612`}}, {{5.037470255649987, 
       3.3216594024983612`}, {4.95963845766806, 3.3393844330275795`}, {
       4.95963845766806, 3.3393844330275795`}, {5.037470255649987, 
       3.3216594024983612`}, {5.037470255649987, 3.3216594024983612`}}, {{
       5.037470255649987, 3.3216594024983612`}, {4.95963845766806, 
       3.3393844330275795`}, {4.95963845766806, 3.3393844330275795`}, {
       5.037470255649987, 3.3216594024983612`}, {5.037470255649987, 
       3.3216594024983612`}}, {{5.037470255649987, 3.3216594024983612`}, {
       4.95963845766806, 3.3393844330275795`}, {4.95963845766806, 
       3.3393844330275795`}, {5.037470255649987, 3.3216594024983612`}, {
       5.037470255649987, 3.3216594024983612`}}, {{4.95963845766806, 
       3.5735516290674147`}, {5.037470255649987, 3.591276659596633}, {
       5.037470255649987, 3.591276659596633}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}}, {{
       4.95963845766806, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.037470255649987, 3.591276659596633}, {
       4.95963845766806, 3.5735516290674147`}, {4.95963845766806, 
       3.5735516290674147`}}, {{4.95963845766806, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}, {4.95963845766806, 3.5735516290674147`}, {
       4.95963845766806, 3.5735516290674147`}}, {{4.95963845766806, 
       3.5735516290674147`}, {5.037470255649987, 3.591276659596633}, {
       5.037470255649987, 3.591276659596633}, {4.95963845766806, 
       3.5735516290674147`}, {4.95963845766806, 3.5735516290674147`}}, {{
       5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}}, {{5.037470255649987, 3.591276659596633}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}, {5.037470255649987, 3.591276659596633}, {
       5.037470255649987, 3.591276659596633}}, {{5.037470255649987, 
       3.591276659596633}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}, {5.037470255649987, 
       3.591276659596633}, {5.037470255649987, 3.591276659596633}}, {{
       5.037470255649987, 3.591276659596633}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}, {
       5.037470255649987, 3.591276659596633}, {5.037470255649987, 
       3.591276659596633}}, {{5.094834951337038, 3.5735516290674147`}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}}, {{5.094834951337038, 
       3.5735516290674147`}, {5.138867625901722, 3.5327348605866744`}, {
       5.138867625901722, 3.5327348605866744`}, {5.094834951337038, 
       3.5735516290674147`}, {5.094834951337038, 3.5735516290674147`}}, {{
       5.094834951337038, 3.5735516290674147`}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}, {
       5.094834951337038, 3.5735516290674147`}, {5.094834951337038, 
       3.5735516290674147`}}, {{5.094834951337038, 3.5735516290674147`}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}, {5.094834951337038, 3.5735516290674147`}, {
       5.094834951337038, 3.5735516290674147`}}, {{5.138867625901722, 
       3.5327348605866744`}, {5.162433198171528, 3.456468031047497}, {
       5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}}, {{
       5.138867625901722, 3.5327348605866744`}, {5.162433198171528, 
       3.456468031047497}, {5.162433198171528, 3.456468031047497}, {
       5.138867625901722, 3.5327348605866744`}, {5.138867625901722, 
       3.5327348605866744`}}, {{5.138867625901722, 3.5327348605866744`}, {
       5.162433198171528, 3.456468031047497}, {5.162433198171528, 
       3.456468031047497}, {5.138867625901722, 3.5327348605866744`}, {
       5.138867625901722, 3.5327348605866744`}}, {{5.138867625901722, 
       3.5327348605866744`}, {5.162433198171528, 3.456468031047497}, {
       5.162433198171528, 3.456468031047497}, {5.138867625901722, 
       3.5327348605866744`}, {5.138867625901722, 3.5327348605866744`}}, {{
       5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}, {{
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}, {{
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}, {{
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}, {{
       5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}, {{
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}, {{
       5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}, {{
       5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}, {{
       5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}, {{
       5.163534406607535, -4.33782130761476}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}}, {{
       5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}, {{
       5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}, {{
       5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}, {{
       5.1045942734929985`, -4.274237349432082}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.274237349432082}, {
       5.1045942734929985`, -4.274237349432082}}, {{
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}, {{
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}, {{
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}, {{
       5.090113975861711, -4.210653391249402}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.090113975861711, -4.210653391249402}, {
       5.090113975861711, -4.210653391249402}}, {{
       5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}, {{
       5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}, {{
       5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}, {{
       5.1045942734929985`, -4.147069433066723}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}, {
       5.1045942734929985`, -4.147069433066723}, {
       5.1045942734929985`, -4.147069433066723}}, {{
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}, {{
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}, {{
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}, {{
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}}, {{
       5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}, {{
       5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}, {{
       5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}, {{
       5.3582004423429055`, -4.293489022920367}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}, {
       5.3582004423429055`, -4.293489022920367}, {
       5.3582004423429055`, -4.293489022920367}}, {{
       5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}, {{
       5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}, {{
       5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}, {{
       5.310375268099182, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.310375268099182, -4.33782130761476}, {
       5.310375268099182, -4.33782130761476}}, {{
       5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}, {{
       5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}, {{
       5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}, {{
       5.24806979622417, -4.3570729811030455`}, {
       5.163534406607535, -4.33782130761476}, {
       5.163534406607535, -4.33782130761476}, {
       5.24806979622417, -4.3570729811030455`}, {
       5.24806979622417, -4.3570729811030455`}}, {{
       5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}, {{
       5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}, {{
       5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}, {{
       5.163534406607535, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}, {
       5.163534406607535, -4.083485474884045}, {
       5.163534406607535, -4.083485474884045}}, {{
       5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}, {{
       5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}, {{
       5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}, {{
       5.24806979622417, -4.064233801395759}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}, {
       5.24806979622417, -4.064233801395759}, {
       5.24806979622417, -4.064233801395759}}, {{
       5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}, {{
       5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}, {{
       5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}, {{
       5.310375268099182, -4.083485474884045}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.310375268099182, -4.083485474884045}, {
       5.310375268099182, -4.083485474884045}}, {{
       5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}, {{
       5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}, {{
       5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}, {{
       5.3582004423429055`, -4.127817759578438}, {
       5.383795698845005, -4.210653391249402}, {
       5.383795698845005, -4.210653391249402}, {
       5.3582004423429055`, -4.127817759578438}, {
       5.3582004423429055`, -4.127817759578438}}, {{
       5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}, {{
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}, {{
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}, {{
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}, {{
       5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}, {{
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}, {{
       5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}, {{
       5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}, {{
       5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}, {{
       5.213514887102683, -3.9234189058141133`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}}, {{
       5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}, {{
       5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}, {{
       5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}, {{
       5.150860829595763, -3.8558284074222344`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.8558284074222344`}, {
       5.150860829595763, -3.8558284074222344`}}, {{
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}, {{
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}, {{
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}, {{
       5.135468102220259, -3.788237909030356}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.135468102220259, -3.788237909030356}, {
       5.135468102220259, -3.788237909030356}}, {{
       5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}, {{
       5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}, {{
       5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}, {{
       5.150860829595763, -3.7206474106384775`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.150860829595763, -3.7206474106384775`}, {
       5.150860829595763, -3.7206474106384775`}}, {{
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}, {{
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}, {{
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}, {{
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}}, {{
       5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}, {{
       5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}, {{
       5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}, {{
       5.420447181841597, -3.876293163677459}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.420447181841597, -3.876293163677459}, {
       5.420447181841597, -3.876293163677459}}, {{
       5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}, {{
       5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}, {{
       5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}, {{
       5.369608456867532, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.369608456867532, -3.9234189058141133`}, {
       5.369608456867532, -3.9234189058141133`}}, {{
       5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}, {{
       5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}, {{
       5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}, {{
       5.303377004517961, -3.9438836620693376`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.213514887102683, -3.9234189058141133`}, {
       5.303377004517961, -3.9438836620693376`}, {
       5.303377004517961, -3.9438836620693376`}}, {{
       5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}, {{
       5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}, {{
       5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}, {{
       5.213514887102683, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.213514887102683, -3.6530569122465986`}, {
       5.213514887102683, -3.6530569122465986`}}, {{
       5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}, {{
       5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}, {{
       5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}, {{
       5.303377004517961, -3.6325921559913743`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.303377004517961, -3.6325921559913743`}, {
       5.303377004517961, -3.6325921559913743`}}, {{
       5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}, {{
       5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}, {{
       5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}, {{
       5.369608456867532, -3.6530569122465986`}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}, {
       5.369608456867532, -3.6530569122465986`}, {
       5.369608456867532, -3.6530569122465986`}}, {{
       5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}, {{
       5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}, {{
       5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}, {{
       5.420447181841597, -3.700182654383253}, {
       5.447655241749955, -3.788237909030356}, {
       5.447655241749955, -3.788237909030356}, {
       5.420447181841597, -3.700182654383253}, {
       5.420447181841597, -3.700182654383253}}, {{
       5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}, {{
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}, {{
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}, {{
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}, {{
       5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}, {{
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}, {{
       5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}, {{
       5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}, {{
       5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}, {{
       5.166897539697304, -3.4070971785629096`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}}, {{
       5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}, {{
       5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}, {{
       5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}, {{
       5.0983315537397305`, -3.33312895770042}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.33312895770042}, {
       5.0983315537397305`, -3.33312895770042}}, {{
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}, {{
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}, {{
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}, {{
       5.081486395244432, -3.2591607368379307`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.081486395244432, -3.2591607368379307`}, {
       5.081486395244432, -3.2591607368379307`}}, {{
       5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}, {{
       5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}, {{
       5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}, {{
       5.0983315537397305`, -3.1851925159754413`}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}, {
       5.0983315537397305`, -3.1851925159754413`}, {
       5.0983315537397305`, -3.1851925159754413`}}, {{
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}, {{
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}, {{
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}, {{
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}}, {{
       5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}, {{
       5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}, {{
       5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}, {{
       5.393355607695052, -3.3555247329439615`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.393355607695052, -3.3555247329439615`}, {
       5.393355607695052, -3.3555247329439615`}}, {{
       5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}, {{
       5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}, {{
       5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}, {{
       5.337719828603047, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.337719828603047, -3.4070971785629096`}, {
       5.337719828603047, -3.4070971785629096`}}, {{
       5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}, {{
       5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}, {{
       5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}, {{
       5.265238891015745, -3.4294929538064505`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.166897539697304, -3.4070971785629096`}, {
       5.265238891015745, -3.4294929538064505`}, {
       5.265238891015745, -3.4294929538064505`}}, {{
       5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}, {{
       5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}, {{
       5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}, {{
       5.166897539697304, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}, {
       5.166897539697304, -3.111224295112952}, {
       5.166897539697304, -3.111224295112952}}, {{
       5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}, {{
       5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}, {{
       5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}, {{
       5.265238891015745, -3.088828519869411}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}, {
       5.265238891015745, -3.088828519869411}, {
       5.265238891015745, -3.088828519869411}}, {{
       5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}, {{
       5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}, {{
       5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}, {{
       5.337719828603047, -3.111224295112952}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}, {
       5.337719828603047, -3.111224295112952}, {
       5.337719828603047, -3.111224295112952}}, {{
       5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}, {{
       5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}, {{
       5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}, {{
       5.393355607695052, -3.1627967407319}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.42313097305592, -3.2591607368379307`}, {
       5.393355607695052, -3.1627967407319}, {
       5.393355607695052, -3.1627967407319}}, {{
       5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.572334059908817}, {
       5.150456015732221, -2.572334059908817}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}, {{
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}, {{
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.872891371667967}, {
       5.150456015732221, -2.872891371667967}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}, {{
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}, {{
       5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}, {{
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}, {{
       5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}, {{
       5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}, {{
       5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}, {{
       5.150456015732221, -2.8728913716679667`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}}, {{
       5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}, {{
       5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}, {{
       5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}, {{
       5.080804453962758, -2.7977520437281793`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.7977520437281793`}, {
       5.080804453962758, -2.7977520437281793`}}, {{
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}, {{
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}, {{
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}, {{
       5.063692593306693, -2.722612715788392}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.063692593306693, -2.722612715788392}, {
       5.063692593306693, -2.722612715788392}}, {{
       5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}, {{
       5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}, {{
       5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}, {{
       5.080804453962758, -2.6474733878486045`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.080804453962758, -2.6474733878486045`}, {
       5.080804453962758, -2.6474733878486045`}}, {{
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}, {{
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}, {{
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}, {{
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}}, {{
       5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}, {{
       5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}, {{
       5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}, {{
       5.38049949707439, -2.820502401663902}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.38049949707439, -2.820502401663902}, {
       5.38049949707439, -2.820502401663902}}, {{
       5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}, {{
       5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}, {{
       5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}, {{
       5.323982860583277, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.323982860583277, -2.8728913716679667`}, {
       5.323982860583277, -2.8728913716679667`}}, {{
       5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}, {{
       5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}, {{
       5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}, {{
       5.250354363436099, -2.8956417296036894`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.150456015732221, -2.8728913716679667`}, {
       5.250354363436099, -2.8956417296036894`}, {
       5.250354363436099, -2.8956417296036894`}}, {{
       5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}, {{
       5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}, {{
       5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}, {{
       5.150456015732221, -2.5723340599088167`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.150456015732221, -2.5723340599088167`}, {
       5.150456015732221, -2.5723340599088167`}}, {{
       5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}, {{
       5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}, {{
       5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}, {{
       5.250354363436099, -2.5495837019730945`}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}, {
       5.250354363436099, -2.5495837019730945`}, {
       5.250354363436099, -2.5495837019730945`}}, {{
       5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}, {{
       5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}, {{
       5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}, {{
       5.323982860583277, -2.572334059908817}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}, {
       5.323982860583277, -2.572334059908817}, {
       5.323982860583277, -2.572334059908817}}, {{
       5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}, {{
       5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}, {{
       5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}, {{
       5.38049949707439, -2.624723029912882}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.4107462830088044`, -2.722612715788392}, {
       5.38049949707439, -2.624723029912882}, {
       5.38049949707439, -2.624723029912882}}, {{
       5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}, {{
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}, {{
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.35914164638797, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}, {{
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}, {{
       5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}, {{
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}, {{
       5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}, {{
       5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}, {{
       5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}, {{
       5.1340991829308456`, -2.3815727223921397`}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}}, {{
       5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}, {{
       5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}, {{
       5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}, {{
       5.065961807540836, -2.308066881829194}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.308066881829194}, {
       5.065961807540836, -2.308066881829194}}, {{
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}, {{
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}, {{
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}, {{
       5.049221949258793, -2.234561041266248}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}, {
       5.049221949258793, -2.234561041266248}, {
       5.049221949258793, -2.234561041266248}}, {{
       5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}, {{
       5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}, {{
       5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}, {{
       5.065961807540836, -2.161055200703302}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.065961807540836, -2.161055200703302}, {
       5.065961807540836, -2.161055200703302}}, {{
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}, {{
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}, {{
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}, {{
       5.388730883947004, -2.234561041266248}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}}, {{
       5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}, {{
       5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}, {{
       5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}, {{
       5.359141646387969, -2.330322659582666}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.359141646387969, -2.330322659582666}, {
       5.359141646387969, -2.330322659582666}}, {{
       5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}, {{
       5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}, {{
       5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}, {{
       5.303853650274951, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}, {
       5.303853650274951, -2.3815727223921397`}, {
       5.303853650274951, -2.3815727223921397`}}, {{
       5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}, {{
       5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}, {{
       5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}, {{
       5.23182579587989, -2.403828500145612}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.1340991829308456`, -2.3815727223921397`}, {
       5.23182579587989, -2.403828500145612}, {
       5.23182579587989, -2.403828500145612}}, {{
       5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}, {{
       5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}, {{
       5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}, {{
       5.1340991829308456`, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}, {
       5.1340991829308456`, -2.0875493601403563`}, {
       5.1340991829308456`, -2.0875493601403563`}}, {{
       5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}, {{
       5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}, {{
       5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}, {{
       5.23182579587989, -2.065293582386884}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.23182579587989, -2.065293582386884}, {
       5.23182579587989, -2.065293582386884}}, {{
       5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}, {{
       5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}, {{
       5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}, {{
       5.303853650274951, -2.0875493601403563`}, {
       5.359141646387969, -2.13879942294983}, {
       5.359141646387969, -2.13879942294983}, {
       5.303853650274951, -2.0875493601403563`}, {
       5.303853650274951, -2.0875493601403563`}}, {{
       5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}, {{
       5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}, {{
       5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}, {{
       5.35914164638797, -2.13879942294983}, {
       5.388730883947004, -2.234561041266248}, {
       5.388730883947004, -2.234561041266248}, {
       5.35914164638797, -2.13879942294983}, {
       5.35914164638797, -2.13879942294983}}, {{
       5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}, {{
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}, {{
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}, {{
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}, {{
       5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}, {{
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}, {{
       5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}, {{
       5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}, {{
       5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}, {{
       5.176461694247064, -1.8627018430271236`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}}, {{
       5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}, {{
       5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}, {{
       5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}, {{
       5.108251160656175, -1.7891170802130791`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.7891170802130791`}, {
       5.108251160656175, -1.7891170802130791`}}, {{
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}, {{
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}, {{
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}, {{
       5.091493329009178, -1.7155323173990347`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.091493329009178, -1.7155323173990347`}, {
       5.091493329009178, -1.7155323173990347`}}, {{
       5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}, {{
       5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}, {{
       5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}, {{
       5.108251160656175, -1.6419475545849902`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.108251160656175, -1.6419475545849902`}, {
       5.108251160656175, -1.6419475545849902`}}, {{
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}, {{
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}, {{
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}, {{
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}}, {{
       5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}, {{
       5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}, {{
       5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}, {{
       5.401745782827754, -1.811396753701459}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.401745782827754, -1.811396753701459}, {
       5.401745782827754, -1.811396753701459}}, {{
       5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}, {{
       5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}, {{
       5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}, {{
       5.346398424722838, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.346398424722838, -1.8627018430271236`}, {
       5.346398424722838, -1.8627018430271236`}}, {{
       5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}, {{
       5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}, {{
       5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}, {{
       5.274293234970924, -1.8849815165155035`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.176461694247064, -1.8627018430271236`}, {
       5.274293234970924, -1.8849815165155035`}, {
       5.274293234970924, -1.8849815165155035`}}, {{
       5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}, {{
       5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}, {{
       5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}, {{
       5.176461694247064, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.176461694247064, -1.5683627917709457`}, {
       5.176461694247064, -1.5683627917709457`}}, {{
       5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}, {{
       5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}, {{
       5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}, {{
       5.274293234970924, -1.5460831182825658`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.274293234970924, -1.5460831182825658`}, {
       5.274293234970924, -1.5460831182825658`}}, {{
       5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}, {{
       5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}, {{
       5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}, {{
       5.346398424722838, -1.5683627917709457`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.346398424722838, -1.5683627917709457`}, {
       5.346398424722838, -1.5683627917709457`}}, {{
       5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}, {{
       5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}, {{
       5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}, {{
       5.401745782827754, -1.6196678810966103`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.431366789960724, -1.7155323173990347`}, {
       5.401745782827754, -1.6196678810966103`}, {
       5.401745782827754, -1.6196678810966103`}}, {{
       5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.162208191993878}, {
       5.19335521461503, -1.162208191993878}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}, {{
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}, {{
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848608`}, {
       5.19335521461503, -1.4089886270848608`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}, {{
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}, {{
       5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}, {{
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}, {{
       5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}, {{
       5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}, {{
       5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}, {{
       5.19335521461503, -1.4089886270848606`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}}, {{
       5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}, {{
       5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}, {{
       5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}, {{
       5.136165979664696, -1.347293518312115}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.347293518312115}, {
       5.136165979664696, -1.347293518312115}}, {{
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}, {{
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}, {{
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}, {{
       5.122115839299774, -1.2855984095393693`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.122115839299774, -1.2855984095393693`}, {
       5.122115839299774, -1.2855984095393693`}}, {{
       5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}, {{
       5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}, {{
       5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}, {{
       5.136165979664696, -1.2239033007666236`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.136165979664696, -1.2239033007666236`}, {
       5.136165979664696, -1.2239033007666236`}}, {{
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}, {{
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}, {{
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}, {{
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}}, {{
       5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}, {{
       5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}, {{
       5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}, {{
       5.382238426549522, -1.3659732942157279`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.382238426549522, -1.3659732942157279`}, {
       5.382238426549522, -1.3659732942157279`}}, {{
       5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}, {{
       5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}, {{
       5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}, {{
       5.335833965245541, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.335833965245541, -1.4089886270848606`}, {
       5.335833965245541, -1.4089886270848606`}}, {{
       5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}, {{
       5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}, {{
       5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}, {{
       5.275379363576638, -1.4276684029884736`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.19335521461503, -1.4089886270848606`}, {
       5.275379363576638, -1.4276684029884736`}, {
       5.275379363576638, -1.4276684029884736`}}, {{
       5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}, {{
       5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}, {{
       5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}, {{
       5.19335521461503, -1.1622081919938778`}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}, {
       5.19335521461503, -1.1622081919938778`}, {
       5.19335521461503, -1.1622081919938778`}}, {{
       5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}, {{
       5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}, {{
       5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}, {{
       5.275379363576638, -1.143528416090265}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}, {
       5.275379363576638, -1.143528416090265}, {
       5.275379363576638, -1.143528416090265}}, {{
       5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}, {{
       5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}, {{
       5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}, {{
       5.335833965245541, -1.162208191993878}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.335833965245541, -1.162208191993878}, {
       5.335833965245541, -1.162208191993878}}, {{
       5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}, {{
       5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}, {{
       5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}, {{
       5.382238426549522, -1.2052235248630108`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.407073340560798, -1.2855984095393693`}, {
       5.382238426549522, -1.2052235248630108`}, {
       5.382238426549522, -1.2052235248630108`}}, {{
       5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}, {{
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}, {{
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.3321267483001495`, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}, {{
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}, {{
       5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}, {{
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}, {{
       5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}, {{
       5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}, {{
       5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}, {{
       5.1356453243930344`, -0.8906737604189562}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}}, {{
       5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}, {{
       5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}, {{
       5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}, {{
       5.076155535967067, -0.8264968402171889}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.8264968402171889}, {
       5.076155535967067, -0.8264968402171889}}, {{
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}, {{
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}, {{
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}, {{
       5.061540200084531, -0.7623199200154217}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}, {
       5.061540200084531, -0.7623199200154217}, {
       5.061540200084531, -0.7623199200154217}}, {{
       5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}, {{
       5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}, {{
       5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}, {{
       5.076155535967067, -0.6981429998136545}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.076155535967067, -0.6981429998136545}, {
       5.076155535967067, -0.6981429998136545}}, {{
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}, {{
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}, {{
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}, {{
       5.357960697318543, -0.7623199200154217}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}}, {{
       5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}, {{
       5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}, {{
       5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}, {{
       5.332126748300149, -0.8459280481589543}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}, {
       5.332126748300149, -0.8459280481589543}, {
       5.332126748300149, -0.8459280481589543}}, {{
       5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}, {{
       5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}, {{
       5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}, {{
       5.283855573010039, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}, {
       5.283855573010039, -0.8906737604189562}, {
       5.283855573010039, -0.8906737604189562}}, {{
       5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}, {{
       5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}, {{
       5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}, {{
       5.220969061837395, -0.9101049683607215}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.1356453243930344`, -0.8906737604189562}, {
       5.220969061837395, -0.9101049683607215}, {
       5.220969061837395, -0.9101049683607215}}, {{
       5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}, {{
       5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}, {{
       5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}, {{
       5.1356453243930344`, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}, {
       5.1356453243930344`, -0.6339660796118872}, {
       5.1356453243930344`, -0.6339660796118872}}, {{
       5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}, {{
       5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}, {{
       5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}, {{
       5.220969061837395, -0.6145348716701219}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}, {
       5.220969061837395, -0.6145348716701219}, {
       5.220969061837395, -0.6145348716701219}}, {{
       5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}, {{
       5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}, {{
       5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}, {{
       5.283855573010039, -0.6339660796118872}, {
       5.332126748300149, -0.6787117918718891}, {
       5.332126748300149, -0.6787117918718891}, {
       5.283855573010039, -0.6339660796118872}, {
       5.283855573010039, -0.6339660796118872}}, {{
       5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}, {{
       5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}, {{
       5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}, {{
       5.3321267483001495`, -0.6787117918718891}, {
       5.357960697318543, -0.7623199200154217}, {
       5.357960697318543, -0.7623199200154217}, {
       5.3321267483001495`, -0.6787117918718891}, {
       5.3321267483001495`, -0.6787117918718891}}, {{
       5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}, {{
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}, {{
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}, {{
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}, {{
       5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.20021028433532914`}, {
       5.459273354743041, -0.20021028433532914`}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}, {{
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}, {{
       5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}, {{
       5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}, {{
       5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}, {{
       5.189511061408361, -0.35595761700931716`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}}, {{
       5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}, {{
       5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}, {{
       5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}, {{
       5.117324862385763, -0.27808395067232317`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.27808395067232317`}, {
       5.117324862385763, -0.27808395067232317`}}, {{
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}, {{
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}, {{
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}, {{
       5.099590296963467, -0.20021028433532917`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.117324862385763, -0.12233661799833516`}, {
       5.099590296963467, -0.20021028433532917`}, {
       5.099590296963467, -0.20021028433532917`}}, {{
       5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}, {{
       5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}, {{
       5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}, {{
       5.117324862385763, -0.12233661799833515`}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}, {
       5.117324862385763, -0.12233661799833515`}, {
       5.117324862385763, -0.12233661799833515`}}, {{
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}, {{
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}, {{
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}, {{
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}}, {{
       5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}, {{
       5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}, {{
       5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}, {{
       5.427925880920669, -0.30166219966003505`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.427925880920669, -0.30166219966003505`}, {
       5.427925880920669, -0.30166219966003505`}}, {{
       5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}, {{
       5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}, {{
       5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}, {{
       5.369352590298147, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}, {
       5.369352590298147, -0.35595761700931716`}, {
       5.369352590298147, -0.35595761700931716`}}, {{
       5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}, {{
       5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}, {{
       5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}, {{
       5.293044734253329, -0.3795358659970291}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.189511061408361, -0.35595761700931716`}, {
       5.293044734253329, -0.3795358659970291}, {
       5.293044734253329, -0.3795358659970291}}, {{
       5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}, {{
       5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}, {{
       5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}, {{
       5.189511061408361, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}, {
       5.189511061408361, -0.04446295166134115}, {
       5.189511061408361, -0.04446295166134115}}, {{
       5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}, {{
       5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}, {{
       5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}, {{
       5.293044734253329, -0.02088470267362924}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}, {
       5.293044734253329, -0.02088470267362924}, {
       5.293044734253329, -0.02088470267362924}}, {{
       5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}, {{
       5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}, {{
       5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}, {{
       5.369352590298147, -0.04446295166134115}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}, {
       5.369352590298147, -0.04446295166134115}, {
       5.369352590298147, -0.04446295166134115}}, {{
       5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}, {{
       5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}, {{
       5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}, {{
       5.427925880920669, -0.09875836901062326}, {
       5.459273354743041, -0.2002102843353292}, {
       5.459273354743041, -0.2002102843353292}, {
       5.427925880920669, -0.09875836901062326}, {
       5.427925880920669, -0.09875836901062326}}, {{5.131303594638972, 
       0.1103341841679071}, {5.0673708809907, 0.17930408254287916`}, {
       5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.3172438792928233}, {5.131303594638972, 0.3862137776677954}, {
       5.131303594638972, 0.3862137776677954}, {5.0673708809907, 
       0.3172438792928233}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}}, {{
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}, {{5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.15842167757808617`}, {5.290582752210057, 
       0.1103341841679071}, {5.222999635552264, 0.08945177920311406}, {
       5.131303594638972, 0.11033418416790708`}, {5.131303594638972, 
       0.11033418416790708`}, {5.222999635552264, 0.08945177920311406}, {
       5.290582752210057, 0.1103341841679071}, {5.342459003730578, 
       0.15842167757808617`}, {5.370222330995599, 0.24827398091785122`}, {
       5.370222330995599, 0.24827398091785122`}}, {{5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}}, {{
       5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.290582752210057, 0.3862137776677954}, {
       5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785127`}, {5.370222330995599, 0.24827398091785127`}, {
       5.342459003730578, 0.3381262842576163}, {5.290582752210057, 
       0.3862137776677954}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}, {{5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}}, {{5.131303594638972, 
       0.1103341841679071}, {5.0673708809907, 0.17930408254287916`}, {
       5.0673708809907, 0.17930408254287916`}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}}, {{
       5.131303594638972, 0.1103341841679071}, {5.0673708809907, 
       0.17930408254287916`}, {5.0673708809907, 0.17930408254287916`}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}}, {{5.131303594638972, 0.1103341841679071}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}, {5.131303594638972, 0.1103341841679071}, {
       5.131303594638972, 0.1103341841679071}}, {{5.131303594638972, 
       0.1103341841679071}, {5.0673708809907, 0.17930408254287916`}, {
       5.0673708809907, 0.17930408254287916`}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}}, {{
       5.0673708809907, 0.17930408254287916`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}}, {{5.0673708809907, 0.17930408254287916`}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}, {5.0673708809907, 0.17930408254287916`}, {
       5.0673708809907, 0.17930408254287916`}}, {{5.0673708809907, 
       0.17930408254287916`}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.17930408254287916`}, {5.0673708809907, 0.17930408254287916`}}, {{
       5.0673708809907, 0.17930408254287916`}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.17930408254287916`}, {5.0673708809907, 
       0.17930408254287916`}}, {{5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}}, {{5.051664015853429, 
       0.24827398091785124`}, {5.0673708809907, 0.3172438792928233}, {
       5.0673708809907, 0.3172438792928233}, {5.051664015853429, 
       0.24827398091785124`}, {5.051664015853429, 0.24827398091785124`}}, {{
       5.051664015853429, 0.24827398091785124`}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}, {
       5.051664015853429, 0.24827398091785124`}, {5.051664015853429, 
       0.24827398091785124`}}, {{5.051664015853429, 0.24827398091785124`}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}, {5.051664015853429, 0.24827398091785124`}, {
       5.051664015853429, 0.24827398091785124`}}, {{5.0673708809907, 
       0.3172438792928233}, {5.131303594638972, 0.3862137776677954}, {
       5.131303594638972, 0.3862137776677954}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}}, {{
       5.0673708809907, 0.3172438792928233}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}, {
       5.0673708809907, 0.3172438792928233}, {5.0673708809907, 
       0.3172438792928233}}, {{5.0673708809907, 0.3172438792928233}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}, {5.0673708809907, 0.3172438792928233}, {
       5.0673708809907, 0.3172438792928233}}, {{5.0673708809907, 
       0.3172438792928233}, {5.131303594638972, 0.3862137776677954}, {
       5.131303594638972, 0.3862137776677954}, {5.0673708809907, 
       0.3172438792928233}, {5.0673708809907, 0.3172438792928233}}, {{
       5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}, {{5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.15842167757808617`}, {5.342459003730578, 
       0.15842167757808617`}, {5.370222330995599, 0.24827398091785122`}, {
       5.370222330995599, 0.24827398091785122`}}, {{5.370222330995599, 
       0.24827398091785122`}, {5.342459003730578, 0.15842167757808617`}, {
       5.342459003730578, 0.15842167757808617`}, {5.370222330995599, 
       0.24827398091785122`}, {5.370222330995599, 0.24827398091785122`}}, {{
       5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}}, {{5.342459003730578, 0.15842167757808617`}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.342459003730578, 0.15842167757808617`}, {
       5.342459003730578, 0.15842167757808617`}}, {{5.342459003730578, 
       0.15842167757808617`}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}, {5.342459003730578, 
       0.15842167757808617`}, {5.342459003730578, 0.15842167757808617`}}, {{
       5.342459003730578, 0.15842167757808617`}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}, {
       5.342459003730578, 0.15842167757808617`}, {5.342459003730578, 
       0.15842167757808617`}}, {{5.342459003730578, 0.15842167757808617`}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}, {5.342459003730578, 0.15842167757808617`}, {
       5.342459003730578, 0.15842167757808617`}}, {{5.290582752210057, 
       0.1103341841679071}, {5.222999635552264, 0.08945177920311406}, {
       5.222999635552264, 0.08945177920311406}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}}, {{
       5.290582752210057, 0.1103341841679071}, {5.222999635552264, 
       0.08945177920311406}, {5.222999635552264, 0.08945177920311406}, {
       5.290582752210057, 0.1103341841679071}, {5.290582752210057, 
       0.1103341841679071}}, {{5.290582752210057, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}, {5.290582752210057, 0.1103341841679071}, {
       5.290582752210057, 0.1103341841679071}}, {{5.290582752210057, 
       0.1103341841679071}, {5.222999635552264, 0.08945177920311406}, {
       5.222999635552264, 0.08945177920311406}, {5.290582752210057, 
       0.1103341841679071}, {5.290582752210057, 0.1103341841679071}}, {{
       5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}}, {{5.222999635552264, 0.08945177920311406}, {
       5.131303594638972, 0.1103341841679071}, {5.131303594638972, 
       0.1103341841679071}, {5.222999635552264, 0.08945177920311406}, {
       5.222999635552264, 0.08945177920311406}}, {{5.222999635552264, 
       0.08945177920311406}, {5.131303594638972, 0.1103341841679071}, {
       5.131303594638972, 0.1103341841679071}, {5.222999635552264, 
       0.08945177920311406}, {5.222999635552264, 0.08945177920311406}}, {{
       5.222999635552264, 0.08945177920311406}, {5.131303594638972, 
       0.1103341841679071}, {5.131303594638972, 0.1103341841679071}, {
       5.222999635552264, 0.08945177920311406}, {5.222999635552264, 
       0.08945177920311406}}, {{5.131303594638972, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}, {5.131303594638972, 0.3862137776677954}, {
       5.131303594638972, 0.3862137776677954}}, {{5.131303594638972, 
       0.3862137776677954}, {5.222999635552264, 0.4070961826325884}, {
       5.222999635552264, 0.4070961826325884}, {5.131303594638972, 
       0.3862137776677954}, {5.131303594638972, 0.3862137776677954}}, {{
       5.131303594638972, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}, {
       5.131303594638972, 0.3862137776677954}, {5.131303594638972, 
       0.3862137776677954}}, {{5.131303594638972, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}, {5.131303594638972, 0.3862137776677954}, {
       5.131303594638972, 0.3862137776677954}}, {{5.222999635552264, 
       0.4070961826325884}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}}, {{
       5.222999635552264, 0.4070961826325884}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}, {
       5.222999635552264, 0.4070961826325884}, {5.222999635552264, 
       0.4070961826325884}}, {{5.222999635552264, 0.4070961826325884}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}, {5.222999635552264, 0.4070961826325884}, {
       5.222999635552264, 0.4070961826325884}}, {{5.222999635552264, 
       0.4070961826325884}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}, {5.222999635552264, 
       0.4070961826325884}, {5.222999635552264, 0.4070961826325884}}, {{
       5.290582752210057, 0.3862137776677954}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}, {{5.290582752210057, 0.3862137776677954}, {
       5.342459003730578, 0.3381262842576163}, {5.342459003730578, 
       0.3381262842576163}, {5.290582752210057, 0.3862137776677954}, {
       5.290582752210057, 0.3862137776677954}}, {{5.290582752210057, 
       0.3862137776677954}, {5.342459003730578, 0.3381262842576163}, {
       5.342459003730578, 0.3381262842576163}, {5.290582752210057, 
       0.3862137776677954}, {5.290582752210057, 0.3862137776677954}}, {{
       5.290582752210057, 0.3862137776677954}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}, {
       5.290582752210057, 0.3862137776677954}, {5.290582752210057, 
       0.3862137776677954}}, {{5.342459003730578, 0.3381262842576163}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}, {5.342459003730578, 0.3381262842576163}, {
       5.342459003730578, 0.3381262842576163}}, {{5.342459003730578, 
       0.3381262842576163}, {5.370222330995599, 0.24827398091785122`}, {
       5.370222330995599, 0.24827398091785122`}, {5.342459003730578, 
       0.3381262842576163}, {5.342459003730578, 0.3381262842576163}}, {{
       5.342459003730578, 0.3381262842576163}, {5.370222330995599, 
       0.24827398091785122`}, {5.370222330995599, 0.24827398091785122`}, {
       5.342459003730578, 0.3381262842576163}, {5.342459003730578, 
       0.3381262842576163}}, {{5.342459003730578, 0.3381262842576163}, {
       5.370222330995599, 0.24827398091785122`}, {5.370222330995599, 
       0.24827398091785122`}, {5.342459003730578, 0.3381262842576163}, {
       5.342459003730578, 0.3381262842576163}}, {{5.165093633765845, 
       0.6255875834022371}, {5.104168175084318, 0.6913132886621612}, {
       5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.8227646991820096}, {5.165093633765845, 0.8884904044419337}, {
       5.165093633765845, 0.8884904044419337}, {5.104168175084318, 
       0.8227646991820096}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}}, {{
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}, {{5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.6714131463367026}, {5.316880648263825, 
       0.6255875834022371}, {5.252476493543351, 0.6056874410767784}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}, {5.252476493543351, 0.6056874410767784}, {
       5.316880648263825, 0.6255875834022371}, {5.366316754416836, 
       0.6714131463367026}, {5.392774155512816, 0.7570389939220854}, {
       5.392774155512816, 0.7570389939220854}}, {{5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}}, {{
       5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.316880648263825, 0.8884904044419337}, {
       5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.316880648263825, 
       0.8884904044419337}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}, {{5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}}, {{5.165093633765845, 
       0.6255875834022371}, {5.104168175084318, 0.6913132886621612}, {
       5.104168175084318, 0.6913132886621612}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}}, {{
       5.165093633765845, 0.6255875834022371}, {5.104168175084318, 
       0.6913132886621612}, {5.104168175084318, 0.6913132886621612}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}}, {{5.165093633765845, 0.6255875834022371}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}, {5.165093633765845, 0.6255875834022371}, {
       5.165093633765845, 0.6255875834022371}}, {{5.165093633765845, 
       0.6255875834022371}, {5.104168175084318, 0.6913132886621612}, {
       5.104168175084318, 0.6913132886621612}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}}, {{
       5.104168175084318, 0.6913132886621612}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}}, {{5.104168175084318, 0.6913132886621612}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}, {5.104168175084318, 0.6913132886621612}, {
       5.104168175084318, 0.6913132886621612}}, {{5.104168175084318, 
       0.6913132886621612}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.6913132886621612}, {5.104168175084318, 0.6913132886621612}}, {{
       5.104168175084318, 0.6913132886621612}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.6913132886621612}, {5.104168175084318, 
       0.6913132886621612}}, {{5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}}, {{5.089200126516854, 
       0.7570389939220854}, {5.104168175084318, 0.8227646991820096}, {
       5.104168175084318, 0.8227646991820096}, {5.089200126516854, 
       0.7570389939220854}, {5.089200126516854, 0.7570389939220854}}, {{
       5.089200126516854, 0.7570389939220854}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}, {
       5.089200126516854, 0.7570389939220854}, {5.089200126516854, 
       0.7570389939220854}}, {{5.089200126516854, 0.7570389939220854}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}, {5.089200126516854, 0.7570389939220854}, {
       5.089200126516854, 0.7570389939220854}}, {{5.104168175084318, 
       0.8227646991820096}, {5.165093633765845, 0.8884904044419337}, {
       5.165093633765845, 0.8884904044419337}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}}, {{
       5.104168175084318, 0.8227646991820096}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}, {
       5.104168175084318, 0.8227646991820096}, {5.104168175084318, 
       0.8227646991820096}}, {{5.104168175084318, 0.8227646991820096}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}, {5.104168175084318, 0.8227646991820096}, {
       5.104168175084318, 0.8227646991820096}}, {{5.104168175084318, 
       0.8227646991820096}, {5.165093633765845, 0.8884904044419337}, {
       5.165093633765845, 0.8884904044419337}, {5.104168175084318, 
       0.8227646991820096}, {5.104168175084318, 0.8227646991820096}}, {{
       5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}, {{5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.6714131463367026}, {5.366316754416836, 
       0.6714131463367026}, {5.392774155512816, 0.7570389939220854}, {
       5.392774155512816, 0.7570389939220854}}, {{5.392774155512816, 
       0.7570389939220854}, {5.366316754416836, 0.6714131463367026}, {
       5.366316754416836, 0.6714131463367026}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}}, {{
       5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}}, {{5.366316754416836, 0.6714131463367026}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.366316754416836, 0.6714131463367026}, {
       5.366316754416836, 0.6714131463367026}}, {{5.366316754416836, 
       0.6714131463367026}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}, {5.366316754416836, 
       0.6714131463367026}, {5.366316754416836, 0.6714131463367026}}, {{
       5.366316754416836, 0.6714131463367026}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}, {
       5.366316754416836, 0.6714131463367026}, {5.366316754416836, 
       0.6714131463367026}}, {{5.366316754416836, 0.6714131463367026}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}, {5.366316754416836, 0.6714131463367026}, {
       5.366316754416836, 0.6714131463367026}}, {{5.316880648263825, 
       0.6255875834022371}, {5.252476493543351, 0.6056874410767784}, {
       5.252476493543351, 0.6056874410767784}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}}, {{
       5.316880648263825, 0.6255875834022371}, {5.252476493543351, 
       0.6056874410767784}, {5.252476493543351, 0.6056874410767784}, {
       5.316880648263825, 0.6255875834022371}, {5.316880648263825, 
       0.6255875834022371}}, {{5.316880648263825, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}, {5.316880648263825, 0.6255875834022371}, {
       5.316880648263825, 0.6255875834022371}}, {{5.316880648263825, 
       0.6255875834022371}, {5.252476493543351, 0.6056874410767784}, {
       5.252476493543351, 0.6056874410767784}, {5.316880648263825, 
       0.6255875834022371}, {5.316880648263825, 0.6255875834022371}}, {{
       5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}}, {{5.252476493543351, 0.6056874410767784}, {
       5.165093633765845, 0.6255875834022371}, {5.165093633765845, 
       0.6255875834022371}, {5.252476493543351, 0.6056874410767784}, {
       5.252476493543351, 0.6056874410767784}}, {{5.252476493543351, 
       0.6056874410767784}, {5.165093633765845, 0.6255875834022371}, {
       5.165093633765845, 0.6255875834022371}, {5.252476493543351, 
       0.6056874410767784}, {5.252476493543351, 0.6056874410767784}}, {{
       5.252476493543351, 0.6056874410767784}, {5.165093633765845, 
       0.6255875834022371}, {5.165093633765845, 0.6255875834022371}, {
       5.252476493543351, 0.6056874410767784}, {5.252476493543351, 
       0.6056874410767784}}, {{5.165093633765845, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}, {5.165093633765845, 0.8884904044419337}, {
       5.165093633765845, 0.8884904044419337}}, {{5.165093633765845, 
       0.8884904044419337}, {5.252476493543351, 0.9083905467673924}, {
       5.252476493543351, 0.9083905467673924}, {5.165093633765845, 
       0.8884904044419337}, {5.165093633765845, 0.8884904044419337}}, {{
       5.165093633765845, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}, {
       5.165093633765845, 0.8884904044419337}, {5.165093633765845, 
       0.8884904044419337}}, {{5.165093633765845, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}, {5.165093633765845, 0.8884904044419337}, {
       5.165093633765845, 0.8884904044419337}}, {{5.252476493543351, 
       0.9083905467673924}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}}, {{
       5.252476493543351, 0.9083905467673924}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}, {
       5.252476493543351, 0.9083905467673924}, {5.252476493543351, 
       0.9083905467673924}}, {{5.252476493543351, 0.9083905467673924}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}, {5.252476493543351, 0.9083905467673924}, {
       5.252476493543351, 0.9083905467673924}}, {{5.252476493543351, 
       0.9083905467673924}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}, {5.252476493543351, 
       0.9083905467673924}, {5.252476493543351, 0.9083905467673924}}, {{
       5.316880648263825, 0.8884904044419337}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}, {{5.316880648263825, 0.8884904044419337}, {
       5.366316754416836, 0.8426648415074682}, {5.366316754416836, 
       0.8426648415074682}, {5.316880648263825, 0.8884904044419337}, {
       5.316880648263825, 0.8884904044419337}}, {{5.316880648263825, 
       0.8884904044419337}, {5.366316754416836, 0.8426648415074682}, {
       5.366316754416836, 0.8426648415074682}, {5.316880648263825, 
       0.8884904044419337}, {5.316880648263825, 0.8884904044419337}}, {{
       5.316880648263825, 0.8884904044419337}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}, {
       5.316880648263825, 0.8884904044419337}, {5.316880648263825, 
       0.8884904044419337}}, {{5.366316754416836, 0.8426648415074682}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}, {5.366316754416836, 0.8426648415074682}, {
       5.366316754416836, 0.8426648415074682}}, {{5.366316754416836, 
       0.8426648415074682}, {5.392774155512816, 0.7570389939220854}, {
       5.392774155512816, 0.7570389939220854}, {5.366316754416836, 
       0.8426648415074682}, {5.366316754416836, 0.8426648415074682}}, {{
       5.366316754416836, 0.8426648415074682}, {5.392774155512816, 
       0.7570389939220854}, {5.392774155512816, 0.7570389939220854}, {
       5.366316754416836, 0.8426648415074682}, {5.366316754416836, 
       0.8426648415074682}}, {{5.366316754416836, 0.8426648415074682}, {
       5.392774155512816, 0.7570389939220854}, {5.392774155512816, 
       0.7570389939220854}, {5.366316754416836, 0.8426648415074682}, {
       5.366316754416836, 0.8426648415074682}}, {{5.150580321776822, 
       1.0978272395775193`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.150580321776822, 1.3857846601631891`}, {
       5.150580321776822, 1.3857846601631891`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}}, {{
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}, {{5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.1480199718095652`}, {5.316832616067108, 
       1.0978272395775193`}, {5.246290755029002, 1.0760306166631477`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}, {5.246290755029002, 1.0760306166631477`}, {
       5.316832616067108, 1.0978272395775193`}, {5.370979975746717, 
       1.1480199718095652`}, {5.399958763212251, 1.2418059498703542`}, {
       5.399958763212251, 1.2418059498703542`}}, {{5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}}, {{
       5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.316832616067108, 1.3857846601631891`}, {
       5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.316832616067108, 
       1.3857846601631891`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}, {{5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}}, {{5.150580321776822, 
       1.0978272395775193`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}}, {{
       5.150580321776822, 1.0978272395775193`}, {5.0838486759901755`, 
       1.1698165947239367`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}}, {{5.150580321776822, 1.0978272395775193`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}, {5.150580321776822, 1.0978272395775193`}, {
       5.150580321776822, 1.0978272395775193`}}, {{5.150580321776822, 
       1.0978272395775193`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}}, {{
       5.0838486759901755`, 1.1698165947239367`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}}, {{5.0838486759901755`, 1.1698165947239367`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}, {5.0838486759901755`, 1.1698165947239367`}, {
       5.0838486759901755`, 1.1698165947239367`}}, {{5.0838486759901755`, 
       1.1698165947239367`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`, 
       1.1698165947239367`}, {5.0838486759901755`, 1.1698165947239367`}}, {{
       5.0838486759901755`, 1.1698165947239367`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.1698165947239367`}, {5.0838486759901755`, 
       1.1698165947239367`}}, {{5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}}, {{5.067454174631679, 
       1.2418059498703542`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.067454174631679, 
       1.2418059498703542`}, {5.067454174631679, 1.2418059498703542`}}, {{
       5.067454174631679, 1.2418059498703542`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.067454174631679, 1.2418059498703542`}, {5.067454174631679, 
       1.2418059498703542`}}, {{5.067454174631679, 1.2418059498703542`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.067454174631679, 1.2418059498703542`}, {
       5.067454174631679, 1.2418059498703542`}}, {{5.0838486759901755`, 
       1.3137953050167717`}, {5.150580321776822, 1.3857846601631891`}, {
       5.150580321776822, 1.3857846601631891`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}}, {{
       5.0838486759901755`, 1.3137953050167717`}, {5.150580321776822, 
       1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}, {
       5.0838486759901755`, 1.3137953050167717`}, {5.0838486759901755`, 
       1.3137953050167717`}}, {{5.0838486759901755`, 1.3137953050167717`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}, {5.0838486759901755`, 1.3137953050167717`}, {
       5.0838486759901755`, 1.3137953050167717`}}, {{5.0838486759901755`, 
       1.3137953050167717`}, {5.150580321776822, 1.3857846601631891`}, {
       5.150580321776822, 1.3857846601631891`}, {5.0838486759901755`, 
       1.3137953050167717`}, {5.0838486759901755`, 1.3137953050167717`}}, {{
       5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}, {{5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.1480199718095652`}, {5.370979975746717, 
       1.1480199718095652`}, {5.399958763212251, 1.2418059498703542`}, {
       5.399958763212251, 1.2418059498703542`}}, {{5.399958763212251, 
       1.2418059498703542`}, {5.370979975746717, 1.1480199718095652`}, {
       5.370979975746717, 1.1480199718095652`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}}, {{
       5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}}, {{5.370979975746717, 1.1480199718095652`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.370979975746717, 1.1480199718095652`}, {
       5.370979975746717, 1.1480199718095652`}}, {{5.370979975746717, 
       1.1480199718095652`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}, {5.370979975746717, 
       1.1480199718095652`}, {5.370979975746717, 1.1480199718095652`}}, {{
       5.370979975746717, 1.1480199718095652`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}, {
       5.370979975746717, 1.1480199718095652`}, {5.370979975746717, 
       1.1480199718095652`}}, {{5.370979975746717, 1.1480199718095652`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}, {5.370979975746717, 1.1480199718095652`}, {
       5.370979975746717, 1.1480199718095652`}}, {{5.316832616067108, 
       1.0978272395775193`}, {5.246290755029002, 1.0760306166631477`}, {
       5.246290755029002, 1.0760306166631477`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}}, {{
       5.316832616067108, 1.0978272395775193`}, {5.246290755029002, 
       1.0760306166631477`}, {5.246290755029002, 1.0760306166631477`}, {
       5.316832616067108, 1.0978272395775193`}, {5.316832616067108, 
       1.0978272395775193`}}, {{5.316832616067108, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}, {5.316832616067108, 1.0978272395775193`}, {
       5.316832616067108, 1.0978272395775193`}}, {{5.316832616067108, 
       1.0978272395775193`}, {5.246290755029002, 1.0760306166631477`}, {
       5.246290755029002, 1.0760306166631477`}, {5.316832616067108, 
       1.0978272395775193`}, {5.316832616067108, 1.0978272395775193`}}, {{
       5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}}, {{5.246290755029002, 1.0760306166631477`}, {
       5.150580321776822, 1.0978272395775193`}, {5.150580321776822, 
       1.0978272395775193`}, {5.246290755029002, 1.0760306166631477`}, {
       5.246290755029002, 1.0760306166631477`}}, {{5.246290755029002, 
       1.0760306166631477`}, {5.150580321776822, 1.0978272395775193`}, {
       5.150580321776822, 1.0978272395775193`}, {5.246290755029002, 
       1.0760306166631477`}, {5.246290755029002, 1.0760306166631477`}}, {{
       5.246290755029002, 1.0760306166631477`}, {5.150580321776822, 
       1.0978272395775193`}, {5.150580321776822, 1.0978272395775193`}, {
       5.246290755029002, 1.0760306166631477`}, {5.246290755029002, 
       1.0760306166631477`}}, {{5.150580321776822, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}, {5.150580321776822, 1.3857846601631891`}, {
       5.150580321776822, 1.3857846601631891`}}, {{5.150580321776822, 
       1.3857846601631891`}, {5.246290755029002, 1.4075812830775607`}, {
       5.246290755029002, 1.4075812830775607`}, {5.150580321776822, 
       1.3857846601631891`}, {5.150580321776822, 1.3857846601631891`}}, {{
       5.150580321776822, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}, {
       5.150580321776822, 1.3857846601631891`}, {5.150580321776822, 
       1.3857846601631891`}}, {{5.150580321776822, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}, {5.150580321776822, 1.3857846601631891`}, {
       5.150580321776822, 1.3857846601631891`}}, {{5.246290755029002, 
       1.4075812830775607`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}}, {{
       5.246290755029002, 1.4075812830775607`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}, {
       5.246290755029002, 1.4075812830775607`}, {5.246290755029002, 
       1.4075812830775607`}}, {{5.246290755029002, 1.4075812830775607`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}, {5.246290755029002, 1.4075812830775607`}, {
       5.246290755029002, 1.4075812830775607`}}, {{5.246290755029002, 
       1.4075812830775607`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}, {5.246290755029002, 
       1.4075812830775607`}, {5.246290755029002, 1.4075812830775607`}}, {{
       5.316832616067108, 1.3857846601631891`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}, {{5.316832616067108, 1.3857846601631891`}, {
       5.370979975746717, 1.3355919279311432`}, {5.370979975746717, 
       1.3355919279311432`}, {5.316832616067108, 1.3857846601631891`}, {
       5.316832616067108, 1.3857846601631891`}}, {{5.316832616067108, 
       1.3857846601631891`}, {5.370979975746717, 1.3355919279311432`}, {
       5.370979975746717, 1.3355919279311432`}, {5.316832616067108, 
       1.3857846601631891`}, {5.316832616067108, 1.3857846601631891`}}, {{
       5.316832616067108, 1.3857846601631891`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}, {
       5.316832616067108, 1.3857846601631891`}, {5.316832616067108, 
       1.3857846601631891`}}, {{5.370979975746717, 1.3355919279311432`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}, {5.370979975746717, 1.3355919279311432`}, {
       5.370979975746717, 1.3355919279311432`}}, {{5.370979975746717, 
       1.3355919279311432`}, {5.399958763212251, 1.2418059498703542`}, {
       5.399958763212251, 1.2418059498703542`}, {5.370979975746717, 
       1.3355919279311432`}, {5.370979975746717, 1.3355919279311432`}}, {{
       5.370979975746717, 1.3355919279311432`}, {5.399958763212251, 
       1.2418059498703542`}, {5.399958763212251, 1.2418059498703542`}, {
       5.370979975746717, 1.3355919279311432`}, {5.370979975746717, 
       1.3355919279311432`}}, {{5.370979975746717, 1.3355919279311432`}, {
       5.399958763212251, 1.2418059498703542`}, {5.399958763212251, 
       1.2418059498703542`}, {5.370979975746717, 1.3355919279311432`}, {
       5.370979975746717, 1.3355919279311432`}}, {{5.139179486262469, 
       1.655364010422419}, {5.087117224416264, 1.7115281977969534`}, {
       5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.8238565725460218`}, {5.139179486262469, 1.8800207599205563`}, {
       5.139179486262469, 1.8800207599205563`}, {5.087117224416264, 
       1.8238565725460218`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.139179486262469, 
       1.655364010422419}, {5.139179486262469, 1.655364010422419}}, {{
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}, {{5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.6945230501469295`}, {5.268885121060485, 
       1.655364010422419}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.268885121060485, 1.655364010422419}, {5.311129456333339, 
       1.6945230501469295`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.3337379384594925`, 1.7676923851714876`}}, {{5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}}, {{
       5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`, 
       1.89702590757058}, {5.268885121060485, 1.8800207599205563`}, {
       5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`, 
       1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.268885121060485, 
       1.8800207599205563`}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}, {{5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}}, {{5.139179486262469, 
       1.655364010422419}, {5.087117224416264, 1.7115281977969534`}, {
       5.087117224416264, 1.7115281977969534`}, {5.139179486262469, 
       1.655364010422419}, {5.139179486262469, 1.655364010422419}}, {{
       5.139179486262469, 1.655364010422419}, {5.087117224416264, 
       1.7115281977969534`}, {5.087117224416264, 1.7115281977969534`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}}, {{5.139179486262469, 1.655364010422419}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}, {5.139179486262469, 1.655364010422419}, {
       5.139179486262469, 1.655364010422419}}, {{5.139179486262469, 
       1.655364010422419}, {5.087117224416264, 1.7115281977969534`}, {
       5.087117224416264, 1.7115281977969534`}, {5.139179486262469, 
       1.655364010422419}, {5.139179486262469, 1.655364010422419}}, {{
       5.087117224416264, 1.7115281977969534`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}}, {{5.087117224416264, 1.7115281977969534`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}, {5.087117224416264, 1.7115281977969534`}, {
       5.087117224416264, 1.7115281977969534`}}, {{5.087117224416264, 
       1.7115281977969534`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.7115281977969534`}, {5.087117224416264, 1.7115281977969534`}}, {{
       5.087117224416264, 1.7115281977969534`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.7115281977969534`}, {5.087117224416264, 
       1.7115281977969534`}}, {{5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}}, {{5.074326668863462, 
       1.7676923851714876`}, {5.087117224416264, 1.8238565725460218`}, {
       5.087117224416264, 1.8238565725460218`}, {5.074326668863462, 
       1.7676923851714876`}, {5.074326668863462, 1.7676923851714876`}}, {{
       5.074326668863462, 1.7676923851714876`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}, {
       5.074326668863462, 1.7676923851714876`}, {5.074326668863462, 
       1.7676923851714876`}}, {{5.074326668863462, 1.7676923851714876`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}, {5.074326668863462, 1.7676923851714876`}, {
       5.074326668863462, 1.7676923851714876`}}, {{5.087117224416264, 
       1.8238565725460218`}, {5.139179486262469, 1.8800207599205563`}, {
       5.139179486262469, 1.8800207599205563`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}}, {{
       5.087117224416264, 1.8238565725460218`}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}, {
       5.087117224416264, 1.8238565725460218`}, {5.087117224416264, 
       1.8238565725460218`}}, {{5.087117224416264, 1.8238565725460218`}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}, {5.087117224416264, 1.8238565725460218`}, {
       5.087117224416264, 1.8238565725460218`}}, {{5.087117224416264, 
       1.8238565725460218`}, {5.139179486262469, 1.8800207599205563`}, {
       5.139179486262469, 1.8800207599205563`}, {5.087117224416264, 
       1.8238565725460218`}, {5.087117224416264, 1.8238565725460218`}}, {{
       5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339, 
       1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}, {{5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.6945230501469295`}, {5.311129456333339, 
       1.6945230501469295`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.3337379384594925`, 1.7676923851714876`}}, {{5.3337379384594925`, 
       1.7676923851714876`}, {5.311129456333339, 1.6945230501469295`}, {
       5.311129456333339, 1.6945230501469295`}, {5.3337379384594925`, 
       1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}}, {{
       5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339, 
       1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}}, {{5.311129456333339, 1.6945230501469295`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.311129456333339, 1.6945230501469295`}, {
       5.311129456333339, 1.6945230501469295`}}, {{5.311129456333339, 
       1.6945230501469295`}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}, {5.311129456333339, 
       1.6945230501469295`}, {5.311129456333339, 1.6945230501469295`}}, {{
       5.311129456333339, 1.6945230501469295`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}, {
       5.311129456333339, 1.6945230501469295`}, {5.311129456333339, 
       1.6945230501469295`}}, {{5.311129456333339, 1.6945230501469295`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}, {5.311129456333339, 1.6945230501469295`}, {
       5.311129456333339, 1.6945230501469295`}}, {{5.268885121060485, 
       1.655364010422419}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}}, {{
       5.268885121060485, 1.655364010422419}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.268885121060485, 1.655364010422419}, {5.268885121060485, 
       1.655364010422419}}, {{5.268885121060485, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.268885121060485, 1.655364010422419}, {
       5.268885121060485, 1.655364010422419}}, {{5.268885121060485, 
       1.655364010422419}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.268885121060485, 
       1.655364010422419}, {5.268885121060485, 1.655364010422419}}, {{
       5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469, 
       1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}}, {{5.2138502302348275`, 1.6383588627723953`}, {
       5.139179486262469, 1.655364010422419}, {5.139179486262469, 
       1.655364010422419}, {5.2138502302348275`, 1.6383588627723953`}, {
       5.2138502302348275`, 1.6383588627723953`}}, {{5.2138502302348275`, 
       1.6383588627723953`}, {5.139179486262469, 1.655364010422419}, {
       5.139179486262469, 1.655364010422419}, {5.2138502302348275`, 
       1.6383588627723953`}, {5.2138502302348275`, 1.6383588627723953`}}, {{
       5.2138502302348275`, 1.6383588627723953`}, {5.139179486262469, 
       1.655364010422419}, {5.139179486262469, 1.655364010422419}, {
       5.2138502302348275`, 1.6383588627723953`}, {5.2138502302348275`, 
       1.6383588627723953`}}, {{5.139179486262469, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}, {5.139179486262469, 1.8800207599205563`}, {
       5.139179486262469, 1.8800207599205563`}}, {{5.139179486262469, 
       1.8800207599205563`}, {5.2138502302348275`, 1.89702590757058}, {
       5.2138502302348275`, 1.89702590757058}, {5.139179486262469, 
       1.8800207599205563`}, {5.139179486262469, 1.8800207599205563`}}, {{
       5.139179486262469, 1.8800207599205563`}, {5.2138502302348275`, 
       1.89702590757058}, {5.2138502302348275`, 1.89702590757058}, {
       5.139179486262469, 1.8800207599205563`}, {5.139179486262469, 
       1.8800207599205563`}}, {{5.139179486262469, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}, {5.139179486262469, 1.8800207599205563`}, {
       5.139179486262469, 1.8800207599205563`}}, {{5.2138502302348275`, 
       1.89702590757058}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.2138502302348275`, 
       1.89702590757058}, {5.2138502302348275`, 1.89702590757058}}, {{
       5.2138502302348275`, 1.89702590757058}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}, {
       5.2138502302348275`, 1.89702590757058}, {5.2138502302348275`, 
       1.89702590757058}}, {{5.2138502302348275`, 1.89702590757058}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}, {5.2138502302348275`, 1.89702590757058}, {
       5.2138502302348275`, 1.89702590757058}}, {{5.2138502302348275`, 
       1.89702590757058}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}, {5.2138502302348275`, 
       1.89702590757058}, {5.2138502302348275`, 1.89702590757058}}, {{
       5.268885121060485, 1.8800207599205563`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}, {{5.268885121060485, 1.8800207599205563`}, {
       5.311129456333339, 1.8408617201960458`}, {5.311129456333339, 
       1.8408617201960458`}, {5.268885121060485, 1.8800207599205563`}, {
       5.268885121060485, 1.8800207599205563`}}, {{5.268885121060485, 
       1.8800207599205563`}, {5.311129456333339, 1.8408617201960458`}, {
       5.311129456333339, 1.8408617201960458`}, {5.268885121060485, 
       1.8800207599205563`}, {5.268885121060485, 1.8800207599205563`}}, {{
       5.268885121060485, 1.8800207599205563`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}, {
       5.268885121060485, 1.8800207599205563`}, {5.268885121060485, 
       1.8800207599205563`}}, {{5.311129456333339, 1.8408617201960458`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}, {5.311129456333339, 1.8408617201960458`}, {
       5.311129456333339, 1.8408617201960458`}}, {{5.311129456333339, 
       1.8408617201960458`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.311129456333339, 
       1.8408617201960458`}, {5.311129456333339, 1.8408617201960458`}}, {{
       5.311129456333339, 1.8408617201960458`}, {5.3337379384594925`, 
       1.7676923851714876`}, {5.3337379384594925`, 1.7676923851714876`}, {
       5.311129456333339, 1.8408617201960458`}, {5.311129456333339, 
       1.8408617201960458`}}, {{5.311129456333339, 1.8408617201960458`}, {
       5.3337379384594925`, 1.7676923851714876`}, {5.3337379384594925`, 
       1.7676923851714876`}, {5.311129456333339, 1.8408617201960458`}, {
       5.311129456333339, 1.8408617201960458`}}, {{5.157996230359432, 
       2.0842942662045143`}, {5.090443811161005, 2.157169062552612}, {
       5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.3029186552488077`}, {5.157996230359432, 2.3757934515969055`}, {
       5.157996230359432, 2.3757934515969055`}, {5.090443811161005, 
       2.3029186552488077`}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}}, {{
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}, {{5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.326293363514285, 
       2.0842942662045143`}, {5.254883864891715, 2.0622295532656296`}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}, {5.254883864891715, 2.0622295532656296`}, {
       5.326293363514285, 2.0842942662045143`}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.410441930091713, 2.23004385890071}, {
       5.410441930091713, 2.23004385890071}}, {{5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}}, {{
       5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.326293363514285, 2.3757934515969055`}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713, 
       2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.326293363514285, 
       2.3757934515969055`}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}, {{5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}}, {{5.157996230359432, 
       2.0842942662045143`}, {5.090443811161005, 2.157169062552612}, {
       5.090443811161005, 2.157169062552612}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}}, {{
       5.157996230359432, 2.0842942662045143`}, {5.090443811161005, 
       2.157169062552612}, {5.090443811161005, 2.157169062552612}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}}, {{5.157996230359432, 2.0842942662045143`}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}, {5.157996230359432, 2.0842942662045143`}, {
       5.157996230359432, 2.0842942662045143`}}, {{5.157996230359432, 
       2.0842942662045143`}, {5.090443811161005, 2.157169062552612}, {
       5.090443811161005, 2.157169062552612}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}}, {{
       5.090443811161005, 2.157169062552612}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}}, {{5.090443811161005, 2.157169062552612}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}, {5.090443811161005, 2.157169062552612}, {
       5.090443811161005, 2.157169062552612}}, {{5.090443811161005, 
       2.157169062552612}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.157169062552612}, {5.090443811161005, 2.157169062552612}}, {{
       5.090443811161005, 2.157169062552612}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.157169062552612}, {5.090443811161005, 
       2.157169062552612}}, {{5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}}, {{5.073847663782004, 
       2.23004385890071}, {5.090443811161005, 2.3029186552488077`}, {
       5.090443811161005, 2.3029186552488077`}, {5.073847663782004, 
       2.23004385890071}, {5.073847663782004, 2.23004385890071}}, {{
       5.073847663782004, 2.23004385890071}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}, {
       5.073847663782004, 2.23004385890071}, {5.073847663782004, 
       2.23004385890071}}, {{5.073847663782004, 2.23004385890071}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}, {5.073847663782004, 2.23004385890071}, {
       5.073847663782004, 2.23004385890071}}, {{5.090443811161005, 
       2.3029186552488077`}, {5.157996230359432, 2.3757934515969055`}, {
       5.157996230359432, 2.3757934515969055`}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}}, {{
       5.090443811161005, 2.3029186552488077`}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}, {
       5.090443811161005, 2.3029186552488077`}, {5.090443811161005, 
       2.3029186552488077`}}, {{5.090443811161005, 2.3029186552488077`}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}, {5.090443811161005, 2.3029186552488077`}, {
       5.090443811161005, 2.3029186552488077`}}, {{5.090443811161005, 
       2.3029186552488077`}, {5.157996230359432, 2.3757934515969055`}, {
       5.157996230359432, 2.3757934515969055`}, {5.090443811161005, 
       2.3029186552488077`}, {5.090443811161005, 2.3029186552488077`}}, {{
       5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}, {{5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.410441930091713, 2.23004385890071}, {
       5.410441930091713, 2.23004385890071}}, {{5.410441930091713, 
       2.23004385890071}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.410441930091713, 
       2.23004385890071}, {5.410441930091713, 2.23004385890071}}, {{
       5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}}, {{5.3811067147578555`, 2.1351043496137274`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.3811067147578555`, 2.1351043496137274`}}, {{5.3811067147578555`, 
       2.1351043496137274`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}, {5.3811067147578555`, 
       2.1351043496137274`}, {5.3811067147578555`, 2.1351043496137274`}}, {{
       5.3811067147578555`, 2.1351043496137274`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}, {
       5.3811067147578555`, 2.1351043496137274`}, {5.3811067147578555`, 
       2.1351043496137274`}}, {{5.3811067147578555`, 2.1351043496137274`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}, {5.3811067147578555`, 2.1351043496137274`}, {
       5.3811067147578555`, 2.1351043496137274`}}, {{5.326293363514285, 
       2.0842942662045143`}, {5.254883864891715, 2.0622295532656296`}, {
       5.254883864891715, 2.0622295532656296`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}}, {{
       5.326293363514285, 2.0842942662045143`}, {5.254883864891715, 
       2.0622295532656296`}, {5.254883864891715, 2.0622295532656296`}, {
       5.326293363514285, 2.0842942662045143`}, {5.326293363514285, 
       2.0842942662045143`}}, {{5.326293363514285, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}, {5.326293363514285, 2.0842942662045143`}, {
       5.326293363514285, 2.0842942662045143`}}, {{5.326293363514285, 
       2.0842942662045143`}, {5.254883864891715, 2.0622295532656296`}, {
       5.254883864891715, 2.0622295532656296`}, {5.326293363514285, 
       2.0842942662045143`}, {5.326293363514285, 2.0842942662045143`}}, {{
       5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}}, {{5.254883864891715, 2.0622295532656296`}, {
       5.157996230359432, 2.0842942662045143`}, {5.157996230359432, 
       2.0842942662045143`}, {5.254883864891715, 2.0622295532656296`}, {
       5.254883864891715, 2.0622295532656296`}}, {{5.254883864891715, 
       2.0622295532656296`}, {5.157996230359432, 2.0842942662045143`}, {
       5.157996230359432, 2.0842942662045143`}, {5.254883864891715, 
       2.0622295532656296`}, {5.254883864891715, 2.0622295532656296`}}, {{
       5.254883864891715, 2.0622295532656296`}, {5.157996230359432, 
       2.0842942662045143`}, {5.157996230359432, 2.0842942662045143`}, {
       5.254883864891715, 2.0622295532656296`}, {5.254883864891715, 
       2.0622295532656296`}}, {{5.157996230359432, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}, {5.157996230359432, 2.3757934515969055`}, {
       5.157996230359432, 2.3757934515969055`}}, {{5.157996230359432, 
       2.3757934515969055`}, {5.254883864891715, 2.39785816453579}, {
       5.254883864891715, 2.39785816453579}, {5.157996230359432, 
       2.3757934515969055`}, {5.157996230359432, 2.3757934515969055`}}, {{
       5.157996230359432, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}, {
       5.157996230359432, 2.3757934515969055`}, {5.157996230359432, 
       2.3757934515969055`}}, {{5.157996230359432, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}, {5.157996230359432, 2.3757934515969055`}, {
       5.157996230359432, 2.3757934515969055`}}, {{5.254883864891715, 
       2.39785816453579}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}}, {{
       5.254883864891715, 2.39785816453579}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}, {
       5.254883864891715, 2.39785816453579}, {5.254883864891715, 
       2.39785816453579}}, {{5.254883864891715, 2.39785816453579}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}, {5.254883864891715, 2.39785816453579}, {
       5.254883864891715, 2.39785816453579}}, {{5.254883864891715, 
       2.39785816453579}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}, {5.254883864891715, 
       2.39785816453579}, {5.254883864891715, 2.39785816453579}}, {{
       5.326293363514285, 2.3757934515969055`}, {5.3811067147578555`, 
       2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}, {{5.326293363514285, 2.3757934515969055`}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.3811067147578555`, 
       2.3249833681876924`}, {5.326293363514285, 2.3757934515969055`}, {
       5.326293363514285, 2.3757934515969055`}}, {{5.326293363514285, 
       2.3757934515969055`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.326293363514285, 
       2.3757934515969055`}, {5.326293363514285, 2.3757934515969055`}}, {{
       5.326293363514285, 2.3757934515969055`}, {5.3811067147578555`, 
       2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.326293363514285, 2.3757934515969055`}, {5.326293363514285, 
       2.3757934515969055`}}, {{5.3811067147578555`, 2.3249833681876924`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.3811067147578555`, 2.3249833681876924`}}, {{5.3811067147578555`, 
       2.3249833681876924`}, {5.410441930091713, 2.23004385890071}, {
       5.410441930091713, 2.23004385890071}, {5.3811067147578555`, 
       2.3249833681876924`}, {5.3811067147578555`, 2.3249833681876924`}}, {{
       5.3811067147578555`, 2.3249833681876924`}, {5.410441930091713, 
       2.23004385890071}, {5.410441930091713, 2.23004385890071}, {
       5.3811067147578555`, 2.3249833681876924`}, {5.3811067147578555`, 
       2.3249833681876924`}}, {{5.3811067147578555`, 2.3249833681876924`}, {
       5.410441930091713, 2.23004385890071}, {5.410441930091713, 
       2.23004385890071}, {5.3811067147578555`, 2.3249833681876924`}, {
       5.3811067147578555`, 2.3249833681876924`}}, {{5.182662311074757, 
       2.6072354269601368`}, {5.127221575152003, 2.6670442744847778`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003, 
       2.786661969534059}, {5.182662311074757, 2.8464708170587}, {
       5.182662311074757, 2.8464708170587}, {5.127221575152003, 
       2.786661969534059}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}}, {{
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}}, {{5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.648935612533489}, {5.320784927947847, 
       2.6072354269601368`}, {5.262178660363542, 2.589126765008848}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}, {5.262178660363542, 2.589126765008848}, {
       5.320784927947847, 2.6072354269601368`}, {5.36577062301836, 
       2.648935612533489}, {5.389846236384392, 2.7268531220094183`}, {
       5.389846236384392, 2.7268531220094183`}}, {{5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}}, {{
       5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.320784927947847, 2.8464708170587}, {
       5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.320784927947847, 
       2.8464708170587}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}, {{5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}}, {{5.182662311074757, 
       2.6072354269601368`}, {5.127221575152003, 2.6670442744847778`}, {
       5.127221575152003, 2.6670442744847778`}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}}, {{
       5.182662311074757, 2.6072354269601368`}, {5.127221575152003, 
       2.6670442744847778`}, {5.127221575152003, 2.6670442744847778`}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}}, {{5.182662311074757, 2.6072354269601368`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}, {5.182662311074757, 2.6072354269601368`}, {
       5.182662311074757, 2.6072354269601368`}}, {{5.182662311074757, 
       2.6072354269601368`}, {5.127221575152003, 2.6670442744847778`}, {
       5.127221575152003, 2.6670442744847778`}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}}, {{
       5.127221575152003, 2.6670442744847778`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}}, {{5.127221575152003, 2.6670442744847778`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.127221575152003, 2.6670442744847778`}, {
       5.127221575152003, 2.6670442744847778`}}, {{5.127221575152003, 
       2.6670442744847778`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003, 
       2.6670442744847778`}, {5.127221575152003, 2.6670442744847778`}}, {{
       5.127221575152003, 2.6670442744847778`}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.6670442744847778`}, {5.127221575152003, 
       2.6670442744847778`}}, {{5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}}, {{5.1136010026382115`, 
       2.7268531220094183`}, {5.127221575152003, 2.786661969534059}, {
       5.127221575152003, 2.786661969534059}, {5.1136010026382115`, 
       2.7268531220094183`}, {5.1136010026382115`, 2.7268531220094183`}}, {{
       5.1136010026382115`, 2.7268531220094183`}, {5.127221575152003, 
       2.786661969534059}, {5.127221575152003, 2.786661969534059}, {
       5.1136010026382115`, 2.7268531220094183`}, {5.1136010026382115`, 
       2.7268531220094183`}}, {{5.1136010026382115`, 2.7268531220094183`}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}, {5.1136010026382115`, 2.7268531220094183`}, {
       5.1136010026382115`, 2.7268531220094183`}}, {{5.127221575152003, 
       2.786661969534059}, {5.182662311074757, 2.8464708170587}, {
       5.182662311074757, 2.8464708170587}, {5.127221575152003, 
       2.786661969534059}, {5.127221575152003, 2.786661969534059}}, {{
       5.127221575152003, 2.786661969534059}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}, {
       5.127221575152003, 2.786661969534059}, {5.127221575152003, 
       2.786661969534059}}, {{5.127221575152003, 2.786661969534059}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}, {5.127221575152003, 2.786661969534059}, {
       5.127221575152003, 2.786661969534059}}, {{5.127221575152003, 
       2.786661969534059}, {5.182662311074757, 2.8464708170587}, {
       5.182662311074757, 2.8464708170587}, {5.127221575152003, 
       2.786661969534059}, {5.127221575152003, 2.786661969534059}}, {{
       5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}, {{5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.648935612533489}, {5.36577062301836, 
       2.648935612533489}, {5.389846236384392, 2.7268531220094183`}, {
       5.389846236384392, 2.7268531220094183`}}, {{5.389846236384392, 
       2.7268531220094183`}, {5.36577062301836, 2.648935612533489}, {
       5.36577062301836, 2.648935612533489}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}}, {{
       5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}}, {{5.36577062301836, 2.648935612533489}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.36577062301836, 2.648935612533489}, {
       5.36577062301836, 2.648935612533489}}, {{5.36577062301836, 
       2.648935612533489}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}, {5.36577062301836, 
       2.648935612533489}, {5.36577062301836, 2.648935612533489}}, {{
       5.36577062301836, 2.648935612533489}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}, {
       5.36577062301836, 2.648935612533489}, {5.36577062301836, 
       2.648935612533489}}, {{5.36577062301836, 2.648935612533489}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}, {5.36577062301836, 2.648935612533489}, {
       5.36577062301836, 2.648935612533489}}, {{5.320784927947847, 
       2.6072354269601368`}, {5.262178660363542, 2.589126765008848}, {
       5.262178660363542, 2.589126765008848}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}}, {{
       5.320784927947847, 2.6072354269601368`}, {5.262178660363542, 
       2.589126765008848}, {5.262178660363542, 2.589126765008848}, {
       5.320784927947847, 2.6072354269601368`}, {5.320784927947847, 
       2.6072354269601368`}}, {{5.320784927947847, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}, {5.320784927947847, 2.6072354269601368`}, {
       5.320784927947847, 2.6072354269601368`}}, {{5.320784927947847, 
       2.6072354269601368`}, {5.262178660363542, 2.589126765008848}, {
       5.262178660363542, 2.589126765008848}, {5.320784927947847, 
       2.6072354269601368`}, {5.320784927947847, 2.6072354269601368`}}, {{
       5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}}, {{5.262178660363542, 2.589126765008848}, {
       5.182662311074757, 2.6072354269601368`}, {5.182662311074757, 
       2.6072354269601368`}, {5.262178660363542, 2.589126765008848}, {
       5.262178660363542, 2.589126765008848}}, {{5.262178660363542, 
       2.589126765008848}, {5.182662311074757, 2.6072354269601368`}, {
       5.182662311074757, 2.6072354269601368`}, {5.262178660363542, 
       2.589126765008848}, {5.262178660363542, 2.589126765008848}}, {{
       5.262178660363542, 2.589126765008848}, {5.182662311074757, 
       2.6072354269601368`}, {5.182662311074757, 2.6072354269601368`}, {
       5.262178660363542, 2.589126765008848}, {5.262178660363542, 
       2.589126765008848}}, {{5.182662311074757, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}, {5.182662311074757, 2.8464708170587}, {
       5.182662311074757, 2.8464708170587}}, {{5.182662311074757, 
       2.8464708170587}, {5.262178660363542, 2.8645794790099885`}, {
       5.262178660363542, 2.8645794790099885`}, {5.182662311074757, 
       2.8464708170587}, {5.182662311074757, 2.8464708170587}}, {{
       5.182662311074757, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}, {
       5.182662311074757, 2.8464708170587}, {5.182662311074757, 
       2.8464708170587}}, {{5.182662311074757, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}, {5.182662311074757, 2.8464708170587}, {
       5.182662311074757, 2.8464708170587}}, {{5.262178660363542, 
       2.8645794790099885`}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}}, {{
       5.262178660363542, 2.8645794790099885`}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}, {
       5.262178660363542, 2.8645794790099885`}, {5.262178660363542, 
       2.8645794790099885`}}, {{5.262178660363542, 2.8645794790099885`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}, {5.262178660363542, 2.8645794790099885`}, {
       5.262178660363542, 2.8645794790099885`}}, {{5.262178660363542, 
       2.8645794790099885`}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}, {5.262178660363542, 
       2.8645794790099885`}, {5.262178660363542, 2.8645794790099885`}}, {{
       5.320784927947847, 2.8464708170587}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}, {{5.320784927947847, 2.8464708170587}, {
       5.36577062301836, 2.8047706314853476`}, {5.36577062301836, 
       2.8047706314853476`}, {5.320784927947847, 2.8464708170587}, {
       5.320784927947847, 2.8464708170587}}, {{5.320784927947847, 
       2.8464708170587}, {5.36577062301836, 2.8047706314853476`}, {
       5.36577062301836, 2.8047706314853476`}, {5.320784927947847, 
       2.8464708170587}, {5.320784927947847, 2.8464708170587}}, {{
       5.320784927947847, 2.8464708170587}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}, {
       5.320784927947847, 2.8464708170587}, {5.320784927947847, 
       2.8464708170587}}, {{5.36577062301836, 2.8047706314853476`}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}, {5.36577062301836, 2.8047706314853476`}, {
       5.36577062301836, 2.8047706314853476`}}, {{5.36577062301836, 
       2.8047706314853476`}, {5.389846236384392, 2.7268531220094183`}, {
       5.389846236384392, 2.7268531220094183`}, {5.36577062301836, 
       2.8047706314853476`}, {5.36577062301836, 2.8047706314853476`}}, {{
       5.36577062301836, 2.8047706314853476`}, {5.389846236384392, 
       2.7268531220094183`}, {5.389846236384392, 2.7268531220094183`}, {
       5.36577062301836, 2.8047706314853476`}, {5.36577062301836, 
       2.8047706314853476`}}, {{5.36577062301836, 2.8047706314853476`}, {
       5.389846236384392, 2.7268531220094183`}, {5.389846236384392, 
       2.7268531220094183`}, {5.36577062301836, 2.8047706314853476`}, {
       5.36577062301836, 2.8047706314853476`}}, {{5.13732711194462, 
       3.1355729766691844`}, {5.083060886232498, 3.1941147756791435`}, {
       5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.3111983736990607`}, {5.13732711194462, 3.3697401727090197`}, {
       5.13732711194462, 3.3697401727090197`}, {5.083060886232498, 
       3.3111983736990607`}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}}, {{
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}, {{5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.176389745149925}, {5.272523605613598, 
       3.1355729766691844`}, {5.215158909926547, 3.1178479461399657`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}, {5.215158909926547, 3.1178479461399657`}, {
       5.272523605613598, 3.1355729766691844`}, {5.316556280178282, 
       3.176389745149925}, {5.340121852448088, 3.252656574689102}, {
       5.340121852448088, 3.252656574689102}}, {{5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}}, {{
       5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.272523605613598, 3.3697401727090197`}, {
       5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.272523605613598, 
       3.3697401727090197`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}, {{5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}}, {{5.13732711194462, 
       3.1355729766691844`}, {5.083060886232498, 3.1941147756791435`}, {
       5.083060886232498, 3.1941147756791435`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}}, {{
       5.13732711194462, 3.1355729766691844`}, {5.083060886232498, 
       3.1941147756791435`}, {5.083060886232498, 3.1941147756791435`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}}, {{5.13732711194462, 3.1355729766691844`}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}, {5.13732711194462, 3.1355729766691844`}, {
       5.13732711194462, 3.1355729766691844`}}, {{5.13732711194462, 
       3.1355729766691844`}, {5.083060886232498, 3.1941147756791435`}, {
       5.083060886232498, 3.1941147756791435`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}}, {{
       5.083060886232498, 3.1941147756791435`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}}, {{5.083060886232498, 3.1941147756791435`}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}, {5.083060886232498, 3.1941147756791435`}, {
       5.083060886232498, 3.1941147756791435`}}, {{5.083060886232498, 
       3.1941147756791435`}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.1941147756791435`}, {5.083060886232498, 3.1941147756791435`}}, {{
       5.083060886232498, 3.1941147756791435`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.1941147756791435`}, {5.083060886232498, 
       3.1941147756791435`}}, {{5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}}, {{5.06972886511013, 
       3.252656574689102}, {5.083060886232498, 3.3111983736990607`}, {
       5.083060886232498, 3.3111983736990607`}, {5.06972886511013, 
       3.252656574689102}, {5.06972886511013, 3.252656574689102}}, {{
       5.06972886511013, 3.252656574689102}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}, {
       5.06972886511013, 3.252656574689102}, {5.06972886511013, 
       3.252656574689102}}, {{5.06972886511013, 3.252656574689102}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}, {5.06972886511013, 3.252656574689102}, {
       5.06972886511013, 3.252656574689102}}, {{5.083060886232498, 
       3.3111983736990607`}, {5.13732711194462, 3.3697401727090197`}, {
       5.13732711194462, 3.3697401727090197`}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}}, {{
       5.083060886232498, 3.3111983736990607`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}, {
       5.083060886232498, 3.3111983736990607`}, {5.083060886232498, 
       3.3111983736990607`}}, {{5.083060886232498, 3.3111983736990607`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}, {5.083060886232498, 3.3111983736990607`}, {
       5.083060886232498, 3.3111983736990607`}}, {{5.083060886232498, 
       3.3111983736990607`}, {5.13732711194462, 3.3697401727090197`}, {
       5.13732711194462, 3.3697401727090197`}, {5.083060886232498, 
       3.3111983736990607`}, {5.083060886232498, 3.3111983736990607`}}, {{
       5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}, {{5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.176389745149925}, {5.316556280178282, 
       3.176389745149925}, {5.340121852448088, 3.252656574689102}, {
       5.340121852448088, 3.252656574689102}}, {{5.340121852448088, 
       3.252656574689102}, {5.316556280178282, 3.176389745149925}, {
       5.316556280178282, 3.176389745149925}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}}, {{
       5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}}, {{5.316556280178282, 3.176389745149925}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.316556280178282, 3.176389745149925}, {
       5.316556280178282, 3.176389745149925}}, {{5.316556280178282, 
       3.176389745149925}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}, {5.316556280178282, 
       3.176389745149925}, {5.316556280178282, 3.176389745149925}}, {{
       5.316556280178282, 3.176389745149925}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}, {
       5.316556280178282, 3.176389745149925}, {5.316556280178282, 
       3.176389745149925}}, {{5.316556280178282, 3.176389745149925}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}, {5.316556280178282, 3.176389745149925}, {
       5.316556280178282, 3.176389745149925}}, {{5.272523605613598, 
       3.1355729766691844`}, {5.215158909926547, 3.1178479461399657`}, {
       5.215158909926547, 3.1178479461399657`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}}, {{
       5.272523605613598, 3.1355729766691844`}, {5.215158909926547, 
       3.1178479461399657`}, {5.215158909926547, 3.1178479461399657`}, {
       5.272523605613598, 3.1355729766691844`}, {5.272523605613598, 
       3.1355729766691844`}}, {{5.272523605613598, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}, {5.272523605613598, 3.1355729766691844`}, {
       5.272523605613598, 3.1355729766691844`}}, {{5.272523605613598, 
       3.1355729766691844`}, {5.215158909926547, 3.1178479461399657`}, {
       5.215158909926547, 3.1178479461399657`}, {5.272523605613598, 
       3.1355729766691844`}, {5.272523605613598, 3.1355729766691844`}}, {{
       5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}}, {{5.215158909926547, 3.1178479461399657`}, {
       5.13732711194462, 3.1355729766691844`}, {5.13732711194462, 
       3.1355729766691844`}, {5.215158909926547, 3.1178479461399657`}, {
       5.215158909926547, 3.1178479461399657`}}, {{5.215158909926547, 
       3.1178479461399657`}, {5.13732711194462, 3.1355729766691844`}, {
       5.13732711194462, 3.1355729766691844`}, {5.215158909926547, 
       3.1178479461399657`}, {5.215158909926547, 3.1178479461399657`}}, {{
       5.215158909926547, 3.1178479461399657`}, {5.13732711194462, 
       3.1355729766691844`}, {5.13732711194462, 3.1355729766691844`}, {
       5.215158909926547, 3.1178479461399657`}, {5.215158909926547, 
       3.1178479461399657`}}, {{5.13732711194462, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}, {5.13732711194462, 3.3697401727090197`}, {
       5.13732711194462, 3.3697401727090197`}}, {{5.13732711194462, 
       3.3697401727090197`}, {5.215158909926547, 3.3874652032382384`}, {
       5.215158909926547, 3.3874652032382384`}, {5.13732711194462, 
       3.3697401727090197`}, {5.13732711194462, 3.3697401727090197`}}, {{
       5.13732711194462, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}, {
       5.13732711194462, 3.3697401727090197`}, {5.13732711194462, 
       3.3697401727090197`}}, {{5.13732711194462, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}, {5.13732711194462, 3.3697401727090197`}, {
       5.13732711194462, 3.3697401727090197`}}, {{5.215158909926547, 
       3.3874652032382384`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}}, {{
       5.215158909926547, 3.3874652032382384`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}, {
       5.215158909926547, 3.3874652032382384`}, {5.215158909926547, 
       3.3874652032382384`}}, {{5.215158909926547, 3.3874652032382384`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}, {5.215158909926547, 3.3874652032382384`}, {
       5.215158909926547, 3.3874652032382384`}}, {{5.215158909926547, 
       3.3874652032382384`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}, {5.215158909926547, 
       3.3874652032382384`}, {5.215158909926547, 3.3874652032382384`}}, {{
       5.272523605613598, 3.3697401727090197`}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}, {{5.272523605613598, 3.3697401727090197`}, {
       5.316556280178282, 3.3289234042282794`}, {5.316556280178282, 
       3.3289234042282794`}, {5.272523605613598, 3.3697401727090197`}, {
       5.272523605613598, 3.3697401727090197`}}, {{5.272523605613598, 
       3.3697401727090197`}, {5.316556280178282, 3.3289234042282794`}, {
       5.316556280178282, 3.3289234042282794`}, {5.272523605613598, 
       3.3697401727090197`}, {5.272523605613598, 3.3697401727090197`}}, {{
       5.272523605613598, 3.3697401727090197`}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}, {
       5.272523605613598, 3.3697401727090197`}, {5.272523605613598, 
       3.3697401727090197`}}, {{5.316556280178282, 3.3289234042282794`}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}, {5.316556280178282, 3.3289234042282794`}, {
       5.316556280178282, 3.3289234042282794`}}, {{5.316556280178282, 
       3.3289234042282794`}, {5.340121852448088, 3.252656574689102}, {
       5.340121852448088, 3.252656574689102}, {5.316556280178282, 
       3.3289234042282794`}, {5.316556280178282, 3.3289234042282794`}}, {{
       5.316556280178282, 3.3289234042282794`}, {5.340121852448088, 
       3.252656574689102}, {5.340121852448088, 3.252656574689102}, {
       5.316556280178282, 3.3289234042282794`}, {5.316556280178282, 
       3.3289234042282794`}}, {{5.316556280178282, 3.3289234042282794`}, {
       5.340121852448088, 3.252656574689102}, {5.340121852448088, 
       3.252656574689102}, {5.316556280178282, 3.3289234042282794`}, {
       5.316556280178282, 3.3289234042282794`}}, {{5.145336877765792, 
       3.610015039022549}, {5.075165998255072, 3.6857146011491078`}, {
       5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.8371137254022245`}, {5.145336877765792, 3.9128132875287833`}, {
       5.145336877765792, 3.9128132875287833`}, {5.075165998255072, 
       3.8371137254022245`}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}}, {{
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}, {{5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.662794617950206}, {5.320157528051014, 
       3.610015039022549}, {5.24598006137811, 3.5870950558236476`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}, {5.24598006137811, 3.5870950558236476`}, {
       5.320157528051014, 3.610015039022549}, {5.377095549092027, 
       3.662794617950206}, {5.407567853193624, 3.761414163275666}, {
       5.407567853193624, 3.761414163275666}}, {{5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}}, {{
       5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.320157528051014, 3.9128132875287833`}, {
       5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.320157528051014, 
       3.9128132875287833`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}, {{5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}}, {{5.145336877765792, 
       3.610015039022549}, {5.075165998255072, 3.6857146011491078`}, {
       5.075165998255072, 3.6857146011491078`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}}, {{
       5.145336877765792, 3.610015039022549}, {5.075165998255072, 
       3.6857146011491078`}, {5.075165998255072, 3.6857146011491078`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}}, {{5.145336877765792, 3.610015039022549}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}, {5.145336877765792, 3.610015039022549}, {
       5.145336877765792, 3.610015039022549}}, {{5.145336877765792, 
       3.610015039022549}, {5.075165998255072, 3.6857146011491078`}, {
       5.075165998255072, 3.6857146011491078`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}}, {{
       5.075165998255072, 3.6857146011491078`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}}, {{5.075165998255072, 3.6857146011491078`}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}, {5.075165998255072, 3.6857146011491078`}, {
       5.075165998255072, 3.6857146011491078`}}, {{5.075165998255072, 
       3.6857146011491078`}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.6857146011491078`}, {5.075165998255072, 3.6857146011491078`}}, {{
       5.075165998255072, 3.6857146011491078`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.6857146011491078`}, {5.075165998255072, 
       3.6857146011491078`}}, {{5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}}, {{5.057926552623181, 
       3.761414163275666}, {5.075165998255072, 3.8371137254022245`}, {
       5.075165998255072, 3.8371137254022245`}, {5.057926552623181, 
       3.761414163275666}, {5.057926552623181, 3.761414163275666}}, {{
       5.057926552623181, 3.761414163275666}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}, {
       5.057926552623181, 3.761414163275666}, {5.057926552623181, 
       3.761414163275666}}, {{5.057926552623181, 3.761414163275666}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}, {5.057926552623181, 3.761414163275666}, {
       5.057926552623181, 3.761414163275666}}, {{5.075165998255072, 
       3.8371137254022245`}, {5.145336877765792, 3.9128132875287833`}, {
       5.145336877765792, 3.9128132875287833`}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}}, {{
       5.075165998255072, 3.8371137254022245`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}, {
       5.075165998255072, 3.8371137254022245`}, {5.075165998255072, 
       3.8371137254022245`}}, {{5.075165998255072, 3.8371137254022245`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}, {5.075165998255072, 3.8371137254022245`}, {
       5.075165998255072, 3.8371137254022245`}}, {{5.075165998255072, 
       3.8371137254022245`}, {5.145336877765792, 3.9128132875287833`}, {
       5.145336877765792, 3.9128132875287833`}, {5.075165998255072, 
       3.8371137254022245`}, {5.075165998255072, 3.8371137254022245`}}, {{
       5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}, {{5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.662794617950206}, {5.377095549092027, 
       3.662794617950206}, {5.407567853193624, 3.761414163275666}, {
       5.407567853193624, 3.761414163275666}}, {{5.407567853193624, 
       3.761414163275666}, {5.377095549092027, 3.662794617950206}, {
       5.377095549092027, 3.662794617950206}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}}, {{
       5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}}, {{5.377095549092027, 3.662794617950206}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.377095549092027, 3.662794617950206}, {
       5.377095549092027, 3.662794617950206}}, {{5.377095549092027, 
       3.662794617950206}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}, {5.377095549092027, 
       3.662794617950206}, {5.377095549092027, 3.662794617950206}}, {{
       5.377095549092027, 3.662794617950206}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}, {
       5.377095549092027, 3.662794617950206}, {5.377095549092027, 
       3.662794617950206}}, {{5.377095549092027, 3.662794617950206}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}, {5.377095549092027, 3.662794617950206}, {
       5.377095549092027, 3.662794617950206}}, {{5.320157528051014, 
       3.610015039022549}, {5.24598006137811, 3.5870950558236476`}, {
       5.24598006137811, 3.5870950558236476`}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}}, {{
       5.320157528051014, 3.610015039022549}, {5.24598006137811, 
       3.5870950558236476`}, {5.24598006137811, 3.5870950558236476`}, {
       5.320157528051014, 3.610015039022549}, {5.320157528051014, 
       3.610015039022549}}, {{5.320157528051014, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}, {5.320157528051014, 3.610015039022549}, {
       5.320157528051014, 3.610015039022549}}, {{5.320157528051014, 
       3.610015039022549}, {5.24598006137811, 3.5870950558236476`}, {
       5.24598006137811, 3.5870950558236476`}, {5.320157528051014, 
       3.610015039022549}, {5.320157528051014, 3.610015039022549}}, {{
       5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}}, {{5.24598006137811, 3.5870950558236476`}, {
       5.145336877765792, 3.610015039022549}, {5.145336877765792, 
       3.610015039022549}, {5.24598006137811, 3.5870950558236476`}, {
       5.24598006137811, 3.5870950558236476`}}, {{5.24598006137811, 
       3.5870950558236476`}, {5.145336877765792, 3.610015039022549}, {
       5.145336877765792, 3.610015039022549}, {5.24598006137811, 
       3.5870950558236476`}, {5.24598006137811, 3.5870950558236476`}}, {{
       5.24598006137811, 3.5870950558236476`}, {5.145336877765792, 
       3.610015039022549}, {5.145336877765792, 3.610015039022549}, {
       5.24598006137811, 3.5870950558236476`}, {5.24598006137811, 
       3.5870950558236476`}}, {{5.145336877765792, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}, {5.145336877765792, 3.9128132875287833`}, {
       5.145336877765792, 3.9128132875287833`}}, {{5.145336877765792, 
       3.9128132875287833`}, {5.24598006137811, 3.9357332707276846`}, {
       5.24598006137811, 3.9357332707276846`}, {5.145336877765792, 
       3.9128132875287833`}, {5.145336877765792, 3.9128132875287833`}}, {{
       5.145336877765792, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}, {
       5.145336877765792, 3.9128132875287833`}, {5.145336877765792, 
       3.9128132875287833`}}, {{5.145336877765792, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}, {5.145336877765792, 3.9128132875287833`}, {
       5.145336877765792, 3.9128132875287833`}}, {{5.24598006137811, 
       3.9357332707276846`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}}, {{
       5.24598006137811, 3.9357332707276846`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}, {
       5.24598006137811, 3.9357332707276846`}, {5.24598006137811, 
       3.9357332707276846`}}, {{5.24598006137811, 3.9357332707276846`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}, {5.24598006137811, 3.9357332707276846`}, {
       5.24598006137811, 3.9357332707276846`}}, {{5.24598006137811, 
       3.9357332707276846`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}, {5.24598006137811, 
       3.9357332707276846`}, {5.24598006137811, 3.9357332707276846`}}, {{
       5.320157528051014, 3.9128132875287833`}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}, {{5.320157528051014, 3.9128132875287833`}, {
       5.377095549092027, 3.8600337086011263`}, {5.377095549092027, 
       3.8600337086011263`}, {5.320157528051014, 3.9128132875287833`}, {
       5.320157528051014, 3.9128132875287833`}}, {{5.320157528051014, 
       3.9128132875287833`}, {5.377095549092027, 3.8600337086011263`}, {
       5.377095549092027, 3.8600337086011263`}, {5.320157528051014, 
       3.9128132875287833`}, {5.320157528051014, 3.9128132875287833`}}, {{
       5.320157528051014, 3.9128132875287833`}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}, {
       5.320157528051014, 3.9128132875287833`}, {5.320157528051014, 
       3.9128132875287833`}}, {{5.377095549092027, 3.8600337086011263`}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}, {5.377095549092027, 3.8600337086011263`}, {
       5.377095549092027, 3.8600337086011263`}}, {{5.377095549092027, 
       3.8600337086011263`}, {5.407567853193624, 3.761414163275666}, {
       5.407567853193624, 3.761414163275666}, {5.377095549092027, 
       3.8600337086011263`}, {5.377095549092027, 3.8600337086011263`}}, {{
       5.377095549092027, 3.8600337086011263`}, {5.407567853193624, 
       3.761414163275666}, {5.407567853193624, 3.761414163275666}, {
       5.377095549092027, 3.8600337086011263`}, {5.377095549092027, 
       3.8600337086011263`}}, {{5.377095549092027, 3.8600337086011263`}, {
       5.407567853193624, 3.761414163275666}, {5.407567853193624, 
       3.761414163275666}, {5.377095549092027, 3.8600337086011263`}, {
       5.377095549092027, 3.8600337086011263`}}, {{
       5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}, {{
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}, {{
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}, {{
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}, {{
       5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}, {{
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}, {{
       5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}, {{
       5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}, {{
       5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}, {{
       5.4062335169756, -4.632952948446621}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}}, {{
       5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}, {{
       5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}, {{
       5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}, {{
       5.33618188402519, -4.557382028179242}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.557382028179242}, {
       5.33618188402519, -4.557382028179242}}, {{
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}, {{
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}, {{
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}, {{
       5.318971734657042, -4.481811107911863}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}, {
       5.318971734657042, -4.481811107911863}, {
       5.318971734657042, -4.481811107911863}}, {{
       5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}, {{
       5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}, {{
       5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}, {{
       5.33618188402519, -4.406240187644484}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}, {
       5.33618188402519, -4.406240187644484}, {
       5.33618188402519, -4.406240187644484}}, {{
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}, {{
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}, {{
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}, {{
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}}, {{
       5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}, {{
       5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}, {{
       5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}, {{
       5.637598343667562, -4.580263061757192}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}, {
       5.637598343667562, -4.580263061757192}, {
       5.637598343667562, -4.580263061757192}}, {{
       5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}, {{
       5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}, {{
       5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}, {{
       5.580757081612717, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}, {
       5.580757081612717, -4.632952948446621}, {
       5.580757081612717, -4.632952948446621}}, {{
       5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}, {{
       5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}, {{
       5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}, {{
       5.506705670189724, -4.65583398202457}, {
       5.4062335169756, -4.632952948446621}, {
       5.4062335169756, -4.632952948446621}, {
       5.506705670189724, -4.65583398202457}, {
       5.506705670189724, -4.65583398202457}}, {{
       5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}, {{
       5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}, {{
       5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}, {{
       5.4062335169756, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.4062335169756, -4.330669267377105}, {
       5.4062335169756, -4.330669267377105}}, {{
       5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}, {{
       5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}, {{
       5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}, {{
       5.506705670189724, -4.3077882337991555`}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}, {
       5.506705670189724, -4.3077882337991555`}, {
       5.506705670189724, -4.3077882337991555`}}, {{
       5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}, {{
       5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}, {{
       5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}, {{
       5.580757081612717, -4.330669267377105}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}, {
       5.580757081612717, -4.330669267377105}, {
       5.580757081612717, -4.330669267377105}}, {{
       5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}, {{
       5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}, {{
       5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}, {{
       5.637598343667562, -4.383359154066534}, {
       5.668018863931275, -4.481811107911863}, {
       5.668018863931275, -4.481811107911863}, {
       5.637598343667562, -4.383359154066534}, {
       5.637598343667562, -4.383359154066534}}, {{
       5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.867806430401208}, {
       5.440105828095692, -3.867806430401208}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}, {{
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}, {{
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}, {{
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}, {{
       5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}, {{
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}, {{
       5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}, {{
       5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}, {{
       5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}, {{
       5.440105828095692, -4.138168423968722}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}}, {{
       5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}, {{
       5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}, {{
       5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}, {{
       5.377451770588773, -4.070577925576844}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -4.070577925576844}, {
       5.377451770588773, -4.070577925576844}}, {{
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}, {{
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}, {{
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}, {{
       5.362059043213269, -4.002987427184965}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.362059043213269, -4.002987427184965}, {
       5.362059043213269, -4.002987427184965}}, {{
       5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}, {{
       5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}, {{
       5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}, {{
       5.377451770588773, -3.9353969287930863`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.377451770588773, -3.9353969287930863`}, {
       5.377451770588773, -3.9353969287930863`}}, {{
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}, {{
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}, {{
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}, {{
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}}, {{
       5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}, {{
       5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}, {{
       5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}, {{
       5.647038122834607, -4.091042681832068}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}, {
       5.647038122834607, -4.091042681832068}, {
       5.647038122834607, -4.091042681832068}}, {{
       5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}, {{
       5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}, {{
       5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}, {{
       5.596199397860541, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}, {
       5.596199397860541, -4.138168423968722}, {
       5.596199397860541, -4.138168423968722}}, {{
       5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}, {{
       5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}, {{
       5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}, {{
       5.529967945510971, -4.158633180223946}, {
       5.440105828095692, -4.138168423968722}, {
       5.440105828095692, -4.138168423968722}, {
       5.529967945510971, -4.158633180223946}, {
       5.529967945510971, -4.158633180223946}}, {{
       5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}, {{
       5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}, {{
       5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}, {{
       5.440105828095692, -3.8678064304012074`}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}, {
       5.440105828095692, -3.8678064304012074`}, {
       5.440105828095692, -3.8678064304012074`}}, {{
       5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}, {{
       5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}, {{
       5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}, {{
       5.529967945510971, -3.847341674145983}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}, {
       5.529967945510971, -3.847341674145983}, {
       5.529967945510971, -3.847341674145983}}, {{
       5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}, {{
       5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}, {{
       5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}, {{
       5.596199397860541, -3.867806430401208}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.596199397860541, -3.867806430401208}, {
       5.596199397860541, -3.867806430401208}}, {{
       5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}, {{
       5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}, {{
       5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}, {{
       5.647038122834607, -3.9149321725378616`}, {
       5.674246182742965, -4.002987427184965}, {
       5.674246182742965, -4.002987427184965}, {
       5.647038122834607, -3.9149321725378616`}, {
       5.647038122834607, -3.9149321725378616`}}, {{
       5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}, {{
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}, {{
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}, {{
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}, {{
       5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}, {{
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}, {{
       5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}, {{
       5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}, {{
       5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}, {{
       5.401146736865703, -3.6625553174808156`}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}}, {{
       5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}, {{
       5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}, {{
       5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}, {{
       5.334838983443117, -3.591023252688629}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.591023252688629}, {
       5.334838983443117, -3.591023252688629}}, {{
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}, {{
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}, {{
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}, {{
       5.318548623138786, -3.519491187896442}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}, {
       5.318548623138786, -3.519491187896442}, {
       5.318548623138786, -3.519491187896442}}, {{
       5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}, {{
       5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}, {{
       5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}, {{
       5.334838983443117, -3.447959123104255}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}, {
       5.334838983443117, -3.447959123104255}, {
       5.334838983443117, -3.447959123104255}}, {{
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}, {{
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}, {{
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}, {{
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}}, {{
       5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}, {{
       5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}, {{
       5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}, {{
       5.620146369462561, -3.6126814192243697`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.620146369462561, -3.6126814192243697`}, {
       5.620146369462561, -3.6126814192243697`}}, {{
       5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}, {{
       5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}, {{
       5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}, {{
       5.566342964319539, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.566342964319539, -3.6625553174808156`}, {
       5.566342964319539, -3.6625553174808156`}}, {{
       5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}, {{
       5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}, {{
       5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}, {{
       5.496249198872184, -3.6842134840165564`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.401146736865703, -3.6625553174808156`}, {
       5.496249198872184, -3.6842134840165564`}, {
       5.496249198872184, -3.6842134840165564`}}, {{
       5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}, {{
       5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}, {{
       5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}, {{
       5.401146736865703, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.401146736865703, -3.376427058312068}, {
       5.401146736865703, -3.376427058312068}}, {{
       5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}, {{
       5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}, {{
       5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}, {{
       5.496249198872184, -3.3547688917763274`}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}, {
       5.496249198872184, -3.3547688917763274`}, {
       5.496249198872184, -3.3547688917763274`}}, {{
       5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}, {{
       5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}, {{
       5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}, {{
       5.566342964319539, -3.376427058312068}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}, {
       5.566342964319539, -3.376427058312068}, {
       5.566342964319539, -3.376427058312068}}, {{
       5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}, {{
       5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}, {{
       5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}, {{
       5.620146369462561, -3.426300956568514}, {
       5.648941078046456, -3.519491187896442}, {
       5.648941078046456, -3.519491187896442}, {
       5.620146369462561, -3.426300956568514}, {
       5.620146369462561, -3.426300956568514}}, {{
       5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}, {{
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}, {{
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}, {{
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}, {{
       5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}, {{
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}, {{
       5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}, {{
       5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}, {{
       5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}, {{
       5.467881085214415, -3.1254751057515655`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}}, {{
       5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}, {{
       5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}, {{
       5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}, {{
       5.411012698336512, -3.064126124300601}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -3.064126124300601}, {
       5.411012698336512, -3.064126124300601}}, {{
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}, {{
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}, {{
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}, {{
       5.397041383303968, -3.0027771428496357`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.397041383303968, -3.0027771428496357`}, {
       5.397041383303968, -3.0027771428496357`}}, {{
       5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}, {{
       5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}, {{
       5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}, {{
       5.411012698336512, -2.9414281613986706`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}, {
       5.411012698336512, -2.9414281613986706`}, {
       5.411012698336512, -2.9414281613986706`}}, {{
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}, {{
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}, {{
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}, {{
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}}, {{
       5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}, {{
       5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}, {{
       5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}, {{
       5.655704607951876, -3.0827011012836247`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.655704607951876, -3.0827011012836247`}, {
       5.655704607951876, -3.0827011012836247`}}, {{
       5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}, {{
       5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}, {{
       5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}, {{
       5.609560489035312, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}, {
       5.609560489035312, -3.1254751057515655`}, {
       5.609560489035312, -3.1254751057515655`}}, {{
       5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}, {{
       5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}, {{
       5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}, {{
       5.549445055086204, -3.14405008273459}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.467881085214415, -3.1254751057515655`}, {
       5.549445055086204, -3.14405008273459}, {
       5.549445055086204, -3.14405008273459}}, {{
       5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}, {{
       5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}, {{
       5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}, {{
       5.467881085214415, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.467881085214415, -2.880079179947706}, {
       5.467881085214415, -2.880079179947706}}, {{
       5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}, {{
       5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}, {{
       5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}, {{
       5.549445055086204, -2.8615042029646816`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}, {
       5.549445055086204, -2.8615042029646816`}, {
       5.549445055086204, -2.8615042029646816`}}, {{
       5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}, {{
       5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}, {{
       5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}, {{
       5.609560489035312, -2.880079179947706}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.609560489035312, -2.880079179947706}, {
       5.609560489035312, -2.880079179947706}}, {{
       5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}, {{
       5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}, {{
       5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}, {{
       5.655704607951876, -2.9228531844156467`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.680400190945759, -3.0027771428496357`}, {
       5.655704607951876, -2.9228531844156467`}, {
       5.655704607951876, -2.9228531844156467`}}, {{
       5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}, {{
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}, {{
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}, {{
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}, {{
       5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}, {{
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}, {{
       5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}, {{
       5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}, {{
       5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}, {{
       5.393601514918432, -2.6049438737984287`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}}, {{
       5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}, {{
       5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}, {{
       5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}, {{
       5.330021554159972, -2.536354521306361}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.536354521306361}, {
       5.330021554159972, -2.536354521306361}}, {{
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}, {{
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}, {{
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}, {{
       5.314401352668757, -2.4677651688142928`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.314401352668757, -2.4677651688142928`}, {
       5.314401352668757, -2.4677651688142928`}}, {{
       5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}, {{
       5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}, {{
       5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}, {{
       5.330021554159972, -2.3991758163222245`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.330021554159972, -2.3991758163222245`}, {
       5.330021554159972, -2.3991758163222245`}}, {{
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}, {{
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}, {{
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}, {{
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}}, {{
       5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}, {{
       5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}, {{
       5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}, {{
       5.6035918603594315`, -2.5571217062487714`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.6035918603594315`, -2.5571217062487714`}, {
       5.6035918603594315`, -2.5571217062487714`}}, {{
       5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}, {{
       5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}, {{
       5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}, {{
       5.552001839417782, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}, {
       5.552001839417782, -2.6049438737984287`}, {
       5.552001839417782, -2.6049438737984287`}}, {{
       5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}, {{
       5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}, {{
       5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}, {{
       5.484791616984919, -2.625711058740839}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.393601514918432, -2.6049438737984287`}, {
       5.484791616984919, -2.625711058740839}, {
       5.484791616984919, -2.625711058740839}}, {{
       5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}, {{
       5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}, {{
       5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}, {{
       5.393601514918432, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.393601514918432, -2.3305864638301568`}, {
       5.393601514918432, -2.3305864638301568`}}, {{
       5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}, {{
       5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}, {{
       5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}, {{
       5.484791616984919, -2.3098192788877463`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.484791616984919, -2.3098192788877463`}, {
       5.484791616984919, -2.3098192788877463`}}, {{
       5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}, {{
       5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}, {{
       5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}, {{
       5.552001839417782, -2.3305864638301568`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.552001839417782, -2.3305864638301568`}, {
       5.552001839417782, -2.3305864638301568`}}, {{
       5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}, {{
       5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}, {{
       5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}, {{
       5.6035918603594315`, -2.378408631379814}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.631202001667457, -2.4677651688142928`}, {
       5.6035918603594315`, -2.378408631379814}, {
       5.6035918603594315`, -2.378408631379814}}, {{
       5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}, {{
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}, {{
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}, {{
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}, {{
       5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}, {{
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}, {{
       5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}, {{
       5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}, {{
       5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}, {{
       5.412765280872141, -2.10698566239981}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}}, {{
       5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}, {{
       5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}, {{
       5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}, {{
       5.344554747281252, -2.0334008995857653`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -2.0334008995857653`}, {
       5.344554747281252, -2.0334008995857653`}}, {{
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}, {{
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}, {{
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}, {{
       5.327796915634255, -1.959816136771721}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.327796915634255, -1.959816136771721}, {
       5.327796915634255, -1.959816136771721}}, {{
       5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}, {{
       5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}, {{
       5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}, {{
       5.344554747281252, -1.8862313739576766`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.344554747281252, -1.8862313739576766`}, {
       5.344554747281252, -1.8862313739576766`}}, {{
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}, {{
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}, {{
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}, {{
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}}, {{
       5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}, {{
       5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}, {{
       5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}, {{
       5.638049369452831, -2.055680573074145}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}, {
       5.638049369452831, -2.055680573074145}, {
       5.638049369452831, -2.055680573074145}}, {{
       5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}, {{
       5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}, {{
       5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}, {{
       5.582702011347915, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}, {
       5.582702011347915, -2.10698566239981}, {
       5.582702011347915, -2.10698566239981}}, {{
       5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}, {{
       5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}, {{
       5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}, {{
       5.510596821596001, -2.12926533588819}, {
       5.412765280872141, -2.10698566239981}, {
       5.412765280872141, -2.10698566239981}, {
       5.510596821596001, -2.12926533588819}, {
       5.510596821596001, -2.12926533588819}}, {{
       5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}, {{
       5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}, {{
       5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}, {{
       5.412765280872141, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.412765280872141, -1.8126466111436321`}, {
       5.412765280872141, -1.8126466111436321`}}, {{
       5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}, {{
       5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}, {{
       5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}, {{
       5.510596821596001, -1.7903669376552522`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.510596821596001, -1.7903669376552522`}, {
       5.510596821596001, -1.7903669376552522`}}, {{
       5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}, {{
       5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}, {{
       5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}, {{
       5.582702011347915, -1.8126466111436321`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.582702011347915, -1.8126466111436321`}, {
       5.582702011347915, -1.8126466111436321`}}, {{
       5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}, {{
       5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}, {{
       5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}, {{
       5.638049369452831, -1.8639517004692967`}, {
       5.667670376585801, -1.959816136771721}, {
       5.667670376585801, -1.959816136771721}, {
       5.638049369452831, -1.8639517004692967`}, {
       5.638049369452831, -1.8639517004692967`}}, {{
       5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727374`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}, {{
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}, {{
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}, {{
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}, {{
       5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}, {{
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}, {{
       5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}, {{
       5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}, {{
       5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}, {{
       5.4600759417338125`, -1.6464365030608277`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}}, {{
       5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}, {{
       5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}, {{
       5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}, {{
       5.396641199666263, -1.5780038108727372`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.5780038108727372`}, {
       5.396641199666263, -1.5780038108727372`}}, {{
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}, {{
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}, {{
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}, {{
       5.381056675221482, -1.509571118684647}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.396641199666263, -1.4411384264965568`}, {
       5.381056675221482, -1.509571118684647}, {
       5.381056675221482, -1.509571118684647}}, {{
       5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}, {{
       5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}, {{
       5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}, {{
       5.396641199666263, -1.4411384264965565`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.396641199666263, -1.4411384264965565`}, {
       5.396641199666263, -1.4411384264965565`}}, {{
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}, {{
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}, {{
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}, {{
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}}, {{
       5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}, {{
       5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}, {{
       5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}, {{
       5.669586662420328, -1.5987235628917036`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.669586662420328, -1.5987235628917036`}, {
       5.669586662420328, -1.5987235628917036`}}, {{
       5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}, {{
       5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}, {{
       5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}, {{
       5.618114474758471, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}, {
       5.618114474758471, -1.6464365030608277`}, {
       5.618114474758471, -1.6464365030608277`}}, {{
       5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}, {{
       5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}, {{
       5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}, {{
       5.551057762651834, -1.667156255079794}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.4600759417338125`, -1.6464365030608277`}, {
       5.551057762651834, -1.667156255079794}, {
       5.551057762651834, -1.667156255079794}}, {{
       5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}, {{
       5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}, {{
       5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}, {{
       5.4600759417338125`, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}, {
       5.4600759417338125`, -1.3727057343084663`}, {
       5.4600759417338125`, -1.3727057343084663`}}, {{
       5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}, {{
       5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}, {{
       5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}, {{
       5.551057762651834, -1.3519859822895}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.551057762651834, -1.3519859822895}, {
       5.551057762651834, -1.3519859822895}}, {{
       5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}, {{
       5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}, {{
       5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}, {{
       5.618114474758471, -1.3727057343084663`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.618114474758471, -1.3727057343084663`}, {
       5.618114474758471, -1.3727057343084663`}}, {{
       5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}, {{
       5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}, {{
       5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}, {{
       5.669586662420328, -1.4204186744775904`}, {
       5.697133741270801, -1.509571118684647}, {
       5.697133741270801, -1.509571118684647}, {
       5.669586662420328, -1.4204186744775904`}, {
       5.669586662420328, -1.4204186744775904`}}, {{
       5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}, {{
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}, {{
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}, {{
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}, {{
       5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}, {{
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}, {{
       5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}, {{
       5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}, {{
       5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}, {{
       5.414092184633981, -1.1653956280258133`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}}, {{
       5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}, {{
       5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}, {{
       5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}, {{
       5.350183892200082, -1.096452074984511}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -1.096452074984511}, {
       5.350183892200082, -1.096452074984511}}, {{
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}, {{
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}, {{
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}, {{
       5.33448302681941, -1.0275085219432087`}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}, {
       5.33448302681941, -1.0275085219432087`}, {
       5.33448302681941, -1.0275085219432087`}}, {{
       5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}, {{
       5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}, {{
       5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}, {{
       5.350183892200082, -0.9585649689019065}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}, {
       5.350183892200082, -0.9585649689019065}, {
       5.350183892200082, -0.9585649689019065}}, {{
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}, {{
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}, {{
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}, {{
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}}, {{
       5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}, {{
       5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}, {{
       5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}, {{
       5.625166935933713, -1.1173265032241009`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.625166935933713, -1.1173265032241009`}, {
       5.625166935933713, -1.1173265032241009`}}, {{
       5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}, {{
       5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}, {{
       5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}, {{
       5.573310500263121, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.573310500263121, -1.1653956280258133`}, {
       5.573310500263121, -1.1653956280258133`}}, {{
       5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}, {{
       5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}, {{
       5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}, {{
       5.505753199211858, -1.1862700562654032`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.414092184633981, -1.1653956280258133`}, {
       5.505753199211858, -1.1862700562654032`}, {
       5.505753199211858, -1.1862700562654032`}}, {{
       5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}, {{
       5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}, {{
       5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}, {{
       5.414092184633981, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}, {
       5.414092184633981, -0.8896214158606042}, {
       5.414092184633981, -0.8896214158606042}}, {{
       5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}, {{
       5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}, {{
       5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}, {{
       5.505753199211858, -0.8687469876210143}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}, {
       5.505753199211858, -0.8687469876210143}, {
       5.505753199211858, -0.8687469876210143}}, {{
       5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}, {{
       5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}, {{
       5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}, {{
       5.573310500263121, -0.8896214158606042}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}, {
       5.573310500263121, -0.8896214158606042}, {
       5.573310500263121, -0.8896214158606042}}, {{
       5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}, {{
       5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}, {{
       5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}, {{
       5.625166935933713, -0.9376905406623166}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.652919658077692, -1.0275085219432087`}, {
       5.625166935933713, -0.9376905406623166}, {
       5.625166935933713, -0.9376905406623166}}, {{
       5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}, {{
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}, {{
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}, {{
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}, {{
       5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}, {{
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}, {{
       5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}, {{
       5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}, {{
       5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}, {{
       5.4159178924293405`, -0.6799674173507025}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}}, {{
       5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}, {{
       5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}, {{
       5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}, {{
       5.350866960408465, -0.6097911974680298}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.6097911974680298}, {
       5.350866960408465, -0.6097911974680298}}, {{
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}, {{
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}, {{
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}, {{
       5.3348853735493975`, -0.539614977585357}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}, {
       5.3348853735493975`, -0.539614977585357}, {
       5.3348853735493975`, -0.539614977585357}}, {{
       5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}, {{
       5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}, {{
       5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}, {{
       5.350866960408465, -0.4694387577026843}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.350866960408465, -0.4694387577026843}, {
       5.350866960408465, -0.4694387577026843}}, {{
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}, {{
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}, {{
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}, {{
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}}, {{
       5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}, {{
       5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}, {{
       5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}, {{
       5.63076652591965, -0.6310388471966266}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.63076652591965, -0.6310388471966266}, {
       5.63076652591965, -0.6310388471966266}}, {{
       5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}, {{
       5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}, {{
       5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}, {{
       5.5779829301892265`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5779829301892265`, -0.6799674173507025}, {
       5.5779829301892265`, -0.6799674173507025}}, {{
       5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}, {{
       5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}, {{
       5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}, {{
       5.5092177475997355`, -0.7012150670792994}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.4159178924293405`, -0.6799674173507025}, {
       5.5092177475997355`, -0.7012150670792994}, {
       5.5092177475997355`, -0.7012150670792994}}, {{
       5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}, {{
       5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}, {{
       5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}, {{
       5.4159178924293405`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.4159178924293405`, -0.39926253782001153`}, {
       5.4159178924293405`, -0.39926253782001153`}}, {{
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}, {{
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}, {{
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}, {{
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5092177475997355`, -0.37801488809141465`}, {
       5.5092177475997355`, -0.37801488809141465`}}, {{
       5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}, {{
       5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}, {{
       5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}, {{
       5.5779829301892265`, -0.39926253782001153`}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}, {
       5.5779829301892265`, -0.39926253782001153`}, {
       5.5779829301892265`, -0.39926253782001153`}}, {{
       5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}, {{
       5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}, {{
       5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}, {{
       5.63076652591965, -0.4481911079740874}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.6590154490691695`, -0.539614977585357}, {
       5.63076652591965, -0.4481911079740874}, {
       5.63076652591965, -0.4481911079740874}}, {{
       5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {5.424236492931953, 
       0.04563835604737325}, {5.435847212432175, 0.09662180417608038}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333887}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}, {{5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}}, {{
       5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.05632854021004101}, {
       5.483107107934601, -0.05632854021004101}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}, {{
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}, {{5.483107107934601, 
       0.1476052523047875}, {5.5508900169378, 0.16304179832573287`}, {
       5.600848337939898, 0.1476052523047875}, {5.639195939441774, 
       0.11205835019702573`}, {5.659718952942547, 0.04563835604737326}, {
       5.659718952942547, 0.04563835604737326}, {5.639195939441774, 
       0.11205835019702573`}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}}, {{
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}, {{5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}, {{
       5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}, {{
       5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}, {{
       5.483107107934601, -0.056328540210040995`}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}}, {{
       5.435847212432175, -0.005345092081333873}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}, {{
       5.435847212432175, -0.005345092081333873}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}, {{
       5.435847212432175, -0.005345092081333873}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}, {{
       5.435847212432175, -0.005345092081333873}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, -0.005345092081333873}, {
       5.435847212432175, -0.005345092081333873}}, {{5.424236492931953, 
       0.04563835604737325}, {5.435847212432175, 0.09662180417608038}, {
       5.435847212432175, 0.09662180417608038}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}}, {{
       5.424236492931953, 0.04563835604737325}, {5.435847212432175, 
       0.09662180417608038}, {5.435847212432175, 0.09662180417608038}, {
       5.424236492931953, 0.04563835604737325}, {5.424236492931953, 
       0.04563835604737325}}, {{5.424236492931953, 0.04563835604737325}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}, {5.424236492931953, 0.04563835604737325}, {
       5.424236492931953, 0.04563835604737325}}, {{5.424236492931953, 
       0.04563835604737325}, {5.435847212432175, 0.09662180417608038}, {
       5.435847212432175, 0.09662180417608038}, {5.424236492931953, 
       0.04563835604737325}, {5.424236492931953, 0.04563835604737325}}, {{
       5.435847212432175, 0.09662180417608038}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}}, {{5.435847212432175, 0.09662180417608038}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}, {5.435847212432175, 0.09662180417608038}, {
       5.435847212432175, 0.09662180417608038}}, {{5.435847212432175, 
       0.09662180417608038}, {5.483107107934601, 0.1476052523047875}, {
       5.483107107934601, 0.1476052523047875}, {5.435847212432175, 
       0.09662180417608038}, {5.435847212432175, 0.09662180417608038}}, {{
       5.435847212432175, 0.09662180417608038}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}, {
       5.435847212432175, 0.09662180417608038}, {5.435847212432175, 
       0.09662180417608038}}, {{5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}, {{
       5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}, {{
       5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}, {{
       5.659718952942547, 0.045638356047373235`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}, {5.659718952942547, 
       0.045638356047373235`}, {5.659718952942547, 0.045638356047373235`}}, {{
       5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}, {{
       5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}, {{
       5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}, {{
       5.639195939441774, -0.020781638102279232`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.639195939441774, -0.020781638102279232`}, {
       5.639195939441774, -0.020781638102279232`}}, {{
       5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}, {{
       5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}, {{
       5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}, {{
       5.600848337939898, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}, {
       5.600848337939898, -0.056328540210040995`}, {
       5.600848337939898, -0.056328540210040995`}}, {{
       5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}, {{
       5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}, {{
       5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}, {{
       5.5508900169378, -0.07176508623098637}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.483107107934601, -0.056328540210040995`}, {
       5.5508900169378, -0.07176508623098637}, {
       5.5508900169378, -0.07176508623098637}}, {{5.483107107934601, 
       0.1476052523047875}, {5.5508900169378, 0.16304179832573287`}, {
       5.5508900169378, 0.16304179832573287`}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}}, {{
       5.483107107934601, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.5508900169378, 0.16304179832573287`}, {
       5.483107107934601, 0.1476052523047875}, {5.483107107934601, 
       0.1476052523047875}}, {{5.483107107934601, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}, {5.483107107934601, 0.1476052523047875}, {
       5.483107107934601, 0.1476052523047875}}, {{5.483107107934601, 
       0.1476052523047875}, {5.5508900169378, 0.16304179832573287`}, {
       5.5508900169378, 0.16304179832573287`}, {5.483107107934601, 
       0.1476052523047875}, {5.483107107934601, 0.1476052523047875}}, {{
       5.5508900169378, 0.16304179832573287`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}}, {{5.5508900169378, 0.16304179832573287`}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}, {5.5508900169378, 0.16304179832573287`}, {
       5.5508900169378, 0.16304179832573287`}}, {{5.5508900169378, 
       0.16304179832573287`}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}, {5.5508900169378, 
       0.16304179832573287`}, {5.5508900169378, 0.16304179832573287`}}, {{
       5.5508900169378, 0.16304179832573287`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}, {
       5.5508900169378, 0.16304179832573287`}, {5.5508900169378, 
       0.16304179832573287`}}, {{5.600848337939898, 0.1476052523047875}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}}, {{5.600848337939898, 
       0.1476052523047875}, {5.639195939441774, 0.11205835019702573`}, {
       5.639195939441774, 0.11205835019702573`}, {5.600848337939898, 
       0.1476052523047875}, {5.600848337939898, 0.1476052523047875}}, {{
       5.600848337939898, 0.1476052523047875}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}, {
       5.600848337939898, 0.1476052523047875}, {5.600848337939898, 
       0.1476052523047875}}, {{5.600848337939898, 0.1476052523047875}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}, {5.600848337939898, 0.1476052523047875}, {
       5.600848337939898, 0.1476052523047875}}, {{5.639195939441774, 
       0.11205835019702573`}, {5.659718952942547, 0.04563835604737323}, {
       5.659718952942547, 0.04563835604737323}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}}, {{
       5.639195939441774, 0.11205835019702573`}, {5.659718952942547, 
       0.04563835604737323}, {5.659718952942547, 0.04563835604737323}, {
       5.639195939441774, 0.11205835019702573`}, {5.639195939441774, 
       0.11205835019702573`}}, {{5.639195939441774, 0.11205835019702573`}, {
       5.659718952942547, 0.04563835604737323}, {5.659718952942547, 
       0.04563835604737323}, {5.639195939441774, 0.11205835019702573`}, {
       5.639195939441774, 0.11205835019702573`}}, {{5.639195939441774, 
       0.11205835019702573`}, {5.659718952942547, 0.04563835604737323}, {
       5.659718952942547, 0.04563835604737323}, {5.639195939441774, 
       0.11205835019702573`}, {5.639195939441774, 0.11205835019702573`}}, {{
       5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.3151241046364435`, 
       0.5077284477255412}, {5.332568692952917, 0.43112809031078175`}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}, {{5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}}, {{5.668926000423906, 
       0.5077284477255412}, {5.638091087778953, 0.4079353682440293}, {
       5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.403574578583309, 0.3545277328960224}, {
       5.403574578583309, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.5804755264770405`, 0.3545277328960224}, {
       5.638091087778953, 0.4079353682440293}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}}, {{
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}, {{5.403574578583309, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.638091087778953, 0.607521527207053}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}, {5.638091087778953, 0.607521527207053}, {
       5.5804755264770405`, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.403574578583309, 0.66092916255506}, {
       5.403574578583309, 0.66092916255506}}, {{5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}}, {{
       5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}, {{5.403574578583309, 0.3545277328960224}, {
       5.332568692952917, 0.4311280903107818}, {5.332568692952917, 
       0.4311280903107818}, {5.403574578583309, 0.3545277328960224}, {
       5.403574578583309, 0.3545277328960224}}, {{5.403574578583309, 
       0.3545277328960224}, {5.332568692952917, 0.4311280903107818}, {
       5.332568692952917, 0.4311280903107818}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}}, {{
       5.403574578583309, 0.3545277328960224}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}}, {{5.332568692952917, 0.4311280903107818}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.332568692952917, 0.4311280903107818}, {
       5.332568692952917, 0.4311280903107818}}, {{5.332568692952917, 
       0.4311280903107818}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}, {5.332568692952917, 
       0.4311280903107818}, {5.332568692952917, 0.4311280903107818}}, {{
       5.332568692952917, 0.4311280903107818}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.4311280903107818}, {5.332568692952917, 
       0.4311280903107818}}, {{5.332568692952917, 0.4311280903107818}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}, {5.332568692952917, 0.4311280903107818}, {
       5.332568692952917, 0.4311280903107818}}, {{5.3151241046364435`, 
       0.5077284477255412}, {5.332568692952917, 0.5843288051403005}, {
       5.332568692952917, 0.5843288051403005}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}}, {{
       5.3151241046364435`, 0.5077284477255412}, {5.332568692952917, 
       0.5843288051403005}, {5.332568692952917, 0.5843288051403005}, {
       5.3151241046364435`, 0.5077284477255412}, {5.3151241046364435`, 
       0.5077284477255412}}, {{5.3151241046364435`, 0.5077284477255412}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}, {5.3151241046364435`, 0.5077284477255412}, {
       5.3151241046364435`, 0.5077284477255412}}, {{5.3151241046364435`, 
       0.5077284477255412}, {5.332568692952917, 0.5843288051403005}, {
       5.332568692952917, 0.5843288051403005}, {5.3151241046364435`, 
       0.5077284477255412}, {5.3151241046364435`, 0.5077284477255412}}, {{
       5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}}, {{5.332568692952917, 0.5843288051403005}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}, {5.332568692952917, 0.5843288051403005}, {
       5.332568692952917, 0.5843288051403005}}, {{5.332568692952917, 
       0.5843288051403005}, {5.403574578583309, 0.66092916255506}, {
       5.403574578583309, 0.66092916255506}, {5.332568692952917, 
       0.5843288051403005}, {5.332568692952917, 0.5843288051403005}}, {{
       5.332568692952917, 0.5843288051403005}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}, {
       5.332568692952917, 0.5843288051403005}, {5.332568692952917, 
       0.5843288051403005}}, {{5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}, {5.668926000423906, 0.5077284477255412}, {
       5.668926000423906, 0.5077284477255412}}, {{5.668926000423906, 
       0.5077284477255412}, {5.638091087778953, 0.4079353682440293}, {
       5.638091087778953, 0.4079353682440293}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}}, {{
       5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}}, {{5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}, {5.668926000423906, 0.5077284477255412}, {
       5.668926000423906, 0.5077284477255412}}, {{5.638091087778953, 
       0.4079353682440293}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}}, {{
       5.638091087778953, 0.4079353682440293}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}, {
       5.638091087778953, 0.4079353682440293}, {5.638091087778953, 
       0.4079353682440293}}, {{5.638091087778953, 0.4079353682440293}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}, {5.638091087778953, 0.4079353682440293}, {
       5.638091087778953, 0.4079353682440293}}, {{5.638091087778953, 
       0.4079353682440293}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}, {5.638091087778953, 
       0.4079353682440293}, {5.638091087778953, 0.4079353682440293}}, {{
       5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}, {{5.5804755264770405`, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.505415376858655, 
       0.3313350108292699}, {5.5804755264770405`, 0.3545277328960224}, {
       5.5804755264770405`, 0.3545277328960224}}, {{5.5804755264770405`, 
       0.3545277328960224}, {5.505415376858655, 0.3313350108292699}, {
       5.505415376858655, 0.3313350108292699}, {5.5804755264770405`, 
       0.3545277328960224}, {5.5804755264770405`, 0.3545277328960224}}, {{
       5.5804755264770405`, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}, {
       5.5804755264770405`, 0.3545277328960224}, {5.5804755264770405`, 
       0.3545277328960224}}, {{5.505415376858655, 0.3313350108292699}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}, {5.505415376858655, 0.3313350108292699}, {
       5.505415376858655, 0.3313350108292699}}, {{5.505415376858655, 
       0.3313350108292699}, {5.403574578583309, 0.3545277328960224}, {
       5.403574578583309, 0.3545277328960224}, {5.505415376858655, 
       0.3313350108292699}, {5.505415376858655, 0.3313350108292699}}, {{
       5.505415376858655, 0.3313350108292699}, {5.403574578583309, 
       0.3545277328960224}, {5.403574578583309, 0.3545277328960224}, {
       5.505415376858655, 0.3313350108292699}, {5.505415376858655, 
       0.3313350108292699}}, {{5.505415376858655, 0.3313350108292699}, {
       5.403574578583309, 0.3545277328960224}, {5.403574578583309, 
       0.3545277328960224}, {5.505415376858655, 0.3313350108292699}, {
       5.505415376858655, 0.3313350108292699}}, {{5.403574578583309, 
       0.66092916255506}, {5.505415376858655, 0.6841218846218124}, {
       5.505415376858655, 0.6841218846218124}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}}, {{
       5.403574578583309, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.505415376858655, 0.6841218846218124}, {
       5.403574578583309, 0.66092916255506}, {5.403574578583309, 
       0.66092916255506}}, {{5.403574578583309, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}, {5.403574578583309, 0.66092916255506}, {
       5.403574578583309, 0.66092916255506}}, {{5.403574578583309, 
       0.66092916255506}, {5.505415376858655, 0.6841218846218124}, {
       5.505415376858655, 0.6841218846218124}, {5.403574578583309, 
       0.66092916255506}, {5.403574578583309, 0.66092916255506}}, {{
       5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}}, {{5.505415376858655, 0.6841218846218124}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}, {5.505415376858655, 0.6841218846218124}, {
       5.505415376858655, 0.6841218846218124}}, {{5.505415376858655, 
       0.6841218846218124}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}, {5.505415376858655, 
       0.6841218846218124}, {5.505415376858655, 0.6841218846218124}}, {{
       5.505415376858655, 0.6841218846218124}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}, {
       5.505415376858655, 0.6841218846218124}, {5.505415376858655, 
       0.6841218846218124}}, {{5.5804755264770405`, 0.66092916255506}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}}, {{5.5804755264770405`, 
       0.66092916255506}, {5.638091087778953, 0.607521527207053}, {
       5.638091087778953, 0.607521527207053}, {5.5804755264770405`, 
       0.66092916255506}, {5.5804755264770405`, 0.66092916255506}}, {{
       5.5804755264770405`, 0.66092916255506}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}, {
       5.5804755264770405`, 0.66092916255506}, {5.5804755264770405`, 
       0.66092916255506}}, {{5.5804755264770405`, 0.66092916255506}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}, {5.5804755264770405`, 0.66092916255506}, {
       5.5804755264770405`, 0.66092916255506}}, {{5.638091087778953, 
       0.607521527207053}, {5.668926000423906, 0.5077284477255412}, {
       5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}}, {{
       5.638091087778953, 0.607521527207053}, {5.668926000423906, 
       0.5077284477255412}, {5.668926000423906, 0.5077284477255412}, {
       5.638091087778953, 0.607521527207053}, {5.638091087778953, 
       0.607521527207053}}, {{5.638091087778953, 0.607521527207053}, {
       5.668926000423906, 0.5077284477255412}, {5.668926000423906, 
       0.5077284477255412}, {5.638091087778953, 0.607521527207053}, {
       5.638091087778953, 0.607521527207053}}, {{5.638091087778953, 
       0.607521527207053}, {5.668926000423906, 0.5077284477255412}, {
       5.668926000423906, 0.5077284477255412}, {5.638091087778953, 
       0.607521527207053}, {5.638091087778953, 0.607521527207053}}, {{
       5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.342004179910006, 
       0.9842241927717074}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}, {{5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}}, {{5.676456860147688, 
       0.9842241927717074}, {5.647308290561745, 0.8898887375377044}, {
       5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.425617349969427, 0.8394019340468944}, {
       5.425617349969427, 0.8394019340468944}, {5.521888535472614, 
       0.8174776081752979}, {5.592843690088268, 0.8394019340468946}, {
       5.647308290561745, 0.8898887375377044}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}}, {{
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}, {{5.425617349969427, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.647308290561745, 1.0785596480057102`}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}, {5.647308290561745, 1.0785596480057102`}, {
       5.592843690088268, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.425617349969427, 1.1290464514965202`}, {
       5.425617349969427, 1.1290464514965202`}}, {{5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}}, {{
       5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}, {{5.425617349969427, 0.8394019340468946}, {
       5.358494734052182, 0.9118130634093009}, {5.358494734052182, 
       0.9118130634093009}, {5.425617349969427, 0.8394019340468946}, {
       5.425617349969427, 0.8394019340468946}}, {{5.425617349969427, 
       0.8394019340468946}, {5.358494734052182, 0.9118130634093009}, {
       5.358494734052182, 0.9118130634093009}, {5.425617349969427, 
       0.8394019340468946}, {5.425617349969427, 0.8394019340468946}}, {{
       5.425617349969427, 0.8394019340468946}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}}, {{5.358494734052182, 0.9118130634093009}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.358494734052182, 0.9118130634093009}, {
       5.358494734052182, 0.9118130634093009}}, {{5.358494734052182, 
       0.9118130634093009}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}, {5.358494734052182, 
       0.9118130634093009}, {5.358494734052182, 0.9118130634093009}}, {{
       5.358494734052182, 0.9118130634093009}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 0.9118130634093009}, {5.358494734052182, 
       0.9118130634093009}}, {{5.358494734052182, 0.9118130634093009}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}, {5.358494734052182, 0.9118130634093009}, {
       5.358494734052182, 0.9118130634093009}}, {{5.342004179910006, 
       0.9842241927717074}, {5.358494734052182, 1.0566353221341138`}, {
       5.358494734052182, 1.0566353221341138`}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}}, {{
       5.342004179910006, 0.9842241927717074}, {5.358494734052182, 
       1.0566353221341138`}, {5.358494734052182, 1.0566353221341138`}, {
       5.342004179910006, 0.9842241927717074}, {5.342004179910006, 
       0.9842241927717074}}, {{5.342004179910006, 0.9842241927717074}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}, {5.342004179910006, 0.9842241927717074}, {
       5.342004179910006, 0.9842241927717074}}, {{5.342004179910006, 
       0.9842241927717074}, {5.358494734052182, 1.0566353221341138`}, {
       5.358494734052182, 1.0566353221341138`}, {5.342004179910006, 
       0.9842241927717074}, {5.342004179910006, 0.9842241927717074}}, {{
       5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}}, {{5.358494734052182, 1.0566353221341138`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}, {5.358494734052182, 1.0566353221341138`}, {
       5.358494734052182, 1.0566353221341138`}}, {{5.358494734052182, 
       1.0566353221341138`}, {5.425617349969427, 1.1290464514965202`}, {
       5.425617349969427, 1.1290464514965202`}, {5.358494734052182, 
       1.0566353221341138`}, {5.358494734052182, 1.0566353221341138`}}, {{
       5.358494734052182, 1.0566353221341138`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}, {
       5.358494734052182, 1.0566353221341138`}, {5.358494734052182, 
       1.0566353221341138`}}, {{5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}, {5.676456860147688, 0.9842241927717074}, {
       5.676456860147688, 0.9842241927717074}}, {{5.676456860147688, 
       0.9842241927717074}, {5.647308290561745, 0.8898887375377044}, {
       5.647308290561745, 0.8898887375377044}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}}, {{
       5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}}, {{5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}, {5.676456860147688, 0.9842241927717074}, {
       5.676456860147688, 0.9842241927717074}}, {{5.647308290561745, 
       0.8898887375377044}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}}, {{
       5.647308290561745, 0.8898887375377044}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}, {
       5.647308290561745, 0.8898887375377044}, {5.647308290561745, 
       0.8898887375377044}}, {{5.647308290561745, 0.8898887375377044}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}, {5.647308290561745, 0.8898887375377044}, {
       5.647308290561745, 0.8898887375377044}}, {{5.647308290561745, 
       0.8898887375377044}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}, {5.647308290561745, 
       0.8898887375377044}, {5.647308290561745, 0.8898887375377044}}, {{
       5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}, {{5.592843690088268, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.521888535472614, 
       0.8174776081752979}, {5.592843690088268, 0.8394019340468946}, {
       5.592843690088268, 0.8394019340468946}}, {{5.592843690088268, 
       0.8394019340468946}, {5.521888535472614, 0.8174776081752979}, {
       5.521888535472614, 0.8174776081752979}, {5.592843690088268, 
       0.8394019340468946}, {5.592843690088268, 0.8394019340468946}}, {{
       5.592843690088268, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}, {
       5.592843690088268, 0.8394019340468946}, {5.592843690088268, 
       0.8394019340468946}}, {{5.521888535472614, 0.8174776081752979}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}, {5.521888535472614, 0.8174776081752979}, {
       5.521888535472614, 0.8174776081752979}}, {{5.521888535472614, 
       0.8174776081752979}, {5.425617349969427, 0.8394019340468946}, {
       5.425617349969427, 0.8394019340468946}, {5.521888535472614, 
       0.8174776081752979}, {5.521888535472614, 0.8174776081752979}}, {{
       5.521888535472614, 0.8174776081752979}, {5.425617349969427, 
       0.8394019340468946}, {5.425617349969427, 0.8394019340468946}, {
       5.521888535472614, 0.8174776081752979}, {5.521888535472614, 
       0.8174776081752979}}, {{5.521888535472614, 0.8174776081752979}, {
       5.425617349969427, 0.8394019340468946}, {5.425617349969427, 
       0.8394019340468946}, {5.521888535472614, 0.8174776081752979}, {
       5.521888535472614, 0.8174776081752979}}, {{5.425617349969427, 
       1.1290464514965202`}, {5.521888535472614, 1.1509707773681168`}, {
       5.521888535472614, 1.1509707773681168`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}}, {{
       5.425617349969427, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.521888535472614, 1.1509707773681168`}, {
       5.425617349969427, 1.1290464514965202`}, {5.425617349969427, 
       1.1290464514965202`}}, {{5.425617349969427, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}, {5.425617349969427, 1.1290464514965202`}, {
       5.425617349969427, 1.1290464514965202`}}, {{5.425617349969427, 
       1.1290464514965202`}, {5.521888535472614, 1.1509707773681168`}, {
       5.521888535472614, 1.1509707773681168`}, {5.425617349969427, 
       1.1290464514965202`}, {5.425617349969427, 1.1290464514965202`}}, {{
       5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}}, {{5.521888535472614, 1.1509707773681168`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}, {5.521888535472614, 1.1509707773681168`}, {
       5.521888535472614, 1.1509707773681168`}}, {{5.521888535472614, 
       1.1509707773681168`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}, {5.521888535472614, 
       1.1509707773681168`}, {5.521888535472614, 1.1509707773681168`}}, {{
       5.521888535472614, 1.1509707773681168`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}, {
       5.521888535472614, 1.1509707773681168`}, {5.521888535472614, 
       1.1509707773681168`}}, {{5.592843690088268, 1.1290464514965202`}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}}, {{5.592843690088268, 
       1.1290464514965202`}, {5.647308290561745, 1.0785596480057102`}, {
       5.647308290561745, 1.0785596480057102`}, {5.592843690088268, 
       1.1290464514965202`}, {5.592843690088268, 1.1290464514965202`}}, {{
       5.592843690088268, 1.1290464514965202`}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}, {
       5.592843690088268, 1.1290464514965202`}, {5.592843690088268, 
       1.1290464514965202`}}, {{5.592843690088268, 1.1290464514965202`}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}, {5.592843690088268, 1.1290464514965202`}, {
       5.592843690088268, 1.1290464514965202`}}, {{5.647308290561745, 
       1.0785596480057102`}, {5.676456860147688, 0.9842241927717074}, {
       5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}}, {{
       5.647308290561745, 1.0785596480057102`}, {5.676456860147688, 
       0.9842241927717074}, {5.676456860147688, 0.9842241927717074}, {
       5.647308290561745, 1.0785596480057102`}, {5.647308290561745, 
       1.0785596480057102`}}, {{5.647308290561745, 1.0785596480057102`}, {
       5.676456860147688, 0.9842241927717074}, {5.676456860147688, 
       0.9842241927717074}, {5.647308290561745, 1.0785596480057102`}, {
       5.647308290561745, 1.0785596480057102`}}, {{5.647308290561745, 
       1.0785596480057102`}, {5.676456860147688, 0.9842241927717074}, {
       5.676456860147688, 0.9842241927717074}, {5.647308290561745, 
       1.0785596480057102`}, {5.647308290561745, 1.0785596480057102`}}, {{
       5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}, {{5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}}, {{5.670325654223054, 
       1.5395395556374045`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.487631802742497, 1.4340612113058158`}, {
       5.487631802742497, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.609427703729535, 1.4340612113058158`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.670325654223054, 
       1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}}, {{
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}, {{5.487631802742497, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.609427703729535, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.487631802742497, 1.6450178999689933`}, {
       5.487631802742497, 1.6450178999689933`}}, {{5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}}, {{
       5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}, {{5.487631802742497, 1.4340612113058158`}, {
       5.438744411698491, 1.4868003834716101`}, {5.438744411698491, 
       1.4868003834716101`}, {5.487631802742497, 1.4340612113058158`}, {
       5.487631802742497, 1.4340612113058158`}}, {{5.487631802742497, 
       1.4340612113058158`}, {5.438744411698491, 1.4868003834716101`}, {
       5.438744411698491, 1.4868003834716101`}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}}, {{
       5.487631802742497, 1.4340612113058158`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}}, {{5.438744411698491, 1.4868003834716101`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.438744411698491, 1.4868003834716101`}, {
       5.438744411698491, 1.4868003834716101`}}, {{5.438744411698491, 
       1.4868003834716101`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.438744411698491, 
       1.4868003834716101`}, {5.438744411698491, 1.4868003834716101`}}, {{
       5.438744411698491, 1.4868003834716101`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.4868003834716101`}, {5.438744411698491, 
       1.4868003834716101`}}, {{5.438744411698491, 1.4868003834716101`}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.438744411698491, 1.4868003834716101`}, {
       5.438744411698491, 1.4868003834716101`}}, {{5.4267338522489785`, 
       1.5395395556374045`}, {5.438744411698491, 1.592278727803199}, {
       5.438744411698491, 1.592278727803199}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}}, {{
       5.4267338522489785`, 1.5395395556374045`}, {5.438744411698491, 
       1.592278727803199}, {5.438744411698491, 1.592278727803199}, {
       5.4267338522489785`, 1.5395395556374045`}, {5.4267338522489785`, 
       1.5395395556374045`}}, {{5.4267338522489785`, 1.5395395556374045`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}, {5.4267338522489785`, 1.5395395556374045`}, {
       5.4267338522489785`, 1.5395395556374045`}}, {{5.4267338522489785`, 
       1.5395395556374045`}, {5.438744411698491, 1.592278727803199}, {
       5.438744411698491, 1.592278727803199}, {5.4267338522489785`, 
       1.5395395556374045`}, {5.4267338522489785`, 1.5395395556374045`}}, {{
       5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}}, {{5.438744411698491, 1.592278727803199}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}, {5.438744411698491, 1.592278727803199}, {
       5.438744411698491, 1.592278727803199}}, {{5.438744411698491, 
       1.592278727803199}, {5.487631802742497, 1.6450178999689933`}, {
       5.487631802742497, 1.6450178999689933`}, {5.438744411698491, 
       1.592278727803199}, {5.438744411698491, 1.592278727803199}}, {{
       5.438744411698491, 1.592278727803199}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}, {
       5.438744411698491, 1.592278727803199}, {5.438744411698491, 
       1.592278727803199}}, {{5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}, {5.670325654223054, 1.5395395556374045`}, {
       5.670325654223054, 1.5395395556374045`}}, {{5.670325654223054, 
       1.5395395556374045`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.670325654223054, 
       1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}}, {{
       5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`, 
       1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}}, {{5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}, {5.670325654223054, 1.5395395556374045`}, {
       5.670325654223054, 1.5395395556374045`}}, {{5.6490958868749175`, 
       1.4708322469856543`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.6490958868749175`, 
       1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}}, {{
       5.6490958868749175`, 1.4708322469856543`}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}, {
       5.6490958868749175`, 1.4708322469856543`}, {5.6490958868749175`, 
       1.4708322469856543`}}, {{5.6490958868749175`, 1.4708322469856543`}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}, {5.6490958868749175`, 1.4708322469856543`}, {
       5.6490958868749175`, 1.4708322469856543`}}, {{5.6490958868749175`, 
       1.4708322469856543`}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}, {5.6490958868749175`, 
       1.4708322469856543`}, {5.6490958868749175`, 1.4708322469856543`}}, {{
       5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}, {{5.609427703729535, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.55774896113464, 
       1.41809307481986}, {5.609427703729535, 1.4340612113058158`}, {
       5.609427703729535, 1.4340612113058158`}}, {{5.609427703729535, 
       1.4340612113058158`}, {5.55774896113464, 1.41809307481986}, {
       5.55774896113464, 1.41809307481986}, {5.609427703729535, 
       1.4340612113058158`}, {5.609427703729535, 1.4340612113058158`}}, {{
       5.609427703729535, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}, {
       5.609427703729535, 1.4340612113058158`}, {5.609427703729535, 
       1.4340612113058158`}}, {{5.55774896113464, 1.41809307481986}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}, {5.55774896113464, 1.41809307481986}, {
       5.55774896113464, 1.41809307481986}}, {{5.55774896113464, 
       1.41809307481986}, {5.487631802742497, 1.4340612113058158`}, {
       5.487631802742497, 1.4340612113058158`}, {5.55774896113464, 
       1.41809307481986}, {5.55774896113464, 1.41809307481986}}, {{
       5.55774896113464, 1.41809307481986}, {5.487631802742497, 
       1.4340612113058158`}, {5.487631802742497, 1.4340612113058158`}, {
       5.55774896113464, 1.41809307481986}, {5.55774896113464, 
       1.41809307481986}}, {{5.55774896113464, 1.41809307481986}, {
       5.487631802742497, 1.4340612113058158`}, {5.487631802742497, 
       1.4340612113058158`}, {5.55774896113464, 1.41809307481986}, {
       5.55774896113464, 1.41809307481986}}, {{5.487631802742497, 
       1.6450178999689933`}, {5.55774896113464, 1.6609860364549491`}, {
       5.55774896113464, 1.6609860364549491`}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}}, {{
       5.487631802742497, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.55774896113464, 1.6609860364549491`}, {
       5.487631802742497, 1.6450178999689933`}, {5.487631802742497, 
       1.6450178999689933`}}, {{5.487631802742497, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}, {5.487631802742497, 1.6450178999689933`}, {
       5.487631802742497, 1.6450178999689933`}}, {{5.487631802742497, 
       1.6450178999689933`}, {5.55774896113464, 1.6609860364549491`}, {
       5.55774896113464, 1.6609860364549491`}, {5.487631802742497, 
       1.6450178999689933`}, {5.487631802742497, 1.6450178999689933`}}, {{
       5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}}, {{5.55774896113464, 1.6609860364549491`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}, {5.55774896113464, 1.6609860364549491`}, {
       5.55774896113464, 1.6609860364549491`}}, {{5.55774896113464, 
       1.6609860364549491`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}, {5.55774896113464, 
       1.6609860364549491`}, {5.55774896113464, 1.6609860364549491`}}, {{
       5.55774896113464, 1.6609860364549491`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}, {
       5.55774896113464, 1.6609860364549491`}, {5.55774896113464, 
       1.6609860364549491`}}, {{5.609427703729535, 1.6450178999689933`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}}, {{5.609427703729535, 
       1.6450178999689933`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.609427703729535, 
       1.6450178999689933`}, {5.609427703729535, 1.6450178999689933`}}, {{
       5.609427703729535, 1.6450178999689933`}, {5.6490958868749175`, 
       1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.609427703729535, 1.6450178999689933`}, {5.609427703729535, 
       1.6450178999689933`}}, {{5.609427703729535, 1.6450178999689933`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}, {5.609427703729535, 1.6450178999689933`}, {
       5.609427703729535, 1.6450178999689933`}}, {{5.6490958868749175`, 
       1.6082468642891548`}, {5.670325654223054, 1.5395395556374045`}, {
       5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`, 
       1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}}, {{
       5.6490958868749175`, 1.6082468642891548`}, {5.670325654223054, 
       1.5395395556374045`}, {5.670325654223054, 1.5395395556374045`}, {
       5.6490958868749175`, 1.6082468642891548`}, {5.6490958868749175`, 
       1.6082468642891548`}}, {{5.6490958868749175`, 1.6082468642891548`}, {
       5.670325654223054, 1.5395395556374045`}, {5.670325654223054, 
       1.5395395556374045`}, {5.6490958868749175`, 1.6082468642891548`}, {
       5.6490958868749175`, 1.6082468642891548`}}, {{5.6490958868749175`, 
       1.6082468642891548`}, {5.670325654223054, 1.5395395556374045`}, {
       5.670325654223054, 1.5395395556374045`}, {5.6490958868749175`, 
       1.6082468642891548`}, {5.6490958868749175`, 1.6082468642891548`}}, {{
       5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.422994625543855, 
       2.0372116199566723`}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}, {{5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}}, {{5.659161188557605, 
       2.0372116199566723`}, {5.638578553396819, 1.9705986682616246`}, {
       5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.482036266297293, 1.9349484984094896`}, {
       5.482036266297293, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.600119547804168, 1.9349484984094896`}, {
       5.638578553396819, 1.9705986682616246`}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}}, {{
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}, {{5.482036266297293, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.638578553396819, 2.10382457165172}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}, {5.638578553396819, 2.10382457165172}, {
       5.600119547804168, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.482036266297293, 2.139474741503855}, {
       5.482036266297293, 2.139474741503855}}, {{5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}}, {{
       5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}, {{5.482036266297293, 1.9349484984094896`}, {
       5.434639075488708, 1.986080059183081}, {5.434639075488708, 
       1.986080059183081}, {5.482036266297293, 1.9349484984094896`}, {
       5.482036266297293, 1.9349484984094896`}}, {{5.482036266297293, 
       1.9349484984094896`}, {5.434639075488708, 1.986080059183081}, {
       5.434639075488708, 1.986080059183081}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}}, {{
       5.482036266297293, 1.9349484984094896`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}}, {{5.434639075488708, 1.986080059183081}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.434639075488708, 1.986080059183081}, {
       5.434639075488708, 1.986080059183081}}, {{5.434639075488708, 
       1.986080059183081}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}, {5.434639075488708, 
       1.986080059183081}, {5.434639075488708, 1.986080059183081}}, {{
       5.434639075488708, 1.986080059183081}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 1.986080059183081}, {5.434639075488708, 
       1.986080059183081}}, {{5.434639075488708, 1.986080059183081}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}, {5.434639075488708, 1.986080059183081}, {
       5.434639075488708, 1.986080059183081}}, {{5.422994625543855, 
       2.0372116199566723`}, {5.434639075488708, 2.0883431807302637`}, {
       5.434639075488708, 2.0883431807302637`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}}, {{
       5.422994625543855, 2.0372116199566723`}, {5.434639075488708, 
       2.0883431807302637`}, {5.434639075488708, 2.0883431807302637`}, {
       5.422994625543855, 2.0372116199566723`}, {5.422994625543855, 
       2.0372116199566723`}}, {{5.422994625543855, 2.0372116199566723`}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}, {5.422994625543855, 2.0372116199566723`}, {
       5.422994625543855, 2.0372116199566723`}}, {{5.422994625543855, 
       2.0372116199566723`}, {5.434639075488708, 2.0883431807302637`}, {
       5.434639075488708, 2.0883431807302637`}, {5.422994625543855, 
       2.0372116199566723`}, {5.422994625543855, 2.0372116199566723`}}, {{
       5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}}, {{5.434639075488708, 2.0883431807302637`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}, {5.434639075488708, 2.0883431807302637`}, {
       5.434639075488708, 2.0883431807302637`}}, {{5.434639075488708, 
       2.0883431807302637`}, {5.482036266297293, 2.139474741503855}, {
       5.482036266297293, 2.139474741503855}, {5.434639075488708, 
       2.0883431807302637`}, {5.434639075488708, 2.0883431807302637`}}, {{
       5.434639075488708, 2.0883431807302637`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}, {
       5.434639075488708, 2.0883431807302637`}, {5.434639075488708, 
       2.0883431807302637`}}, {{5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}, {5.659161188557605, 2.0372116199566723`}, {
       5.659161188557605, 2.0372116199566723`}}, {{5.659161188557605, 
       2.0372116199566723`}, {5.638578553396819, 1.9705986682616246`}, {
       5.638578553396819, 1.9705986682616246`}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}}, {{
       5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}}, {{5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}, {5.659161188557605, 2.0372116199566723`}, {
       5.659161188557605, 2.0372116199566723`}}, {{5.638578553396819, 
       1.9705986682616246`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}}, {{
       5.638578553396819, 1.9705986682616246`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}, {
       5.638578553396819, 1.9705986682616246`}, {5.638578553396819, 
       1.9705986682616246`}}, {{5.638578553396819, 1.9705986682616246`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}, {5.638578553396819, 1.9705986682616246`}, {
       5.638578553396819, 1.9705986682616246`}}, {{5.638578553396819, 
       1.9705986682616246`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}, {5.638578553396819, 
       1.9705986682616246`}, {5.638578553396819, 1.9705986682616246`}}, {{
       5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}, {{5.600119547804168, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.550016092266663, 
       1.9194671074880334`}, {5.600119547804168, 1.9349484984094896`}, {
       5.600119547804168, 1.9349484984094896`}}, {{5.600119547804168, 
       1.9349484984094896`}, {5.550016092266663, 1.9194671074880334`}, {
       5.550016092266663, 1.9194671074880334`}, {5.600119547804168, 
       1.9349484984094896`}, {5.600119547804168, 1.9349484984094896`}}, {{
       5.600119547804168, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}, {
       5.600119547804168, 1.9349484984094896`}, {5.600119547804168, 
       1.9349484984094896`}}, {{5.550016092266663, 1.9194671074880334`}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}, {5.550016092266663, 1.9194671074880334`}, {
       5.550016092266663, 1.9194671074880334`}}, {{5.550016092266663, 
       1.9194671074880334`}, {5.482036266297293, 1.9349484984094896`}, {
       5.482036266297293, 1.9349484984094896`}, {5.550016092266663, 
       1.9194671074880334`}, {5.550016092266663, 1.9194671074880334`}}, {{
       5.550016092266663, 1.9194671074880334`}, {5.482036266297293, 
       1.9349484984094896`}, {5.482036266297293, 1.9349484984094896`}, {
       5.550016092266663, 1.9194671074880334`}, {5.550016092266663, 
       1.9194671074880334`}}, {{5.550016092266663, 1.9194671074880334`}, {
       5.482036266297293, 1.9349484984094896`}, {5.482036266297293, 
       1.9349484984094896`}, {5.550016092266663, 1.9194671074880334`}, {
       5.550016092266663, 1.9194671074880334`}}, {{5.482036266297293, 
       2.139474741503855}, {5.550016092266663, 2.1549561324253115`}, {
       5.550016092266663, 2.1549561324253115`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}}, {{
       5.482036266297293, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.550016092266663, 2.1549561324253115`}, {
       5.482036266297293, 2.139474741503855}, {5.482036266297293, 
       2.139474741503855}}, {{5.482036266297293, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}, {5.482036266297293, 2.139474741503855}, {
       5.482036266297293, 2.139474741503855}}, {{5.482036266297293, 
       2.139474741503855}, {5.550016092266663, 2.1549561324253115`}, {
       5.550016092266663, 2.1549561324253115`}, {5.482036266297293, 
       2.139474741503855}, {5.482036266297293, 2.139474741503855}}, {{
       5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}}, {{5.550016092266663, 2.1549561324253115`}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}, {5.550016092266663, 2.1549561324253115`}, {
       5.550016092266663, 2.1549561324253115`}}, {{5.550016092266663, 
       2.1549561324253115`}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}, {5.550016092266663, 
       2.1549561324253115`}, {5.550016092266663, 2.1549561324253115`}}, {{
       5.550016092266663, 2.1549561324253115`}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}, {
       5.550016092266663, 2.1549561324253115`}, {5.550016092266663, 
       2.1549561324253115`}}, {{5.600119547804168, 2.139474741503855}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}}, {{5.600119547804168, 
       2.139474741503855}, {5.638578553396819, 2.10382457165172}, {
       5.638578553396819, 2.10382457165172}, {5.600119547804168, 
       2.139474741503855}, {5.600119547804168, 2.139474741503855}}, {{
       5.600119547804168, 2.139474741503855}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}, {
       5.600119547804168, 2.139474741503855}, {5.600119547804168, 
       2.139474741503855}}, {{5.600119547804168, 2.139474741503855}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}, {5.600119547804168, 2.139474741503855}, {
       5.600119547804168, 2.139474741503855}}, {{5.638578553396819, 
       2.10382457165172}, {5.659161188557605, 2.0372116199566723`}, {
       5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}}, {{
       5.638578553396819, 2.10382457165172}, {5.659161188557605, 
       2.0372116199566723`}, {5.659161188557605, 2.0372116199566723`}, {
       5.638578553396819, 2.10382457165172}, {5.638578553396819, 
       2.10382457165172}}, {{5.638578553396819, 2.10382457165172}, {
       5.659161188557605, 2.0372116199566723`}, {5.659161188557605, 
       2.0372116199566723`}, {5.638578553396819, 2.10382457165172}, {
       5.638578553396819, 2.10382457165172}}, {{5.638578553396819, 
       2.10382457165172}, {5.659161188557605, 2.0372116199566723`}, {
       5.659161188557605, 2.0372116199566723`}, {5.638578553396819, 
       2.10382457165172}, {5.638578553396819, 2.10382457165172}}, {{
       5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.6560577882824896`}, {5.429898798779611, 2.6560577882824896`}, {
       5.361754302615776, 2.582544265908168}, {5.345012694915826, 
       2.509030743533846}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}, {{5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}}, {{5.684557110370965, 
       2.509030743533846}, {5.654964780555043, 2.4132591175407136`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366, 
       2.339745595166392}, {5.429898798779611, 2.362003698785202}, {
       5.429898798779611, 2.362003698785202}, {5.527635624759366, 
       2.339745595166392}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.654964780555043, 2.4132591175407136`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}}, {{
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}, {{5.429898798779611, 2.65605778828249}, {
       5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.654964780555043, 2.6048023695269786`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}, {5.654964780555043, 2.6048023695269786`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.527635624759366, 
       2.6783158919013004`}, {5.429898798779611, 2.65605778828249}, {
       5.429898798779611, 2.65605778828249}}, {{5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}}, {{
       5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}, {{5.429898798779611, 2.3620036987852027`}, {
       5.361754302615776, 2.4355172211595244`}, {5.361754302615776, 
       2.4355172211595244`}, {5.429898798779611, 2.3620036987852027`}, {
       5.429898798779611, 2.3620036987852027`}}, {{5.429898798779611, 
       2.3620036987852027`}, {5.361754302615776, 2.4355172211595244`}, {
       5.361754302615776, 2.4355172211595244`}, {5.429898798779611, 
       2.3620036987852027`}, {5.429898798779611, 2.3620036987852027`}}, {{
       5.429898798779611, 2.3620036987852027`}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}}, {{5.361754302615776, 2.4355172211595244`}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.361754302615776, 2.4355172211595244`}, {
       5.361754302615776, 2.4355172211595244`}}, {{5.361754302615776, 
       2.4355172211595244`}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}, {5.361754302615776, 
       2.4355172211595244`}, {5.361754302615776, 2.4355172211595244`}}, {{
       5.361754302615776, 2.4355172211595244`}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.4355172211595244`}, {5.361754302615776, 
       2.4355172211595244`}}, {{5.361754302615776, 2.4355172211595244`}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}, {5.361754302615776, 2.4355172211595244`}, {
       5.361754302615776, 2.4355172211595244`}}, {{5.345012694915826, 
       2.509030743533846}, {5.361754302615776, 2.582544265908168}, {
       5.361754302615776, 2.582544265908168}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}}, {{
       5.345012694915826, 2.509030743533846}, {5.361754302615776, 
       2.582544265908168}, {5.361754302615776, 2.582544265908168}, {
       5.345012694915826, 2.509030743533846}, {5.345012694915826, 
       2.509030743533846}}, {{5.345012694915826, 2.509030743533846}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}, {5.345012694915826, 2.509030743533846}, {
       5.345012694915826, 2.509030743533846}}, {{5.345012694915826, 
       2.509030743533846}, {5.361754302615776, 2.582544265908168}, {
       5.361754302615776, 2.582544265908168}, {5.345012694915826, 
       2.509030743533846}, {5.345012694915826, 2.509030743533846}}, {{
       5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}}, {{5.361754302615776, 2.582544265908168}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}, {5.361754302615776, 2.582544265908168}, {
       5.361754302615776, 2.582544265908168}}, {{5.361754302615776, 
       2.582544265908168}, {5.429898798779611, 2.65605778828249}, {
       5.429898798779611, 2.65605778828249}, {5.361754302615776, 
       2.582544265908168}, {5.361754302615776, 2.582544265908168}}, {{
       5.361754302615776, 2.582544265908168}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}, {
       5.361754302615776, 2.582544265908168}, {5.361754302615776, 
       2.582544265908168}}, {{5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}, {5.684557110370965, 2.509030743533846}, {
       5.684557110370965, 2.509030743533846}}, {{5.684557110370965, 
       2.509030743533846}, {5.654964780555043, 2.4132591175407136`}, {
       5.654964780555043, 2.4132591175407136`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}}, {{
       5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}}, {{5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}, {5.684557110370965, 2.509030743533846}, {
       5.684557110370965, 2.509030743533846}}, {{5.654964780555043, 
       2.4132591175407136`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}}, {{
       5.654964780555043, 2.4132591175407136`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.654964780555043, 2.4132591175407136`}, {5.654964780555043, 
       2.4132591175407136`}}, {{5.654964780555043, 2.4132591175407136`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.654964780555043, 2.4132591175407136`}, {
       5.654964780555043, 2.4132591175407136`}}, {{5.654964780555043, 
       2.4132591175407136`}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.654964780555043, 
       2.4132591175407136`}, {5.654964780555043, 2.4132591175407136`}}, {{
       5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366, 
       2.339745595166392}, {5.527635624759366, 2.339745595166392}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}, {{5.5996710065071795`, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.527635624759366, 
       2.339745595166392}, {5.5996710065071795`, 2.3620036987852027`}, {
       5.5996710065071795`, 2.3620036987852027`}}, {{5.5996710065071795`, 
       2.3620036987852027`}, {5.527635624759366, 2.339745595166392}, {
       5.527635624759366, 2.339745595166392}, {5.5996710065071795`, 
       2.3620036987852027`}, {5.5996710065071795`, 2.3620036987852027`}}, {{
       5.5996710065071795`, 2.3620036987852027`}, {5.527635624759366, 
       2.339745595166392}, {5.527635624759366, 2.339745595166392}, {
       5.5996710065071795`, 2.3620036987852027`}, {5.5996710065071795`, 
       2.3620036987852027`}}, {{5.527635624759366, 2.339745595166392}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}, {5.527635624759366, 2.339745595166392}, {
       5.527635624759366, 2.339745595166392}}, {{5.527635624759366, 
       2.339745595166392}, {5.429898798779611, 2.3620036987852027`}, {
       5.429898798779611, 2.3620036987852027`}, {5.527635624759366, 
       2.339745595166392}, {5.527635624759366, 2.339745595166392}}, {{
       5.527635624759366, 2.339745595166392}, {5.429898798779611, 
       2.3620036987852027`}, {5.429898798779611, 2.3620036987852027`}, {
       5.527635624759366, 2.339745595166392}, {5.527635624759366, 
       2.339745595166392}}, {{5.527635624759366, 2.339745595166392}, {
       5.429898798779611, 2.3620036987852027`}, {5.429898798779611, 
       2.3620036987852027`}, {5.527635624759366, 2.339745595166392}, {
       5.527635624759366, 2.339745595166392}}, {{5.429898798779611, 
       2.65605778828249}, {5.527635624759366, 2.6783158919013004`}, {
       5.527635624759366, 2.6783158919013004`}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}}, {{
       5.429898798779611, 2.65605778828249}, {5.527635624759366, 
       2.6783158919013004`}, {5.527635624759366, 2.6783158919013004`}, {
       5.429898798779611, 2.65605778828249}, {5.429898798779611, 
       2.65605778828249}}, {{5.429898798779611, 2.65605778828249}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}, {5.429898798779611, 2.65605778828249}, {
       5.429898798779611, 2.65605778828249}}, {{5.429898798779611, 
       2.65605778828249}, {5.527635624759366, 2.6783158919013004`}, {
       5.527635624759366, 2.6783158919013004`}, {5.429898798779611, 
       2.65605778828249}, {5.429898798779611, 2.65605778828249}}, {{
       5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}}, {{5.527635624759366, 2.6783158919013004`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.527635624759366, 2.6783158919013004`}, {
       5.527635624759366, 2.6783158919013004`}}, {{5.527635624759366, 
       2.6783158919013004`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.527635624759366, 
       2.6783158919013004`}, {5.527635624759366, 2.6783158919013004`}}, {{
       5.527635624759366, 2.6783158919013004`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.527635624759366, 2.6783158919013004`}, {5.527635624759366, 
       2.6783158919013004`}}, {{5.5996710065071795`, 2.6560577882824896`}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}}, {{5.5996710065071795`, 
       2.6560577882824896`}, {5.654964780555043, 2.6048023695269786`}, {
       5.654964780555043, 2.6048023695269786`}, {5.5996710065071795`, 
       2.6560577882824896`}, {5.5996710065071795`, 2.6560577882824896`}}, {{
       5.5996710065071795`, 2.6560577882824896`}, {5.654964780555043, 
       2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}, {
       5.5996710065071795`, 2.6560577882824896`}, {5.5996710065071795`, 
       2.6560577882824896`}}, {{5.5996710065071795`, 2.6560577882824896`}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}, {5.5996710065071795`, 2.6560577882824896`}, {
       5.5996710065071795`, 2.6560577882824896`}}, {{5.654964780555043, 
       2.6048023695269786`}, {5.684557110370965, 2.509030743533846}, {
       5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}}, {{
       5.654964780555043, 2.6048023695269786`}, {5.684557110370965, 
       2.509030743533846}, {5.684557110370965, 2.509030743533846}, {
       5.654964780555043, 2.6048023695269786`}, {5.654964780555043, 
       2.6048023695269786`}}, {{5.654964780555043, 2.6048023695269786`}, {
       5.684557110370965, 2.509030743533846}, {5.684557110370965, 
       2.509030743533846}, {5.654964780555043, 2.6048023695269786`}, {
       5.654964780555043, 2.6048023695269786`}}, {{5.654964780555043, 
       2.6048023695269786`}, {5.684557110370965, 2.509030743533846}, {
       5.684557110370965, 2.509030743533846}, {5.654964780555043, 
       2.6048023695269786`}, {5.654964780555043, 2.6048023695269786`}}, {{
       5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.293893225237583, 
       2.9899887628063078`}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}, {{5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}}, {{5.61082101461415, 
       2.9899887628063078`}, {5.583199792635015, 2.900596364258633}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802, 
       2.8319794850672957`}, {5.373125172581725, 2.8527550044236323`}, {
       5.373125172581725, 2.8527550044236323`}, {5.464351871618802, 
       2.8319794850672957`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.583199792635015, 2.900596364258633}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}}, {{
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}, {{5.373125172581725, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.583199792635015, 3.0793811613539823`}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}, {5.583199792635015, 3.0793811613539823`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.373125172581725, 3.1272225211889833`}, {
       5.373125172581725, 3.1272225211889833`}}, {{5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}}, {{
       5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}, {{5.373125172581725, 2.8527550044236323`}, {
       5.309519695523783, 2.92137188361497}, {5.309519695523783, 
       2.92137188361497}, {5.373125172581725, 2.8527550044236323`}, {
       5.373125172581725, 2.8527550044236323`}}, {{5.373125172581725, 
       2.8527550044236323`}, {5.309519695523783, 2.92137188361497}, {
       5.309519695523783, 2.92137188361497}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}}, {{
       5.373125172581725, 2.8527550044236323`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}}, {{5.309519695523783, 2.92137188361497}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.309519695523783, 2.92137188361497}, {
       5.309519695523783, 2.92137188361497}}, {{5.309519695523783, 
       2.92137188361497}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}, {5.309519695523783, 
       2.92137188361497}, {5.309519695523783, 2.92137188361497}}, {{
       5.309519695523783, 2.92137188361497}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 2.92137188361497}, {5.309519695523783, 
       2.92137188361497}}, {{5.309519695523783, 2.92137188361497}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}, {5.309519695523783, 2.92137188361497}, {
       5.309519695523783, 2.92137188361497}}, {{5.293893225237583, 
       2.9899887628063078`}, {5.309519695523783, 3.0586056419976457`}, {
       5.309519695523783, 3.0586056419976457`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}}, {{
       5.293893225237583, 2.9899887628063078`}, {5.309519695523783, 
       3.0586056419976457`}, {5.309519695523783, 3.0586056419976457`}, {
       5.293893225237583, 2.9899887628063078`}, {5.293893225237583, 
       2.9899887628063078`}}, {{5.293893225237583, 2.9899887628063078`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}, {5.293893225237583, 2.9899887628063078`}, {
       5.293893225237583, 2.9899887628063078`}}, {{5.293893225237583, 
       2.9899887628063078`}, {5.309519695523783, 3.0586056419976457`}, {
       5.309519695523783, 3.0586056419976457`}, {5.293893225237583, 
       2.9899887628063078`}, {5.293893225237583, 2.9899887628063078`}}, {{
       5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}}, {{5.309519695523783, 3.0586056419976457`}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}, {5.309519695523783, 3.0586056419976457`}, {
       5.309519695523783, 3.0586056419976457`}}, {{5.309519695523783, 
       3.0586056419976457`}, {5.373125172581725, 3.1272225211889833`}, {
       5.373125172581725, 3.1272225211889833`}, {5.309519695523783, 
       3.0586056419976457`}, {5.309519695523783, 3.0586056419976457`}}, {{
       5.309519695523783, 3.0586056419976457`}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}, {
       5.309519695523783, 3.0586056419976457`}, {5.309519695523783, 
       3.0586056419976457`}}, {{5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}, {5.61082101461415, 2.9899887628063078`}, {
       5.61082101461415, 2.9899887628063078`}}, {{5.61082101461415, 
       2.9899887628063078`}, {5.583199792635015, 2.900596364258633}, {
       5.583199792635015, 2.900596364258633}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}}, {{
       5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}}, {{5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}, {5.61082101461415, 2.9899887628063078`}, {
       5.61082101461415, 2.9899887628063078`}}, {{5.583199792635015, 
       2.900596364258633}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}}, {{
       5.583199792635015, 2.900596364258633}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.583199792635015, 2.900596364258633}, {5.583199792635015, 
       2.900596364258633}}, {{5.583199792635015, 2.900596364258633}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.583199792635015, 2.900596364258633}, {
       5.583199792635015, 2.900596364258633}}, {{5.583199792635015, 
       2.900596364258633}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.583199792635015, 
       2.900596364258633}, {5.583199792635015, 2.900596364258633}}, {{
       5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802, 
       2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}, {{5.5315890672700085`, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.464351871618802, 
       2.8319794850672957`}, {5.5315890672700085`, 2.8527550044236323`}, {
       5.5315890672700085`, 2.8527550044236323`}}, {{5.5315890672700085`, 
       2.8527550044236323`}, {5.464351871618802, 2.8319794850672957`}, {
       5.464351871618802, 2.8319794850672957`}, {5.5315890672700085`, 
       2.8527550044236323`}, {5.5315890672700085`, 2.8527550044236323`}}, {{
       5.5315890672700085`, 2.8527550044236323`}, {5.464351871618802, 
       2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}, {
       5.5315890672700085`, 2.8527550044236323`}, {5.5315890672700085`, 
       2.8527550044236323`}}, {{5.464351871618802, 2.8319794850672957`}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}, {5.464351871618802, 2.8319794850672957`}, {
       5.464351871618802, 2.8319794850672957`}}, {{5.464351871618802, 
       2.8319794850672957`}, {5.373125172581725, 2.8527550044236323`}, {
       5.373125172581725, 2.8527550044236323`}, {5.464351871618802, 
       2.8319794850672957`}, {5.464351871618802, 2.8319794850672957`}}, {{
       5.464351871618802, 2.8319794850672957`}, {5.373125172581725, 
       2.8527550044236323`}, {5.373125172581725, 2.8527550044236323`}, {
       5.464351871618802, 2.8319794850672957`}, {5.464351871618802, 
       2.8319794850672957`}}, {{5.464351871618802, 2.8319794850672957`}, {
       5.373125172581725, 2.8527550044236323`}, {5.373125172581725, 
       2.8527550044236323`}, {5.464351871618802, 2.8319794850672957`}, {
       5.464351871618802, 2.8319794850672957`}}, {{5.373125172581725, 
       3.1272225211889833`}, {5.464351871618802, 3.14799804054532}, {
       5.464351871618802, 3.14799804054532}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}}, {{
       5.373125172581725, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.464351871618802, 3.14799804054532}, {
       5.373125172581725, 3.1272225211889833`}, {5.373125172581725, 
       3.1272225211889833`}}, {{5.373125172581725, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}, {5.373125172581725, 3.1272225211889833`}, {
       5.373125172581725, 3.1272225211889833`}}, {{5.373125172581725, 
       3.1272225211889833`}, {5.464351871618802, 3.14799804054532}, {
       5.464351871618802, 3.14799804054532}, {5.373125172581725, 
       3.1272225211889833`}, {5.373125172581725, 3.1272225211889833`}}, {{
       5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}}, {{5.464351871618802, 3.14799804054532}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.464351871618802, 3.14799804054532}, {
       5.464351871618802, 3.14799804054532}}, {{5.464351871618802, 
       3.14799804054532}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.464351871618802, 
       3.14799804054532}, {5.464351871618802, 3.14799804054532}}, {{
       5.464351871618802, 3.14799804054532}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.464351871618802, 3.14799804054532}, {5.464351871618802, 
       3.14799804054532}}, {{5.5315890672700085`, 3.1272225211889833`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}}, {{5.5315890672700085`, 
       3.1272225211889833`}, {5.583199792635015, 3.0793811613539823`}, {
       5.583199792635015, 3.0793811613539823`}, {5.5315890672700085`, 
       3.1272225211889833`}, {5.5315890672700085`, 3.1272225211889833`}}, {{
       5.5315890672700085`, 3.1272225211889833`}, {5.583199792635015, 
       3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}, {
       5.5315890672700085`, 3.1272225211889833`}, {5.5315890672700085`, 
       3.1272225211889833`}}, {{5.5315890672700085`, 3.1272225211889833`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}, {5.5315890672700085`, 3.1272225211889833`}, {
       5.5315890672700085`, 3.1272225211889833`}}, {{5.583199792635015, 
       3.0793811613539823`}, {5.61082101461415, 2.9899887628063078`}, {
       5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}}, {{
       5.583199792635015, 3.0793811613539823`}, {5.61082101461415, 
       2.9899887628063078`}, {5.61082101461415, 2.9899887628063078`}, {
       5.583199792635015, 3.0793811613539823`}, {5.583199792635015, 
       3.0793811613539823`}}, {{5.583199792635015, 3.0793811613539823`}, {
       5.61082101461415, 2.9899887628063078`}, {5.61082101461415, 
       2.9899887628063078`}, {5.583199792635015, 3.0793811613539823`}, {
       5.583199792635015, 3.0793811613539823`}}, {{5.583199792635015, 
       3.0793811613539823`}, {5.61082101461415, 2.9899887628063078`}, {
       5.61082101461415, 2.9899887628063078`}, {5.583199792635015, 
       3.0793811613539823`}, {5.583199792635015, 3.0793811613539823`}}, {{
       5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.317162575190067, 
       3.526795912348139}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}, {{5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}}, {{5.66680387576051, 
       3.526795912348139}, {5.636331571658912, 3.428176367022679}, {
       5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.404572900332678, 3.375396788095022}, {
       5.404572900332678, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.579393550617899, 3.375396788095022}, {
       5.636331571658912, 3.428176367022679}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}}, {{
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}, {{5.404572900332678, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.636331571658912, 3.6254154576735993`}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}, {5.636331571658912, 3.6254154576735993`}, {
       5.579393550617899, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.404572900332678, 3.6781950366012564`}, {
       5.404572900332678, 3.6781950366012564`}}, {{5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}}, {{
       5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}, {{5.404572900332678, 3.375396788095022}, {
       5.334402020821957, 3.451096350221581}, {5.334402020821957, 
       3.451096350221581}, {5.404572900332678, 3.375396788095022}, {
       5.404572900332678, 3.375396788095022}}, {{5.404572900332678, 
       3.375396788095022}, {5.334402020821957, 3.451096350221581}, {
       5.334402020821957, 3.451096350221581}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}}, {{
       5.404572900332678, 3.375396788095022}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}}, {{5.334402020821957, 3.451096350221581}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.334402020821957, 3.451096350221581}, {
       5.334402020821957, 3.451096350221581}}, {{5.334402020821957, 
       3.451096350221581}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}, {5.334402020821957, 
       3.451096350221581}, {5.334402020821957, 3.451096350221581}}, {{
       5.334402020821957, 3.451096350221581}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.451096350221581}, {5.334402020821957, 
       3.451096350221581}}, {{5.334402020821957, 3.451096350221581}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}, {5.334402020821957, 3.451096350221581}, {
       5.334402020821957, 3.451096350221581}}, {{5.317162575190067, 
       3.526795912348139}, {5.334402020821957, 3.6024954744746975`}, {
       5.334402020821957, 3.6024954744746975`}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}}, {{
       5.317162575190067, 3.526795912348139}, {5.334402020821957, 
       3.6024954744746975`}, {5.334402020821957, 3.6024954744746975`}, {
       5.317162575190067, 3.526795912348139}, {5.317162575190067, 
       3.526795912348139}}, {{5.317162575190067, 3.526795912348139}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}, {5.317162575190067, 3.526795912348139}, {
       5.317162575190067, 3.526795912348139}}, {{5.317162575190067, 
       3.526795912348139}, {5.334402020821957, 3.6024954744746975`}, {
       5.334402020821957, 3.6024954744746975`}, {5.317162575190067, 
       3.526795912348139}, {5.317162575190067, 3.526795912348139}}, {{
       5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}}, {{5.334402020821957, 3.6024954744746975`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}, {5.334402020821957, 3.6024954744746975`}, {
       5.334402020821957, 3.6024954744746975`}}, {{5.334402020821957, 
       3.6024954744746975`}, {5.404572900332678, 3.6781950366012564`}, {
       5.404572900332678, 3.6781950366012564`}, {5.334402020821957, 
       3.6024954744746975`}, {5.334402020821957, 3.6024954744746975`}}, {{
       5.334402020821957, 3.6024954744746975`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}, {
       5.334402020821957, 3.6024954744746975`}, {5.334402020821957, 
       3.6024954744746975`}}, {{5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}, {5.66680387576051, 3.526795912348139}, {
       5.66680387576051, 3.526795912348139}}, {{5.66680387576051, 
       3.526795912348139}, {5.636331571658912, 3.428176367022679}, {
       5.636331571658912, 3.428176367022679}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}}, {{
       5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}}, {{5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}, {5.66680387576051, 3.526795912348139}, {
       5.66680387576051, 3.526795912348139}}, {{5.636331571658912, 
       3.428176367022679}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}}, {{
       5.636331571658912, 3.428176367022679}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}, {
       5.636331571658912, 3.428176367022679}, {5.636331571658912, 
       3.428176367022679}}, {{5.636331571658912, 3.428176367022679}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}, {5.636331571658912, 3.428176367022679}, {
       5.636331571658912, 3.428176367022679}}, {{5.636331571658912, 
       3.428176367022679}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}, {5.636331571658912, 
       3.428176367022679}, {5.636331571658912, 3.428176367022679}}, {{
       5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}, {{5.579393550617899, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.505216083944996, 
       3.3524768048961207`}, {5.579393550617899, 3.375396788095022}, {
       5.579393550617899, 3.375396788095022}}, {{5.579393550617899, 
       3.375396788095022}, {5.505216083944996, 3.3524768048961207`}, {
       5.505216083944996, 3.3524768048961207`}, {5.579393550617899, 
       3.375396788095022}, {5.579393550617899, 3.375396788095022}}, {{
       5.579393550617899, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}, {
       5.579393550617899, 3.375396788095022}, {5.579393550617899, 
       3.375396788095022}}, {{5.505216083944996, 3.3524768048961207`}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}, {5.505216083944996, 3.3524768048961207`}, {
       5.505216083944996, 3.3524768048961207`}}, {{5.505216083944996, 
       3.3524768048961207`}, {5.404572900332678, 3.375396788095022}, {
       5.404572900332678, 3.375396788095022}, {5.505216083944996, 
       3.3524768048961207`}, {5.505216083944996, 3.3524768048961207`}}, {{
       5.505216083944996, 3.3524768048961207`}, {5.404572900332678, 
       3.375396788095022}, {5.404572900332678, 3.375396788095022}, {
       5.505216083944996, 3.3524768048961207`}, {5.505216083944996, 
       3.3524768048961207`}}, {{5.505216083944996, 3.3524768048961207`}, {
       5.404572900332678, 3.375396788095022}, {5.404572900332678, 
       3.375396788095022}, {5.505216083944996, 3.3524768048961207`}, {
       5.505216083944996, 3.3524768048961207`}}, {{5.404572900332678, 
       3.6781950366012564`}, {5.505216083944996, 3.7011150198001577`}, {
       5.505216083944996, 3.7011150198001577`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}}, {{
       5.404572900332678, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.505216083944996, 3.7011150198001577`}, {
       5.404572900332678, 3.6781950366012564`}, {5.404572900332678, 
       3.6781950366012564`}}, {{5.404572900332678, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}, {5.404572900332678, 3.6781950366012564`}, {
       5.404572900332678, 3.6781950366012564`}}, {{5.404572900332678, 
       3.6781950366012564`}, {5.505216083944996, 3.7011150198001577`}, {
       5.505216083944996, 3.7011150198001577`}, {5.404572900332678, 
       3.6781950366012564`}, {5.404572900332678, 3.6781950366012564`}}, {{
       5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}}, {{5.505216083944996, 3.7011150198001577`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}, {5.505216083944996, 3.7011150198001577`}, {
       5.505216083944996, 3.7011150198001577`}}, {{5.505216083944996, 
       3.7011150198001577`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}, {5.505216083944996, 
       3.7011150198001577`}, {5.505216083944996, 3.7011150198001577`}}, {{
       5.505216083944996, 3.7011150198001577`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}, {
       5.505216083944996, 3.7011150198001577`}, {5.505216083944996, 
       3.7011150198001577`}}, {{5.579393550617899, 3.6781950366012564`}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}}, {{5.579393550617899, 
       3.6781950366012564`}, {5.636331571658912, 3.6254154576735993`}, {
       5.636331571658912, 3.6254154576735993`}, {5.579393550617899, 
       3.6781950366012564`}, {5.579393550617899, 3.6781950366012564`}}, {{
       5.579393550617899, 3.6781950366012564`}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}, {
       5.579393550617899, 3.6781950366012564`}, {5.579393550617899, 
       3.6781950366012564`}}, {{5.579393550617899, 3.6781950366012564`}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}, {5.579393550617899, 3.6781950366012564`}, {
       5.579393550617899, 3.6781950366012564`}}, {{5.636331571658912, 
       3.6254154576735993`}, {5.66680387576051, 3.526795912348139}, {
       5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}}, {{
       5.636331571658912, 3.6254154576735993`}, {5.66680387576051, 
       3.526795912348139}, {5.66680387576051, 3.526795912348139}, {
       5.636331571658912, 3.6254154576735993`}, {5.636331571658912, 
       3.6254154576735993`}}, {{5.636331571658912, 3.6254154576735993`}, {
       5.66680387576051, 3.526795912348139}, {5.66680387576051, 
       3.526795912348139}, {5.636331571658912, 3.6254154576735993`}, {
       5.636331571658912, 3.6254154576735993`}}, {{5.636331571658912, 
       3.6254154576735993`}, {5.66680387576051, 3.526795912348139}, {
       5.66680387576051, 3.526795912348139}, {5.636331571658912, 
       3.6254154576735993`}, {5.636331571658912, 3.6254154576735993`}}, {{
       5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}, {{
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}, {{
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}, {{
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}, {{
       5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}, {{
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}, {{
       5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}, {{
       5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}, {{
       5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}, {{
       5.6690993172383735`, -4.398327284888616}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}}, {{
       5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}, {{
       5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}, {{
       5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}, {{
       5.600442607900408, -4.324261192655293}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.324261192655293}, {
       5.600442607900408, -4.324261192655293}}, {{
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}, {{
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}, {{
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}, {{
       5.583575160660909, -4.250195100421971}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}, {
       5.583575160660909, -4.250195100421971}, {
       5.583575160660909, -4.250195100421971}}, {{
       5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}, {{
       5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}, {{
       5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}, {{
       5.600442607900408, -4.176129008188648}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.600442607900408, -4.176129008188648}, {
       5.600442607900408, -4.176129008188648}}, {{
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}, {{
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}, {{
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}, {{
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}}, {{
       5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}, {{
       5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}, {{
       5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}, {{
       5.895857024206652, -4.346686600965555}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}, {
       5.895857024206652, -4.346686600965555}, {
       5.895857024206652, -4.346686600965555}}, {{
       5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}, {{
       5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}, {{
       5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}, {{
       5.840147630393304, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}, {
       5.840147630393304, -4.398327284888616}, {
       5.840147630393304, -4.398327284888616}}, {{
       5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}, {{
       5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}, {{
       5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}, {{
       5.767570789340455, -4.420752693198877}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.6690993172383735`, -4.398327284888616}, {
       5.767570789340455, -4.420752693198877}, {
       5.767570789340455, -4.420752693198877}}, {{
       5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}, {{
       5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}, {{
       5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}, {{
       5.6690993172383735`, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}, {
       5.6690993172383735`, -4.102062915955326}, {
       5.6690993172383735`, -4.102062915955326}}, {{
       5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}, {{
       5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}, {{
       5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}, {{
       5.767570789340455, -4.079637507645065}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}, {
       5.767570789340455, -4.079637507645065}, {
       5.767570789340455, -4.079637507645065}}, {{
       5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}, {{
       5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}, {{
       5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}, {{
       5.840147630393304, -4.102062915955326}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}, {
       5.840147630393304, -4.102062915955326}, {
       5.840147630393304, -4.102062915955326}}, {{
       5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}, {{
       5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}, {{
       5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}, {{
       5.895857024206652, -4.153703599878387}, {
       5.925671786970768, -4.250195100421971}, {
       5.925671786970768, -4.250195100421971}, {
       5.895857024206652, -4.153703599878387}, {
       5.895857024206652, -4.153703599878387}}, {{
       5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.67483065003865, -3.6284336430882127`}, {
       5.67483065003865, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}, {{
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}, {{
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}, {{
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}, {{
       5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}, {{
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}, {{
       5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}, {{
       5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}, {{
       5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}, {{
       5.67483065003865, -3.898832294846215}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.67483065003865, -3.898832294846215}, {
       5.67483065003865, -3.898832294846215}}, {{
       5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}, {{
       5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}, {{
       5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}, {{
       5.612168097312618, -3.8312326319067145`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.8312326319067145`}, {
       5.612168097312618, -3.8312326319067145`}}, {{
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}, {{
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}, {{
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}, {{
       5.596773282848153, -3.763632968967214}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.596773282848153, -3.763632968967214}, {
       5.596773282848153, -3.763632968967214}}, {{
       5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}, {{
       5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}, {{
       5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}, {{
       5.612168097312618, -3.6960333060277133`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.612168097312618, -3.6960333060277133`}, {
       5.612168097312618, -3.6960333060277133`}}, {{
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}, {{
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}, {{
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}, {{
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}}, {{
       5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}, {{
       5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}, {{
       5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}, {{
       5.881791002580285, -3.8517001629636898`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}, {
       5.881791002580285, -3.8517001629636898`}, {
       5.881791002580285, -3.8517001629636898`}}, {{
       5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}, {{
       5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}, {{
       5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}, {{
       5.830945384419644, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.830945384419644, -3.898832294846215}, {
       5.830945384419644, -3.898832294846215}}, {{
       5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}, {{
       5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}, {{
       5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}, {{
       5.764704951794539, -3.9192998259031904`}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.6748306500386505`, -3.898832294846215}, {
       5.764704951794539, -3.9192998259031904`}, {
       5.764704951794539, -3.9192998259031904`}}, {{
       5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}, {{
       5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}, {{
       5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}, {{
       5.6748306500386505`, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.6748306500386505`, -3.6284336430882127`}, {
       5.6748306500386505`, -3.6284336430882127`}}, {{
       5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}, {{
       5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}, {{
       5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}, {{
       5.764704951794539, -3.6079661120312374`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.764704951794539, -3.6079661120312374`}, {
       5.764704951794539, -3.6079661120312374`}}, {{
       5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}, {{
       5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}, {{
       5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}, {{
       5.830945384419644, -3.6284336430882127`}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}, {
       5.830945384419644, -3.6284336430882127`}, {
       5.830945384419644, -3.6284336430882127`}}, {{
       5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}, {{
       5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}, {{
       5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}, {{
       5.881791002580285, -3.675565774970738}, {
       5.909002751610142, -3.763632968967214}, {
       5.909002751610142, -3.763632968967214}, {
       5.881791002580285, -3.675565774970738}, {
       5.881791002580285, -3.675565774970738}}, {{
       5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}, {{
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}, {{
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}, {{
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}, {{
       5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}, {{
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}, {{
       5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}, {{
       5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}, {{
       5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}, {{
       5.630881358007497, -3.4113212646150233`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}}, {{
       5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}, {{
       5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}, {{
       5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}, {{
       5.56662657512903, -3.342003921546893}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.342003921546893}, {
       5.56662657512903, -3.342003921546893}}, {{
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}, {{
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}, {{
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}, {{
       5.550840584647708, -3.2726865784787624`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}, {
       5.550840584647708, -3.2726865784787624`}, {
       5.550840584647708, -3.2726865784787624`}}, {{
       5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}, {{
       5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}, {{
       5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}, {{
       5.56662657512903, -3.203369235410632}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.56662657512903, -3.203369235410632}, {
       5.56662657512903, -3.203369235410632}}, {{
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}, {{
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}, {{
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}, {{
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}}, {{
       5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}, {{
       5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}, {{
       5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}, {{
       5.8431004895062575`, -3.3629915243002335`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.8431004895062575`, -3.3629915243002335`}, {
       5.8431004895062575`, -3.3629915243002335`}}, {{
       5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}, {{
       5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}, {{
       5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}, {{
       5.790962904727077, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}, {
       5.790962904727077, -3.4113212646150233`}, {
       5.790962904727077, -3.4113212646150233`}}, {{
       5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}, {{
       5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}, {{
       5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}, {{
       5.723039329466573, -3.432308867368364}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.630881358007497, -3.4113212646150233`}, {
       5.723039329466573, -3.432308867368364}, {
       5.723039329466573, -3.432308867368364}}, {{
       5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}, {{
       5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}, {{
       5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}, {{
       5.630881358007497, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.630881358007497, -3.1340518923425016`}, {
       5.630881358007497, -3.1340518923425016`}}, {{
       5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}, {{
       5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}, {{
       5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}, {{
       5.723039329466573, -3.1130642895891607`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.723039329466573, -3.1130642895891607`}, {
       5.723039329466573, -3.1130642895891607`}}, {{
       5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}, {{
       5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}, {{
       5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}, {{
       5.790962904727077, -3.1340518923425016`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.790962904727077, -3.1340518923425016`}, {
       5.790962904727077, -3.1340518923425016`}}, {{
       5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}, {{
       5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}, {{
       5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}, {{
       5.8431004895062575`, -3.1823816326572913`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.871003678086866, -3.2726865784787624`}, {
       5.8431004895062575`, -3.1823816326572913`}, {
       5.8431004895062575`, -3.1823816326572913`}}, {{
       5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}, {{
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}, {{
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}, {{
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}, {{
       5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}, {{
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}, {{
       5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}, {{
       5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}, {{
       5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}, {{
       5.635097904009415, -2.8967159542837866`}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}}, {{
       5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}, {{
       5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}, {{
       5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}, {{
       5.578229517131511, -2.835366972832822}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.835366972832822}, {
       5.578229517131511, -2.835366972832822}}, {{
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}, {{
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}, {{
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}, {{
       5.5642582020989675`, -2.774017991381857}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.5642582020989675`, -2.774017991381857}, {
       5.5642582020989675`, -2.774017991381857}}, {{
       5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}, {{
       5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}, {{
       5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}, {{
       5.578229517131511, -2.7126690099308917`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}, {
       5.578229517131511, -2.7126690099308917`}, {
       5.578229517131511, -2.7126690099308917`}}, {{
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}, {{
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}, {{
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}, {{
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}}, {{
       5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}, {{
       5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}, {{
       5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}, {{
       5.822921426746875, -2.853941949815846}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.822921426746875, -2.853941949815846}, {
       5.822921426746875, -2.853941949815846}}, {{
       5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}, {{
       5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}, {{
       5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}, {{
       5.7767773078303115`, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}, {
       5.7767773078303115`, -2.8967159542837866`}, {
       5.7767773078303115`, -2.8967159542837866`}}, {{
       5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}, {{
       5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}, {{
       5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}, {{
       5.716661873881203, -2.915290931266811}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.635097904009415, -2.8967159542837866`}, {
       5.716661873881203, -2.915290931266811}, {
       5.716661873881203, -2.915290931266811}}, {{
       5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}, {{
       5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}, {{
       5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}, {{
       5.635097904009415, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.635097904009415, -2.651320028479927}, {
       5.635097904009415, -2.651320028479927}}, {{
       5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}, {{
       5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}, {{
       5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}, {{
       5.716661873881203, -2.6327450514969026`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.716661873881203, -2.6327450514969026`}, {
       5.716661873881203, -2.6327450514969026`}}, {{
       5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}, {{
       5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}, {{
       5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}, {{
       5.7767773078303115`, -2.651320028479927}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.7767773078303115`, -2.651320028479927}, {
       5.7767773078303115`, -2.651320028479927}}, {{
       5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}, {{
       5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}, {{
       5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}, {{
       5.822921426746875, -2.6940940329478678`}, {
       5.847617009740759, -2.774017991381857}, {
       5.847617009740759, -2.774017991381857}, {
       5.822921426746875, -2.6940940329478678`}, {
       5.822921426746875, -2.6940940329478678`}}, {{
       5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}, {{
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}, {{
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}, {{
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}, {{
       5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}, {{
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}, {{
       5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}, {{
       5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}, {{
       5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}, {{
       5.639744246180363, -2.405503639510272}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}}, {{
       5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}, {{
       5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}, {{
       5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}, {{
       5.5761642854219025`, -2.336914287018204}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.336914287018204}, {
       5.5761642854219025`, -2.336914287018204}}, {{
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}, {{
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}, {{
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}, {{
       5.560544083930687, -2.268324934526136}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.560544083930687, -2.268324934526136}, {
       5.560544083930687, -2.268324934526136}}, {{
       5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}, {{
       5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}, {{
       5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}, {{
       5.5761642854219025`, -2.1997355820340676`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}, {
       5.5761642854219025`, -2.1997355820340676`}, {
       5.5761642854219025`, -2.1997355820340676`}}, {{
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}, {{
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}, {{
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}, {{
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}}, {{
       5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}, {{
       5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}, {{
       5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}, {{
       5.849734591621362, -2.3576814719606145`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}, {
       5.849734591621362, -2.3576814719606145`}, {
       5.849734591621362, -2.3576814719606145`}}, {{
       5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}, {{
       5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}, {{
       5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}, {{
       5.798144570679713, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.798144570679713, -2.405503639510272}, {
       5.798144570679713, -2.405503639510272}}, {{
       5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}, {{
       5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}, {{
       5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}, {{
       5.7309343482468496`, -2.4262708244526823`}, {
       5.639744246180363, -2.405503639510272}, {
       5.639744246180363, -2.405503639510272}, {
       5.7309343482468496`, -2.4262708244526823`}, {
       5.7309343482468496`, -2.4262708244526823`}}, {{
       5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}, {{
       5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}, {{
       5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}, {{
       5.639744246180363, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.639744246180363, -2.131146229542}, {
       5.639744246180363, -2.131146229542}}, {{
       5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}, {{
       5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}, {{
       5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}, {{
       5.7309343482468496`, -2.1103790445995894`}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}, {
       5.7309343482468496`, -2.1103790445995894`}, {
       5.7309343482468496`, -2.1103790445995894`}}, {{
       5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}, {{
       5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}, {{
       5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}, {{
       5.798144570679713, -2.131146229542}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}, {
       5.798144570679713, -2.131146229542}, {
       5.798144570679713, -2.131146229542}}, {{
       5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}, {{
       5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}, {{
       5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}, {{
       5.849734591621362, -2.178968397091657}, {
       5.877344732929388, -2.268324934526136}, {
       5.877344732929388, -2.268324934526136}, {
       5.849734591621362, -2.178968397091657}, {
       5.849734591621362, -2.178968397091657}}, {{
       5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954885`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}, {{
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}, {{
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}, {{
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}, {{
       5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}, {{
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}, {{
       5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}, {{
       5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}, {{
       5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}, {{
       5.68489328687736, -1.8686118234835787`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}}, {{
       5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}, {{
       5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}, {{
       5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}, {{
       5.62145854480981, -1.8001791312954882`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.8001791312954882`}, {
       5.62145854480981, -1.8001791312954882`}}, {{
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}, {{
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}, {{
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}, {{
       5.60587402036503, -1.731746439107398}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.62145854480981, -1.6633137469193078`}, {
       5.60587402036503, -1.731746439107398}, {
       5.60587402036503, -1.731746439107398}}, {{
       5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}, {{
       5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}, {{
       5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}, {{
       5.62145854480981, -1.6633137469193076`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.62145854480981, -1.6633137469193076`}, {
       5.62145854480981, -1.6633137469193076`}}, {{
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}, {{
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}, {{
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}, {{
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}}, {{
       5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}, {{
       5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}, {{
       5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}, {{
       5.8944040075638755`, -1.8208988833144546`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.8944040075638755`, -1.8208988833144546`}, {
       5.8944040075638755`, -1.8208988833144546`}}, {{
       5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}, {{
       5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}, {{
       5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}, {{
       5.842931819902018, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}, {
       5.842931819902018, -1.8686118234835787`}, {
       5.842931819902018, -1.8686118234835787`}}, {{
       5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}, {{
       5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}, {{
       5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}, {{
       5.775875107795382, -1.889331575502545}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.68489328687736, -1.8686118234835787`}, {
       5.775875107795382, -1.889331575502545}, {
       5.775875107795382, -1.889331575502545}}, {{
       5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}, {{
       5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}, {{
       5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}, {{
       5.68489328687736, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}, {
       5.68489328687736, -1.5948810547312173`}, {
       5.68489328687736, -1.5948810547312173`}}, {{
       5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}, {{
       5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}, {{
       5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}, {{
       5.775875107795382, -1.574161302712251}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.775875107795382, -1.574161302712251}, {
       5.775875107795382, -1.574161302712251}}, {{
       5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}, {{
       5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}, {{
       5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}, {{
       5.842931819902018, -1.5948810547312173`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.842931819902018, -1.5948810547312173`}, {
       5.842931819902018, -1.5948810547312173`}}, {{
       5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}, {{
       5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}, {{
       5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}, {{
       5.8944040075638755`, -1.6425939949003414`}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.9219510864143485`, -1.731746439107398}, {
       5.8944040075638755`, -1.6425939949003414`}, {
       5.8944040075638755`, -1.6425939949003414`}}, {{
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}, {{
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}, {{
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}, {{
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}, {{
       5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}, {{
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}, {{
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}, {{
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}, {{
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}, {{
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}}, {{
       5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}, {{
       5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}, {{
       5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}, {{
       5.6161964381527225`, -1.2714926803391453`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.2714926803391453`}, {
       5.6161964381527225`, -1.2714926803391453`}}, {{
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}, {{
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}, {{
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}, {{
       5.600495572772051, -1.202549127297843}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.600495572772051, -1.202549127297843}, {
       5.600495572772051, -1.202549127297843}}, {{
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}, {{
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}, {{
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}, {{
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6161964381527225`, -1.1336055742565407`}, {
       5.6161964381527225`, -1.1336055742565407`}}, {{
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}, {{
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}, {{
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}, {{
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}}, {{
       5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}, {{
       5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}, {{
       5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}, {{
       5.891179481886353, -1.2923671085787352`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.891179481886353, -1.2923671085787352`}, {
       5.891179481886353, -1.2923671085787352`}}, {{
       5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}, {{
       5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}, {{
       5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}, {{
       5.839323046215761, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.839323046215761, -1.3404362333804476`}, {
       5.839323046215761, -1.3404362333804476`}}, {{
       5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}, {{
       5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}, {{
       5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}, {{
       5.771765745164498, -1.3613106616200374`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.6801047305866215`, -1.3404362333804476`}, {
       5.771765745164498, -1.3613106616200374`}, {
       5.771765745164498, -1.3613106616200374`}}, {{
       5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}, {{
       5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}, {{
       5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}, {{
       5.6801047305866215`, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.6801047305866215`, -1.0646620212152385`}, {
       5.6801047305866215`, -1.0646620212152385`}}, {{
       5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}, {{
       5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}, {{
       5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}, {{
       5.771765745164498, -1.0437875929756486`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.771765745164498, -1.0437875929756486`}, {
       5.771765745164498, -1.0437875929756486`}}, {{
       5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}, {{
       5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}, {{
       5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}, {{
       5.839323046215761, -1.0646620212152385`}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}, {
       5.839323046215761, -1.0646620212152385`}, {
       5.839323046215761, -1.0646620212152385`}}, {{
       5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}, {{
       5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}, {{
       5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}, {{
       5.891179481886353, -1.112731146016951}, {
       5.918932204030332, -1.202549127297843}, {
       5.918932204030332, -1.202549127297843}, {
       5.891179481886353, -1.112731146016951}, {
       5.891179481886353, -1.112731146016951}}, {{
       5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}, {{
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}, {{
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}, {{
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}, {{
       5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}, {{
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}, {{
       5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}, {{
       5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}, {{
       5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}, {{
       5.689656821690153, -0.8524472368964864}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}}, {{
       5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}, {{
       5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}, {{
       5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}, {{
       5.62886585103622, -0.7868666158206444}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.7868666158206444}, {
       5.62886585103622, -0.7868666158206444}}, {{
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}, {{
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}, {{
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}, {{
       5.613930843226632, -0.7212859947448025}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}, {
       5.613930843226632, -0.7212859947448025}, {
       5.613930843226632, -0.7212859947448025}}, {{
       5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}, {{
       5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}, {{
       5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}, {{
       5.62886585103622, -0.6557053736689605}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}, {
       5.62886585103622, -0.6557053736689605}, {
       5.62886585103622, -0.6557053736689605}}, {{
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}, {{
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}, {{
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}, {{
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}}, {{
       5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}, {{
       5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}, {{
       5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}, {{
       5.89043575856004, -0.8067228301897428}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}, {
       5.89043575856004, -0.8067228301897428}, {
       5.89043575856004, -0.8067228301897428}}, {{
       5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}, {{
       5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}, {{
       5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}, {{
       5.841108778617193, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.841108778617193, -0.8524472368964864}, {
       5.841108778617193, -0.8524472368964864}}, {{
       5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}, {{
       5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}, {{
       5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}, {{
       5.7768467908647585`, -0.8723034512655847}, {
       5.689656821690153, -0.8524472368964864}, {
       5.689656821690153, -0.8524472368964864}, {
       5.7768467908647585`, -0.8723034512655847}, {
       5.7768467908647585`, -0.8723034512655847}}, {{
       5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}, {{
       5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}, {{
       5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}, {{
       5.689656821690153, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.689656821690153, -0.5901247525931186}, {
       5.689656821690153, -0.5901247525931186}}, {{
       5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}, {{
       5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}, {{
       5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}, {{
       5.7768467908647585`, -0.5702685382240202}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}, {
       5.7768467908647585`, -0.5702685382240202}, {
       5.7768467908647585`, -0.5702685382240202}}, {{
       5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}, {{
       5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}, {{
       5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}, {{
       5.841108778617193, -0.5901247525931186}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}, {
       5.841108778617193, -0.5901247525931186}, {
       5.841108778617193, -0.5901247525931186}}, {{
       5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}, {{
       5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}, {{
       5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}, {{
       5.89043575856004, -0.6358491592998622}, {
       5.916834757080713, -0.7212859947448025}, {
       5.916834757080713, -0.7212859947448025}, {
       5.89043575856004, -0.6358491592998622}, {
       5.89043575856004, -0.6358491592998622}}, {{
       5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979662`}, {
       5.700969390825196, -0.17255877448979662`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}, {{
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}, {{
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.406962720019234}, {
       5.700969390825196, -0.406962720019234}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}, {{
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}, {{
       5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}, {{
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}, {{
       5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}, {{
       5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}, {{
       5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}, {{
       5.700969390825196, -0.40696272001923395`}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}}, {{
       5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}, {{
       5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}, {{
       5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}, {{
       5.646648300463125, -0.3483617336368746}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.3483617336368746}, {
       5.646648300463125, -0.3483617336368746}}, {{
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}, {{
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}, {{
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}, {{
       5.63330280029993, -0.2897607472545153}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.646648300463125, -0.23115976087215595`}, {
       5.63330280029993, -0.2897607472545153}, {
       5.63330280029993, -0.2897607472545153}}, {{
       5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}, {{
       5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}, {{
       5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}, {{
       5.646648300463125, -0.23115976087215592`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.646648300463125, -0.23115976087215592`}, {
       5.646648300463125, -0.23115976087215592`}}, {{
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}, {{
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}, {{
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}, {{
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}}, {{
       5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}, {{
       5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}, {{
       5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}, {{
       5.880379764688078, -0.3661046846605174}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.880379764688078, -0.3661046846605174}, {
       5.880379764688078, -0.3661046846605174}}, {{
       5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}, {{
       5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}, {{
       5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}, {{
       5.836302571875726, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.836302571875726, -0.40696272001923395`}, {
       5.836302571875726, -0.40696272001923395`}}, {{
       5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}, {{
       5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}, {{
       5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}, {{
       5.778879878900179, -0.42470567104287676`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.700969390825196, -0.40696272001923395`}, {
       5.778879878900179, -0.42470567104287676`}, {
       5.778879878900179, -0.42470567104287676`}}, {{
       5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}, {{
       5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}, {{
       5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}, {{
       5.700969390825196, -0.17255877448979656`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}, {
       5.700969390825196, -0.17255877448979656`}, {
       5.700969390825196, -0.17255877448979656`}}, {{
       5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}, {{
       5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}, {{
       5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}, {{
       5.778879878900179, -0.1548158234661538}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.778879878900179, -0.1548158234661538}, {
       5.778879878900179, -0.1548158234661538}}, {{
       5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}, {{
       5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}, {{
       5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}, {{
       5.836302571875726, -0.17255877448979662`}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}, {
       5.836302571875726, -0.17255877448979662`}, {
       5.836302571875726, -0.17255877448979662`}}, {{
       5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}, {{
       5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}, {{
       5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}, {{
       5.880379764688078, -0.2134168098485132}, {
       5.903969162400992, -0.2897607472545153}, {
       5.903969162400992, -0.2897607472545153}, {
       5.880379764688078, -0.2134168098485132}, {
       5.880379764688078, -0.2134168098485132}}, {{5.641727282507628, 
       0.117716365463937}, {5.594467387005202, 0.16869981359264413`}, {
       5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.27066670985005836`}, {5.641727282507628, 0.3216501579787655}, {
       5.641727282507628, 0.3216501579787655}, {5.594467387005202, 
       0.27066670985005836`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.1686998135926441}, {5.641727282507628, 
       0.117716365463937}, {5.641727282507628, 0.117716365463937}}, {{
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}, {{5.818339127515574, 0.21968326172135125`}, {
       5.797816114014801, 0.15326326757169878`}, {5.7594685125129255`, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.641727282507628, 0.11771636546393699`}, {5.641727282507628, 
       0.11771636546393699`}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7594685125129255`, 0.117716365463937}, {5.797816114014801, 
       0.15326326757169878`}, {5.818339127515574, 0.21968326172135125`}, {
       5.818339127515574, 0.21968326172135125`}}, {{5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}}, {{
       5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7594685125129255`, 0.3216501579787655}, {
       5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135125`}, {5.818339127515574, 0.21968326172135125`}, {
       5.797816114014801, 0.2861032558710037}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}, {{5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}}, {{5.641727282507628, 
       0.117716365463937}, {5.594467387005202, 0.16869981359264413`}, {
       5.594467387005202, 0.16869981359264413`}, {5.641727282507628, 
       0.117716365463937}, {5.641727282507628, 0.117716365463937}}, {{
       5.641727282507628, 0.117716365463937}, {5.594467387005202, 
       0.16869981359264413`}, {5.594467387005202, 0.16869981359264413`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}}, {{5.641727282507628, 0.117716365463937}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}, {5.641727282507628, 0.117716365463937}, {
       5.641727282507628, 0.117716365463937}}, {{5.641727282507628, 
       0.117716365463937}, {5.594467387005202, 0.16869981359264413`}, {
       5.594467387005202, 0.16869981359264413`}, {5.641727282507628, 
       0.117716365463937}, {5.641727282507628, 0.117716365463937}}, {{
       5.594467387005202, 0.16869981359264413`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}}, {{5.594467387005202, 0.16869981359264413`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}, {5.594467387005202, 0.16869981359264413`}, {
       5.594467387005202, 0.16869981359264413`}}, {{5.594467387005202, 
       0.16869981359264413`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.16869981359264413`}, {5.594467387005202, 0.16869981359264413`}}, {{
       5.594467387005202, 0.16869981359264413`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.16869981359264413`}, {5.594467387005202, 
       0.16869981359264413`}}, {{5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}}, {{5.58285666750498, 
       0.21968326172135125`}, {5.594467387005202, 0.27066670985005836`}, {
       5.594467387005202, 0.27066670985005836`}, {5.58285666750498, 
       0.21968326172135125`}, {5.58285666750498, 0.21968326172135125`}}, {{
       5.58285666750498, 0.21968326172135125`}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}, {
       5.58285666750498, 0.21968326172135125`}, {5.58285666750498, 
       0.21968326172135125`}}, {{5.58285666750498, 0.21968326172135125`}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}, {5.58285666750498, 0.21968326172135125`}, {
       5.58285666750498, 0.21968326172135125`}}, {{5.594467387005202, 
       0.27066670985005836`}, {5.641727282507628, 0.3216501579787655}, {
       5.641727282507628, 0.3216501579787655}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}}, {{
       5.594467387005202, 0.27066670985005836`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}, {
       5.594467387005202, 0.27066670985005836`}, {5.594467387005202, 
       0.27066670985005836`}}, {{5.594467387005202, 0.27066670985005836`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}, {5.594467387005202, 0.27066670985005836`}, {
       5.594467387005202, 0.27066670985005836`}}, {{5.594467387005202, 
       0.27066670985005836`}, {5.641727282507628, 0.3216501579787655}, {
       5.641727282507628, 0.3216501579787655}, {5.594467387005202, 
       0.27066670985005836`}, {5.594467387005202, 0.27066670985005836`}}, {{
       5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}, {{5.818339127515574, 0.21968326172135125`}, {
       5.797816114014801, 0.15326326757169878`}, {5.797816114014801, 
       0.15326326757169878`}, {5.818339127515574, 0.21968326172135125`}, {
       5.818339127515574, 0.21968326172135125`}}, {{5.818339127515574, 
       0.21968326172135125`}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}, {5.818339127515574, 
       0.21968326172135125`}, {5.818339127515574, 0.21968326172135125`}}, {{
       5.818339127515574, 0.21968326172135125`}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}, {
       5.818339127515574, 0.21968326172135125`}, {5.818339127515574, 
       0.21968326172135125`}}, {{5.797816114014801, 0.15326326757169878`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}}, {{5.797816114014801, 
       0.15326326757169878`}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}, {5.797816114014801, 
       0.15326326757169878`}, {5.797816114014801, 0.15326326757169878`}}, {{
       5.797816114014801, 0.15326326757169878`}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}, {
       5.797816114014801, 0.15326326757169878`}, {5.797816114014801, 
       0.15326326757169878`}}, {{5.797816114014801, 0.15326326757169878`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}, {5.797816114014801, 0.15326326757169878`}, {
       5.797816114014801, 0.15326326757169878`}}, {{5.7594685125129255`, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}}, {{
       5.7594685125129255`, 0.117716365463937}, {5.7095101915108275`, 
       0.10227981944299162`}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7594685125129255`, 0.117716365463937}, {5.7594685125129255`, 
       0.117716365463937}}, {{5.7594685125129255`, 0.117716365463937}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.7095101915108275`, 
       0.10227981944299162`}, {5.7594685125129255`, 0.117716365463937}, {
       5.7594685125129255`, 0.117716365463937}}, {{5.7594685125129255`, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.7594685125129255`, 
       0.117716365463937}, {5.7594685125129255`, 0.117716365463937}}, {{
       5.7095101915108275`, 0.10227981944299162`}, {5.641727282507628, 
       0.117716365463937}, {5.641727282507628, 0.117716365463937}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.7095101915108275`, 
       0.10227981944299162`}}, {{5.7095101915108275`, 0.10227981944299162`}, {
       5.641727282507628, 0.117716365463937}, {5.641727282507628, 
       0.117716365463937}, {5.7095101915108275`, 0.10227981944299162`}, {
       5.7095101915108275`, 0.10227981944299162`}}, {{5.7095101915108275`, 
       0.10227981944299162`}, {5.641727282507628, 0.117716365463937}, {
       5.641727282507628, 0.117716365463937}, {5.7095101915108275`, 
       0.10227981944299162`}, {5.7095101915108275`, 0.10227981944299162`}}, {{
       5.7095101915108275`, 0.10227981944299162`}, {5.641727282507628, 
       0.117716365463937}, {5.641727282507628, 0.117716365463937}, {
       5.7095101915108275`, 0.10227981944299162`}, {5.7095101915108275`, 
       0.10227981944299162`}}, {{5.641727282507628, 0.3216501579787655}, {
       5.7095101915108275`, 0.33708670399971086`}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.641727282507628, 0.3216501579787655}, {
       5.641727282507628, 0.3216501579787655}}, {{5.641727282507628, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.7095101915108275`, 0.33708670399971086`}, {5.641727282507628, 
       0.3216501579787655}, {5.641727282507628, 0.3216501579787655}}, {{
       5.641727282507628, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.641727282507628, 0.3216501579787655}, {5.641727282507628, 
       0.3216501579787655}}, {{5.641727282507628, 0.3216501579787655}, {
       5.7095101915108275`, 0.33708670399971086`}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.641727282507628, 0.3216501579787655}, {
       5.641727282507628, 0.3216501579787655}}, {{5.7095101915108275`, 
       0.33708670399971086`}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}}, {{
       5.7095101915108275`, 0.33708670399971086`}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7095101915108275`, 0.33708670399971086`}, {5.7095101915108275`, 
       0.33708670399971086`}}, {{5.7095101915108275`, 0.33708670399971086`}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7095101915108275`, 0.33708670399971086`}, {
       5.7095101915108275`, 0.33708670399971086`}}, {{5.7095101915108275`, 
       0.33708670399971086`}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7095101915108275`, 
       0.33708670399971086`}, {5.7095101915108275`, 0.33708670399971086`}}, {{
       5.7594685125129255`, 0.3216501579787655}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}}, {{5.7594685125129255`, 0.3216501579787655}, {
       5.797816114014801, 0.2861032558710037}, {5.797816114014801, 
       0.2861032558710037}, {5.7594685125129255`, 0.3216501579787655}, {
       5.7594685125129255`, 0.3216501579787655}}, {{5.7594685125129255`, 
       0.3216501579787655}, {5.797816114014801, 0.2861032558710037}, {
       5.797816114014801, 0.2861032558710037}, {5.7594685125129255`, 
       0.3216501579787655}, {5.7594685125129255`, 0.3216501579787655}}, {{
       5.7594685125129255`, 0.3216501579787655}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}, {
       5.7594685125129255`, 0.3216501579787655}, {5.7594685125129255`, 
       0.3216501579787655}}, {{5.797816114014801, 0.2861032558710037}, {
       5.818339127515574, 0.21968326172135122`}, {5.818339127515574, 
       0.21968326172135122`}, {5.797816114014801, 0.2861032558710037}, {
       5.797816114014801, 0.2861032558710037}}, {{5.797816114014801, 
       0.2861032558710037}, {5.818339127515574, 0.21968326172135122`}, {
       5.818339127515574, 0.21968326172135122`}, {5.797816114014801, 
       0.2861032558710037}, {5.797816114014801, 0.2861032558710037}}, {{
       5.797816114014801, 0.2861032558710037}, {5.818339127515574, 
       0.21968326172135122`}, {5.818339127515574, 0.21968326172135122`}, {
       5.797816114014801, 0.2861032558710037}, {5.797816114014801, 
       0.2861032558710037}}, {{5.797816114014801, 0.2861032558710037}, {
       5.818339127515574, 0.21968326172135122`}, {5.818339127515574, 
       0.21968326172135122`}, {5.797816114014801, 0.2861032558710037}, {
       5.797816114014801, 0.2861032558710037}}, {{5.690554404791883, 
       0.6390918836757744}, {5.62976465582665, 0.7046711868074756}, {
       5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.8358297930708781}, {5.690554404791883, 0.9014090962025794}, {
       5.690554404791883, 0.9014090962025794}, {5.62976465582665, 
       0.8358297930708781}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}}, {{
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}, {{5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.684815371479755}, {5.842003318057306, 
       0.6390918836757744}, {5.7777426217490335`, 0.6192360683480538}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}, {5.7777426217490335`, 0.6192360683480538}, {
       5.842003318057306, 0.6390918836757744}, {5.8913293066981005`, 
       0.684815371479755}, {5.917727774690018, 0.7702504899391769}, {
       5.917727774690018, 0.7702504899391769}}, {{5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}}, {{
       5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.842003318057306, 0.9014090962025794}, {
       5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.842003318057306, 
       0.9014090962025794}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}, {{5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}}, {{5.690554404791883, 
       0.6390918836757744}, {5.62976465582665, 0.7046711868074756}, {
       5.62976465582665, 0.7046711868074756}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}}, {{
       5.690554404791883, 0.6390918836757744}, {5.62976465582665, 
       0.7046711868074756}, {5.62976465582665, 0.7046711868074756}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}}, {{5.690554404791883, 0.6390918836757744}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}, {5.690554404791883, 0.6390918836757744}, {
       5.690554404791883, 0.6390918836757744}}, {{5.690554404791883, 
       0.6390918836757744}, {5.62976465582665, 0.7046711868074756}, {
       5.62976465582665, 0.7046711868074756}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}}, {{
       5.62976465582665, 0.7046711868074756}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}}, {{5.62976465582665, 0.7046711868074756}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}, {5.62976465582665, 0.7046711868074756}, {
       5.62976465582665, 0.7046711868074756}}, {{5.62976465582665, 
       0.7046711868074756}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.7046711868074756}, {5.62976465582665, 0.7046711868074756}}, {{
       5.62976465582665, 0.7046711868074756}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.7046711868074756}, {5.62976465582665, 
       0.7046711868074756}}, {{5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}}, {{5.614829948159171, 
       0.7702504899391769}, {5.62976465582665, 0.8358297930708781}, {
       5.62976465582665, 0.8358297930708781}, {5.614829948159171, 
       0.7702504899391769}, {5.614829948159171, 0.7702504899391769}}, {{
       5.614829948159171, 0.7702504899391769}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}, {
       5.614829948159171, 0.7702504899391769}, {5.614829948159171, 
       0.7702504899391769}}, {{5.614829948159171, 0.7702504899391769}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}, {5.614829948159171, 0.7702504899391769}, {
       5.614829948159171, 0.7702504899391769}}, {{5.62976465582665, 
       0.8358297930708781}, {5.690554404791883, 0.9014090962025794}, {
       5.690554404791883, 0.9014090962025794}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}}, {{
       5.62976465582665, 0.8358297930708781}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}, {
       5.62976465582665, 0.8358297930708781}, {5.62976465582665, 
       0.8358297930708781}}, {{5.62976465582665, 0.8358297930708781}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}, {5.62976465582665, 0.8358297930708781}, {
       5.62976465582665, 0.8358297930708781}}, {{5.62976465582665, 
       0.8358297930708781}, {5.690554404791883, 0.9014090962025794}, {
       5.690554404791883, 0.9014090962025794}, {5.62976465582665, 
       0.8358297930708781}, {5.62976465582665, 0.8358297930708781}}, {{
       5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}, {{5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.684815371479755}, {5.8913293066981005`, 
       0.684815371479755}, {5.917727774690018, 0.7702504899391769}, {
       5.917727774690018, 0.7702504899391769}}, {{5.917727774690018, 
       0.7702504899391769}, {5.8913293066981005`, 0.684815371479755}, {
       5.8913293066981005`, 0.684815371479755}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}}, {{
       5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}}, {{5.8913293066981005`, 0.684815371479755}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.8913293066981005`, 0.684815371479755}, {
       5.8913293066981005`, 0.684815371479755}}, {{5.8913293066981005`, 
       0.684815371479755}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}, {5.8913293066981005`, 
       0.684815371479755}, {5.8913293066981005`, 0.684815371479755}}, {{
       5.8913293066981005`, 0.684815371479755}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}, {
       5.8913293066981005`, 0.684815371479755}, {5.8913293066981005`, 
       0.684815371479755}}, {{5.8913293066981005`, 0.684815371479755}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}, {5.8913293066981005`, 0.684815371479755}, {
       5.8913293066981005`, 0.684815371479755}}, {{5.842003318057306, 
       0.6390918836757744}, {5.7777426217490335`, 0.6192360683480538}, {
       5.7777426217490335`, 0.6192360683480538}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}}, {{
       5.842003318057306, 0.6390918836757744}, {5.7777426217490335`, 
       0.6192360683480538}, {5.7777426217490335`, 0.6192360683480538}, {
       5.842003318057306, 0.6390918836757744}, {5.842003318057306, 
       0.6390918836757744}}, {{5.842003318057306, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}, {5.842003318057306, 0.6390918836757744}, {
       5.842003318057306, 0.6390918836757744}}, {{5.842003318057306, 
       0.6390918836757744}, {5.7777426217490335`, 0.6192360683480538}, {
       5.7777426217490335`, 0.6192360683480538}, {5.842003318057306, 
       0.6390918836757744}, {5.842003318057306, 0.6390918836757744}}, {{
       5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}}, {{5.7777426217490335`, 0.6192360683480538}, {
       5.690554404791883, 0.6390918836757744}, {5.690554404791883, 
       0.6390918836757744}, {5.7777426217490335`, 0.6192360683480538}, {
       5.7777426217490335`, 0.6192360683480538}}, {{5.7777426217490335`, 
       0.6192360683480538}, {5.690554404791883, 0.6390918836757744}, {
       5.690554404791883, 0.6390918836757744}, {5.7777426217490335`, 
       0.6192360683480538}, {5.7777426217490335`, 0.6192360683480538}}, {{
       5.7777426217490335`, 0.6192360683480538}, {5.690554404791883, 
       0.6390918836757744}, {5.690554404791883, 0.6390918836757744}, {
       5.7777426217490335`, 0.6192360683480538}, {5.7777426217490335`, 
       0.6192360683480538}}, {{5.690554404791883, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}, {5.690554404791883, 0.9014090962025794}, {
       5.690554404791883, 0.9014090962025794}}, {{5.690554404791883, 
       0.9014090962025794}, {5.7777426217490335`, 0.9212649115303}, {
       5.7777426217490335`, 0.9212649115303}, {5.690554404791883, 
       0.9014090962025794}, {5.690554404791883, 0.9014090962025794}}, {{
       5.690554404791883, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}, {
       5.690554404791883, 0.9014090962025794}, {5.690554404791883, 
       0.9014090962025794}}, {{5.690554404791883, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}, {5.690554404791883, 0.9014090962025794}, {
       5.690554404791883, 0.9014090962025794}}, {{5.7777426217490335`, 
       0.9212649115303}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}}, {{
       5.7777426217490335`, 0.9212649115303}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}, {
       5.7777426217490335`, 0.9212649115303}, {5.7777426217490335`, 
       0.9212649115303}}, {{5.7777426217490335`, 0.9212649115303}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}, {5.7777426217490335`, 0.9212649115303}, {
       5.7777426217490335`, 0.9212649115303}}, {{5.7777426217490335`, 
       0.9212649115303}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}, {5.7777426217490335`, 
       0.9212649115303}, {5.7777426217490335`, 0.9212649115303}}, {{
       5.842003318057306, 0.9014090962025794}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}, {{5.842003318057306, 0.9014090962025794}, {
       5.8913293066981005`, 0.8556856083985988}, {5.8913293066981005`, 
       0.8556856083985988}, {5.842003318057306, 0.9014090962025794}, {
       5.842003318057306, 0.9014090962025794}}, {{5.842003318057306, 
       0.9014090962025794}, {5.8913293066981005`, 0.8556856083985988}, {
       5.8913293066981005`, 0.8556856083985988}, {5.842003318057306, 
       0.9014090962025794}, {5.842003318057306, 0.9014090962025794}}, {{
       5.842003318057306, 0.9014090962025794}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}, {
       5.842003318057306, 0.9014090962025794}, {5.842003318057306, 
       0.9014090962025794}}, {{5.8913293066981005`, 0.8556856083985988}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}, {5.8913293066981005`, 0.8556856083985988}, {
       5.8913293066981005`, 0.8556856083985988}}, {{5.8913293066981005`, 
       0.8556856083985988}, {5.917727774690018, 0.7702504899391769}, {
       5.917727774690018, 0.7702504899391769}, {5.8913293066981005`, 
       0.8556856083985988}, {5.8913293066981005`, 0.8556856083985988}}, {{
       5.8913293066981005`, 0.8556856083985988}, {5.917727774690018, 
       0.7702504899391769}, {5.917727774690018, 0.7702504899391769}, {
       5.8913293066981005`, 0.8556856083985988}, {5.8913293066981005`, 
       0.8556856083985988}}, {{5.8913293066981005`, 0.8556856083985988}, {
       5.917727774690018, 0.7702504899391769}, {5.917727774690018, 
       0.7702504899391769}, {5.8913293066981005`, 0.8556856083985988}, {
       5.8913293066981005`, 0.8556856083985988}}, {{5.668788769640803, 
       1.087304322590759}, {5.596678723561459, 1.1650958359819856`}, {
       5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.3206788627644384`}, {5.668788769640803, 1.398470376155665}, {
       5.668788769640803, 1.398470376155665}, {5.596678723561459, 
       1.3206788627644384`}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}}, {{
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}, {{5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.14154246090482}, {5.848440574429175, 
       1.087304322590759}, {5.772213219476114, 1.0637509475135936`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}, {5.772213219476115, 1.0637509475135936`}, {
       5.848440574429175, 1.087304322590759}, {5.9069520730673934`, 
       1.14154246090482}, {5.938266476823361, 1.242887349373212}, {
       5.938266476823361, 1.242887349373212}}, {{5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}}, {{
       5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.848440574429175, 1.398470376155665}, {
       5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.848440574429175, 
       1.398470376155665}, {5.772213219476114, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}, {{5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}}, {{5.668788769640803, 
       1.087304322590759}, {5.596678723561459, 1.1650958359819856`}, {
       5.596678723561459, 1.1650958359819856`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}}, {{
       5.668788769640803, 1.087304322590759}, {5.596678723561459, 
       1.1650958359819856`}, {5.596678723561459, 1.1650958359819856`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}}, {{5.668788769640803, 1.087304322590759}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}, {5.668788769640803, 1.087304322590759}, {
       5.668788769640803, 1.087304322590759}}, {{5.668788769640803, 
       1.087304322590759}, {5.596678723561459, 1.1650958359819856`}, {
       5.596678723561459, 1.1650958359819856`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}}, {{
       5.596678723561459, 1.1650958359819856`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}}, {{5.596678723561459, 1.1650958359819856`}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}, {5.596678723561459, 1.1650958359819856`}, {
       5.596678723561459, 1.1650958359819856`}}, {{5.596678723561459, 
       1.1650958359819856`}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.1650958359819856`}, {5.596678723561459, 1.1650958359819856`}}, {{
       5.596678723561459, 1.1650958359819856`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.1650958359819856`}, {5.596678723561459, 
       1.1650958359819856`}}, {{5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}}, {{5.578962867246617, 
       1.242887349373212}, {5.596678723561459, 1.3206788627644384`}, {
       5.596678723561459, 1.3206788627644384`}, {5.578962867246617, 
       1.242887349373212}, {5.578962867246617, 1.242887349373212}}, {{
       5.578962867246617, 1.242887349373212}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}, {
       5.578962867246617, 1.242887349373212}, {5.578962867246617, 
       1.242887349373212}}, {{5.578962867246617, 1.242887349373212}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}, {5.578962867246617, 1.242887349373212}, {
       5.578962867246617, 1.242887349373212}}, {{5.596678723561459, 
       1.3206788627644384`}, {5.668788769640803, 1.398470376155665}, {
       5.668788769640803, 1.398470376155665}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}}, {{
       5.596678723561459, 1.3206788627644384`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}, {
       5.596678723561459, 1.3206788627644384`}, {5.596678723561459, 
       1.3206788627644384`}}, {{5.596678723561459, 1.3206788627644384`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}, {5.596678723561459, 1.3206788627644384`}, {
       5.596678723561459, 1.3206788627644384`}}, {{5.596678723561459, 
       1.3206788627644384`}, {5.668788769640803, 1.398470376155665}, {
       5.668788769640803, 1.398470376155665}, {5.596678723561459, 
       1.3206788627644384`}, {5.596678723561459, 1.3206788627644384`}}, {{
       5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}, {{5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.14154246090482}, {5.9069520730673934`, 
       1.14154246090482}, {5.938266476823361, 1.242887349373212}, {
       5.938266476823361, 1.242887349373212}}, {{5.938266476823361, 
       1.242887349373212}, {5.9069520730673934`, 1.14154246090482}, {
       5.9069520730673934`, 1.14154246090482}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}}, {{
       5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}}, {{5.9069520730673934`, 1.14154246090482}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.9069520730673934`, 1.14154246090482}, {
       5.9069520730673934`, 1.14154246090482}}, {{5.9069520730673934`, 
       1.14154246090482}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}, {5.9069520730673934`, 
       1.14154246090482}, {5.9069520730673934`, 1.14154246090482}}, {{
       5.9069520730673934`, 1.14154246090482}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}, {
       5.9069520730673934`, 1.14154246090482}, {5.9069520730673934`, 
       1.14154246090482}}, {{5.9069520730673934`, 1.14154246090482}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}, {5.9069520730673934`, 1.14154246090482}, {
       5.9069520730673934`, 1.14154246090482}}, {{5.848440574429175, 
       1.087304322590759}, {5.772213219476115, 1.0637509475135936`}, {
       5.772213219476115, 1.0637509475135936`}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}}, {{
       5.848440574429175, 1.087304322590759}, {5.772213219476115, 
       1.0637509475135936`}, {5.772213219476115, 1.0637509475135936`}, {
       5.848440574429175, 1.087304322590759}, {5.848440574429175, 
       1.087304322590759}}, {{5.848440574429175, 1.087304322590759}, {
       5.772213219476115, 1.0637509475135936`}, {5.772213219476115, 
       1.0637509475135936`}, {5.848440574429175, 1.087304322590759}, {
       5.848440574429175, 1.087304322590759}}, {{5.848440574429175, 
       1.087304322590759}, {5.772213219476115, 1.0637509475135936`}, {
       5.772213219476115, 1.0637509475135936`}, {5.848440574429175, 
       1.087304322590759}, {5.848440574429175, 1.087304322590759}}, {{
       5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.772213219476114, 
       1.0637509475135936`}}, {{5.772213219476114, 1.0637509475135936`}, {
       5.668788769640803, 1.087304322590759}, {5.668788769640803, 
       1.087304322590759}, {5.772213219476114, 1.0637509475135936`}, {
       5.772213219476114, 1.0637509475135936`}}, {{5.772213219476114, 
       1.0637509475135936`}, {5.668788769640803, 1.087304322590759}, {
       5.668788769640803, 1.087304322590759}, {5.772213219476114, 
       1.0637509475135936`}, {5.772213219476114, 1.0637509475135936`}}, {{
       5.772213219476114, 1.0637509475135936`}, {5.668788769640803, 
       1.087304322590759}, {5.668788769640803, 1.087304322590759}, {
       5.772213219476114, 1.0637509475135936`}, {5.772213219476114, 
       1.0637509475135936`}}, {{5.668788769640803, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}, {5.668788769640803, 1.398470376155665}, {
       5.668788769640803, 1.398470376155665}}, {{5.668788769640803, 
       1.398470376155665}, {5.772213219476115, 1.4220237512328304`}, {
       5.772213219476115, 1.4220237512328304`}, {5.668788769640803, 
       1.398470376155665}, {5.668788769640803, 1.398470376155665}}, {{
       5.668788769640803, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}, {
       5.668788769640803, 1.398470376155665}, {5.668788769640803, 
       1.398470376155665}}, {{5.668788769640803, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}, {5.668788769640803, 1.398470376155665}, {
       5.668788769640803, 1.398470376155665}}, {{5.772213219476115, 
       1.4220237512328304`}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}}, {{
       5.772213219476115, 1.4220237512328304`}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}, {
       5.772213219476115, 1.4220237512328304`}, {5.772213219476115, 
       1.4220237512328304`}}, {{5.772213219476115, 1.4220237512328304`}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}, {5.772213219476115, 1.4220237512328304`}, {
       5.772213219476115, 1.4220237512328304`}}, {{5.772213219476115, 
       1.4220237512328304`}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}, {5.772213219476115, 
       1.4220237512328304`}, {5.772213219476115, 1.4220237512328304`}}, {{
       5.848440574429175, 1.398470376155665}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}, {{5.848440574429175, 1.398470376155665}, {
       5.9069520730673934`, 1.344232237841604}, {5.9069520730673934`, 
       1.344232237841604}, {5.848440574429175, 1.398470376155665}, {
       5.848440574429175, 1.398470376155665}}, {{5.848440574429175, 
       1.398470376155665}, {5.9069520730673934`, 1.344232237841604}, {
       5.9069520730673934`, 1.344232237841604}, {5.848440574429175, 
       1.398470376155665}, {5.848440574429175, 1.398470376155665}}, {{
       5.848440574429175, 1.398470376155665}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}, {
       5.848440574429175, 1.398470376155665}, {5.848440574429175, 
       1.398470376155665}}, {{5.9069520730673934`, 1.344232237841604}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}, {5.9069520730673934`, 1.344232237841604}, {
       5.9069520730673934`, 1.344232237841604}}, {{5.9069520730673934`, 
       1.344232237841604}, {5.938266476823361, 1.242887349373212}, {
       5.938266476823361, 1.242887349373212}, {5.9069520730673934`, 
       1.344232237841604}, {5.9069520730673934`, 1.344232237841604}}, {{
       5.9069520730673934`, 1.344232237841604}, {5.938266476823361, 
       1.242887349373212}, {5.938266476823361, 1.242887349373212}, {
       5.9069520730673934`, 1.344232237841604}, {5.9069520730673934`, 
       1.344232237841604}}, {{5.9069520730673934`, 1.344232237841604}, {
       5.938266476823361, 1.242887349373212}, {5.938266476823361, 
       1.242887349373212}, {5.9069520730673934`, 1.344232237841604}, {
       5.9069520730673934`, 1.344232237841604}}, {{5.650757437115237, 
       1.6149672460295592`}, {5.601870046071231, 1.6677064181953536`}, {
       5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.7731847625269423`}, {5.650757437115237, 1.8259239346927367`}, {
       5.650757437115237, 1.8259239346927367`}, {5.601870046071231, 
       1.7731847625269423`}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}}, {{
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}, {{5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.6517382817093977`}, {5.772553338102275, 
       1.6149672460295592`}, {5.72087459550738, 1.5989991095436034`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}, {5.72087459550738, 1.5989991095436034`}, {
       5.772553338102275, 1.6149672460295592`}, {5.812221521247658, 
       1.6517382817093977`}, {5.833451288595794, 1.720445590361148}, {
       5.833451288595794, 1.720445590361148}}, {{5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}}, {{
       5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.772553338102275, 1.8259239346927367`}, {
       5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.772553338102275, 
       1.8259239346927367`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}, {{5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}}, {{5.650757437115237, 
       1.6149672460295592`}, {5.601870046071231, 1.6677064181953536`}, {
       5.601870046071231, 1.6677064181953536`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}}, {{
       5.650757437115237, 1.6149672460295592`}, {5.601870046071231, 
       1.6677064181953536`}, {5.601870046071231, 1.6677064181953536`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}}, {{5.650757437115237, 1.6149672460295592`}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}, {5.650757437115237, 1.6149672460295592`}, {
       5.650757437115237, 1.6149672460295592`}}, {{5.650757437115237, 
       1.6149672460295592`}, {5.601870046071231, 1.6677064181953536`}, {
       5.601870046071231, 1.6677064181953536`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}}, {{
       5.601870046071231, 1.6677064181953536`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}}, {{5.601870046071231, 1.6677064181953536`}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}, {5.601870046071231, 1.6677064181953536`}, {
       5.601870046071231, 1.6677064181953536`}}, {{5.601870046071231, 
       1.6677064181953536`}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.6677064181953536`}, {5.601870046071231, 1.6677064181953536`}}, {{
       5.601870046071231, 1.6677064181953536`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.6677064181953536`}, {5.601870046071231, 
       1.6677064181953536`}}, {{5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}}, {{5.589859486621719, 
       1.720445590361148}, {5.601870046071231, 1.7731847625269423`}, {
       5.601870046071231, 1.7731847625269423`}, {5.589859486621719, 
       1.720445590361148}, {5.589859486621719, 1.720445590361148}}, {{
       5.589859486621719, 1.720445590361148}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}, {
       5.589859486621719, 1.720445590361148}, {5.589859486621719, 
       1.720445590361148}}, {{5.589859486621719, 1.720445590361148}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}, {5.589859486621719, 1.720445590361148}, {
       5.589859486621719, 1.720445590361148}}, {{5.601870046071231, 
       1.7731847625269423`}, {5.650757437115237, 1.8259239346927367`}, {
       5.650757437115237, 1.8259239346927367`}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}}, {{
       5.601870046071231, 1.7731847625269423`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}, {
       5.601870046071231, 1.7731847625269423`}, {5.601870046071231, 
       1.7731847625269423`}}, {{5.601870046071231, 1.7731847625269423`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}, {5.601870046071231, 1.7731847625269423`}, {
       5.601870046071231, 1.7731847625269423`}}, {{5.601870046071231, 
       1.7731847625269423`}, {5.650757437115237, 1.8259239346927367`}, {
       5.650757437115237, 1.8259239346927367`}, {5.601870046071231, 
       1.7731847625269423`}, {5.601870046071231, 1.7731847625269423`}}, {{
       5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}, {{5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.6517382817093977`}, {5.812221521247658, 
       1.6517382817093977`}, {5.833451288595794, 1.720445590361148}, {
       5.833451288595794, 1.720445590361148}}, {{5.833451288595794, 
       1.720445590361148}, {5.812221521247658, 1.6517382817093977`}, {
       5.812221521247658, 1.6517382817093977`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}}, {{
       5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}}, {{5.812221521247658, 1.6517382817093977`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.812221521247658, 1.6517382817093977`}, {
       5.812221521247658, 1.6517382817093977`}}, {{5.812221521247658, 
       1.6517382817093977`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}, {5.812221521247658, 
       1.6517382817093977`}, {5.812221521247658, 1.6517382817093977`}}, {{
       5.812221521247658, 1.6517382817093977`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}, {
       5.812221521247658, 1.6517382817093977`}, {5.812221521247658, 
       1.6517382817093977`}}, {{5.812221521247658, 1.6517382817093977`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}, {5.812221521247658, 1.6517382817093977`}, {
       5.812221521247658, 1.6517382817093977`}}, {{5.772553338102275, 
       1.6149672460295592`}, {5.72087459550738, 1.5989991095436034`}, {
       5.72087459550738, 1.5989991095436034`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}}, {{
       5.772553338102275, 1.6149672460295592`}, {5.72087459550738, 
       1.5989991095436034`}, {5.72087459550738, 1.5989991095436034`}, {
       5.772553338102275, 1.6149672460295592`}, {5.772553338102275, 
       1.6149672460295592`}}, {{5.772553338102275, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}, {5.772553338102275, 1.6149672460295592`}, {
       5.772553338102275, 1.6149672460295592`}}, {{5.772553338102275, 
       1.6149672460295592`}, {5.72087459550738, 1.5989991095436034`}, {
       5.72087459550738, 1.5989991095436034`}, {5.772553338102275, 
       1.6149672460295592`}, {5.772553338102275, 1.6149672460295592`}}, {{
       5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}}, {{5.72087459550738, 1.5989991095436034`}, {
       5.650757437115237, 1.6149672460295592`}, {5.650757437115237, 
       1.6149672460295592`}, {5.72087459550738, 1.5989991095436034`}, {
       5.72087459550738, 1.5989991095436034`}}, {{5.72087459550738, 
       1.5989991095436034`}, {5.650757437115237, 1.6149672460295592`}, {
       5.650757437115237, 1.6149672460295592`}, {5.72087459550738, 
       1.5989991095436034`}, {5.72087459550738, 1.5989991095436034`}}, {{
       5.72087459550738, 1.5989991095436034`}, {5.650757437115237, 
       1.6149672460295592`}, {5.650757437115237, 1.6149672460295592`}, {
       5.72087459550738, 1.5989991095436034`}, {5.72087459550738, 
       1.5989991095436034`}}, {{5.650757437115237, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}, {5.650757437115237, 1.8259239346927367`}, {
       5.650757437115237, 1.8259239346927367`}}, {{5.650757437115237, 
       1.8259239346927367`}, {5.72087459550738, 1.8418920711786926`}, {
       5.72087459550738, 1.8418920711786926`}, {5.650757437115237, 
       1.8259239346927367`}, {5.650757437115237, 1.8259239346927367`}}, {{
       5.650757437115237, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}, {
       5.650757437115237, 1.8259239346927367`}, {5.650757437115237, 
       1.8259239346927367`}}, {{5.650757437115237, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}, {5.650757437115237, 1.8259239346927367`}, {
       5.650757437115237, 1.8259239346927367`}}, {{5.72087459550738, 
       1.8418920711786926`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}}, {{
       5.72087459550738, 1.8418920711786926`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}, {
       5.72087459550738, 1.8418920711786926`}, {5.72087459550738, 
       1.8418920711786926`}}, {{5.72087459550738, 1.8418920711786926`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}, {5.72087459550738, 1.8418920711786926`}, {
       5.72087459550738, 1.8418920711786926`}}, {{5.72087459550738, 
       1.8418920711786926`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}, {5.72087459550738, 
       1.8418920711786926`}, {5.72087459550738, 1.8418920711786926`}}, {{
       5.772553338102275, 1.8259239346927367`}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}, {{5.772553338102275, 1.8259239346927367`}, {
       5.812221521247658, 1.7891528990128982`}, {5.812221521247658, 
       1.7891528990128982`}, {5.772553338102275, 1.8259239346927367`}, {
       5.772553338102275, 1.8259239346927367`}}, {{5.772553338102275, 
       1.8259239346927367`}, {5.812221521247658, 1.7891528990128982`}, {
       5.812221521247658, 1.7891528990128982`}, {5.772553338102275, 
       1.8259239346927367`}, {5.772553338102275, 1.8259239346927367`}}, {{
       5.772553338102275, 1.8259239346927367`}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}, {
       5.772553338102275, 1.8259239346927367`}, {5.772553338102275, 
       1.8259239346927367`}}, {{5.812221521247658, 1.7891528990128982`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}, {5.812221521247658, 1.7891528990128982`}, {
       5.812221521247658, 1.7891528990128982`}}, {{5.812221521247658, 
       1.7891528990128982`}, {5.833451288595794, 1.720445590361148}, {
       5.833451288595794, 1.720445590361148}, {5.812221521247658, 
       1.7891528990128982`}, {5.812221521247658, 1.7891528990128982`}}, {{
       5.812221521247658, 1.7891528990128982`}, {5.833451288595794, 
       1.720445590361148}, {5.833451288595794, 1.720445590361148}, {
       5.812221521247658, 1.7891528990128982`}, {5.812221521247658, 
       1.7891528990128982`}}, {{5.812221521247658, 1.7891528990128982`}, {
       5.833451288595794, 1.720445590361148}, {5.833451288595794, 
       1.720445590361148}, {5.812221521247658, 1.7891528990128982`}, {
       5.812221521247658, 1.7891528990128982`}}, {{5.646685014052404, 
       2.104257196793243}, {5.59928782324382, 2.1553887575668345`}, {
       5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.257651879114017}, {5.646685014052404, 2.3087834398876086`}, {
       5.646685014052404, 2.3087834398876086`}, {5.59928782324382, 
       2.257651879114017}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}}, {{
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}, {{5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.139907366645378}, {5.764768295559279, 
       2.104257196793243}, {5.714664840021775, 2.0887758058717867`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}, {5.714664840021775, 2.0887758058717867`}, {
       5.764768295559279, 2.104257196793243}, {5.803227301151931, 
       2.139907366645378}, {5.823809936312717, 2.206520318340426}, {
       5.823809936312717, 2.206520318340426}}, {{5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}}, {{
       5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.764768295559279, 2.3087834398876086`}, {
       5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.764768295559279, 
       2.3087834398876086`}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}, {{5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}}, {{5.646685014052404, 
       2.104257196793243}, {5.59928782324382, 2.1553887575668345`}, {
       5.59928782324382, 2.1553887575668345`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}}, {{
       5.646685014052404, 2.104257196793243}, {5.59928782324382, 
       2.1553887575668345`}, {5.59928782324382, 2.1553887575668345`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}}, {{5.646685014052404, 2.104257196793243}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}, {5.646685014052404, 2.104257196793243}, {
       5.646685014052404, 2.104257196793243}}, {{5.646685014052404, 
       2.104257196793243}, {5.59928782324382, 2.1553887575668345`}, {
       5.59928782324382, 2.1553887575668345`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}}, {{
       5.59928782324382, 2.1553887575668345`}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}}, {{5.59928782324382, 2.1553887575668345`}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}, {5.59928782324382, 2.1553887575668345`}, {
       5.59928782324382, 2.1553887575668345`}}, {{5.59928782324382, 
       2.1553887575668345`}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.1553887575668345`}, {5.59928782324382, 2.1553887575668345`}}, {{
       5.59928782324382, 2.1553887575668345`}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.1553887575668345`}, {5.59928782324382, 
       2.1553887575668345`}}, {{5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}}, {{5.587643373298967, 
       2.206520318340426}, {5.59928782324382, 2.257651879114017}, {
       5.59928782324382, 2.257651879114017}, {5.587643373298967, 
       2.206520318340426}, {5.587643373298967, 2.206520318340426}}, {{
       5.587643373298967, 2.206520318340426}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}, {
       5.587643373298967, 2.206520318340426}, {5.587643373298967, 
       2.206520318340426}}, {{5.587643373298967, 2.206520318340426}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}, {5.587643373298967, 2.206520318340426}, {
       5.587643373298967, 2.206520318340426}}, {{5.59928782324382, 
       2.257651879114017}, {5.646685014052404, 2.3087834398876086`}, {
       5.646685014052404, 2.3087834398876086`}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}}, {{
       5.59928782324382, 2.257651879114017}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}, {
       5.59928782324382, 2.257651879114017}, {5.59928782324382, 
       2.257651879114017}}, {{5.59928782324382, 2.257651879114017}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}, {5.59928782324382, 2.257651879114017}, {
       5.59928782324382, 2.257651879114017}}, {{5.59928782324382, 
       2.257651879114017}, {5.646685014052404, 2.3087834398876086`}, {
       5.646685014052404, 2.3087834398876086`}, {5.59928782324382, 
       2.257651879114017}, {5.59928782324382, 2.257651879114017}}, {{
       5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}, {{5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.139907366645378}, {5.803227301151931, 
       2.139907366645378}, {5.823809936312717, 2.206520318340426}, {
       5.823809936312717, 2.206520318340426}}, {{5.823809936312717, 
       2.206520318340426}, {5.803227301151931, 2.139907366645378}, {
       5.803227301151931, 2.139907366645378}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}}, {{
       5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}}, {{5.803227301151931, 2.139907366645378}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.803227301151931, 2.139907366645378}, {
       5.803227301151931, 2.139907366645378}}, {{5.803227301151931, 
       2.139907366645378}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}, {5.803227301151931, 
       2.139907366645378}, {5.803227301151931, 2.139907366645378}}, {{
       5.803227301151931, 2.139907366645378}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}, {
       5.803227301151931, 2.139907366645378}, {5.803227301151931, 
       2.139907366645378}}, {{5.803227301151931, 2.139907366645378}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}, {5.803227301151931, 2.139907366645378}, {
       5.803227301151931, 2.139907366645378}}, {{5.764768295559279, 
       2.104257196793243}, {5.714664840021775, 2.0887758058717867`}, {
       5.714664840021775, 2.0887758058717867`}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}}, {{
       5.764768295559279, 2.104257196793243}, {5.714664840021775, 
       2.0887758058717867`}, {5.714664840021775, 2.0887758058717867`}, {
       5.764768295559279, 2.104257196793243}, {5.764768295559279, 
       2.104257196793243}}, {{5.764768295559279, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}, {5.764768295559279, 2.104257196793243}, {
       5.764768295559279, 2.104257196793243}}, {{5.764768295559279, 
       2.104257196793243}, {5.714664840021775, 2.0887758058717867`}, {
       5.714664840021775, 2.0887758058717867`}, {5.764768295559279, 
       2.104257196793243}, {5.764768295559279, 2.104257196793243}}, {{
       5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}}, {{5.714664840021775, 2.0887758058717867`}, {
       5.646685014052404, 2.104257196793243}, {5.646685014052404, 
       2.104257196793243}, {5.714664840021775, 2.0887758058717867`}, {
       5.714664840021775, 2.0887758058717867`}}, {{5.714664840021775, 
       2.0887758058717867`}, {5.646685014052404, 2.104257196793243}, {
       5.646685014052404, 2.104257196793243}, {5.714664840021775, 
       2.0887758058717867`}, {5.714664840021775, 2.0887758058717867`}}, {{
       5.714664840021775, 2.0887758058717867`}, {5.646685014052404, 
       2.104257196793243}, {5.646685014052404, 2.104257196793243}, {
       5.714664840021775, 2.0887758058717867`}, {5.714664840021775, 
       2.0887758058717867`}}, {{5.646685014052404, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}, {5.646685014052404, 2.3087834398876086`}, {
       5.646685014052404, 2.3087834398876086`}}, {{5.646685014052404, 
       2.3087834398876086`}, {5.714664840021775, 2.324264830809065}, {
       5.714664840021775, 2.324264830809065}, {5.646685014052404, 
       2.3087834398876086`}, {5.646685014052404, 2.3087834398876086`}}, {{
       5.646685014052404, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}, {
       5.646685014052404, 2.3087834398876086`}, {5.646685014052404, 
       2.3087834398876086`}}, {{5.646685014052404, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}, {5.646685014052404, 2.3087834398876086`}, {
       5.646685014052404, 2.3087834398876086`}}, {{5.714664840021775, 
       2.324264830809065}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}}, {{
       5.714664840021775, 2.324264830809065}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}, {
       5.714664840021775, 2.324264830809065}, {5.714664840021775, 
       2.324264830809065}}, {{5.714664840021775, 2.324264830809065}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}, {5.714664840021775, 2.324264830809065}, {
       5.714664840021775, 2.324264830809065}}, {{5.714664840021775, 
       2.324264830809065}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}, {5.714664840021775, 
       2.324264830809065}, {5.714664840021775, 2.324264830809065}}, {{
       5.764768295559279, 2.3087834398876086`}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}, {{5.764768295559279, 2.3087834398876086`}, {
       5.803227301151931, 2.2731332700354736`}, {5.803227301151931, 
       2.2731332700354736`}, {5.764768295559279, 2.3087834398876086`}, {
       5.764768295559279, 2.3087834398876086`}}, {{5.764768295559279, 
       2.3087834398876086`}, {5.803227301151931, 2.2731332700354736`}, {
       5.803227301151931, 2.2731332700354736`}, {5.764768295559279, 
       2.3087834398876086`}, {5.764768295559279, 2.3087834398876086`}}, {{
       5.764768295559279, 2.3087834398876086`}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}, {
       5.764768295559279, 2.3087834398876086`}, {5.764768295559279, 
       2.3087834398876086`}}, {{5.803227301151931, 2.2731332700354736`}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}, {5.803227301151931, 2.2731332700354736`}, {
       5.803227301151931, 2.2731332700354736`}}, {{5.803227301151931, 
       2.2731332700354736`}, {5.823809936312717, 2.206520318340426}, {
       5.823809936312717, 2.206520318340426}, {5.803227301151931, 
       2.2731332700354736`}, {5.803227301151931, 2.2731332700354736`}}, {{
       5.803227301151931, 2.2731332700354736`}, {5.823809936312717, 
       2.206520318340426}, {5.823809936312717, 2.206520318340426}, {
       5.803227301151931, 2.2731332700354736`}, {5.803227301151931, 
       2.2731332700354736`}}, {{5.803227301151931, 2.2731332700354736`}, {
       5.823809936312717, 2.206520318340426}, {5.823809936312717, 
       2.206520318340426}, {5.803227301151931, 2.2731332700354736`}, {
       5.803227301151931, 2.2731332700354736`}}, {{5.621501308897328, 
       2.655898410457235}, {5.557895831839386, 2.7245152896485725`}, {
       5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.8617490480312484`}, {5.621501308897328, 2.930365927222586}, {
       5.621501308897328, 2.930365927222586}, {5.557895831839386, 
       2.8617490480312484`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.621501308897328, 
       2.655898410457235}, {5.621501308897328, 2.655898410457235}}, {{
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}, {{5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.703739770292236}, {5.779965203585611, 
       2.655898410457235}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.779965203585611, 2.655898410457235}, {5.831575928950618, 
       2.703739770292236}, {5.859197150929753, 2.7931321688399104`}, {
       5.859197150929753, 2.7931321688399104`}}, {{5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}}, {{
       5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.779965203585611, 2.930365927222586}, {
       5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.779965203585611, 
       2.930365927222586}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}, {{5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}}, {{5.621501308897328, 
       2.655898410457235}, {5.557895831839386, 2.7245152896485725`}, {
       5.557895831839386, 2.7245152896485725`}, {5.621501308897328, 
       2.655898410457235}, {5.621501308897328, 2.655898410457235}}, {{
       5.621501308897328, 2.655898410457235}, {5.557895831839386, 
       2.7245152896485725`}, {5.557895831839386, 2.7245152896485725`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}}, {{5.621501308897328, 2.655898410457235}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}, {5.621501308897328, 2.655898410457235}, {
       5.621501308897328, 2.655898410457235}}, {{5.621501308897328, 
       2.655898410457235}, {5.557895831839386, 2.7245152896485725`}, {
       5.557895831839386, 2.7245152896485725`}, {5.621501308897328, 
       2.655898410457235}, {5.621501308897328, 2.655898410457235}}, {{
       5.557895831839386, 2.7245152896485725`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}}, {{5.557895831839386, 2.7245152896485725`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}, {5.557895831839386, 2.7245152896485725`}, {
       5.557895831839386, 2.7245152896485725`}}, {{5.557895831839386, 
       2.7245152896485725`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.7245152896485725`}, {5.557895831839386, 2.7245152896485725`}}, {{
       5.557895831839386, 2.7245152896485725`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.7245152896485725`}, {5.557895831839386, 
       2.7245152896485725`}}, {{5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}}, {{5.542269361553186, 
       2.7931321688399104`}, {5.557895831839386, 2.8617490480312484`}, {
       5.557895831839386, 2.8617490480312484`}, {5.542269361553186, 
       2.7931321688399104`}, {5.542269361553186, 2.7931321688399104`}}, {{
       5.542269361553186, 2.7931321688399104`}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}, {
       5.542269361553186, 2.7931321688399104`}, {5.542269361553186, 
       2.7931321688399104`}}, {{5.542269361553186, 2.7931321688399104`}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}, {5.542269361553186, 2.7931321688399104`}, {
       5.542269361553186, 2.7931321688399104`}}, {{5.557895831839386, 
       2.8617490480312484`}, {5.621501308897328, 2.930365927222586}, {
       5.621501308897328, 2.930365927222586}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}}, {{
       5.557895831839386, 2.8617490480312484`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}, {
       5.557895831839386, 2.8617490480312484`}, {5.557895831839386, 
       2.8617490480312484`}}, {{5.557895831839386, 2.8617490480312484`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}, {5.557895831839386, 2.8617490480312484`}, {
       5.557895831839386, 2.8617490480312484`}}, {{5.557895831839386, 
       2.8617490480312484`}, {5.621501308897328, 2.930365927222586}, {
       5.621501308897328, 2.930365927222586}, {5.557895831839386, 
       2.8617490480312484`}, {5.557895831839386, 2.8617490480312484`}}, {{
       5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}, {{5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.703739770292236}, {5.831575928950618, 
       2.703739770292236}, {5.859197150929753, 2.7931321688399104`}, {
       5.859197150929753, 2.7931321688399104`}}, {{5.859197150929753, 
       2.7931321688399104`}, {5.831575928950618, 2.703739770292236}, {
       5.831575928950618, 2.703739770292236}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}}, {{
       5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}}, {{5.831575928950618, 2.703739770292236}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.831575928950618, 2.703739770292236}, {
       5.831575928950618, 2.703739770292236}}, {{5.831575928950618, 
       2.703739770292236}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}, {5.831575928950618, 
       2.703739770292236}, {5.831575928950618, 2.703739770292236}}, {{
       5.831575928950618, 2.703739770292236}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}, {
       5.831575928950618, 2.703739770292236}, {5.831575928950618, 
       2.703739770292236}}, {{5.831575928950618, 2.703739770292236}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}, {5.831575928950618, 2.703739770292236}, {
       5.831575928950618, 2.703739770292236}}, {{5.779965203585611, 
       2.655898410457235}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}}, {{
       5.779965203585611, 2.655898410457235}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.779965203585611, 2.655898410457235}, {5.779965203585611, 
       2.655898410457235}}, {{5.779965203585611, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.779965203585611, 2.655898410457235}, {
       5.779965203585611, 2.655898410457235}}, {{5.779965203585611, 
       2.655898410457235}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.779965203585611, 
       2.655898410457235}, {5.779965203585611, 2.655898410457235}}, {{
       5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328, 
       2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}}, {{5.7127280079344045`, 2.6351228911008984`}, {
       5.621501308897328, 2.655898410457235}, {5.621501308897328, 
       2.655898410457235}, {5.7127280079344045`, 2.6351228911008984`}, {
       5.7127280079344045`, 2.6351228911008984`}}, {{5.7127280079344045`, 
       2.6351228911008984`}, {5.621501308897328, 2.655898410457235}, {
       5.621501308897328, 2.655898410457235}, {5.7127280079344045`, 
       2.6351228911008984`}, {5.7127280079344045`, 2.6351228911008984`}}, {{
       5.7127280079344045`, 2.6351228911008984`}, {5.621501308897328, 
       2.655898410457235}, {5.621501308897328, 2.655898410457235}, {
       5.7127280079344045`, 2.6351228911008984`}, {5.7127280079344045`, 
       2.6351228911008984`}}, {{5.621501308897328, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.621501308897328, 2.930365927222586}, {
       5.621501308897328, 2.930365927222586}}, {{5.621501308897328, 
       2.930365927222586}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.621501308897328, 
       2.930365927222586}, {5.621501308897328, 2.930365927222586}}, {{
       5.621501308897328, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.621501308897328, 2.930365927222586}, {5.621501308897328, 
       2.930365927222586}}, {{5.621501308897328, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.621501308897328, 2.930365927222586}, {
       5.621501308897328, 2.930365927222586}}, {{5.7127280079344045`, 
       2.9511414465789225`}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}}, {{
       5.7127280079344045`, 2.9511414465789225`}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}, {
       5.7127280079344045`, 2.9511414465789225`}, {5.7127280079344045`, 
       2.9511414465789225`}}, {{5.7127280079344045`, 2.9511414465789225`}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}, {5.7127280079344045`, 2.9511414465789225`}, {
       5.7127280079344045`, 2.9511414465789225`}}, {{5.7127280079344045`, 
       2.9511414465789225`}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}, {5.7127280079344045`, 
       2.9511414465789225`}, {5.7127280079344045`, 2.9511414465789225`}}, {{
       5.779965203585611, 2.930365927222586}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}, {{5.779965203585611, 2.930365927222586}, {
       5.831575928950618, 2.882524567387585}, {5.831575928950618, 
       2.882524567387585}, {5.779965203585611, 2.930365927222586}, {
       5.779965203585611, 2.930365927222586}}, {{5.779965203585611, 
       2.930365927222586}, {5.831575928950618, 2.882524567387585}, {
       5.831575928950618, 2.882524567387585}, {5.779965203585611, 
       2.930365927222586}, {5.779965203585611, 2.930365927222586}}, {{
       5.779965203585611, 2.930365927222586}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}, {
       5.779965203585611, 2.930365927222586}, {5.779965203585611, 
       2.930365927222586}}, {{5.831575928950618, 2.882524567387585}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}, {5.831575928950618, 2.882524567387585}, {
       5.831575928950618, 2.882524567387585}}, {{5.831575928950618, 
       2.882524567387585}, {5.859197150929753, 2.7931321688399104`}, {
       5.859197150929753, 2.7931321688399104`}, {5.831575928950618, 
       2.882524567387585}, {5.831575928950618, 2.882524567387585}}, {{
       5.831575928950618, 2.882524567387585}, {5.859197150929753, 
       2.7931321688399104`}, {5.859197150929753, 2.7931321688399104`}, {
       5.831575928950618, 2.882524567387585}, {5.831575928950618, 
       2.882524567387585}}, {{5.831575928950618, 2.882524567387585}, {
       5.859197150929753, 2.7931321688399104`}, {5.859197150929753, 
       2.7931321688399104`}, {5.831575928950618, 2.882524567387585}, {
       5.831575928950618, 2.882524567387585}}, {{5.733739775945973, 
       3.16613761318721}, {5.680717028739826, 3.2233379614547464`}, {
       5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.3377386579898194`}, {5.733739775945973, 3.394939006257356}, {
       5.733739775945973, 3.394939006257356}, {5.680717028739826, 
       3.3377386579898194`}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}}, {{
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}, {{5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.206019089529551}, {5.865838321825984, 
       3.16613761318721}, {5.809788104254051, 3.1488187412620143`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}, {5.809788104254051, 3.1488187412620143`}, {
       5.865838321825984, 3.16613761318721}, {5.908862013664058, 
       3.206019089529551}, {5.931887594765989, 3.280538309722283}, {
       5.931887594765989, 3.280538309722283}}, {{5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}}, {{
       5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.865838321825984, 3.394939006257356}, {
       5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.865838321825984, 
       3.394939006257356}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}, {{5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}}, {{5.733739775945973, 
       3.16613761318721}, {5.680717028739826, 3.2233379614547464`}, {
       5.680717028739826, 3.2233379614547464`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}}, {{
       5.733739775945973, 3.16613761318721}, {5.680717028739826, 
       3.2233379614547464`}, {5.680717028739826, 3.2233379614547464`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}}, {{5.733739775945973, 3.16613761318721}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}, {5.733739775945973, 3.16613761318721}, {
       5.733739775945973, 3.16613761318721}}, {{5.733739775945973, 
       3.16613761318721}, {5.680717028739826, 3.2233379614547464`}, {
       5.680717028739826, 3.2233379614547464`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}}, {{
       5.680717028739826, 3.2233379614547464`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}}, {{5.680717028739826, 3.2233379614547464`}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}, {5.680717028739826, 3.2233379614547464`}, {
       5.680717028739826, 3.2233379614547464`}}, {{5.680717028739826, 
       3.2233379614547464`}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.2233379614547464`}, {5.680717028739826, 3.2233379614547464`}}, {{
       5.680717028739826, 3.2233379614547464`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.2233379614547464`}, {5.680717028739826, 
       3.2233379614547464`}}, {{5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}}, {{5.667690503005968, 
       3.280538309722283}, {5.680717028739826, 3.3377386579898194`}, {
       5.680717028739826, 3.3377386579898194`}, {5.667690503005968, 
       3.280538309722283}, {5.667690503005968, 3.280538309722283}}, {{
       5.667690503005968, 3.280538309722283}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}, {
       5.667690503005968, 3.280538309722283}, {5.667690503005968, 
       3.280538309722283}}, {{5.667690503005968, 3.280538309722283}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}, {5.667690503005968, 3.280538309722283}, {
       5.667690503005968, 3.280538309722283}}, {{5.680717028739826, 
       3.3377386579898194`}, {5.733739775945973, 3.394939006257356}, {
       5.733739775945973, 3.394939006257356}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}}, {{
       5.680717028739826, 3.3377386579898194`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}, {
       5.680717028739826, 3.3377386579898194`}, {5.680717028739826, 
       3.3377386579898194`}}, {{5.680717028739826, 3.3377386579898194`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}, {5.680717028739826, 3.3377386579898194`}, {
       5.680717028739826, 3.3377386579898194`}}, {{5.680717028739826, 
       3.3377386579898194`}, {5.733739775945973, 3.394939006257356}, {
       5.733739775945973, 3.394939006257356}, {5.680717028739826, 
       3.3377386579898194`}, {5.680717028739826, 3.3377386579898194`}}, {{
       5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}, {{5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.206019089529551}, {5.908862013664058, 
       3.206019089529551}, {5.931887594765989, 3.280538309722283}, {
       5.931887594765989, 3.280538309722283}}, {{5.931887594765989, 
       3.280538309722283}, {5.908862013664058, 3.206019089529551}, {
       5.908862013664058, 3.206019089529551}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}}, {{
       5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}}, {{5.908862013664058, 3.206019089529551}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.908862013664058, 3.206019089529551}, {
       5.908862013664058, 3.206019089529551}}, {{5.908862013664058, 
       3.206019089529551}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}, {5.908862013664058, 
       3.206019089529551}, {5.908862013664058, 3.206019089529551}}, {{
       5.908862013664058, 3.206019089529551}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}, {
       5.908862013664058, 3.206019089529551}, {5.908862013664058, 
       3.206019089529551}}, {{5.908862013664058, 3.206019089529551}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}, {5.908862013664058, 3.206019089529551}, {
       5.908862013664058, 3.206019089529551}}, {{5.865838321825984, 
       3.16613761318721}, {5.809788104254051, 3.1488187412620143`}, {
       5.809788104254051, 3.1488187412620143`}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}}, {{
       5.865838321825984, 3.16613761318721}, {5.809788104254051, 
       3.1488187412620143`}, {5.809788104254051, 3.1488187412620143`}, {
       5.865838321825984, 3.16613761318721}, {5.865838321825984, 
       3.16613761318721}}, {{5.865838321825984, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}, {5.865838321825984, 3.16613761318721}, {
       5.865838321825984, 3.16613761318721}}, {{5.865838321825984, 
       3.16613761318721}, {5.809788104254051, 3.1488187412620143`}, {
       5.809788104254051, 3.1488187412620143`}, {5.865838321825984, 
       3.16613761318721}, {5.865838321825984, 3.16613761318721}}, {{
       5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}}, {{5.809788104254051, 3.1488187412620143`}, {
       5.733739775945973, 3.16613761318721}, {5.733739775945973, 
       3.16613761318721}, {5.809788104254051, 3.1488187412620143`}, {
       5.809788104254051, 3.1488187412620143`}}, {{5.809788104254051, 
       3.1488187412620143`}, {5.733739775945973, 3.16613761318721}, {
       5.733739775945973, 3.16613761318721}, {5.809788104254051, 
       3.1488187412620143`}, {5.809788104254051, 3.1488187412620143`}}, {{
       5.809788104254051, 3.1488187412620143`}, {5.733739775945973, 
       3.16613761318721}, {5.733739775945973, 3.16613761318721}, {
       5.809788104254051, 3.1488187412620143`}, {5.809788104254051, 
       3.1488187412620143`}}, {{5.733739775945973, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}, {5.733739775945973, 3.394939006257356}, {
       5.733739775945973, 3.394939006257356}}, {{5.733739775945973, 
       3.394939006257356}, {5.809788104254051, 3.4122578781825514`}, {
       5.809788104254051, 3.4122578781825514`}, {5.733739775945973, 
       3.394939006257356}, {5.733739775945973, 3.394939006257356}}, {{
       5.733739775945973, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}, {
       5.733739775945973, 3.394939006257356}, {5.733739775945973, 
       3.394939006257356}}, {{5.733739775945973, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}, {5.733739775945973, 3.394939006257356}, {
       5.733739775945973, 3.394939006257356}}, {{5.809788104254051, 
       3.4122578781825514`}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}}, {{
       5.809788104254051, 3.4122578781825514`}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}, {
       5.809788104254051, 3.4122578781825514`}, {5.809788104254051, 
       3.4122578781825514`}}, {{5.809788104254051, 3.4122578781825514`}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}, {5.809788104254051, 3.4122578781825514`}, {
       5.809788104254051, 3.4122578781825514`}}, {{5.809788104254051, 
       3.4122578781825514`}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}, {5.809788104254051, 
       3.4122578781825514`}, {5.809788104254051, 3.4122578781825514`}}, {{
       5.865838321825984, 3.394939006257356}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}, {{5.865838321825984, 3.394939006257356}, {
       5.908862013664058, 3.355057529915015}, {5.908862013664058, 
       3.355057529915015}, {5.865838321825984, 3.394939006257356}, {
       5.865838321825984, 3.394939006257356}}, {{5.865838321825984, 
       3.394939006257356}, {5.908862013664058, 3.355057529915015}, {
       5.908862013664058, 3.355057529915015}, {5.865838321825984, 
       3.394939006257356}, {5.865838321825984, 3.394939006257356}}, {{
       5.865838321825984, 3.394939006257356}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}, {
       5.865838321825984, 3.394939006257356}, {5.865838321825984, 
       3.394939006257356}}, {{5.908862013664058, 3.355057529915015}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}, {5.908862013664058, 3.355057529915015}, {
       5.908862013664058, 3.355057529915015}}, {{5.908862013664058, 
       3.355057529915015}, {5.931887594765989, 3.280538309722283}, {
       5.931887594765989, 3.280538309722283}, {5.908862013664058, 
       3.355057529915015}, {5.908862013664058, 3.355057529915015}}, {{
       5.908862013664058, 3.355057529915015}, {5.931887594765989, 
       3.280538309722283}, {5.931887594765989, 3.280538309722283}, {
       5.908862013664058, 3.355057529915015}, {5.908862013664058, 
       3.355057529915015}}, {{5.908862013664058, 3.355057529915015}, {
       5.931887594765989, 3.280538309722283}, {5.931887594765989, 
       3.280538309722283}, {5.908862013664058, 3.355057529915015}, {
       5.908862013664058, 3.355057529915015}}, {{5.694608372808513, 
       3.6104560912330017`}, {5.624622011390266, 3.6859565972995236`}, {
       5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.8369576094325684`}, {5.694608372808513, 3.9124581154990903`}, {
       5.694608372808513, 3.9124581154990903`}, {5.624622011390266, 
       3.8369576094325684`}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}}, {{
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}, {{5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.663096883426144}, {5.86896932281435, 
       3.6104560912330017`}, {5.794986909769825, 3.587596377359622}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}, {5.794986909769825, 3.587596377359622}, {
       5.86896932281435, 3.6104560912330017`}, {5.925757622274204, 
       3.663096883426144}, {5.95614979781727, 3.761457103366046}, {
       5.95614979781727, 3.761457103366046}}, {{5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}}, {{
       5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.86896932281435, 3.9124581154990903`}, {
       5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.86896932281435, 
       3.9124581154990903`}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}, {{5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}}, {{5.694608372808513, 
       3.6104560912330017`}, {5.624622011390266, 3.6859565972995236`}, {
       5.624622011390266, 3.6859565972995236`}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}}, {{
       5.694608372808513, 3.6104560912330017`}, {5.624622011390266, 
       3.6859565972995236`}, {5.624622011390266, 3.6859565972995236`}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}}, {{5.694608372808513, 3.6104560912330017`}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}, {5.694608372808513, 3.6104560912330017`}, {
       5.694608372808513, 3.6104560912330017`}}, {{5.694608372808513, 
       3.6104560912330017`}, {5.624622011390266, 3.6859565972995236`}, {
       5.624622011390266, 3.6859565972995236`}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}}, {{
       5.624622011390266, 3.6859565972995236`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}}, {{5.624622011390266, 3.6859565972995236`}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}, {5.624622011390266, 3.6859565972995236`}, {
       5.624622011390266, 3.6859565972995236`}}, {{5.624622011390266, 
       3.6859565972995236`}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.6859565972995236`}, {5.624622011390266, 3.6859565972995236`}}, {{
       5.624622011390266, 3.6859565972995236`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.6859565972995236`}, {5.624622011390266, 
       3.6859565972995236`}}, {{5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}}, {{5.607427897805593, 
       3.761457103366046}, {5.624622011390266, 3.8369576094325684`}, {
       5.624622011390266, 3.8369576094325684`}, {5.607427897805593, 
       3.761457103366046}, {5.607427897805593, 3.761457103366046}}, {{
       5.607427897805593, 3.761457103366046}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}, {
       5.607427897805593, 3.761457103366046}, {5.607427897805593, 
       3.761457103366046}}, {{5.607427897805593, 3.761457103366046}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}, {5.607427897805593, 3.761457103366046}, {
       5.607427897805593, 3.761457103366046}}, {{5.624622011390266, 
       3.8369576094325684`}, {5.694608372808513, 3.9124581154990903`}, {
       5.694608372808513, 3.9124581154990903`}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}}, {{
       5.624622011390266, 3.8369576094325684`}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}, {
       5.624622011390266, 3.8369576094325684`}, {5.624622011390266, 
       3.8369576094325684`}}, {{5.624622011390266, 3.8369576094325684`}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}, {5.624622011390266, 3.8369576094325684`}, {
       5.624622011390266, 3.8369576094325684`}}, {{5.624622011390266, 
       3.8369576094325684`}, {5.694608372808513, 3.9124581154990903`}, {
       5.694608372808513, 3.9124581154990903`}, {5.624622011390266, 
       3.8369576094325684`}, {5.624622011390266, 3.8369576094325684`}}, {{
       5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}, {{5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.663096883426144}, {5.925757622274204, 
       3.663096883426144}, {5.95614979781727, 3.761457103366046}, {
       5.95614979781727, 3.761457103366046}}, {{5.95614979781727, 
       3.761457103366046}, {5.925757622274204, 3.663096883426144}, {
       5.925757622274204, 3.663096883426144}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}}, {{
       5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}}, {{5.925757622274204, 3.663096883426144}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.925757622274204, 3.663096883426144}, {
       5.925757622274204, 3.663096883426144}}, {{5.925757622274204, 
       3.663096883426144}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}, {5.925757622274204, 
       3.663096883426144}, {5.925757622274204, 3.663096883426144}}, {{
       5.925757622274204, 3.663096883426144}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}, {
       5.925757622274204, 3.663096883426144}, {5.925757622274204, 
       3.663096883426144}}, {{5.925757622274204, 3.663096883426144}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}, {5.925757622274204, 3.663096883426144}, {
       5.925757622274204, 3.663096883426144}}, {{5.86896932281435, 
       3.6104560912330017`}, {5.794986909769825, 3.587596377359622}, {
       5.794986909769825, 3.587596377359622}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}}, {{
       5.86896932281435, 3.6104560912330017`}, {5.794986909769825, 
       3.587596377359622}, {5.794986909769825, 3.587596377359622}, {
       5.86896932281435, 3.6104560912330017`}, {5.86896932281435, 
       3.6104560912330017`}}, {{5.86896932281435, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}, {5.86896932281435, 3.6104560912330017`}, {
       5.86896932281435, 3.6104560912330017`}}, {{5.86896932281435, 
       3.6104560912330017`}, {5.794986909769825, 3.587596377359622}, {
       5.794986909769825, 3.587596377359622}, {5.86896932281435, 
       3.6104560912330017`}, {5.86896932281435, 3.6104560912330017`}}, {{
       5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}}, {{5.794986909769825, 3.587596377359622}, {
       5.694608372808513, 3.6104560912330017`}, {5.694608372808513, 
       3.6104560912330017`}, {5.794986909769825, 3.587596377359622}, {
       5.794986909769825, 3.587596377359622}}, {{5.794986909769825, 
       3.587596377359622}, {5.694608372808513, 3.6104560912330017`}, {
       5.694608372808513, 3.6104560912330017`}, {5.794986909769825, 
       3.587596377359622}, {5.794986909769825, 3.587596377359622}}, {{
       5.794986909769825, 3.587596377359622}, {5.694608372808513, 
       3.6104560912330017`}, {5.694608372808513, 3.6104560912330017`}, {
       5.794986909769825, 3.587596377359622}, {5.794986909769825, 
       3.587596377359622}}, {{5.694608372808513, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}, {5.694608372808513, 3.9124581154990903`}, {
       5.694608372808513, 3.9124581154990903`}}, {{5.694608372808513, 
       3.9124581154990903`}, {5.794986909769825, 3.93531782937247}, {
       5.794986909769825, 3.93531782937247}, {5.694608372808513, 
       3.9124581154990903`}, {5.694608372808513, 3.9124581154990903`}}, {{
       5.694608372808513, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}, {
       5.694608372808513, 3.9124581154990903`}, {5.694608372808513, 
       3.9124581154990903`}}, {{5.694608372808513, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}, {5.694608372808513, 3.9124581154990903`}, {
       5.694608372808513, 3.9124581154990903`}}, {{5.794986909769825, 
       3.93531782937247}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}}, {{
       5.794986909769825, 3.93531782937247}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}, {
       5.794986909769825, 3.93531782937247}, {5.794986909769825, 
       3.93531782937247}}, {{5.794986909769825, 3.93531782937247}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}, {5.794986909769825, 3.93531782937247}, {
       5.794986909769825, 3.93531782937247}}, {{5.794986909769825, 
       3.93531782937247}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}, {5.794986909769825, 
       3.93531782937247}, {5.794986909769825, 3.93531782937247}}, {{
       5.86896932281435, 3.9124581154990903`}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}, {{5.86896932281435, 3.9124581154990903`}, {
       5.925757622274204, 3.859817323305948}, {5.925757622274204, 
       3.859817323305948}, {5.86896932281435, 3.9124581154990903`}, {
       5.86896932281435, 3.9124581154990903`}}, {{5.86896932281435, 
       3.9124581154990903`}, {5.925757622274204, 3.859817323305948}, {
       5.925757622274204, 3.859817323305948}, {5.86896932281435, 
       3.9124581154990903`}, {5.86896932281435, 3.9124581154990903`}}, {{
       5.86896932281435, 3.9124581154990903`}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}, {
       5.86896932281435, 3.9124581154990903`}, {5.86896932281435, 
       3.9124581154990903`}}, {{5.925757622274204, 3.859817323305948}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}, {5.925757622274204, 3.859817323305948}, {
       5.925757622274204, 3.859817323305948}}, {{5.925757622274204, 
       3.859817323305948}, {5.95614979781727, 3.761457103366046}, {
       5.95614979781727, 3.761457103366046}, {5.925757622274204, 
       3.859817323305948}, {5.925757622274204, 3.859817323305948}}, {{
       5.925757622274204, 3.859817323305948}, {5.95614979781727, 
       3.761457103366046}, {5.95614979781727, 3.761457103366046}, {
       5.925757622274204, 3.859817323305948}, {5.925757622274204, 
       3.859817323305948}}, {{5.925757622274204, 3.859817323305948}, {
       5.95614979781727, 3.761457103366046}, {5.95614979781727, 
       3.761457103366046}, {5.925757622274204, 3.859817323305948}, {
       5.925757622274204, 3.859817323305948}}, {{
       5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}, {{
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}, {{
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}, {{
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}, {{
       5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}, {{
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}, {{
       5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}, {{
       5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}, {{
       5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}, {{
       5.899372678276874, -4.687544257642998}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}}, {{
       5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}, {{
       5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}, {{
       5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}, {{
       5.829929521242306, -4.612629754406659}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.612629754406659}, {
       5.829929521242306, -4.612629754406659}}, {{
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}, {{
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}, {{
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}, {{
       5.812868861057459, -4.53771525117032}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}, {
       5.812868861057459, -4.53771525117032}, {
       5.812868861057459, -4.53771525117032}}, {{
       5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}, {{
       5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}, {{
       5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}, {{
       5.829929521242306, -4.46280074793398}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}, {
       5.829929521242306, -4.46280074793398}, {
       5.829929521242306, -4.46280074793398}}, {{
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}, {{
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}, {{
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}, {{
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}}, {{
       6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}, {{
       6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}, {{
       6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}, {{
       6.128727845537843, -4.635312040899417}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}, {
       6.128727845537843, -4.635312040899417}, {
       6.128727845537843, -4.635312040899417}}, {{
       6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}, {{
       6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}, {{
       6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}, {{
       6.072380312715705, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}, {
       6.072380312715705, -4.687544257642998}, {
       6.072380312715705, -4.687544257642998}}, {{
       5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}, {{
       5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}, {{
       5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}, {{
       5.99897211970872, -4.7102265441357565`}, {
       5.899372678276874, -4.687544257642998}, {
       5.899372678276874, -4.687544257642998}, {
       5.99897211970872, -4.7102265441357565`}, {
       5.99897211970872, -4.7102265441357565`}}, {{
       5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}, {{
       5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}, {{
       5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}, {{
       5.899372678276874, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}, {
       5.899372678276874, -4.387886244697641}, {
       5.899372678276874, -4.387886244697641}}, {{
       5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}, {{
       5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}, {{
       5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}, {{
       5.99897211970872, -4.365203958204883}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}, {
       5.99897211970872, -4.365203958204883}, {
       5.99897211970872, -4.365203958204883}}, {{
       6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}, {{
       6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}, {{
       6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}, {{
       6.072380312715705, -4.387886244697641}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}, {
       6.072380312715705, -4.387886244697641}, {
       6.072380312715705, -4.387886244697641}}, {{
       6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}, {{
       6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}, {{
       6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}, {{
       6.128727845537843, -4.440118461441222}, {
       6.15888412993512, -4.53771525117032}, {
       6.15888412993512, -4.53771525117032}, {
       6.128727845537843, -4.440118461441222}, {
       6.128727845537843, -4.440118461441222}}, {{
       5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.894017592219742, -3.8507944434571098`}, {
       5.894017592219742, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}, {{
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}, {{
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}, {{
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}, {{
       5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}, {{
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}, {{
       5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}, {{
       5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}, {{
       5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}, {{
       5.894017592219742, -4.121193095215112}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}, {
       5.894017592219742, -4.121193095215112}, {
       5.894017592219742, -4.121193095215112}}, {{
       5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}, {{
       5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}, {{
       5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}, {{
       5.831355039493711, -4.053593432275612}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -4.053593432275612}, {
       5.831355039493711, -4.053593432275612}}, {{
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}, {{
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}, {{
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}, {{
       5.8159602250292455`, -3.985993769336111}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.8159602250292455`, -3.985993769336111}, {
       5.8159602250292455`, -3.985993769336111}}, {{
       5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}, {{
       5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}, {{
       5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}, {{
       5.831355039493711, -3.9183941063966103`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.831355039493711, -3.9183941063966103`}, {
       5.831355039493711, -3.9183941063966103`}}, {{
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}, {{
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}, {{
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}, {{
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}}, {{
       6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}, {{
       6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}, {{
       6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}, {{
       6.100977944761378, -4.074060963332586}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}, {
       6.100977944761378, -4.074060963332586}, {
       6.100977944761378, -4.074060963332586}}, {{
       6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}, {{
       6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}, {{
       6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}, {{
       6.050132326600737, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}, {
       6.050132326600737, -4.121193095215112}, {
       6.050132326600737, -4.121193095215112}}, {{
       5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}, {{
       5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}, {{
       5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}, {{
       5.983891893975632, -4.141660626272087}, {
       5.894017592219743, -4.121193095215112}, {
       5.894017592219743, -4.121193095215112}, {
       5.983891893975632, -4.141660626272087}, {
       5.983891893975632, -4.141660626272087}}, {{
       5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}, {{
       5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}, {{
       5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}, {{
       5.894017592219743, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.894017592219743, -3.8507944434571098`}, {
       5.894017592219743, -3.8507944434571098`}}, {{
       5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}, {{
       5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}, {{
       5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}, {{
       5.983891893975632, -3.8303269124001345`}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}, {
       5.983891893975632, -3.8303269124001345`}, {
       5.983891893975632, -3.8303269124001345`}}, {{
       6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}, {{
       6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}, {{
       6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}, {{
       6.050132326600737, -3.8507944434571098`}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}, {
       6.050132326600737, -3.8507944434571098`}, {
       6.050132326600737, -3.8507944434571098`}}, {{
       6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}, {{
       6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}, {{
       6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}, {{
       6.100977944761378, -3.897926575339635}, {
       6.128189693791235, -3.985993769336111}, {
       6.128189693791235, -3.985993769336111}, {
       6.100977944761378, -3.897926575339635}, {
       6.100977944761378, -3.897926575339635}}, {{
       5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}, {{
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}, {{
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}, {{
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}, {{
       5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}, {{
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}, {{
       5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}, {{
       5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}, {{
       5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}, {{
       5.944596379818668, -3.6478872630710812`}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}}, {{
       5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}, {{
       5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}, {{
       5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}, {{
       5.883667863946784, -3.582158259748299}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.582158259748299}, {
       5.883667863946784, -3.582158259748299}}, {{
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}, {{
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}, {{
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}, {{
       5.86869906429472, -3.516429256425517}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.86869906429472, -3.516429256425517}, {
       5.86869906429472, -3.516429256425517}}, {{
       5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}, {{
       5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}, {{
       5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}, {{
       5.883667863946784, -3.4507002531027346`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.883667863946784, -3.4507002531027346`}, {
       5.883667863946784, -3.4507002531027346`}}, {{
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}, {{
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}, {{
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}, {{
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}}, {{
       6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}, {{
       6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}, {{
       6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}, {{
       6.145829597683494, -3.602059400646843}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.145829597683494, -3.602059400646843}, {
       6.145829597683494, -3.602059400646843}}, {{
       6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}, {{
       6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}, {{
       6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}, {{
       6.096391010866565, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}, {
       6.096391010866565, -3.6478872630710812`}, {
       6.096391010866565, -3.6478872630710812`}}, {{
       6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}, {{
       6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}, {{
       6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}, {{
       6.031983624397571, -3.667788403969625}, {
       5.944596379818668, -3.6478872630710812`}, {
       5.944596379818668, -3.6478872630710812`}, {
       6.031983624397571, -3.667788403969625}, {
       6.031983624397571, -3.667788403969625}}, {{
       5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}, {{
       5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}, {{
       5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}, {{
       5.944596379818668, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}, {
       5.944596379818668, -3.3849712497799525`}, {
       5.944596379818668, -3.3849712497799525`}}, {{
       6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}, {{
       6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}, {{
       6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}, {{
       6.031983624397571, -3.3650701088814086`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.031983624397571, -3.3650701088814086`}, {
       6.031983624397571, -3.3650701088814086`}}, {{
       6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}, {{
       6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}, {{
       6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}, {{
       6.096391010866565, -3.3849712497799525`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.096391010866565, -3.3849712497799525`}, {
       6.096391010866565, -3.3849712497799525`}}, {{
       6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}, {{
       6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}, {{
       6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}, {{
       6.145829597683494, -3.4307991122041908`}, {
       6.172288326390513, -3.516429256425517}, {
       6.172288326390513, -3.516429256425517}, {
       6.145829597683494, -3.4307991122041908`}, {
       6.145829597683494, -3.4307991122041908`}}, {{
       5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}, {{
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}, {{
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}, {{
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}, {{
       5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}, {{
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}, {{
       5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}, {{
       5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}, {{
       5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}, {{
       5.915060368162928, -3.1493092647252503`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}}, {{
       5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}, {{
       5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}, {{
       5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}, {{
       5.8441121732411165`, -3.072771143403423}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -3.072771143403423}, {
       5.8441121732411165`, -3.072771143403423}}, {{
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}, {{
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}, {{
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}, {{
       5.826681758266077, -2.9962330220815954`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.826681758266077, -2.9962330220815954`}, {
       5.826681758266077, -2.9962330220815954`}}, {{
       5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}, {{
       5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}, {{
       5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}, {{
       5.8441121732411165`, -2.919694900759768}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.8441121732411165`, -2.919694900759768}, {
       5.8441121732411165`, -2.919694900759768}}, {{
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}, {{
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}, {{
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}, {{
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}}, {{
       6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}, {{
       6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}, {{
       6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}, {{
       6.149386337891748, -3.095945021897448}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.149386337891748, -3.095945021897448}, {
       6.149386337891748, -3.095945021897448}}, {{
       6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}, {{
       6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}, {{
       6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}, {{
       6.09181758795663, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.09181758795663, -3.1493092647252503`}, {
       6.09181758795663, -3.1493092647252503`}}, {{
       6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}, {{
       6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}, {{
       6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}, {{
       6.016818423046472, -3.1724831432192753`}, {
       5.915060368162928, -3.1493092647252503`}, {
       5.915060368162928, -3.1493092647252503`}, {
       6.016818423046472, -3.1724831432192753`}, {
       6.016818423046472, -3.1724831432192753`}}, {{
       5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}, {{
       5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}, {{
       5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}, {{
       5.915060368162928, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}, {
       5.915060368162928, -2.8431567794379404`}, {
       5.915060368162928, -2.8431567794379404`}}, {{
       6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}, {{
       6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}, {{
       6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}, {{
       6.016818423046472, -2.8199829009439155`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.016818423046472, -2.8199829009439155`}, {
       6.016818423046472, -2.8199829009439155`}}, {{
       6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}, {{
       6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}, {{
       6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}, {{
       6.09181758795663, -2.8431567794379404`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}, {
       6.09181758795663, -2.8431567794379404`}, {
       6.09181758795663, -2.8431567794379404`}}, {{
       6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}, {{
       6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}, {{
       6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}, {{
       6.149386337891748, -2.896521022265743}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.180196197853481, -2.9962330220815954`}, {
       6.149386337891748, -2.896521022265743}, {
       6.149386337891748, -2.896521022265743}}, {{
       5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}, {{
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}, {{
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}, {{
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}, {{
       5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}, {{
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}, {{
       5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}, {{
       5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}, {{
       5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}, {{
       5.95477875910403, -2.648898537662729}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}}, {{
       5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}, {{
       5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}, {{
       5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}, {{
       5.902504386811693, -2.5925055279047986`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.5925055279047986`}, {
       5.902504386811693, -2.5925055279047986`}}, {{
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}, {{
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}, {{
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}, {{
       5.889661720375722, -2.5361125181468682`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}, {
       5.889661720375722, -2.5361125181468682`}, {
       5.889661720375722, -2.5361125181468682`}}, {{
       5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}, {{
       5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}, {{
       5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}, {{
       5.902504386811693, -2.479719508388938}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.902504386811693, -2.479719508388938}, {
       5.902504386811693, -2.479719508388938}}, {{
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}, {{
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}, {{
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}, {{
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}}, {{
       6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}, {{
       6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}, {{
       6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}, {{
       6.127429282388893, -2.609579957397883}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}, {
       6.127429282388893, -2.609579957397883}, {
       6.127429282388893, -2.609579957397883}}, {{
       6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}, {{
       6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}, {{
       6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}, {{
       6.085012836560647, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.085012836560647, -2.648898537662729}, {
       6.085012836560647, -2.648898537662729}}, {{
       6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}, {{
       6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}, {{
       6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}, {{
       6.02975372429643, -2.6659729671558132`}, {
       5.95477875910403, -2.648898537662729}, {
       5.95477875910403, -2.648898537662729}, {
       6.02975372429643, -2.6659729671558132`}, {
       6.02975372429643, -2.6659729671558132`}}, {{
       5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}, {{
       5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}, {{
       5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}, {{
       5.95477875910403, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}, {
       5.95477875910403, -2.4233264986310075`}, {
       5.95477875910403, -2.4233264986310075`}}, {{
       6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}, {{
       6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}, {{
       6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}, {{
       6.02975372429643, -2.406252069137923}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.02975372429643, -2.406252069137923}, {
       6.02975372429643, -2.406252069137923}}, {{
       6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}, {{
       6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}, {{
       6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}, {{
       6.085012836560647, -2.4233264986310075`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.085012836560647, -2.4233264986310075`}, {
       6.085012836560647, -2.4233264986310075`}}, {{
       6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}, {{
       6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}, {{
       6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}, {{
       6.127429282388893, -2.4626450788958536`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.150129875288956, -2.5361125181468682`}, {
       6.127429282388893, -2.4626450788958536`}, {
       6.127429282388893, -2.4626450788958536`}}, {{
       5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.0186886122810392`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}, {{
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}, {{
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}, {{
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}, {{
       5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}, {{
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}, {{
       5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}, {{
       5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}, {{
       5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}, {{
       5.976878859258512, -2.0708937125413054`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}}, {{
       5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}, {{
       5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}, {{
       5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}, {{
       5.928486534424667, -2.018688612281039}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -2.018688612281039}, {
       5.928486534424667, -2.018688612281039}}, {{
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}, {{
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}, {{
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}, {{
       5.916597601881839, -1.9664835120207724`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.916597601881839, -1.9664835120207724`}, {
       5.916597601881839, -1.9664835120207724`}}, {{
       5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}, {{
       5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}, {{
       5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}, {{
       5.928486534424667, -1.9142784117605058`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.928486534424667, -1.9142784117605058`}, {
       5.928486534424667, -1.9142784117605058`}}, {{
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}, {{
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}, {{
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}, {{
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}}, {{
       6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}, {{
       6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}, {{
       6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}, {{
       6.136707850772948, -2.0344950448052037`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.136707850772948, -2.0344950448052037`}, {
       6.136707850772948, -2.0344950448052037`}}, {{
       6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}, {{
       6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}, {{
       6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}, {{
       6.097441374011857, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.097441374011857, -2.0708937125413054`}, {
       6.097441374011857, -2.0708937125413054`}}, {{
       6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}, {{
       6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}, {{
       6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}, {{
       6.0462859647079386`, -2.0867001450654703`}, {
       5.976878859258512, -2.0708937125413054`}, {
       5.976878859258512, -2.0708937125413054`}, {
       6.0462859647079386`, -2.0867001450654703`}, {
       6.0462859647079386`, -2.0867001450654703`}}, {{
       5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}, {{
       5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}, {{
       5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}, {{
       5.976878859258512, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       5.976878859258512, -1.8620733115002392`}, {
       5.976878859258512, -1.8620733115002392`}}, {{
       6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}, {{
       6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}, {{
       6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}, {{
       6.0462859647079386`, -1.8462668789760743`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.0462859647079386`, -1.8462668789760743`}, {
       6.0462859647079386`, -1.8462668789760743`}}, {{
       6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}, {{
       6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}, {{
       6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}, {{
       6.097441374011857, -1.8620733115002392`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}, {
       6.097441374011857, -1.8620733115002392`}, {
       6.097441374011857, -1.8620733115002392`}}, {{
       6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}, {{
       6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}, {{
       6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}, {{
       6.136707850772948, -1.898471979236341}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.15772263138853, -1.9664835120207724`}, {
       6.136707850772948, -1.898471979236341}, {
       6.136707850772948, -1.898471979236341}}, {{
       5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}, {{
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}, {{
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}, {{
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}, {{
       5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}, {{
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}, {{
       5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}, {{
       5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}, {{
       5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}, {{
       5.8811113127349435`, -1.6178580569774688`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}}, {{
       5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}, {{
       5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}, {{
       5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}, {{
       5.816752939926914, -1.5484289622487746`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.5484289622487746`}, {
       5.816752939926914, -1.5484289622487746`}}, {{
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}, {{
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}, {{
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}, {{
       5.800941499672536, -1.4789998675200802`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.800941499672536, -1.4789998675200802`}, {
       5.800941499672536, -1.4789998675200802`}}, {{
       5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}, {{
       5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}, {{
       5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}, {{
       5.816752939926914, -1.4095707727913858`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.816752939926914, -1.4095707727913858`}, {
       5.816752939926914, -1.4095707727913858`}}, {{
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}, {{
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}, {{
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}, {{
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}}, {{
       6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}, {{
       6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}, {{
       6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}, {{
       6.093672578529374, -1.56945040068241}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.093672578529374, -1.56945040068241}, {
       6.093672578529374, -1.56945040068241}}, {{
       6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}, {{
       6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}, {{
       6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}, {{
       6.041450938859758, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}, {
       6.041450938859758, -1.6178580569774688`}, {
       6.041450938859758, -1.6178580569774688`}}, {{
       5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}, {{
       5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}, {{
       5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}, {{
       5.973417858935764, -1.6388794954111043`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.8811113127349435`, -1.6178580569774688`}, {
       5.973417858935764, -1.6388794954111043`}, {
       5.973417858935764, -1.6388794954111043`}}, {{
       5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}, {{
       5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}, {{
       5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}, {{
       5.8811113127349435`, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}, {
       5.8811113127349435`, -1.3401416780626916`}, {
       5.8811113127349435`, -1.3401416780626916`}}, {{
       5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}, {{
       5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}, {{
       5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}, {{
       5.973417858935764, -1.319120239629056}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}, {
       5.973417858935764, -1.319120239629056}, {
       5.973417858935764, -1.319120239629056}}, {{
       6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}, {{
       6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}, {{
       6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}, {{
       6.041450938859758, -1.3401416780626916`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.041450938859758, -1.3401416780626916`}, {
       6.041450938859758, -1.3401416780626916`}}, {{
       6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}, {{
       6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}, {{
       6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}, {{
       6.093672578529374, -1.3885493343577504`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.1216207519221655`, -1.4789998675200802`}, {
       6.093672578529374, -1.3885493343577504`}, {
       6.093672578529374, -1.3885493343577504`}}, {{
       5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268429}, {
       5.949201054112538, -0.8547672606268429}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}, {{
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}, {{
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}, {{
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}, {{
       5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}, {{
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}, {{
       5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}, {{
       5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}, {{
       5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}, {{
       5.949201054112538, -1.119090944136998}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}}, {{
       5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}, {{
       5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}, {{
       5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}, {{
       5.887946322822244, -1.0530100232594592`}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -1.0530100232594592`}, {
       5.887946322822244, -1.0530100232594592`}}, {{
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}, {{
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}, {{
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}, {{
       5.872897379198647, -0.9869291023819204}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}, {
       5.872897379198647, -0.9869291023819204}, {
       5.872897379198647, -0.9869291023819204}}, {{
       5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}, {{
       5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}, {{
       5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}, {{
       5.887946322822244, -0.9208481815043816}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}, {
       5.887946322822244, -0.9208481815043816}, {
       5.887946322822244, -0.9208481815043816}}, {{
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}, {{
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}, {{
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}, {{
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}}, {{
       6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}, {{
       6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}, {{
       6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}, {{
       6.1515116883139385`, -1.0730177162200736`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}, {
       6.1515116883139385`, -1.0730177162200736`}, {
       6.1515116883139385`, -1.0730177162200736`}}, {{
       6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}, {{
       6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}, {{
       6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}, {{
       6.101808403940319, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.101808403940319, -1.119090944136998}, {
       6.101808403940319, -1.119090944136998}}, {{
       6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}, {{
       6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}, {{
       6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}, {{
       6.0370561759431025`, -1.1390986370976122`}, {
       5.949201054112538, -1.119090944136998}, {
       5.949201054112538, -1.119090944136998}, {
       6.0370561759431025`, -1.1390986370976122`}, {
       6.0370561759431025`, -1.1390986370976122`}}, {{
       5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}, {{
       5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}, {{
       5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}, {{
       5.949201054112538, -0.8547672606268428}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}, {
       5.949201054112538, -0.8547672606268428}, {
       5.949201054112538, -0.8547672606268428}}, {{
       6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}, {{
       6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}, {{
       6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}, {{
       6.0370561759431025`, -0.8347595676662286}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}, {
       6.0370561759431025`, -0.8347595676662286}, {
       6.0370561759431025`, -0.8347595676662286}}, {{
       6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}, {{
       6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}, {{
       6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}, {{
       6.101808403940319, -0.8547672606268429}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.101808403940319, -0.8547672606268429}, {
       6.101808403940319, -0.8547672606268429}}, {{
       6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}, {{
       6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}, {{
       6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}, {{
       6.1515116883139385`, -0.9008404885437674}, {
       6.17811207885421, -0.9869291023819204}, {
       6.17811207885421, -0.9869291023819204}, {
       6.1515116883139385`, -0.9008404885437674}, {
       6.1515116883139385`, -0.9008404885437674}}, {{
       5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.3683182130957874}, {
       5.887887880466244, -0.3683182130957874}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}, {{
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}, {{
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}, {{
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}, {{
       5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}, {{
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}, {{
       5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}, {{
       5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}, {{
       5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}, {{
       5.887887880466244, -0.6027221586252247}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}}, {{
       5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}, {{
       5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}, {{
       5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}, {{
       5.8335667901041734`, -0.5441211722428654}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.5441211722428654}, {
       5.8335667901041734`, -0.5441211722428654}}, {{
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}, {{
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}, {{
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}, {{
       5.820221289940978, -0.48552018586050605`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.820221289940978, -0.48552018586050605`}, {
       5.820221289940978, -0.48552018586050605`}}, {{
       5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}, {{
       5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}, {{
       5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}, {{
       5.8335667901041734`, -0.4269191994781467}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.8335667901041734`, -0.4269191994781467}, {
       5.8335667901041734`, -0.4269191994781467}}, {{
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}, {{
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}, {{
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}, {{
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}}, {{
       6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}, {{
       6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}, {{
       6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}, {{
       6.067298254329126, -0.5618641232665081}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}, {
       6.067298254329126, -0.5618641232665081}, {
       6.067298254329126, -0.5618641232665081}}, {{
       6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}, {{
       6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}, {{
       6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}, {{
       6.023221061516774, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}, {
       6.023221061516774, -0.6027221586252247}, {
       6.023221061516774, -0.6027221586252247}}, {{
       5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}, {{
       5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}, {{
       5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}, {{
       5.965798368541227, -0.6204651096488676}, {
       5.887887880466244, -0.6027221586252247}, {
       5.887887880466244, -0.6027221586252247}, {
       5.965798368541227, -0.6204651096488676}, {
       5.965798368541227, -0.6204651096488676}}, {{
       5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}, {{
       5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}, {{
       5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}, {{
       5.887887880466244, -0.36831821309578733`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.887887880466244, -0.36831821309578733`}, {
       5.887887880466244, -0.36831821309578733`}}, {{
       5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}, {{
       5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}, {{
       5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}, {{
       5.965798368541227, -0.35057526207214457`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}, {
       5.965798368541227, -0.35057526207214457`}, {
       5.965798368541227, -0.35057526207214457`}}, {{
       6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}, {{
       6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}, {{
       6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}, {{
       6.023221061516774, -0.3683182130957874}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.023221061516774, -0.3683182130957874}, {
       6.023221061516774, -0.3683182130957874}}, {{
       6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}, {{
       6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}, {{
       6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}, {{
       6.067298254329126, -0.40917624845450395`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.09088765204204, -0.48552018586050605`}, {
       6.067298254329126, -0.40917624845450395`}, {
       6.067298254329126, -0.40917624845450395`}}, {{
       5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, 0.09524424099391537}, {
       5.937816157286512, 0.1705497532096615}, {5.937816157286512, 
       0.1705497532096615}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, -0.05536678343757695}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}, {{5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}}, {{
       6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.1306722956533231}, {
       5.937816157286512, -0.1306722956533231}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}, {{
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}, {{5.937816157286512, 
       0.17054975320966154`}, {6.037935448337073, 0.19335042769551855`}, {
       6.1117267882834065`, 0.1705497532096615}, {6.168368421584745, 
       0.1180449154797724}, {6.198682103781854, 0.019938728778169233`}, {
       6.198682103781854, 0.019938728778169233`}, {6.168368421584745, 
       0.1180449154797724}, {6.1117267882834065`, 0.1705497532096615}, {
       6.037935448337073, 0.19335042769551855`}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}}, {{
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}}, {{5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}, {{
       5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}, {{
       5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}, {{
       5.937816157286512, -0.13067229565332308`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}}, {{
       5.868010548433059, -0.055366783437576936`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}, {{
       5.868010548433059, -0.055366783437576936`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}, {{
       5.868010548433059, -0.055366783437576936`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}, {{
       5.868010548433059, -0.055366783437576936`}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, -0.055366783437576936`}, {
       5.868010548433059, -0.055366783437576936`}}, {{5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, 0.09524424099391536}, {
       5.868010548433059, 0.09524424099391536}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}}, {{
       5.850860841788064, 0.019938728778169212`}, {5.868010548433059, 
       0.09524424099391536}, {5.868010548433059, 0.09524424099391536}, {
       5.850860841788064, 0.019938728778169212`}, {5.850860841788064, 
       0.019938728778169212`}}, {{5.850860841788064, 0.019938728778169212`}, {
       5.868010548433059, 0.09524424099391536}, {5.868010548433059, 
       0.09524424099391536}, {5.850860841788064, 0.019938728778169212`}, {
       5.850860841788064, 0.019938728778169212`}}, {{5.850860841788064, 
       0.019938728778169212`}, {5.868010548433059, 0.09524424099391536}, {
       5.868010548433059, 0.09524424099391536}, {5.850860841788064, 
       0.019938728778169212`}, {5.850860841788064, 0.019938728778169212`}}, {{
       5.868010548433059, 0.09524424099391537}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}, {
       5.868010548433059, 0.09524424099391537}, {5.868010548433059, 
       0.09524424099391537}}, {{5.868010548433059, 0.09524424099391537}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}, {5.868010548433059, 0.09524424099391537}, {
       5.868010548433059, 0.09524424099391537}}, {{5.868010548433059, 
       0.09524424099391537}, {5.937816157286512, 0.17054975320966154`}, {
       5.937816157286512, 0.17054975320966154`}, {5.868010548433059, 
       0.09524424099391537}, {5.868010548433059, 0.09524424099391537}}, {{
       5.868010548433059, 0.09524424099391537}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}, {
       5.868010548433059, 0.09524424099391537}, {5.868010548433059, 
       0.09524424099391537}}, {{6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}, {{
       6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}, {{
       6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}, {{
       6.198682103781854, 0.01993872877816919}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}, {6.198682103781854, 
       0.01993872877816919}, {6.198682103781854, 0.01993872877816919}}, {{
       6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}, {{
       6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}, {{
       6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}, {{
       6.168368421584745, -0.07816745792343398}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.168368421584745, -0.07816745792343398}, {
       6.168368421584745, -0.07816745792343398}}, {{
       6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}, {{
       6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}, {{
       6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}, {{
       6.1117267882834065`, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.1117267882834065`, -0.13067229565332308`}, {
       6.1117267882834065`, -0.13067229565332308`}}, {{
       6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}, {{
       6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}, {{
       6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}, {{
       6.037935448337073, -0.15347297013918013`}, {
       5.937816157286512, -0.13067229565332308`}, {
       5.937816157286512, -0.13067229565332308`}, {
       6.037935448337073, -0.15347297013918013`}, {
       6.037935448337073, -0.15347297013918013`}}, {{5.937816157286512, 
       0.17054975320966154`}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}}, {{
       5.937816157286512, 0.17054975320966154`}, {6.037935448337073, 
       0.19335042769551855`}, {6.037935448337073, 0.19335042769551855`}, {
       5.937816157286512, 0.17054975320966154`}, {5.937816157286512, 
       0.17054975320966154`}}, {{5.937816157286512, 0.17054975320966154`}, {
       6.037935448337073, 0.19335042769551855`}, {6.037935448337073, 
       0.19335042769551855`}, {5.937816157286512, 0.17054975320966154`}, {
       5.937816157286512, 0.17054975320966154`}}, {{5.937816157286512, 
       0.17054975320966154`}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}, {5.937816157286512, 
       0.17054975320966154`}, {5.937816157286512, 0.17054975320966154`}}, {{
       6.037935448337073, 0.19335042769551855`}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.037935448337073, 0.19335042769551855`}, {6.037935448337073, 
       0.19335042769551855`}}, {{6.037935448337073, 0.19335042769551855`}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}, {6.037935448337073, 0.19335042769551855`}, {
       6.037935448337073, 0.19335042769551855`}}, {{6.037935448337073, 
       0.19335042769551855`}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}, {6.037935448337073, 
       0.19335042769551855`}, {6.037935448337073, 0.19335042769551855`}}, {{
       6.037935448337073, 0.19335042769551855`}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}, {
       6.037935448337073, 0.19335042769551855`}, {6.037935448337073, 
       0.19335042769551855`}}, {{6.1117267882834065`, 0.1705497532096615}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}}, {{6.1117267882834065`, 
       0.1705497532096615}, {6.168368421584745, 0.1180449154797724}, {
       6.168368421584745, 0.1180449154797724}, {6.1117267882834065`, 
       0.1705497532096615}, {6.1117267882834065`, 0.1705497532096615}}, {{
       6.1117267882834065`, 0.1705497532096615}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}, {
       6.1117267882834065`, 0.1705497532096615}, {6.1117267882834065`, 
       0.1705497532096615}}, {{6.1117267882834065`, 0.1705497532096615}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}, {6.1117267882834065`, 0.1705497532096615}, {
       6.1117267882834065`, 0.1705497532096615}}, {{6.168368421584745, 
       0.1180449154797724}, {6.198682103781854, 0.019938728778169185`}, {
       6.198682103781854, 0.019938728778169185`}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}}, {{
       6.168368421584745, 0.1180449154797724}, {6.198682103781854, 
       0.019938728778169185`}, {6.198682103781854, 0.019938728778169185`}, {
       6.168368421584745, 0.1180449154797724}, {6.168368421584745, 
       0.1180449154797724}}, {{6.168368421584745, 0.1180449154797724}, {
       6.198682103781854, 0.019938728778169185`}, {6.198682103781854, 
       0.019938728778169185`}, {6.168368421584745, 0.1180449154797724}, {
       6.168368421584745, 0.1180449154797724}}, {{6.168368421584745, 
       0.1180449154797724}, {6.198682103781854, 0.019938728778169185`}, {
       6.198682103781854, 0.019938728778169185`}, {6.168368421584745, 
       0.1180449154797724}, {6.168368421584745, 0.1180449154797724}}, {{
       5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.804316508840108, 
       0.5339415044172112}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}, {{5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}}, {{6.107214335370953, 
       0.5339415044172112}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.031489878738242, 0.40278289815380874`}, {5.9672291824299695`, 
       0.3829270828260881}, {5.880040965472819, 0.40278289815380874`}, {
       5.880040965472819, 0.40278289815380874`}, {5.9672291824299695`, 
       0.3829270828260881}, {6.031489878738242, 0.40278289815380874`}, {
       6.0808158673790365`, 0.44850638595778936`}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}}, {{
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}}, {{5.880040965472819, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.0808158673790365`, 0.6193766228766331}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}, {6.0808158673790365`, 0.6193766228766331}, {
       6.031489878738242, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.880040965472819, 0.6651001106806137}, {
       5.880040965472819, 0.6651001106806137}}, {{6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}}, {{
       5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}, {{5.880040965472819, 0.40278289815380874`}, {
       5.819251216507586, 0.46836220128551}, {5.819251216507586, 
       0.46836220128551}, {5.880040965472819, 0.40278289815380874`}, {
       5.880040965472819, 0.40278289815380874`}}, {{5.880040965472819, 
       0.40278289815380874`}, {5.819251216507586, 0.46836220128551}, {
       5.819251216507586, 0.46836220128551}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}}, {{
       5.880040965472819, 0.40278289815380874`}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}}, {{5.819251216507586, 0.46836220128551}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.819251216507586, 0.46836220128551}, {
       5.819251216507586, 0.46836220128551}}, {{5.819251216507586, 
       0.46836220128551}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}, {5.819251216507586, 
       0.46836220128551}, {5.819251216507586, 0.46836220128551}}, {{
       5.819251216507586, 0.46836220128551}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.46836220128551}, {5.819251216507586, 
       0.46836220128551}}, {{5.819251216507586, 0.46836220128551}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}, {5.819251216507586, 0.46836220128551}, {
       5.819251216507586, 0.46836220128551}}, {{5.804316508840108, 
       0.5339415044172112}, {5.819251216507586, 0.5995208075489125}, {
       5.819251216507586, 0.5995208075489125}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}}, {{
       5.804316508840108, 0.5339415044172112}, {5.819251216507586, 
       0.5995208075489125}, {5.819251216507586, 0.5995208075489125}, {
       5.804316508840108, 0.5339415044172112}, {5.804316508840108, 
       0.5339415044172112}}, {{5.804316508840108, 0.5339415044172112}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}, {5.804316508840108, 0.5339415044172112}, {
       5.804316508840108, 0.5339415044172112}}, {{5.804316508840108, 
       0.5339415044172112}, {5.819251216507586, 0.5995208075489125}, {
       5.819251216507586, 0.5995208075489125}, {5.804316508840108, 
       0.5339415044172112}, {5.804316508840108, 0.5339415044172112}}, {{
       5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}}, {{5.819251216507586, 0.5995208075489125}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}, {5.819251216507586, 0.5995208075489125}, {
       5.819251216507586, 0.5995208075489125}}, {{5.819251216507586, 
       0.5995208075489125}, {5.880040965472819, 0.6651001106806137}, {
       5.880040965472819, 0.6651001106806137}, {5.819251216507586, 
       0.5995208075489125}, {5.819251216507586, 0.5995208075489125}}, {{
       5.819251216507586, 0.5995208075489125}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}, {
       5.819251216507586, 0.5995208075489125}, {5.819251216507586, 
       0.5995208075489125}}, {{6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.44850638595778936`}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.107214335370953, 0.5339415044172112}, {
       6.107214335370953, 0.5339415044172112}}, {{6.107214335370953, 
       0.5339415044172112}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.0808158673790365`, 0.44850638595778936`}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}}, {{
       6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}}, {{6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.44850638595778936`}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.107214335370953, 0.5339415044172112}, {
       6.107214335370953, 0.5339415044172112}}, {{6.0808158673790365`, 
       0.44850638595778936`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}}, {{
       6.0808158673790365`, 0.44850638595778936`}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}, {
       6.0808158673790365`, 0.44850638595778936`}, {6.0808158673790365`, 
       0.44850638595778936`}}, {{6.0808158673790365`, 0.44850638595778936`}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}, {6.0808158673790365`, 0.44850638595778936`}, {
       6.0808158673790365`, 0.44850638595778936`}}, {{6.0808158673790365`, 
       0.44850638595778936`}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}, {6.0808158673790365`, 
       0.44850638595778936`}, {6.0808158673790365`, 0.44850638595778936`}}, {{
       6.031489878738242, 0.40278289815380874`}, {5.9672291824299695`, 
       0.3829270828260881}, {5.9672291824299695`, 0.3829270828260881}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}}, {{6.031489878738242, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}, {6.031489878738242, 0.40278289815380874`}, {
       6.031489878738242, 0.40278289815380874`}}, {{6.031489878738242, 
       0.40278289815380874`}, {5.9672291824299695`, 0.3829270828260881}, {
       5.9672291824299695`, 0.3829270828260881}, {6.031489878738242, 
       0.40278289815380874`}, {6.031489878738242, 0.40278289815380874`}}, {{
       6.031489878738242, 0.40278289815380874`}, {5.9672291824299695`, 
       0.3829270828260881}, {5.9672291824299695`, 0.3829270828260881}, {
       6.031489878738242, 0.40278289815380874`}, {6.031489878738242, 
       0.40278289815380874`}}, {{5.9672291824299695`, 0.3829270828260881}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}, {5.9672291824299695`, 0.3829270828260881}, {
       5.9672291824299695`, 0.3829270828260881}}, {{5.9672291824299695`, 
       0.3829270828260881}, {5.880040965472819, 0.40278289815380874`}, {
       5.880040965472819, 0.40278289815380874`}, {5.9672291824299695`, 
       0.3829270828260881}, {5.9672291824299695`, 0.3829270828260881}}, {{
       5.9672291824299695`, 0.3829270828260881}, {5.880040965472819, 
       0.40278289815380874`}, {5.880040965472819, 0.40278289815380874`}, {
       5.9672291824299695`, 0.3829270828260881}, {5.9672291824299695`, 
       0.3829270828260881}}, {{5.9672291824299695`, 0.3829270828260881}, {
       5.880040965472819, 0.40278289815380874`}, {5.880040965472819, 
       0.40278289815380874`}, {5.9672291824299695`, 0.3829270828260881}, {
       5.9672291824299695`, 0.3829270828260881}}, {{5.880040965472819, 
       0.6651001106806137}, {5.9672291824299695`, 0.6849559260083343}, {
       5.9672291824299695`, 0.6849559260083343}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}}, {{
       5.880040965472819, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.9672291824299695`, 0.6849559260083343}, {
       5.880040965472819, 0.6651001106806137}, {5.880040965472819, 
       0.6651001106806137}}, {{5.880040965472819, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}, {5.880040965472819, 0.6651001106806137}, {
       5.880040965472819, 0.6651001106806137}}, {{5.880040965472819, 
       0.6651001106806137}, {5.9672291824299695`, 0.6849559260083343}, {
       5.9672291824299695`, 0.6849559260083343}, {5.880040965472819, 
       0.6651001106806137}, {5.880040965472819, 0.6651001106806137}}, {{
       5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}}, {{5.9672291824299695`, 0.6849559260083343}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}, {5.9672291824299695`, 0.6849559260083343}, {
       5.9672291824299695`, 0.6849559260083343}}, {{5.9672291824299695`, 
       0.6849559260083343}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}, {5.9672291824299695`, 
       0.6849559260083343}, {5.9672291824299695`, 0.6849559260083343}}, {{
       5.9672291824299695`, 0.6849559260083343}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}, {
       5.9672291824299695`, 0.6849559260083343}, {5.9672291824299695`, 
       0.6849559260083343}}, {{6.031489878738242, 0.6651001106806137}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}}, {{6.031489878738242, 
       0.6651001106806137}, {6.0808158673790365`, 0.6193766228766331}, {
       6.0808158673790365`, 0.6193766228766331}, {6.031489878738242, 
       0.6651001106806137}, {6.031489878738242, 0.6651001106806137}}, {{
       6.031489878738242, 0.6651001106806137}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}, {
       6.031489878738242, 0.6651001106806137}, {6.031489878738242, 
       0.6651001106806137}}, {{6.031489878738242, 0.6651001106806137}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}, {6.031489878738242, 0.6651001106806137}, {
       6.031489878738242, 0.6651001106806137}}, {{6.0808158673790365`, 
       0.6193766228766331}, {6.107214335370953, 0.5339415044172112}, {
       6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}}, {{
       6.0808158673790365`, 0.6193766228766331}, {6.107214335370953, 
       0.5339415044172112}, {6.107214335370953, 0.5339415044172112}, {
       6.0808158673790365`, 0.6193766228766331}, {6.0808158673790365`, 
       0.6193766228766331}}, {{6.0808158673790365`, 0.6193766228766331}, {
       6.107214335370953, 0.5339415044172112}, {6.107214335370953, 
       0.5339415044172112}, {6.0808158673790365`, 0.6193766228766331}, {
       6.0808158673790365`, 0.6193766228766331}}, {{6.0808158673790365`, 
       0.6193766228766331}, {6.107214335370953, 0.5339415044172112}, {
       6.107214335370953, 0.5339415044172112}, {6.0808158673790365`, 
       0.6193766228766331}, {6.0808158673790365`, 0.6193766228766331}}, {{
       5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`, 
       1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258065`}, {5.8756536577236975`, 
       0.9584816254121231}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}, {{5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}}, {{6.210311592223357, 
       0.9584816254121231}, {6.181145134103425, 0.8640882763253076}, {
       6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {5.9593181413486125`, 0.8135704889847561}, {
       5.9593181413486125`, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.126647108598442, 0.8135704889847561}, {
       6.181145134103426, 0.8640882763253076}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}}, {{
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}, {{5.9593181413486125`, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.181145134103426, 1.0528749744989385`}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}, {6.181145134103425, 1.0528749744989385`}, {
       6.126647108598442, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {5.9593181413486125`, 1.10339276183949}, {
       5.9593181413486125`, 1.10339276183949}}, {{6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}}, {{
       5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}, {{5.9593181413486125`, 0.8135704889847561}, {
       5.892154332151104, 0.8860260571984396}, {5.892154332151104, 
       0.8860260571984396}, {5.9593181413486125`, 0.8135704889847561}, {
       5.9593181413486125`, 0.8135704889847561}}, {{5.9593181413486125`, 
       0.8135704889847561}, {5.892154332151104, 0.8860260571984396}, {
       5.892154332151104, 0.8860260571984396}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}}, {{
       5.9593181413486125`, 0.8135704889847561}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}}, {{5.892154332151104, 0.8860260571984396}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.892154332151104, 0.8860260571984396}, {
       5.892154332151104, 0.8860260571984396}}, {{5.892154332151104, 
       0.8860260571984396}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}, {5.892154332151104, 
       0.8860260571984396}, {5.892154332151104, 0.8860260571984396}}, {{
       5.892154332151104, 0.8860260571984396}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 0.8860260571984396}, {5.892154332151104, 
       0.8860260571984396}}, {{5.892154332151104, 0.8860260571984396}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}, {5.892154332151104, 0.8860260571984396}, {
       5.892154332151104, 0.8860260571984396}}, {{5.8756536577236975`, 
       0.9584816254121231}, {5.892154332151104, 1.0309371936258065`}, {
       5.892154332151104, 1.0309371936258065`}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}}, {{
       5.8756536577236975`, 0.9584816254121231}, {5.892154332151104, 
       1.0309371936258065`}, {5.892154332151104, 1.0309371936258065`}, {
       5.8756536577236975`, 0.9584816254121231}, {5.8756536577236975`, 
       0.9584816254121231}}, {{5.8756536577236975`, 0.9584816254121231}, {
       5.892154332151104, 1.0309371936258065`}, {5.892154332151104, 
       1.0309371936258065`}, {5.8756536577236975`, 0.9584816254121231}, {
       5.8756536577236975`, 0.9584816254121231}}, {{5.8756536577236975`, 
       0.9584816254121231}, {5.892154332151104, 1.0309371936258065`}, {
       5.892154332151104, 1.0309371936258065`}, {5.8756536577236975`, 
       0.9584816254121231}, {5.8756536577236975`, 0.9584816254121231}}, {{
       5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`, 
       1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258067`}, {5.892154332151104, 
       1.0309371936258067`}}, {{5.892154332151104, 1.0309371936258067`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}, {5.892154332151104, 1.0309371936258067`}, {
       5.892154332151104, 1.0309371936258067`}}, {{5.892154332151104, 
       1.0309371936258067`}, {5.9593181413486125`, 1.10339276183949}, {
       5.9593181413486125`, 1.10339276183949}, {5.892154332151104, 
       1.0309371936258067`}, {5.892154332151104, 1.0309371936258067`}}, {{
       5.892154332151104, 1.0309371936258067`}, {5.9593181413486125`, 
       1.10339276183949}, {5.9593181413486125`, 1.10339276183949}, {
       5.892154332151104, 1.0309371936258067`}, {5.892154332151104, 
       1.0309371936258067`}}, {{6.210311592223357, 0.9584816254121231}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}, {6.210311592223357, 0.9584816254121231}, {
       6.210311592223357, 0.9584816254121231}}, {{6.210311592223357, 
       0.9584816254121231}, {6.181145134103425, 0.8640882763253076}, {
       6.181145134103425, 0.8640882763253076}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}}, {{
       6.210311592223357, 0.9584816254121231}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}}, {{6.210311592223357, 0.9584816254121231}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}, {6.210311592223357, 0.9584816254121231}, {
       6.210311592223357, 0.9584816254121231}}, {{6.181145134103425, 
       0.8640882763253076}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}}, {{
       6.181145134103425, 0.8640882763253076}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}, {
       6.181145134103425, 0.8640882763253076}, {6.181145134103425, 
       0.8640882763253076}}, {{6.181145134103425, 0.8640882763253076}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}, {6.181145134103425, 0.8640882763253076}, {
       6.181145134103425, 0.8640882763253076}}, {{6.181145134103425, 
       0.8640882763253076}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}, {6.181145134103425, 
       0.8640882763253076}, {6.181145134103425, 0.8640882763253076}}, {{
       6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}, {{6.126647108598442, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.055648408666054, 
       0.7916327081116241}, {6.126647108598442, 0.8135704889847561}, {
       6.126647108598442, 0.8135704889847561}}, {{6.126647108598442, 
       0.8135704889847561}, {6.055648408666054, 0.7916327081116241}, {
       6.055648408666054, 0.7916327081116241}, {6.126647108598442, 
       0.8135704889847561}, {6.126647108598442, 0.8135704889847561}}, {{
       6.126647108598442, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}, {
       6.126647108598442, 0.8135704889847561}, {6.126647108598442, 
       0.8135704889847561}}, {{6.055648408666054, 0.7916327081116241}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}, {6.055648408666054, 0.7916327081116241}, {
       6.055648408666054, 0.7916327081116241}}, {{6.055648408666054, 
       0.7916327081116241}, {5.9593181413486125`, 0.8135704889847561}, {
       5.9593181413486125`, 0.8135704889847561}, {6.055648408666054, 
       0.7916327081116241}, {6.055648408666054, 0.7916327081116241}}, {{
       6.055648408666054, 0.7916327081116241}, {5.9593181413486125`, 
       0.8135704889847561}, {5.9593181413486125`, 0.8135704889847561}, {
       6.055648408666054, 0.7916327081116241}, {6.055648408666054, 
       0.7916327081116241}}, {{6.055648408666054, 0.7916327081116241}, {
       5.9593181413486125`, 0.8135704889847561}, {5.9593181413486125`, 
       0.8135704889847561}, {6.055648408666054, 0.7916327081116241}, {
       6.055648408666054, 0.7916327081116241}}, {{5.9593181413486125`, 
       1.10339276183949}, {6.055648408666054, 1.1253305427126221`}, {
       6.055648408666054, 1.1253305427126221`}, {5.9593181413486125`, 
       1.10339276183949}, {5.9593181413486125`, 1.10339276183949}}, {{
       5.9593181413486125`, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.055648408666054, 1.1253305427126221`}, {
       5.9593181413486125`, 1.10339276183949}, {5.9593181413486125`, 
       1.10339276183949}}, {{5.9593181413486125`, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}, {5.9593181413486125`, 1.10339276183949}, {
       5.9593181413486125`, 1.10339276183949}}, {{5.9593181413486125`, 
       1.10339276183949}, {6.055648408666054, 1.1253305427126221`}, {
       6.055648408666054, 1.1253305427126221`}, {5.9593181413486125`, 
       1.10339276183949}, {5.9593181413486125`, 1.10339276183949}}, {{
       6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}}, {{6.055648408666054, 1.1253305427126221`}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}, {6.055648408666054, 1.1253305427126221`}, {
       6.055648408666054, 1.1253305427126221`}}, {{6.055648408666054, 
       1.1253305427126221`}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}, {6.055648408666054, 
       1.1253305427126221`}, {6.055648408666054, 1.1253305427126221`}}, {{
       6.055648408666054, 1.1253305427126221`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}, {
       6.055648408666054, 1.1253305427126221`}, {6.055648408666054, 
       1.1253305427126221`}}, {{6.126647108598442, 1.10339276183949}, {
       6.181145134103425, 1.0528749744989385`}, {6.181145134103425, 
       1.0528749744989385`}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}}, {{6.126647108598442, 
       1.10339276183949}, {6.181145134103425, 1.0528749744989385`}, {
       6.181145134103425, 1.0528749744989385`}, {6.126647108598442, 
       1.10339276183949}, {6.126647108598442, 1.10339276183949}}, {{
       6.126647108598442, 1.10339276183949}, {6.181145134103425, 
       1.0528749744989385`}, {6.181145134103425, 1.0528749744989385`}, {
       6.126647108598442, 1.10339276183949}, {6.126647108598442, 
       1.10339276183949}}, {{6.126647108598442, 1.10339276183949}, {
       6.181145134103425, 1.0528749744989385`}, {6.181145134103425, 
       1.0528749744989385`}, {6.126647108598442, 1.10339276183949}, {
       6.126647108598442, 1.10339276183949}}, {{6.181145134103426, 
       1.0528749744989385`}, {6.210311592223357, 0.9584816254121231}, {
       6.210311592223357, 0.9584816254121231}, {6.181145134103426, 
       1.0528749744989385`}, {6.181145134103426, 1.0528749744989385`}}, {{
       6.181145134103426, 1.0528749744989385`}, {6.210311592223357, 
       0.9584816254121231}, {6.210311592223357, 0.9584816254121231}, {
       6.181145134103426, 1.0528749744989385`}, {6.181145134103426, 
       1.0528749744989385`}}, {{6.181145134103426, 1.0528749744989385`}, {
       6.210311592223357, 0.9584816254121231}, {6.210311592223357, 
       0.9584816254121231}, {6.181145134103426, 1.0528749744989385`}, {
       6.181145134103426, 1.0528749744989385`}}, {{6.181145134103426, 
       1.0528749744989385`}, {6.210311592223357, 0.9584816254121231}, {
       6.210311592223357, 0.9584816254121231}, {6.181145134103426, 
       1.0528749744989385`}, {6.181145134103426, 1.0528749744989385`}}, {{
       5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.5895514865834939`}, {5.941490844175088, 
       1.6574462175794573`}, {5.941490844175088, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.863092761740935, 
       1.5216567555875307`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}, {{5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}}, {{6.176685091477548, 
       1.5216567555875307`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {5.941490844175089, 1.385867293595604}, {
       5.941490844175089, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.098287009043395, 1.385867293595604}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}}, {{
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}, {{5.941490844175089, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.1493545649634545`, 1.610108357059439}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}, {6.1493545649634545`, 1.610108357059439}, {
       6.098287009043395, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {5.941490844175089, 1.6574462175794573`}, {
       5.941490844175089, 1.6574462175794573`}}, {{6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}}, {{
       5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}, {{5.941490844175088, 1.385867293595604}, {
       5.878554773552046, 1.4537620245915674`}, {5.878554773552046, 
       1.4537620245915674`}, {5.941490844175088, 1.385867293595604}, {
       5.941490844175088, 1.385867293595604}}, {{5.941490844175088, 
       1.385867293595604}, {5.878554773552046, 1.4537620245915674`}, {
       5.878554773552046, 1.4537620245915674`}, {5.941490844175088, 
       1.385867293595604}, {5.941490844175088, 1.385867293595604}}, {{
       5.941490844175088, 1.385867293595604}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}}, {{5.878554773552046, 1.4537620245915674`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.878554773552046, 1.4537620245915674`}, {
       5.878554773552046, 1.4537620245915674`}}, {{5.878554773552046, 
       1.4537620245915674`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}, {5.878554773552046, 
       1.4537620245915674`}, {5.878554773552046, 1.4537620245915674`}}, {{
       5.878554773552046, 1.4537620245915674`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.4537620245915674`}, {5.878554773552046, 
       1.4537620245915674`}}, {{5.878554773552046, 1.4537620245915674`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}, {5.878554773552046, 1.4537620245915674`}, {
       5.878554773552046, 1.4537620245915674`}}, {{5.863092761740935, 
       1.5216567555875307`}, {5.878554773552046, 1.5895514865834939`}, {
       5.878554773552046, 1.5895514865834939`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}}, {{
       5.863092761740935, 1.5216567555875307`}, {5.878554773552046, 
       1.5895514865834939`}, {5.878554773552046, 1.5895514865834939`}, {
       5.863092761740935, 1.5216567555875307`}, {5.863092761740935, 
       1.5216567555875307`}}, {{5.863092761740935, 1.5216567555875307`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}, {5.863092761740935, 1.5216567555875307`}, {
       5.863092761740935, 1.5216567555875307`}}, {{5.863092761740935, 
       1.5216567555875307`}, {5.878554773552046, 1.5895514865834939`}, {
       5.878554773552046, 1.5895514865834939`}, {5.863092761740935, 
       1.5216567555875307`}, {5.863092761740935, 1.5216567555875307`}}, {{
       5.878554773552046, 1.5895514865834939`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}}, {{5.878554773552046, 1.5895514865834939`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}, {5.878554773552046, 1.5895514865834939`}, {
       5.878554773552046, 1.5895514865834939`}}, {{5.878554773552046, 
       1.5895514865834939`}, {5.941490844175089, 1.6574462175794573`}, {
       5.941490844175089, 1.6574462175794573`}, {5.878554773552046, 
       1.5895514865834939`}, {5.878554773552046, 1.5895514865834939`}}, {{
       5.878554773552046, 1.5895514865834939`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}, {
       5.878554773552046, 1.5895514865834939`}, {5.878554773552046, 
       1.5895514865834939`}}, {{6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}, {6.176685091477548, 1.5216567555875307`}, {
       6.176685091477548, 1.5216567555875307`}}, {{6.176685091477548, 
       1.5216567555875307`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}}, {{
       6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`, 
       1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}}, {{6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}, {6.176685091477548, 1.5216567555875307`}, {
       6.176685091477548, 1.5216567555875307`}}, {{6.1493545649634545`, 
       1.4332051541156223`}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.1493545649634545`, 
       1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}}, {{
       6.1493545649634545`, 1.4332051541156223`}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}, {
       6.1493545649634545`, 1.4332051541156223`}, {6.1493545649634545`, 
       1.4332051541156223`}}, {{6.1493545649634545`, 1.4332051541156223`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}, {6.1493545649634545`, 1.4332051541156223`}, {
       6.1493545649634545`, 1.4332051541156223`}}, {{6.1493545649634545`, 
       1.4332051541156223`}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}, {6.1493545649634545`, 
       1.4332051541156223`}, {6.1493545649634545`, 1.4332051541156223`}}, {{
       6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}, {{6.098287009043395, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.031757441312225, 
       1.3653104231196591`}, {6.098287009043395, 1.385867293595604}, {
       6.098287009043395, 1.385867293595604}}, {{6.098287009043395, 
       1.385867293595604}, {6.031757441312225, 1.3653104231196591`}, {
       6.031757441312225, 1.3653104231196591`}, {6.098287009043395, 
       1.385867293595604}, {6.098287009043395, 1.385867293595604}}, {{
       6.098287009043395, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}, {
       6.098287009043395, 1.385867293595604}, {6.098287009043395, 
       1.385867293595604}}, {{6.031757441312225, 1.3653104231196591`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}, {6.031757441312225, 1.3653104231196591`}, {
       6.031757441312225, 1.3653104231196591`}}, {{6.031757441312225, 
       1.3653104231196591`}, {5.941490844175088, 1.385867293595604}, {
       5.941490844175088, 1.385867293595604}, {6.031757441312225, 
       1.3653104231196591`}, {6.031757441312225, 1.3653104231196591`}}, {{
       6.031757441312225, 1.3653104231196591`}, {5.941490844175088, 
       1.385867293595604}, {5.941490844175088, 1.385867293595604}, {
       6.031757441312225, 1.3653104231196591`}, {6.031757441312225, 
       1.3653104231196591`}}, {{6.031757441312225, 1.3653104231196591`}, {
       5.941490844175088, 1.385867293595604}, {5.941490844175088, 
       1.385867293595604}, {6.031757441312225, 1.3653104231196591`}, {
       6.031757441312225, 1.3653104231196591`}}, {{5.941490844175089, 
       1.6574462175794573`}, {6.031757441312225, 1.6780030880554022`}, {
       6.031757441312225, 1.6780030880554022`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}}, {{
       5.941490844175089, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.031757441312225, 1.6780030880554022`}, {
       5.941490844175089, 1.6574462175794573`}, {5.941490844175089, 
       1.6574462175794573`}}, {{5.941490844175089, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}, {5.941490844175089, 1.6574462175794573`}, {
       5.941490844175089, 1.6574462175794573`}}, {{5.941490844175089, 
       1.6574462175794573`}, {6.031757441312225, 1.6780030880554022`}, {
       6.031757441312225, 1.6780030880554022`}, {5.941490844175089, 
       1.6574462175794573`}, {5.941490844175089, 1.6574462175794573`}}, {{
       6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}}, {{6.031757441312225, 1.6780030880554022`}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}, {6.031757441312225, 1.6780030880554022`}, {
       6.031757441312225, 1.6780030880554022`}}, {{6.031757441312225, 
       1.6780030880554022`}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}, {6.031757441312225, 
       1.6780030880554022`}, {6.031757441312225, 1.6780030880554022`}}, {{
       6.031757441312225, 1.6780030880554022`}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}, {
       6.031757441312225, 1.6780030880554022`}, {6.031757441312225, 
       1.6780030880554022`}}, {{6.098287009043395, 1.6574462175794573`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}}, {{6.098287009043395, 
       1.6574462175794573`}, {6.1493545649634545`, 1.610108357059439}, {
       6.1493545649634545`, 1.610108357059439}, {6.098287009043395, 
       1.6574462175794573`}, {6.098287009043395, 1.6574462175794573`}}, {{
       6.098287009043395, 1.6574462175794573`}, {6.1493545649634545`, 
       1.610108357059439}, {6.1493545649634545`, 1.610108357059439}, {
       6.098287009043395, 1.6574462175794573`}, {6.098287009043395, 
       1.6574462175794573`}}, {{6.098287009043395, 1.6574462175794573`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}, {6.098287009043395, 1.6574462175794573`}, {
       6.098287009043395, 1.6574462175794573`}}, {{6.1493545649634545`, 
       1.610108357059439}, {6.176685091477548, 1.5216567555875307`}, {
       6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`, 
       1.610108357059439}, {6.1493545649634545`, 1.610108357059439}}, {{
       6.1493545649634545`, 1.610108357059439}, {6.176685091477548, 
       1.5216567555875307`}, {6.176685091477548, 1.5216567555875307`}, {
       6.1493545649634545`, 1.610108357059439}, {6.1493545649634545`, 
       1.610108357059439}}, {{6.1493545649634545`, 1.610108357059439}, {
       6.176685091477548, 1.5216567555875307`}, {6.176685091477548, 
       1.5216567555875307`}, {6.1493545649634545`, 1.610108357059439}, {
       6.1493545649634545`, 1.610108357059439}}, {{6.1493545649634545`, 
       1.610108357059439}, {6.176685091477548, 1.5216567555875307`}, {
       6.176685091477548, 1.5216567555875307`}, {6.1493545649634545`, 
       1.610108357059439}, {6.1493545649634545`, 1.610108357059439}}, {{
       5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.846153356070333, 
       1.9944753947482339`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}, {{5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}}, {{6.195661975056241, 
       1.9944753947482339`}, {6.165201234558789, 1.8958932734842866`}, {
       6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`, 
       1.8202224377634333`}, {5.93353051081681, 1.8431337233065277`}, {
       5.93353051081681, 1.8431337233065277`}, {6.0341355024390735`, 
       1.8202224377634333`}, {6.108284820309764, 1.8431337233065277`}, {
       6.165201234558789, 1.8958932734842866`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}}, {{
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}, {{5.93353051081681, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764, 
       2.1458170661899403`}, {6.165201234558789, 2.0930575160121814`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}, {6.165201234558789, 2.0930575160121814`}, {
       6.108284820309764, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {5.93353051081681, 2.1458170661899403`}, {
       5.93353051081681, 2.1458170661899403`}}, {{6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}}, {{
       5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}, {{5.93353051081681, 1.8431337233065277`}, {
       5.863386259692001, 1.9188045590273808`}, {5.863386259692001, 
       1.9188045590273808`}, {5.93353051081681, 1.8431337233065277`}, {
       5.93353051081681, 1.8431337233065277`}}, {{5.93353051081681, 
       1.8431337233065277`}, {5.863386259692001, 1.9188045590273808`}, {
       5.863386259692001, 1.9188045590273808`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}}, {{
       5.93353051081681, 1.8431337233065277`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}}, {{5.863386259692001, 1.9188045590273808`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.863386259692001, 1.9188045590273808`}, {
       5.863386259692001, 1.9188045590273808`}}, {{5.863386259692001, 
       1.9188045590273808`}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}, {5.863386259692001, 
       1.9188045590273808`}, {5.863386259692001, 1.9188045590273808`}}, {{
       5.863386259692001, 1.9188045590273808`}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 1.9188045590273808`}, {5.863386259692001, 
       1.9188045590273808`}}, {{5.863386259692001, 1.9188045590273808`}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}, {5.863386259692001, 1.9188045590273808`}, {
       5.863386259692001, 1.9188045590273808`}}, {{5.846153356070333, 
       1.9944753947482339`}, {5.863386259692001, 2.070146230469087}, {
       5.863386259692001, 2.070146230469087}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}}, {{
       5.846153356070333, 1.9944753947482339`}, {5.863386259692001, 
       2.070146230469087}, {5.863386259692001, 2.070146230469087}, {
       5.846153356070333, 1.9944753947482339`}, {5.846153356070333, 
       1.9944753947482339`}}, {{5.846153356070333, 1.9944753947482339`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}, {5.846153356070333, 1.9944753947482339`}, {
       5.846153356070333, 1.9944753947482339`}}, {{5.846153356070333, 
       1.9944753947482339`}, {5.863386259692001, 2.070146230469087}, {
       5.863386259692001, 2.070146230469087}, {5.846153356070333, 
       1.9944753947482339`}, {5.846153356070333, 1.9944753947482339`}}, {{
       5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}}, {{5.863386259692001, 2.070146230469087}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}, {5.863386259692001, 2.070146230469087}, {
       5.863386259692001, 2.070146230469087}}, {{5.863386259692001, 
       2.070146230469087}, {5.93353051081681, 2.1458170661899403`}, {
       5.93353051081681, 2.1458170661899403`}, {5.863386259692001, 
       2.070146230469087}, {5.863386259692001, 2.070146230469087}}, {{
       5.863386259692001, 2.070146230469087}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}, {
       5.863386259692001, 2.070146230469087}, {5.863386259692001, 
       2.070146230469087}}, {{6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}, {6.195661975056241, 1.9944753947482339`}, {
       6.195661975056241, 1.9944753947482339`}}, {{6.195661975056241, 
       1.9944753947482339`}, {6.165201234558789, 1.8958932734842866`}, {
       6.165201234558789, 1.8958932734842866`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}}, {{
       6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}}, {{6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}, {6.195661975056241, 1.9944753947482339`}, {
       6.195661975056241, 1.9944753947482339`}}, {{6.165201234558789, 
       1.8958932734842866`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}}, {{
       6.165201234558789, 1.8958932734842866`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}, {
       6.165201234558789, 1.8958932734842866`}, {6.165201234558789, 
       1.8958932734842866`}}, {{6.165201234558789, 1.8958932734842866`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}, {6.165201234558789, 1.8958932734842866`}, {
       6.165201234558789, 1.8958932734842866`}}, {{6.165201234558789, 
       1.8958932734842866`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}, {6.165201234558789, 
       1.8958932734842866`}, {6.165201234558789, 1.8958932734842866`}}, {{
       6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`, 
       1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}, {{6.108284820309764, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.0341355024390735`, 
       1.8202224377634333`}, {6.108284820309764, 1.8431337233065277`}, {
       6.108284820309764, 1.8431337233065277`}}, {{6.108284820309764, 
       1.8431337233065277`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.108284820309764, 
       1.8431337233065277`}, {6.108284820309764, 1.8431337233065277`}}, {{
       6.108284820309764, 1.8431337233065277`}, {6.0341355024390735`, 
       1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.108284820309764, 1.8431337233065277`}, {6.108284820309764, 
       1.8431337233065277`}}, {{6.0341355024390735`, 1.8202224377634333`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.0341355024390735`, 1.8202224377634333`}}, {{6.0341355024390735`, 
       1.8202224377634333`}, {5.93353051081681, 1.8431337233065277`}, {
       5.93353051081681, 1.8431337233065277`}, {6.0341355024390735`, 
       1.8202224377634333`}, {6.0341355024390735`, 1.8202224377634333`}}, {{
       6.0341355024390735`, 1.8202224377634333`}, {5.93353051081681, 
       1.8431337233065277`}, {5.93353051081681, 1.8431337233065277`}, {
       6.0341355024390735`, 1.8202224377634333`}, {6.0341355024390735`, 
       1.8202224377634333`}}, {{6.0341355024390735`, 1.8202224377634333`}, {
       5.93353051081681, 1.8431337233065277`}, {5.93353051081681, 
       1.8431337233065277`}, {6.0341355024390735`, 1.8202224377634333`}, {
       6.0341355024390735`, 1.8202224377634333`}}, {{5.93353051081681, 
       2.1458170661899403`}, {6.0341355024390735`, 2.1687283517330345`}, {
       6.0341355024390735`, 2.1687283517330345`}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}}, {{
       5.93353051081681, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.0341355024390735`, 2.1687283517330345`}, {
       5.93353051081681, 2.1458170661899403`}, {5.93353051081681, 
       2.1458170661899403`}}, {{5.93353051081681, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}, {5.93353051081681, 2.1458170661899403`}, {
       5.93353051081681, 2.1458170661899403`}}, {{5.93353051081681, 
       2.1458170661899403`}, {6.0341355024390735`, 2.1687283517330345`}, {
       6.0341355024390735`, 2.1687283517330345`}, {5.93353051081681, 
       2.1458170661899403`}, {5.93353051081681, 2.1458170661899403`}}, {{
       6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}}, {{6.0341355024390735`, 2.1687283517330345`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}, {6.0341355024390735`, 2.1687283517330345`}, {
       6.0341355024390735`, 2.1687283517330345`}}, {{6.0341355024390735`, 
       2.1687283517330345`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}, {6.0341355024390735`, 
       2.1687283517330345`}, {6.0341355024390735`, 2.1687283517330345`}}, {{
       6.0341355024390735`, 2.1687283517330345`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}, {
       6.0341355024390735`, 2.1687283517330345`}, {6.0341355024390735`, 
       2.1687283517330345`}}, {{6.108284820309764, 2.1458170661899403`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}}, {{6.108284820309764, 
       2.1458170661899403`}, {6.165201234558789, 2.0930575160121814`}, {
       6.165201234558789, 2.0930575160121814`}, {6.108284820309764, 
       2.1458170661899403`}, {6.108284820309764, 2.1458170661899403`}}, {{
       6.108284820309764, 2.1458170661899403`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}, {
       6.108284820309764, 2.1458170661899403`}, {6.108284820309764, 
       2.1458170661899403`}}, {{6.108284820309764, 2.1458170661899403`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}, {6.108284820309764, 2.1458170661899403`}, {
       6.108284820309764, 2.1458170661899403`}}, {{6.165201234558789, 
       2.0930575160121814`}, {6.195661975056241, 1.9944753947482339`}, {
       6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}}, {{
       6.165201234558789, 2.0930575160121814`}, {6.195661975056241, 
       1.9944753947482339`}, {6.195661975056241, 1.9944753947482339`}, {
       6.165201234558789, 2.0930575160121814`}, {6.165201234558789, 
       2.0930575160121814`}}, {{6.165201234558789, 2.0930575160121814`}, {
       6.195661975056241, 1.9944753947482339`}, {6.195661975056241, 
       1.9944753947482339`}, {6.165201234558789, 2.0930575160121814`}, {
       6.165201234558789, 2.0930575160121814`}}, {{6.165201234558789, 
       2.0930575160121814`}, {6.195661975056241, 1.9944753947482339`}, {
       6.195661975056241, 1.9944753947482339`}, {6.165201234558789, 
       2.0930575160121814`}, {6.165201234558789, 2.0930575160121814`}}, {{
       5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.882287466381099, 
       2.4880860120130475`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}, {{5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}}, {{6.216502996152151, 
       2.4880860120130475`}, {6.187375094951565, 2.393817447249806}, {
       6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {5.965841348823862, 2.343366442452545}, {
       5.965841348823862, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.132949113709388, 2.343366442452545}, {
       6.187375094951565, 2.393817447249806}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}}, {{
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}, {{5.965841348823862, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.187375094951565, 2.582354576776289}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}, {6.187375094951565, 2.582354576776289}, {
       6.132949113709388, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {5.965841348823862, 2.63280558157355}, {
       5.965841348823862, 2.63280558157355}}, {{6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}}, {{
       5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}, {{5.965841348823862, 2.343366442452545}, {
       5.898766327560889, 2.4157262272327964`}, {5.898766327560889, 
       2.4157262272327964`}, {5.965841348823862, 2.343366442452545}, {
       5.965841348823862, 2.343366442452545}}, {{5.965841348823862, 
       2.343366442452545}, {5.898766327560889, 2.4157262272327964`}, {
       5.898766327560889, 2.4157262272327964`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}}, {{
       5.965841348823862, 2.343366442452545}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}}, {{5.898766327560889, 2.4157262272327964`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.898766327560889, 2.4157262272327964`}, {
       5.898766327560889, 2.4157262272327964`}}, {{5.898766327560889, 
       2.4157262272327964`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}, {5.898766327560889, 
       2.4157262272327964`}, {5.898766327560889, 2.4157262272327964`}}, {{
       5.898766327560889, 2.4157262272327964`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.4157262272327964`}, {5.898766327560889, 
       2.4157262272327964`}}, {{5.898766327560889, 2.4157262272327964`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}, {5.898766327560889, 2.4157262272327964`}, {
       5.898766327560889, 2.4157262272327964`}}, {{5.882287466381099, 
       2.4880860120130475`}, {5.898766327560889, 2.5604457967932985`}, {
       5.898766327560889, 2.5604457967932985`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}}, {{
       5.882287466381099, 2.4880860120130475`}, {5.898766327560889, 
       2.5604457967932985`}, {5.898766327560889, 2.5604457967932985`}, {
       5.882287466381099, 2.4880860120130475`}, {5.882287466381099, 
       2.4880860120130475`}}, {{5.882287466381099, 2.4880860120130475`}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}, {5.882287466381099, 2.4880860120130475`}, {
       5.882287466381099, 2.4880860120130475`}}, {{5.882287466381099, 
       2.4880860120130475`}, {5.898766327560889, 2.5604457967932985`}, {
       5.898766327560889, 2.5604457967932985`}, {5.882287466381099, 
       2.4880860120130475`}, {5.882287466381099, 2.4880860120130475`}}, {{
       5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}}, {{5.898766327560889, 2.5604457967932985`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}, {5.898766327560889, 2.5604457967932985`}, {
       5.898766327560889, 2.5604457967932985`}}, {{5.898766327560889, 
       2.5604457967932985`}, {5.965841348823862, 2.63280558157355}, {
       5.965841348823862, 2.63280558157355}, {5.898766327560889, 
       2.5604457967932985`}, {5.898766327560889, 2.5604457967932985`}}, {{
       5.898766327560889, 2.5604457967932985`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}, {
       5.898766327560889, 2.5604457967932985`}, {5.898766327560889, 
       2.5604457967932985`}}, {{6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}, {6.216502996152151, 2.4880860120130475`}, {
       6.216502996152151, 2.4880860120130475`}}, {{6.216502996152151, 
       2.4880860120130475`}, {6.187375094951565, 2.393817447249806}, {
       6.187375094951565, 2.393817447249806}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}}, {{
       6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}}, {{6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}, {6.216502996152151, 2.4880860120130475`}, {
       6.216502996152151, 2.4880860120130475`}}, {{6.187375094951565, 
       2.393817447249806}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}}, {{
       6.187375094951565, 2.393817447249806}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}, {
       6.187375094951565, 2.393817447249806}, {6.187375094951565, 
       2.393817447249806}}, {{6.187375094951565, 2.393817447249806}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}, {6.187375094951565, 2.393817447249806}, {
       6.187375094951565, 2.393817447249806}}, {{6.187375094951565, 
       2.393817447249806}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}, {6.187375094951565, 
       2.393817447249806}, {6.187375094951565, 2.393817447249806}}, {{
       6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}, {{6.132949113709388, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.062044271287421, 
       2.3214576624695544`}, {6.132949113709388, 2.343366442452545}, {
       6.132949113709388, 2.343366442452545}}, {{6.132949113709388, 
       2.343366442452545}, {6.062044271287421, 2.3214576624695544`}, {
       6.062044271287421, 2.3214576624695544`}, {6.132949113709388, 
       2.343366442452545}, {6.132949113709388, 2.343366442452545}}, {{
       6.132949113709388, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}, {
       6.132949113709388, 2.343366442452545}, {6.132949113709388, 
       2.343366442452545}}, {{6.062044271287421, 2.3214576624695544`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}, {6.062044271287421, 2.3214576624695544`}, {
       6.062044271287421, 2.3214576624695544`}}, {{6.062044271287421, 
       2.3214576624695544`}, {5.965841348823862, 2.343366442452545}, {
       5.965841348823862, 2.343366442452545}, {6.062044271287421, 
       2.3214576624695544`}, {6.062044271287421, 2.3214576624695544`}}, {{
       6.062044271287421, 2.3214576624695544`}, {5.965841348823862, 
       2.343366442452545}, {5.965841348823862, 2.343366442452545}, {
       6.062044271287421, 2.3214576624695544`}, {6.062044271287421, 
       2.3214576624695544`}}, {{6.062044271287421, 2.3214576624695544`}, {
       5.965841348823862, 2.343366442452545}, {5.965841348823862, 
       2.343366442452545}, {6.062044271287421, 2.3214576624695544`}, {
       6.062044271287421, 2.3214576624695544`}}, {{5.965841348823862, 
       2.63280558157355}, {6.062044271287421, 2.6547143615565405`}, {
       6.062044271287421, 2.6547143615565405`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}}, {{
       5.965841348823862, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.062044271287421, 2.6547143615565405`}, {
       5.965841348823862, 2.63280558157355}, {5.965841348823862, 
       2.63280558157355}}, {{5.965841348823862, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}, {5.965841348823862, 2.63280558157355}, {
       5.965841348823862, 2.63280558157355}}, {{5.965841348823862, 
       2.63280558157355}, {6.062044271287421, 2.6547143615565405`}, {
       6.062044271287421, 2.6547143615565405`}, {5.965841348823862, 
       2.63280558157355}, {5.965841348823862, 2.63280558157355}}, {{
       6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}}, {{6.062044271287421, 2.6547143615565405`}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}, {6.062044271287421, 2.6547143615565405`}, {
       6.062044271287421, 2.6547143615565405`}}, {{6.062044271287421, 
       2.6547143615565405`}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}, {6.062044271287421, 
       2.6547143615565405`}, {6.062044271287421, 2.6547143615565405`}}, {{
       6.062044271287421, 2.6547143615565405`}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}, {
       6.062044271287421, 2.6547143615565405`}, {6.062044271287421, 
       2.6547143615565405`}}, {{6.132949113709388, 2.63280558157355}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}}, {{6.132949113709388, 
       2.63280558157355}, {6.187375094951565, 2.582354576776289}, {
       6.187375094951565, 2.582354576776289}, {6.132949113709388, 
       2.63280558157355}, {6.132949113709388, 2.63280558157355}}, {{
       6.132949113709388, 2.63280558157355}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}, {
       6.132949113709388, 2.63280558157355}, {6.132949113709388, 
       2.63280558157355}}, {{6.132949113709388, 2.63280558157355}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}, {6.132949113709388, 2.63280558157355}, {
       6.132949113709388, 2.63280558157355}}, {{6.187375094951565, 
       2.582354576776289}, {6.216502996152151, 2.4880860120130475`}, {
       6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}}, {{
       6.187375094951565, 2.582354576776289}, {6.216502996152151, 
       2.4880860120130475`}, {6.216502996152151, 2.4880860120130475`}, {
       6.187375094951565, 2.582354576776289}, {6.187375094951565, 
       2.582354576776289}}, {{6.187375094951565, 2.582354576776289}, {
       6.216502996152151, 2.4880860120130475`}, {6.216502996152151, 
       2.4880860120130475`}, {6.187375094951565, 2.582354576776289}, {
       6.187375094951565, 2.582354576776289}}, {{6.187375094951565, 
       2.582354576776289}, {6.216502996152151, 2.4880860120130475`}, {
       6.216502996152151, 2.4880860120130475`}, {6.187375094951565, 
       2.582354576776289}, {6.187375094951565, 2.582354576776289}}, {{
       5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.821151533065186, 
       3.0407084168298297`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}, {{5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}}, {{6.113785841941831, 
       3.0407084168298297`}, {6.088281870768799, 2.9581682179432556`}, {
       6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.894310110284348, 2.9139940440767917`}, {
       5.894310110284348, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {6.040627264722669, 2.9139940440767917`}, {
       6.088281870768799, 2.9581682179432556`}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}}, {{
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}, {{5.894310110284348, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.088281870768799, 3.123248615716404}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}, {6.088281870768799, 3.123248615716404}, {
       6.040627264722669, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.894310110284348, 3.1674227895828677`}, {
       5.894310110284348, 3.1674227895828677`}}, {{6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}}, {{
       5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}, {{5.894310110284348, 2.9139940440767917`}, {
       5.83558018680167, 2.9773512304533107`}, {5.83558018680167, 
       2.9773512304533107`}, {5.894310110284348, 2.9139940440767917`}, {
       5.894310110284348, 2.9139940440767917`}}, {{5.894310110284348, 
       2.9139940440767917`}, {5.83558018680167, 2.9773512304533107`}, {
       5.83558018680167, 2.9773512304533107`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}}, {{
       5.894310110284348, 2.9139940440767917`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}}, {{5.83558018680167, 2.9773512304533107`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.83558018680167, 2.9773512304533107`}, {
       5.83558018680167, 2.9773512304533107`}}, {{5.83558018680167, 
       2.9773512304533107`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}, {5.83558018680167, 
       2.9773512304533107`}, {5.83558018680167, 2.9773512304533107`}}, {{
       5.83558018680167, 2.9773512304533107`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 2.9773512304533107`}, {5.83558018680167, 
       2.9773512304533107`}}, {{5.83558018680167, 2.9773512304533107`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}, {5.83558018680167, 2.9773512304533107`}, {
       5.83558018680167, 2.9773512304533107`}}, {{5.821151533065186, 
       3.0407084168298297`}, {5.83558018680167, 3.1040656032063487`}, {
       5.83558018680167, 3.1040656032063487`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}}, {{
       5.821151533065186, 3.0407084168298297`}, {5.83558018680167, 
       3.1040656032063487`}, {5.83558018680167, 3.1040656032063487`}, {
       5.821151533065186, 3.0407084168298297`}, {5.821151533065186, 
       3.0407084168298297`}}, {{5.821151533065186, 3.0407084168298297`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}, {5.821151533065186, 3.0407084168298297`}, {
       5.821151533065186, 3.0407084168298297`}}, {{5.821151533065186, 
       3.0407084168298297`}, {5.83558018680167, 3.1040656032063487`}, {
       5.83558018680167, 3.1040656032063487`}, {5.821151533065186, 
       3.0407084168298297`}, {5.821151533065186, 3.0407084168298297`}}, {{
       5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}}, {{5.83558018680167, 3.1040656032063487`}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}, {5.83558018680167, 3.1040656032063487`}, {
       5.83558018680167, 3.1040656032063487`}}, {{5.83558018680167, 
       3.1040656032063487`}, {5.894310110284348, 3.1674227895828677`}, {
       5.894310110284348, 3.1674227895828677`}, {5.83558018680167, 
       3.1040656032063487`}, {5.83558018680167, 3.1040656032063487`}}, {{
       5.83558018680167, 3.1040656032063487`}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}, {
       5.83558018680167, 3.1040656032063487`}, {5.83558018680167, 
       3.1040656032063487`}}, {{6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}, {6.113785841941831, 3.0407084168298297`}, {
       6.113785841941831, 3.0407084168298297`}}, {{6.113785841941831, 
       3.0407084168298297`}, {6.088281870768799, 2.9581682179432556`}, {
       6.088281870768799, 2.9581682179432556`}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}}, {{
       6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}}, {{6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}, {6.113785841941831, 3.0407084168298297`}, {
       6.113785841941831, 3.0407084168298297`}}, {{6.088281870768799, 
       2.9581682179432556`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}}, {{
       6.088281870768799, 2.9581682179432556`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}, {
       6.088281870768799, 2.9581682179432556`}, {6.088281870768799, 
       2.9581682179432556`}}, {{6.088281870768799, 2.9581682179432556`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}, {6.088281870768799, 2.9581682179432556`}, {
       6.088281870768799, 2.9581682179432556`}}, {{6.088281870768799, 
       2.9581682179432556`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}, {6.088281870768799, 
       2.9581682179432556`}, {6.088281870768799, 2.9581682179432556`}}, {{
       6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}, {{6.040627264722669, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.978544004940057, 
       2.8948110315667366`}, {6.040627264722669, 2.9139940440767917`}, {
       6.040627264722669, 2.9139940440767917`}}, {{6.040627264722669, 
       2.9139940440767917`}, {5.978544004940057, 2.8948110315667366`}, {
       5.978544004940057, 2.8948110315667366`}, {6.040627264722669, 
       2.9139940440767917`}, {6.040627264722669, 2.9139940440767917`}}, {{
       6.040627264722669, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}, {
       6.040627264722669, 2.9139940440767917`}, {6.040627264722669, 
       2.9139940440767917`}}, {{5.978544004940057, 2.8948110315667366`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}, {5.978544004940057, 2.8948110315667366`}, {
       5.978544004940057, 2.8948110315667366`}}, {{5.978544004940057, 
       2.8948110315667366`}, {5.894310110284348, 2.9139940440767917`}, {
       5.894310110284348, 2.9139940440767917`}, {5.978544004940057, 
       2.8948110315667366`}, {5.978544004940057, 2.8948110315667366`}}, {{
       5.978544004940057, 2.8948110315667366`}, {5.894310110284348, 
       2.9139940440767917`}, {5.894310110284348, 2.9139940440767917`}, {
       5.978544004940057, 2.8948110315667366`}, {5.978544004940057, 
       2.8948110315667366`}}, {{5.978544004940057, 2.8948110315667366`}, {
       5.894310110284348, 2.9139940440767917`}, {5.894310110284348, 
       2.9139940440767917`}, {5.978544004940057, 2.8948110315667366`}, {
       5.978544004940057, 2.8948110315667366`}}, {{5.894310110284348, 
       3.1674227895828677`}, {5.978544004940057, 3.186605802092923}, {
       5.978544004940057, 3.186605802092923}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}}, {{
       5.894310110284348, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.978544004940057, 3.186605802092923}, {
       5.894310110284348, 3.1674227895828677`}, {5.894310110284348, 
       3.1674227895828677`}}, {{5.894310110284348, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}, {5.894310110284348, 3.1674227895828677`}, {
       5.894310110284348, 3.1674227895828677`}}, {{5.894310110284348, 
       3.1674227895828677`}, {5.978544004940057, 3.186605802092923}, {
       5.978544004940057, 3.186605802092923}, {5.894310110284348, 
       3.1674227895828677`}, {5.894310110284348, 3.1674227895828677`}}, {{
       5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}}, {{5.978544004940057, 3.186605802092923}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}, {5.978544004940057, 3.186605802092923}, {
       5.978544004940057, 3.186605802092923}}, {{5.978544004940057, 
       3.186605802092923}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}, {5.978544004940057, 
       3.186605802092923}, {5.978544004940057, 3.186605802092923}}, {{
       5.978544004940057, 3.186605802092923}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}, {
       5.978544004940057, 3.186605802092923}, {5.978544004940057, 
       3.186605802092923}}, {{6.040627264722669, 3.1674227895828677`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}}, {{6.040627264722669, 
       3.1674227895828677`}, {6.088281870768799, 3.123248615716404}, {
       6.088281870768799, 3.123248615716404}, {6.040627264722669, 
       3.1674227895828677`}, {6.040627264722669, 3.1674227895828677`}}, {{
       6.040627264722669, 3.1674227895828677`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}, {
       6.040627264722669, 3.1674227895828677`}, {6.040627264722669, 
       3.1674227895828677`}}, {{6.040627264722669, 3.1674227895828677`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}, {6.040627264722669, 3.1674227895828677`}, {
       6.040627264722669, 3.1674227895828677`}}, {{6.088281870768799, 
       3.123248615716404}, {6.113785841941831, 3.0407084168298297`}, {
       6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}}, {{
       6.088281870768799, 3.123248615716404}, {6.113785841941831, 
       3.0407084168298297`}, {6.113785841941831, 3.0407084168298297`}, {
       6.088281870768799, 3.123248615716404}, {6.088281870768799, 
       3.123248615716404}}, {{6.088281870768799, 3.123248615716404}, {
       6.113785841941831, 3.0407084168298297`}, {6.113785841941831, 
       3.0407084168298297`}, {6.088281870768799, 3.123248615716404}, {
       6.088281870768799, 3.123248615716404}}, {{6.088281870768799, 
       3.123248615716404}, {6.113785841941831, 3.0407084168298297`}, {
       6.113785841941831, 3.0407084168298297`}, {6.088281870768799, 
       3.123248615716404}, {6.088281870768799, 3.123248615716404}}, {{
       5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.847400887554275, 
       3.4741985301599154`}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}, {{5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}}, {{6.111597979314296, 
       3.4741985301599154`}, {6.088572398212365, 3.3996793099671834`}, {
       6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.91345016049428, 3.3597978336248424`}, {
       5.91345016049428, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {6.045548706374291, 3.3597978336248424`}, {
       6.088572398212365, 3.3996793099671834`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}}, {{
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}, {{5.91345016049428, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.088572398212365, 3.5487177503526475`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}, {6.088572398212365, 3.5487177503526475`}, {
       6.045548706374291, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.91345016049428, 3.5885992266949884`}, {
       5.91345016049428, 3.5885992266949884`}}, {{6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}}, {{
       5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}, {{5.91345016049428, 3.3597978336248424`}, {
       5.860427413288133, 3.416998181892379}, {5.860427413288133, 
       3.416998181892379}, {5.91345016049428, 3.3597978336248424`}, {
       5.91345016049428, 3.3597978336248424`}}, {{5.91345016049428, 
       3.3597978336248424`}, {5.860427413288133, 3.416998181892379}, {
       5.860427413288133, 3.416998181892379}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}}, {{
       5.91345016049428, 3.3597978336248424`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}}, {{5.860427413288133, 3.416998181892379}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.860427413288133, 3.416998181892379}, {
       5.860427413288133, 3.416998181892379}}, {{5.860427413288133, 
       3.416998181892379}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}, {5.860427413288133, 
       3.416998181892379}, {5.860427413288133, 3.416998181892379}}, {{
       5.860427413288133, 3.416998181892379}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.416998181892379}, {5.860427413288133, 
       3.416998181892379}}, {{5.860427413288133, 3.416998181892379}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}, {5.860427413288133, 3.416998181892379}, {
       5.860427413288133, 3.416998181892379}}, {{5.847400887554275, 
       3.4741985301599154`}, {5.860427413288133, 3.531398878427452}, {
       5.860427413288133, 3.531398878427452}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}}, {{
       5.847400887554275, 3.4741985301599154`}, {5.860427413288133, 
       3.531398878427452}, {5.860427413288133, 3.531398878427452}, {
       5.847400887554275, 3.4741985301599154`}, {5.847400887554275, 
       3.4741985301599154`}}, {{5.847400887554275, 3.4741985301599154`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}, {5.847400887554275, 3.4741985301599154`}, {
       5.847400887554275, 3.4741985301599154`}}, {{5.847400887554275, 
       3.4741985301599154`}, {5.860427413288133, 3.531398878427452}, {
       5.860427413288133, 3.531398878427452}, {5.847400887554275, 
       3.4741985301599154`}, {5.847400887554275, 3.4741985301599154`}}, {{
       5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}}, {{5.860427413288133, 3.531398878427452}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}, {5.860427413288133, 3.531398878427452}, {
       5.860427413288133, 3.531398878427452}}, {{5.860427413288133, 
       3.531398878427452}, {5.91345016049428, 3.5885992266949884`}, {
       5.91345016049428, 3.5885992266949884`}, {5.860427413288133, 
       3.531398878427452}, {5.860427413288133, 3.531398878427452}}, {{
       5.860427413288133, 3.531398878427452}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}, {
       5.860427413288133, 3.531398878427452}, {5.860427413288133, 
       3.531398878427452}}, {{6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}, {6.111597979314296, 3.4741985301599154`}, {
       6.111597979314296, 3.4741985301599154`}}, {{6.111597979314296, 
       3.4741985301599154`}, {6.088572398212365, 3.3996793099671834`}, {
       6.088572398212365, 3.3996793099671834`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}}, {{
       6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}}, {{6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}, {6.111597979314296, 3.4741985301599154`}, {
       6.111597979314296, 3.4741985301599154`}}, {{6.088572398212365, 
       3.3996793099671834`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}}, {{
       6.088572398212365, 3.3996793099671834`}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}, {
       6.088572398212365, 3.3996793099671834`}, {6.088572398212365, 
       3.3996793099671834`}}, {{6.088572398212365, 3.3996793099671834`}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}, {6.088572398212365, 3.3996793099671834`}, {
       6.088572398212365, 3.3996793099671834`}}, {{6.088572398212365, 
       3.3996793099671834`}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}, {6.088572398212365, 
       3.3996793099671834`}, {6.088572398212365, 3.3996793099671834`}}, {{
       6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}, {{6.045548706374291, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.989498488802358, 
       3.342478961699647}, {6.045548706374291, 3.3597978336248424`}, {
       6.045548706374291, 3.3597978336248424`}}, {{6.045548706374291, 
       3.3597978336248424`}, {5.989498488802358, 3.342478961699647}, {
       5.989498488802358, 3.342478961699647}, {6.045548706374291, 
       3.3597978336248424`}, {6.045548706374291, 3.3597978336248424`}}, {{
       6.045548706374291, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}, {
       6.045548706374291, 3.3597978336248424`}, {6.045548706374291, 
       3.3597978336248424`}}, {{5.989498488802358, 3.342478961699647}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}, {5.989498488802358, 3.342478961699647}, {
       5.989498488802358, 3.342478961699647}}, {{5.989498488802358, 
       3.342478961699647}, {5.91345016049428, 3.3597978336248424`}, {
       5.91345016049428, 3.3597978336248424`}, {5.989498488802358, 
       3.342478961699647}, {5.989498488802358, 3.342478961699647}}, {{
       5.989498488802358, 3.342478961699647}, {5.91345016049428, 
       3.3597978336248424`}, {5.91345016049428, 3.3597978336248424`}, {
       5.989498488802358, 3.342478961699647}, {5.989498488802358, 
       3.342478961699647}}, {{5.989498488802358, 3.342478961699647}, {
       5.91345016049428, 3.3597978336248424`}, {5.91345016049428, 
       3.3597978336248424`}, {5.989498488802358, 3.342478961699647}, {
       5.989498488802358, 3.342478961699647}}, {{5.91345016049428, 
       3.5885992266949884`}, {5.989498488802358, 3.605918098620184}, {
       5.989498488802358, 3.605918098620184}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}}, {{
       5.91345016049428, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.989498488802358, 3.605918098620184}, {
       5.91345016049428, 3.5885992266949884`}, {5.91345016049428, 
       3.5885992266949884`}}, {{5.91345016049428, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}, {5.91345016049428, 3.5885992266949884`}, {
       5.91345016049428, 3.5885992266949884`}}, {{5.91345016049428, 
       3.5885992266949884`}, {5.989498488802358, 3.605918098620184}, {
       5.989498488802358, 3.605918098620184}, {5.91345016049428, 
       3.5885992266949884`}, {5.91345016049428, 3.5885992266949884`}}, {{
       5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}}, {{5.989498488802358, 3.605918098620184}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}, {5.989498488802358, 3.605918098620184}, {
       5.989498488802358, 3.605918098620184}}, {{5.989498488802358, 
       3.605918098620184}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}, {5.989498488802358, 
       3.605918098620184}, {5.989498488802358, 3.605918098620184}}, {{
       5.989498488802358, 3.605918098620184}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}, {
       5.989498488802358, 3.605918098620184}, {5.989498488802358, 
       3.605918098620184}}, {{6.045548706374291, 3.5885992266949884`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}}, {{6.045548706374291, 
       3.5885992266949884`}, {6.088572398212365, 3.5487177503526475`}, {
       6.088572398212365, 3.5487177503526475`}, {6.045548706374291, 
       3.5885992266949884`}, {6.045548706374291, 3.5885992266949884`}}, {{
       6.045548706374291, 3.5885992266949884`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}, {
       6.045548706374291, 3.5885992266949884`}, {6.045548706374291, 
       3.5885992266949884`}}, {{6.045548706374291, 3.5885992266949884`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}, {6.045548706374291, 3.5885992266949884`}, {
       6.045548706374291, 3.5885992266949884`}}, {{6.088572398212365, 
       3.5487177503526475`}, {6.111597979314296, 3.4741985301599154`}, {
       6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}}, {{
       6.088572398212365, 3.5487177503526475`}, {6.111597979314296, 
       3.4741985301599154`}, {6.111597979314296, 3.4741985301599154`}, {
       6.088572398212365, 3.5487177503526475`}, {6.088572398212365, 
       3.5487177503526475`}}, {{6.088572398212365, 3.5487177503526475`}, {
       6.111597979314296, 3.4741985301599154`}, {6.111597979314296, 
       3.4741985301599154`}, {6.088572398212365, 3.5487177503526475`}, {
       6.088572398212365, 3.5487177503526475`}}, {{6.088572398212365, 
       3.5487177503526475`}, {6.111597979314296, 3.4741985301599154`}, {
       6.111597979314296, 3.4741985301599154`}, {6.088572398212365, 
       3.5487177503526475`}, {6.088572398212365, 3.5487177503526475`}}, {{
       6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}, {{
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}, {{
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}, {{
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}, {{
       6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}, {{
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}, {{
       6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}, {{
       6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}, {{
       6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}, {{
       6.143804753648909, -4.442637077622077}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}}, {{
       6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}, {{
       6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}, {{
       6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}, {{
       6.074361596614341, -4.367722574385738}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.367722574385738}, {
       6.074361596614341, -4.367722574385738}}, {{
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}, {{
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}, {{
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}, {{
       6.057300936429494, -4.292808071149398}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}, {
       6.057300936429494, -4.292808071149398}, {
       6.057300936429494, -4.292808071149398}}, {{
       6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}, {{
       6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}, {{
       6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}, {{
       6.074361596614341, -4.217893567913059}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.074361596614341, -4.217893567913059}, {
       6.074361596614341, -4.217893567913059}}, {{
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}, {{
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}, {{
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}, {{
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}}, {{
       6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}, {{
       6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}, {{
       6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}, {{
       6.3731599209098775`, -4.390404860878496}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}, {
       6.3731599209098775`, -4.390404860878496}, {
       6.3731599209098775`, -4.390404860878496}}, {{
       6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}, {{
       6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}, {{
       6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}, {{
       6.316812388087739, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}, {
       6.316812388087739, -4.442637077622077}, {
       6.316812388087739, -4.442637077622077}}, {{
       6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}, {{
       6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}, {{
       6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}, {{
       6.243404195080754, -4.465319364114835}, {
       6.143804753648909, -4.442637077622077}, {
       6.143804753648909, -4.442637077622077}, {
       6.243404195080754, -4.465319364114835}, {
       6.243404195080754, -4.465319364114835}}, {{
       6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}, {{
       6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}, {{
       6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}, {{
       6.143804753648909, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.143804753648909, -4.1429790646767195`}, {
       6.143804753648909, -4.1429790646767195`}}, {{
       6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}, {{
       6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}, {{
       6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}, {{
       6.243404195080754, -4.1202967781839615`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.243404195080754, -4.1202967781839615`}, {
       6.243404195080754, -4.1202967781839615`}}, {{
       6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}, {{
       6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}, {{
       6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}, {{
       6.316812388087739, -4.1429790646767195`}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.316812388087739, -4.1429790646767195`}, {
       6.316812388087739, -4.1429790646767195`}}, {{
       6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}, {{
       6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}, {{
       6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}, {{
       6.3731599209098775`, -4.195211281420301}, {
       6.403316205307155, -4.292808071149398}, {
       6.403316205307155, -4.292808071149398}, {
       6.3731599209098775`, -4.195211281420301}, {
       6.3731599209098775`, -4.195211281420301}}, {{
       6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}, {{
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}, {{
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.142320992112987, -3.878259608965569}, {
       6.142320992112987, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}, {{
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}, {{
       6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}, {{
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}, {{
       6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}, {{
       6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}, {{
       6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}, {{
       6.142320992112986, -3.878259608965569}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}}, {{
       6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}, {{
       6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}, {{
       6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}, {{
       6.081392476241103, -3.812530605642787}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.812530605642787}, {
       6.081392476241103, -3.812530605642787}}, {{
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}, {{
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}, {{
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}, {{
       6.0664236765890385`, -3.7468016023200046`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.0664236765890385`, -3.7468016023200046`}, {
       6.0664236765890385`, -3.7468016023200046`}}, {{
       6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}, {{
       6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}, {{
       6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}, {{
       6.081392476241103, -3.6810725989972224`}, {
       6.142320992112986, -3.61534359567444}, {
       6.142320992112986, -3.61534359567444}, {
       6.081392476241103, -3.6810725989972224`}, {
       6.081392476241103, -3.6810725989972224`}}, {{
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}, {{
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}, {{
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}, {{
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}}, {{
       6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}, {{
       6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}, {{
       6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}, {{
       6.343554209977812, -3.8324317465413307`}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.343554209977812, -3.8324317465413307`}, {
       6.343554209977812, -3.8324317465413307`}}, {{
       6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}, {{
       6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}, {{
       6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}, {{
       6.2941156231608835`, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}, {
       6.2941156231608835`, -3.878259608965569}, {
       6.2941156231608835`, -3.878259608965569}}, {{
       6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}, {{
       6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}, {{
       6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}, {{
       6.22970823669189, -3.898160749864113}, {
       6.142320992112986, -3.878259608965569}, {
       6.142320992112986, -3.878259608965569}, {
       6.22970823669189, -3.898160749864113}, {
       6.22970823669189, -3.898160749864113}}, {{
       6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}, {{
       6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}, {{
       6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}, {{
       6.142320992112987, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.142320992112987, -3.61534359567444}, {
       6.142320992112987, -3.61534359567444}}, {{
       6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}, {{
       6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}, {{
       6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}, {{
       6.22970823669189, -3.5954424547758963`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.22970823669189, -3.5954424547758963`}, {
       6.22970823669189, -3.5954424547758963`}}, {{
       6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}, {{
       6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}, {{
       6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}, {{
       6.2941156231608835`, -3.61534359567444}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.2941156231608835`, -3.61534359567444}, {
       6.2941156231608835`, -3.61534359567444}}, {{
       6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}, {{
       6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}, {{
       6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}, {{
       6.343554209977812, -3.6611714580986785`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.370012938684831, -3.7468016023200046`}, {
       6.343554209977812, -3.6611714580986785`}, {
       6.343554209977812, -3.6611714580986785`}}, {{
       6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}, {{
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}, {{
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}, {{
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}, {{
       6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}, {{
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}, {{
       6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}, {{
       6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}, {{
       6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}, {{
       6.178371159534393, -3.3882642578828426`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}}, {{
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}, {{
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}, {{
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}, {{
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.3220716133251598`}, {
       6.1170128642514205`, -3.3220716133251598`}}, {{
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}, {{
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}, {{
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}, {{
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1019384772268905`, -3.2558789687674774`}, {
       6.1019384772268905`, -3.2558789687674774`}}, {{
       6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}, {{
       6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}, {{
       6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}, {{
       6.1170128642514205`, -3.189686324209795}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}, {
       6.1170128642514205`, -3.189686324209795}, {
       6.1170128642514205`, -3.189686324209795}}, {{
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}, {{
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}, {{
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}, {{
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}}, {{
       6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}, {{
       6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}, {{
       6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}, {{
       6.381023842367759, -3.3421131334942795`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.381023842367759, -3.3421131334942795`}, {
       6.381023842367759, -3.3421131334942795`}}, {{
       6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}, {{
       6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}, {{
       6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}, {{
       6.331236524149398, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}, {
       6.331236524149398, -3.3882642578828426`}, {
       6.331236524149398, -3.3882642578828426`}}, {{
       6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}, {{
       6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}, {{
       6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}, {{
       6.266374818906506, -3.408305778051962}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.178371159534393, -3.3882642578828426`}, {
       6.266374818906506, -3.408305778051962}, {
       6.266374818906506, -3.408305778051962}}, {{
       6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}, {{
       6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}, {{
       6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}, {{
       6.178371159534393, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}, {
       6.178371159534393, -3.123493679652112}, {
       6.178371159534393, -3.123493679652112}}, {{
       6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}, {{
       6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}, {{
       6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}, {{
       6.266374818906506, -3.103452159482993}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}, {
       6.266374818906506, -3.103452159482993}, {
       6.266374818906506, -3.103452159482993}}, {{
       6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}, {{
       6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}, {{
       6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}, {{
       6.331236524149398, -3.123493679652112}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.331236524149398, -3.123493679652112}, {
       6.331236524149398, -3.123493679652112}}, {{
       6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}, {{
       6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}, {{
       6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}, {{
       6.381023842367759, -3.1696448040406753`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.407669206456901, -3.2558789687674774`}, {
       6.381023842367759, -3.1696448040406753`}, {
       6.381023842367759, -3.1696448040406753`}}, {{
       6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}, {{
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}, {{
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}, {{
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}, {{
       6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}, {{
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}, {{
       6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}, {{
       6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}, {{
       6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}, {{
       6.147546797917118, -2.8240674359753593`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}}, {{
       6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}, {{
       6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}, {{
       6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}, {{
       6.095272425624781, -2.767674426217429}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.767674426217429}, {
       6.095272425624781, -2.767674426217429}}, {{
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}, {{
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}, {{
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}, {{
       6.082429759188809, -2.7112814164594985`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}, {
       6.082429759188809, -2.7112814164594985`}, {
       6.082429759188809, -2.7112814164594985`}}, {{
       6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}, {{
       6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}, {{
       6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}, {{
       6.095272425624781, -2.654888406701568}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.095272425624781, -2.654888406701568}, {
       6.095272425624781, -2.654888406701568}}, {{
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}, {{
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}, {{
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}, {{
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}}, {{
       6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}, {{
       6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}, {{
       6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}, {{
       6.320197321201981, -2.7847488557105127`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.320197321201981, -2.7847488557105127`}, {
       6.320197321201981, -2.7847488557105127`}}, {{
       6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}, {{
       6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}, {{
       6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}, {{
       6.277780875373735, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.277780875373735, -2.8240674359753593`}, {
       6.277780875373735, -2.8240674359753593`}}, {{
       6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}, {{
       6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}, {{
       6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}, {{
       6.222521763109518, -2.8411418654684435`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.147546797917118, -2.8240674359753593`}, {
       6.222521763109518, -2.8411418654684435`}, {
       6.222521763109518, -2.8411418654684435`}}, {{
       6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}, {{
       6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}, {{
       6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}, {{
       6.147546797917118, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.147546797917118, -2.5984953969436377`}, {
       6.147546797917118, -2.5984953969436377`}}, {{
       6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}, {{
       6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}, {{
       6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}, {{
       6.222521763109518, -2.5814209674505535`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.222521763109518, -2.5814209674505535`}, {
       6.222521763109518, -2.5814209674505535`}}, {{
       6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}, {{
       6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}, {{
       6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}, {{
       6.277780875373735, -2.5984953969436377`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.277780875373735, -2.5984953969436377`}, {
       6.277780875373735, -2.5984953969436377`}}, {{
       6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}, {{
       6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}, {{
       6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}, {{
       6.320197321201981, -2.6378139772084843`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.3428979141020445`, -2.7112814164594985`}, {
       6.320197321201981, -2.6378139772084843`}, {
       6.320197321201981, -2.6378139772084843`}}, {{
       6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}, {{
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}, {{
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}, {{
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}, {{
       6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}, {{
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}, {{
       6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}, {{
       6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}, {{
       6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}, {{
       6.1971043979490865`, -2.369453156873047}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}}, {{
       6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}, {{
       6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}, {{
       6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}, {{
       6.130531843057161, -2.297635427209347}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.297635427209347}, {
       6.130531843057161, -2.297635427209347}}, {{
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}, {{
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}, {{
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}, {{
       6.114176426841236, -2.2258176975456467`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.114176426841236, -2.2258176975456467`}, {
       6.114176426841236, -2.2258176975456467`}}, {{
       6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}, {{
       6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}, {{
       6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}, {{
       6.130531843057161, -2.1539999678819464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.130531843057161, -2.1539999678819464`}, {
       6.130531843057161, -2.1539999678819464`}}, {{
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}, {{
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}, {{
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}, {{
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}}, {{
       6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}, {{
       6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}, {{
       6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}, {{
       6.416978610387711, -2.3193800861087377`}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}, {
       6.416978610387711, -2.3193800861087377`}, {
       6.416978610387711, -2.3193800861087377`}}, {{
       6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}, {{
       6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}, {{
       6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}, {{
       6.362960340164786, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.362960340164786, -2.369453156873047}, {
       6.362960340164786, -2.369453156873047}}, {{
       6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}, {{
       6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}, {{
       6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}, {{
       6.2925866537259365`, -2.391197815772438}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.1971043979490865`, -2.369453156873047}, {
       6.2925866537259365`, -2.391197815772438}, {
       6.2925866537259365`, -2.391197815772438}}, {{
       6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}, {{
       6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}, {{
       6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}, {{
       6.1971043979490865`, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.1971043979490865`, -2.0821822382182464`}, {
       6.1971043979490865`, -2.0821822382182464`}}, {{
       6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}, {{
       6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}, {{
       6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}, {{
       6.2925866537259365`, -2.0604375793188554`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.2925866537259365`, -2.0604375793188554`}, {
       6.2925866537259365`, -2.0604375793188554`}}, {{
       6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}, {{
       6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}, {{
       6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}, {{
       6.362960340164786, -2.0821822382182464`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.362960340164786, -2.0821822382182464`}, {
       6.362960340164786, -2.0821822382182464`}}, {{
       6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}, {{
       6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}, {{
       6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}, {{
       6.416978610387711, -2.1322553089825558`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.445888311272637, -2.2258176975456467`}, {
       6.416978610387711, -2.1322553089825558`}, {
       6.416978610387711, -2.1322553089825558`}}, {{
       6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}, {{
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}, {{
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}, {{
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}, {{
       6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}, {{
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}, {{
       6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}, {{
       6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}, {{
       6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}, {{
       6.146617157163223, -1.8996331213972428`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}}, {{
       6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}, {{
       6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}, {{
       6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}, {{
       6.098224832329378, -1.8474280211369762`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.8474280211369762`}, {
       6.098224832329378, -1.8474280211369762`}}, {{
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}, {{
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}, {{
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}, {{
       6.08633589978655, -1.7952229208767096`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}, {
       6.08633589978655, -1.7952229208767096`}, {
       6.08633589978655, -1.7952229208767096`}}, {{
       6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}, {{
       6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}, {{
       6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}, {{
       6.098224832329378, -1.743017820616443}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.098224832329378, -1.743017820616443}, {
       6.098224832329378, -1.743017820616443}}, {{
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}, {{
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}, {{
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}, {{
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}}, {{
       6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}, {{
       6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}, {{
       6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}, {{
       6.306446148677659, -1.8632344536611412`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.306446148677659, -1.8632344536611412`}, {
       6.306446148677659, -1.8632344536611412`}}, {{
       6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}, {{
       6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}, {{
       6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}, {{
       6.267179671916568, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.267179671916568, -1.8996331213972428`}, {
       6.267179671916568, -1.8996331213972428`}}, {{
       6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}, {{
       6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}, {{
       6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}, {{
       6.21602426261265, -1.9154395539214077`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.146617157163223, -1.8996331213972428`}, {
       6.21602426261265, -1.9154395539214077`}, {
       6.21602426261265, -1.9154395539214077`}}, {{
       6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}, {{
       6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}, {{
       6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}, {{
       6.146617157163223, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.146617157163223, -1.6908127203561765`}, {
       6.146617157163223, -1.6908127203561765`}}, {{
       6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}, {{
       6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}, {{
       6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}, {{
       6.21602426261265, -1.6750062878320116`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.21602426261265, -1.6750062878320116`}, {
       6.21602426261265, -1.6750062878320116`}}, {{
       6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}, {{
       6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}, {{
       6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}, {{
       6.267179671916568, -1.6908127203561765`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.267179671916568, -1.6908127203561765`}, {
       6.267179671916568, -1.6908127203561765`}}, {{
       6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}, {{
       6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}, {{
       6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}, {{
       6.306446148677659, -1.7272113880922781`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.327460929293241, -1.7952229208767096`}, {
       6.306446148677659, -1.7272113880922781`}, {
       6.306446148677659, -1.7272113880922781`}}, {{
       6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}, {{
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}, {{
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}, {{
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}, {{
       6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}, {{
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}, {{
       6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}, {{
       6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}, {{
       6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}, {{
       6.2030232567129495`, -1.3798374682649495`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}}, {{
       6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}, {{
       6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}, {{
       6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}, {{
       6.135568839727751, -1.3070683956113598`}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.3070683956113598`}, {
       6.135568839727751, -1.3070683956113598`}}, {{
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}, {{
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}, {{
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}, {{
       6.118996769342491, -1.23429932295777}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}, {
       6.118996769342491, -1.23429932295777}, {
       6.118996769342491, -1.23429932295777}}, {{
       6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}, {{
       6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}, {{
       6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}, {{
       6.135568839727751, -1.16153025030418}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.135568839727751, -1.16153025030418}, {
       6.135568839727751, -1.16153025030418}}, {{
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}, {{
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}, {{
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}, {{
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}}, {{
       6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}, {{
       6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}, {{
       6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}, {{
       6.4258100617890825`, -1.3291010979912161`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.4258100617890825`, -1.3291010979912161`}, {
       6.4258100617890825`, -1.3291010979912161`}}, {{
       6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}, {{
       6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}, {{
       6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}, {{
       6.371076231453868, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}, {
       6.371076231453868, -1.3798374682649495`}, {
       6.371076231453868, -1.3798374682649495`}}, {{
       6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}, {{
       6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}, {{
       6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}, {{
       6.299770330733394, -1.401870170644806}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.2030232567129495`, -1.3798374682649495`}, {
       6.299770330733394, -1.401870170644806}, {
       6.299770330733394, -1.401870170644806}}, {{
       6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}, {{
       6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}, {{
       6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}, {{
       6.2030232567129495`, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.2030232567129495`, -1.0887611776505903`}, {
       6.2030232567129495`, -1.0887611776505903`}}, {{
       6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}, {{
       6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}, {{
       6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}, {{
       6.299770330733394, -1.0667284752707338`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.299770330733394, -1.0667284752707338`}, {
       6.299770330733394, -1.0667284752707338`}}, {{
       6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}, {{
       6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}, {{
       6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}, {{
       6.371076231453868, -1.0887611776505903`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.371076231453868, -1.0887611776505903`}, {
       6.371076231453868, -1.0887611776505903`}}, {{
       6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}, {{
       6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}, {{
       6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}, {{
       6.4258100617890825`, -1.1394975479243237`}, {
       6.455102718824326, -1.23429932295777}, {
       6.455102718824326, -1.23429932295777}, {
       6.4258100617890825`, -1.1394975479243237`}, {
       6.4258100617890825`, -1.1394975479243237`}}, {{
       6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091628}, {
       6.160705813016764, -0.6347178347091628}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}, {{
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}, {{
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193179}, {
       6.160705813016764, -0.8990415182193179}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}, {{
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}, {{
       6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}, {{
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}, {{
       6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}, {{
       6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}, {{
       6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}, {{
       6.160705813016764, -0.8990415182193178}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}}, {{
       6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}, {{
       6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}, {{
       6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}, {{
       6.09945108172647, -0.8329605973417791}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.8329605973417791}, {
       6.09945108172647, -0.8329605973417791}}, {{
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}, {{
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}, {{
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}, {{
       6.084402138102873, -0.7668796764642403}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}, {
       6.084402138102873, -0.7668796764642403}, {
       6.084402138102873, -0.7668796764642403}}, {{
       6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}, {{
       6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}, {{
       6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}, {{
       6.09945108172647, -0.7007987555867015}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}, {
       6.09945108172647, -0.7007987555867015}, {
       6.09945108172647, -0.7007987555867015}}, {{
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}, {{
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}, {{
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}, {{
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}}, {{
       6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}, {{
       6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}, {{
       6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}, {{
       6.363016447218165, -0.8529682903023933}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}, {
       6.363016447218165, -0.8529682903023933}, {
       6.363016447218165, -0.8529682903023933}}, {{
       6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}, {{
       6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}, {{
       6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}, {{
       6.313313162844545, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}, {
       6.313313162844545, -0.8990415182193178}, {
       6.313313162844545, -0.8990415182193178}}, {{
       6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}, {{
       6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}, {{
       6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}, {{
       6.248560934847329, -0.9190492111799321}, {
       6.160705813016764, -0.8990415182193178}, {
       6.160705813016764, -0.8990415182193178}, {
       6.248560934847329, -0.9190492111799321}, {
       6.248560934847329, -0.9190492111799321}}, {{
       6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}, {{
       6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}, {{
       6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}, {{
       6.160705813016764, -0.6347178347091627}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}, {
       6.160705813016764, -0.6347178347091627}, {
       6.160705813016764, -0.6347178347091627}}, {{
       6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}, {{
       6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}, {{
       6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}, {{
       6.248560934847329, -0.6147101417485484}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}, {
       6.248560934847329, -0.6147101417485484}, {
       6.248560934847329, -0.6147101417485484}}, {{
       6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}, {{
       6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}, {{
       6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}, {{
       6.313313162844545, -0.6347178347091628}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}, {
       6.313313162844545, -0.6347178347091628}, {
       6.313313162844545, -0.6347178347091628}}, {{
       6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}, {{
       6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}, {{
       6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}, {{
       6.363016447218165, -0.6807910626260872}, {
       6.389616837758436, -0.7668796764642403}, {
       6.389616837758436, -0.7668796764642403}, {
       6.363016447218165, -0.6807910626260872}, {
       6.363016447218165, -0.6807910626260872}}, {{
       6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}, {{
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}, {{
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}, {{
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}, {{
       6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}, {{
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}, {{
       6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}, {{
       6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}, {{
       6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}, {{
       6.132981995773083, -0.42281220618550774`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}}, {{
       6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}, {{
       6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}, {{
       6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}, {{
       6.066223107311982, -0.3507934619457558}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.3507934619457558}, {
       6.066223107311982, -0.3507934619457558}}, {{
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}, {{
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}, {{
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}, {{
       6.049821913026043, -0.27877471770600387`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.066223107311982, -0.20675597346625196`}, {
       6.049821913026043, -0.27877471770600387`}, {
       6.049821913026043, -0.27877471770600387`}}, {{
       6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}, {{
       6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}, {{
       6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}, {{
       6.066223107311982, -0.20675597346625194`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.066223107311982, -0.20675597346625194`}, {
       6.066223107311982, -0.20675597346625194`}}, {{
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}, {{
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}, {{
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}, {{
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}}, {{
       6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}, {{
       6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}, {{
       6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}, {{
       6.35347162618447, -0.37259898316160406`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.35347162618447, -0.37259898316160406`}, {
       6.35347162618447, -0.37259898316160406`}}, {{
       6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}, {{
       6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}, {{
       6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}, {{
       6.2993021612671605`, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.2993021612671605`, -0.42281220618550774`}, {
       6.2993021612671605`, -0.42281220618550774`}}, {{
       6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}, {{
       6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}, {{
       6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}, {{
       6.228731502063912, -0.44461772740135597`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.132981995773083, -0.42281220618550774`}, {
       6.228731502063912, -0.44461772740135597`}, {
       6.228731502063912, -0.44461772740135597`}}, {{
       6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}, {{
       6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}, {{
       6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}, {{
       6.132981995773083, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.132981995773083, -0.13473722922650003`}, {
       6.132981995773083, -0.13473722922650003`}}, {{
       6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}, {{
       6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}, {{
       6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}, {{
       6.228731502063912, -0.11293170801065175`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.228731502063912, -0.11293170801065175`}, {
       6.228731502063912, -0.11293170801065175`}}, {{
       6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}, {{
       6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}, {{
       6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}, {{
       6.2993021612671605`, -0.13473722922650003`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.2993021612671605`, -0.13473722922650003`}, {
       6.2993021612671605`, -0.13473722922650003`}}, {{
       6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}, {{
       6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}, {{
       6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}, {{
       6.35347162618447, -0.18495045225040369`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.3824622440142, -0.27877471770600387`}, {
       6.35347162618447, -0.18495045225040369`}, {
       6.35347162618447, -0.18495045225040369`}}, {{6.1551632030793995`, 
       0.15222489757654997`}, {6.088973505956324, 0.22362960454963116`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.3664390184957935}, {6.1551632030793995`, 0.4378437254688746}, {
       6.1551632030793995`, 0.4378437254688746}, {6.088973505956324, 
       0.36643901849579347`}, {6.0727121494947705`, 0.2950343115227123}, {
       6.088973505956324, 0.22362960454963113`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}}, {{
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}}, {{6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.2020099988587903}, {6.320065310248659, 
       0.15222489757654997`}, {6.25009634182941, 0.13060529188570913`}, {
       6.1551632030793995`, 0.15222489757654997`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.25009634182941, 0.13060529188570913`}, {
       6.320065310248659, 0.15222489757654997`}, {6.373772922206355, 
       0.2020099988587903}, {6.402516363833288, 0.2950343115227123}, {
       6.402516363833288, 0.2950343115227123}}, {{6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}}, {{
       6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.320065310248659, 0.4378437254688746}, {
       6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.320065310248659, 
       0.4378437254688746}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}, {{6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}}, {{6.1551632030793995`, 
       0.15222489757654997`}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}}, {{
       6.1551632030793995`, 0.15222489757654997`}, {6.088973505956324, 
       0.22362960454963116`}, {6.088973505956324, 0.22362960454963116`}, {
       6.1551632030793995`, 0.15222489757654997`}, {6.1551632030793995`, 
       0.15222489757654997`}}, {{6.1551632030793995`, 0.15222489757654997`}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}}, {{6.1551632030793995`, 
       0.15222489757654997`}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}}, {{
       6.088973505956324, 0.22362960454963116`}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}}, {{6.088973505956324, 0.22362960454963116`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.22362960454963116`}, {
       6.088973505956324, 0.22362960454963116`}}, {{6.088973505956324, 
       0.22362960454963116`}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.22362960454963116`}, {6.088973505956324, 0.22362960454963116`}}, {{
       6.088973505956324, 0.22362960454963116`}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}, {
       6.088973505956324, 0.22362960454963116`}, {6.088973505956324, 
       0.22362960454963116`}}, {{6.0727121494947705`, 0.2950343115227123}, {
       6.088973505956324, 0.36643901849579347`}, {6.088973505956324, 
       0.36643901849579347`}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}}, {{6.0727121494947705`, 
       0.2950343115227123}, {6.088973505956324, 0.36643901849579347`}, {
       6.088973505956324, 0.36643901849579347`}, {6.0727121494947705`, 
       0.2950343115227123}, {6.0727121494947705`, 0.2950343115227123}}, {{
       6.0727121494947705`, 0.2950343115227123}, {6.088973505956324, 
       0.36643901849579347`}, {6.088973505956324, 0.36643901849579347`}, {
       6.0727121494947705`, 0.2950343115227123}, {6.0727121494947705`, 
       0.2950343115227123}}, {{6.0727121494947705`, 0.2950343115227123}, {
       6.088973505956324, 0.36643901849579347`}, {6.088973505956324, 
       0.36643901849579347`}, {6.0727121494947705`, 0.2950343115227123}, {
       6.0727121494947705`, 0.2950343115227123}}, {{6.088973505956324, 
       0.3664390184957935}, {6.1551632030793995`, 0.4378437254688746}, {
       6.1551632030793995`, 0.4378437254688746}, {6.088973505956324, 
       0.3664390184957935}, {6.088973505956324, 0.3664390184957935}}, {{
       6.088973505956324, 0.3664390184957935}, {6.1551632030793995`, 
       0.4378437254688746}, {6.1551632030793995`, 0.4378437254688746}, {
       6.088973505956324, 0.3664390184957935}, {6.088973505956324, 
       0.3664390184957935}}, {{6.088973505956324, 0.3664390184957935}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}, {6.088973505956324, 0.3664390184957935}, {
       6.088973505956324, 0.3664390184957935}}, {{6.088973505956324, 
       0.3664390184957935}, {6.1551632030793995`, 0.4378437254688746}, {
       6.1551632030793995`, 0.4378437254688746}, {6.088973505956324, 
       0.3664390184957935}, {6.088973505956324, 0.3664390184957935}}, {{
       6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}, {{6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.2020099988587903}, {6.373772922206355, 
       0.2020099988587903}, {6.402516363833288, 0.2950343115227123}, {
       6.402516363833288, 0.2950343115227123}}, {{6.402516363833288, 
       0.2950343115227123}, {6.373772922206355, 0.2020099988587903}, {
       6.373772922206355, 0.2020099988587903}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}}, {{
       6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}}, {{6.373772922206355, 0.2020099988587903}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.373772922206355, 0.2020099988587903}, {
       6.373772922206355, 0.2020099988587903}}, {{6.373772922206355, 
       0.2020099988587903}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}, {6.373772922206355, 
       0.2020099988587903}, {6.373772922206355, 0.2020099988587903}}, {{
       6.373772922206355, 0.2020099988587903}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}, {
       6.373772922206355, 0.2020099988587903}, {6.373772922206355, 
       0.2020099988587903}}, {{6.373772922206355, 0.2020099988587903}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}, {6.373772922206355, 0.2020099988587903}, {
       6.373772922206355, 0.2020099988587903}}, {{6.320065310248659, 
       0.15222489757654997`}, {6.25009634182941, 0.13060529188570913`}, {
       6.25009634182941, 0.13060529188570913`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}}, {{
       6.320065310248659, 0.15222489757654997`}, {6.25009634182941, 
       0.13060529188570913`}, {6.25009634182941, 0.13060529188570913`}, {
       6.320065310248659, 0.15222489757654997`}, {6.320065310248659, 
       0.15222489757654997`}}, {{6.320065310248659, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}, {6.320065310248659, 0.15222489757654997`}, {
       6.320065310248659, 0.15222489757654997`}}, {{6.320065310248659, 
       0.15222489757654997`}, {6.25009634182941, 0.13060529188570913`}, {
       6.25009634182941, 0.13060529188570913`}, {6.320065310248659, 
       0.15222489757654997`}, {6.320065310248659, 0.15222489757654997`}}, {{
       6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}}, {{6.25009634182941, 0.13060529188570913`}, {
       6.1551632030793995`, 0.15222489757654997`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.25009634182941, 0.13060529188570913`}, {
       6.25009634182941, 0.13060529188570913`}}, {{6.25009634182941, 
       0.13060529188570913`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.1551632030793995`, 0.15222489757654997`}, {6.25009634182941, 
       0.13060529188570913`}, {6.25009634182941, 0.13060529188570913`}}, {{
       6.25009634182941, 0.13060529188570913`}, {6.1551632030793995`, 
       0.15222489757654997`}, {6.1551632030793995`, 0.15222489757654997`}, {
       6.25009634182941, 0.13060529188570913`}, {6.25009634182941, 
       0.13060529188570913`}}, {{6.1551632030793995`, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}, {6.1551632030793995`, 0.4378437254688746}, {
       6.1551632030793995`, 0.4378437254688746}}, {{6.1551632030793995`, 
       0.4378437254688746}, {6.25009634182941, 0.4594633311597155}, {
       6.25009634182941, 0.4594633311597155}, {6.1551632030793995`, 
       0.4378437254688746}, {6.1551632030793995`, 0.4378437254688746}}, {{
       6.1551632030793995`, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}, {
       6.1551632030793995`, 0.4378437254688746}, {6.1551632030793995`, 
       0.4378437254688746}}, {{6.1551632030793995`, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}, {6.1551632030793995`, 0.4378437254688746}, {
       6.1551632030793995`, 0.4378437254688746}}, {{6.25009634182941, 
       0.4594633311597155}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}}, {{
       6.25009634182941, 0.4594633311597155}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}, {
       6.25009634182941, 0.4594633311597155}, {6.25009634182941, 
       0.4594633311597155}}, {{6.25009634182941, 0.4594633311597155}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}, {6.25009634182941, 0.4594633311597155}, {
       6.25009634182941, 0.4594633311597155}}, {{6.25009634182941, 
       0.4594633311597155}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}, {6.25009634182941, 
       0.4594633311597155}, {6.25009634182941, 0.4594633311597155}}, {{
       6.320065310248659, 0.4378437254688746}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}, {{6.320065310248659, 0.4378437254688746}, {
       6.373772922206355, 0.3880586241866343}, {6.373772922206355, 
       0.3880586241866343}, {6.320065310248659, 0.4378437254688746}, {
       6.320065310248659, 0.4378437254688746}}, {{6.320065310248659, 
       0.4378437254688746}, {6.373772922206355, 0.3880586241866343}, {
       6.373772922206355, 0.3880586241866343}, {6.320065310248659, 
       0.4378437254688746}, {6.320065310248659, 0.4378437254688746}}, {{
       6.320065310248659, 0.4378437254688746}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}, {
       6.320065310248659, 0.4378437254688746}, {6.320065310248659, 
       0.4378437254688746}}, {{6.373772922206355, 0.3880586241866343}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}, {6.373772922206355, 0.3880586241866343}, {
       6.373772922206355, 0.3880586241866343}}, {{6.373772922206355, 
       0.3880586241866343}, {6.402516363833288, 0.2950343115227123}, {
       6.402516363833288, 0.2950343115227123}, {6.373772922206355, 
       0.3880586241866343}, {6.373772922206355, 0.3880586241866343}}, {{
       6.373772922206355, 0.3880586241866343}, {6.402516363833288, 
       0.2950343115227123}, {6.402516363833288, 0.2950343115227123}, {
       6.373772922206355, 0.3880586241866343}, {6.373772922206355, 
       0.3880586241866343}}, {{6.373772922206355, 0.3880586241866343}, {
       6.402516363833288, 0.2950343115227123}, {6.402516363833288, 
       0.2950343115227123}, {6.373772922206355, 0.3880586241866343}, {
       6.373772922206355, 0.3880586241866343}}, {{6.232394970709101, 
       0.6157192740461499}, {6.1791882695788685`, 0.6731180697551582}, {
       6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.787915661173175}, {6.232394970709101, 0.8453144568821833}, {
       6.232394970709101, 0.8453144568821833}, {6.1791882695788685`, 
       0.787915661173175}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}}, {{
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}, {{6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.6557391127793147}, {6.364951811324127, 
       0.6157192740461499}, {6.308707136504852, 0.5983403170703064}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}, {6.308707136504852, 0.5983403170703064}, {
       6.364951811324127, 0.6157192740461499}, {6.408124766966121, 
       0.6557391127793147}, {6.431230231631639, 0.7305168654641666}, {
       6.431230231631639, 0.7305168654641666}}, {{6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}}, {{
       6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.364951811324127, 0.8453144568821833}, {
       6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.364951811324127, 
       0.8453144568821833}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}, {{6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}}, {{6.232394970709101, 
       0.6157192740461499}, {6.1791882695788685`, 0.6731180697551582}, {
       6.1791882695788685`, 0.6731180697551582}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}}, {{
       6.232394970709101, 0.6157192740461499}, {6.1791882695788685`, 
       0.6731180697551582}, {6.1791882695788685`, 0.6731180697551582}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}}, {{6.232394970709101, 0.6157192740461499}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}, {6.232394970709101, 0.6157192740461499}, {
       6.232394970709101, 0.6157192740461499}}, {{6.232394970709101, 
       0.6157192740461499}, {6.1791882695788685`, 0.6731180697551582}, {
       6.1791882695788685`, 0.6731180697551582}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}}, {{
       6.1791882695788685`, 0.6731180697551582}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}}, {{6.1791882695788685`, 0.6731180697551582}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}, {6.1791882695788685`, 0.6731180697551582}, {
       6.1791882695788685`, 0.6731180697551582}}, {{6.1791882695788685`, 
       0.6731180697551582}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.6731180697551582}, {6.1791882695788685`, 0.6731180697551582}}, {{
       6.1791882695788685`, 0.6731180697551582}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.6731180697551582}, {6.1791882695788685`, 
       0.6731180697551582}}, {{6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}}, {{6.166116550401588, 
       0.7305168654641666}, {6.1791882695788685`, 0.787915661173175}, {
       6.1791882695788685`, 0.787915661173175}, {6.166116550401588, 
       0.7305168654641666}, {6.166116550401588, 0.7305168654641666}}, {{
       6.166116550401588, 0.7305168654641666}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}, {
       6.166116550401588, 0.7305168654641666}, {6.166116550401588, 
       0.7305168654641666}}, {{6.166116550401588, 0.7305168654641666}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}, {6.166116550401588, 0.7305168654641666}, {
       6.166116550401588, 0.7305168654641666}}, {{6.1791882695788685`, 
       0.787915661173175}, {6.232394970709101, 0.8453144568821833}, {
       6.232394970709101, 0.8453144568821833}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}}, {{
       6.1791882695788685`, 0.787915661173175}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}, {
       6.1791882695788685`, 0.787915661173175}, {6.1791882695788685`, 
       0.787915661173175}}, {{6.1791882695788685`, 0.787915661173175}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}, {6.1791882695788685`, 0.787915661173175}, {
       6.1791882695788685`, 0.787915661173175}}, {{6.1791882695788685`, 
       0.787915661173175}, {6.232394970709101, 0.8453144568821833}, {
       6.232394970709101, 0.8453144568821833}, {6.1791882695788685`, 
       0.787915661173175}, {6.1791882695788685`, 0.787915661173175}}, {{
       6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}, {{6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.6557391127793147}, {6.408124766966121, 
       0.6557391127793147}, {6.431230231631639, 0.7305168654641666}, {
       6.431230231631639, 0.7305168654641666}}, {{6.431230231631639, 
       0.7305168654641666}, {6.408124766966121, 0.6557391127793147}, {
       6.408124766966121, 0.6557391127793147}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}}, {{
       6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}}, {{6.408124766966121, 0.6557391127793147}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.408124766966121, 0.6557391127793147}, {
       6.408124766966121, 0.6557391127793147}}, {{6.408124766966121, 
       0.6557391127793147}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}, {6.408124766966121, 
       0.6557391127793147}, {6.408124766966121, 0.6557391127793147}}, {{
       6.408124766966121, 0.6557391127793147}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}, {
       6.408124766966121, 0.6557391127793147}, {6.408124766966121, 
       0.6557391127793147}}, {{6.408124766966121, 0.6557391127793147}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}, {6.408124766966121, 0.6557391127793147}, {
       6.408124766966121, 0.6557391127793147}}, {{6.364951811324127, 
       0.6157192740461499}, {6.308707136504852, 0.5983403170703064}, {
       6.308707136504852, 0.5983403170703064}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}}, {{
       6.364951811324127, 0.6157192740461499}, {6.308707136504852, 
       0.5983403170703064}, {6.308707136504852, 0.5983403170703064}, {
       6.364951811324127, 0.6157192740461499}, {6.364951811324127, 
       0.6157192740461499}}, {{6.364951811324127, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}, {6.364951811324127, 0.6157192740461499}, {
       6.364951811324127, 0.6157192740461499}}, {{6.364951811324127, 
       0.6157192740461499}, {6.308707136504852, 0.5983403170703064}, {
       6.308707136504852, 0.5983403170703064}, {6.364951811324127, 
       0.6157192740461499}, {6.364951811324127, 0.6157192740461499}}, {{
       6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}}, {{6.308707136504852, 0.5983403170703064}, {
       6.232394970709101, 0.6157192740461499}, {6.232394970709101, 
       0.6157192740461499}, {6.308707136504852, 0.5983403170703064}, {
       6.308707136504852, 0.5983403170703064}}, {{6.308707136504852, 
       0.5983403170703064}, {6.232394970709101, 0.6157192740461499}, {
       6.232394970709101, 0.6157192740461499}, {6.308707136504852, 
       0.5983403170703064}, {6.308707136504852, 0.5983403170703064}}, {{
       6.308707136504852, 0.5983403170703064}, {6.232394970709101, 
       0.6157192740461499}, {6.232394970709101, 0.6157192740461499}, {
       6.308707136504852, 0.5983403170703064}, {6.308707136504852, 
       0.5983403170703064}}, {{6.232394970709101, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}, {6.232394970709101, 0.8453144568821833}, {
       6.232394970709101, 0.8453144568821833}}, {{6.232394970709101, 
       0.8453144568821833}, {6.308707136504852, 0.8626934138580268}, {
       6.308707136504852, 0.8626934138580268}, {6.232394970709101, 
       0.8453144568821833}, {6.232394970709101, 0.8453144568821833}}, {{
       6.232394970709101, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}, {
       6.232394970709101, 0.8453144568821833}, {6.232394970709101, 
       0.8453144568821833}}, {{6.232394970709101, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}, {6.232394970709101, 0.8453144568821833}, {
       6.232394970709101, 0.8453144568821833}}, {{6.308707136504852, 
       0.8626934138580268}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}}, {{
       6.308707136504852, 0.8626934138580268}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}, {
       6.308707136504852, 0.8626934138580268}, {6.308707136504852, 
       0.8626934138580268}}, {{6.308707136504852, 0.8626934138580268}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}, {6.308707136504852, 0.8626934138580268}, {
       6.308707136504852, 0.8626934138580268}}, {{6.308707136504852, 
       0.8626934138580268}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}, {6.308707136504852, 
       0.8626934138580268}, {6.308707136504852, 0.8626934138580268}}, {{
       6.364951811324127, 0.8453144568821833}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}, {{6.364951811324127, 0.8453144568821833}, {
       6.408124766966121, 0.8052946181490185}, {6.408124766966121, 
       0.8052946181490185}, {6.364951811324127, 0.8453144568821833}, {
       6.364951811324127, 0.8453144568821833}}, {{6.364951811324127, 
       0.8453144568821833}, {6.408124766966121, 0.8052946181490185}, {
       6.408124766966121, 0.8052946181490185}, {6.364951811324127, 
       0.8453144568821833}, {6.364951811324127, 0.8453144568821833}}, {{
       6.364951811324127, 0.8453144568821833}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}, {
       6.364951811324127, 0.8453144568821833}, {6.364951811324127, 
       0.8453144568821833}}, {{6.408124766966121, 0.8052946181490185}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}, {6.408124766966121, 0.8052946181490185}, {
       6.408124766966121, 0.8052946181490185}}, {{6.408124766966121, 
       0.8052946181490185}, {6.431230231631639, 0.7305168654641666}, {
       6.431230231631639, 0.7305168654641666}, {6.408124766966121, 
       0.8052946181490185}, {6.408124766966121, 0.8052946181490185}}, {{
       6.408124766966121, 0.8052946181490185}, {6.431230231631639, 
       0.7305168654641666}, {6.431230231631639, 0.7305168654641666}, {
       6.408124766966121, 0.8052946181490185}, {6.408124766966121, 
       0.8052946181490185}}, {{6.408124766966121, 0.8052946181490185}, {
       6.431230231631639, 0.7305168654641666}, {6.431230231631639, 
       0.7305168654641666}, {6.408124766966121, 0.8052946181490185}, {
       6.408124766966121, 0.8052946181490185}}, {{6.12971674079559, 
       1.1350463193708702`}, {6.066780670172548, 1.2029410503668336`}, {
       6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.33873051235876}, {6.12971674079559, 1.4066252433547235`}, {
       6.12971674079559, 1.4066252433547235`}, {6.066780670172548, 
       1.33873051235876}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}}, {{
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}, {{6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.1823841798908885`}, {6.286512905663898, 
       1.1350463193708702`}, {6.219983337932727, 1.1144894488949253`}, {
       6.129716740795591, 1.1350463193708702`}, {6.129716740795591, 
       1.1350463193708702`}, {6.219983337932727, 1.1144894488949253`}, {
       6.286512905663898, 1.1350463193708702`}, {6.337580461583957, 
       1.1823841798908885`}, {6.364910988098051, 1.2708357813627968`}, {
       6.364910988098051, 1.2708357813627968`}}, {{6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}}, {{
       6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.286512905663898, 1.4066252433547235`}, {
       6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.286512905663898, 
       1.4066252433547235`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}, {{6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}}, {{6.12971674079559, 
       1.1350463193708702`}, {6.066780670172548, 1.2029410503668336`}, {
       6.066780670172548, 1.2029410503668336`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}}, {{
       6.12971674079559, 1.1350463193708702`}, {6.066780670172548, 
       1.2029410503668336`}, {6.066780670172548, 1.2029410503668336`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}}, {{6.12971674079559, 1.1350463193708702`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}, {6.12971674079559, 1.1350463193708702`}, {
       6.12971674079559, 1.1350463193708702`}}, {{6.12971674079559, 
       1.1350463193708702`}, {6.066780670172548, 1.2029410503668336`}, {
       6.066780670172548, 1.2029410503668336`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}}, {{
       6.066780670172548, 1.2029410503668336`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}}, {{6.066780670172548, 1.2029410503668336`}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}, {6.066780670172548, 1.2029410503668336`}, {
       6.066780670172548, 1.2029410503668336`}}, {{6.066780670172548, 
       1.2029410503668336`}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.2029410503668336`}, {6.066780670172548, 1.2029410503668336`}}, {{
       6.066780670172548, 1.2029410503668336`}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.2029410503668336`}, {6.066780670172548, 
       1.2029410503668336`}}, {{6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}}, {{6.051318658361438, 
       1.2708357813627968`}, {6.066780670172548, 1.33873051235876}, {
       6.066780670172548, 1.33873051235876}, {6.051318658361438, 
       1.2708357813627968`}, {6.051318658361438, 1.2708357813627968`}}, {{
       6.051318658361438, 1.2708357813627968`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}, {
       6.051318658361438, 1.2708357813627968`}, {6.051318658361438, 
       1.2708357813627968`}}, {{6.051318658361438, 1.2708357813627968`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}, {6.051318658361438, 1.2708357813627968`}, {
       6.051318658361438, 1.2708357813627968`}}, {{6.066780670172548, 
       1.33873051235876}, {6.12971674079559, 1.4066252433547235`}, {
       6.12971674079559, 1.4066252433547235`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}}, {{
       6.066780670172548, 1.33873051235876}, {6.12971674079559, 
       1.4066252433547235`}, {6.12971674079559, 1.4066252433547235`}, {
       6.066780670172548, 1.33873051235876}, {6.066780670172548, 
       1.33873051235876}}, {{6.066780670172548, 1.33873051235876}, {
       6.12971674079559, 1.4066252433547235`}, {6.12971674079559, 
       1.4066252433547235`}, {6.066780670172548, 1.33873051235876}, {
       6.066780670172548, 1.33873051235876}}, {{6.066780670172548, 
       1.33873051235876}, {6.12971674079559, 1.4066252433547235`}, {
       6.12971674079559, 1.4066252433547235`}, {6.066780670172548, 
       1.33873051235876}, {6.066780670172548, 1.33873051235876}}, {{
       6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}, {{6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.1823841798908885`}, {6.337580461583957, 
       1.1823841798908885`}, {6.364910988098051, 1.2708357813627968`}, {
       6.364910988098051, 1.2708357813627968`}}, {{6.364910988098051, 
       1.2708357813627968`}, {6.337580461583957, 1.1823841798908885`}, {
       6.337580461583957, 1.1823841798908885`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}}, {{
       6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}}, {{6.337580461583957, 1.1823841798908885`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.337580461583957, 1.1823841798908885`}, {
       6.337580461583957, 1.1823841798908885`}}, {{6.337580461583957, 
       1.1823841798908885`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}, {6.337580461583957, 
       1.1823841798908885`}, {6.337580461583957, 1.1823841798908885`}}, {{
       6.337580461583957, 1.1823841798908885`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}, {
       6.337580461583957, 1.1823841798908885`}, {6.337580461583957, 
       1.1823841798908885`}}, {{6.337580461583957, 1.1823841798908885`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}, {6.337580461583957, 1.1823841798908885`}, {
       6.337580461583957, 1.1823841798908885`}}, {{6.286512905663898, 
       1.1350463193708702`}, {6.219983337932727, 1.1144894488949253`}, {
       6.219983337932727, 1.1144894488949253`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}}, {{
       6.286512905663898, 1.1350463193708702`}, {6.219983337932727, 
       1.1144894488949253`}, {6.219983337932727, 1.1144894488949253`}, {
       6.286512905663898, 1.1350463193708702`}, {6.286512905663898, 
       1.1350463193708702`}}, {{6.286512905663898, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}, {6.286512905663898, 1.1350463193708702`}, {
       6.286512905663898, 1.1350463193708702`}}, {{6.286512905663898, 
       1.1350463193708702`}, {6.219983337932727, 1.1144894488949253`}, {
       6.219983337932727, 1.1144894488949253`}, {6.286512905663898, 
       1.1350463193708702`}, {6.286512905663898, 1.1350463193708702`}}, {{
       6.219983337932727, 1.1144894488949253`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}}, {{6.219983337932727, 1.1144894488949253`}, {
       6.12971674079559, 1.1350463193708702`}, {6.12971674079559, 
       1.1350463193708702`}, {6.219983337932727, 1.1144894488949253`}, {
       6.219983337932727, 1.1144894488949253`}}, {{6.219983337932727, 
       1.1144894488949253`}, {6.12971674079559, 1.1350463193708702`}, {
       6.12971674079559, 1.1350463193708702`}, {6.219983337932727, 
       1.1144894488949253`}, {6.219983337932727, 1.1144894488949253`}}, {{
       6.219983337932727, 1.1144894488949253`}, {6.12971674079559, 
       1.1350463193708702`}, {6.12971674079559, 1.1350463193708702`}, {
       6.219983337932727, 1.1144894488949253`}, {6.219983337932727, 
       1.1144894488949253`}}, {{6.129716740795591, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}, {6.129716740795591, 1.4066252433547235`}, {
       6.129716740795591, 1.4066252433547235`}}, {{6.129716740795591, 
       1.4066252433547235`}, {6.219983337932727, 1.4271821138306684`}, {
       6.219983337932727, 1.4271821138306684`}, {6.129716740795591, 
       1.4066252433547235`}, {6.129716740795591, 1.4066252433547235`}}, {{
       6.129716740795591, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}, {
       6.129716740795591, 1.4066252433547235`}, {6.129716740795591, 
       1.4066252433547235`}}, {{6.129716740795591, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}, {6.129716740795591, 1.4066252433547235`}, {
       6.129716740795591, 1.4066252433547235`}}, {{6.219983337932727, 
       1.4271821138306684`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}}, {{
       6.219983337932727, 1.4271821138306684`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}, {
       6.219983337932727, 1.4271821138306684`}, {6.219983337932727, 
       1.4271821138306684`}}, {{6.219983337932727, 1.4271821138306684`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}, {6.219983337932727, 1.4271821138306684`}, {
       6.219983337932727, 1.4271821138306684`}}, {{6.219983337932727, 
       1.4271821138306684`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}, {6.219983337932727, 
       1.4271821138306684`}, {6.219983337932727, 1.4271821138306684`}}, {{
       6.286512905663898, 1.4066252433547235`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}, {{6.286512905663898, 1.4066252433547235`}, {
       6.337580461583957, 1.3592873828347052`}, {6.337580461583957, 
       1.3592873828347052`}, {6.286512905663898, 1.4066252433547235`}, {
       6.286512905663898, 1.4066252433547235`}}, {{6.286512905663898, 
       1.4066252433547235`}, {6.337580461583957, 1.3592873828347052`}, {
       6.337580461583957, 1.3592873828347052`}, {6.286512905663898, 
       1.4066252433547235`}, {6.286512905663898, 1.4066252433547235`}}, {{
       6.286512905663898, 1.4066252433547235`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}, {
       6.286512905663898, 1.4066252433547235`}, {6.286512905663898, 
       1.4066252433547235`}}, {{6.337580461583957, 1.3592873828347052`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}, {6.337580461583957, 1.3592873828347052`}, {
       6.337580461583957, 1.3592873828347052`}}, {{6.337580461583957, 
       1.3592873828347052`}, {6.364910988098051, 1.2708357813627968`}, {
       6.364910988098051, 1.2708357813627968`}, {6.337580461583957, 
       1.3592873828347052`}, {6.337580461583957, 1.3592873828347052`}}, {{
       6.337580461583957, 1.3592873828347052`}, {6.364910988098051, 
       1.2708357813627968`}, {6.364910988098051, 1.2708357813627968`}, {
       6.337580461583957, 1.3592873828347052`}, {6.337580461583957, 
       1.3592873828347052`}}, {{6.337580461583957, 1.3592873828347052`}, {
       6.364910988098051, 1.2708357813627968`}, {6.364910988098051, 
       1.2708357813627968`}, {6.337580461583957, 1.3592873828347052`}, {
       6.337580461583957, 1.3592873828347052`}}, {{6.188669742878711, 
       1.5852890136695272`}, {6.124692476399525, 1.654306975141546}, {
       6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.7923428980855833`}, {6.188669742878711, 1.8613608595576019`}, {
       6.188669742878711, 1.8613608595576019`}, {6.124692476399525, 
       1.7923428980855831`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.6543069751415458`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}}, {{
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}, {{6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.6334100178418933`}, {6.348059897417868, 
       1.5852890136695272`}, {6.280429684070488, 1.5643920563698746`}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}, {6.280429684070488, 1.5643920563698746`}, {
       6.348059897417868, 1.5852890136695272`}, {6.399972299974856, 
       1.6334100178418933`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.4277549746874465`, 1.7233249366135646`}}, {{6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}}, {{
       6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.348059897417868, 1.8613608595576019`}, {
       6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`, 
       1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.348059897417868, 
       1.8613608595576019`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}, {{6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}}, {{6.188669742878711, 
       1.5852890136695272`}, {6.124692476399525, 1.654306975141546}, {
       6.124692476399525, 1.654306975141546}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}}, {{
       6.188669742878711, 1.5852890136695272`}, {6.124692476399525, 
       1.654306975141546}, {6.124692476399525, 1.654306975141546}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}}, {{6.188669742878711, 1.5852890136695272`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}, {6.188669742878711, 1.5852890136695272`}, {
       6.188669742878711, 1.5852890136695272`}}, {{6.188669742878711, 
       1.5852890136695272`}, {6.124692476399525, 1.654306975141546}, {
       6.124692476399525, 1.654306975141546}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}}, {{
       6.124692476399525, 1.654306975141546}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}}, {{6.124692476399525, 1.654306975141546}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}, {6.124692476399525, 1.654306975141546}, {
       6.124692476399525, 1.654306975141546}}, {{6.124692476399525, 
       1.654306975141546}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.654306975141546}, {6.124692476399525, 1.654306975141546}}, {{
       6.124692476399525, 1.654306975141546}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.654306975141546}, {6.124692476399525, 
       1.654306975141546}}, {{6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.7923428980855831`}, {6.124692476399525, 
       1.7923428980855831`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}}, {{6.108974665609133, 
       1.7233249366135646`}, {6.124692476399525, 1.7923428980855831`}, {
       6.124692476399525, 1.7923428980855831`}, {6.108974665609133, 
       1.7233249366135646`}, {6.108974665609133, 1.7233249366135646`}}, {{
       6.108974665609133, 1.7233249366135646`}, {6.124692476399525, 
       1.7923428980855831`}, {6.124692476399525, 1.7923428980855831`}, {
       6.108974665609133, 1.7233249366135646`}, {6.108974665609133, 
       1.7233249366135646`}}, {{6.108974665609133, 1.7233249366135646`}, {
       6.124692476399525, 1.7923428980855831`}, {6.124692476399525, 
       1.7923428980855831`}, {6.108974665609133, 1.7233249366135646`}, {
       6.108974665609133, 1.7233249366135646`}}, {{6.124692476399525, 
       1.7923428980855833`}, {6.188669742878711, 1.8613608595576019`}, {
       6.188669742878711, 1.8613608595576019`}, {6.124692476399525, 
       1.7923428980855833`}, {6.124692476399525, 1.7923428980855833`}}, {{
       6.124692476399525, 1.7923428980855833`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}, {
       6.124692476399525, 1.7923428980855833`}, {6.124692476399525, 
       1.7923428980855833`}}, {{6.124692476399525, 1.7923428980855833`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}, {6.124692476399525, 1.7923428980855833`}, {
       6.124692476399525, 1.7923428980855833`}}, {{6.124692476399525, 
       1.7923428980855833`}, {6.188669742878711, 1.8613608595576019`}, {
       6.188669742878711, 1.8613608595576019`}, {6.124692476399525, 
       1.7923428980855833`}, {6.124692476399525, 1.7923428980855833`}}, {{
       6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856, 
       1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}, {{6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.6334100178418933`}, {6.399972299974856, 
       1.6334100178418933`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.4277549746874465`, 1.7233249366135646`}}, {{6.4277549746874465`, 
       1.7233249366135646`}, {6.399972299974856, 1.6334100178418933`}, {
       6.399972299974856, 1.6334100178418933`}, {6.4277549746874465`, 
       1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}}, {{
       6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856, 
       1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}}, {{6.399972299974856, 1.6334100178418933`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.399972299974856, 1.6334100178418933`}, {
       6.399972299974856, 1.6334100178418933`}}, {{6.399972299974856, 
       1.6334100178418933`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}, {6.399972299974856, 
       1.6334100178418933`}, {6.399972299974856, 1.6334100178418933`}}, {{
       6.399972299974856, 1.6334100178418933`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}, {
       6.399972299974856, 1.6334100178418933`}, {6.399972299974856, 
       1.6334100178418933`}}, {{6.399972299974856, 1.6334100178418933`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}, {6.399972299974856, 1.6334100178418933`}, {
       6.399972299974856, 1.6334100178418933`}}, {{6.348059897417868, 
       1.5852890136695272`}, {6.280429684070488, 1.5643920563698746`}, {
       6.280429684070488, 1.5643920563698746`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}}, {{
       6.348059897417868, 1.5852890136695272`}, {6.280429684070488, 
       1.5643920563698746`}, {6.280429684070488, 1.5643920563698746`}, {
       6.348059897417868, 1.5852890136695272`}, {6.348059897417868, 
       1.5852890136695272`}}, {{6.348059897417868, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}, {6.348059897417868, 1.5852890136695272`}, {
       6.348059897417868, 1.5852890136695272`}}, {{6.348059897417868, 
       1.5852890136695272`}, {6.280429684070488, 1.5643920563698746`}, {
       6.280429684070488, 1.5643920563698746`}, {6.348059897417868, 
       1.5852890136695272`}, {6.348059897417868, 1.5852890136695272`}}, {{
       6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}}, {{6.280429684070488, 1.5643920563698746`}, {
       6.188669742878711, 1.5852890136695272`}, {6.188669742878711, 
       1.5852890136695272`}, {6.280429684070488, 1.5643920563698746`}, {
       6.280429684070488, 1.5643920563698746`}}, {{6.280429684070488, 
       1.5643920563698746`}, {6.188669742878711, 1.5852890136695272`}, {
       6.188669742878711, 1.5852890136695272`}, {6.280429684070488, 
       1.5643920563698746`}, {6.280429684070488, 1.5643920563698746`}}, {{
       6.280429684070488, 1.5643920563698746`}, {6.188669742878711, 
       1.5852890136695272`}, {6.188669742878711, 1.5852890136695272`}, {
       6.280429684070488, 1.5643920563698746`}, {6.280429684070488, 
       1.5643920563698746`}}, {{6.188669742878711, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}, {6.188669742878711, 1.8613608595576019`}, {
       6.188669742878711, 1.8613608595576019`}}, {{6.188669742878711, 
       1.8613608595576019`}, {6.280429684070488, 1.8822578168572546`}, {
       6.280429684070488, 1.8822578168572546`}, {6.188669742878711, 
       1.8613608595576019`}, {6.188669742878711, 1.8613608595576019`}}, {{
       6.188669742878711, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}, {
       6.188669742878711, 1.8613608595576019`}, {6.188669742878711, 
       1.8613608595576019`}}, {{6.188669742878711, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}, {6.188669742878711, 1.8613608595576019`}, {
       6.188669742878711, 1.8613608595576019`}}, {{6.280429684070488, 
       1.8822578168572546`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}}, {{
       6.280429684070488, 1.8822578168572546`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}, {
       6.280429684070488, 1.8822578168572546`}, {6.280429684070488, 
       1.8822578168572546`}}, {{6.280429684070488, 1.8822578168572546`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}, {6.280429684070488, 1.8822578168572546`}, {
       6.280429684070488, 1.8822578168572546`}}, {{6.280429684070488, 
       1.8822578168572546`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}, {6.280429684070488, 
       1.8822578168572546`}, {6.280429684070488, 1.8822578168572546`}}, {{
       6.348059897417868, 1.8613608595576019`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}, {{6.348059897417868, 1.8613608595576019`}, {
       6.399972299974856, 1.8132398553852358`}, {6.399972299974856, 
       1.8132398553852358`}, {6.348059897417868, 1.8613608595576019`}, {
       6.348059897417868, 1.8613608595576019`}}, {{6.348059897417868, 
       1.8613608595576019`}, {6.399972299974856, 1.8132398553852358`}, {
       6.399972299974856, 1.8132398553852358`}, {6.348059897417868, 
       1.8613608595576019`}, {6.348059897417868, 1.8613608595576019`}}, {{
       6.348059897417868, 1.8613608595576019`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}, {
       6.348059897417868, 1.8613608595576019`}, {6.348059897417868, 
       1.8613608595576019`}}, {{6.399972299974856, 1.8132398553852358`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}, {6.399972299974856, 1.8132398553852358`}, {
       6.399972299974856, 1.8132398553852358`}}, {{6.399972299974856, 
       1.8132398553852358`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.399972299974856, 
       1.8132398553852358`}, {6.399972299974856, 1.8132398553852358`}}, {{
       6.399972299974856, 1.8132398553852358`}, {6.4277549746874465`, 
       1.7233249366135646`}, {6.4277549746874465`, 1.7233249366135646`}, {
       6.399972299974856, 1.8132398553852358`}, {6.399972299974856, 
       1.8132398553852358`}}, {{6.399972299974856, 1.8132398553852358`}, {
       6.4277549746874465`, 1.7233249366135646`}, {6.4277549746874465`, 
       1.7233249366135646`}, {6.399972299974856, 1.8132398553852358`}, {
       6.399972299974856, 1.8132398553852358`}}, {{6.209149727284057, 
       2.077779843784034}, {6.144328172804688, 2.1477086137334176`}, {
       6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.287566153632185}, {6.209149727284057, 2.357494923581569}, {
       6.209149727284057, 2.357494923581569}, {6.144328172804688, 
       2.287566153632185}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}}, {{
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}, {{6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.1265358858161787`}, {6.370643303901561, 
       2.077779843784034}, {6.302120595755305, 2.056607115866795}, {
       6.209149727284057, 2.0777798437840334`}, {6.209149727284057, 
       2.0777798437840334`}, {6.302120595755306, 2.056607115866795}, {
       6.370643303901561, 2.077779843784034}, {6.423240778218434, 
       2.1265358858161787`}, {6.451390092210314, 2.2176373836828014`}, {
       6.451390092210314, 2.2176373836828014`}}, {{6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}}, {{
       6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.370643303901561, 2.357494923581569}, {
       6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.370643303901561, 
       2.357494923581569}, {6.302120595755305, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}, {{6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}}, {{6.209149727284057, 
       2.077779843784034}, {6.144328172804688, 2.1477086137334176`}, {
       6.144328172804688, 2.1477086137334176`}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}}, {{
       6.209149727284057, 2.077779843784034}, {6.144328172804688, 
       2.1477086137334176`}, {6.144328172804688, 2.1477086137334176`}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}}, {{6.209149727284057, 2.077779843784034}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}, {6.209149727284057, 2.077779843784034}, {
       6.209149727284057, 2.077779843784034}}, {{6.209149727284057, 
       2.077779843784034}, {6.144328172804688, 2.1477086137334176`}, {
       6.144328172804688, 2.1477086137334176`}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}}, {{
       6.144328172804688, 2.1477086137334176`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}}, {{6.144328172804688, 2.1477086137334176`}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}, {6.144328172804688, 2.1477086137334176`}, {
       6.144328172804688, 2.1477086137334176`}}, {{6.144328172804688, 
       2.1477086137334176`}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.1477086137334176`}, {6.144328172804688, 2.1477086137334176`}}, {{
       6.144328172804688, 2.1477086137334176`}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.1477086137334176`}, {6.144328172804688, 
       2.1477086137334176`}}, {{6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}}, {{6.128402938975304, 
       2.2176373836828014`}, {6.144328172804688, 2.287566153632185}, {
       6.144328172804688, 2.287566153632185}, {6.128402938975304, 
       2.2176373836828014`}, {6.128402938975304, 2.2176373836828014`}}, {{
       6.128402938975304, 2.2176373836828014`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}, {
       6.128402938975304, 2.2176373836828014`}, {6.128402938975304, 
       2.2176373836828014`}}, {{6.128402938975304, 2.2176373836828014`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}, {6.128402938975304, 2.2176373836828014`}, {
       6.128402938975304, 2.2176373836828014`}}, {{6.144328172804688, 
       2.287566153632185}, {6.209149727284057, 2.3574949235815694`}, {
       6.209149727284057, 2.3574949235815694`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}}, {{
       6.144328172804688, 2.287566153632185}, {6.209149727284057, 
       2.3574949235815694`}, {6.209149727284057, 2.3574949235815694`}, {
       6.144328172804688, 2.287566153632185}, {6.144328172804688, 
       2.287566153632185}}, {{6.144328172804688, 2.287566153632185}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}, {6.144328172804688, 2.287566153632185}, {
       6.144328172804688, 2.287566153632185}}, {{6.144328172804688, 
       2.287566153632185}, {6.209149727284057, 2.3574949235815694`}, {
       6.209149727284057, 2.3574949235815694`}, {6.144328172804688, 
       2.287566153632185}, {6.144328172804688, 2.287566153632185}}, {{
       6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}, {{6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.1265358858161787`}, {6.423240778218434, 
       2.1265358858161787`}, {6.451390092210314, 2.2176373836828014`}, {
       6.451390092210314, 2.2176373836828014`}}, {{6.451390092210314, 
       2.2176373836828014`}, {6.423240778218434, 2.1265358858161787`}, {
       6.423240778218434, 2.1265358858161787`}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}}, {{
       6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}}, {{6.423240778218434, 2.1265358858161787`}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.423240778218434, 2.1265358858161787`}, {
       6.423240778218434, 2.1265358858161787`}}, {{6.423240778218434, 
       2.1265358858161787`}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}, {6.423240778218434, 
       2.1265358858161787`}, {6.423240778218434, 2.1265358858161787`}}, {{
       6.423240778218434, 2.1265358858161787`}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}, {
       6.423240778218434, 2.1265358858161787`}, {6.423240778218434, 
       2.1265358858161787`}}, {{6.423240778218434, 2.1265358858161787`}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}, {6.423240778218434, 2.1265358858161787`}, {
       6.423240778218434, 2.1265358858161787`}}, {{6.370643303901561, 
       2.077779843784034}, {6.302120595755306, 2.056607115866795}, {
       6.302120595755306, 2.056607115866795}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}}, {{
       6.370643303901561, 2.077779843784034}, {6.302120595755306, 
       2.056607115866795}, {6.302120595755306, 2.056607115866795}, {
       6.370643303901561, 2.077779843784034}, {6.370643303901561, 
       2.077779843784034}}, {{6.370643303901561, 2.077779843784034}, {
       6.302120595755306, 2.056607115866795}, {6.302120595755306, 
       2.056607115866795}, {6.370643303901561, 2.077779843784034}, {
       6.370643303901561, 2.077779843784034}}, {{6.370643303901561, 
       2.077779843784034}, {6.302120595755306, 2.056607115866795}, {
       6.302120595755306, 2.056607115866795}, {6.370643303901561, 
       2.077779843784034}, {6.370643303901561, 2.077779843784034}}, {{
       6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.302120595755305, 
       2.056607115866795}}, {{6.302120595755305, 2.056607115866795}, {
       6.209149727284057, 2.077779843784034}, {6.209149727284057, 
       2.077779843784034}, {6.302120595755305, 2.056607115866795}, {
       6.302120595755305, 2.056607115866795}}, {{6.302120595755305, 
       2.056607115866795}, {6.209149727284057, 2.077779843784034}, {
       6.209149727284057, 2.077779843784034}, {6.302120595755305, 
       2.056607115866795}, {6.302120595755305, 2.056607115866795}}, {{
       6.302120595755305, 2.056607115866795}, {6.209149727284057, 
       2.077779843784034}, {6.209149727284057, 2.077779843784034}, {
       6.302120595755305, 2.056607115866795}, {6.302120595755305, 
       2.056607115866795}}, {{6.209149727284057, 2.3574949235815694`}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}, {6.209149727284057, 2.3574949235815694`}, {
       6.209149727284057, 2.3574949235815694`}}, {{6.209149727284057, 
       2.3574949235815694`}, {6.302120595755306, 2.378667651498808}, {
       6.302120595755306, 2.378667651498808}, {6.209149727284057, 
       2.3574949235815694`}, {6.209149727284057, 2.3574949235815694`}}, {{
       6.209149727284057, 2.3574949235815694`}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}, {
       6.209149727284057, 2.3574949235815694`}, {6.209149727284057, 
       2.3574949235815694`}}, {{6.209149727284057, 2.3574949235815694`}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}, {6.209149727284057, 2.3574949235815694`}, {
       6.209149727284057, 2.3574949235815694`}}, {{6.302120595755306, 
       2.378667651498808}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}}, {{
       6.302120595755306, 2.378667651498808}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}, {
       6.302120595755306, 2.378667651498808}, {6.302120595755306, 
       2.378667651498808}}, {{6.302120595755306, 2.378667651498808}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}, {6.302120595755306, 2.378667651498808}, {
       6.302120595755306, 2.378667651498808}}, {{6.302120595755306, 
       2.378667651498808}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}, {6.302120595755306, 
       2.378667651498808}, {6.302120595755306, 2.378667651498808}}, {{
       6.370643303901561, 2.357494923581569}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}, {{6.370643303901561, 2.357494923581569}, {
       6.423240778218434, 2.308738881549424}, {6.423240778218434, 
       2.308738881549424}, {6.370643303901561, 2.357494923581569}, {
       6.370643303901561, 2.357494923581569}}, {{6.370643303901561, 
       2.357494923581569}, {6.423240778218434, 2.308738881549424}, {
       6.423240778218434, 2.308738881549424}, {6.370643303901561, 
       2.357494923581569}, {6.370643303901561, 2.357494923581569}}, {{
       6.370643303901561, 2.357494923581569}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}, {
       6.370643303901561, 2.357494923581569}, {6.370643303901561, 
       2.357494923581569}}, {{6.423240778218434, 2.308738881549424}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}, {6.423240778218434, 2.308738881549424}, {
       6.423240778218434, 2.308738881549424}}, {{6.423240778218434, 
       2.308738881549424}, {6.451390092210314, 2.2176373836828014`}, {
       6.451390092210314, 2.2176373836828014`}, {6.423240778218434, 
       2.308738881549424}, {6.423240778218434, 2.308738881549424}}, {{
       6.423240778218434, 2.308738881549424}, {6.451390092210314, 
       2.2176373836828014`}, {6.451390092210314, 2.2176373836828014`}, {
       6.423240778218434, 2.308738881549424}, {6.423240778218434, 
       2.308738881549424}}, {{6.423240778218434, 2.308738881549424}, {
       6.451390092210314, 2.2176373836828014`}, {6.451390092210314, 
       2.2176373836828014`}, {6.423240778218434, 2.308738881549424}, {
       6.423240778218434, 2.308738881549424}}, {{6.130007095863632, 
       2.6344843358205394`}, {6.062932074600658, 2.706844120600791}, {
       6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.851563690161293}, {6.130007095863632, 2.9239234749415446`}, {
       6.130007095863632, 2.9239234749415446`}, {6.062932074600658, 
       2.851563690161293}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}}, {{
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}, {{6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.6849353406178005`}, {6.297114860749157, 
       2.6344843358205394`}, {6.2262100183271905`, 2.612575555837549}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}, {6.2262100183271905`, 2.612575555837549}, {
       6.297114860749157, 2.6344843358205394`}, {6.351540841991334, 
       2.6849353406178005`}, {6.3806687431919205`, 2.779203905381042}, {
       6.3806687431919205`, 2.779203905381042}}, {{6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}}, {{
       6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`, 
       2.945832254924535}, {6.297114860749157, 2.9239234749415446`}, {
       6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`, 
       2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.297114860749157, 
       2.9239234749415446`}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}, {{6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}}, {{6.130007095863632, 
       2.6344843358205394`}, {6.062932074600658, 2.706844120600791}, {
       6.062932074600658, 2.706844120600791}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}}, {{
       6.130007095863632, 2.6344843358205394`}, {6.062932074600658, 
       2.706844120600791}, {6.062932074600658, 2.706844120600791}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}}, {{6.130007095863632, 2.6344843358205394`}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}, {6.130007095863632, 2.6344843358205394`}, {
       6.130007095863632, 2.6344843358205394`}}, {{6.130007095863632, 
       2.6344843358205394`}, {6.062932074600658, 2.706844120600791}, {
       6.062932074600658, 2.706844120600791}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}}, {{
       6.062932074600658, 2.706844120600791}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}}, {{6.062932074600658, 2.706844120600791}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}, {6.062932074600658, 2.706844120600791}, {
       6.062932074600658, 2.706844120600791}}, {{6.062932074600658, 
       2.706844120600791}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.706844120600791}, {6.062932074600658, 2.706844120600791}}, {{
       6.062932074600658, 2.706844120600791}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.706844120600791}, {6.062932074600658, 
       2.706844120600791}}, {{6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}}, {{6.046453213420868, 
       2.779203905381042}, {6.062932074600658, 2.851563690161293}, {
       6.062932074600658, 2.851563690161293}, {6.046453213420868, 
       2.779203905381042}, {6.046453213420868, 2.779203905381042}}, {{
       6.046453213420868, 2.779203905381042}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}, {
       6.046453213420868, 2.779203905381042}, {6.046453213420868, 
       2.779203905381042}}, {{6.046453213420868, 2.779203905381042}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}, {6.046453213420868, 2.779203905381042}, {
       6.046453213420868, 2.779203905381042}}, {{6.062932074600658, 
       2.851563690161293}, {6.130007095863632, 2.9239234749415446`}, {
       6.130007095863632, 2.9239234749415446`}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}}, {{
       6.062932074600658, 2.851563690161293}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}, {
       6.062932074600658, 2.851563690161293}, {6.062932074600658, 
       2.851563690161293}}, {{6.062932074600658, 2.851563690161293}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}, {6.062932074600658, 2.851563690161293}, {
       6.062932074600658, 2.851563690161293}}, {{6.062932074600658, 
       2.851563690161293}, {6.130007095863632, 2.9239234749415446`}, {
       6.130007095863632, 2.9239234749415446`}, {6.062932074600658, 
       2.851563690161293}, {6.062932074600658, 2.851563690161293}}, {{
       6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}, {{6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.6849353406178005`}, {6.351540841991334, 
       2.6849353406178005`}, {6.3806687431919205`, 2.779203905381042}, {
       6.3806687431919205`, 2.779203905381042}}, {{6.3806687431919205`, 
       2.779203905381042}, {6.351540841991334, 2.6849353406178005`}, {
       6.351540841991334, 2.6849353406178005`}, {6.3806687431919205`, 
       2.779203905381042}, {6.3806687431919205`, 2.779203905381042}}, {{
       6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}}, {{6.351540841991334, 2.6849353406178005`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.351540841991334, 2.6849353406178005`}, {
       6.351540841991334, 2.6849353406178005`}}, {{6.351540841991334, 
       2.6849353406178005`}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}, {6.351540841991334, 
       2.6849353406178005`}, {6.351540841991334, 2.6849353406178005`}}, {{
       6.351540841991334, 2.6849353406178005`}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}, {
       6.351540841991334, 2.6849353406178005`}, {6.351540841991334, 
       2.6849353406178005`}}, {{6.351540841991334, 2.6849353406178005`}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}, {6.351540841991334, 2.6849353406178005`}, {
       6.351540841991334, 2.6849353406178005`}}, {{6.297114860749157, 
       2.6344843358205394`}, {6.2262100183271905`, 2.612575555837549}, {
       6.2262100183271905`, 2.612575555837549}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}}, {{
       6.297114860749157, 2.6344843358205394`}, {6.2262100183271905`, 
       2.612575555837549}, {6.2262100183271905`, 2.612575555837549}, {
       6.297114860749157, 2.6344843358205394`}, {6.297114860749157, 
       2.6344843358205394`}}, {{6.297114860749157, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}, {6.297114860749157, 2.6344843358205394`}, {
       6.297114860749157, 2.6344843358205394`}}, {{6.297114860749157, 
       2.6344843358205394`}, {6.2262100183271905`, 2.612575555837549}, {
       6.2262100183271905`, 2.612575555837549}, {6.297114860749157, 
       2.6344843358205394`}, {6.297114860749157, 2.6344843358205394`}}, {{
       6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}}, {{6.2262100183271905`, 2.612575555837549}, {
       6.130007095863632, 2.6344843358205394`}, {6.130007095863632, 
       2.6344843358205394`}, {6.2262100183271905`, 2.612575555837549}, {
       6.2262100183271905`, 2.612575555837549}}, {{6.2262100183271905`, 
       2.612575555837549}, {6.130007095863632, 2.6344843358205394`}, {
       6.130007095863632, 2.6344843358205394`}, {6.2262100183271905`, 
       2.612575555837549}, {6.2262100183271905`, 2.612575555837549}}, {{
       6.2262100183271905`, 2.612575555837549}, {6.130007095863632, 
       2.6344843358205394`}, {6.130007095863632, 2.6344843358205394`}, {
       6.2262100183271905`, 2.612575555837549}, {6.2262100183271905`, 
       2.612575555837549}}, {{6.130007095863632, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}, {6.130007095863632, 2.9239234749415446`}, {
       6.130007095863632, 2.9239234749415446`}}, {{6.130007095863632, 
       2.9239234749415446`}, {6.2262100183271905`, 2.945832254924535}, {
       6.2262100183271905`, 2.945832254924535}, {6.130007095863632, 
       2.9239234749415446`}, {6.130007095863632, 2.9239234749415446`}}, {{
       6.130007095863632, 2.9239234749415446`}, {6.2262100183271905`, 
       2.945832254924535}, {6.2262100183271905`, 2.945832254924535}, {
       6.130007095863632, 2.9239234749415446`}, {6.130007095863632, 
       2.9239234749415446`}}, {{6.130007095863632, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}, {6.130007095863632, 2.9239234749415446`}, {
       6.130007095863632, 2.9239234749415446`}}, {{6.2262100183271905`, 
       2.945832254924535}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.2262100183271905`, 
       2.945832254924535}, {6.2262100183271905`, 2.945832254924535}}, {{
       6.2262100183271905`, 2.945832254924535}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}, {
       6.2262100183271905`, 2.945832254924535}, {6.2262100183271905`, 
       2.945832254924535}}, {{6.2262100183271905`, 2.945832254924535}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}, {6.2262100183271905`, 2.945832254924535}, {
       6.2262100183271905`, 2.945832254924535}}, {{6.2262100183271905`, 
       2.945832254924535}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}, {6.2262100183271905`, 
       2.945832254924535}, {6.2262100183271905`, 2.945832254924535}}, {{
       6.297114860749157, 2.9239234749415446`}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}, {{6.297114860749157, 2.9239234749415446`}, {
       6.351540841991334, 2.8734724701442835`}, {6.351540841991334, 
       2.8734724701442835`}, {6.297114860749157, 2.9239234749415446`}, {
       6.297114860749157, 2.9239234749415446`}}, {{6.297114860749157, 
       2.9239234749415446`}, {6.351540841991334, 2.8734724701442835`}, {
       6.351540841991334, 2.8734724701442835`}, {6.297114860749157, 
       2.9239234749415446`}, {6.297114860749157, 2.9239234749415446`}}, {{
       6.297114860749157, 2.9239234749415446`}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}, {
       6.297114860749157, 2.9239234749415446`}, {6.297114860749157, 
       2.9239234749415446`}}, {{6.351540841991334, 2.8734724701442835`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}, {6.351540841991334, 2.8734724701442835`}, {
       6.351540841991334, 2.8734724701442835`}}, {{6.351540841991334, 
       2.8734724701442835`}, {6.3806687431919205`, 2.779203905381042}, {
       6.3806687431919205`, 2.779203905381042}, {6.351540841991334, 
       2.8734724701442835`}, {6.351540841991334, 2.8734724701442835`}}, {{
       6.351540841991334, 2.8734724701442835`}, {6.3806687431919205`, 
       2.779203905381042}, {6.3806687431919205`, 2.779203905381042}, {
       6.351540841991334, 2.8734724701442835`}, {6.351540841991334, 
       2.8734724701442835`}}, {{6.351540841991334, 2.8734724701442835`}, {
       6.3806687431919205`, 2.779203905381042}, {6.3806687431919205`, 
       2.779203905381042}, {6.351540841991334, 2.8734724701442835`}, {
       6.351540841991334, 2.8734724701442835`}}, {{6.194051610877686, 
       3.084844964017741}, {6.127275875910808, 3.1568818820800204`}, {
       6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.300955718204579}, {6.194051610877686, 3.3729926362668583`}, {
       6.194051610877686, 3.3729926362668583`}, {6.127275875910808, 
       3.300955718204579}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}}, {{
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}, {{6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.1350708582734663`}, {6.360413747017079, 
       3.084844964017741}, {6.289825279413398, 3.063033940211187}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}, {6.289825279413398, 3.063033940211187}, {
       6.360413747017079, 3.084844964017741}, {6.414596881517942, 
       3.1350708582734663`}, {6.443594815086774, 3.2289188001422997`}, {
       6.443594815086774, 3.2289188001422997`}}, {{6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}}, {{
       6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.360413747017079, 3.3729926362668583`}, {
       6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.360413747017079, 
       3.3729926362668583`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}, {{6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}}, {{6.194051610877686, 
       3.084844964017741}, {6.127275875910808, 3.1568818820800204`}, {
       6.127275875910808, 3.1568818820800204`}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}}, {{
       6.194051610877686, 3.084844964017741}, {6.127275875910808, 
       3.1568818820800204`}, {6.127275875910808, 3.1568818820800204`}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}}, {{6.194051610877686, 3.084844964017741}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}, {6.194051610877686, 3.084844964017741}, {
       6.194051610877686, 3.084844964017741}}, {{6.194051610877686, 
       3.084844964017741}, {6.127275875910808, 3.1568818820800204`}, {
       6.127275875910808, 3.1568818820800204`}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}}, {{
       6.127275875910808, 3.1568818820800204`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}}, {{6.127275875910808, 3.1568818820800204`}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}, {6.127275875910808, 3.1568818820800204`}, {
       6.127275875910808, 3.1568818820800204`}}, {{6.127275875910808, 
       3.1568818820800204`}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.1568818820800204`}, {6.127275875910808, 3.1568818820800204`}}, {{
       6.127275875910808, 3.1568818820800204`}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.1568818820800204`}, {6.127275875910808, 
       3.1568818820800204`}}, {{6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}}, {{6.110870542807991, 
       3.2289188001422997`}, {6.127275875910808, 3.300955718204579}, {
       6.127275875910808, 3.300955718204579}, {6.110870542807991, 
       3.2289188001422997`}, {6.110870542807991, 3.2289188001422997`}}, {{
       6.110870542807991, 3.2289188001422997`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}, {
       6.110870542807991, 3.2289188001422997`}, {6.110870542807991, 
       3.2289188001422997`}}, {{6.110870542807991, 3.2289188001422997`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}, {6.110870542807991, 3.2289188001422997`}, {
       6.110870542807991, 3.2289188001422997`}}, {{6.127275875910808, 
       3.300955718204579}, {6.194051610877686, 3.3729926362668583`}, {
       6.194051610877686, 3.3729926362668583`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}}, {{
       6.127275875910808, 3.300955718204579}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}, {
       6.127275875910808, 3.300955718204579}, {6.127275875910808, 
       3.300955718204579}}, {{6.127275875910808, 3.300955718204579}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}, {6.127275875910808, 3.300955718204579}, {
       6.127275875910808, 3.300955718204579}}, {{6.127275875910808, 
       3.300955718204579}, {6.194051610877686, 3.3729926362668583`}, {
       6.194051610877686, 3.3729926362668583`}, {6.127275875910808, 
       3.300955718204579}, {6.127275875910808, 3.300955718204579}}, {{
       6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}, {{6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.1350708582734663`}, {6.414596881517942, 
       3.1350708582734663`}, {6.443594815086774, 3.2289188001422997`}, {
       6.443594815086774, 3.2289188001422997`}}, {{6.443594815086774, 
       3.2289188001422997`}, {6.414596881517942, 3.1350708582734663`}, {
       6.414596881517942, 3.1350708582734663`}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}}, {{
       6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}}, {{6.414596881517942, 3.1350708582734663`}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.414596881517942, 3.1350708582734663`}, {
       6.414596881517942, 3.1350708582734663`}}, {{6.414596881517942, 
       3.1350708582734663`}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}, {6.414596881517942, 
       3.1350708582734663`}, {6.414596881517942, 3.1350708582734663`}}, {{
       6.414596881517942, 3.1350708582734663`}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}, {
       6.414596881517942, 3.1350708582734663`}, {6.414596881517942, 
       3.1350708582734663`}}, {{6.414596881517942, 3.1350708582734663`}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}, {6.414596881517942, 3.1350708582734663`}, {
       6.414596881517942, 3.1350708582734663`}}, {{6.360413747017079, 
       3.084844964017741}, {6.289825279413398, 3.063033940211187}, {
       6.289825279413398, 3.063033940211187}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}}, {{
       6.360413747017079, 3.084844964017741}, {6.289825279413398, 
       3.063033940211187}, {6.289825279413398, 3.063033940211187}, {
       6.360413747017079, 3.084844964017741}, {6.360413747017079, 
       3.084844964017741}}, {{6.360413747017079, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}, {6.360413747017079, 3.084844964017741}, {
       6.360413747017079, 3.084844964017741}}, {{6.360413747017079, 
       3.084844964017741}, {6.289825279413398, 3.063033940211187}, {
       6.289825279413398, 3.063033940211187}, {6.360413747017079, 
       3.084844964017741}, {6.360413747017079, 3.084844964017741}}, {{
       6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}}, {{6.289825279413398, 3.063033940211187}, {
       6.194051610877686, 3.084844964017741}, {6.194051610877686, 
       3.084844964017741}, {6.289825279413398, 3.063033940211187}, {
       6.289825279413398, 3.063033940211187}}, {{6.289825279413398, 
       3.063033940211187}, {6.194051610877686, 3.084844964017741}, {
       6.194051610877686, 3.084844964017741}, {6.289825279413398, 
       3.063033940211187}, {6.289825279413398, 3.063033940211187}}, {{
       6.289825279413398, 3.063033940211187}, {6.194051610877686, 
       3.084844964017741}, {6.194051610877686, 3.084844964017741}, {
       6.289825279413398, 3.063033940211187}, {6.289825279413398, 
       3.063033940211187}}, {{6.194051610877686, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}, {6.194051610877686, 3.3729926362668583`}, {
       6.194051610877686, 3.3729926362668583`}}, {{6.194051610877686, 
       3.3729926362668583`}, {6.289825279413398, 3.3948036600734124`}, {
       6.289825279413398, 3.3948036600734124`}, {6.194051610877686, 
       3.3729926362668583`}, {6.194051610877686, 3.3729926362668583`}}, {{
       6.194051610877686, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}, {
       6.194051610877686, 3.3729926362668583`}, {6.194051610877686, 
       3.3729926362668583`}}, {{6.194051610877686, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}, {6.194051610877686, 3.3729926362668583`}, {
       6.194051610877686, 3.3729926362668583`}}, {{6.289825279413398, 
       3.3948036600734124`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}}, {{
       6.289825279413398, 3.3948036600734124`}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}, {
       6.289825279413398, 3.3948036600734124`}, {6.289825279413398, 
       3.3948036600734124`}}, {{6.289825279413398, 3.3948036600734124`}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}, {6.289825279413398, 3.3948036600734124`}, {
       6.289825279413398, 3.3948036600734124`}}, {{6.289825279413398, 
       3.3948036600734124`}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}, {6.289825279413398, 
       3.3948036600734124`}, {6.289825279413398, 3.3948036600734124`}}, {{
       6.360413747017079, 3.3729926362668583`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}, {{6.360413747017079, 3.3729926362668583`}, {
       6.414596881517942, 3.322766742011133}, {6.414596881517942, 
       3.322766742011133}, {6.360413747017079, 3.3729926362668583`}, {
       6.360413747017079, 3.3729926362668583`}}, {{6.360413747017079, 
       3.3729926362668583`}, {6.414596881517942, 3.322766742011133}, {
       6.414596881517942, 3.322766742011133}, {6.360413747017079, 
       3.3729926362668583`}, {6.360413747017079, 3.3729926362668583`}}, {{
       6.360413747017079, 3.3729926362668583`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}, {
       6.360413747017079, 3.3729926362668583`}, {6.360413747017079, 
       3.3729926362668583`}}, {{6.414596881517942, 3.322766742011133}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}, {6.414596881517942, 3.322766742011133}, {
       6.414596881517942, 3.322766742011133}}, {{6.414596881517942, 
       3.322766742011133}, {6.443594815086774, 3.2289188001422997`}, {
       6.443594815086774, 3.2289188001422997`}, {6.414596881517942, 
       3.322766742011133}, {6.414596881517942, 3.322766742011133}}, {{
       6.414596881517942, 3.322766742011133}, {6.443594815086774, 
       3.2289188001422997`}, {6.443594815086774, 3.2289188001422997`}, {
       6.414596881517942, 3.322766742011133}, {6.414596881517942, 
       3.322766742011133}}, {{6.414596881517942, 3.322766742011133}, {
       6.443594815086774, 3.2289188001422997`}, {6.443594815086774, 
       3.2289188001422997`}, {6.414596881517942, 3.322766742011133}, {
       6.414596881517942, 3.322766742011133}}, {{6.157855081110001, 
       3.573951207401159}, {6.09710621629842, 3.639486405163924}, {
       6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.770556800689454}, {6.157855081110001, 3.836091998452219}, {
       6.157855081110001, 3.836091998452219}, {6.09710621629842, 
       3.770556800689454}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}}, {{
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}, {{6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.6196439438674104`}, {6.309202137388913, 
       3.573951207401159}, {6.244984659620384, 3.5541087461046454`}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}, {6.244984659620384, 3.5541087461046454`}, {
       6.309202137388913, 3.573951207401159}, {6.358494951829567, 
       3.6196439438674104`}, {6.384875665528368, 3.705021602926689}, {
       6.384875665528368, 3.705021602926689}}, {{6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}}, {{
       6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.309202137388913, 3.836091998452219}, {
       6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.309202137388913, 
       3.836091998452219}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}, {{6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}}, {{6.157855081110001, 
       3.573951207401159}, {6.09710621629842, 3.639486405163924}, {
       6.09710621629842, 3.639486405163924}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}}, {{
       6.157855081110001, 3.573951207401159}, {6.09710621629842, 
       3.639486405163924}, {6.09710621629842, 3.639486405163924}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}}, {{6.157855081110001, 3.573951207401159}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}, {6.157855081110001, 3.573951207401159}, {
       6.157855081110001, 3.573951207401159}}, {{6.157855081110001, 
       3.573951207401159}, {6.09710621629842, 3.639486405163924}, {
       6.09710621629842, 3.639486405163924}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}}, {{
       6.09710621629842, 3.639486405163924}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}}, {{6.09710621629842, 3.639486405163924}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}, {6.09710621629842, 3.639486405163924}, {
       6.09710621629842, 3.639486405163924}}, {{6.09710621629842, 
       3.639486405163924}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.639486405163924}, {6.09710621629842, 3.639486405163924}}, {{
       6.09710621629842, 3.639486405163924}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.639486405163924}, {6.09710621629842, 
       3.639486405163924}}, {{6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}}, {{6.082181552970546, 
       3.705021602926689}, {6.09710621629842, 3.770556800689454}, {
       6.09710621629842, 3.770556800689454}, {6.082181552970546, 
       3.705021602926689}, {6.082181552970546, 3.705021602926689}}, {{
       6.082181552970546, 3.705021602926689}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}, {
       6.082181552970546, 3.705021602926689}, {6.082181552970546, 
       3.705021602926689}}, {{6.082181552970546, 3.705021602926689}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}, {6.082181552970546, 3.705021602926689}, {
       6.082181552970546, 3.705021602926689}}, {{6.09710621629842, 
       3.770556800689454}, {6.157855081110001, 3.836091998452219}, {
       6.157855081110001, 3.836091998452219}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}}, {{
       6.09710621629842, 3.770556800689454}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}, {
       6.09710621629842, 3.770556800689454}, {6.09710621629842, 
       3.770556800689454}}, {{6.09710621629842, 3.770556800689454}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}, {6.09710621629842, 3.770556800689454}, {
       6.09710621629842, 3.770556800689454}}, {{6.09710621629842, 
       3.770556800689454}, {6.157855081110001, 3.836091998452219}, {
       6.157855081110001, 3.836091998452219}, {6.09710621629842, 
       3.770556800689454}, {6.09710621629842, 3.770556800689454}}, {{
       6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}, {{6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.6196439438674104`}, {6.358494951829567, 
       3.6196439438674104`}, {6.384875665528368, 3.705021602926689}, {
       6.384875665528368, 3.705021602926689}}, {{6.384875665528368, 
       3.705021602926689}, {6.358494951829567, 3.6196439438674104`}, {
       6.358494951829567, 3.6196439438674104`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}}, {{
       6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}}, {{6.358494951829567, 3.6196439438674104`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.358494951829567, 3.6196439438674104`}, {
       6.358494951829567, 3.6196439438674104`}}, {{6.358494951829567, 
       3.6196439438674104`}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}, {6.358494951829567, 
       3.6196439438674104`}, {6.358494951829567, 3.6196439438674104`}}, {{
       6.358494951829567, 3.6196439438674104`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}, {
       6.358494951829567, 3.6196439438674104`}, {6.358494951829567, 
       3.6196439438674104`}}, {{6.358494951829567, 3.6196439438674104`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}, {6.358494951829567, 3.6196439438674104`}, {
       6.358494951829567, 3.6196439438674104`}}, {{6.309202137388913, 
       3.573951207401159}, {6.244984659620384, 3.5541087461046454`}, {
       6.244984659620384, 3.5541087461046454`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}}, {{
       6.309202137388913, 3.573951207401159}, {6.244984659620384, 
       3.5541087461046454`}, {6.244984659620384, 3.5541087461046454`}, {
       6.309202137388913, 3.573951207401159}, {6.309202137388913, 
       3.573951207401159}}, {{6.309202137388913, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}, {6.309202137388913, 3.573951207401159}, {
       6.309202137388913, 3.573951207401159}}, {{6.309202137388913, 
       3.573951207401159}, {6.244984659620384, 3.5541087461046454`}, {
       6.244984659620384, 3.5541087461046454`}, {6.309202137388913, 
       3.573951207401159}, {6.309202137388913, 3.573951207401159}}, {{
       6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}}, {{6.244984659620384, 3.5541087461046454`}, {
       6.157855081110001, 3.573951207401159}, {6.157855081110001, 
       3.573951207401159}, {6.244984659620384, 3.5541087461046454`}, {
       6.244984659620384, 3.5541087461046454`}}, {{6.244984659620384, 
       3.5541087461046454`}, {6.157855081110001, 3.573951207401159}, {
       6.157855081110001, 3.573951207401159}, {6.244984659620384, 
       3.5541087461046454`}, {6.244984659620384, 3.5541087461046454`}}, {{
       6.244984659620384, 3.5541087461046454`}, {6.157855081110001, 
       3.573951207401159}, {6.157855081110001, 3.573951207401159}, {
       6.244984659620384, 3.5541087461046454`}, {6.244984659620384, 
       3.5541087461046454`}}, {{6.157855081110001, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}, {6.157855081110001, 3.836091998452219}, {
       6.157855081110001, 3.836091998452219}}, {{6.157855081110001, 
       3.836091998452219}, {6.244984659620384, 3.8559344597487324`}, {
       6.244984659620384, 3.8559344597487324`}, {6.157855081110001, 
       3.836091998452219}, {6.157855081110001, 3.836091998452219}}, {{
       6.157855081110001, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}, {
       6.157855081110001, 3.836091998452219}, {6.157855081110001, 
       3.836091998452219}}, {{6.157855081110001, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}, {6.157855081110001, 3.836091998452219}, {
       6.157855081110001, 3.836091998452219}}, {{6.244984659620384, 
       3.8559344597487324`}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}}, {{
       6.244984659620384, 3.8559344597487324`}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}, {
       6.244984659620384, 3.8559344597487324`}, {6.244984659620384, 
       3.8559344597487324`}}, {{6.244984659620384, 3.8559344597487324`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}, {6.244984659620384, 3.8559344597487324`}, {
       6.244984659620384, 3.8559344597487324`}}, {{6.244984659620384, 
       3.8559344597487324`}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}, {6.244984659620384, 
       3.8559344597487324`}, {6.244984659620384, 3.8559344597487324`}}, {{
       6.309202137388913, 3.836091998452219}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}, {{6.309202137388913, 3.836091998452219}, {
       6.358494951829567, 3.7903992619859674`}, {6.358494951829567, 
       3.7903992619859674`}, {6.309202137388913, 3.836091998452219}, {
       6.309202137388913, 3.836091998452219}}, {{6.309202137388913, 
       3.836091998452219}, {6.358494951829567, 3.7903992619859674`}, {
       6.358494951829567, 3.7903992619859674`}, {6.309202137388913, 
       3.836091998452219}, {6.309202137388913, 3.836091998452219}}, {{
       6.309202137388913, 3.836091998452219}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}, {
       6.309202137388913, 3.836091998452219}, {6.309202137388913, 
       3.836091998452219}}, {{6.358494951829567, 3.7903992619859674`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}, {6.358494951829567, 3.7903992619859674`}, {
       6.358494951829567, 3.7903992619859674`}}, {{6.358494951829567, 
       3.7903992619859674`}, {6.384875665528368, 3.705021602926689}, {
       6.384875665528368, 3.705021602926689}, {6.358494951829567, 
       3.7903992619859674`}, {6.358494951829567, 3.7903992619859674`}}, {{
       6.358494951829567, 3.7903992619859674`}, {6.384875665528368, 
       3.705021602926689}, {6.384875665528368, 3.705021602926689}, {
       6.358494951829567, 3.7903992619859674`}, {6.358494951829567, 
       3.7903992619859674`}}, {{6.358494951829567, 3.7903992619859674`}, {
       6.384875665528368, 3.705021602926689}, {6.384875665528368, 
       3.705021602926689}, {6.358494951829567, 3.7903992619859674`}, {
       6.358494951829567, 3.7903992619859674`}}, {{
       6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}, {{
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}, {{
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}, {{
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}, {{
       6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}, {{
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}, {{
       6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}, {{
       6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}, {{
       6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}, {{
       6.440029613488014, -4.6649500144576}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}}, {{
       6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}, {{
       6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}, {{
       6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}, {{
       6.375562996133289, -4.595404146719295}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.595404146719295}, {
       6.375562996133289, -4.595404146719295}}, {{
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}, {{
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}, {{
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}, {{
       6.359724962568542, -4.525858278980991}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}, {
       6.359724962568542, -4.525858278980991}, {
       6.359724962568542, -4.525858278980991}}, {{
       6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}, {{
       6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}, {{
       6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}, {{
       6.375562996133289, -4.456312411242687}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}, {
       6.375562996133289, -4.456312411242687}, {
       6.375562996133289, -4.456312411242687}}, {{
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}, {{
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}, {{
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}, {{
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}}, {{
       6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}, {{
       6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}, {{
       6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}, {{
       6.652948386734189, -4.616460941175385}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}, {
       6.652948386734189, -4.616460941175385}, {
       6.652948386734189, -4.616460941175385}}, {{
       6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}, {{
       6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}, {{
       6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}, {{
       6.600638915326958, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.600638915326958, -4.6649500144576}, {
       6.600638915326958, -4.6649500144576}}, {{
       6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}, {{
       6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}, {{
       6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}, {{
       6.5324914103549805`, -4.68600680891369}, {
       6.440029613488014, -4.6649500144576}, {
       6.440029613488014, -4.6649500144576}, {
       6.5324914103549805`, -4.68600680891369}, {
       6.5324914103549805`, -4.68600680891369}}, {{
       6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}, {{
       6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}, {{
       6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}, {{
       6.440029613488014, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.440029613488014, -4.386766543504382}, {
       6.440029613488014, -4.386766543504382}}, {{
       6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}, {{
       6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}, {{
       6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}, {{
       6.5324914103549805`, -4.365709749048292}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}, {
       6.5324914103549805`, -4.365709749048292}, {
       6.5324914103549805`, -4.365709749048292}}, {{
       6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}, {{
       6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}, {{
       6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}, {{
       6.600638915326958, -4.386766543504382}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}, {
       6.600638915326958, -4.386766543504382}, {
       6.600638915326958, -4.386766543504382}}, {{
       6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}, {{
       6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}, {{
       6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}, {{
       6.652948386734189, -4.435255616786597}, {
       6.68094356624643, -4.525858278980991}, {
       6.68094356624643, -4.525858278980991}, {
       6.652948386734189, -4.435255616786597}, {
       6.652948386734189, -4.435255616786597}}, {{
       6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}, {{
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}, {{
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}, {{
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}, {{
       6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}, {{
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}, {{
       6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}, {{
       6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}, {{
       6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}, {{
       6.413831506846525, -4.153828497836305}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}}, {{
       6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}, {{
       6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}, {{
       6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}, {{
       6.347484221064705, -4.082253785975923}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -4.082253785975923}, {
       6.347484221064705, -4.082253785975923}}, {{
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}, {{
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}, {{
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}, {{
       6.331184148527001, -4.010679074115541}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.331184148527001, -4.010679074115541}, {
       6.331184148527001, -4.010679074115541}}, {{
       6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}, {{
       6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}, {{
       6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}, {{
       6.347484221064705, -3.9391043622551587`}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}, {
       6.347484221064705, -3.9391043622551587`}, {
       6.347484221064705, -3.9391043622551587`}}, {{
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}, {{
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}, {{
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}, {{
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}}, {{
       6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}, {{
       6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}, {{
       6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}, {{
       6.632961705956362, -4.1039248650049345`}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}, {
       6.632961705956362, -4.1039248650049345`}, {
       6.632961705956362, -4.1039248650049345`}}, {{
       6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}, {{
       6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}, {{
       6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}, {{
       6.579126223485571, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}, {
       6.579126223485571, -4.153828497836305}, {
       6.579126223485571, -4.153828497836305}}, {{
       6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}, {{
       6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}, {{
       6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}, {{
       6.508990668477077, -4.175499576865317}, {
       6.413831506846525, -4.153828497836305}, {
       6.413831506846525, -4.153828497836305}, {
       6.508990668477077, -4.175499576865317}, {
       6.508990668477077, -4.175499576865317}}, {{
       6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}, {{
       6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}, {{
       6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}, {{
       6.413831506846525, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}, {
       6.413831506846525, -3.867529650394776}, {
       6.413831506846525, -3.867529650394776}}, {{
       6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}, {{
       6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}, {{
       6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}, {{
       6.508990668477077, -3.845858571365765}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}, {
       6.508990668477077, -3.845858571365765}, {
       6.508990668477077, -3.845858571365765}}, {{
       6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}, {{
       6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}, {{
       6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}, {{
       6.579126223485571, -3.867529650394776}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.579126223485571, -3.867529650394776}, {
       6.579126223485571, -3.867529650394776}}, {{
       6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}, {{
       6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}, {{
       6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}, {{
       6.632961705956362, -3.9174332832261474`}, {
       6.661773581805095, -4.010679074115541}, {
       6.661773581805095, -4.010679074115541}, {
       6.632961705956362, -3.9174332832261474`}, {
       6.632961705956362, -3.9174332832261474`}}, {{
       6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}, {{
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}, {{
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}, {{
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}, {{
       6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}, {{
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}, {{
       6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}, {{
       6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}, {{
       6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}, {{
       6.406892094169329, -3.5913638916321156`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}}, {{
       6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}, {{
       6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}, {{
       6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}, {{
       6.345533798886357, -3.5251712470744327`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.5251712470744327`}, {
       6.345533798886357, -3.5251712470744327`}}, {{
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}, {{
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}, {{
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}, {{
       6.330459411861827, -3.4589786025167504`}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}, {
       6.330459411861827, -3.4589786025167504`}, {
       6.330459411861827, -3.4589786025167504`}}, {{
       6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}, {{
       6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}, {{
       6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}, {{
       6.345533798886357, -3.392785957959068}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}, {
       6.345533798886357, -3.392785957959068}, {
       6.345533798886357, -3.392785957959068}}, {{
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}, {{
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}, {{
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}, {{
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}}, {{
       6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}, {{
       6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}, {{
       6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}, {{
       6.609544777002696, -3.5452127672435525`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.609544777002696, -3.5452127672435525`}, {
       6.609544777002696, -3.5452127672435525`}}, {{
       6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}, {{
       6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}, {{
       6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}, {{
       6.559757458784334, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}, {
       6.559757458784334, -3.5913638916321156`}, {
       6.559757458784334, -3.5913638916321156`}}, {{
       6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}, {{
       6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}, {{
       6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}, {{
       6.494895753541442, -3.611405411801235}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.406892094169329, -3.5913638916321156`}, {
       6.494895753541442, -3.611405411801235}, {
       6.494895753541442, -3.611405411801235}}, {{
       6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}, {{
       6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}, {{
       6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}, {{
       6.406892094169329, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}, {
       6.406892094169329, -3.326593313401385}, {
       6.406892094169329, -3.326593313401385}}, {{
       6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}, {{
       6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}, {{
       6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}, {{
       6.494895753541442, -3.306551793232266}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}, {
       6.494895753541442, -3.306551793232266}, {
       6.494895753541442, -3.306551793232266}}, {{
       6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}, {{
       6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}, {{
       6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}, {{
       6.559757458784334, -3.326593313401385}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.559757458784334, -3.326593313401385}, {
       6.559757458784334, -3.326593313401385}}, {{
       6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}, {{
       6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}, {{
       6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}, {{
       6.609544777002696, -3.3727444377899483`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.636190141091837, -3.4589786025167504`}, {
       6.609544777002696, -3.3727444377899483`}, {
       6.609544777002696, -3.3727444377899483`}}, {{
       6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}, {{
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}, {{
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}, {{
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}, {{
       6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}, {{
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}, {{
       6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}, {{
       6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}, {{
       6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}, {{
       6.400873848676051, -3.1695382022920553`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}}, {{
       6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}, {{
       6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}, {{
       6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}, {{
       6.337082937971227, -3.1007212793507963`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -3.1007212793507963`}, {
       6.337082937971227, -3.1007212793507963`}}, {{
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}, {{
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}, {{
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}, {{
       6.3214109107061764`, -3.0319043564095374`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.3214109107061764`, -3.0319043564095374`}, {
       6.3214109107061764`, -3.0319043564095374`}}, {{
       6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}, {{
       6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}, {{
       6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}, {{
       6.337082937971227, -2.9630874334682784`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.337082937971227, -2.9630874334682784`}, {
       6.337082937971227, -2.9630874334682784`}}, {{
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}, {{
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}, {{
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}, {{
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}}, {{
       6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}, {{
       6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}, {{
       6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}, {{
       6.611560914460682, -3.1215573670810897`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.611560914460682, -3.1215573670810897`}, {
       6.611560914460682, -3.1215573670810897`}}, {{
       6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}, {{
       6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}, {{
       6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}, {{
       6.559799724615802, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}, {
       6.559799724615802, -3.1695382022920553`}, {
       6.559799724615802, -3.1695382022920553`}}, {{
       6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}, {{
       6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}, {{
       6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}, {{
       6.49236650750587, -3.190374290022348}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.400873848676051, -3.1695382022920553`}, {
       6.49236650750587, -3.190374290022348}, {
       6.49236650750587, -3.190374290022348}}, {{
       6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}, {{
       6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}, {{
       6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}, {{
       6.400873848676051, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.400873848676051, -2.8942705105270194`}, {
       6.400873848676051, -2.8942705105270194`}}, {{
       6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}, {{
       6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}, {{
       6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}, {{
       6.49236650750587, -2.8734344227967266`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.49236650750587, -2.8734344227967266`}, {
       6.49236650750587, -2.8734344227967266`}}, {{
       6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}, {{
       6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}, {{
       6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}, {{
       6.559799724615802, -2.8942705105270194`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}, {
       6.559799724615802, -2.8942705105270194`}, {
       6.559799724615802, -2.8942705105270194`}}, {{
       6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}, {{
       6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}, {{
       6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}, {{
       6.611560914460682, -2.942251345737985}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.6392626625856765`, -3.0319043564095374`}, {
       6.611560914460682, -2.942251345737985}, {
       6.611560914460682, -2.942251345737985}}, {{
       6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}, {{
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}, {{
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}, {{
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}, {{
       6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}, {{
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}, {{
       6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}, {{
       6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}, {{
       6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}, {{
       6.4592998206587, -2.603680635291917}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}}, {{
       6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}, {{
       6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}, {{
       6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}, {{
       6.389931416538398, -2.52884677466569}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.52884677466569}, {
       6.389931416538398, -2.52884677466569}}, {{
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}, {{
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}, {{
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}, {{
       6.372889121504598, -2.454012914039463}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.372889121504598, -2.454012914039463}, {
       6.372889121504598, -2.454012914039463}}, {{
       6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}, {{
       6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}, {{
       6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}, {{
       6.389931416538398, -2.3791790534132358`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.389931416538398, -2.3791790534132358`}, {
       6.389931416538398, -2.3791790534132358`}}, {{
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}, {{
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}, {{
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}, {{
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}}, {{
       6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}, {{
       6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}, {{
       6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}, {{
       6.688408095815581, -2.551504644540743}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}, {
       6.688408095815581, -2.551504644540743}, {
       6.688408095815581, -2.551504644540743}}, {{
       6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}, {{
       6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}, {{
       6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}, {{
       6.632121218966905, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}, {
       6.632121218966905, -2.603680635291917}, {
       6.632121218966905, -2.603680635291917}}, {{
       6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}, {{
       6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}, {{
       6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}, {{
       6.558792047084427, -2.62633850516697}, {
       6.4592998206587, -2.603680635291917}, {
       6.4592998206587, -2.603680635291917}, {
       6.558792047084427, -2.62633850516697}, {
       6.558792047084427, -2.62633850516697}}, {{
       6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}, {{
       6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}, {{
       6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}, {{
       6.4592998206587, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.4592998206587, -2.3043451927870087`}, {
       6.4592998206587, -2.3043451927870087`}}, {{
       6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}, {{
       6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}, {{
       6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}, {{
       6.558792047084427, -2.2816873229119556`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.558792047084427, -2.2816873229119556`}, {
       6.558792047084427, -2.2816873229119556`}}, {{
       6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}, {{
       6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}, {{
       6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}, {{
       6.632121218966905, -2.3043451927870087`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.632121218966905, -2.3043451927870087`}, {
       6.632121218966905, -2.3043451927870087`}}, {{
       6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}, {{
       6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}, {{
       6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}, {{
       6.688408095815581, -2.3565211835381827`}, {
       6.718531918121006, -2.454012914039463}, {
       6.718531918121006, -2.454012914039463}, {
       6.688408095815581, -2.3565211835381827`}, {
       6.688408095815581, -2.3565211835381827`}}, {{
       6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}, {{
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}, {{
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}, {{
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}, {{
       6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}, {{
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}, {{
       6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}, {{
       6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}, {{
       6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}, {{
       6.401666843570241, -2.100979314470346}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}}, {{
       6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}, {{
       6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}, {{
       6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}, {{
       6.337447560474659, -2.031700268172025}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -2.031700268172025}, {
       6.337447560474659, -2.031700268172025}}, {{
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}, {{
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}, {{
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}, {{
       6.321670291511169, -1.9624212218737038`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.321670291511169, -1.9624212218737038`}, {
       6.321670291511169, -1.9624212218737038`}}, {{
       6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}, {{
       6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}, {{
       6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}, {{
       6.337447560474659, -1.8931421755753828`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.337447560474659, -1.8931421755753828`}, {
       6.337447560474659, -1.8931421755753828`}}, {{
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}, {{
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}, {{
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}, {{
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}}, {{
       6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}, {{
       6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}, {{
       6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}, {{
       6.613768727250945, -2.0526762755964634`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}, {
       6.613768727250945, -2.0526762755964634`}, {
       6.613768727250945, -2.0526762755964634`}}, {{
       6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}, {{
       6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}, {{
       6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}, {{
       6.561659947688386, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.561659947688386, -2.100979314470346}, {
       6.561659947688386, -2.100979314470346}}, {{
       6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}, {{
       6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}, {{
       6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}, {{
       6.493773899162337, -2.1219553218947844`}, {
       6.401666843570241, -2.100979314470346}, {
       6.401666843570241, -2.100979314470346}, {
       6.493773899162337, -2.1219553218947844`}, {
       6.493773899162337, -2.1219553218947844`}}, {{
       6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}, {{
       6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}, {{
       6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}, {{
       6.401666843570241, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.401666843570241, -1.8238631292770617`}, {
       6.401666843570241, -1.8238631292770617`}}, {{
       6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}, {{
       6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}, {{
       6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}, {{
       6.493773899162337, -1.8028871218526232`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.493773899162337, -1.8028871218526232`}, {
       6.493773899162337, -1.8028871218526232`}}, {{
       6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}, {{
       6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}, {{
       6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}, {{
       6.561659947688386, -1.8238631292770617`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.561659947688386, -1.8238631292770617`}, {
       6.561659947688386, -1.8238631292770617`}}, {{
       6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}, {{
       6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}, {{
       6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}, {{
       6.613768727250945, -1.8721661681509443`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.641656499747458, -1.9624212218737038`}, {
       6.613768727250945, -1.8721661681509443`}, {
       6.613768727250945, -1.8721661681509443`}}, {{
       6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774719`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}, {{
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}, {{
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}, {{
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}, {{
       6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}, {{
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}, {{
       6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}, {{
       6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}, {{
       6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}, {{
       6.467089539710077, -1.646968941352684}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}}, {{
       6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}, {{
       6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}, {{
       6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}, {{
       6.410488914662338, -1.5859088183774717`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.5859088183774717`}, {
       6.410488914662338, -1.5859088183774717`}}, {{
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}, {{
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}, {{
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}, {{
       6.396583382837097, -1.5248486954022595`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.410488914662338, -1.4637885724270474`}, {
       6.396583382837097, -1.5248486954022595`}, {
       6.396583382837097, -1.5248486954022595`}}, {{
       6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}, {{
       6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}, {{
       6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}, {{
       6.410488914662338, -1.4637885724270472`}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}, {
       6.410488914662338, -1.4637885724270472`}, {
       6.410488914662338, -1.4637885724270472`}}, {{
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}, {{
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}, {{
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}, {{
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}}, {{
       6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}, {{
       6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}, {{
       6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}, {{
       6.654028705198154, -1.6043963360512856`}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}, {
       6.654028705198154, -1.6043963360512856`}, {
       6.654028705198154, -1.6043963360512856`}}, {{
       6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}, {{
       6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}, {{
       6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}, {{
       6.60810185345604, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}, {
       6.60810185345604, -1.646968941352684}, {
       6.60810185345604, -1.646968941352684}}, {{
       6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}, {{
       6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}, {{
       6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}, {{
       6.548269469888683, -1.665456459026498}, {
       6.467089539710077, -1.646968941352684}, {
       6.467089539710077, -1.646968941352684}, {
       6.548269469888683, -1.665456459026498}, {
       6.548269469888683, -1.665456459026498}}, {{
       6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}, {{
       6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}, {{
       6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}, {{
       6.467089539710077, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}, {
       6.467089539710077, -1.402728449451835}, {
       6.467089539710077, -1.402728449451835}}, {{
       6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}, {{
       6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}, {{
       6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}, {{
       6.548269469888683, -1.384240931778021}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}, {
       6.548269469888683, -1.384240931778021}, {
       6.548269469888683, -1.384240931778021}}, {{
       6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}, {{
       6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}, {{
       6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}, {{
       6.60810185345604, -1.402728449451835}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.60810185345604, -1.402728449451835}, {
       6.60810185345604, -1.402728449451835}}, {{
       6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}, {{
       6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}, {{
       6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}, {{
       6.654028705198154, -1.4453010547532334`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.67860801032902, -1.5248486954022595`}, {
       6.654028705198154, -1.4453010547532334`}, {
       6.654028705198154, -1.4453010547532334`}}, {{
       6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}, {{
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}, {{
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}, {{
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}, {{
       6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}, {{
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}, {{
       6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}, {{
       6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}, {{
       6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}, {{
       6.434795489883959, -1.1217174912923116`}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}}, {{
       6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}, {{
       6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}, {{
       6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}, {{
       6.371775125279847, -1.05373182488979}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -1.05373182488979}, {
       6.371775125279847, -1.05373182488979}}, {{
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}, {{
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}, {{
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}, {{
       6.356292404286895, -0.9857461584872683}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}, {
       6.356292404286895, -0.9857461584872683}, {
       6.356292404286895, -0.9857461584872683}}, {{
       6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}, {{
       6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}, {{
       6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}, {{
       6.371775125279847, -0.9177604920847466}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}, {
       6.371775125279847, -0.9177604920847466}, {
       6.371775125279847, -0.9177604920847466}}, {{
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}, {{
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}, {{
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}, {{
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}}, {{
       6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}, {{
       6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}, {{
       6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}, {{
       6.6429376147794095`, -1.074316228391448}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.6429376147794095`, -1.074316228391448}, {
       6.6429376147794095`, -1.074316228391448}}, {{
       6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}, {{
       6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}, {{
       6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}, {{
       6.591801661078088, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.591801661078088, -1.1217174912923116`}, {
       6.591801661078088, -1.1217174912923116`}}, {{
       6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}, {{
       6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}, {{
       6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}, {{
       6.525182986383814, -1.1423018947939698`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.434795489883959, -1.1217174912923116`}, {
       6.525182986383814, -1.1423018947939698`}, {
       6.525182986383814, -1.1423018947939698`}}, {{
       6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}, {{
       6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}, {{
       6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}, {{
       6.434795489883959, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}, {
       6.434795489883959, -0.849774825682225}, {
       6.434795489883959, -0.849774825682225}}, {{
       6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}, {{
       6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}, {{
       6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}, {{
       6.525182986383814, -0.8291904221805668}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}, {
       6.525182986383814, -0.8291904221805668}, {
       6.525182986383814, -0.8291904221805668}}, {{
       6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}, {{
       6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}, {{
       6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}, {{
       6.591801661078088, -0.849774825682225}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.591801661078088, -0.849774825682225}, {
       6.591801661078088, -0.849774825682225}}, {{
       6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}, {{
       6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}, {{
       6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}, {{
       6.6429376147794095`, -0.8971760885830885}, {
       6.670304746675152, -0.9857461584872683}, {
       6.670304746675152, -0.9857461584872683}, {
       6.6429376147794095`, -0.8971760885830885}, {
       6.6429376147794095`, -0.8971760885830885}}, {{
       6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}, {{
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}, {{
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}, {{
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}, {{
       6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}, {{
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}, {{
       6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}, {{
       6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}, {{
       6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}, {{
       6.463759891994268, -0.6878731923773076}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}}, {{
       6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}, {{
       6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}, {{
       6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}, {{
       6.396375475739749, -0.6151796357311843}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.6151796357311843}, {
       6.396375475739749, -0.6151796357311843}}, {{
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}, {{
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}, {{
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}, {{
       6.3798206029982865`, -0.5424860790850609}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}, {
       6.3798206029982865`, -0.5424860790850609}, {
       6.3798206029982865`, -0.5424860790850609}}, {{
       6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}, {{
       6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}, {{
       6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}, {{
       6.396375475739749, -0.4697925224389375}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}, {
       6.396375475739749, -0.4697925224389375}, {
       6.396375475739749, -0.4697925224389375}}, {{
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}, {{
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}, {{
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}, {{
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}}, {{
       6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}, {{
       6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}, {{
       6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}, {{
       6.686315500362485, -0.6371894737037211}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}, {
       6.686315500362485, -0.6371894737037211}, {
       6.686315500362485, -0.6371894737037211}}, {{
       6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}, {{
       6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}, {{
       6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}, {{
       6.63163846998623, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}, {
       6.63163846998623, -0.6878731923773076}, {
       6.63163846998623, -0.6878731923773076}}, {{
       6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}, {{
       6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}, {{
       6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}, {{
       6.560406566868513, -0.7098830303498445}, {
       6.463759891994268, -0.6878731923773076}, {
       6.463759891994268, -0.6878731923773076}, {
       6.560406566868513, -0.7098830303498445}, {
       6.560406566868513, -0.7098830303498445}}, {{
       6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}, {{
       6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}, {{
       6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}, {{
       6.463759891994268, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.463759891994268, -0.3970989657928141}, {
       6.463759891994268, -0.3970989657928141}}, {{
       6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}, {{
       6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}, {{
       6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}, {{
       6.560406566868513, -0.37508912782027726`}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}, {
       6.560406566868513, -0.37508912782027726`}, {
       6.560406566868513, -0.37508912782027726`}}, {{
       6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}, {{
       6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}, {{
       6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}, {{
       6.63163846998623, -0.3970989657928141}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}, {
       6.63163846998623, -0.3970989657928141}, {
       6.63163846998623, -0.3970989657928141}}, {{
       6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}, {{
       6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}, {{
       6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}, {{
       6.686315500362485, -0.4477826844664006}, {
       6.715577758982212, -0.5424860790850609}, {
       6.715577758982212, -0.5424860790850609}, {
       6.686315500362485, -0.4477826844664006}, {
       6.686315500362485, -0.4477826844664006}}, {{
       6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, 0.10458225215268897`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, -0.03448237988931001}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}, {{6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}}, {{
       6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}, {{
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}, {{6.419448594430425, 
       0.17411456817368842`}, {6.511892374179, 0.19516725949992914`}, {
       6.580026599918834, 0.17411456817368842`}, {6.632325878295307, 
       0.12563494347892964`}, {6.660315602663038, 0.0350499361316895}, {
       6.660315602663038, 0.0350499361316895}, {6.632325878295307, 
       0.12563494347892964`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}}, {{
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}, {{6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}, {{
       6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}, {{
       6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}, {{
       6.419448594430425, -0.10401469591030947`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}}, {{
       6.354994539049581, -0.034482379889309994`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}, {{
       6.354994539049581, -0.034482379889309994`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}, {{
       6.354994539049581, -0.034482379889309994`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}, {{
       6.354994539049581, -0.034482379889309994`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, -0.034482379889309994`}, {
       6.354994539049581, -0.034482379889309994`}}, {{6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, 0.10458225215268896`}, {
       6.354994539049581, 0.10458225215268896`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}}, {{
       6.3391595916862205`, 0.03504993613168948}, {6.354994539049581, 
       0.10458225215268896`}, {6.354994539049581, 0.10458225215268896`}, {
       6.3391595916862205`, 0.03504993613168948}, {6.3391595916862205`, 
       0.03504993613168948}}, {{6.3391595916862205`, 0.03504993613168948}, {
       6.354994539049581, 0.10458225215268896`}, {6.354994539049581, 
       0.10458225215268896`}, {6.3391595916862205`, 0.03504993613168948}, {
       6.3391595916862205`, 0.03504993613168948}}, {{6.3391595916862205`, 
       0.03504993613168948}, {6.354994539049581, 0.10458225215268896`}, {
       6.354994539049581, 0.10458225215268896`}, {6.3391595916862205`, 
       0.03504993613168948}, {6.3391595916862205`, 0.03504993613168948}}, {{
       6.354994539049581, 0.10458225215268897`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}, {
       6.354994539049581, 0.10458225215268897`}, {6.354994539049581, 
       0.10458225215268897`}}, {{6.354994539049581, 0.10458225215268897`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}, {6.354994539049581, 0.10458225215268897`}, {
       6.354994539049581, 0.10458225215268897`}}, {{6.354994539049581, 
       0.10458225215268897`}, {6.419448594430425, 0.17411456817368842`}, {
       6.419448594430425, 0.17411456817368842`}, {6.354994539049581, 
       0.10458225215268897`}, {6.354994539049581, 0.10458225215268897`}}, {{
       6.354994539049581, 0.10458225215268897`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}, {
       6.354994539049581, 0.10458225215268897`}, {6.354994539049581, 
       0.10458225215268897`}}, {{6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}, {{
       6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}, {{
       6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}, {{
       6.660315602663038, 0.03504993613168946}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}, {6.660315602663038, 
       0.03504993613168946}, {6.660315602663038, 0.03504993613168946}}, {{
       6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}, {{
       6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}, {{
       6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}, {{
       6.632325878295307, -0.05553507121555068}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.632325878295307, -0.05553507121555068}, {
       6.632325878295307, -0.05553507121555068}}, {{
       6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}, {{
       6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}, {{
       6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}, {{
       6.580026599918834, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.580026599918834, -0.10401469591030947`}, {
       6.580026599918834, -0.10401469591030947`}}, {{
       6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}, {{
       6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}, {{
       6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}, {{
       6.511892374179, -0.12506738723655014`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.419448594430425, -0.10401469591030947`}, {
       6.511892374179, -0.12506738723655014`}, {
       6.511892374179, -0.12506738723655014`}}, {{6.419448594430425, 
       0.17411456817368842`}, {6.511892374179, 0.19516725949992914`}, {
       6.511892374179, 0.19516725949992914`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}}, {{
       6.419448594430425, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.511892374179, 0.19516725949992914`}, {
       6.419448594430425, 0.17411456817368842`}, {6.419448594430425, 
       0.17411456817368842`}}, {{6.419448594430425, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}, {6.419448594430425, 0.17411456817368842`}, {
       6.419448594430425, 0.17411456817368842`}}, {{6.419448594430425, 
       0.17411456817368842`}, {6.511892374179, 0.19516725949992914`}, {
       6.511892374179, 0.19516725949992914`}, {6.419448594430425, 
       0.17411456817368842`}, {6.419448594430425, 0.17411456817368842`}}, {{
       6.511892374179, 0.19516725949992914`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}}, {{6.511892374179, 0.19516725949992914`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}, {6.511892374179, 0.19516725949992914`}, {
       6.511892374179, 0.19516725949992914`}}, {{6.511892374179, 
       0.19516725949992914`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}, {6.511892374179, 
       0.19516725949992914`}, {6.511892374179, 0.19516725949992914`}}, {{
       6.511892374179, 0.19516725949992914`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}, {
       6.511892374179, 0.19516725949992914`}, {6.511892374179, 
       0.19516725949992914`}}, {{6.580026599918834, 0.17411456817368842`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}}, {{6.580026599918834, 
       0.17411456817368842`}, {6.632325878295307, 0.12563494347892964`}, {
       6.632325878295307, 0.12563494347892964`}, {6.580026599918834, 
       0.17411456817368842`}, {6.580026599918834, 0.17411456817368842`}}, {{
       6.580026599918834, 0.17411456817368842`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}, {
       6.580026599918834, 0.17411456817368842`}, {6.580026599918834, 
       0.17411456817368842`}}, {{6.580026599918834, 0.17411456817368842`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}, {6.580026599918834, 0.17411456817368842`}, {
       6.580026599918834, 0.17411456817368842`}}, {{6.632325878295307, 
       0.12563494347892964`}, {6.660315602663038, 0.035049936131689455`}, {
       6.660315602663038, 0.035049936131689455`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}}, {{
       6.632325878295307, 0.12563494347892964`}, {6.660315602663038, 
       0.035049936131689455`}, {6.660315602663038, 0.035049936131689455`}, {
       6.632325878295307, 0.12563494347892964`}, {6.632325878295307, 
       0.12563494347892964`}}, {{6.632325878295307, 0.12563494347892964`}, {
       6.660315602663038, 0.035049936131689455`}, {6.660315602663038, 
       0.035049936131689455`}, {6.632325878295307, 0.12563494347892964`}, {
       6.632325878295307, 0.12563494347892964`}}, {{6.632325878295307, 
       0.12563494347892964`}, {6.660315602663038, 0.035049936131689455`}, {
       6.660315602663038, 0.035049936131689455`}, {6.632325878295307, 
       0.12563494347892964`}, {6.632325878295307, 0.12563494347892964`}}, {{
       6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.337909661427842, 
       0.5285951207726394}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}, {{6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}}, {{6.603023342657892, 
       0.5285951207726394}, {6.579917877992374, 0.45381736808778755`}, {
       6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.404188081735354, 0.41379752935462266`}, {
       6.404188081735354, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.53674492235038, 0.41379752935462266`}, {
       6.579917877992374, 0.45381736808778755`}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}}, {{
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}, {{6.404188081735354, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.579917877992374, 0.6033728734574912}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}, {6.579917877992374, 0.6033728734574912}, {
       6.53674492235038, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.404188081735354, 0.6433927121906561}, {
       6.404188081735354, 0.6433927121906561}}, {{6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}}, {{
       6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}, {{6.404188081735354, 0.41379752935462266`}, {
       6.350981380605122, 0.471196325063631}, {6.350981380605122, 
       0.471196325063631}, {6.404188081735354, 0.41379752935462266`}, {
       6.404188081735354, 0.41379752935462266`}}, {{6.404188081735354, 
       0.41379752935462266`}, {6.350981380605122, 0.471196325063631}, {
       6.350981380605122, 0.471196325063631}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}}, {{
       6.404188081735354, 0.41379752935462266`}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}}, {{6.350981380605122, 0.471196325063631}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.350981380605122, 0.471196325063631}, {
       6.350981380605122, 0.471196325063631}}, {{6.350981380605122, 
       0.471196325063631}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}, {6.350981380605122, 
       0.471196325063631}, {6.350981380605122, 0.471196325063631}}, {{
       6.350981380605122, 0.471196325063631}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.471196325063631}, {6.350981380605122, 
       0.471196325063631}}, {{6.350981380605122, 0.471196325063631}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}, {6.350981380605122, 0.471196325063631}, {
       6.350981380605122, 0.471196325063631}}, {{6.337909661427842, 
       0.5285951207726394}, {6.350981380605122, 0.5859939164816478}, {
       6.350981380605122, 0.5859939164816478}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}}, {{
       6.337909661427842, 0.5285951207726394}, {6.350981380605122, 
       0.5859939164816478}, {6.350981380605122, 0.5859939164816478}, {
       6.337909661427842, 0.5285951207726394}, {6.337909661427842, 
       0.5285951207726394}}, {{6.337909661427842, 0.5285951207726394}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}, {6.337909661427842, 0.5285951207726394}, {
       6.337909661427842, 0.5285951207726394}}, {{6.337909661427842, 
       0.5285951207726394}, {6.350981380605122, 0.5859939164816478}, {
       6.350981380605122, 0.5859939164816478}, {6.337909661427842, 
       0.5285951207726394}, {6.337909661427842, 0.5285951207726394}}, {{
       6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}}, {{6.350981380605122, 0.5859939164816478}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}, {6.350981380605122, 0.5859939164816478}, {
       6.350981380605122, 0.5859939164816478}}, {{6.350981380605122, 
       0.5859939164816478}, {6.404188081735354, 0.6433927121906561}, {
       6.404188081735354, 0.6433927121906561}, {6.350981380605122, 
       0.5859939164816478}, {6.350981380605122, 0.5859939164816478}}, {{
       6.350981380605122, 0.5859939164816478}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}, {
       6.350981380605122, 0.5859939164816478}, {6.350981380605122, 
       0.5859939164816478}}, {{6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}, {6.603023342657892, 0.5285951207726394}, {
       6.603023342657892, 0.5285951207726394}}, {{6.603023342657892, 
       0.5285951207726394}, {6.579917877992374, 0.45381736808778755`}, {
       6.579917877992374, 0.45381736808778755`}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}}, {{
       6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}}, {{6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}, {6.603023342657892, 0.5285951207726394}, {
       6.603023342657892, 0.5285951207726394}}, {{6.579917877992374, 
       0.45381736808778755`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}}, {{
       6.579917877992374, 0.45381736808778755`}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}, {
       6.579917877992374, 0.45381736808778755`}, {6.579917877992374, 
       0.45381736808778755`}}, {{6.579917877992374, 0.45381736808778755`}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}, {6.579917877992374, 0.45381736808778755`}, {
       6.579917877992374, 0.45381736808778755`}}, {{6.579917877992374, 
       0.45381736808778755`}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}, {6.579917877992374, 
       0.45381736808778755`}, {6.579917877992374, 0.45381736808778755`}}, {{
       6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}, {{6.53674492235038, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.480500247531105, 
       0.3964185723787792}, {6.53674492235038, 0.41379752935462266`}, {
       6.53674492235038, 0.41379752935462266`}}, {{6.53674492235038, 
       0.41379752935462266`}, {6.480500247531105, 0.3964185723787792}, {
       6.480500247531105, 0.3964185723787792}, {6.53674492235038, 
       0.41379752935462266`}, {6.53674492235038, 0.41379752935462266`}}, {{
       6.53674492235038, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}, {
       6.53674492235038, 0.41379752935462266`}, {6.53674492235038, 
       0.41379752935462266`}}, {{6.480500247531105, 0.3964185723787792}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}, {6.480500247531105, 0.3964185723787792}, {
       6.480500247531105, 0.3964185723787792}}, {{6.480500247531105, 
       0.3964185723787792}, {6.404188081735354, 0.41379752935462266`}, {
       6.404188081735354, 0.41379752935462266`}, {6.480500247531105, 
       0.3964185723787792}, {6.480500247531105, 0.3964185723787792}}, {{
       6.480500247531105, 0.3964185723787792}, {6.404188081735354, 
       0.41379752935462266`}, {6.404188081735354, 0.41379752935462266`}, {
       6.480500247531105, 0.3964185723787792}, {6.480500247531105, 
       0.3964185723787792}}, {{6.480500247531105, 0.3964185723787792}, {
       6.404188081735354, 0.41379752935462266`}, {6.404188081735354, 
       0.41379752935462266`}, {6.480500247531105, 0.3964185723787792}, {
       6.480500247531105, 0.3964185723787792}}, {{6.404188081735354, 
       0.6433927121906561}, {6.480500247531105, 0.6607716691664995}, {
       6.480500247531105, 0.6607716691664995}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}}, {{
       6.404188081735354, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.480500247531105, 0.6607716691664995}, {
       6.404188081735354, 0.6433927121906561}, {6.404188081735354, 
       0.6433927121906561}}, {{6.404188081735354, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}, {6.404188081735354, 0.6433927121906561}, {
       6.404188081735354, 0.6433927121906561}}, {{6.404188081735354, 
       0.6433927121906561}, {6.480500247531105, 0.6607716691664995}, {
       6.480500247531105, 0.6607716691664995}, {6.404188081735354, 
       0.6433927121906561}, {6.404188081735354, 0.6433927121906561}}, {{
       6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}}, {{6.480500247531105, 0.6607716691664995}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}, {6.480500247531105, 0.6607716691664995}, {
       6.480500247531105, 0.6607716691664995}}, {{6.480500247531105, 
       0.6607716691664995}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}, {6.480500247531105, 
       0.6607716691664995}, {6.480500247531105, 0.6607716691664995}}, {{
       6.480500247531105, 0.6607716691664995}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}, {
       6.480500247531105, 0.6607716691664995}, {6.480500247531105, 
       0.6607716691664995}}, {{6.53674492235038, 0.6433927121906561}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}}, {{6.53674492235038, 
       0.6433927121906561}, {6.579917877992374, 0.6033728734574912}, {
       6.579917877992374, 0.6033728734574912}, {6.53674492235038, 
       0.6433927121906561}, {6.53674492235038, 0.6433927121906561}}, {{
       6.53674492235038, 0.6433927121906561}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}, {
       6.53674492235038, 0.6433927121906561}, {6.53674492235038, 
       0.6433927121906561}}, {{6.53674492235038, 0.6433927121906561}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}, {6.53674492235038, 0.6433927121906561}, {
       6.53674492235038, 0.6433927121906561}}, {{6.579917877992374, 
       0.6033728734574912}, {6.603023342657892, 0.5285951207726394}, {
       6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}}, {{
       6.579917877992374, 0.6033728734574912}, {6.603023342657892, 
       0.5285951207726394}, {6.603023342657892, 0.5285951207726394}, {
       6.579917877992374, 0.6033728734574912}, {6.579917877992374, 
       0.6033728734574912}}, {{6.579917877992374, 0.6033728734574912}, {
       6.603023342657892, 0.5285951207726394}, {6.603023342657892, 
       0.5285951207726394}, {6.579917877992374, 0.6033728734574912}, {
       6.579917877992374, 0.6033728734574912}}, {{6.579917877992374, 
       0.6033728734574912}, {6.603023342657892, 0.5285951207726394}, {
       6.603023342657892, 0.5285951207726394}, {6.579917877992374, 
       0.6033728734574912}, {6.579917877992374, 0.6033728734574912}}, {{
       6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.1786313880649457`}, {6.380412974199382, 1.1786313880649457`}, {
       6.311538024565798, 1.1043298606349732`}, {6.294616960473593, 
       1.0300283332050004`}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}, {{6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}}, {{6.637801015376753, 
       1.0300283332050004`}, {6.607891479899203, 0.9332301134229565}, {
       6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.380412974199382, 0.881425278345055}, {
       6.380412974199382, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.552005001650963, 0.881425278345055}, {
       6.607891479899203, 0.9332301134229565}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}}, {{
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}, {{6.380412974199382, 1.178631388064946}, {
       6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.607891479899203, 1.1268265529870445`}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}, {6.607891479899203, 1.1268265529870445`}, {
       6.552005001650963, 1.1786313880649457`}, {6.479197459310518, 
       1.201128080417017}, {6.380412974199382, 1.178631388064946}, {
       6.380412974199382, 1.178631388064946}}, {{6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}}, {{
       6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}, {{6.380412974199382, 0.881425278345055}, {
       6.311538024565798, 0.9557268057750277}, {6.311538024565798, 
       0.9557268057750277}, {6.380412974199382, 0.881425278345055}, {
       6.380412974199382, 0.881425278345055}}, {{6.380412974199382, 
       0.881425278345055}, {6.311538024565798, 0.9557268057750277}, {
       6.311538024565798, 0.9557268057750277}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}}, {{
       6.380412974199382, 0.881425278345055}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}}, {{6.311538024565798, 0.9557268057750277}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.311538024565798, 0.9557268057750277}, {
       6.311538024565798, 0.9557268057750277}}, {{6.311538024565798, 
       0.9557268057750277}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}, {6.311538024565798, 
       0.9557268057750277}, {6.311538024565798, 0.9557268057750277}}, {{
       6.311538024565798, 0.9557268057750277}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 0.9557268057750277}, {6.311538024565798, 
       0.9557268057750277}}, {{6.311538024565798, 0.9557268057750277}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}, {6.311538024565798, 0.9557268057750277}, {
       6.311538024565798, 0.9557268057750277}}, {{6.294616960473593, 
       1.0300283332050004`}, {6.311538024565798, 1.1043298606349732`}, {
       6.311538024565798, 1.1043298606349732`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}}, {{
       6.294616960473593, 1.0300283332050004`}, {6.311538024565798, 
       1.1043298606349732`}, {6.311538024565798, 1.1043298606349732`}, {
       6.294616960473593, 1.0300283332050004`}, {6.294616960473593, 
       1.0300283332050004`}}, {{6.294616960473593, 1.0300283332050004`}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}, {6.294616960473593, 1.0300283332050004`}, {
       6.294616960473593, 1.0300283332050004`}}, {{6.294616960473593, 
       1.0300283332050004`}, {6.311538024565798, 1.1043298606349732`}, {
       6.311538024565798, 1.1043298606349732`}, {6.294616960473593, 
       1.0300283332050004`}, {6.294616960473593, 1.0300283332050004`}}, {{
       6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}}, {{6.311538024565798, 1.1043298606349732`}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}, {6.311538024565798, 1.1043298606349732`}, {
       6.311538024565798, 1.1043298606349732`}}, {{6.311538024565798, 
       1.1043298606349732`}, {6.380412974199382, 1.178631388064946}, {
       6.380412974199382, 1.178631388064946}, {6.311538024565798, 
       1.1043298606349732`}, {6.311538024565798, 1.1043298606349732`}}, {{
       6.311538024565798, 1.1043298606349732`}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}, {
       6.311538024565798, 1.1043298606349732`}, {6.311538024565798, 
       1.1043298606349732`}}, {{6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}, {6.637801015376753, 1.0300283332050004`}, {
       6.637801015376753, 1.0300283332050004`}}, {{6.637801015376753, 
       1.0300283332050004`}, {6.607891479899203, 0.9332301134229565}, {
       6.607891479899203, 0.9332301134229565}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}}, {{
       6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}}, {{6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}, {6.637801015376753, 1.0300283332050004`}, {
       6.637801015376753, 1.0300283332050004`}}, {{6.607891479899203, 
       0.9332301134229565}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}}, {{
       6.607891479899203, 0.9332301134229565}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}, {
       6.607891479899203, 0.9332301134229565}, {6.607891479899203, 
       0.9332301134229565}}, {{6.607891479899203, 0.9332301134229565}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}, {6.607891479899203, 0.9332301134229565}, {
       6.607891479899203, 0.9332301134229565}}, {{6.607891479899203, 
       0.9332301134229565}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}, {6.607891479899203, 
       0.9332301134229565}, {6.607891479899203, 0.9332301134229565}}, {{
       6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}, {{6.552005001650963, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.479197459310518, 
       0.8589285859929837}, {6.552005001650963, 0.881425278345055}, {
       6.552005001650963, 0.881425278345055}}, {{6.552005001650963, 
       0.881425278345055}, {6.479197459310518, 0.8589285859929837}, {
       6.479197459310518, 0.8589285859929837}, {6.552005001650963, 
       0.881425278345055}, {6.552005001650963, 0.881425278345055}}, {{
       6.552005001650963, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}, {
       6.552005001650963, 0.881425278345055}, {6.552005001650963, 
       0.881425278345055}}, {{6.479197459310518, 0.8589285859929837}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}, {6.479197459310518, 0.8589285859929837}, {
       6.479197459310518, 0.8589285859929837}}, {{6.479197459310518, 
       0.8589285859929837}, {6.380412974199382, 0.881425278345055}, {
       6.380412974199382, 0.881425278345055}, {6.479197459310518, 
       0.8589285859929837}, {6.479197459310518, 0.8589285859929837}}, {{
       6.479197459310518, 0.8589285859929837}, {6.380412974199382, 
       0.881425278345055}, {6.380412974199382, 0.881425278345055}, {
       6.479197459310518, 0.8589285859929837}, {6.479197459310518, 
       0.8589285859929837}}, {{6.479197459310518, 0.8589285859929837}, {
       6.380412974199382, 0.881425278345055}, {6.380412974199382, 
       0.881425278345055}, {6.479197459310518, 0.8589285859929837}, {
       6.479197459310518, 0.8589285859929837}}, {{6.380412974199382, 
       1.178631388064946}, {6.479197459310518, 1.201128080417017}, {
       6.479197459310518, 1.201128080417017}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}}, {{
       6.380412974199382, 1.178631388064946}, {6.479197459310518, 
       1.201128080417017}, {6.479197459310518, 1.201128080417017}, {
       6.380412974199382, 1.178631388064946}, {6.380412974199382, 
       1.178631388064946}}, {{6.380412974199382, 1.178631388064946}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}, {6.380412974199382, 1.178631388064946}, {
       6.380412974199382, 1.178631388064946}}, {{6.380412974199382, 
       1.178631388064946}, {6.479197459310518, 1.201128080417017}, {
       6.479197459310518, 1.201128080417017}, {6.380412974199382, 
       1.178631388064946}, {6.380412974199382, 1.178631388064946}}, {{
       6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}}, {{6.479197459310518, 1.201128080417017}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}, {6.479197459310518, 1.201128080417017}, {
       6.479197459310518, 1.201128080417017}}, {{6.479197459310518, 
       1.201128080417017}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}, {6.479197459310518, 
       1.201128080417017}, {6.479197459310518, 1.201128080417017}}, {{
       6.479197459310518, 1.201128080417017}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}, {
       6.479197459310518, 1.201128080417017}, {6.479197459310518, 
       1.201128080417017}}, {{6.552005001650963, 1.1786313880649457`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}}, {{6.552005001650963, 
       1.1786313880649457`}, {6.607891479899203, 1.1268265529870445`}, {
       6.607891479899203, 1.1268265529870445`}, {6.552005001650963, 
       1.1786313880649457`}, {6.552005001650963, 1.1786313880649457`}}, {{
       6.552005001650963, 1.1786313880649457`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}, {
       6.552005001650963, 1.1786313880649457`}, {6.552005001650963, 
       1.1786313880649457`}}, {{6.552005001650963, 1.1786313880649457`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}, {6.552005001650963, 1.1786313880649457`}, {
       6.552005001650963, 1.1786313880649457`}}, {{6.607891479899203, 
       1.1268265529870445`}, {6.637801015376753, 1.0300283332050004`}, {
       6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}}, {{
       6.607891479899203, 1.1268265529870445`}, {6.637801015376753, 
       1.0300283332050004`}, {6.637801015376753, 1.0300283332050004`}, {
       6.607891479899203, 1.1268265529870445`}, {6.607891479899203, 
       1.1268265529870445`}}, {{6.607891479899203, 1.1268265529870445`}, {
       6.637801015376753, 1.0300283332050004`}, {6.637801015376753, 
       1.0300283332050004`}, {6.607891479899203, 1.1268265529870445`}, {
       6.607891479899203, 1.1268265529870445`}}, {{6.607891479899203, 
       1.1268265529870445`}, {6.637801015376753, 1.0300283332050004`}, {
       6.637801015376753, 1.0300283332050004`}, {6.607891479899203, 
       1.1268265529870445`}, {6.607891479899203, 1.1268265529870445`}}, {{
       6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`, 
       1.4354354382816115`}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802, 
       1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.340742083096224, 
       1.50445339975363}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}, {{6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}}, {{6.659522392174537, 
       1.50445339975363}, {6.631739717461946, 1.4145384809819588`}, {
       6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.420437160365802, 1.3664174768095927`}, {
       6.420437160365802, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.579827314904959, 1.3664174768095927`}, {
       6.631739717461946, 1.4145384809819588`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}}, {{
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}, {{6.420437160365802, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.631739717461946, 1.5943683185253013`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}, {6.631739717461946, 1.5943683185253013`}, {
       6.579827314904959, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.420437160365802, 1.6424893226976673`}, {
       6.420437160365802, 1.6424893226976673`}}, {{6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}}, {{
       6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`, 
       1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}, {{6.420437160365802, 1.3664174768095927`}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.3564598938866155`, 
       1.4354354382816115`}, {6.420437160365802, 1.3664174768095927`}, {
       6.420437160365802, 1.3664174768095927`}}, {{6.420437160365802, 
       1.3664174768095927`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}}, {{
       6.420437160365802, 1.3664174768095927`}, {6.3564598938866155`, 
       1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}}, {{6.3564598938866155`, 1.4354354382816115`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.3564598938866155`, 1.4354354382816115`}}, {{6.3564598938866155`, 
       1.4354354382816115`}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}, {6.3564598938866155`, 
       1.4354354382816115`}, {6.3564598938866155`, 1.4354354382816115`}}, {{
       6.3564598938866155`, 1.4354354382816115`}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.4354354382816115`}, {6.3564598938866155`, 
       1.4354354382816115`}}, {{6.3564598938866155`, 1.4354354382816115`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}, {6.3564598938866155`, 1.4354354382816115`}, {
       6.3564598938866155`, 1.4354354382816115`}}, {{6.340742083096224, 
       1.50445339975363}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}}, {{
       6.340742083096224, 1.50445339975363}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.340742083096224, 1.50445339975363}, {6.340742083096224, 
       1.50445339975363}}, {{6.340742083096224, 1.50445339975363}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.340742083096224, 1.50445339975363}, {
       6.340742083096224, 1.50445339975363}}, {{6.340742083096224, 
       1.50445339975363}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.340742083096224, 
       1.50445339975363}, {6.340742083096224, 1.50445339975363}}, {{
       6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802, 
       1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}}, {{6.3564598938866155`, 1.5734713612256486`}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}, {6.3564598938866155`, 1.5734713612256486`}, {
       6.3564598938866155`, 1.5734713612256486`}}, {{6.3564598938866155`, 
       1.5734713612256486`}, {6.420437160365802, 1.6424893226976673`}, {
       6.420437160365802, 1.6424893226976673`}, {6.3564598938866155`, 
       1.5734713612256486`}, {6.3564598938866155`, 1.5734713612256486`}}, {{
       6.3564598938866155`, 1.5734713612256486`}, {6.420437160365802, 
       1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}, {
       6.3564598938866155`, 1.5734713612256486`}, {6.3564598938866155`, 
       1.5734713612256486`}}, {{6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}, {6.659522392174537, 1.50445339975363}, {
       6.659522392174537, 1.50445339975363}}, {{6.659522392174537, 
       1.50445339975363}, {6.631739717461946, 1.4145384809819588`}, {
       6.631739717461946, 1.4145384809819588`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}}, {{
       6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}}, {{6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}, {6.659522392174537, 1.50445339975363}, {
       6.659522392174537, 1.50445339975363}}, {{6.631739717461946, 
       1.4145384809819588`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}}, {{
       6.631739717461946, 1.4145384809819588`}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}, {
       6.631739717461946, 1.4145384809819588`}, {6.631739717461946, 
       1.4145384809819588`}}, {{6.631739717461946, 1.4145384809819588`}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}, {6.631739717461946, 1.4145384809819588`}, {
       6.631739717461946, 1.4145384809819588`}}, {{6.631739717461946, 
       1.4145384809819588`}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}, {6.631739717461946, 
       1.4145384809819588`}, {6.631739717461946, 1.4145384809819588`}}, {{
       6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}, {{6.579827314904959, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.512197101557579, 
       1.34552051950994}, {6.579827314904959, 1.3664174768095927`}, {
       6.579827314904959, 1.3664174768095927`}}, {{6.579827314904959, 
       1.3664174768095927`}, {6.512197101557579, 1.34552051950994}, {
       6.512197101557579, 1.34552051950994}, {6.579827314904959, 
       1.3664174768095927`}, {6.579827314904959, 1.3664174768095927`}}, {{
       6.579827314904959, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}, {
       6.579827314904959, 1.3664174768095927`}, {6.579827314904959, 
       1.3664174768095927`}}, {{6.512197101557579, 1.34552051950994}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}, {6.512197101557579, 1.34552051950994}, {
       6.512197101557579, 1.34552051950994}}, {{6.512197101557579, 
       1.34552051950994}, {6.420437160365802, 1.3664174768095927`}, {
       6.420437160365802, 1.3664174768095927`}, {6.512197101557579, 
       1.34552051950994}, {6.512197101557579, 1.34552051950994}}, {{
       6.512197101557579, 1.34552051950994}, {6.420437160365802, 
       1.3664174768095927`}, {6.420437160365802, 1.3664174768095927`}, {
       6.512197101557579, 1.34552051950994}, {6.512197101557579, 
       1.34552051950994}}, {{6.512197101557579, 1.34552051950994}, {
       6.420437160365802, 1.3664174768095927`}, {6.420437160365802, 
       1.3664174768095927`}, {6.512197101557579, 1.34552051950994}, {
       6.512197101557579, 1.34552051950994}}, {{6.420437160365802, 
       1.6424893226976673`}, {6.512197101557579, 1.66338627999732}, {
       6.512197101557579, 1.66338627999732}, {6.420437160365802, 
       1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}}, {{
       6.420437160365802, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.512197101557579, 1.66338627999732}, {
       6.420437160365802, 1.6424893226976673`}, {6.420437160365802, 
       1.6424893226976673`}}, {{6.420437160365802, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}, {6.420437160365802, 1.6424893226976673`}, {
       6.420437160365802, 1.6424893226976673`}}, {{6.420437160365802, 
       1.6424893226976673`}, {6.512197101557579, 1.66338627999732}, {
       6.512197101557579, 1.66338627999732}, {6.420437160365802, 
       1.6424893226976673`}, {6.420437160365802, 1.6424893226976673`}}, {{
       6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}}, {{6.512197101557579, 1.66338627999732}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}, {6.512197101557579, 1.66338627999732}, {
       6.512197101557579, 1.66338627999732}}, {{6.512197101557579, 
       1.66338627999732}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}, {6.512197101557579, 
       1.66338627999732}, {6.512197101557579, 1.66338627999732}}, {{
       6.512197101557579, 1.66338627999732}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}, {
       6.512197101557579, 1.66338627999732}, {6.512197101557579, 
       1.66338627999732}}, {{6.579827314904959, 1.6424893226976673`}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}}, {{6.579827314904959, 
       1.6424893226976673`}, {6.631739717461946, 1.5943683185253013`}, {
       6.631739717461946, 1.5943683185253013`}, {6.579827314904959, 
       1.6424893226976673`}, {6.579827314904959, 1.6424893226976673`}}, {{
       6.579827314904959, 1.6424893226976673`}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}, {
       6.579827314904959, 1.6424893226976673`}, {6.579827314904959, 
       1.6424893226976673`}}, {{6.579827314904959, 1.6424893226976673`}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}, {6.579827314904959, 1.6424893226976673`}, {
       6.579827314904959, 1.6424893226976673`}}, {{6.631739717461946, 
       1.5943683185253013`}, {6.659522392174537, 1.50445339975363}, {
       6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}}, {{
       6.631739717461946, 1.5943683185253013`}, {6.659522392174537, 
       1.50445339975363}, {6.659522392174537, 1.50445339975363}, {
       6.631739717461946, 1.5943683185253013`}, {6.631739717461946, 
       1.5943683185253013`}}, {{6.631739717461946, 1.5943683185253013`}, {
       6.659522392174537, 1.50445339975363}, {6.659522392174537, 
       1.50445339975363}, {6.631739717461946, 1.5943683185253013`}, {
       6.631739717461946, 1.5943683185253013`}}, {{6.631739717461946, 
       1.5943683185253013`}, {6.659522392174537, 1.50445339975363}, {
       6.659522392174537, 1.50445339975363}, {6.631739717461946, 
       1.5943683185253013`}, {6.631739717461946, 1.5943683185253013`}}, {{
       6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.1305649472193093`}, {6.438983334450372, 2.1305649472193093`}, {
       6.374161779971002, 2.0606361772699255`}, {6.358236546141619, 
       1.9907074073205417`}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}, {{6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}}, {{6.681223699376629, 
       1.9907074073205417`}, {6.653074385384749, 1.8996059094539193`}, {
       6.600476911067876, 1.850849867421774}, {6.53195420292162, 
       1.8296771395045353`}, {6.438983334450372, 1.850849867421774}, {
       6.438983334450372, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.600476911067876, 1.850849867421774}, {
       6.653074385384749, 1.8996059094539193`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}}, {{
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}, {{6.438983334450372, 2.13056494721931}, {
       6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.653074385384749, 2.0818089051871644`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}, {6.653074385384749, 2.0818089051871644`}, {
       6.600476911067876, 2.1305649472193093`}, {6.53195420292162, 
       2.1517376751365482`}, {6.438983334450372, 2.13056494721931}, {
       6.438983334450372, 2.13056494721931}}, {{6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}}, {{
       6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}, {{6.438983334450372, 1.850849867421774}, {
       6.374161779971002, 1.920778637371158}, {6.374161779971002, 
       1.920778637371158}, {6.438983334450372, 1.850849867421774}, {
       6.438983334450372, 1.850849867421774}}, {{6.438983334450372, 
       1.850849867421774}, {6.374161779971002, 1.920778637371158}, {
       6.374161779971002, 1.920778637371158}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}}, {{
       6.438983334450372, 1.850849867421774}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}}, {{6.374161779971002, 1.920778637371158}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.374161779971002, 1.920778637371158}, {
       6.374161779971002, 1.920778637371158}}, {{6.374161779971002, 
       1.920778637371158}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}, {6.374161779971002, 
       1.920778637371158}, {6.374161779971002, 1.920778637371158}}, {{
       6.374161779971002, 1.920778637371158}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 1.920778637371158}, {6.374161779971002, 
       1.920778637371158}}, {{6.374161779971002, 1.920778637371158}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}, {6.374161779971002, 1.920778637371158}, {
       6.374161779971002, 1.920778637371158}}, {{6.358236546141619, 
       1.9907074073205417`}, {6.374161779971002, 2.0606361772699255`}, {
       6.374161779971002, 2.0606361772699255`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}}, {{
       6.358236546141619, 1.9907074073205417`}, {6.374161779971002, 
       2.0606361772699255`}, {6.374161779971002, 2.0606361772699255`}, {
       6.358236546141619, 1.9907074073205417`}, {6.358236546141619, 
       1.9907074073205417`}}, {{6.358236546141619, 1.9907074073205417`}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}, {6.358236546141619, 1.9907074073205417`}, {
       6.358236546141619, 1.9907074073205417`}}, {{6.358236546141619, 
       1.9907074073205417`}, {6.374161779971002, 2.0606361772699255`}, {
       6.374161779971002, 2.0606361772699255`}, {6.358236546141619, 
       1.9907074073205417`}, {6.358236546141619, 1.9907074073205417`}}, {{
       6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}}, {{6.374161779971002, 2.0606361772699255`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}, {6.374161779971002, 2.0606361772699255`}, {
       6.374161779971002, 2.0606361772699255`}}, {{6.374161779971002, 
       2.0606361772699255`}, {6.438983334450372, 2.13056494721931}, {
       6.438983334450372, 2.13056494721931}, {6.374161779971002, 
       2.0606361772699255`}, {6.374161779971002, 2.0606361772699255`}}, {{
       6.374161779971002, 2.0606361772699255`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}, {
       6.374161779971002, 2.0606361772699255`}, {6.374161779971002, 
       2.0606361772699255`}}, {{6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}, {6.681223699376629, 1.9907074073205417`}, {
       6.681223699376629, 1.9907074073205417`}}, {{6.681223699376629, 
       1.9907074073205417`}, {6.653074385384749, 1.8996059094539193`}, {
       6.653074385384749, 1.8996059094539193`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}}, {{
       6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}}, {{6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}, {6.681223699376629, 1.9907074073205417`}, {
       6.681223699376629, 1.9907074073205417`}}, {{6.653074385384749, 
       1.8996059094539193`}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}}, {{
       6.653074385384749, 1.8996059094539193`}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}, {
       6.653074385384749, 1.8996059094539193`}, {6.653074385384749, 
       1.8996059094539193`}}, {{6.653074385384749, 1.8996059094539193`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}, {6.653074385384749, 1.8996059094539193`}, {
       6.653074385384749, 1.8996059094539193`}}, {{6.653074385384749, 
       1.8996059094539193`}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}, {6.653074385384749, 
       1.8996059094539193`}, {6.653074385384749, 1.8996059094539193`}}, {{
       6.600476911067876, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.531954202921621, 1.8296771395045353`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}, {{6.600476911067876, 1.850849867421774}, {
       6.531954202921621, 1.8296771395045353`}, {6.531954202921621, 
       1.8296771395045353`}, {6.600476911067876, 1.850849867421774}, {
       6.600476911067876, 1.850849867421774}}, {{6.600476911067876, 
       1.850849867421774}, {6.531954202921621, 1.8296771395045353`}, {
       6.531954202921621, 1.8296771395045353`}, {6.600476911067876, 
       1.850849867421774}, {6.600476911067876, 1.850849867421774}}, {{
       6.600476911067876, 1.850849867421774}, {6.531954202921621, 
       1.8296771395045353`}, {6.531954202921621, 1.8296771395045353`}, {
       6.600476911067876, 1.850849867421774}, {6.600476911067876, 
       1.850849867421774}}, {{6.53195420292162, 1.8296771395045353`}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}, {6.53195420292162, 1.8296771395045353`}, {
       6.53195420292162, 1.8296771395045353`}}, {{6.53195420292162, 
       1.8296771395045353`}, {6.438983334450372, 1.850849867421774}, {
       6.438983334450372, 1.850849867421774}, {6.53195420292162, 
       1.8296771395045353`}, {6.53195420292162, 1.8296771395045353`}}, {{
       6.53195420292162, 1.8296771395045353`}, {6.438983334450372, 
       1.850849867421774}, {6.438983334450372, 1.850849867421774}, {
       6.53195420292162, 1.8296771395045353`}, {6.53195420292162, 
       1.8296771395045353`}}, {{6.53195420292162, 1.8296771395045353`}, {
       6.438983334450372, 1.850849867421774}, {6.438983334450372, 
       1.850849867421774}, {6.53195420292162, 1.8296771395045353`}, {
       6.53195420292162, 1.8296771395045353`}}, {{6.438983334450372, 
       2.13056494721931}, {6.531954202921621, 2.1517376751365482`}, {
       6.531954202921621, 2.1517376751365482`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}}, {{
       6.438983334450372, 2.13056494721931}, {6.531954202921621, 
       2.1517376751365482`}, {6.531954202921621, 2.1517376751365482`}, {
       6.438983334450372, 2.13056494721931}, {6.438983334450372, 
       2.13056494721931}}, {{6.438983334450372, 2.13056494721931}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}, {6.438983334450372, 2.13056494721931}, {
       6.438983334450372, 2.13056494721931}}, {{6.438983334450372, 
       2.13056494721931}, {6.531954202921621, 2.1517376751365482`}, {
       6.531954202921621, 2.1517376751365482`}, {6.438983334450372, 
       2.13056494721931}, {6.438983334450372, 2.13056494721931}}, {{
       6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}}, {{6.531954202921621, 2.1517376751365482`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}, {6.531954202921621, 2.1517376751365482`}, {
       6.531954202921621, 2.1517376751365482`}}, {{6.531954202921621, 
       2.1517376751365482`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}, {6.531954202921621, 
       2.1517376751365482`}, {6.531954202921621, 2.1517376751365482`}}, {{
       6.531954202921621, 2.1517376751365482`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}, {
       6.531954202921621, 2.1517376751365482`}, {6.531954202921621, 
       2.1517376751365482`}}, {{6.600476911067876, 2.1305649472193093`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}}, {{6.600476911067876, 
       2.1305649472193093`}, {6.653074385384749, 2.0818089051871644`}, {
       6.653074385384749, 2.0818089051871644`}, {6.600476911067876, 
       2.1305649472193093`}, {6.600476911067876, 2.1305649472193093`}}, {{
       6.600476911067876, 2.1305649472193093`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}, {
       6.600476911067876, 2.1305649472193093`}, {6.600476911067876, 
       2.1305649472193093`}}, {{6.600476911067876, 2.1305649472193093`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}, {6.600476911067876, 2.1305649472193093`}, {
       6.600476911067876, 2.1305649472193093`}}, {{6.653074385384749, 
       2.0818089051871644`}, {6.681223699376629, 1.9907074073205417`}, {
       6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}}, {{
       6.653074385384749, 2.0818089051871644`}, {6.681223699376629, 
       1.9907074073205417`}, {6.681223699376629, 1.9907074073205417`}, {
       6.653074385384749, 2.0818089051871644`}, {6.653074385384749, 
       2.0818089051871644`}}, {{6.653074385384749, 2.0818089051871644`}, {
       6.681223699376629, 1.9907074073205417`}, {6.681223699376629, 
       1.9907074073205417`}, {6.653074385384749, 2.0818089051871644`}, {
       6.653074385384749, 2.0818089051871644`}}, {{6.653074385384749, 
       2.0818089051871644`}, {6.681223699376629, 1.9907074073205417`}, {
       6.681223699376629, 1.9907074073205417`}, {6.653074385384749, 
       2.0818089051871644`}, {6.653074385384749, 2.0818089051871644`}}, {{
       6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.299112196457192, 
       2.51343200227038}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}, {{6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}}, {{6.634502725859906, 
       2.51343200227038}, {6.605272419863214, 2.4188320180517047`}, {
       6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.38295982880787, 2.368203642944649}, {
       6.38295982880787, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.550655093509228, 2.368203642944649}, {
       6.605272419863214, 2.4188320180517047`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}}, {{
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}, {{6.38295982880787, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.605272419863214, 2.6080319864890558`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}, {6.605272419863214, 2.6080319864890558`}, {
       6.550655093509228, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.38295982880787, 2.6586603615961115`}, {
       6.38295982880787, 2.6586603615961115`}}, {{6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}}, {{
       6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}, {{6.38295982880787, 2.368203642944649}, {
       6.315648992275237, 2.4408178226075146`}, {6.315648992275237, 
       2.4408178226075146`}, {6.38295982880787, 2.368203642944649}, {
       6.38295982880787, 2.368203642944649}}, {{6.38295982880787, 
       2.368203642944649}, {6.315648992275237, 2.4408178226075146`}, {
       6.315648992275237, 2.4408178226075146`}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}}, {{
       6.38295982880787, 2.368203642944649}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}}, {{6.315648992275237, 2.4408178226075146`}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.315648992275237, 2.4408178226075146`}, {
       6.315648992275237, 2.4408178226075146`}}, {{6.315648992275237, 
       2.4408178226075146`}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}, {6.315648992275237, 
       2.4408178226075146`}, {6.315648992275237, 2.4408178226075146`}}, {{
       6.315648992275237, 2.4408178226075146`}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.4408178226075146`}, {6.315648992275237, 
       2.4408178226075146`}}, {{6.315648992275237, 2.4408178226075146`}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}, {6.315648992275237, 2.4408178226075146`}, {
       6.315648992275237, 2.4408178226075146`}}, {{6.299112196457192, 
       2.51343200227038}, {6.315648992275237, 2.586046181933246}, {
       6.315648992275237, 2.586046181933246}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}}, {{
       6.299112196457192, 2.51343200227038}, {6.315648992275237, 
       2.586046181933246}, {6.315648992275237, 2.586046181933246}, {
       6.299112196457192, 2.51343200227038}, {6.299112196457192, 
       2.51343200227038}}, {{6.299112196457192, 2.51343200227038}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}, {6.299112196457192, 2.51343200227038}, {
       6.299112196457192, 2.51343200227038}}, {{6.299112196457192, 
       2.51343200227038}, {6.315648992275237, 2.586046181933246}, {
       6.315648992275237, 2.586046181933246}, {6.299112196457192, 
       2.51343200227038}, {6.299112196457192, 2.51343200227038}}, {{
       6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}}, {{6.315648992275237, 2.586046181933246}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}, {6.315648992275237, 2.586046181933246}, {
       6.315648992275237, 2.586046181933246}}, {{6.315648992275237, 
       2.586046181933246}, {6.38295982880787, 2.6586603615961115`}, {
       6.38295982880787, 2.6586603615961115`}, {6.315648992275237, 
       2.586046181933246}, {6.315648992275237, 2.586046181933246}}, {{
       6.315648992275237, 2.586046181933246}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}, {
       6.315648992275237, 2.586046181933246}, {6.315648992275237, 
       2.586046181933246}}, {{6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}, {6.634502725859906, 2.51343200227038}, {
       6.634502725859906, 2.51343200227038}}, {{6.634502725859906, 
       2.51343200227038}, {6.605272419863214, 2.4188320180517047`}, {
       6.605272419863214, 2.4188320180517047`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}}, {{
       6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}}, {{6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}, {6.634502725859906, 2.51343200227038}, {
       6.634502725859906, 2.51343200227038}}, {{6.605272419863214, 
       2.4188320180517047`}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}}, {{
       6.605272419863214, 2.4188320180517047`}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}, {
       6.605272419863214, 2.4188320180517047`}, {6.605272419863214, 
       2.4188320180517047`}}, {{6.605272419863214, 2.4188320180517047`}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}, {6.605272419863214, 2.4188320180517047`}, {
       6.605272419863214, 2.4188320180517047`}}, {{6.605272419863214, 
       2.4188320180517047`}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}, {6.605272419863214, 
       2.4188320180517047`}, {6.605272419863214, 2.4188320180517047`}}, {{
       6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}, {{6.550655093509228, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.479500971337196, 
       2.346217838388839}, {6.550655093509228, 2.368203642944649}, {
       6.550655093509228, 2.368203642944649}}, {{6.550655093509228, 
       2.368203642944649}, {6.479500971337196, 2.346217838388839}, {
       6.479500971337196, 2.346217838388839}, {6.550655093509228, 
       2.368203642944649}, {6.550655093509228, 2.368203642944649}}, {{
       6.550655093509228, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}, {
       6.550655093509228, 2.368203642944649}, {6.550655093509228, 
       2.368203642944649}}, {{6.479500971337196, 2.346217838388839}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}, {6.479500971337196, 2.346217838388839}, {
       6.479500971337196, 2.346217838388839}}, {{6.479500971337196, 
       2.346217838388839}, {6.38295982880787, 2.368203642944649}, {
       6.38295982880787, 2.368203642944649}, {6.479500971337196, 
       2.346217838388839}, {6.479500971337196, 2.346217838388839}}, {{
       6.479500971337196, 2.346217838388839}, {6.38295982880787, 
       2.368203642944649}, {6.38295982880787, 2.368203642944649}, {
       6.479500971337196, 2.346217838388839}, {6.479500971337196, 
       2.346217838388839}}, {{6.479500971337196, 2.346217838388839}, {
       6.38295982880787, 2.368203642944649}, {6.38295982880787, 
       2.368203642944649}, {6.479500971337196, 2.346217838388839}, {
       6.479500971337196, 2.346217838388839}}, {{6.38295982880787, 
       2.6586603615961115`}, {6.479500971337196, 2.6806461661519214`}, {
       6.479500971337196, 2.6806461661519214`}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}}, {{
       6.38295982880787, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.479500971337196, 2.6806461661519214`}, {
       6.38295982880787, 2.6586603615961115`}, {6.38295982880787, 
       2.6586603615961115`}}, {{6.38295982880787, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}, {6.38295982880787, 2.6586603615961115`}, {
       6.38295982880787, 2.6586603615961115`}}, {{6.38295982880787, 
       2.6586603615961115`}, {6.479500971337196, 2.6806461661519214`}, {
       6.479500971337196, 2.6806461661519214`}, {6.38295982880787, 
       2.6586603615961115`}, {6.38295982880787, 2.6586603615961115`}}, {{
       6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}}, {{6.479500971337196, 2.6806461661519214`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}, {6.479500971337196, 2.6806461661519214`}, {
       6.479500971337196, 2.6806461661519214`}}, {{6.479500971337196, 
       2.6806461661519214`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}, {6.479500971337196, 
       2.6806461661519214`}, {6.479500971337196, 2.6806461661519214`}}, {{
       6.479500971337196, 2.6806461661519214`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}, {
       6.479500971337196, 2.6806461661519214`}, {6.479500971337196, 
       2.6806461661519214`}}, {{6.550655093509228, 2.6586603615961115`}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}}, {{6.550655093509228, 
       2.6586603615961115`}, {6.605272419863214, 2.6080319864890558`}, {
       6.605272419863214, 2.6080319864890558`}, {6.550655093509228, 
       2.6586603615961115`}, {6.550655093509228, 2.6586603615961115`}}, {{
       6.550655093509228, 2.6586603615961115`}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}, {
       6.550655093509228, 2.6586603615961115`}, {6.550655093509228, 
       2.6586603615961115`}}, {{6.550655093509228, 2.6586603615961115`}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}, {6.550655093509228, 2.6586603615961115`}, {
       6.550655093509228, 2.6586603615961115`}}, {{6.605272419863214, 
       2.6080319864890558`}, {6.634502725859906, 2.51343200227038}, {
       6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}}, {{
       6.605272419863214, 2.6080319864890558`}, {6.634502725859906, 
       2.51343200227038}, {6.634502725859906, 2.51343200227038}, {
       6.605272419863214, 2.6080319864890558`}, {6.605272419863214, 
       2.6080319864890558`}}, {{6.605272419863214, 2.6080319864890558`}, {
       6.634502725859906, 2.51343200227038}, {6.634502725859906, 
       2.51343200227038}, {6.605272419863214, 2.6080319864890558`}, {
       6.605272419863214, 2.6080319864890558`}}, {{6.605272419863214, 
       2.6080319864890558`}, {6.634502725859906, 2.51343200227038}, {
       6.634502725859906, 2.51343200227038}, {6.605272419863214, 
       2.6080319864890558`}, {6.605272419863214, 2.6080319864890558`}}, {{
       6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.325372149584101, 
       2.972611763730079}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}, {{6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}}, {{6.653414522642294, 
       2.972611763730079}, {6.624824630848246, 2.8800843946072026`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424, 
       2.809061137460671}, {6.407382742848649, 2.8305652494370155`}, {
       6.407382742848649, 2.8305652494370155`}, {6.501808740951424, 
       2.809061137460671}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.624824630848246, 2.8800843946072026`}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}}, {{
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}, {{6.407382742848649, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`, 
       3.114658278023142}, {6.624824630848246, 3.065139132852955}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}, {6.624824630848246, 3.065139132852955}, {
       6.5714039293777455`, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.407382742848649, 3.114658278023142}, {
       6.407382742848649, 3.114658278023142}}, {{6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}}, {{
       6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}, {{6.407382742848649, 2.8305652494370155`}, {
       6.341546636539922, 2.901588506583547}, {6.341546636539922, 
       2.901588506583547}, {6.407382742848649, 2.8305652494370155`}, {
       6.407382742848649, 2.8305652494370155`}}, {{6.407382742848649, 
       2.8305652494370155`}, {6.341546636539922, 2.901588506583547}, {
       6.341546636539922, 2.901588506583547}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}}, {{
       6.407382742848649, 2.8305652494370155`}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}}, {{6.341546636539922, 2.901588506583547}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.341546636539922, 2.901588506583547}, {
       6.341546636539922, 2.901588506583547}}, {{6.341546636539922, 
       2.901588506583547}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}, {6.341546636539922, 
       2.901588506583547}, {6.341546636539922, 2.901588506583547}}, {{
       6.341546636539922, 2.901588506583547}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 2.901588506583547}, {6.341546636539922, 
       2.901588506583547}}, {{6.341546636539922, 2.901588506583547}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}, {6.341546636539922, 2.901588506583547}, {
       6.341546636539922, 2.901588506583547}}, {{6.325372149584101, 
       2.972611763730079}, {6.341546636539922, 3.0436350208766108`}, {
       6.341546636539922, 3.0436350208766108`}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}}, {{
       6.325372149584101, 2.972611763730079}, {6.341546636539922, 
       3.0436350208766108`}, {6.341546636539922, 3.0436350208766108`}, {
       6.325372149584101, 2.972611763730079}, {6.325372149584101, 
       2.972611763730079}}, {{6.325372149584101, 2.972611763730079}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}, {6.325372149584101, 2.972611763730079}, {
       6.325372149584101, 2.972611763730079}}, {{6.325372149584101, 
       2.972611763730079}, {6.341546636539922, 3.0436350208766108`}, {
       6.341546636539922, 3.0436350208766108`}, {6.325372149584101, 
       2.972611763730079}, {6.325372149584101, 2.972611763730079}}, {{
       6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}}, {{6.341546636539922, 3.0436350208766108`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}, {6.341546636539922, 3.0436350208766108`}, {
       6.341546636539922, 3.0436350208766108`}}, {{6.341546636539922, 
       3.0436350208766108`}, {6.407382742848649, 3.114658278023142}, {
       6.407382742848649, 3.114658278023142}, {6.341546636539922, 
       3.0436350208766108`}, {6.341546636539922, 3.0436350208766108`}}, {{
       6.341546636539922, 3.0436350208766108`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}, {
       6.341546636539922, 3.0436350208766108`}, {6.341546636539922, 
       3.0436350208766108`}}, {{6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}, {6.653414522642294, 2.972611763730079}, {
       6.653414522642294, 2.972611763730079}}, {{6.653414522642294, 
       2.972611763730079}, {6.624824630848246, 2.8800843946072026`}, {
       6.624824630848246, 2.8800843946072026`}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}}, {{
       6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}}, {{6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}, {6.653414522642294, 2.972611763730079}, {
       6.653414522642294, 2.972611763730079}}, {{6.624824630848246, 
       2.8800843946072026`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}}, {{
       6.624824630848246, 2.8800843946072026`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.624824630848246, 2.8800843946072026`}, {6.624824630848246, 
       2.8800843946072026`}}, {{6.624824630848246, 2.8800843946072026`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.624824630848246, 2.8800843946072026`}, {
       6.624824630848246, 2.8800843946072026`}}, {{6.624824630848246, 
       2.8800843946072026`}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.624824630848246, 
       2.8800843946072026`}, {6.624824630848246, 2.8800843946072026`}}, {{
       6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424, 
       2.809061137460671}, {6.501808740951424, 2.809061137460671}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}, {{6.5714039293777455`, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.501808740951424, 
       2.809061137460671}, {6.5714039293777455`, 2.8305652494370155`}, {
       6.5714039293777455`, 2.8305652494370155`}}, {{6.5714039293777455`, 
       2.8305652494370155`}, {6.501808740951424, 2.809061137460671}, {
       6.501808740951424, 2.809061137460671}, {6.5714039293777455`, 
       2.8305652494370155`}, {6.5714039293777455`, 2.8305652494370155`}}, {{
       6.5714039293777455`, 2.8305652494370155`}, {6.501808740951424, 
       2.809061137460671}, {6.501808740951424, 2.809061137460671}, {
       6.5714039293777455`, 2.8305652494370155`}, {6.5714039293777455`, 
       2.8305652494370155`}}, {{6.501808740951424, 2.809061137460671}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}, {6.501808740951424, 2.809061137460671}, {
       6.501808740951424, 2.809061137460671}}, {{6.501808740951424, 
       2.809061137460671}, {6.407382742848649, 2.8305652494370155`}, {
       6.407382742848649, 2.8305652494370155`}, {6.501808740951424, 
       2.809061137460671}, {6.501808740951424, 2.809061137460671}}, {{
       6.501808740951424, 2.809061137460671}, {6.407382742848649, 
       2.8305652494370155`}, {6.407382742848649, 2.8305652494370155`}, {
       6.501808740951424, 2.809061137460671}, {6.501808740951424, 
       2.809061137460671}}, {{6.501808740951424, 2.809061137460671}, {
       6.407382742848649, 2.8305652494370155`}, {6.407382742848649, 
       2.8305652494370155`}, {6.501808740951424, 2.809061137460671}, {
       6.501808740951424, 2.809061137460671}}, {{6.407382742848649, 
       3.114658278023142}, {6.501808740951424, 3.1361623899994866`}, {
       6.501808740951424, 3.1361623899994866`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}}, {{
       6.407382742848649, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.501808740951424, 3.1361623899994866`}, {
       6.407382742848649, 3.114658278023142}, {6.407382742848649, 
       3.114658278023142}}, {{6.407382742848649, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}, {6.407382742848649, 3.114658278023142}, {
       6.407382742848649, 3.114658278023142}}, {{6.407382742848649, 
       3.114658278023142}, {6.501808740951424, 3.1361623899994866`}, {
       6.501808740951424, 3.1361623899994866`}, {6.407382742848649, 
       3.114658278023142}, {6.407382742848649, 3.114658278023142}}, {{
       6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}}, {{6.501808740951424, 3.1361623899994866`}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}, {6.501808740951424, 3.1361623899994866`}, {
       6.501808740951424, 3.1361623899994866`}}, {{6.501808740951424, 
       3.1361623899994866`}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}, {6.501808740951424, 
       3.1361623899994866`}, {6.501808740951424, 3.1361623899994866`}}, {{
       6.501808740951424, 3.1361623899994866`}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}, {
       6.501808740951424, 3.1361623899994866`}, {6.501808740951424, 
       3.1361623899994866`}}, {{6.5714039293777455`, 3.114658278023142}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}}, {{6.5714039293777455`, 
       3.114658278023142}, {6.624824630848246, 3.065139132852955}, {
       6.624824630848246, 3.065139132852955}, {6.5714039293777455`, 
       3.114658278023142}, {6.5714039293777455`, 3.114658278023142}}, {{
       6.5714039293777455`, 3.114658278023142}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}, {
       6.5714039293777455`, 3.114658278023142}, {6.5714039293777455`, 
       3.114658278023142}}, {{6.5714039293777455`, 3.114658278023142}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}, {6.5714039293777455`, 3.114658278023142}, {
       6.5714039293777455`, 3.114658278023142}}, {{6.624824630848246, 
       3.065139132852955}, {6.653414522642294, 2.972611763730079}, {
       6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}}, {{
       6.624824630848246, 3.065139132852955}, {6.653414522642294, 
       2.972611763730079}, {6.653414522642294, 2.972611763730079}, {
       6.624824630848246, 3.065139132852955}, {6.624824630848246, 
       3.065139132852955}}, {{6.624824630848246, 3.065139132852955}, {
       6.653414522642294, 2.972611763730079}, {6.653414522642294, 
       2.972611763730079}, {6.624824630848246, 3.065139132852955}, {
       6.624824630848246, 3.065139132852955}}, {{6.624824630848246, 
       3.065139132852955}, {6.653414522642294, 2.972611763730079}, {
       6.653414522642294, 2.972611763730079}, {6.624824630848246, 
       3.065139132852955}, {6.624824630848246, 3.065139132852955}}, {{
       6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.319749885066836, 
       3.517444916309843}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}, {{6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}}, {{6.622443997624657, 
       3.517444916309843}, {6.596063283925856, 3.4320672572505644`}, {
       6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.395423413206291, 3.386374520784313}, {
       6.395423413206291, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.546770469485202, 3.386374520784313}, {
       6.596063283925856, 3.4320672572505644`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}}, {{
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}, {{6.395423413206291, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.596063283925856, 3.6028225753691214`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}, {6.596063283925856, 3.6028225753691214`}, {
       6.546770469485202, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.395423413206291, 3.648515311835373}, {
       6.395423413206291, 3.648515311835373}}, {{6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}}, {{
       6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}, {{6.395423413206291, 3.386374520784313}, {
       6.33467454839471, 3.451909718547078}, {6.33467454839471, 
       3.451909718547078}, {6.395423413206291, 3.386374520784313}, {
       6.395423413206291, 3.386374520784313}}, {{6.395423413206291, 
       3.386374520784313}, {6.33467454839471, 3.451909718547078}, {
       6.33467454839471, 3.451909718547078}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}}, {{
       6.395423413206291, 3.386374520784313}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}}, {{6.33467454839471, 3.451909718547078}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.33467454839471, 3.451909718547078}, {
       6.33467454839471, 3.451909718547078}}, {{6.33467454839471, 
       3.451909718547078}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}, {6.33467454839471, 
       3.451909718547078}, {6.33467454839471, 3.451909718547078}}, {{
       6.33467454839471, 3.451909718547078}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.451909718547078}, {6.33467454839471, 
       3.451909718547078}}, {{6.33467454839471, 3.451909718547078}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}, {6.33467454839471, 3.451909718547078}, {
       6.33467454839471, 3.451909718547078}}, {{6.319749885066836, 
       3.517444916309843}, {6.33467454839471, 3.582980114072608}, {
       6.33467454839471, 3.582980114072608}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}}, {{
       6.319749885066836, 3.517444916309843}, {6.33467454839471, 
       3.582980114072608}, {6.33467454839471, 3.582980114072608}, {
       6.319749885066836, 3.517444916309843}, {6.319749885066836, 
       3.517444916309843}}, {{6.319749885066836, 3.517444916309843}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}, {6.319749885066836, 3.517444916309843}, {
       6.319749885066836, 3.517444916309843}}, {{6.319749885066836, 
       3.517444916309843}, {6.33467454839471, 3.582980114072608}, {
       6.33467454839471, 3.582980114072608}, {6.319749885066836, 
       3.517444916309843}, {6.319749885066836, 3.517444916309843}}, {{
       6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}}, {{6.33467454839471, 3.582980114072608}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}, {6.33467454839471, 3.582980114072608}, {
       6.33467454839471, 3.582980114072608}}, {{6.33467454839471, 
       3.582980114072608}, {6.395423413206291, 3.648515311835373}, {
       6.395423413206291, 3.648515311835373}, {6.33467454839471, 
       3.582980114072608}, {6.33467454839471, 3.582980114072608}}, {{
       6.33467454839471, 3.582980114072608}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}, {
       6.33467454839471, 3.582980114072608}, {6.33467454839471, 
       3.582980114072608}}, {{6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}, {6.622443997624657, 3.517444916309843}, {
       6.622443997624657, 3.517444916309843}}, {{6.622443997624657, 
       3.517444916309843}, {6.596063283925856, 3.4320672572505644`}, {
       6.596063283925856, 3.4320672572505644`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}}, {{
       6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}}, {{6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}, {6.622443997624657, 3.517444916309843}, {
       6.622443997624657, 3.517444916309843}}, {{6.596063283925856, 
       3.4320672572505644`}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}}, {{
       6.596063283925856, 3.4320672572505644`}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}, {
       6.596063283925856, 3.4320672572505644`}, {6.596063283925856, 
       3.4320672572505644`}}, {{6.596063283925856, 3.4320672572505644`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}, {6.596063283925856, 3.4320672572505644`}, {
       6.596063283925856, 3.4320672572505644`}}, {{6.596063283925856, 
       3.4320672572505644`}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}, {6.596063283925856, 
       3.4320672572505644`}, {6.596063283925856, 3.4320672572505644`}}, {{
       6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}, {{6.546770469485202, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.482552991716673, 
       3.3665320594877994`}, {6.546770469485202, 3.386374520784313}, {
       6.546770469485202, 3.386374520784313}}, {{6.546770469485202, 
       3.386374520784313}, {6.482552991716673, 3.3665320594877994`}, {
       6.482552991716673, 3.3665320594877994`}, {6.546770469485202, 
       3.386374520784313}, {6.546770469485202, 3.386374520784313}}, {{
       6.546770469485202, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}, {
       6.546770469485202, 3.386374520784313}, {6.546770469485202, 
       3.386374520784313}}, {{6.482552991716673, 3.3665320594877994`}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}, {6.482552991716673, 3.3665320594877994`}, {
       6.482552991716673, 3.3665320594877994`}}, {{6.482552991716673, 
       3.3665320594877994`}, {6.395423413206291, 3.386374520784313}, {
       6.395423413206291, 3.386374520784313}, {6.482552991716673, 
       3.3665320594877994`}, {6.482552991716673, 3.3665320594877994`}}, {{
       6.482552991716673, 3.3665320594877994`}, {6.395423413206291, 
       3.386374520784313}, {6.395423413206291, 3.386374520784313}, {
       6.482552991716673, 3.3665320594877994`}, {6.482552991716673, 
       3.3665320594877994`}}, {{6.482552991716673, 3.3665320594877994`}, {
       6.395423413206291, 3.386374520784313}, {6.395423413206291, 
       3.386374520784313}, {6.482552991716673, 3.3665320594877994`}, {
       6.482552991716673, 3.3665320594877994`}}, {{6.395423413206291, 
       3.648515311835373}, {6.482552991716673, 3.6683577731318864`}, {
       6.482552991716673, 3.6683577731318864`}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}}, {{
       6.395423413206291, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.482552991716673, 3.6683577731318864`}, {
       6.395423413206291, 3.648515311835373}, {6.395423413206291, 
       3.648515311835373}}, {{6.395423413206291, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}, {6.395423413206291, 3.648515311835373}, {
       6.395423413206291, 3.648515311835373}}, {{6.395423413206291, 
       3.648515311835373}, {6.482552991716673, 3.6683577731318864`}, {
       6.482552991716673, 3.6683577731318864`}, {6.395423413206291, 
       3.648515311835373}, {6.395423413206291, 3.648515311835373}}, {{
       6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}}, {{6.482552991716673, 3.6683577731318864`}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}, {6.482552991716673, 3.6683577731318864`}, {
       6.482552991716673, 3.6683577731318864`}}, {{6.482552991716673, 
       3.6683577731318864`}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}, {6.482552991716673, 
       3.6683577731318864`}, {6.482552991716673, 3.6683577731318864`}}, {{
       6.482552991716673, 3.6683577731318864`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}, {
       6.482552991716673, 3.6683577731318864`}, {6.482552991716673, 
       3.6683577731318864`}}, {{6.546770469485202, 3.648515311835373}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}}, {{6.546770469485202, 
       3.648515311835373}, {6.596063283925856, 3.6028225753691214`}, {
       6.596063283925856, 3.6028225753691214`}, {6.546770469485202, 
       3.648515311835373}, {6.546770469485202, 3.648515311835373}}, {{
       6.546770469485202, 3.648515311835373}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}, {
       6.546770469485202, 3.648515311835373}, {6.546770469485202, 
       3.648515311835373}}, {{6.546770469485202, 3.648515311835373}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}, {6.546770469485202, 3.648515311835373}, {
       6.546770469485202, 3.648515311835373}}, {{6.596063283925856, 
       3.6028225753691214`}, {6.622443997624657, 3.517444916309843}, {
       6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}}, {{
       6.596063283925856, 3.6028225753691214`}, {6.622443997624657, 
       3.517444916309843}, {6.622443997624657, 3.517444916309843}, {
       6.596063283925856, 3.6028225753691214`}, {6.596063283925856, 
       3.6028225753691214`}}, {{6.596063283925856, 3.6028225753691214`}, {
       6.622443997624657, 3.517444916309843}, {6.622443997624657, 
       3.517444916309843}, {6.596063283925856, 3.6028225753691214`}, {
       6.596063283925856, 3.6028225753691214`}}, {{6.596063283925856, 
       3.6028225753691214`}, {6.622443997624657, 3.517444916309843}, {
       6.622443997624657, 3.517444916309843}, {6.596063283925856, 
       3.6028225753691214`}, {6.596063283925856, 3.6028225753691214`}}, {{
       6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}, {{
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}, {{
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}, {{
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}, {{
       6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}, {{
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}, {{
       6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}, {{
       6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}, {{
       6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}, {{
       6.627425289564412, -4.404058749872826}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}}, {{
       6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}, {{
       6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}, {{
       6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}, {{
       6.562958672209687, -4.334512882134521}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.334512882134521}, {
       6.562958672209687, -4.334512882134521}}, {{
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}, {{
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}, {{
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}, {{
       6.54712063864494, -4.264967014396217}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}, {
       6.54712063864494, -4.264967014396217}, {
       6.54712063864494, -4.264967014396217}}, {{
       6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}, {{
       6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}, {{
       6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}, {{
       6.562958672209687, -4.195421146657913}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}, {
       6.562958672209687, -4.195421146657913}, {
       6.562958672209687, -4.195421146657913}}, {{
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}, {{
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}, {{
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}, {{
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}}, {{
       6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}, {{
       6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}, {{
       6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}, {{
       6.840344062810587, -4.355569676590611}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}, {
       6.840344062810587, -4.355569676590611}, {
       6.840344062810587, -4.355569676590611}}, {{
       6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}, {{
       6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}, {{
       6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}, {{
       6.788034591403356, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}, {
       6.788034591403356, -4.404058749872826}, {
       6.788034591403356, -4.404058749872826}}, {{
       6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}, {{
       6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}, {{
       6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}, {{
       6.719887086431378, -4.425115544328916}, {
       6.627425289564412, -4.404058749872826}, {
       6.627425289564412, -4.404058749872826}, {
       6.719887086431378, -4.425115544328916}, {
       6.719887086431378, -4.425115544328916}}, {{
       6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}, {{
       6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}, {{
       6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}, {{
       6.627425289564412, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}, {
       6.627425289564412, -4.125875278919608}, {
       6.627425289564412, -4.125875278919608}}, {{
       6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}, {{
       6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}, {{
       6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}, {{
       6.719887086431378, -4.104818484463518}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}, {
       6.719887086431378, -4.104818484463518}, {
       6.719887086431378, -4.104818484463518}}, {{
       6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}, {{
       6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}, {{
       6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}, {{
       6.788034591403356, -4.125875278919608}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}, {
       6.788034591403356, -4.125875278919608}, {
       6.788034591403356, -4.125875278919608}}, {{
       6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}, {{
       6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}, {{
       6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}, {{
       6.840344062810587, -4.174364352201823}, {
       6.868339242322828, -4.264967014396217}, {
       6.868339242322828, -4.264967014396217}, {
       6.840344062810587, -4.174364352201823}, {
       6.840344062810587, -4.174364352201823}}, {{
       6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.6075971854109765`}, {
       6.646835656073857, -3.6075971854109765`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}, {{
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}, {{
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.907815591164819}, {
       6.646835656073857, -3.907815591164819}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}, {{
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}, {{
       6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}, {{
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}, {{
       6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}, {{
       6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}, {{
       6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}, {{
       6.646835656073857, -3.9078155911648187`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}}, {{
       6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}, {{
       6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}, {{
       6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}, {{
       6.5772626328447625`, -3.832760989726358}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.832760989726358}, {
       6.5772626328447625`, -3.832760989726358}}, {{
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}, {{
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}, {{
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}, {{
       6.560170067385027, -3.7577063882878976`}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.560170067385027, -3.7577063882878976`}, {
       6.560170067385027, -3.7577063882878976`}}, {{
       6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}, {{
       6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}, {{
       6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}, {{
       6.5772626328447625`, -3.682651786849437}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}, {
       6.5772626328447625`, -3.682651786849437}, {
       6.5772626328447625`, -3.682651786849437}}, {{
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}, {{
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}, {{
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}, {{
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}}, {{
       6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}, {{
       6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}, {{
       6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}, {{
       6.876619742238273, -3.855485694541609}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.876619742238273, -3.855485694541609}, {
       6.876619742238273, -3.855485694541609}}, {{
       6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}, {{
       6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}, {{
       6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}, {{
       6.820166833451519, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.820166833451519, -3.9078155911648187`}, {
       6.820166833451519, -3.9078155911648187`}}, {{
       6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}, {{
       6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}, {{
       6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}, {{
       6.746621359205028, -3.9305402959800695`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.646835656073857, -3.9078155911648187`}, {
       6.746621359205028, -3.9305402959800695`}, {
       6.746621359205028, -3.9305402959800695`}}, {{
       6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}, {{
       6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}, {{
       6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}, {{
       6.646835656073857, -3.607597185410976}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.646835656073857, -3.607597185410976}, {
       6.646835656073857, -3.607597185410976}}, {{
       6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}, {{
       6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}, {{
       6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}, {{
       6.746621359205028, -3.5848724805957257`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.746621359205028, -3.5848724805957257`}, {
       6.746621359205028, -3.5848724805957257`}}, {{
       6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}, {{
       6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}, {{
       6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}, {{
       6.820166833451519, -3.6075971854109765`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.820166833451519, -3.6075971854109765`}, {
       6.820166833451519, -3.6075971854109765`}}, {{
       6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}, {{
       6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}, {{
       6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}, {{
       6.876619742238273, -3.6599270820341863`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.906832422140349, -3.7577063882878976`}, {
       6.876619742238273, -3.6599270820341863`}, {
       6.876619742238273, -3.6599270820341863`}}, {{
       6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}, {{
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}, {{
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}, {{
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}, {{
       6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}, {{
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}, {{
       6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}, {{
       6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}, {{
       6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}, {{
       6.662014836285836, -3.3719704710302962`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}}, {{
       6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}, {{
       6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}, {{
       6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}, {{
       6.5958528548853685`, -3.3005956634696227`}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.3005956634696227`}, {
       6.5958528548853685`, -3.3005956634696227`}}, {{
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}, {{
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}, {{
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}, {{
       6.57959830756881, -3.229220855908949}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.57959830756881, -3.229220855908949}, {
       6.57959830756881, -3.229220855908949}}, {{
       6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}, {{
       6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}, {{
       6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}, {{
       6.5958528548853685`, -3.157846048348275}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.5958528548853685`, -3.157846048348275}, {
       6.5958528548853685`, -3.157846048348275}}, {{
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}, {{
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}, {{
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}, {{
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}}, {{
       6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}, {{
       6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}, {{
       6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}, {{
       6.880533016599377, -3.322206216346804}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.880533016599377, -3.322206216346804}, {
       6.880533016599377, -3.322206216346804}}, {{
       6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}, {{
       6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}, {{
       6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}, {{
       6.826847893719886, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.826847893719886, -3.3719704710302962`}, {
       6.826847893719886, -3.3719704710302962`}}, {{
       6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}, {{
       6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}, {{
       6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}, {{
       6.756908223523839, -3.3935810239074775`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.662014836285836, -3.3719704710302962`}, {
       6.756908223523839, -3.3935810239074775`}, {
       6.756908223523839, -3.3935810239074775`}}, {{
       6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}, {{
       6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}, {{
       6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}, {{
       6.662014836285836, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}, {
       6.662014836285836, -3.0864712407876014`}, {
       6.662014836285836, -3.0864712407876014`}}, {{
       6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}, {{
       6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}, {{
       6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}, {{
       6.756908223523839, -3.06486068791042}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.756908223523839, -3.06486068791042}, {
       6.756908223523839, -3.06486068791042}}, {{
       6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}, {{
       6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}, {{
       6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}, {{
       6.826847893719886, -3.0864712407876014`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.826847893719886, -3.0864712407876014`}, {
       6.826847893719886, -3.0864712407876014`}}, {{
       6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}, {{
       6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}, {{
       6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}, {{
       6.880533016599377, -3.1362354954710936`}, {
       6.909264422436912, -3.229220855908949}, {
       6.909264422436912, -3.229220855908949}, {
       6.880533016599377, -3.1362354954710936`}, {
       6.880533016599377, -3.1362354954710936`}}, {{
       6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}, {{
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}, {{
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}, {{
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}, {{
       6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}, {{
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}, {{
       6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}, {{
       6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}, {{
       6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}, {{
       6.655137791326531, -2.904934927434726}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}}, {{
       6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}, {{
       6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}, {{
       6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}, {{
       6.590382478571581, -2.835077618318781}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.835077618318781}, {
       6.590382478571581, -2.835077618318781}}, {{
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}, {{
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}, {{
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}, {{
       6.574473518880624, -2.7652203092028365`}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}, {
       6.574473518880624, -2.7652203092028365`}, {
       6.574473518880624, -2.7652203092028365`}}, {{
       6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}, {{
       6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}, {{
       6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}, {{
       6.590382478571581, -2.695363000086892}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}, {
       6.590382478571581, -2.695363000086892}, {
       6.590382478571581, -2.695363000086892}}, {{
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}, {{
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}, {{
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}, {{
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}}, {{
       6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}, {{
       6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}, {{
       6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}, {{
       6.869010060707297, -2.856228709636602}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}, {
       6.869010060707297, -2.856228709636602}, {
       6.869010060707297, -2.856228709636602}}, {{
       6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}, {{
       6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}, {{
       6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}, {{
       6.816466336218346, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}, {
       6.816466336218346, -2.904934927434726}, {
       6.816466336218346, -2.904934927434726}}, {{
       6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}, {{
       6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}, {{
       6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}, {{
       6.748013652038437, -2.926086018752547}, {
       6.655137791326531, -2.904934927434726}, {
       6.655137791326531, -2.904934927434726}, {
       6.748013652038437, -2.926086018752547}, {
       6.748013652038437, -2.926086018752547}}, {{
       6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}, {{
       6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}, {{
       6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}, {{
       6.655137791326531, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}, {
       6.655137791326531, -2.625505690970947}, {
       6.655137791326531, -2.625505690970947}}, {{
       6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}, {{
       6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}, {{
       6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}, {{
       6.748013652038437, -2.604354599653126}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}, {
       6.748013652038437, -2.604354599653126}, {
       6.748013652038437, -2.604354599653126}}, {{
       6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}, {{
       6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}, {{
       6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}, {{
       6.816466336218346, -2.625505690970947}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.816466336218346, -2.625505690970947}, {
       6.816466336218346, -2.625505690970947}}, {{
       6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}, {{
       6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}, {{
       6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}, {{
       6.869010060707297, -2.6742119087690708`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.897130608664253, -2.7652203092028365`}, {
       6.869010060707297, -2.6742119087690708`}, {
       6.869010060707297, -2.6742119087690708`}}, {{
       6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}, {{
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}, {{
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}, {{
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}, {{
       6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}, {{
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}, {{
       6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}, {{
       6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}, {{
       6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}, {{
       6.7197968334671465`, -2.3439960876851895`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}}, {{
       6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}, {{
       6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}, {{
       6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}, {{
       6.659671399221255, -2.279133439862914}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.279133439862914}, {
       6.659671399221255, -2.279133439862914}}, {{
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}, {{
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}, {{
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}, {{
       6.644899899106061, -2.2142707920406384`}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}, {
       6.644899899106061, -2.2142707920406384`}, {
       6.644899899106061, -2.2142707920406384`}}, {{
       6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}, {{
       6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}, {{
       6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}, {{
       6.659671399221255, -2.149408144218363}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.659671399221255, -2.149408144218363}, {
       6.659671399221255, -2.149408144218363}}, {{
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}, {{
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}, {{
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}, {{
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}}, {{
       6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}, {{
       6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}, {{
       6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}, {{
       6.918377652902534, -2.298772269422289}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.918377652902534, -2.298772269422289}, {
       6.918377652902534, -2.298772269422289}}, {{
       6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}, {{
       6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}, {{
       6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}, {{
       6.869590702189317, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.869590702189317, -2.3439960876851895`}, {
       6.869590702189317, -2.3439960876851895`}}, {{
       6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}, {{
       6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}, {{
       6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}, {{
       6.806032251360906, -2.3636349172445645`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.7197968334671465`, -2.3439960876851895`}, {
       6.806032251360906, -2.3636349172445645`}, {
       6.806032251360906, -2.3636349172445645`}}, {{
       6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}, {{
       6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}, {{
       6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}, {{
       6.7197968334671465`, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}, {
       6.7197968334671465`, -2.084545496396087}, {
       6.7197968334671465`, -2.084545496396087}}, {{
       6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}, {{
       6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}, {{
       6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}, {{
       6.806032251360906, -2.064906666836712}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}, {
       6.806032251360906, -2.064906666836712}, {
       6.806032251360906, -2.064906666836712}}, {{
       6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}, {{
       6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}, {{
       6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}, {{
       6.869590702189317, -2.084545496396087}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.869590702189317, -2.084545496396087}, {
       6.869590702189317, -2.084545496396087}}, {{
       6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}, {{
       6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}, {{
       6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}, {{
       6.918377652902534, -2.1297693146589878`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.944487636550402, -2.2142707920406384`}, {
       6.918377652902534, -2.1297693146589878`}, {
       6.918377652902534, -2.1297693146589878`}}, {{
       6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506884`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}, {{
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}, {{
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}, {{
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}, {{
       6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}, {{
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}, {{
       6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}, {{
       6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}, {{
       6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}, {{
       6.644829404856591, -1.8659356759259005`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}}, {{
       6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}, {{
       6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}, {{
       6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}, {{
       6.588228779808851, -1.8048755529506881`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.8048755529506881`}, {
       6.588228779808851, -1.8048755529506881`}}, {{
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}, {{
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}, {{
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}, {{
       6.57432324798361, -1.743815429975476}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.588228779808851, -1.6827553070002639`}, {
       6.57432324798361, -1.743815429975476}, {
       6.57432324798361, -1.743815429975476}}, {{
       6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}, {{
       6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}, {{
       6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}, {{
       6.588228779808851, -1.6827553070002637`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.588228779808851, -1.6827553070002637`}, {
       6.588228779808851, -1.6827553070002637`}}, {{
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}, {{
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}, {{
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}, {{
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}}, {{
       6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}, {{
       6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}, {{
       6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}, {{
       6.831768570344668, -1.823363070624502}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.831768570344668, -1.823363070624502}, {
       6.831768570344668, -1.823363070624502}}, {{
       6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}, {{
       6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}, {{
       6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}, {{
       6.785841718602553, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.785841718602553, -1.8659356759259005`}, {
       6.785841718602553, -1.8659356759259005`}}, {{
       6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}, {{
       6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}, {{
       6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}, {{
       6.726009335035196, -1.8844231935997144`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.644829404856591, -1.8659356759259005`}, {
       6.726009335035196, -1.8844231935997144`}, {
       6.726009335035196, -1.8844231935997144`}}, {{
       6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}, {{
       6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}, {{
       6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}, {{
       6.644829404856591, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.644829404856591, -1.6216951840250515`}, {
       6.644829404856591, -1.6216951840250515`}}, {{
       6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}, {{
       6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}, {{
       6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}, {{
       6.726009335035196, -1.6032076663512376`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.726009335035196, -1.6032076663512376`}, {
       6.726009335035196, -1.6032076663512376`}}, {{
       6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}, {{
       6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}, {{
       6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}, {{
       6.785841718602553, -1.6216951840250515`}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}, {
       6.785841718602553, -1.6216951840250515`}, {
       6.785841718602553, -1.6216951840250515`}}, {{
       6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}, {{
       6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}, {{
       6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}, {{
       6.831768570344668, -1.66426778932645}, {
       6.856347875475533, -1.743815429975476}, {
       6.856347875475533, -1.743815429975476}, {
       6.831768570344668, -1.66426778932645}, {
       6.831768570344668, -1.66426778932645}}, {{
       6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}, {{
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}, {{
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}, {{
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}, {{
       6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}, {{
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}, {{
       6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}, {{
       6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}, {{
       6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}, {{
       6.706694731648507, -1.4186431363003453`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}}, {{
       6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}, {{
       6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}, {{
       6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}, {{
       6.649063429878147, -1.3564711307729922`}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.3564711307729922`}, {
       6.649063429878147, -1.3564711307729922`}}, {{
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}, {{
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}, {{
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}, {{
       6.6349046833939544`, -1.294299125245639}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}, {
       6.6349046833939544`, -1.294299125245639}, {
       6.6349046833939544`, -1.294299125245639}}, {{
       6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}, {{
       6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}, {{
       6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}, {{
       6.649063429878147, -1.232127119718286}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.649063429878147, -1.232127119718286}, {
       6.649063429878147, -1.232127119718286}}, {{
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}, {{
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}, {{
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}, {{
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}}, {{
       6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}, {{
       6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}, {{
       6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}, {{
       6.897037991106429, -1.3752952993956136`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.897037991106429, -1.3752952993956136`}, {
       6.897037991106429, -1.3752952993956136`}}, {{
       6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}, {{
       6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}, {{
       6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}, {{
       6.850274828157612, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.850274828157612, -1.4186431363003453`}, {
       6.850274828157612, -1.4186431363003453`}}, {{
       6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}, {{
       6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}, {{
       6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}, {{
       6.7893529187246004`, -1.4374673049229667`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.706694731648507, -1.4186431363003453`}, {
       6.7893529187246004`, -1.4374673049229667`}, {
       6.7893529187246004`, -1.4374673049229667`}}, {{
       6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}, {{
       6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}, {{
       6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}, {{
       6.706694731648507, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.706694731648507, -1.1699551141909328`}, {
       6.706694731648507, -1.1699551141909328`}}, {{
       6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}, {{
       6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}, {{
       6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}, {{
       6.7893529187246004`, -1.1511309455683114`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.7893529187246004`, -1.1511309455683114`}, {
       6.7893529187246004`, -1.1511309455683114`}}, {{
       6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}, {{
       6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}, {{
       6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}, {{
       6.850274828157612, -1.1699551141909328`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.850274828157612, -1.1699551141909328`}, {
       6.850274828157612, -1.1699551141909328`}}, {{
       6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}, {{
       6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}, {{
       6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}, {{
       6.897037991106429, -1.2133029510956646`}, {
       6.922064876412164, -1.294299125245639}, {
       6.922064876412164, -1.294299125245639}, {
       6.897037991106429, -1.2133029510956646`}, {
       6.897037991106429, -1.2133029510956646`}}, {{
       6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}, {{
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}, {{
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}, {{
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}, {{
       6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}, {{
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}, {{
       6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}, {{
       6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}, {{
       6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}, {{
       6.69243299082192, -0.9243107442404005}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}}, {{
       6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}, {{
       6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}, {{
       6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}, {{
       6.634014740121302, -0.8612897869847532}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.8612897869847532}, {
       6.634014740121302, -0.8612897869847532}}, {{
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}, {{
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}, {{
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}, {{
       6.6196626575496476`, -0.798268829729106}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}, {
       6.6196626575496476`, -0.798268829729106}, {
       6.6196626575496476`, -0.798268829729106}}, {{
       6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}, {{
       6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}, {{
       6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}, {{
       6.634014740121302, -0.7352478724734587}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}, {
       6.634014740121302, -0.7352478724734587}, {
       6.634014740121302, -0.7352478724734587}}, {{
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}, {{
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}, {{
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}, {{
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}}, {{
       6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}, {{
       6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}, {{
       6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}, {{
       6.88537536603484, -0.8803709975083126}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.88537536603484, -0.8803709975083126}, {
       6.88537536603484, -0.8803709975083126}}, {{
       6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}, {{
       6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}, {{
       6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}, {{
       6.8379736573664625`, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}, {
       6.8379736573664625`, -0.9243107442404005}, {
       6.8379736573664625`, -0.9243107442404005}}, {{
       6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}, {{
       6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}, {{
       6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}, {{
       6.776219866126432, -0.9433919547639599}, {
       6.69243299082192, -0.9243107442404005}, {
       6.69243299082192, -0.9243107442404005}, {
       6.776219866126432, -0.9433919547639599}, {
       6.776219866126432, -0.9433919547639599}}, {{
       6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}, {{
       6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}, {{
       6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}, {{
       6.69243299082192, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}, {
       6.69243299082192, -0.6722269152178114}, {
       6.69243299082192, -0.6722269152178114}}, {{
       6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}, {{
       6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}, {{
       6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}, {{
       6.776219866126432, -0.653145704694252}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.776219866126432, -0.653145704694252}, {
       6.776219866126432, -0.653145704694252}}, {{
       6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}, {{
       6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}, {{
       6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}, {{
       6.8379736573664625`, -0.6722269152178114}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}, {
       6.8379736573664625`, -0.6722269152178114}, {
       6.8379736573664625`, -0.6722269152178114}}, {{
       6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}, {{
       6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}, {{
       6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}, {{
       6.88537536603484, -0.7161666619498993}, {
       6.910743990638735, -0.798268829729106}, {
       6.910743990638735, -0.798268829729106}, {
       6.88537536603484, -0.7161666619498993}, {
       6.88537536603484, -0.7161666619498993}}, {{
       6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947431}, {
       6.626169087862926, -0.09196413059947431}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495338}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}, {{
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}, {{
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}, {{
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}, {{
       6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618056`}, {
       6.873925795705952, -0.23500653256618056`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}, {{
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}, {{
       6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}, {{
       6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}, {{
       6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}, {{
       6.626169087862926, -0.3780489345328869}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}}, {{
       6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}, {{
       6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}, {{
       6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}, {{
       6.559871404815905, -0.3065277335495337}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.3065277335495337}, {
       6.559871404815905, -0.3065277335495337}}, {{
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}, {{
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}, {{
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}, {{
       6.543583518581918, -0.2350065325661806}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.559871404815905, -0.16348533158282746`}, {
       6.543583518581918, -0.2350065325661806}, {
       6.543583518581918, -0.2350065325661806}}, {{
       6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}, {{
       6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}, {{
       6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}, {{
       6.559871404815905, -0.16348533158282744`}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}, {
       6.559871404815905, -0.16348533158282744`}, {
       6.559871404815905, -0.16348533158282744`}}, {{
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}, {{
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}, {{
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}, {{
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}}, {{
       6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}, {{
       6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}, {{
       6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}, {{
       6.845135460268706, -0.32818261078862665`}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}, {
       6.845135460268706, -0.32818261078862665`}, {
       6.845135460268706, -0.32818261078862665`}}, {{
       6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}, {{
       6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}, {{
       6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}, {{
       6.791340226424944, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}, {
       6.791340226424944, -0.3780489345328869}, {
       6.791340226424944, -0.3780489345328869}}, {{
       6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}, {{
       6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}, {{
       6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}, {{
       6.721257106347193, -0.3997038117719798}, {
       6.626169087862926, -0.3780489345328869}, {
       6.626169087862926, -0.3780489345328869}, {
       6.721257106347193, -0.3997038117719798}, {
       6.721257106347193, -0.3997038117719798}}, {{
       6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}, {{
       6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}, {{
       6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}, {{
       6.626169087862926, -0.09196413059947428}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}, {
       6.626169087862926, -0.09196413059947428}, {
       6.626169087862926, -0.09196413059947428}}, {{
       6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}, {{
       6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}, {{
       6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}, {{
       6.721257106347193, -0.07030925336038141}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}, {
       6.721257106347193, -0.07030925336038141}, {
       6.721257106347193, -0.07030925336038141}}, {{
       6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}, {{
       6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}, {{
       6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}, {{
       6.791340226424944, -0.09196413059947431}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.791340226424944, -0.09196413059947431}, {
       6.791340226424944, -0.09196413059947431}}, {{
       6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}, {{
       6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}, {{
       6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}, {{
       6.845135460268706, -0.14183045434373456`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.873925795705952, -0.23500653256618062`}, {
       6.845135460268706, -0.14183045434373456`}, {
       6.845135460268706, -0.14183045434373456`}}, {{6.668106860191438, 
       0.09923453595851475}, {6.603652804810594, 0.16876685197951424`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.30783148402151317`}, {6.668106860191438, 0.3773638000425127}, {
       6.668106860191438, 0.3773638000425127}, {6.603652804810594, 
       0.30783148402151317`}, {6.5878178574472335`, 0.2382991680005137}, {
       6.603652804810594, 0.16876685197951422`}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}}, {{
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}}, {{6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.14771416065327353`}, {6.828684865679847, 
       0.09923453595851475}, {6.760550639940013, 0.07818184463227407}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}, {6.760550639940013, 0.07818184463227407}, {
       6.828684865679847, 0.09923453595851475}, {6.88098414405632, 
       0.14771416065327353`}, {6.908973868424051, 0.23829916800051368`}, {
       6.908973868424051, 0.23829916800051368`}}, {{6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}}, {{
       6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.828684865679847, 0.3773638000425127}, {
       6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051373`}, {6.908973868424051, 0.23829916800051373`}, {
       6.88098414405632, 0.3288841753477539}, {6.828684865679847, 
       0.3773638000425127}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}, {{6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}}, {{6.668106860191438, 
       0.09923453595851475}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}}, {{
       6.668106860191438, 0.09923453595851475}, {6.603652804810594, 
       0.16876685197951424`}, {6.603652804810594, 0.16876685197951424`}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}}, {{6.668106860191438, 0.09923453595851475}, {
       6.603652804810594, 0.16876685197951424`}, {6.603652804810594, 
       0.16876685197951424`}, {6.668106860191438, 0.09923453595851475}, {
       6.668106860191438, 0.09923453595851475}}, {{6.668106860191438, 
       0.09923453595851475}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}}, {{
       6.603652804810594, 0.16876685197951424`}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.603652804810594, 0.16876685197951424`}, {6.603652804810594, 
       0.16876685197951424`}}, {{6.603652804810594, 0.16876685197951424`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.16876685197951424`}, {
       6.603652804810594, 0.16876685197951424`}}, {{6.603652804810594, 
       0.16876685197951424`}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.16876685197951424`}, {6.603652804810594, 0.16876685197951424`}}, {{
       6.603652804810594, 0.16876685197951424`}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}, {
       6.603652804810594, 0.16876685197951424`}, {6.603652804810594, 
       0.16876685197951424`}}, {{6.5878178574472335`, 0.2382991680005137}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}}, {{6.5878178574472335`, 
       0.2382991680005137}, {6.603652804810594, 0.30783148402151317`}, {
       6.603652804810594, 0.30783148402151317`}, {6.5878178574472335`, 
       0.2382991680005137}, {6.5878178574472335`, 0.2382991680005137}}, {{
       6.5878178574472335`, 0.2382991680005137}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}, {
       6.5878178574472335`, 0.2382991680005137}, {6.5878178574472335`, 
       0.2382991680005137}}, {{6.5878178574472335`, 0.2382991680005137}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}, {6.5878178574472335`, 0.2382991680005137}, {
       6.5878178574472335`, 0.2382991680005137}}, {{6.603652804810594, 
       0.30783148402151317`}, {6.668106860191438, 0.3773638000425127}, {
       6.668106860191438, 0.3773638000425127}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}}, {{
       6.603652804810594, 0.30783148402151317`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}, {
       6.603652804810594, 0.30783148402151317`}, {6.603652804810594, 
       0.30783148402151317`}}, {{6.603652804810594, 0.30783148402151317`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}, {6.603652804810594, 0.30783148402151317`}, {
       6.603652804810594, 0.30783148402151317`}}, {{6.603652804810594, 
       0.30783148402151317`}, {6.668106860191438, 0.3773638000425127}, {
       6.668106860191438, 0.3773638000425127}, {6.603652804810594, 
       0.30783148402151317`}, {6.603652804810594, 0.30783148402151317`}}, {{
       6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}, {{6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.14771416065327353`}, {6.88098414405632, 
       0.14771416065327353`}, {6.908973868424051, 0.23829916800051368`}, {
       6.908973868424051, 0.23829916800051368`}}, {{6.908973868424051, 
       0.23829916800051368`}, {6.88098414405632, 0.14771416065327353`}, {
       6.88098414405632, 0.14771416065327353`}, {6.908973868424051, 
       0.23829916800051368`}, {6.908973868424051, 0.23829916800051368`}}, {{
       6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}}, {{6.88098414405632, 0.14771416065327353`}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.88098414405632, 0.14771416065327353`}, {
       6.88098414405632, 0.14771416065327353`}}, {{6.88098414405632, 
       0.14771416065327353`}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}, {6.88098414405632, 
       0.14771416065327353`}, {6.88098414405632, 0.14771416065327353`}}, {{
       6.88098414405632, 0.14771416065327353`}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}, {
       6.88098414405632, 0.14771416065327353`}, {6.88098414405632, 
       0.14771416065327353`}}, {{6.88098414405632, 0.14771416065327353`}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}, {6.88098414405632, 0.14771416065327353`}, {
       6.88098414405632, 0.14771416065327353`}}, {{6.828684865679847, 
       0.09923453595851475}, {6.760550639940013, 0.07818184463227407}, {
       6.760550639940013, 0.07818184463227407}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}}, {{
       6.828684865679847, 0.09923453595851475}, {6.760550639940013, 
       0.07818184463227407}, {6.760550639940013, 0.07818184463227407}, {
       6.828684865679847, 0.09923453595851475}, {6.828684865679847, 
       0.09923453595851475}}, {{6.828684865679847, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}, {6.828684865679847, 0.09923453595851475}, {
       6.828684865679847, 0.09923453595851475}}, {{6.828684865679847, 
       0.09923453595851475}, {6.760550639940013, 0.07818184463227407}, {
       6.760550639940013, 0.07818184463227407}, {6.828684865679847, 
       0.09923453595851475}, {6.828684865679847, 0.09923453595851475}}, {{
       6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}}, {{6.760550639940013, 0.07818184463227407}, {
       6.668106860191438, 0.09923453595851475}, {6.668106860191438, 
       0.09923453595851475}, {6.760550639940013, 0.07818184463227407}, {
       6.760550639940013, 0.07818184463227407}}, {{6.760550639940013, 
       0.07818184463227407}, {6.668106860191438, 0.09923453595851475}, {
       6.668106860191438, 0.09923453595851475}, {6.760550639940013, 
       0.07818184463227407}, {6.760550639940013, 0.07818184463227407}}, {{
       6.760550639940013, 0.07818184463227407}, {6.668106860191438, 
       0.09923453595851475}, {6.668106860191438, 0.09923453595851475}, {
       6.760550639940013, 0.07818184463227407}, {6.760550639940013, 
       0.07818184463227407}}, {{6.668106860191438, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}, {6.668106860191438, 0.3773638000425127}, {
       6.668106860191438, 0.3773638000425127}}, {{6.668106860191438, 
       0.3773638000425127}, {6.760550639940013, 0.39841649136875334`}, {
       6.760550639940013, 0.39841649136875334`}, {6.668106860191438, 
       0.3773638000425127}, {6.668106860191438, 0.3773638000425127}}, {{
       6.668106860191438, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}, {
       6.668106860191438, 0.3773638000425127}, {6.668106860191438, 
       0.3773638000425127}}, {{6.668106860191438, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}, {6.668106860191438, 0.3773638000425127}, {
       6.668106860191438, 0.3773638000425127}}, {{6.760550639940013, 
       0.39841649136875334`}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}}, {{
       6.760550639940013, 0.39841649136875334`}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}, {
       6.760550639940013, 0.39841649136875334`}, {6.760550639940013, 
       0.39841649136875334`}}, {{6.760550639940013, 0.39841649136875334`}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}, {6.760550639940013, 0.39841649136875334`}, {
       6.760550639940013, 0.39841649136875334`}}, {{6.760550639940013, 
       0.39841649136875334`}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}, {6.760550639940013, 
       0.39841649136875334`}, {6.760550639940013, 0.39841649136875334`}}, {{
       6.828684865679847, 0.3773638000425127}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}, {{6.828684865679847, 0.3773638000425127}, {
       6.88098414405632, 0.3288841753477539}, {6.88098414405632, 
       0.3288841753477539}, {6.828684865679847, 0.3773638000425127}, {
       6.828684865679847, 0.3773638000425127}}, {{6.828684865679847, 
       0.3773638000425127}, {6.88098414405632, 0.3288841753477539}, {
       6.88098414405632, 0.3288841753477539}, {6.828684865679847, 
       0.3773638000425127}, {6.828684865679847, 0.3773638000425127}}, {{
       6.828684865679847, 0.3773638000425127}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}, {
       6.828684865679847, 0.3773638000425127}, {6.828684865679847, 
       0.3773638000425127}}, {{6.88098414405632, 0.3288841753477539}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}, {6.88098414405632, 0.3288841753477539}, {
       6.88098414405632, 0.3288841753477539}}, {{6.88098414405632, 
       0.3288841753477539}, {6.908973868424051, 0.23829916800051368`}, {
       6.908973868424051, 0.23829916800051368`}, {6.88098414405632, 
       0.3288841753477539}, {6.88098414405632, 0.3288841753477539}}, {{
       6.88098414405632, 0.3288841753477539}, {6.908973868424051, 
       0.23829916800051368`}, {6.908973868424051, 0.23829916800051368`}, {
       6.88098414405632, 0.3288841753477539}, {6.88098414405632, 
       0.3288841753477539}}, {{6.88098414405632, 0.3288841753477539}, {
       6.908973868424051, 0.23829916800051368`}, {6.908973868424051, 
       0.23829916800051368`}, {6.88098414405632, 0.3288841753477539}, {
       6.88098414405632, 0.3288841753477539}}, {{6.681704815183866, 
       0.5905561819630012}, {6.6113363078012855`, 0.6664689428333709}, {
       6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.8182944645741103}, {6.681704815183866, 0.89420722544448}, {
       6.681704815183866, 0.89420722544448}, {6.6113363078012855`, 
       0.8182944645741103}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}}, {{
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}, {{6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.6434844082488482}, {6.857017826877608, 
       0.5905561819630012}, {6.782631448260309, 0.5675716473784785}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}, {6.782631448260309, 0.5675716473784785}, {
       6.857017826877608, 0.5905561819630012}, {6.914116207030617, 
       0.6434844082488482}, {6.94467433272448, 0.7423817037037406}, {
       6.94467433272448, 0.7423817037037406}}, {{6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}}, {{
       6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.857017826877608, 0.89420722544448}, {
       6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.857017826877608, 
       0.89420722544448}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}, {{6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}}, {{6.681704815183866, 
       0.5905561819630012}, {6.6113363078012855`, 0.6664689428333709}, {
       6.6113363078012855`, 0.6664689428333709}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}}, {{
       6.681704815183866, 0.5905561819630012}, {6.6113363078012855`, 
       0.6664689428333709}, {6.6113363078012855`, 0.6664689428333709}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}}, {{6.681704815183866, 0.5905561819630012}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}, {6.681704815183866, 0.5905561819630012}, {
       6.681704815183866, 0.5905561819630012}}, {{6.681704815183866, 
       0.5905561819630012}, {6.6113363078012855`, 0.6664689428333709}, {
       6.6113363078012855`, 0.6664689428333709}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}}, {{
       6.6113363078012855`, 0.6664689428333709}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}}, {{6.6113363078012855`, 0.6664689428333709}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}, {6.6113363078012855`, 0.6664689428333709}, {
       6.6113363078012855`, 0.6664689428333709}}, {{6.6113363078012855`, 
       0.6664689428333709}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.6664689428333709}, {6.6113363078012855`, 0.6664689428333709}}, {{
       6.6113363078012855`, 0.6664689428333709}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.6664689428333709}, {6.6113363078012855`, 
       0.6664689428333709}}, {{6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}}, {{6.594048309336994, 
       0.7423817037037406}, {6.6113363078012855`, 0.8182944645741103}, {
       6.6113363078012855`, 0.8182944645741103}, {6.594048309336994, 
       0.7423817037037406}, {6.594048309336994, 0.7423817037037406}}, {{
       6.594048309336994, 0.7423817037037406}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}, {
       6.594048309336994, 0.7423817037037406}, {6.594048309336994, 
       0.7423817037037406}}, {{6.594048309336994, 0.7423817037037406}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}, {6.594048309336994, 0.7423817037037406}, {
       6.594048309336994, 0.7423817037037406}}, {{6.6113363078012855`, 
       0.8182944645741103}, {6.681704815183866, 0.89420722544448}, {
       6.681704815183866, 0.89420722544448}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}}, {{
       6.6113363078012855`, 0.8182944645741103}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}, {
       6.6113363078012855`, 0.8182944645741103}, {6.6113363078012855`, 
       0.8182944645741103}}, {{6.6113363078012855`, 0.8182944645741103}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}, {6.6113363078012855`, 0.8182944645741103}, {
       6.6113363078012855`, 0.8182944645741103}}, {{6.6113363078012855`, 
       0.8182944645741103}, {6.681704815183866, 0.89420722544448}, {
       6.681704815183866, 0.89420722544448}, {6.6113363078012855`, 
       0.8182944645741103}, {6.6113363078012855`, 0.8182944645741103}}, {{
       6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}, {{6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.6434844082488482}, {6.914116207030617, 
       0.6434844082488482}, {6.94467433272448, 0.7423817037037406}, {
       6.94467433272448, 0.7423817037037406}}, {{6.94467433272448, 
       0.7423817037037406}, {6.914116207030617, 0.6434844082488482}, {
       6.914116207030617, 0.6434844082488482}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}}, {{
       6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}}, {{6.914116207030617, 0.6434844082488482}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.914116207030617, 0.6434844082488482}, {
       6.914116207030617, 0.6434844082488482}}, {{6.914116207030617, 
       0.6434844082488482}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}, {6.914116207030617, 
       0.6434844082488482}, {6.914116207030617, 0.6434844082488482}}, {{
       6.914116207030617, 0.6434844082488482}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}, {
       6.914116207030617, 0.6434844082488482}, {6.914116207030617, 
       0.6434844082488482}}, {{6.914116207030617, 0.6434844082488482}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}, {6.914116207030617, 0.6434844082488482}, {
       6.914116207030617, 0.6434844082488482}}, {{6.857017826877608, 
       0.5905561819630012}, {6.782631448260309, 0.5675716473784785}, {
       6.782631448260309, 0.5675716473784785}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}}, {{
       6.857017826877608, 0.5905561819630012}, {6.782631448260309, 
       0.5675716473784785}, {6.782631448260309, 0.5675716473784785}, {
       6.857017826877608, 0.5905561819630012}, {6.857017826877608, 
       0.5905561819630012}}, {{6.857017826877608, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}, {6.857017826877608, 0.5905561819630012}, {
       6.857017826877608, 0.5905561819630012}}, {{6.857017826877608, 
       0.5905561819630012}, {6.782631448260309, 0.5675716473784785}, {
       6.782631448260309, 0.5675716473784785}, {6.857017826877608, 
       0.5905561819630012}, {6.857017826877608, 0.5905561819630012}}, {{
       6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}}, {{6.782631448260309, 0.5675716473784785}, {
       6.681704815183866, 0.5905561819630012}, {6.681704815183866, 
       0.5905561819630012}, {6.782631448260309, 0.5675716473784785}, {
       6.782631448260309, 0.5675716473784785}}, {{6.782631448260309, 
       0.5675716473784785}, {6.681704815183866, 0.5905561819630012}, {
       6.681704815183866, 0.5905561819630012}, {6.782631448260309, 
       0.5675716473784785}, {6.782631448260309, 0.5675716473784785}}, {{
       6.782631448260309, 0.5675716473784785}, {6.681704815183866, 
       0.5905561819630012}, {6.681704815183866, 0.5905561819630012}, {
       6.782631448260309, 0.5675716473784785}, {6.782631448260309, 
       0.5675716473784785}}, {{6.681704815183866, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}, {6.681704815183866, 0.89420722544448}, {
       6.681704815183866, 0.89420722544448}}, {{6.681704815183866, 
       0.89420722544448}, {6.782631448260309, 0.9171917600290026}, {
       6.782631448260309, 0.9171917600290026}, {6.681704815183866, 
       0.89420722544448}, {6.681704815183866, 0.89420722544448}}, {{
       6.681704815183866, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}, {
       6.681704815183866, 0.89420722544448}, {6.681704815183866, 
       0.89420722544448}}, {{6.681704815183866, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}, {6.681704815183866, 0.89420722544448}, {
       6.681704815183866, 0.89420722544448}}, {{6.782631448260309, 
       0.9171917600290026}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}}, {{
       6.782631448260309, 0.9171917600290026}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}, {
       6.782631448260309, 0.9171917600290026}, {6.782631448260309, 
       0.9171917600290026}}, {{6.782631448260309, 0.9171917600290026}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}, {6.782631448260309, 0.9171917600290026}, {
       6.782631448260309, 0.9171917600290026}}, {{6.782631448260309, 
       0.9171917600290026}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}, {6.782631448260309, 
       0.9171917600290026}, {6.782631448260309, 0.9171917600290026}}, {{
       6.857017826877608, 0.89420722544448}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}, {{6.857017826877608, 0.89420722544448}, {
       6.914116207030617, 0.8412789991586329}, {6.914116207030617, 
       0.8412789991586329}, {6.857017826877608, 0.89420722544448}, {
       6.857017826877608, 0.89420722544448}}, {{6.857017826877608, 
       0.89420722544448}, {6.914116207030617, 0.8412789991586329}, {
       6.914116207030617, 0.8412789991586329}, {6.857017826877608, 
       0.89420722544448}, {6.857017826877608, 0.89420722544448}}, {{
       6.857017826877608, 0.89420722544448}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}, {
       6.857017826877608, 0.89420722544448}, {6.857017826877608, 
       0.89420722544448}}, {{6.914116207030617, 0.8412789991586329}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}, {6.914116207030617, 0.8412789991586329}, {
       6.914116207030617, 0.8412789991586329}}, {{6.914116207030617, 
       0.8412789991586329}, {6.94467433272448, 0.7423817037037406}, {
       6.94467433272448, 0.7423817037037406}, {6.914116207030617, 
       0.8412789991586329}, {6.914116207030617, 0.8412789991586329}}, {{
       6.914116207030617, 0.8412789991586329}, {6.94467433272448, 
       0.7423817037037406}, {6.94467433272448, 0.7423817037037406}, {
       6.914116207030617, 0.8412789991586329}, {6.914116207030617, 
       0.8412789991586329}}, {{6.914116207030617, 0.8412789991586329}, {
       6.94467433272448, 0.7423817037037406}, {6.94467433272448, 
       0.7423817037037406}, {6.914116207030617, 0.8412789991586329}, {
       6.914116207030617, 0.8412789991586329}}, {{6.645838323647305, 
       1.1297603572391623`}, {6.580443740183912, 1.2003073044649166`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912, 
       1.3414011989164247`}, {6.645838323647305, 1.411948146142179}, {
       6.645838323647305, 1.411948146142179}, {6.580443740183912, 
       1.3414011989164247`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}}, {{
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}}, {{6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.1789474075285935`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.739631063835945, 1.1084004603028395`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}, {6.739631063835945, 1.1084004603028395`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.861821960749832, 
       1.1789474075285935`}, {6.890220117475078, 1.2708542516906707`}, {
       6.890220117475078, 1.2708542516906707`}}, {{6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}}, {{
       6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.8087595195324875`, 1.411948146142179}, {
       6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.8087595195324875`, 
       1.411948146142179}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}, {{6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}}, {{6.645838323647305, 
       1.1297603572391623`}, {6.580443740183912, 1.2003073044649166`}, {
       6.580443740183912, 1.2003073044649166`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}}, {{
       6.645838323647305, 1.1297603572391623`}, {6.580443740183912, 
       1.2003073044649166`}, {6.580443740183912, 1.2003073044649166`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}}, {{6.645838323647305, 1.1297603572391623`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}, {6.645838323647305, 1.1297603572391623`}, {
       6.645838323647305, 1.1297603572391623`}}, {{6.645838323647305, 
       1.1297603572391623`}, {6.580443740183912, 1.2003073044649166`}, {
       6.580443740183912, 1.2003073044649166`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}}, {{
       6.580443740183912, 1.2003073044649166`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}}, {{6.580443740183912, 1.2003073044649166`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.580443740183912, 1.2003073044649166`}, {
       6.580443740183912, 1.2003073044649166`}}, {{6.580443740183912, 
       1.2003073044649166`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912, 
       1.2003073044649166`}, {6.580443740183912, 1.2003073044649166`}}, {{
       6.580443740183912, 1.2003073044649166`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.2003073044649166`}, {6.580443740183912, 
       1.2003073044649166`}}, {{6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}}, {{6.5643777257047145`, 
       1.2708542516906707`}, {6.580443740183912, 1.3414011989164247`}, {
       6.580443740183912, 1.3414011989164247`}, {6.5643777257047145`, 
       1.2708542516906707`}, {6.5643777257047145`, 1.2708542516906707`}}, {{
       6.5643777257047145`, 1.2708542516906707`}, {6.580443740183912, 
       1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}, {
       6.5643777257047145`, 1.2708542516906707`}, {6.5643777257047145`, 
       1.2708542516906707`}}, {{6.5643777257047145`, 1.2708542516906707`}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}, {6.5643777257047145`, 1.2708542516906707`}, {
       6.5643777257047145`, 1.2708542516906707`}}, {{6.580443740183912, 
       1.3414011989164247`}, {6.645838323647305, 1.411948146142179}, {
       6.645838323647305, 1.411948146142179}, {6.580443740183912, 
       1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}}, {{
       6.580443740183912, 1.3414011989164247`}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}, {
       6.580443740183912, 1.3414011989164247`}, {6.580443740183912, 
       1.3414011989164247`}}, {{6.580443740183912, 1.3414011989164247`}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}, {6.580443740183912, 1.3414011989164247`}, {
       6.580443740183912, 1.3414011989164247`}}, {{6.580443740183912, 
       1.3414011989164247`}, {6.645838323647305, 1.411948146142179}, {
       6.645838323647305, 1.411948146142179}, {6.580443740183912, 
       1.3414011989164247`}, {6.580443740183912, 1.3414011989164247`}}, {{
       6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}, {{6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.1789474075285935`}, {6.861821960749832, 
       1.1789474075285935`}, {6.890220117475078, 1.2708542516906707`}, {
       6.890220117475078, 1.2708542516906707`}}, {{6.890220117475078, 
       1.2708542516906707`}, {6.861821960749832, 1.1789474075285935`}, {
       6.861821960749832, 1.1789474075285935`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}}, {{
       6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}}, {{6.861821960749832, 1.1789474075285935`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.861821960749832, 1.1789474075285935`}, {
       6.861821960749832, 1.1789474075285935`}}, {{6.861821960749832, 
       1.1789474075285935`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.861821960749832, 
       1.1789474075285935`}, {6.861821960749832, 1.1789474075285935`}}, {{
       6.861821960749832, 1.1789474075285935`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.861821960749832, 1.1789474075285935`}, {6.861821960749832, 
       1.1789474075285935`}}, {{6.861821960749832, 1.1789474075285935`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.861821960749832, 1.1789474075285935`}, {
       6.861821960749832, 1.1789474075285935`}}, {{6.8087595195324875`, 
       1.1297603572391623`}, {6.739631063835945, 1.1084004603028395`}, {
       6.739631063835945, 1.1084004603028395`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}}, {{
       6.8087595195324875`, 1.1297603572391623`}, {6.739631063835945, 
       1.1084004603028395`}, {6.739631063835945, 1.1084004603028395`}, {
       6.8087595195324875`, 1.1297603572391623`}, {6.8087595195324875`, 
       1.1297603572391623`}}, {{6.8087595195324875`, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}, {6.8087595195324875`, 1.1297603572391623`}, {
       6.8087595195324875`, 1.1297603572391623`}}, {{6.8087595195324875`, 
       1.1297603572391623`}, {6.739631063835945, 1.1084004603028395`}, {
       6.739631063835945, 1.1084004603028395`}, {6.8087595195324875`, 
       1.1297603572391623`}, {6.8087595195324875`, 1.1297603572391623`}}, {{
       6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}}, {{6.739631063835945, 1.1084004603028395`}, {
       6.645838323647305, 1.1297603572391623`}, {6.645838323647305, 
       1.1297603572391623`}, {6.739631063835945, 1.1084004603028395`}, {
       6.739631063835945, 1.1084004603028395`}}, {{6.739631063835945, 
       1.1084004603028395`}, {6.645838323647305, 1.1297603572391623`}, {
       6.645838323647305, 1.1297603572391623`}, {6.739631063835945, 
       1.1084004603028395`}, {6.739631063835945, 1.1084004603028395`}}, {{
       6.739631063835945, 1.1084004603028395`}, {6.645838323647305, 
       1.1297603572391623`}, {6.645838323647305, 1.1297603572391623`}, {
       6.739631063835945, 1.1084004603028395`}, {6.739631063835945, 
       1.1084004603028395`}}, {{6.645838323647305, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}, {6.645838323647305, 1.411948146142179}, {
       6.645838323647305, 1.411948146142179}}, {{6.645838323647305, 
       1.411948146142179}, {6.739631063835945, 1.433308043078502}, {
       6.739631063835945, 1.433308043078502}, {6.645838323647305, 
       1.411948146142179}, {6.645838323647305, 1.411948146142179}}, {{
       6.645838323647305, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}, {
       6.645838323647305, 1.411948146142179}, {6.645838323647305, 
       1.411948146142179}}, {{6.645838323647305, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}, {6.645838323647305, 1.411948146142179}, {
       6.645838323647305, 1.411948146142179}}, {{6.739631063835945, 
       1.433308043078502}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}}, {{
       6.739631063835945, 1.433308043078502}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}, {
       6.739631063835945, 1.433308043078502}, {6.739631063835945, 
       1.433308043078502}}, {{6.739631063835945, 1.433308043078502}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}, {6.739631063835945, 1.433308043078502}, {
       6.739631063835945, 1.433308043078502}}, {{6.739631063835945, 
       1.433308043078502}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}, {6.739631063835945, 
       1.433308043078502}, {6.739631063835945, 1.433308043078502}}, {{
       6.8087595195324875`, 1.411948146142179}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}, {{6.8087595195324875`, 1.411948146142179}, {
       6.861821960749832, 1.3627610958527479`}, {6.861821960749832, 
       1.3627610958527479`}, {6.8087595195324875`, 1.411948146142179}, {
       6.8087595195324875`, 1.411948146142179}}, {{6.8087595195324875`, 
       1.411948146142179}, {6.861821960749832, 1.3627610958527479`}, {
       6.861821960749832, 1.3627610958527479`}, {6.8087595195324875`, 
       1.411948146142179}, {6.8087595195324875`, 1.411948146142179}}, {{
       6.8087595195324875`, 1.411948146142179}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}, {
       6.8087595195324875`, 1.411948146142179}, {6.8087595195324875`, 
       1.411948146142179}}, {{6.861821960749832, 1.3627610958527479`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}, {6.861821960749832, 1.3627610958527479`}, {
       6.861821960749832, 1.3627610958527479`}}, {{6.861821960749832, 
       1.3627610958527479`}, {6.890220117475078, 1.2708542516906707`}, {
       6.890220117475078, 1.2708542516906707`}, {6.861821960749832, 
       1.3627610958527479`}, {6.861821960749832, 1.3627610958527479`}}, {{
       6.861821960749832, 1.3627610958527479`}, {6.890220117475078, 
       1.2708542516906707`}, {6.890220117475078, 1.2708542516906707`}, {
       6.861821960749832, 1.3627610958527479`}, {6.861821960749832, 
       1.3627610958527479`}}, {{6.861821960749832, 1.3627610958527479`}, {
       6.890220117475078, 1.2708542516906707`}, {6.890220117475078, 
       1.2708542516906707`}, {6.861821960749832, 1.3627610958527479`}, {
       6.861821960749832, 1.3627610958527479`}}, {{6.6933450503580545`, 
       1.5890733247505344`}, {6.638526448092365, 1.6482110214252461`}, {
       6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.7664864147746695`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.638526448092365, 
       1.7664864147746695`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}}, {{
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}, {{6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.829917710735652, 
       1.5890733247505344`}, {6.771969099132499, 1.5711678709258474`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.771969099132499, 1.5711678709258474`}, {
       6.829917710735652, 1.5890733247505344`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.89820404092445, 1.7073487180999578`}, {
       6.89820404092445, 1.7073487180999578`}}, {{6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}}, {{
       6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499, 
       1.8435295652740682`}, {6.829917710735652, 1.8256241114493812`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.829917710735652, 
       1.8256241114493812`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}, {{6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}}, {{6.6933450503580545`, 
       1.5890733247505344`}, {6.638526448092365, 1.6482110214252461`}, {
       6.638526448092365, 1.6482110214252461`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}}, {{
       6.6933450503580545`, 1.5890733247505344`}, {6.638526448092365, 
       1.6482110214252461`}, {6.638526448092365, 1.6482110214252461`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}}, {{6.6933450503580545`, 1.5890733247505344`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.6933450503580545`, 1.5890733247505344`}}, {{6.6933450503580545`, 
       1.5890733247505344`}, {6.638526448092365, 1.6482110214252461`}, {
       6.638526448092365, 1.6482110214252461`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}}, {{
       6.638526448092365, 1.6482110214252461`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}}, {{6.638526448092365, 1.6482110214252461`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}, {6.638526448092365, 1.6482110214252461`}, {
       6.638526448092365, 1.6482110214252461`}}, {{6.638526448092365, 
       1.6482110214252461`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.6482110214252461`}, {6.638526448092365, 1.6482110214252461`}}, {{
       6.638526448092365, 1.6482110214252461`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.6482110214252461`}, {6.638526448092365, 
       1.6482110214252461`}}, {{6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}}, {{6.625058720169256, 
       1.7073487180999578`}, {6.638526448092365, 1.7664864147746695`}, {
       6.638526448092365, 1.7664864147746695`}, {6.625058720169256, 
       1.7073487180999578`}, {6.625058720169256, 1.7073487180999578`}}, {{
       6.625058720169256, 1.7073487180999578`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}, {
       6.625058720169256, 1.7073487180999578`}, {6.625058720169256, 
       1.7073487180999578`}}, {{6.625058720169256, 1.7073487180999578`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}, {6.625058720169256, 1.7073487180999578`}, {
       6.625058720169256, 1.7073487180999578`}}, {{6.638526448092365, 
       1.7664864147746695`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}}, {{
       6.638526448092365, 1.7664864147746695`}, {6.6933450503580545`, 
       1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.638526448092365, 1.7664864147746695`}, {6.638526448092365, 
       1.7664864147746695`}}, {{6.638526448092365, 1.7664864147746695`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}, {6.638526448092365, 1.7664864147746695`}, {
       6.638526448092365, 1.7664864147746695`}}, {{6.638526448092365, 
       1.7664864147746695`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.638526448092365, 
       1.7664864147746695`}, {6.638526448092365, 1.7664864147746695`}}, {{
       6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}, {{6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.89820404092445, 1.7073487180999578`}, {
       6.89820404092445, 1.7073487180999578`}}, {{6.89820404092445, 
       1.7073487180999578`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}}, {{
       6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}}, {{6.8743985944156965`, 1.6303055676005591`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.8743985944156965`, 1.6303055676005591`}}, {{6.8743985944156965`, 
       1.6303055676005591`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}, {6.8743985944156965`, 
       1.6303055676005591`}, {6.8743985944156965`, 1.6303055676005591`}}, {{
       6.8743985944156965`, 1.6303055676005591`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}, {
       6.8743985944156965`, 1.6303055676005591`}, {6.8743985944156965`, 
       1.6303055676005591`}}, {{6.8743985944156965`, 1.6303055676005591`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}, {6.8743985944156965`, 1.6303055676005591`}, {
       6.8743985944156965`, 1.6303055676005591`}}, {{6.829917710735652, 
       1.5890733247505344`}, {6.771969099132499, 1.5711678709258474`}, {
       6.771969099132499, 1.5711678709258474`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}}, {{
       6.829917710735652, 1.5890733247505344`}, {6.771969099132499, 
       1.5711678709258474`}, {6.771969099132499, 1.5711678709258474`}, {
       6.829917710735652, 1.5890733247505344`}, {6.829917710735652, 
       1.5890733247505344`}}, {{6.829917710735652, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}, {6.829917710735652, 1.5890733247505344`}, {
       6.829917710735652, 1.5890733247505344`}}, {{6.829917710735652, 
       1.5890733247505344`}, {6.771969099132499, 1.5711678709258474`}, {
       6.771969099132499, 1.5711678709258474`}, {6.829917710735652, 
       1.5890733247505344`}, {6.829917710735652, 1.5890733247505344`}}, {{
       6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}}, {{6.771969099132499, 1.5711678709258474`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.771969099132499, 1.5711678709258474`}, {
       6.771969099132499, 1.5711678709258474`}}, {{6.771969099132499, 
       1.5711678709258474`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.6933450503580545`, 1.5890733247505344`}, {6.771969099132499, 
       1.5711678709258474`}, {6.771969099132499, 1.5711678709258474`}}, {{
       6.771969099132499, 1.5711678709258474`}, {6.6933450503580545`, 
       1.5890733247505344`}, {6.6933450503580545`, 1.5890733247505344`}, {
       6.771969099132499, 1.5711678709258474`}, {6.771969099132499, 
       1.5711678709258474`}}, {{6.6933450503580545`, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.6933450503580545`, 1.8256241114493812`}}, {{6.6933450503580545`, 
       1.8256241114493812`}, {6.771969099132499, 1.8435295652740682`}, {
       6.771969099132499, 1.8435295652740682`}, {6.6933450503580545`, 
       1.8256241114493812`}, {6.6933450503580545`, 1.8256241114493812`}}, {{
       6.6933450503580545`, 1.8256241114493812`}, {6.771969099132499, 
       1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}, {
       6.6933450503580545`, 1.8256241114493812`}, {6.6933450503580545`, 
       1.8256241114493812`}}, {{6.6933450503580545`, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}, {6.6933450503580545`, 1.8256241114493812`}, {
       6.6933450503580545`, 1.8256241114493812`}}, {{6.771969099132499, 
       1.8435295652740682`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.771969099132499, 
       1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}}, {{
       6.771969099132499, 1.8435295652740682`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}, {
       6.771969099132499, 1.8435295652740682`}, {6.771969099132499, 
       1.8435295652740682`}}, {{6.771969099132499, 1.8435295652740682`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}, {6.771969099132499, 1.8435295652740682`}, {
       6.771969099132499, 1.8435295652740682`}}, {{6.771969099132499, 
       1.8435295652740682`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}, {6.771969099132499, 
       1.8435295652740682`}, {6.771969099132499, 1.8435295652740682`}}, {{
       6.829917710735652, 1.8256241114493812`}, {6.8743985944156965`, 
       1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}, {{6.829917710735652, 1.8256241114493812`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.8743985944156965`, 
       1.7843918685993565`}, {6.829917710735652, 1.8256241114493812`}, {
       6.829917710735652, 1.8256241114493812`}}, {{6.829917710735652, 
       1.8256241114493812`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.829917710735652, 
       1.8256241114493812`}, {6.829917710735652, 1.8256241114493812`}}, {{
       6.829917710735652, 1.8256241114493812`}, {6.8743985944156965`, 
       1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.829917710735652, 1.8256241114493812`}, {6.829917710735652, 
       1.8256241114493812`}}, {{6.8743985944156965`, 1.7843918685993565`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.8743985944156965`, 1.7843918685993565`}}, {{6.8743985944156965`, 
       1.7843918685993565`}, {6.89820404092445, 1.7073487180999578`}, {
       6.89820404092445, 1.7073487180999578`}, {6.8743985944156965`, 
       1.7843918685993565`}, {6.8743985944156965`, 1.7843918685993565`}}, {{
       6.8743985944156965`, 1.7843918685993565`}, {6.89820404092445, 
       1.7073487180999578`}, {6.89820404092445, 1.7073487180999578`}, {
       6.8743985944156965`, 1.7843918685993565`}, {6.8743985944156965`, 
       1.7843918685993565`}}, {{6.8743985944156965`, 1.7843918685993565`}, {
       6.89820404092445, 1.7073487180999578`}, {6.89820404092445, 
       1.7073487180999578`}, {6.8743985944156965`, 1.7843918685993565`}, {
       6.8743985944156965`, 1.7843918685993565`}}, {{6.730606204598308, 
       2.119109799473035}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`, 
       2.283286060231335}, {6.730606204598308, 2.3380114804841017`}, {
       6.730606204598308, 2.3380114804841017`}, {6.6798776301805285`, 
       2.283286060231335}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}}, {{
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}, {{6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.157265695708619}, {6.856989149056108, 
       2.119109799473035}, {6.803364095978873, 2.102540275455852}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}, {6.803364095978873, 2.102540275455852}, {
       6.856989149056108, 2.119109799473035}, {6.898151304322223, 
       2.157265695708619}, {6.920180621285009, 2.2285606399785682`}, {
       6.920180621285009, 2.2285606399785682`}}, {{6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}}, {{
       6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.856989149056108, 2.3380114804841017`}, {
       6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.856989149056108, 
       2.3380114804841017`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}, {{6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}}, {{6.730606204598308, 
       2.119109799473035}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}}, {{
       6.730606204598308, 2.119109799473035}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}}, {{6.730606204598308, 2.119109799473035}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.730606204598308, 2.119109799473035}, {
       6.730606204598308, 2.119109799473035}}, {{6.730606204598308, 
       2.119109799473035}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}}, {{
       6.6798776301805285`, 2.1738352197258015`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}}, {{6.6798776301805285`, 2.1738352197258015`}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}, {6.6798776301805285`, 2.1738352197258015`}, {
       6.6798776301805285`, 2.1738352197258015`}}, {{6.6798776301805285`, 
       2.1738352197258015`}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`, 
       2.1738352197258015`}, {6.6798776301805285`, 2.1738352197258015`}}, {{
       6.6798776301805285`, 2.1738352197258015`}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.1738352197258015`}, {6.6798776301805285`, 
       2.1738352197258015`}}, {{6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}}, {{6.667414732369407, 
       2.2285606399785682`}, {6.6798776301805285`, 2.283286060231335}, {
       6.6798776301805285`, 2.283286060231335}, {6.667414732369407, 
       2.2285606399785682`}, {6.667414732369407, 2.2285606399785682`}}, {{
       6.667414732369407, 2.2285606399785682`}, {6.6798776301805285`, 
       2.283286060231335}, {6.6798776301805285`, 2.283286060231335}, {
       6.667414732369407, 2.2285606399785682`}, {6.667414732369407, 
       2.2285606399785682`}}, {{6.667414732369407, 2.2285606399785682`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}, {6.667414732369407, 2.2285606399785682`}, {
       6.667414732369407, 2.2285606399785682`}}, {{6.6798776301805285`, 
       2.283286060231335}, {6.730606204598308, 2.3380114804841017`}, {
       6.730606204598308, 2.3380114804841017`}, {6.6798776301805285`, 
       2.283286060231335}, {6.6798776301805285`, 2.283286060231335}}, {{
       6.6798776301805285`, 2.283286060231335}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}, {
       6.6798776301805285`, 2.283286060231335}, {6.6798776301805285`, 
       2.283286060231335}}, {{6.6798776301805285`, 2.283286060231335}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}, {6.6798776301805285`, 2.283286060231335}, {
       6.6798776301805285`, 2.283286060231335}}, {{6.6798776301805285`, 
       2.283286060231335}, {6.730606204598308, 2.3380114804841017`}, {
       6.730606204598308, 2.3380114804841017`}, {6.6798776301805285`, 
       2.283286060231335}, {6.6798776301805285`, 2.283286060231335}}, {{
       6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}, {{6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.157265695708619}, {6.898151304322223, 
       2.157265695708619}, {6.920180621285009, 2.2285606399785682`}, {
       6.920180621285009, 2.2285606399785682`}}, {{6.920180621285009, 
       2.2285606399785682`}, {6.898151304322223, 2.157265695708619}, {
       6.898151304322223, 2.157265695708619}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}}, {{
       6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}}, {{6.898151304322223, 2.157265695708619}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.898151304322223, 2.157265695708619}, {
       6.898151304322223, 2.157265695708619}}, {{6.898151304322223, 
       2.157265695708619}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}, {6.898151304322223, 
       2.157265695708619}, {6.898151304322223, 2.157265695708619}}, {{
       6.898151304322223, 2.157265695708619}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}, {
       6.898151304322223, 2.157265695708619}, {6.898151304322223, 
       2.157265695708619}}, {{6.898151304322223, 2.157265695708619}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}, {6.898151304322223, 2.157265695708619}, {
       6.898151304322223, 2.157265695708619}}, {{6.856989149056108, 
       2.119109799473035}, {6.803364095978873, 2.102540275455852}, {
       6.803364095978873, 2.102540275455852}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}}, {{
       6.856989149056108, 2.119109799473035}, {6.803364095978873, 
       2.102540275455852}, {6.803364095978873, 2.102540275455852}, {
       6.856989149056108, 2.119109799473035}, {6.856989149056108, 
       2.119109799473035}}, {{6.856989149056108, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}, {6.856989149056108, 2.119109799473035}, {
       6.856989149056108, 2.119109799473035}}, {{6.856989149056108, 
       2.119109799473035}, {6.803364095978873, 2.102540275455852}, {
       6.803364095978873, 2.102540275455852}, {6.856989149056108, 
       2.119109799473035}, {6.856989149056108, 2.119109799473035}}, {{
       6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}}, {{6.803364095978873, 2.102540275455852}, {
       6.730606204598308, 2.119109799473035}, {6.730606204598308, 
       2.119109799473035}, {6.803364095978873, 2.102540275455852}, {
       6.803364095978873, 2.102540275455852}}, {{6.803364095978873, 
       2.102540275455852}, {6.730606204598308, 2.119109799473035}, {
       6.730606204598308, 2.119109799473035}, {6.803364095978873, 
       2.102540275455852}, {6.803364095978873, 2.102540275455852}}, {{
       6.803364095978873, 2.102540275455852}, {6.730606204598308, 
       2.119109799473035}, {6.730606204598308, 2.119109799473035}, {
       6.803364095978873, 2.102540275455852}, {6.803364095978873, 
       2.102540275455852}}, {{6.730606204598308, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}, {6.730606204598308, 2.3380114804841017`}, {
       6.730606204598308, 2.3380114804841017`}}, {{6.730606204598308, 
       2.3380114804841017`}, {6.803364095978873, 2.3545810045012843`}, {
       6.803364095978873, 2.3545810045012843`}, {6.730606204598308, 
       2.3380114804841017`}, {6.730606204598308, 2.3380114804841017`}}, {{
       6.730606204598308, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}, {
       6.730606204598308, 2.3380114804841017`}, {6.730606204598308, 
       2.3380114804841017`}}, {{6.730606204598308, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}, {6.730606204598308, 2.3380114804841017`}, {
       6.730606204598308, 2.3380114804841017`}}, {{6.803364095978873, 
       2.3545810045012843`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}}, {{
       6.803364095978873, 2.3545810045012843`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}, {
       6.803364095978873, 2.3545810045012843`}, {6.803364095978873, 
       2.3545810045012843`}}, {{6.803364095978873, 2.3545810045012843`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}, {6.803364095978873, 2.3545810045012843`}, {
       6.803364095978873, 2.3545810045012843`}}, {{6.803364095978873, 
       2.3545810045012843`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}, {6.803364095978873, 
       2.3545810045012843`}, {6.803364095978873, 2.3545810045012843`}}, {{
       6.856989149056108, 2.3380114804841017`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}, {{6.856989149056108, 2.3380114804841017`}, {
       6.898151304322223, 2.2998555842485175`}, {6.898151304322223, 
       2.2998555842485175`}, {6.856989149056108, 2.3380114804841017`}, {
       6.856989149056108, 2.3380114804841017`}}, {{6.856989149056108, 
       2.3380114804841017`}, {6.898151304322223, 2.2998555842485175`}, {
       6.898151304322223, 2.2998555842485175`}, {6.856989149056108, 
       2.3380114804841017`}, {6.856989149056108, 2.3380114804841017`}}, {{
       6.856989149056108, 2.3380114804841017`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}, {
       6.856989149056108, 2.3380114804841017`}, {6.856989149056108, 
       2.3380114804841017`}}, {{6.898151304322223, 2.2998555842485175`}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}, {6.898151304322223, 2.2998555842485175`}, {
       6.898151304322223, 2.2998555842485175`}}, {{6.898151304322223, 
       2.2998555842485175`}, {6.920180621285009, 2.2285606399785682`}, {
       6.920180621285009, 2.2285606399785682`}, {6.898151304322223, 
       2.2998555842485175`}, {6.898151304322223, 2.2998555842485175`}}, {{
       6.898151304322223, 2.2998555842485175`}, {6.920180621285009, 
       2.2285606399785682`}, {6.920180621285009, 2.2285606399785682`}, {
       6.898151304322223, 2.2998555842485175`}, {6.898151304322223, 
       2.2998555842485175`}}, {{6.898151304322223, 2.2998555842485175`}, {
       6.920180621285009, 2.2285606399785682`}, {6.920180621285009, 
       2.2285606399785682`}, {6.898151304322223, 2.2998555842485175`}, {
       6.898151304322223, 2.2998555842485175`}}, {{6.635189422279444, 
       2.5945230597158435`}, {6.569353315970717, 2.665546316862375}, {
       6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.807592831155439}, {6.635189422279444, 2.8786160883019702`}, {
       6.635189422279444, 2.8786160883019702`}, {6.569353315970717, 
       2.807592831155439}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}}, {{
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}, {{6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.6440422048860306`}, {6.79921060880854, 
       2.5945230597158435`}, {6.729615420382219, 2.5730189477394987`}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}, {6.729615420382219, 2.5730189477394987`}, {
       6.79921060880854, 2.5945230597158435`}, {6.85263131027904, 
       2.6440422048860306`}, {6.881221202073088, 2.736569574008907}, {
       6.881221202073088, 2.736569574008907}}, {{6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}}, {{
       6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.79921060880854, 2.8786160883019702`}, {
       6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.79921060880854, 
       2.8786160883019702`}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}, {{6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}}, {{6.635189422279444, 
       2.5945230597158435`}, {6.569353315970717, 2.665546316862375}, {
       6.569353315970717, 2.665546316862375}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}}, {{
       6.635189422279444, 2.5945230597158435`}, {6.569353315970717, 
       2.665546316862375}, {6.569353315970717, 2.665546316862375}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}}, {{6.635189422279444, 2.5945230597158435`}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}, {6.635189422279444, 2.5945230597158435`}, {
       6.635189422279444, 2.5945230597158435`}}, {{6.635189422279444, 
       2.5945230597158435`}, {6.569353315970717, 2.665546316862375}, {
       6.569353315970717, 2.665546316862375}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}}, {{
       6.569353315970717, 2.665546316862375}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}}, {{6.569353315970717, 2.665546316862375}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}, {6.569353315970717, 2.665546316862375}, {
       6.569353315970717, 2.665546316862375}}, {{6.569353315970717, 
       2.665546316862375}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.665546316862375}, {6.569353315970717, 2.665546316862375}}, {{
       6.569353315970717, 2.665546316862375}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.665546316862375}, {6.569353315970717, 
       2.665546316862375}}, {{6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}}, {{6.553178829014896, 
       2.736569574008907}, {6.569353315970717, 2.807592831155439}, {
       6.569353315970717, 2.807592831155439}, {6.553178829014896, 
       2.736569574008907}, {6.553178829014896, 2.736569574008907}}, {{
       6.553178829014896, 2.736569574008907}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}, {
       6.553178829014896, 2.736569574008907}, {6.553178829014896, 
       2.736569574008907}}, {{6.553178829014896, 2.736569574008907}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}, {6.553178829014896, 2.736569574008907}, {
       6.553178829014896, 2.736569574008907}}, {{6.569353315970717, 
       2.807592831155439}, {6.635189422279444, 2.8786160883019702`}, {
       6.635189422279444, 2.8786160883019702`}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}}, {{
       6.569353315970717, 2.807592831155439}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}, {
       6.569353315970717, 2.807592831155439}, {6.569353315970717, 
       2.807592831155439}}, {{6.569353315970717, 2.807592831155439}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}, {6.569353315970717, 2.807592831155439}, {
       6.569353315970717, 2.807592831155439}}, {{6.569353315970717, 
       2.807592831155439}, {6.635189422279444, 2.8786160883019702`}, {
       6.635189422279444, 2.8786160883019702`}, {6.569353315970717, 
       2.807592831155439}, {6.569353315970717, 2.807592831155439}}, {{
       6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}, {{6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.6440422048860306`}, {6.85263131027904, 
       2.6440422048860306`}, {6.881221202073088, 2.736569574008907}, {
       6.881221202073088, 2.736569574008907}}, {{6.881221202073088, 
       2.736569574008907}, {6.85263131027904, 2.6440422048860306`}, {
       6.85263131027904, 2.6440422048860306`}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}}, {{
       6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}}, {{6.85263131027904, 2.6440422048860306`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.85263131027904, 2.6440422048860306`}, {
       6.85263131027904, 2.6440422048860306`}}, {{6.85263131027904, 
       2.6440422048860306`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}, {6.85263131027904, 
       2.6440422048860306`}, {6.85263131027904, 2.6440422048860306`}}, {{
       6.85263131027904, 2.6440422048860306`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}, {
       6.85263131027904, 2.6440422048860306`}, {6.85263131027904, 
       2.6440422048860306`}}, {{6.85263131027904, 2.6440422048860306`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}, {6.85263131027904, 2.6440422048860306`}, {
       6.85263131027904, 2.6440422048860306`}}, {{6.79921060880854, 
       2.5945230597158435`}, {6.729615420382219, 2.5730189477394987`}, {
       6.729615420382219, 2.5730189477394987`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}}, {{
       6.79921060880854, 2.5945230597158435`}, {6.729615420382219, 
       2.5730189477394987`}, {6.729615420382219, 2.5730189477394987`}, {
       6.79921060880854, 2.5945230597158435`}, {6.79921060880854, 
       2.5945230597158435`}}, {{6.79921060880854, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}, {6.79921060880854, 2.5945230597158435`}, {
       6.79921060880854, 2.5945230597158435`}}, {{6.79921060880854, 
       2.5945230597158435`}, {6.729615420382219, 2.5730189477394987`}, {
       6.729615420382219, 2.5730189477394987`}, {6.79921060880854, 
       2.5945230597158435`}, {6.79921060880854, 2.5945230597158435`}}, {{
       6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}}, {{6.729615420382219, 2.5730189477394987`}, {
       6.635189422279444, 2.5945230597158435`}, {6.635189422279444, 
       2.5945230597158435`}, {6.729615420382219, 2.5730189477394987`}, {
       6.729615420382219, 2.5730189477394987`}}, {{6.729615420382219, 
       2.5730189477394987`}, {6.635189422279444, 2.5945230597158435`}, {
       6.635189422279444, 2.5945230597158435`}, {6.729615420382219, 
       2.5730189477394987`}, {6.729615420382219, 2.5730189477394987`}}, {{
       6.729615420382219, 2.5730189477394987`}, {6.635189422279444, 
       2.5945230597158435`}, {6.635189422279444, 2.5945230597158435`}, {
       6.729615420382219, 2.5730189477394987`}, {6.729615420382219, 
       2.5730189477394987`}}, {{6.635189422279444, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}, {6.635189422279444, 2.8786160883019702`}, {
       6.635189422279444, 2.8786160883019702`}}, {{6.635189422279444, 
       2.8786160883019702`}, {6.729615420382219, 2.900120200278315}, {
       6.729615420382219, 2.900120200278315}, {6.635189422279444, 
       2.8786160883019702`}, {6.635189422279444, 2.8786160883019702`}}, {{
       6.635189422279444, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}, {
       6.635189422279444, 2.8786160883019702`}, {6.635189422279444, 
       2.8786160883019702`}}, {{6.635189422279444, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}, {6.635189422279444, 2.8786160883019702`}, {
       6.635189422279444, 2.8786160883019702`}}, {{6.729615420382219, 
       2.900120200278315}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}}, {{
       6.729615420382219, 2.900120200278315}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}, {
       6.729615420382219, 2.900120200278315}, {6.729615420382219, 
       2.900120200278315}}, {{6.729615420382219, 2.900120200278315}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}, {6.729615420382219, 2.900120200278315}, {
       6.729615420382219, 2.900120200278315}}, {{6.729615420382219, 
       2.900120200278315}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}, {6.729615420382219, 
       2.900120200278315}, {6.729615420382219, 2.900120200278315}}, {{
       6.79921060880854, 2.8786160883019702`}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}, {{6.79921060880854, 2.8786160883019702`}, {
       6.85263131027904, 2.829096943131783}, {6.85263131027904, 
       2.829096943131783}, {6.79921060880854, 2.8786160883019702`}, {
       6.79921060880854, 2.8786160883019702`}}, {{6.79921060880854, 
       2.8786160883019702`}, {6.85263131027904, 2.829096943131783}, {
       6.85263131027904, 2.829096943131783}, {6.79921060880854, 
       2.8786160883019702`}, {6.79921060880854, 2.8786160883019702`}}, {{
       6.79921060880854, 2.8786160883019702`}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}, {
       6.79921060880854, 2.8786160883019702`}, {6.79921060880854, 
       2.8786160883019702`}}, {{6.85263131027904, 2.829096943131783}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}, {6.85263131027904, 2.829096943131783}, {
       6.85263131027904, 2.829096943131783}}, {{6.85263131027904, 
       2.829096943131783}, {6.881221202073088, 2.736569574008907}, {
       6.881221202073088, 2.736569574008907}, {6.85263131027904, 
       2.829096943131783}, {6.85263131027904, 2.829096943131783}}, {{
       6.85263131027904, 2.829096943131783}, {6.881221202073088, 
       2.736569574008907}, {6.881221202073088, 2.736569574008907}, {
       6.85263131027904, 2.829096943131783}, {6.85263131027904, 
       2.829096943131783}}, {{6.85263131027904, 2.829096943131783}, {
       6.881221202073088, 2.736569574008907}, {6.881221202073088, 
       2.736569574008907}, {6.85263131027904, 2.829096943131783}, {
       6.85263131027904, 2.829096943131783}}, {{6.690401385500142, 
       3.1767043127584165`}, {6.636138386367973, 3.2352426309699105`}, {
       6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.3523192673928994`}, {6.690401385500142, 3.4108575856043934`}, {
       6.690401385500142, 3.4108575856043934`}, {6.636138386367973, 
       3.3523192673928994`}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}}, {{
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}, {{6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.217518654341667}, {6.825589840609398, 
       3.1767043127584165`}, {6.768228555732197, 3.1589803361301727`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}, {6.768228555732197, 3.1589803361301727`}, {
       6.825589840609398, 3.1767043127584165`}, {6.86961989706414, 
       3.217518654341667}, {6.893184068164027, 3.293780949181405}, {
       6.893184068164027, 3.293780949181405}}, {{6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}}, {{
       6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.825589840609398, 3.4108575856043934`}, {
       6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.825589840609398, 
       3.4108575856043934`}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}, {{6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}}, {{6.690401385500142, 
       3.1767043127584165`}, {6.636138386367973, 3.2352426309699105`}, {
       6.636138386367973, 3.2352426309699105`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}}, {{
       6.690401385500142, 3.1767043127584165`}, {6.636138386367973, 
       3.2352426309699105`}, {6.636138386367973, 3.2352426309699105`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}}, {{6.690401385500142, 3.1767043127584165`}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}, {6.690401385500142, 3.1767043127584165`}, {
       6.690401385500142, 3.1767043127584165`}}, {{6.690401385500142, 
       3.1767043127584165`}, {6.636138386367973, 3.2352426309699105`}, {
       6.636138386367973, 3.2352426309699105`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}}, {{
       6.636138386367973, 3.2352426309699105`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}}, {{6.636138386367973, 3.2352426309699105`}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}, {6.636138386367973, 3.2352426309699105`}, {
       6.636138386367973, 3.2352426309699105`}}, {{6.636138386367973, 
       3.2352426309699105`}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.2352426309699105`}, {6.636138386367973, 3.2352426309699105`}}, {{
       6.636138386367973, 3.2352426309699105`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.2352426309699105`}, {6.636138386367973, 
       3.2352426309699105`}}, {{6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}}, {{6.622807157945513, 
       3.293780949181405}, {6.636138386367973, 3.3523192673928994`}, {
       6.636138386367973, 3.3523192673928994`}, {6.622807157945513, 
       3.293780949181405}, {6.622807157945513, 3.293780949181405}}, {{
       6.622807157945513, 3.293780949181405}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}, {
       6.622807157945513, 3.293780949181405}, {6.622807157945513, 
       3.293780949181405}}, {{6.622807157945513, 3.293780949181405}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}, {6.622807157945513, 3.293780949181405}, {
       6.622807157945513, 3.293780949181405}}, {{6.636138386367973, 
       3.3523192673928994`}, {6.690401385500142, 3.4108575856043934`}, {
       6.690401385500142, 3.4108575856043934`}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}}, {{
       6.636138386367973, 3.3523192673928994`}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}, {
       6.636138386367973, 3.3523192673928994`}, {6.636138386367973, 
       3.3523192673928994`}}, {{6.636138386367973, 3.3523192673928994`}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}, {6.636138386367973, 3.3523192673928994`}, {
       6.636138386367973, 3.3523192673928994`}}, {{6.636138386367973, 
       3.3523192673928994`}, {6.690401385500142, 3.4108575856043934`}, {
       6.690401385500142, 3.4108575856043934`}, {6.636138386367973, 
       3.3523192673928994`}, {6.636138386367973, 3.3523192673928994`}}, {{
       6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}, {{6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.217518654341667}, {6.86961989706414, 
       3.217518654341667}, {6.893184068164027, 3.293780949181405}, {
       6.893184068164027, 3.293780949181405}}, {{6.893184068164027, 
       3.293780949181405}, {6.86961989706414, 3.217518654341667}, {
       6.86961989706414, 3.217518654341667}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}}, {{
       6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}}, {{6.86961989706414, 3.217518654341667}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.86961989706414, 3.217518654341667}, {
       6.86961989706414, 3.217518654341667}}, {{6.86961989706414, 
       3.217518654341667}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}, {6.86961989706414, 
       3.217518654341667}, {6.86961989706414, 3.217518654341667}}, {{
       6.86961989706414, 3.217518654341667}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}, {
       6.86961989706414, 3.217518654341667}, {6.86961989706414, 
       3.217518654341667}}, {{6.86961989706414, 3.217518654341667}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}, {6.86961989706414, 3.217518654341667}, {
       6.86961989706414, 3.217518654341667}}, {{6.825589840609398, 
       3.1767043127584165`}, {6.768228555732197, 3.1589803361301727`}, {
       6.768228555732197, 3.1589803361301727`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}}, {{
       6.825589840609398, 3.1767043127584165`}, {6.768228555732197, 
       3.1589803361301727`}, {6.768228555732197, 3.1589803361301727`}, {
       6.825589840609398, 3.1767043127584165`}, {6.825589840609398, 
       3.1767043127584165`}}, {{6.825589840609398, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}, {6.825589840609398, 3.1767043127584165`}, {
       6.825589840609398, 3.1767043127584165`}}, {{6.825589840609398, 
       3.1767043127584165`}, {6.768228555732197, 3.1589803361301727`}, {
       6.768228555732197, 3.1589803361301727`}, {6.825589840609398, 
       3.1767043127584165`}, {6.825589840609398, 3.1767043127584165`}}, {{
       6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}}, {{6.768228555732197, 3.1589803361301727`}, {
       6.690401385500142, 3.1767043127584165`}, {6.690401385500142, 
       3.1767043127584165`}, {6.768228555732197, 3.1589803361301727`}, {
       6.768228555732197, 3.1589803361301727`}}, {{6.768228555732197, 
       3.1589803361301727`}, {6.690401385500142, 3.1767043127584165`}, {
       6.690401385500142, 3.1767043127584165`}, {6.768228555732197, 
       3.1589803361301727`}, {6.768228555732197, 3.1589803361301727`}}, {{
       6.768228555732197, 3.1589803361301727`}, {6.690401385500142, 
       3.1767043127584165`}, {6.690401385500142, 3.1767043127584165`}, {
       6.768228555732197, 3.1589803361301727`}, {6.768228555732197, 
       3.1589803361301727`}}, {{6.690401385500142, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}, {6.690401385500142, 3.4108575856043934`}, {
       6.690401385500142, 3.4108575856043934`}}, {{6.690401385500142, 
       3.4108575856043934`}, {6.768228555732197, 3.428581562232637}, {
       6.768228555732197, 3.428581562232637}, {6.690401385500142, 
       3.4108575856043934`}, {6.690401385500142, 3.4108575856043934`}}, {{
       6.690401385500142, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}, {
       6.690401385500142, 3.4108575856043934`}, {6.690401385500142, 
       3.4108575856043934`}}, {{6.690401385500142, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}, {6.690401385500142, 3.4108575856043934`}, {
       6.690401385500142, 3.4108575856043934`}}, {{6.768228555732197, 
       3.428581562232637}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}}, {{
       6.768228555732197, 3.428581562232637}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}, {
       6.768228555732197, 3.428581562232637}, {6.768228555732197, 
       3.428581562232637}}, {{6.768228555732197, 3.428581562232637}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}, {6.768228555732197, 3.428581562232637}, {
       6.768228555732197, 3.428581562232637}}, {{6.768228555732197, 
       3.428581562232637}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}, {6.768228555732197, 
       3.428581562232637}, {6.768228555732197, 3.428581562232637}}, {{
       6.825589840609398, 3.4108575856043934`}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}, {{6.825589840609398, 3.4108575856043934`}, {
       6.86961989706414, 3.3700432440211427`}, {6.86961989706414, 
       3.3700432440211427`}, {6.825589840609398, 3.4108575856043934`}, {
       6.825589840609398, 3.4108575856043934`}}, {{6.825589840609398, 
       3.4108575856043934`}, {6.86961989706414, 3.3700432440211427`}, {
       6.86961989706414, 3.3700432440211427`}, {6.825589840609398, 
       3.4108575856043934`}, {6.825589840609398, 3.4108575856043934`}}, {{
       6.825589840609398, 3.4108575856043934`}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}, {
       6.825589840609398, 3.4108575856043934`}, {6.825589840609398, 
       3.4108575856043934`}}, {{6.86961989706414, 3.3700432440211427`}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}, {6.86961989706414, 3.3700432440211427`}, {
       6.86961989706414, 3.3700432440211427`}}, {{6.86961989706414, 
       3.3700432440211427`}, {6.893184068164027, 3.293780949181405}, {
       6.893184068164027, 3.293780949181405}, {6.86961989706414, 
       3.3700432440211427`}, {6.86961989706414, 3.3700432440211427`}}, {{
       6.86961989706414, 3.3700432440211427`}, {6.893184068164027, 
       3.293780949181405}, {6.893184068164027, 3.293780949181405}, {
       6.86961989706414, 3.3700432440211427`}, {6.86961989706414, 
       3.3700432440211427`}}, {{6.86961989706414, 3.3700432440211427`}, {
       6.893184068164027, 3.293780949181405}, {6.893184068164027, 
       3.293780949181405}, {6.86961989706414, 3.3700432440211427`}, {
       6.86961989706414, 3.3700432440211427`}}, {{6.636744923649835, 
       3.6022973954429838`}, {6.567897822030072, 3.6765688807462644`}, {
       6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.8251118513528257`}, {6.636744923649835, 3.8993833366561064`}, {
       6.636744923649835, 3.8993833366561064`}, {6.567897822030072, 
       3.8251118513528257`}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.636744923649835, 
       3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}}, {{
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}, {{6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.654081284418261}, {6.808267571781685, 
       3.6022973954429838`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.808267571781685, 3.6022973954429838`}, {6.8641314536080476`, 
       3.654081284418261}, {6.89402889584761, 3.750840366049545}, {
       6.89402889584761, 3.750840366049545}}, {{6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}}, {{
       6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`, 
       3.9218709329841097`}, {6.808267571781685, 3.8993833366561064`}, {
       6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.808267571781685, 
       3.8993833366561064`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}, {{6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}}, {{6.636744923649835, 
       3.6022973954429838`}, {6.567897822030072, 3.6765688807462644`}, {
       6.567897822030072, 3.6765688807462644`}, {6.636744923649835, 
       3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}}, {{
       6.636744923649835, 3.6022973954429838`}, {6.567897822030072, 
       3.6765688807462644`}, {6.567897822030072, 3.6765688807462644`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}}, {{6.636744923649835, 3.6022973954429838`}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}, {6.636744923649835, 3.6022973954429838`}, {
       6.636744923649835, 3.6022973954429838`}}, {{6.636744923649835, 
       3.6022973954429838`}, {6.567897822030072, 3.6765688807462644`}, {
       6.567897822030072, 3.6765688807462644`}, {6.636744923649835, 
       3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}}, {{
       6.567897822030072, 3.6765688807462644`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}}, {{6.567897822030072, 3.6765688807462644`}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}, {6.567897822030072, 3.6765688807462644`}, {
       6.567897822030072, 3.6765688807462644`}}, {{6.567897822030072, 
       3.6765688807462644`}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.6765688807462644`}, {6.567897822030072, 3.6765688807462644`}}, {{
       6.567897822030072, 3.6765688807462644`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.6765688807462644`}, {6.567897822030072, 
       3.6765688807462644`}}, {{6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}}, {{6.55098359958391, 
       3.750840366049545}, {6.567897822030072, 3.8251118513528257`}, {
       6.567897822030072, 3.8251118513528257`}, {6.55098359958391, 
       3.750840366049545}, {6.55098359958391, 3.750840366049545}}, {{
       6.55098359958391, 3.750840366049545}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}, {
       6.55098359958391, 3.750840366049545}, {6.55098359958391, 
       3.750840366049545}}, {{6.55098359958391, 3.750840366049545}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}, {6.55098359958391, 3.750840366049545}, {
       6.55098359958391, 3.750840366049545}}, {{6.567897822030072, 
       3.8251118513528257`}, {6.636744923649835, 3.8993833366561064`}, {
       6.636744923649835, 3.8993833366561064`}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}}, {{
       6.567897822030072, 3.8251118513528257`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}, {
       6.567897822030072, 3.8251118513528257`}, {6.567897822030072, 
       3.8251118513528257`}}, {{6.567897822030072, 3.8251118513528257`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}, {6.567897822030072, 3.8251118513528257`}, {
       6.567897822030072, 3.8251118513528257`}}, {{6.567897822030072, 
       3.8251118513528257`}, {6.636744923649835, 3.8993833366561064`}, {
       6.636744923649835, 3.8993833366561064`}, {6.567897822030072, 
       3.8251118513528257`}, {6.567897822030072, 3.8251118513528257`}}, {{
       6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}, {{6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.654081284418261}, {6.8641314536080476`, 
       3.654081284418261}, {6.89402889584761, 3.750840366049545}, {
       6.89402889584761, 3.750840366049545}}, {{6.89402889584761, 
       3.750840366049545}, {6.8641314536080476`, 3.654081284418261}, {
       6.8641314536080476`, 3.654081284418261}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}}, {{
       6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}}, {{6.8641314536080476`, 3.654081284418261}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.8641314536080476`, 3.654081284418261}, {
       6.8641314536080476`, 3.654081284418261}}, {{6.8641314536080476`, 
       3.654081284418261}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}, {6.8641314536080476`, 
       3.654081284418261}, {6.8641314536080476`, 3.654081284418261}}, {{
       6.8641314536080476`, 3.654081284418261}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}, {
       6.8641314536080476`, 3.654081284418261}, {6.8641314536080476`, 
       3.654081284418261}}, {{6.8641314536080476`, 3.654081284418261}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}, {6.8641314536080476`, 3.654081284418261}, {
       6.8641314536080476`, 3.654081284418261}}, {{6.808267571781685, 
       3.6022973954429838`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}}, {{
       6.808267571781685, 3.6022973954429838`}, {6.7354894675091606`, 
       3.5798097991149804`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.808267571781685, 3.6022973954429838`}, {6.808267571781685, 
       3.6022973954429838`}}, {{6.808267571781685, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}, {6.808267571781685, 3.6022973954429838`}, {
       6.808267571781685, 3.6022973954429838`}}, {{6.808267571781685, 
       3.6022973954429838`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.808267571781685, 
       3.6022973954429838`}, {6.808267571781685, 3.6022973954429838`}}, {{
       6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835, 
       3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}}, {{6.7354894675091606`, 3.5798097991149804`}, {
       6.636744923649835, 3.6022973954429838`}, {6.636744923649835, 
       3.6022973954429838`}, {6.7354894675091606`, 3.5798097991149804`}, {
       6.7354894675091606`, 3.5798097991149804`}}, {{6.7354894675091606`, 
       3.5798097991149804`}, {6.636744923649835, 3.6022973954429838`}, {
       6.636744923649835, 3.6022973954429838`}, {6.7354894675091606`, 
       3.5798097991149804`}, {6.7354894675091606`, 3.5798097991149804`}}, {{
       6.7354894675091606`, 3.5798097991149804`}, {6.636744923649835, 
       3.6022973954429838`}, {6.636744923649835, 3.6022973954429838`}, {
       6.7354894675091606`, 3.5798097991149804`}, {6.7354894675091606`, 
       3.5798097991149804`}}, {{6.636744923649835, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}, {6.636744923649835, 3.8993833366561064`}, {
       6.636744923649835, 3.8993833366561064`}}, {{6.636744923649835, 
       3.8993833366561064`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.636744923649835, 
       3.8993833366561064`}, {6.636744923649835, 3.8993833366561064`}}, {{
       6.636744923649835, 3.8993833366561064`}, {6.7354894675091606`, 
       3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.636744923649835, 3.8993833366561064`}, {6.636744923649835, 
       3.8993833366561064`}}, {{6.636744923649835, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}, {6.636744923649835, 3.8993833366561064`}, {
       6.636744923649835, 3.8993833366561064`}}, {{6.7354894675091606`, 
       3.9218709329841097`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.7354894675091606`, 
       3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}}, {{
       6.7354894675091606`, 3.9218709329841097`}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}, {
       6.7354894675091606`, 3.9218709329841097`}, {6.7354894675091606`, 
       3.9218709329841097`}}, {{6.7354894675091606`, 3.9218709329841097`}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}, {6.7354894675091606`, 3.9218709329841097`}, {
       6.7354894675091606`, 3.9218709329841097`}}, {{6.7354894675091606`, 
       3.9218709329841097`}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}, {6.7354894675091606`, 
       3.9218709329841097`}, {6.7354894675091606`, 3.9218709329841097`}}, {{
       6.808267571781685, 3.8993833366561064`}, {6.8641314536080476`, 
       3.847599447680829}, {6.8641314536080476`, 3.847599447680829}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}, {{6.808267571781685, 3.8993833366561064`}, {
       6.8641314536080476`, 3.847599447680829}, {6.8641314536080476`, 
       3.847599447680829}, {6.808267571781685, 3.8993833366561064`}, {
       6.808267571781685, 3.8993833366561064`}}, {{6.808267571781685, 
       3.8993833366561064`}, {6.8641314536080476`, 3.847599447680829}, {
       6.8641314536080476`, 3.847599447680829}, {6.808267571781685, 
       3.8993833366561064`}, {6.808267571781685, 3.8993833366561064`}}, {{
       6.808267571781685, 3.8993833366561064`}, {6.8641314536080476`, 
       3.847599447680829}, {6.8641314536080476`, 3.847599447680829}, {
       6.808267571781685, 3.8993833366561064`}, {6.808267571781685, 
       3.8993833366561064`}}, {{6.8641314536080476`, 3.847599447680829}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}, {6.8641314536080476`, 3.847599447680829}, {
       6.8641314536080476`, 3.847599447680829}}, {{6.8641314536080476`, 
       3.847599447680829}, {6.89402889584761, 3.750840366049545}, {
       6.89402889584761, 3.750840366049545}, {6.8641314536080476`, 
       3.847599447680829}, {6.8641314536080476`, 3.847599447680829}}, {{
       6.8641314536080476`, 3.847599447680829}, {6.89402889584761, 
       3.750840366049545}, {6.89402889584761, 3.750840366049545}, {
       6.8641314536080476`, 3.847599447680829}, {6.8641314536080476`, 
       3.847599447680829}}, {{6.8641314536080476`, 3.847599447680829}, {
       6.89402889584761, 3.750840366049545}, {6.89402889584761, 
       3.750840366049545}, {6.8641314536080476`, 3.847599447680829}, {
       6.8641314536080476`, 3.847599447680829}}, {{
       6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}, {{
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}, {{
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}, {{
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}, {{
       6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}, {{
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}, {{
       6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}, {{
       6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}, {{
       6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}, {{
       6.900169073278873, -4.6726026940610925`}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}}, {{
       6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}, {{
       6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}, {{
       6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}, {{
       6.825919569393277, -4.592503157452106}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.592503157452106}, {
       6.825919569393277, -4.592503157452106}}, {{
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}, {{
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}, {{
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}, {{
       6.807678095232546, -4.512403620843119}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}, {
       6.807678095232546, -4.512403620843119}, {
       6.807678095232546, -4.512403620843119}}, {{
       6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}, {{
       6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}, {{
       6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}, {{
       6.825919569393277, -4.432304084234132}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}, {
       6.825919569393277, -4.432304084234132}, {
       6.825919569393277, -4.432304084234132}}, {{
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}, {{
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}, {{
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}, {{
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}}, {{
       7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}, {{
       7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}, {{
       7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}, {{
       7.145398525825903, -4.616755345730929}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.145398525825903, -4.616755345730929}, {
       7.145398525825903, -4.616755345730929}}, {{
       7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}, {{
       7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}, {{
       7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}, {{
       7.085151029371524, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}, {
       7.085151029371524, -4.6726026940610925`}, {
       7.085151029371524, -4.6726026940610925`}}, {{
       7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}, {{
       7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}, {{
       7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}, {{
       7.006662058756414, -4.696854882339916}, {
       6.900169073278873, -4.6726026940610925`}, {
       6.900169073278873, -4.6726026940610925`}, {
       7.006662058756414, -4.696854882339916}, {
       7.006662058756414, -4.696854882339916}}, {{
       6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}, {{
       6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}, {{
       6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}, {{
       6.900169073278873, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}, {
       6.900169073278873, -4.352204547625146}, {
       6.900169073278873, -4.352204547625146}}, {{
       7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}, {{
       7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}, {{
       7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}, {{
       7.006662058756414, -4.327952359346322}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}, {
       7.006662058756414, -4.327952359346322}, {
       7.006662058756414, -4.327952359346322}}, {{
       7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}, {{
       7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}, {{
       7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}, {{
       7.085151029371524, -4.352204547625146}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}, {
       7.085151029371524, -4.352204547625146}, {
       7.085151029371524, -4.352204547625146}}, {{
       7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}, {{
       7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}, {{
       7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}, {{
       7.145398525825903, -4.408051895955309}, {
       7.17764200741785, -4.512403620843119}, {
       7.17764200741785, -4.512403620843119}, {
       7.145398525825903, -4.408051895955309}, {
       7.145398525825903, -4.408051895955309}}, {{
       6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}, {{
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}, {{
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}, {{
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}, {{
       6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}, {{
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}, {{
       6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}, {{
       6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}, {{
       6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}, {{
       6.91612417633883, -4.139782575309563}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}}, {{
       6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}, {{
       6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}, {{
       6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}, {{
       6.853590128498297, -4.072321542007189}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -4.072321542007189}, {
       6.853590128498297, -4.072321542007189}}, {{
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}, {{
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}, {{
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}, {{
       6.838226884864958, -4.004860508704816}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.838226884864958, -4.004860508704816}, {
       6.838226884864958, -4.004860508704816}}, {{
       6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}, {{
       6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}, {{
       6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}, {{
       6.853590128498297, -3.9373994754024424`}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}, {
       6.853590128498297, -3.9373994754024424`}, {
       6.853590128498297, -3.9373994754024424`}}, {{
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}, {{
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}, {{
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}, {{
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}}, {{
       7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}, {{
       7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}, {{
       7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}, {{
       7.122660106075306, -4.092747099387375}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.122660106075306, -4.092747099387375}, {
       7.122660106075306, -4.092747099387375}}, {{
       7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}, {{
       7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}, {{
       7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}, {{
       7.0719187592865715`, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}, {
       7.0719187592865715`, -4.139782575309563}, {
       7.0719187592865715`, -4.139782575309563}}, {{
       7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}, {{
       7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}, {{
       7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}, {{
       7.005814168864499, -4.160208132689748}, {
       6.91612417633883, -4.139782575309563}, {
       6.91612417633883, -4.139782575309563}, {
       7.005814168864499, -4.160208132689748}, {
       7.005814168864499, -4.160208132689748}}, {{
       6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}, {{
       6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}, {{
       6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}, {{
       6.91612417633883, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}, {
       6.91612417633883, -3.869938442100069}, {
       6.91612417633883, -3.869938442100069}}, {{
       7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}, {{
       7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}, {{
       7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}, {{
       7.005814168864499, -3.849512884719884}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.005814168864499, -3.849512884719884}, {
       7.005814168864499, -3.849512884719884}}, {{
       7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}, {{
       7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}, {{
       7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}, {{
       7.0719187592865715`, -3.869938442100069}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}, {
       7.0719187592865715`, -3.869938442100069}, {
       7.0719187592865715`, -3.869938442100069}}, {{
       7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}, {{
       7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}, {{
       7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}, {{
       7.122660106075306, -3.916973918022257}, {
       7.149816050760443, -4.004860508704816}, {
       7.149816050760443, -4.004860508704816}, {
       7.122660106075306, -3.916973918022257}, {
       7.122660106075306, -3.916973918022257}}, {{
       6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}, {{
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}, {{
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}, {{
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}, {{
       6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}, {{
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}, {{
       6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}, {{
       6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}, {{
       6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}, {{
       6.94654995218811, -3.654269436164857}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}}, {{
       6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}, {{
       6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}, {{
       6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}, {{
       6.881599964256209, -3.584202113639435}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.584202113639435}, {
       6.881599964256209, -3.584202113639435}}, {{
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}, {{
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}, {{
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}, {{
       6.865643177145213, -3.5141347911140133`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.865643177145213, -3.5141347911140133`}, {
       6.865643177145213, -3.5141347911140133`}}, {{
       6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}, {{
       6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}, {{
       6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}, {{
       6.881599964256209, -3.4440674685885915`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.881599964256209, -3.4440674685885915`}, {
       6.881599964256209, -3.4440674685885915`}}, {{
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}, {{
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}, {{
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}, {{
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}}, {{
       7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}, {{
       7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}, {{
       7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}, {{
       7.161065190000579, -3.605416791901243}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}, {
       7.161065190000579, -3.605416791901243}, {
       7.161065190000579, -3.605416791901243}}, {{
       7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}, {{
       7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}, {{
       7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}, {{
       7.108363502273904, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}, {
       7.108363502273904, -3.654269436164857}, {
       7.108363502273904, -3.654269436164857}}, {{
       7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}, {{
       7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}, {{
       7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}, {{
       7.039705027436233, -3.675484114426665}, {
       6.94654995218811, -3.654269436164857}, {
       6.94654995218811, -3.654269436164857}, {
       7.039705027436233, -3.675484114426665}, {
       7.039705027436233, -3.675484114426665}}, {{
       6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}, {{
       6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}, {{
       6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}, {{
       6.94654995218811, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}, {
       6.94654995218811, -3.3740001460631697`}, {
       6.94654995218811, -3.3740001460631697`}}, {{
       7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}, {{
       7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}, {{
       7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}, {{
       7.039705027436233, -3.3527854678013616`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.039705027436233, -3.3527854678013616`}, {
       7.039705027436233, -3.3527854678013616`}}, {{
       7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}, {{
       7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}, {{
       7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}, {{
       7.108363502273904, -3.3740001460631697`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.108363502273904, -3.3740001460631697`}, {
       7.108363502273904, -3.3740001460631697`}}, {{
       7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}, {{
       7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}, {{
       7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}, {{
       7.161065190000579, -3.4228527903267834`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.189270277316801, -3.5141347911140133`}, {
       7.161065190000579, -3.4228527903267834`}, {
       7.161065190000579, -3.4228527903267834`}}, {{
       6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}, {{
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}, {{
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}, {{
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}, {{
       6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}, {{
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}, {{
       6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}, {{
       6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}, {{
       6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}, {{
       6.904602538222859, -3.1095685943705247`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}}, {{
       6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}, {{
       6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}, {{
       6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}, {{
       6.839847225467909, -3.03971128525458}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -3.03971128525458}, {
       6.839847225467909, -3.03971128525458}}, {{
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}, {{
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}, {{
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}, {{
       6.823938265776952, -2.9698539761386353`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.823938265776952, -2.9698539761386353`}, {
       6.823938265776952, -2.9698539761386353`}}, {{
       6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}, {{
       6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}, {{
       6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}, {{
       6.839847225467909, -2.8999966670226907`}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}, {
       6.839847225467909, -2.8999966670226907`}, {
       6.839847225467909, -2.8999966670226907`}}, {{
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}, {{
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}, {{
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}, {{
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}}, {{
       7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}, {{
       7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}, {{
       7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}, {{
       7.118474807603625, -3.060862376572401}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.118474807603625, -3.060862376572401}, {
       7.118474807603625, -3.060862376572401}}, {{
       7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}, {{
       7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}, {{
       7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}, {{
       7.065931083114673, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}, {
       7.065931083114673, -3.1095685943705247`}, {
       7.065931083114673, -3.1095685943705247`}}, {{
       6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}, {{
       6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}, {{
       6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}, {{
       6.997478398934764, -3.1307196856883457`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.904602538222859, -3.1095685943705247`}, {
       6.997478398934764, -3.1307196856883457`}, {
       6.997478398934764, -3.1307196856883457`}}, {{
       6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}, {{
       6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}, {{
       6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}, {{
       6.904602538222859, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}, {
       6.904602538222859, -2.830139357906746}, {
       6.904602538222859, -2.830139357906746}}, {{
       6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}, {{
       6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}, {{
       6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}, {{
       6.997478398934764, -2.808988266588925}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}, {
       6.997478398934764, -2.808988266588925}, {
       6.997478398934764, -2.808988266588925}}, {{
       7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}, {{
       7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}, {{
       7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}, {{
       7.065931083114673, -2.830139357906746}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.065931083114673, -2.830139357906746}, {
       7.065931083114673, -2.830139357906746}}, {{
       7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}, {{
       7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}, {{
       7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}, {{
       7.118474807603625, -2.8788455757048697`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.146595355560581, -2.9698539761386353`}, {
       7.118474807603625, -2.8788455757048697`}, {
       7.118474807603625, -2.8788455757048697`}}, {{
       6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}, {{
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}, {{
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}, {{
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}, {{
       6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}, {{
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}, {{
       6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}, {{
       6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}, {{
       6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}, {{
       6.903764400064638, -2.5828512607924385`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}}, {{
       6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}, {{
       6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}, {{
       6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}, {{
       6.843318232972852, -2.5176426099534828`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.5176426099534828`}, {
       6.843318232972852, -2.5176426099534828`}}, {{
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}, {{
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}, {{
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}, {{
       6.828467935833911, -2.452433959114527}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.828467935833911, -2.452433959114527}, {
       6.828467935833911, -2.452433959114527}}, {{
       6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}, {{
       6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}, {{
       6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}, {{
       6.843318232972852, -2.3872253082755712`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.843318232972852, -2.3872253082755712`}, {
       6.843318232972852, -2.3872253082755712`}}, {{
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}, {{
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}, {{
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}, {{
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}}, {{
       7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}, {{
       7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}, {{
       7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}, {{
       7.1034045281296665`, -2.5373862007968904`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.1034045281296665`, -2.5373862007968904`}, {
       7.1034045281296665`, -2.5373862007968904`}}, {{
       7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}, {{
       7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}, {{
       7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}, {{
       7.054357328526091, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}, {
       7.054357328526091, -2.5828512607924385`}, {
       7.054357328526091, -2.5828512607924385`}}, {{
       6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}, {{
       6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}, {{
       6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}, {{
       6.990459831783576, -2.602594851635846}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.903764400064638, -2.5828512607924385`}, {
       6.990459831783576, -2.602594851635846}, {
       6.990459831783576, -2.602594851635846}}, {{
       6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}, {{
       6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}, {{
       6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}, {{
       6.903764400064638, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}, {
       6.903764400064638, -2.3220166574366154`}, {
       6.903764400064638, -2.3220166574366154`}}, {{
       6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}, {{
       6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}, {{
       6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}, {{
       6.990459831783576, -2.302273066593208}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}, {
       6.990459831783576, -2.302273066593208}, {
       6.990459831783576, -2.302273066593208}}, {{
       7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}, {{
       7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}, {{
       7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}, {{
       7.054357328526091, -2.3220166574366154`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.054357328526091, -2.3220166574366154`}, {
       7.054357328526091, -2.3220166574366154`}}, {{
       7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}, {{
       7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}, {{
       7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}, {{
       7.1034045281296665`, -2.3674817174321636`}, {
       7.129653792756819, -2.452433959114527}, {
       7.129653792756819, -2.452433959114527}, {
       7.1034045281296665`, -2.3674817174321636`}, {
       7.1034045281296665`, -2.3674817174321636`}}, {{
       6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}, {{
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}, {{
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}, {{
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}, {{
       6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}, {{
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}, {{
       6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}, {{
       6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}, {{
       6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}, {{
       6.941008555276944, -2.141960975486927}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}}, {{
       6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}, {{
       6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}, {{
       6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}, {{
       6.880883121031052, -2.0770983276646513`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -2.0770983276646513`}, {
       6.880883121031052, -2.0770983276646513`}}, {{
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}, {{
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}, {{
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}, {{
       6.866111620915858, -2.0122356798423757`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.866111620915858, -2.0122356798423757`}, {
       6.866111620915858, -2.0122356798423757`}}, {{
       6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}, {{
       6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}, {{
       6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}, {{
       6.880883121031052, -1.9473730320201001`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.880883121031052, -1.9473730320201001`}, {
       6.880883121031052, -1.9473730320201001`}}, {{
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}, {{
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}, {{
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}, {{
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}}, {{
       7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}, {{
       7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}, {{
       7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}, {{
       7.139589374712331, -2.0967371572240263`}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}, {
       7.139589374712331, -2.0967371572240263`}, {
       7.139589374712331, -2.0967371572240263`}}, {{
       7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}, {{
       7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}, {{
       7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}, {{
       7.090802423999114, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.090802423999114, -2.141960975486927}, {
       7.090802423999114, -2.141960975486927}}, {{
       7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}, {{
       7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}, {{
       7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}, {{
       7.0272439731707035`, -2.161599805046302}, {
       6.941008555276944, -2.141960975486927}, {
       6.941008555276944, -2.141960975486927}, {
       7.0272439731707035`, -2.161599805046302}, {
       7.0272439731707035`, -2.161599805046302}}, {{
       6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}, {{
       6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}, {{
       6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}, {{
       6.941008555276944, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       6.941008555276944, -1.8825103841978246`}, {
       6.941008555276944, -1.8825103841978246`}}, {{
       7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}, {{
       7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}, {{
       7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}, {{
       7.0272439731707035`, -1.8628715546384493`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.0272439731707035`, -1.8628715546384493`}, {
       7.0272439731707035`, -1.8628715546384493`}}, {{
       7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}, {{
       7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}, {{
       7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}, {{
       7.090802423999114, -1.8825103841978246`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}, {
       7.090802423999114, -1.8825103841978246`}, {
       7.090802423999114, -1.8825103841978246`}}, {{
       7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}, {{
       7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}, {{
       7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}, {{
       7.139589374712331, -1.927734202460725}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.165699358360199, -2.0122356798423757`}, {
       7.139589374712331, -1.927734202460725}, {
       7.139589374712331, -1.927734202460725}}, {{
       6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}, {{
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}, {{
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}, {{
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}, {{
       6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}, {{
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}, {{
       6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}, {{
       6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}, {{
       6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}, {{
       6.879971894450916, -1.647632221859904}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}}, {{
       6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}, {{
       6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}, {{
       6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}, {{
       6.822340592680558, -1.5854602163325509`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.5854602163325509`}, {
       6.822340592680558, -1.5854602163325509`}}, {{
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}, {{
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}, {{
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}, {{
       6.808181846196364, -1.5232882108051977`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.808181846196364, -1.5232882108051977`}, {
       6.808181846196364, -1.5232882108051977`}}, {{
       6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}, {{
       6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}, {{
       6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}, {{
       6.822340592680558, -1.4611162052778446`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.822340592680558, -1.4611162052778446`}, {
       6.822340592680558, -1.4611162052778446`}}, {{
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}, {{
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}, {{
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}, {{
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}}, {{
       7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}, {{
       7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}, {{
       7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}, {{
       7.0703151539088385`, -1.6042843849551722`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}, {
       7.0703151539088385`, -1.6042843849551722`}, {
       7.0703151539088385`, -1.6042843849551722`}}, {{
       7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}, {{
       7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}, {{
       7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}, {{
       7.023551990960021, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}, {
       7.023551990960021, -1.647632221859904}, {
       7.023551990960021, -1.647632221859904}}, {{
       6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}, {{
       6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}, {{
       6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}, {{
       6.96263008152701, -1.6664563904825254`}, {
       6.879971894450916, -1.647632221859904}, {
       6.879971894450916, -1.647632221859904}, {
       6.96263008152701, -1.6664563904825254`}, {
       6.96263008152701, -1.6664563904825254`}}, {{
       6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}, {{
       6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}, {{
       6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}, {{
       6.879971894450916, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}, {
       6.879971894450916, -1.3989441997504914`}, {
       6.879971894450916, -1.3989441997504914`}}, {{
       6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}, {{
       6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}, {{
       6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}, {{
       6.96263008152701, -1.38012003112787}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}, {
       6.96263008152701, -1.38012003112787}, {
       6.96263008152701, -1.38012003112787}}, {{
       7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}, {{
       7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}, {{
       7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}, {{
       7.023551990960021, -1.3989441997504914`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.023551990960021, -1.3989441997504914`}, {
       7.023551990960021, -1.3989441997504914`}}, {{
       7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}, {{
       7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}, {{
       7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}, {{
       7.0703151539088385`, -1.4422920366552232`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.095342039214573, -1.5232882108051977`}, {
       7.0703151539088385`, -1.4422920366552232`}, {
       7.0703151539088385`, -1.4422920366552232`}}, {{
       6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}, {{
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}, {{
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}, {{
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}, {{
       6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}, {{
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}, {{
       6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}, {{
       6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}, {{
       6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}, {{
       6.881503775818905, -1.1456263124536281`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}}, {{
       6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}, {{
       6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}, {{
       6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}, {{
       6.8230855251182865`, -1.0826053551979808`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -1.0826053551979808`}, {
       6.8230855251182865`, -1.0826053551979808`}}, {{
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}, {{
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}, {{
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}, {{
       6.808733442546632, -1.0195843979423336`}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.808733442546632, -1.0195843979423336`}, {
       6.808733442546632, -1.0195843979423336`}}, {{
       6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}, {{
       6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}, {{
       6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}, {{
       6.8230855251182865`, -0.9565634406866863}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}, {
       6.8230855251182865`, -0.9565634406866863}, {
       6.8230855251182865`, -0.9565634406866863}}, {{
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}, {{
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}, {{
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}, {{
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}}, {{
       7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}, {{
       7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}, {{
       7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}, {{
       7.074446151031824, -1.1016865657215402`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.074446151031824, -1.1016865657215402`}, {
       7.074446151031824, -1.1016865657215402`}}, {{
       7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}, {{
       7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}, {{
       7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}, {{
       7.027044442363447, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}, {
       7.027044442363447, -1.1456263124536281`}, {
       7.027044442363447, -1.1456263124536281`}}, {{
       6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}, {{
       6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}, {{
       6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}, {{
       6.965290651123417, -1.1647075229771875`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.881503775818905, -1.1456263124536281`}, {
       6.965290651123417, -1.1647075229771875`}, {
       6.965290651123417, -1.1647075229771875`}}, {{
       6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}, {{
       6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}, {{
       6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}, {{
       6.881503775818905, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}, {
       6.881503775818905, -0.893542483431039}, {
       6.881503775818905, -0.893542483431039}}, {{
       6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}, {{
       6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}, {{
       6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}, {{
       6.965290651123417, -0.8744612729074797}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}, {
       6.965290651123417, -0.8744612729074797}, {
       6.965290651123417, -0.8744612729074797}}, {{
       7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}, {{
       7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}, {{
       7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}, {{
       7.027044442363447, -0.893542483431039}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}, {
       7.027044442363447, -0.893542483431039}, {
       7.027044442363447, -0.893542483431039}}, {{
       7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}, {{
       7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}, {{
       7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}, {{
       7.074446151031824, -0.9374822301631269}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.0998147756357195`, -1.0195843979423336`}, {
       7.074446151031824, -0.9374822301631269}, {
       7.074446151031824, -0.9374822301631269}}, {{
       6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.30890591666472045`}, {
       6.875436124385875, -0.30890591666472045`}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}, {{
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}, {{
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028113}, {
       6.875436124385875, -0.5947917849028113}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}, {{
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}, {{
       6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}, {{
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}, {{
       6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}, {{
       6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}, {{
       6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}, {{
       6.875436124385875, -0.5947917849028111}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}}, {{
       6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}, {{
       6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}, {{
       6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}, {{
       6.809184542968488, -0.5233203178432885}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.5233203178432885}, {
       6.809184542968488, -0.5233203178432885}}, {{
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}, {{
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}, {{
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}, {{
       6.792907982893489, -0.4518488507837658}, {
       6.809184542968488, -0.3803773837242431}, {
       6.809184542968488, -0.3803773837242431}, {
       6.792907982893489, -0.4518488507837658}, {
       6.792907982893489, -0.4518488507837658}}, {{
       6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}, {{
       6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}, {{
       6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}, {{
       6.809184542968488, -0.38037738372424307`}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}, {
       6.809184542968488, -0.38037738372424307`}, {
       6.809184542968488, -0.38037738372424307`}}, {{
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}, {{
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}, {{
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}, {{
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}}, {{
       7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}, {{
       7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}, {{
       7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}, {{
       7.094250233452436, -0.5449601368618767}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}, {
       7.094250233452436, -0.5449601368618767}, {
       7.094250233452436, -0.5449601368618767}}, {{
       7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}, {{
       7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}, {{
       7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}, {{
       7.040492407370646, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}, {
       7.040492407370646, -0.5947917849028111}, {
       7.040492407370646, -0.5947917849028111}}, {{
       6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}, {{
       6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}, {{
       6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}, {{
       6.970458021213857, -0.6164316039213994}, {
       6.875436124385875, -0.5947917849028111}, {
       6.875436124385875, -0.5947917849028111}, {
       6.970458021213857, -0.6164316039213994}, {
       6.970458021213857, -0.6164316039213994}}, {{
       6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}, {{
       6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}, {{
       6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}, {{
       6.875436124385875, -0.3089059166647204}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}, {
       6.875436124385875, -0.3089059166647204}, {
       6.875436124385875, -0.3089059166647204}}, {{
       6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}, {{
       6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}, {{
       6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}, {{
       6.970458021213857, -0.2872660976461322}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}, {
       6.970458021213857, -0.2872660976461322}, {
       6.970458021213857, -0.2872660976461322}}, {{
       7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}, {{
       7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}, {{
       7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}, {{
       7.040492407370646, -0.30890591666472045`}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}, {
       7.040492407370646, -0.30890591666472045`}, {
       7.040492407370646, -0.30890591666472045`}}, {{
       7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}, {{
       7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}, {{
       7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}, {{
       7.094250233452436, -0.3587375647056549}, {
       7.123020548863032, -0.4518488507837658}, {
       7.123020548863032, -0.4518488507837658}, {
       7.094250233452436, -0.3587375647056549}, {
       7.094250233452436, -0.3587375647056549}}, {{
       6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {6.920588730729565, 
       0.043846028048759644`}, {6.932075606427196, 0.09428566973331229}, {
       6.9788314121383745`, 0.1447253114178649}, {6.9788314121383745`, 
       0.1447253114178649}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635793}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}, {{6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}}, {{
       7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.05703325532034563}, {
       6.9788314121383745`, -0.05703325532034563}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}, {{
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}, {{6.9788314121383745`, 
       0.14472531141786493`}, {7.045891326050571, 0.15999720609587864`}, {
       7.095316774955993, 0.1447253114178649}, {7.133255348163785, 
       0.10955756441132598`}, {7.153559456364802, 0.04384602804875966}, {
       7.153559456364802, 0.04384602804875966}, {7.133255348163785, 
       0.10955756441132598`}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {6.9788314121383745`, 
       0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}}, {{
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}, {{6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}, {{
       6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}, {{
       6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}, {{
       6.9788314121383745`, -0.057033255320345616`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}}, {{
       6.932075606427196, -0.006593613635792986}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}, {{
       6.932075606427196, -0.006593613635792986}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}, {{
       6.932075606427196, -0.006593613635792986}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}, {{
       6.932075606427196, -0.006593613635792986}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, -0.006593613635792986}, {
       6.932075606427196, -0.006593613635792986}}, {{6.920588730729565, 
       0.043846028048759644`}, {6.932075606427196, 0.09428566973331227}, {
       6.932075606427196, 0.09428566973331227}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}}, {{
       6.920588730729565, 0.043846028048759644`}, {6.932075606427196, 
       0.09428566973331227}, {6.932075606427196, 0.09428566973331227}, {
       6.920588730729565, 0.043846028048759644`}, {6.920588730729565, 
       0.043846028048759644`}}, {{6.920588730729565, 0.043846028048759644`}, {
       6.932075606427196, 0.09428566973331227}, {6.932075606427196, 
       0.09428566973331227}, {6.920588730729565, 0.043846028048759644`}, {
       6.920588730729565, 0.043846028048759644`}}, {{6.920588730729565, 
       0.043846028048759644`}, {6.932075606427196, 0.09428566973331227}, {
       6.932075606427196, 0.09428566973331227}, {6.920588730729565, 
       0.043846028048759644`}, {6.920588730729565, 0.043846028048759644`}}, {{
       6.932075606427196, 0.09428566973331229}, {6.9788314121383745`, 
       0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.932075606427196, 0.09428566973331229}, {6.932075606427196, 
       0.09428566973331229}}, {{6.932075606427196, 0.09428566973331229}, {
       6.9788314121383745`, 0.14472531141786493`}, {6.9788314121383745`, 
       0.14472531141786493`}, {6.932075606427196, 0.09428566973331229}, {
       6.932075606427196, 0.09428566973331229}}, {{6.932075606427196, 
       0.09428566973331229}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}, {6.932075606427196, 
       0.09428566973331229}, {6.932075606427196, 0.09428566973331229}}, {{
       6.932075606427196, 0.09428566973331229}, {6.9788314121383745`, 
       0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.932075606427196, 0.09428566973331229}, {6.932075606427196, 
       0.09428566973331229}}, {{7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}, {{
       7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}, {{
       7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}, {{
       7.153559456364802, 0.04384602804875963}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}, {7.153559456364802, 
       0.04384602804875963}, {7.153559456364802, 0.04384602804875963}}, {{
       7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}, {{
       7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}, {{
       7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}, {{
       7.133255348163785, -0.021865508313806695`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.133255348163785, -0.021865508313806695`}, {
       7.133255348163785, -0.021865508313806695`}}, {{
       7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}, {{
       7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}, {{
       7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}, {{
       7.095316774955993, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}, {
       7.095316774955993, -0.057033255320345616`}, {
       7.095316774955993, -0.057033255320345616`}}, {{
       7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}, {{
       7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}, {{
       7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}, {{
       7.045891326050571, -0.07230514999835934}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       6.9788314121383745`, -0.057033255320345616`}, {
       7.045891326050571, -0.07230514999835934}, {
       7.045891326050571, -0.07230514999835934}}, {{6.9788314121383745`, 
       0.14472531141786493`}, {7.045891326050571, 0.15999720609587864`}, {
       7.045891326050571, 0.15999720609587864`}, {6.9788314121383745`, 
       0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}}, {{
       6.9788314121383745`, 0.14472531141786493`}, {7.045891326050571, 
       0.15999720609587864`}, {7.045891326050571, 0.15999720609587864`}, {
       6.9788314121383745`, 0.14472531141786493`}, {6.9788314121383745`, 
       0.14472531141786493`}}, {{6.9788314121383745`, 0.14472531141786493`}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}, {6.9788314121383745`, 0.14472531141786493`}, {
       6.9788314121383745`, 0.14472531141786493`}}, {{6.9788314121383745`, 
       0.14472531141786493`}, {7.045891326050571, 0.15999720609587864`}, {
       7.045891326050571, 0.15999720609587864`}, {6.9788314121383745`, 
       0.14472531141786493`}, {6.9788314121383745`, 0.14472531141786493`}}, {{
       7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}}, {{7.045891326050571, 0.15999720609587864`}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}, {7.045891326050571, 0.15999720609587864`}, {
       7.045891326050571, 0.15999720609587864`}}, {{7.045891326050571, 
       0.15999720609587864`}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}, {7.045891326050571, 
       0.15999720609587864`}, {7.045891326050571, 0.15999720609587864`}}, {{
       7.045891326050571, 0.15999720609587864`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}, {
       7.045891326050571, 0.15999720609587864`}, {7.045891326050571, 
       0.15999720609587864`}}, {{7.095316774955993, 0.1447253114178649}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}}, {{7.095316774955993, 
       0.1447253114178649}, {7.133255348163785, 0.10955756441132598`}, {
       7.133255348163785, 0.10955756441132598`}, {7.095316774955993, 
       0.1447253114178649}, {7.095316774955993, 0.1447253114178649}}, {{
       7.095316774955993, 0.1447253114178649}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}, {
       7.095316774955993, 0.1447253114178649}, {7.095316774955993, 
       0.1447253114178649}}, {{7.095316774955993, 0.1447253114178649}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}, {7.095316774955993, 0.1447253114178649}, {
       7.095316774955993, 0.1447253114178649}}, {{7.133255348163785, 
       0.10955756441132598`}, {7.153559456364802, 0.043846028048759624`}, {
       7.153559456364802, 0.043846028048759624`}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}}, {{
       7.133255348163785, 0.10955756441132598`}, {7.153559456364802, 
       0.043846028048759624`}, {7.153559456364802, 0.043846028048759624`}, {
       7.133255348163785, 0.10955756441132598`}, {7.133255348163785, 
       0.10955756441132598`}}, {{7.133255348163785, 0.10955756441132598`}, {
       7.153559456364802, 0.043846028048759624`}, {7.153559456364802, 
       0.043846028048759624`}, {7.133255348163785, 0.10955756441132598`}, {
       7.133255348163785, 0.10955756441132598`}}, {{7.133255348163785, 
       0.10955756441132598`}, {7.153559456364802, 0.043846028048759624`}, {
       7.153559456364802, 0.043846028048759624`}, {7.133255348163785, 
       0.10955756441132598`}, {7.133255348163785, 0.10955756441132598`}}, {{
       6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.839439546595807, 
       0.45437020003482936`}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}, {{6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}}, {{7.160497759051173, 
       0.45437020003482936`}, {7.132516558122411, 0.3638127776602549}, {
       7.080233205937332, 0.31534791599484513`}, {7.0121197284516485`, 
       0.2943016356402628}, {6.919704099709649, 0.31534791599484513`}, {
       6.919704099709649, 0.31534791599484513`}, {7.0121197284516485`, 
       0.2943016356402628}, {7.080233205937332, 0.31534791599484513`}, {
       7.132516558122411, 0.3638127776602549}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}}, {{
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}}, {{6.919704099709649, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.132516558122411, 0.5449276224094038}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}, {7.132516558122411, 0.5449276224094038}, {
       7.080233205937332, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {6.919704099709649, 0.5933924840748136}, {
       6.919704099709649, 0.5933924840748136}}, {{7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}}, {{
       6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}, {{6.919704099709649, 0.31534791599484513`}, {
       6.855269671896411, 0.3848590580148372}, {6.855269671896411, 
       0.3848590580148372}, {6.919704099709649, 0.31534791599484513`}, {
       6.919704099709649, 0.31534791599484513`}}, {{6.919704099709649, 
       0.31534791599484513`}, {6.855269671896411, 0.3848590580148372}, {
       6.855269671896411, 0.3848590580148372}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}}, {{
       6.919704099709649, 0.31534791599484513`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}}, {{6.855269671896411, 0.3848590580148372}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.855269671896411, 0.3848590580148372}, {
       6.855269671896411, 0.3848590580148372}}, {{6.855269671896411, 
       0.3848590580148372}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}, {6.855269671896411, 
       0.3848590580148372}, {6.855269671896411, 0.3848590580148372}}, {{
       6.855269671896411, 0.3848590580148372}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.3848590580148372}, {6.855269671896411, 
       0.3848590580148372}}, {{6.855269671896411, 0.3848590580148372}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}, {6.855269671896411, 0.3848590580148372}, {
       6.855269671896411, 0.3848590580148372}}, {{6.839439546595807, 
       0.45437020003482936`}, {6.855269671896411, 0.5238813420548215}, {
       6.855269671896411, 0.5238813420548215}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}}, {{
       6.839439546595807, 0.45437020003482936`}, {6.855269671896411, 
       0.5238813420548215}, {6.855269671896411, 0.5238813420548215}, {
       6.839439546595807, 0.45437020003482936`}, {6.839439546595807, 
       0.45437020003482936`}}, {{6.839439546595807, 0.45437020003482936`}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}, {6.839439546595807, 0.45437020003482936`}, {
       6.839439546595807, 0.45437020003482936`}}, {{6.839439546595807, 
       0.45437020003482936`}, {6.855269671896411, 0.5238813420548215}, {
       6.855269671896411, 0.5238813420548215}, {6.839439546595807, 
       0.45437020003482936`}, {6.839439546595807, 0.45437020003482936`}}, {{
       6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}}, {{6.855269671896411, 0.5238813420548215}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}, {6.855269671896411, 0.5238813420548215}, {
       6.855269671896411, 0.5238813420548215}}, {{6.855269671896411, 
       0.5238813420548215}, {6.919704099709649, 0.5933924840748136}, {
       6.919704099709649, 0.5933924840748136}, {6.855269671896411, 
       0.5238813420548215}, {6.855269671896411, 0.5238813420548215}}, {{
       6.855269671896411, 0.5238813420548215}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}, {
       6.855269671896411, 0.5238813420548215}, {6.855269671896411, 
       0.5238813420548215}}, {{7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}, {7.160497759051173, 0.45437020003482936`}, {
       7.160497759051173, 0.45437020003482936`}}, {{7.160497759051173, 
       0.45437020003482936`}, {7.132516558122411, 0.3638127776602549}, {
       7.132516558122411, 0.3638127776602549}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}}, {{
       7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}}, {{7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}, {7.160497759051173, 0.45437020003482936`}, {
       7.160497759051173, 0.45437020003482936`}}, {{7.132516558122411, 
       0.3638127776602549}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}}, {{
       7.132516558122411, 0.3638127776602549}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}, {
       7.132516558122411, 0.3638127776602549}, {7.132516558122411, 
       0.3638127776602549}}, {{7.132516558122411, 0.3638127776602549}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}, {7.132516558122411, 0.3638127776602549}, {
       7.132516558122411, 0.3638127776602549}}, {{7.132516558122411, 
       0.3638127776602549}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}, {7.132516558122411, 
       0.3638127776602549}, {7.132516558122411, 0.3638127776602549}}, {{
       7.080233205937332, 0.31534791599484513`}, {7.0121197284516485`, 
       0.2943016356402628}, {7.0121197284516485`, 0.2943016356402628}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}}, {{7.080233205937332, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}, {7.080233205937332, 0.31534791599484513`}, {
       7.080233205937332, 0.31534791599484513`}}, {{7.080233205937332, 
       0.31534791599484513`}, {7.0121197284516485`, 0.2943016356402628}, {
       7.0121197284516485`, 0.2943016356402628}, {7.080233205937332, 
       0.31534791599484513`}, {7.080233205937332, 0.31534791599484513`}}, {{
       7.080233205937332, 0.31534791599484513`}, {7.0121197284516485`, 
       0.2943016356402628}, {7.0121197284516485`, 0.2943016356402628}, {
       7.080233205937332, 0.31534791599484513`}, {7.080233205937332, 
       0.31534791599484513`}}, {{7.0121197284516485`, 0.2943016356402628}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}, {7.0121197284516485`, 0.2943016356402628}, {
       7.0121197284516485`, 0.2943016356402628}}, {{7.0121197284516485`, 
       0.2943016356402628}, {6.919704099709649, 0.31534791599484513`}, {
       6.919704099709649, 0.31534791599484513`}, {7.0121197284516485`, 
       0.2943016356402628}, {7.0121197284516485`, 0.2943016356402628}}, {{
       7.0121197284516485`, 0.2943016356402628}, {6.919704099709649, 
       0.31534791599484513`}, {6.919704099709649, 0.31534791599484513`}, {
       7.0121197284516485`, 0.2943016356402628}, {7.0121197284516485`, 
       0.2943016356402628}}, {{7.0121197284516485`, 0.2943016356402628}, {
       6.919704099709649, 0.31534791599484513`}, {6.919704099709649, 
       0.31534791599484513`}, {7.0121197284516485`, 0.2943016356402628}, {
       7.0121197284516485`, 0.2943016356402628}}, {{6.919704099709649, 
       0.5933924840748136}, {7.0121197284516485`, 0.6144387644293959}, {
       7.0121197284516485`, 0.6144387644293959}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}}, {{
       6.919704099709649, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.0121197284516485`, 0.6144387644293959}, {
       6.919704099709649, 0.5933924840748136}, {6.919704099709649, 
       0.5933924840748136}}, {{6.919704099709649, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}, {6.919704099709649, 0.5933924840748136}, {
       6.919704099709649, 0.5933924840748136}}, {{6.919704099709649, 
       0.5933924840748136}, {7.0121197284516485`, 0.6144387644293959}, {
       7.0121197284516485`, 0.6144387644293959}, {6.919704099709649, 
       0.5933924840748136}, {6.919704099709649, 0.5933924840748136}}, {{
       7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}}, {{7.0121197284516485`, 0.6144387644293959}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}, {7.0121197284516485`, 0.6144387644293959}, {
       7.0121197284516485`, 0.6144387644293959}}, {{7.0121197284516485`, 
       0.6144387644293959}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}, {7.0121197284516485`, 
       0.6144387644293959}, {7.0121197284516485`, 0.6144387644293959}}, {{
       7.0121197284516485`, 0.6144387644293959}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}, {
       7.0121197284516485`, 0.6144387644293959}, {7.0121197284516485`, 
       0.6144387644293959}}, {{7.080233205937332, 0.5933924840748136}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}}, {{7.080233205937332, 
       0.5933924840748136}, {7.132516558122411, 0.5449276224094038}, {
       7.132516558122411, 0.5449276224094038}, {7.080233205937332, 
       0.5933924840748136}, {7.080233205937332, 0.5933924840748136}}, {{
       7.080233205937332, 0.5933924840748136}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}, {
       7.080233205937332, 0.5933924840748136}, {7.080233205937332, 
       0.5933924840748136}}, {{7.080233205937332, 0.5933924840748136}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}, {7.080233205937332, 0.5933924840748136}, {
       7.080233205937332, 0.5933924840748136}}, {{7.132516558122411, 
       0.5449276224094038}, {7.160497759051173, 0.45437020003482936`}, {
       7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}}, {{
       7.132516558122411, 0.5449276224094038}, {7.160497759051173, 
       0.45437020003482936`}, {7.160497759051173, 0.45437020003482936`}, {
       7.132516558122411, 0.5449276224094038}, {7.132516558122411, 
       0.5449276224094038}}, {{7.132516558122411, 0.5449276224094038}, {
       7.160497759051173, 0.45437020003482936`}, {7.160497759051173, 
       0.45437020003482936`}, {7.132516558122411, 0.5449276224094038}, {
       7.132516558122411, 0.5449276224094038}}, {{7.132516558122411, 
       0.5449276224094038}, {7.160497759051173, 0.45437020003482936`}, {
       7.160497759051173, 0.45437020003482936`}, {7.132516558122411, 
       0.5449276224094038}, {7.132516558122411, 0.5449276224094038}}, {{
       6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.8584762192425, 
       0.9930056619992144}, {6.873868754997188, 0.9254160050271929}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}, {{6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}}, {{7.170659472420348, 
       0.9930056619992144}, {7.143451751219389, 0.9049515035334025}, {
       7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {6.936522032536962, 0.8578263480551716}, {
       6.936522032536962, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.092613659125886, 0.8578263480551716}, {
       7.143451751219389, 0.9049515035334025}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}}, {{
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}, {{6.936522032536962, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.143451751219389, 1.0810598204650264`}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}, {7.143451751219389, 1.0810598204650264`}, {
       7.092613659125886, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {6.936522032536962, 1.1281849759432572`}, {
       6.936522032536962, 1.1281849759432572`}}, {{7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}}, {{
       6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}, {{6.936522032536962, 0.8578263480551716}, {
       6.873868754997188, 0.925416005027193}, {6.873868754997188, 
       0.925416005027193}, {6.936522032536962, 0.8578263480551716}, {
       6.936522032536962, 0.8578263480551716}}, {{6.936522032536962, 
       0.8578263480551716}, {6.873868754997188, 0.925416005027193}, {
       6.873868754997188, 0.925416005027193}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}}, {{
       6.936522032536962, 0.8578263480551716}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}}, {{6.873868754997188, 0.925416005027193}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.873868754997188, 0.925416005027193}, {
       6.873868754997188, 0.925416005027193}}, {{6.873868754997188, 
       0.925416005027193}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}, {6.873868754997188, 
       0.925416005027193}, {6.873868754997188, 0.925416005027193}}, {{
       6.873868754997188, 0.925416005027193}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 0.925416005027193}, {6.873868754997188, 
       0.925416005027193}}, {{6.873868754997188, 0.925416005027193}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}, {6.873868754997188, 0.925416005027193}, {
       6.873868754997188, 0.925416005027193}}, {{6.8584762192425, 
       0.9930056619992144}, {6.873868754997188, 1.0605953189712358`}, {
       6.873868754997188, 1.0605953189712358`}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}}, {{
       6.8584762192425, 0.9930056619992144}, {6.873868754997188, 
       1.0605953189712358`}, {6.873868754997188, 1.0605953189712358`}, {
       6.8584762192425, 0.9930056619992144}, {6.8584762192425, 
       0.9930056619992144}}, {{6.8584762192425, 0.9930056619992144}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}, {6.8584762192425, 0.9930056619992144}, {
       6.8584762192425, 0.9930056619992144}}, {{6.8584762192425, 
       0.9930056619992144}, {6.873868754997188, 1.0605953189712358`}, {
       6.873868754997188, 1.0605953189712358`}, {6.8584762192425, 
       0.9930056619992144}, {6.8584762192425, 0.9930056619992144}}, {{
       6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}}, {{6.873868754997188, 1.0605953189712358`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}, {6.873868754997188, 1.0605953189712358`}, {
       6.873868754997188, 1.0605953189712358`}}, {{6.873868754997188, 
       1.0605953189712358`}, {6.936522032536962, 1.1281849759432572`}, {
       6.936522032536962, 1.1281849759432572`}, {6.873868754997188, 
       1.0605953189712358`}, {6.873868754997188, 1.0605953189712358`}}, {{
       6.873868754997188, 1.0605953189712358`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}, {
       6.873868754997188, 1.0605953189712358`}, {6.873868754997188, 
       1.0605953189712358`}}, {{7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}, {7.170659472420348, 0.9930056619992144}, {
       7.170659472420348, 0.9930056619992144}}, {{7.170659472420348, 
       0.9930056619992144}, {7.143451751219389, 0.9049515035334025}, {
       7.143451751219389, 0.9049515035334025}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}}, {{
       7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}}, {{7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}, {7.170659472420348, 0.9930056619992144}, {
       7.170659472420348, 0.9930056619992144}}, {{7.143451751219389, 
       0.9049515035334025}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}}, {{
       7.143451751219389, 0.9049515035334025}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}, {
       7.143451751219389, 0.9049515035334025}, {7.143451751219389, 
       0.9049515035334025}}, {{7.143451751219389, 0.9049515035334025}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}, {7.143451751219389, 0.9049515035334025}, {
       7.143451751219389, 0.9049515035334025}}, {{7.143451751219389, 
       0.9049515035334025}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}, {7.143451751219389, 
       0.9049515035334025}, {7.143451751219389, 0.9049515035334025}}, {{
       7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}, {{7.092613659125886, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.026383031277695, 
       0.837361846561381}, {7.092613659125886, 0.8578263480551716}, {
       7.092613659125886, 0.8578263480551716}}, {{7.092613659125886, 
       0.8578263480551716}, {7.026383031277695, 0.837361846561381}, {
       7.026383031277695, 0.837361846561381}, {7.092613659125886, 
       0.8578263480551716}, {7.092613659125886, 0.8578263480551716}}, {{
       7.092613659125886, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}, {
       7.092613659125886, 0.8578263480551716}, {7.092613659125886, 
       0.8578263480551716}}, {{7.026383031277695, 0.837361846561381}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}, {7.026383031277695, 0.837361846561381}, {
       7.026383031277695, 0.837361846561381}}, {{7.026383031277695, 
       0.837361846561381}, {6.936522032536962, 0.8578263480551716}, {
       6.936522032536962, 0.8578263480551716}, {7.026383031277695, 
       0.837361846561381}, {7.026383031277695, 0.837361846561381}}, {{
       7.026383031277695, 0.837361846561381}, {6.936522032536962, 
       0.8578263480551716}, {6.936522032536962, 0.8578263480551716}, {
       7.026383031277695, 0.837361846561381}, {7.026383031277695, 
       0.837361846561381}}, {{7.026383031277695, 0.837361846561381}, {
       6.936522032536962, 0.8578263480551716}, {6.936522032536962, 
       0.8578263480551716}, {7.026383031277695, 0.837361846561381}, {
       7.026383031277695, 0.837361846561381}}, {{6.936522032536962, 
       1.1281849759432572`}, {7.026383031277695, 1.1486494774370477`}, {
       7.026383031277695, 1.1486494774370477`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}}, {{
       6.936522032536962, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.026383031277695, 1.1486494774370477`}, {
       6.936522032536962, 1.1281849759432572`}, {6.936522032536962, 
       1.1281849759432572`}}, {{6.936522032536962, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}, {6.936522032536962, 1.1281849759432572`}, {
       6.936522032536962, 1.1281849759432572`}}, {{6.936522032536962, 
       1.1281849759432572`}, {7.026383031277695, 1.1486494774370477`}, {
       7.026383031277695, 1.1486494774370477`}, {6.936522032536962, 
       1.1281849759432572`}, {6.936522032536962, 1.1281849759432572`}}, {{
       7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}}, {{7.026383031277695, 1.1486494774370477`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}, {7.026383031277695, 1.1486494774370477`}, {
       7.026383031277695, 1.1486494774370477`}}, {{7.026383031277695, 
       1.1486494774370477`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}, {7.026383031277695, 
       1.1486494774370477`}, {7.026383031277695, 1.1486494774370477`}}, {{
       7.026383031277695, 1.1486494774370477`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}, {
       7.026383031277695, 1.1486494774370477`}, {7.026383031277695, 
       1.1486494774370477`}}, {{7.092613659125886, 1.1281849759432572`}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}}, {{7.092613659125886, 
       1.1281849759432572`}, {7.143451751219389, 1.0810598204650264`}, {
       7.143451751219389, 1.0810598204650264`}, {7.092613659125886, 
       1.1281849759432572`}, {7.092613659125886, 1.1281849759432572`}}, {{
       7.092613659125886, 1.1281849759432572`}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}, {
       7.092613659125886, 1.1281849759432572`}, {7.092613659125886, 
       1.1281849759432572`}}, {{7.092613659125886, 1.1281849759432572`}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}, {7.092613659125886, 1.1281849759432572`}, {
       7.092613659125886, 1.1281849759432572`}}, {{7.143451751219389, 
       1.0810598204650264`}, {7.170659472420348, 0.9930056619992144}, {
       7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}}, {{
       7.143451751219389, 1.0810598204650264`}, {7.170659472420348, 
       0.9930056619992144}, {7.170659472420348, 0.9930056619992144}, {
       7.143451751219389, 1.0810598204650264`}, {7.143451751219389, 
       1.0810598204650264`}}, {{7.143451751219389, 1.0810598204650264`}, {
       7.170659472420348, 0.9930056619992144}, {7.170659472420348, 
       0.9930056619992144}, {7.143451751219389, 1.0810598204650264`}, {
       7.143451751219389, 1.0810598204650264`}}, {{7.143451751219389, 
       1.0810598204650264`}, {7.170659472420348, 0.9930056619992144}, {
       7.170659472420348, 0.9930056619992144}, {7.143451751219389, 
       1.0810598204650264`}, {7.143451751219389, 1.0810598204650264`}}, {{
       6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.820735941120695, 
       1.5167738208779487`}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}, {{6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}}, {{7.0938812618758895`, 
       1.5167738208779487`}, {7.070075815367136, 1.43973067037855}, {
       7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.889022271309494, 1.3984984275285253`}, {
       6.889022271309494, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {7.025594931687091, 1.3984984275285253`}, {
       7.070075815367136, 1.43973067037855}, {7.0938812618758895`, 
       1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}}, {{
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}, {{6.889022271309494, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.070075815367136, 1.5938169713773473`}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}, {7.070075815367136, 1.5938169713773473`}, {
       7.025594931687091, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.889022271309494, 1.635049214227372}, {
       6.889022271309494, 1.635049214227372}}, {{7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}}, {{
       6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}, {{6.889022271309494, 1.3984984275285253`}, {
       6.834203669043804, 1.457636124203237}, {6.834203669043804, 
       1.457636124203237}, {6.889022271309494, 1.3984984275285253`}, {
       6.889022271309494, 1.3984984275285253`}}, {{6.889022271309494, 
       1.3984984275285253`}, {6.834203669043804, 1.457636124203237}, {
       6.834203669043804, 1.457636124203237}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}}, {{
       6.889022271309494, 1.3984984275285253`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}}, {{6.834203669043804, 1.457636124203237}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.834203669043804, 1.457636124203237}, {
       6.834203669043804, 1.457636124203237}}, {{6.834203669043804, 
       1.457636124203237}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}, {6.834203669043804, 
       1.457636124203237}, {6.834203669043804, 1.457636124203237}}, {{
       6.834203669043804, 1.457636124203237}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.457636124203237}, {6.834203669043804, 
       1.457636124203237}}, {{6.834203669043804, 1.457636124203237}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}, {6.834203669043804, 1.457636124203237}, {
       6.834203669043804, 1.457636124203237}}, {{6.820735941120695, 
       1.5167738208779487`}, {6.834203669043804, 1.5759115175526603`}, {
       6.834203669043804, 1.5759115175526603`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}}, {{
       6.820735941120695, 1.5167738208779487`}, {6.834203669043804, 
       1.5759115175526603`}, {6.834203669043804, 1.5759115175526603`}, {
       6.820735941120695, 1.5167738208779487`}, {6.820735941120695, 
       1.5167738208779487`}}, {{6.820735941120695, 1.5167738208779487`}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}, {6.820735941120695, 1.5167738208779487`}, {
       6.820735941120695, 1.5167738208779487`}}, {{6.820735941120695, 
       1.5167738208779487`}, {6.834203669043804, 1.5759115175526603`}, {
       6.834203669043804, 1.5759115175526603`}, {6.820735941120695, 
       1.5167738208779487`}, {6.820735941120695, 1.5167738208779487`}}, {{
       6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}}, {{6.834203669043804, 1.5759115175526603`}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}, {6.834203669043804, 1.5759115175526603`}, {
       6.834203669043804, 1.5759115175526603`}}, {{6.834203669043804, 
       1.5759115175526603`}, {6.889022271309494, 1.635049214227372}, {
       6.889022271309494, 1.635049214227372}, {6.834203669043804, 
       1.5759115175526603`}, {6.834203669043804, 1.5759115175526603`}}, {{
       6.834203669043804, 1.5759115175526603`}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}, {
       6.834203669043804, 1.5759115175526603`}, {6.834203669043804, 
       1.5759115175526603`}}, {{7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.0938812618758895`, 1.5167738208779487`}}, {{7.0938812618758895`, 
       1.5167738208779487`}, {7.070075815367136, 1.43973067037855}, {
       7.070075815367136, 1.43973067037855}, {7.0938812618758895`, 
       1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}}, {{
       7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136, 
       1.43973067037855}, {7.070075815367136, 1.43973067037855}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}}, {{7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.0938812618758895`, 1.5167738208779487`}}, {{7.070075815367136, 
       1.43973067037855}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.070075815367136, 
       1.43973067037855}, {7.070075815367136, 1.43973067037855}}, {{
       7.070075815367136, 1.43973067037855}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}, {
       7.070075815367136, 1.43973067037855}, {7.070075815367136, 
       1.43973067037855}}, {{7.070075815367136, 1.43973067037855}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}, {7.070075815367136, 1.43973067037855}, {
       7.070075815367136, 1.43973067037855}}, {{7.070075815367136, 
       1.43973067037855}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}, {7.070075815367136, 
       1.43973067037855}, {7.070075815367136, 1.43973067037855}}, {{
       7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}, {{7.025594931687091, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.967646320083938, 
       1.3805929737038383`}, {7.025594931687091, 1.3984984275285253`}, {
       7.025594931687091, 1.3984984275285253`}}, {{7.025594931687091, 
       1.3984984275285253`}, {6.967646320083938, 1.3805929737038383`}, {
       6.967646320083938, 1.3805929737038383`}, {7.025594931687091, 
       1.3984984275285253`}, {7.025594931687091, 1.3984984275285253`}}, {{
       7.025594931687091, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}, {
       7.025594931687091, 1.3984984275285253`}, {7.025594931687091, 
       1.3984984275285253`}}, {{6.967646320083938, 1.3805929737038383`}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}, {6.967646320083938, 1.3805929737038383`}, {
       6.967646320083938, 1.3805929737038383`}}, {{6.967646320083938, 
       1.3805929737038383`}, {6.889022271309494, 1.3984984275285253`}, {
       6.889022271309494, 1.3984984275285253`}, {6.967646320083938, 
       1.3805929737038383`}, {6.967646320083938, 1.3805929737038383`}}, {{
       6.967646320083938, 1.3805929737038383`}, {6.889022271309494, 
       1.3984984275285253`}, {6.889022271309494, 1.3984984275285253`}, {
       6.967646320083938, 1.3805929737038383`}, {6.967646320083938, 
       1.3805929737038383`}}, {{6.967646320083938, 1.3805929737038383`}, {
       6.889022271309494, 1.3984984275285253`}, {6.889022271309494, 
       1.3984984275285253`}, {6.967646320083938, 1.3805929737038383`}, {
       6.967646320083938, 1.3805929737038383`}}, {{6.889022271309494, 
       1.635049214227372}, {6.967646320083938, 1.652954668052059}, {
       6.967646320083938, 1.652954668052059}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}}, {{
       6.889022271309494, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.967646320083938, 1.652954668052059}, {
       6.889022271309494, 1.635049214227372}, {6.889022271309494, 
       1.635049214227372}}, {{6.889022271309494, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}, {6.889022271309494, 1.635049214227372}, {
       6.889022271309494, 1.635049214227372}}, {{6.889022271309494, 
       1.635049214227372}, {6.967646320083938, 1.652954668052059}, {
       6.967646320083938, 1.652954668052059}, {6.889022271309494, 
       1.635049214227372}, {6.889022271309494, 1.635049214227372}}, {{
       6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}}, {{6.967646320083938, 1.652954668052059}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}, {6.967646320083938, 1.652954668052059}, {
       6.967646320083938, 1.652954668052059}}, {{6.967646320083938, 
       1.652954668052059}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}, {6.967646320083938, 
       1.652954668052059}, {6.967646320083938, 1.652954668052059}}, {{
       6.967646320083938, 1.652954668052059}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}, {
       6.967646320083938, 1.652954668052059}, {6.967646320083938, 
       1.652954668052059}}, {{7.025594931687091, 1.635049214227372}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}}, {{7.025594931687091, 
       1.635049214227372}, {7.070075815367136, 1.5938169713773473`}, {
       7.070075815367136, 1.5938169713773473`}, {7.025594931687091, 
       1.635049214227372}, {7.025594931687091, 1.635049214227372}}, {{
       7.025594931687091, 1.635049214227372}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}, {
       7.025594931687091, 1.635049214227372}, {7.025594931687091, 
       1.635049214227372}}, {{7.025594931687091, 1.635049214227372}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}, {7.025594931687091, 1.635049214227372}, {
       7.025594931687091, 1.635049214227372}}, {{7.070075815367136, 
       1.5938169713773473`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}}, {{
       7.070075815367136, 1.5938169713773473`}, {7.0938812618758895`, 
       1.5167738208779487`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.070075815367136, 1.5938169713773473`}, {7.070075815367136, 
       1.5938169713773473`}}, {{7.070075815367136, 1.5938169713773473`}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.0938812618758895`, 
       1.5167738208779487`}, {7.070075815367136, 1.5938169713773473`}, {
       7.070075815367136, 1.5938169713773473`}}, {{7.070075815367136, 
       1.5938169713773473`}, {7.0938812618758895`, 1.5167738208779487`}, {
       7.0938812618758895`, 1.5167738208779487`}, {7.070075815367136, 
       1.5938169713773473`}, {7.070075815367136, 1.5938169713773473`}}, {{
       6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043, 
       1.9931407504512633`}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.844163433560921, 
       2.04786617070403}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}, {{6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}}, {{7.096929322476524, 
       2.04786617070403}, {7.074900005513737, 1.9765712264340805`}, {
       7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {7.033737850247623, 1.9384153301984968`}, {
       7.074900005513737, 1.9765712264340805`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}}, {{
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}, {{6.9073549057898225`, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.074900005513737, 2.1191611149739793`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}, {7.074900005513737, 2.1191611149739793`}, {
       7.033737850247623, 2.1573170112095634`}, {6.980112797170388, 
       2.173886535226746}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.9073549057898225`, 2.1573170112095634`}}, {{7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}}, {{
       6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043, 
       1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}, {{6.9073549057898225`, 1.9384153301984968`}, {
       6.856626331372043, 1.9931407504512633`}, {6.856626331372043, 
       1.9931407504512633`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.9073549057898225`, 1.9384153301984968`}}, {{6.9073549057898225`, 
       1.9384153301984968`}, {6.856626331372043, 1.9931407504512633`}, {
       6.856626331372043, 1.9931407504512633`}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}}, {{
       6.9073549057898225`, 1.9384153301984968`}, {6.856626331372043, 
       1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}}, {{6.856626331372043, 1.9931407504512633`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.856626331372043, 1.9931407504512633`}, {
       6.856626331372043, 1.9931407504512633`}}, {{6.856626331372043, 
       1.9931407504512633`}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}, {6.856626331372043, 
       1.9931407504512633`}, {6.856626331372043, 1.9931407504512633`}}, {{
       6.856626331372043, 1.9931407504512633`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 1.9931407504512633`}, {6.856626331372043, 
       1.9931407504512633`}}, {{6.856626331372043, 1.9931407504512633`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}, {6.856626331372043, 1.9931407504512633`}, {
       6.856626331372043, 1.9931407504512633`}}, {{6.844163433560921, 
       2.04786617070403}, {6.856626331372043, 2.1025915909567967`}, {
       6.856626331372043, 2.1025915909567967`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}}, {{
       6.844163433560921, 2.04786617070403}, {6.856626331372043, 
       2.1025915909567967`}, {6.856626331372043, 2.1025915909567967`}, {
       6.844163433560921, 2.04786617070403}, {6.844163433560921, 
       2.04786617070403}}, {{6.844163433560921, 2.04786617070403}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}, {6.844163433560921, 2.04786617070403}, {
       6.844163433560921, 2.04786617070403}}, {{6.844163433560921, 
       2.04786617070403}, {6.856626331372043, 2.1025915909567967`}, {
       6.856626331372043, 2.1025915909567967`}, {6.844163433560921, 
       2.04786617070403}, {6.844163433560921, 2.04786617070403}}, {{
       6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}}, {{6.856626331372043, 2.1025915909567967`}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.856626331372043, 2.1025915909567967`}, {
       6.856626331372043, 2.1025915909567967`}}, {{6.856626331372043, 
       2.1025915909567967`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.856626331372043, 
       2.1025915909567967`}, {6.856626331372043, 2.1025915909567967`}}, {{
       6.856626331372043, 2.1025915909567967`}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.856626331372043, 2.1025915909567967`}, {6.856626331372043, 
       2.1025915909567967`}}, {{7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}, {7.096929322476524, 2.04786617070403}, {
       7.096929322476524, 2.04786617070403}}, {{7.096929322476524, 
       2.04786617070403}, {7.074900005513737, 1.9765712264340805`}, {
       7.074900005513737, 1.9765712264340805`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}}, {{
       7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}}, {{7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}, {7.096929322476524, 2.04786617070403}, {
       7.096929322476524, 2.04786617070403}}, {{7.074900005513737, 
       1.9765712264340805`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}}, {{
       7.074900005513737, 1.9765712264340805`}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}, {
       7.074900005513737, 1.9765712264340805`}, {7.074900005513737, 
       1.9765712264340805`}}, {{7.074900005513737, 1.9765712264340805`}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}, {7.074900005513737, 1.9765712264340805`}, {
       7.074900005513737, 1.9765712264340805`}}, {{7.074900005513737, 
       1.9765712264340805`}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}, {7.074900005513737, 
       1.9765712264340805`}, {7.074900005513737, 1.9765712264340805`}}, {{
       7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}, {{7.033737850247623, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.980112797170388, 
       1.921845806181314}, {7.033737850247623, 1.9384153301984968`}, {
       7.033737850247623, 1.9384153301984968`}}, {{7.033737850247623, 
       1.9384153301984968`}, {6.980112797170388, 1.921845806181314}, {
       6.980112797170388, 1.921845806181314}, {7.033737850247623, 
       1.9384153301984968`}, {7.033737850247623, 1.9384153301984968`}}, {{
       7.033737850247623, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}, {
       7.033737850247623, 1.9384153301984968`}, {7.033737850247623, 
       1.9384153301984968`}}, {{6.980112797170388, 1.921845806181314}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.980112797170388, 1.921845806181314}, {
       6.980112797170388, 1.921845806181314}}, {{6.980112797170388, 
       1.921845806181314}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.980112797170388, 
       1.921845806181314}, {6.980112797170388, 1.921845806181314}}, {{
       6.980112797170388, 1.921845806181314}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.9073549057898225`, 1.9384153301984968`}, {
       6.980112797170388, 1.921845806181314}, {6.980112797170388, 
       1.921845806181314}}, {{6.980112797170388, 1.921845806181314}, {
       6.9073549057898225`, 1.9384153301984968`}, {6.9073549057898225`, 
       1.9384153301984968`}, {6.980112797170388, 1.921845806181314}, {
       6.980112797170388, 1.921845806181314}}, {{6.9073549057898225`, 
       2.1573170112095634`}, {6.980112797170388, 2.173886535226746}, {
       6.980112797170388, 2.173886535226746}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}}, {{
       6.9073549057898225`, 2.1573170112095634`}, {6.980112797170388, 
       2.173886535226746}, {6.980112797170388, 2.173886535226746}, {
       6.9073549057898225`, 2.1573170112095634`}, {6.9073549057898225`, 
       2.1573170112095634`}}, {{6.9073549057898225`, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}, {6.9073549057898225`, 2.1573170112095634`}, {
       6.9073549057898225`, 2.1573170112095634`}}, {{6.9073549057898225`, 
       2.1573170112095634`}, {6.980112797170388, 2.173886535226746}, {
       6.980112797170388, 2.173886535226746}, {6.9073549057898225`, 
       2.1573170112095634`}, {6.9073549057898225`, 2.1573170112095634`}}, {{
       6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}}, {{6.980112797170388, 2.173886535226746}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}, {6.980112797170388, 2.173886535226746}, {
       6.980112797170388, 2.173886535226746}}, {{6.980112797170388, 
       2.173886535226746}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}, {6.980112797170388, 
       2.173886535226746}, {6.980112797170388, 2.173886535226746}}, {{
       6.980112797170388, 2.173886535226746}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}, {
       6.980112797170388, 2.173886535226746}, {6.980112797170388, 
       2.173886535226746}}, {{7.033737850247623, 2.1573170112095634`}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}}, {{7.033737850247623, 
       2.1573170112095634`}, {7.074900005513737, 2.1191611149739793`}, {
       7.074900005513737, 2.1191611149739793`}, {7.033737850247623, 
       2.1573170112095634`}, {7.033737850247623, 2.1573170112095634`}}, {{
       7.033737850247623, 2.1573170112095634`}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}, {
       7.033737850247623, 2.1573170112095634`}, {7.033737850247623, 
       2.1573170112095634`}}, {{7.033737850247623, 2.1573170112095634`}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}, {7.033737850247623, 2.1573170112095634`}, {
       7.033737850247623, 2.1573170112095634`}}, {{7.074900005513737, 
       2.1191611149739793`}, {7.096929322476524, 2.04786617070403}, {
       7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}}, {{
       7.074900005513737, 2.1191611149739793`}, {7.096929322476524, 
       2.04786617070403}, {7.096929322476524, 2.04786617070403}, {
       7.074900005513737, 2.1191611149739793`}, {7.074900005513737, 
       2.1191611149739793`}}, {{7.074900005513737, 2.1191611149739793`}, {
       7.096929322476524, 2.04786617070403}, {7.096929322476524, 
       2.04786617070403}, {7.074900005513737, 2.1191611149739793`}, {
       7.074900005513737, 2.1191611149739793`}}, {{7.074900005513737, 
       2.1191611149739793`}, {7.096929322476524, 2.04786617070403}, {
       7.096929322476524, 2.04786617070403}, {7.074900005513737, 
       2.1191611149739793`}, {7.074900005513737, 2.1191611149739793`}}, {{
       6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.824702632571057, 
       2.480908611991962}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}, {{6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}}, {{7.135001115963513, 
       2.480908611991962}, {7.107957658189009, 2.3933860701829213`}, {
       7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.902277253419171, 2.3465454273051365`}, {
       6.902277253419171, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {7.0574264951154, 2.3465454273051365`}, {
       7.107957658189009, 2.3933860701829213`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}}, {{
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}, {{6.902277253419171, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.107957658189009, 2.5684311538010025`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}, {7.107957658189009, 2.5684311538010025`}, {
       7.0574264951154, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.902277253419171, 2.6152717966787873`}, {
       6.902277253419171, 2.6152717966787873`}}, {{7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}}, {{
       6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}, {{6.902277253419171, 2.3465454273051365`}, {
       6.840002237696009, 2.413727019648549}, {6.840002237696009, 
       2.413727019648549}, {6.902277253419171, 2.3465454273051365`}, {
       6.902277253419171, 2.3465454273051365`}}, {{6.902277253419171, 
       2.3465454273051365`}, {6.840002237696009, 2.413727019648549}, {
       6.840002237696009, 2.413727019648549}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}}, {{
       6.902277253419171, 2.3465454273051365`}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}}, {{6.840002237696009, 2.413727019648549}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.840002237696009, 2.413727019648549}, {
       6.840002237696009, 2.413727019648549}}, {{6.840002237696009, 
       2.413727019648549}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}, {6.840002237696009, 
       2.413727019648549}, {6.840002237696009, 2.413727019648549}}, {{
       6.840002237696009, 2.413727019648549}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.413727019648549}, {6.840002237696009, 
       2.413727019648549}}, {{6.840002237696009, 2.413727019648549}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}, {6.840002237696009, 2.413727019648549}, {
       6.840002237696009, 2.413727019648549}}, {{6.824702632571057, 
       2.480908611991962}, {6.840002237696009, 2.5480902043353746`}, {
       6.840002237696009, 2.5480902043353746`}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}}, {{
       6.824702632571057, 2.480908611991962}, {6.840002237696009, 
       2.5480902043353746`}, {6.840002237696009, 2.5480902043353746`}, {
       6.824702632571057, 2.480908611991962}, {6.824702632571057, 
       2.480908611991962}}, {{6.824702632571057, 2.480908611991962}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}, {6.824702632571057, 2.480908611991962}, {
       6.824702632571057, 2.480908611991962}}, {{6.824702632571057, 
       2.480908611991962}, {6.840002237696009, 2.5480902043353746`}, {
       6.840002237696009, 2.5480902043353746`}, {6.824702632571057, 
       2.480908611991962}, {6.824702632571057, 2.480908611991962}}, {{
       6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}}, {{6.840002237696009, 2.5480902043353746`}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}, {6.840002237696009, 2.5480902043353746`}, {
       6.840002237696009, 2.5480902043353746`}}, {{6.840002237696009, 
       2.5480902043353746`}, {6.902277253419171, 2.6152717966787873`}, {
       6.902277253419171, 2.6152717966787873`}, {6.840002237696009, 
       2.5480902043353746`}, {6.840002237696009, 2.5480902043353746`}}, {{
       6.840002237696009, 2.5480902043353746`}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}, {
       6.840002237696009, 2.5480902043353746`}, {6.840002237696009, 
       2.5480902043353746`}}, {{7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}, {7.135001115963513, 2.480908611991962}, {
       7.135001115963513, 2.480908611991962}}, {{7.135001115963513, 
       2.480908611991962}, {7.107957658189009, 2.3933860701829213`}, {
       7.107957658189009, 2.3933860701829213`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}}, {{
       7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}}, {{7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}, {7.135001115963513, 2.480908611991962}, {
       7.135001115963513, 2.480908611991962}}, {{7.107957658189009, 
       2.3933860701829213`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}}, {{
       7.107957658189009, 2.3933860701829213`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}, {
       7.107957658189009, 2.3933860701829213`}, {7.107957658189009, 
       2.3933860701829213`}}, {{7.107957658189009, 2.3933860701829213`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}, {7.107957658189009, 2.3933860701829213`}, {
       7.107957658189009, 2.3933860701829213`}}, {{7.107957658189009, 
       2.3933860701829213`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}, {7.107957658189009, 
       2.3933860701829213`}, {7.107957658189009, 2.3933860701829213`}}, {{
       7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}, {{7.0574264951154, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.991595726916838, 
       2.3262044778395086`}, {7.0574264951154, 2.3465454273051365`}, {
       7.0574264951154, 2.3465454273051365`}}, {{7.0574264951154, 
       2.3465454273051365`}, {6.991595726916838, 2.3262044778395086`}, {
       6.991595726916838, 2.3262044778395086`}, {7.0574264951154, 
       2.3465454273051365`}, {7.0574264951154, 2.3465454273051365`}}, {{
       7.0574264951154, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}, {
       7.0574264951154, 2.3465454273051365`}, {7.0574264951154, 
       2.3465454273051365`}}, {{6.991595726916838, 2.3262044778395086`}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}, {6.991595726916838, 2.3262044778395086`}, {
       6.991595726916838, 2.3262044778395086`}}, {{6.991595726916838, 
       2.3262044778395086`}, {6.902277253419171, 2.3465454273051365`}, {
       6.902277253419171, 2.3465454273051365`}, {6.991595726916838, 
       2.3262044778395086`}, {6.991595726916838, 2.3262044778395086`}}, {{
       6.991595726916838, 2.3262044778395086`}, {6.902277253419171, 
       2.3465454273051365`}, {6.902277253419171, 2.3465454273051365`}, {
       6.991595726916838, 2.3262044778395086`}, {6.991595726916838, 
       2.3262044778395086`}}, {{6.991595726916838, 2.3262044778395086`}, {
       6.902277253419171, 2.3465454273051365`}, {6.902277253419171, 
       2.3465454273051365`}, {6.991595726916838, 2.3262044778395086`}, {
       6.991595726916838, 2.3262044778395086`}}, {{6.902277253419171, 
       2.6152717966787873`}, {6.991595726916838, 2.635612746144415}, {
       6.991595726916838, 2.635612746144415}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}}, {{
       6.902277253419171, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.991595726916838, 2.635612746144415}, {
       6.902277253419171, 2.6152717966787873`}, {6.902277253419171, 
       2.6152717966787873`}}, {{6.902277253419171, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}, {6.902277253419171, 2.6152717966787873`}, {
       6.902277253419171, 2.6152717966787873`}}, {{6.902277253419171, 
       2.6152717966787873`}, {6.991595726916838, 2.635612746144415}, {
       6.991595726916838, 2.635612746144415}, {6.902277253419171, 
       2.6152717966787873`}, {6.902277253419171, 2.6152717966787873`}}, {{
       6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}}, {{6.991595726916838, 2.635612746144415}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}, {6.991595726916838, 2.635612746144415}, {
       6.991595726916838, 2.635612746144415}}, {{6.991595726916838, 
       2.635612746144415}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}, {6.991595726916838, 
       2.635612746144415}, {6.991595726916838, 2.635612746144415}}, {{
       6.991595726916838, 2.635612746144415}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}, {
       6.991595726916838, 2.635612746144415}, {6.991595726916838, 
       2.635612746144415}}, {{7.0574264951154, 2.6152717966787873`}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}}, {{7.0574264951154, 
       2.6152717966787873`}, {7.107957658189009, 2.5684311538010025`}, {
       7.107957658189009, 2.5684311538010025`}, {7.0574264951154, 
       2.6152717966787873`}, {7.0574264951154, 2.6152717966787873`}}, {{
       7.0574264951154, 2.6152717966787873`}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}, {
       7.0574264951154, 2.6152717966787873`}, {7.0574264951154, 
       2.6152717966787873`}}, {{7.0574264951154, 2.6152717966787873`}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}, {7.0574264951154, 2.6152717966787873`}, {
       7.0574264951154, 2.6152717966787873`}}, {{7.107957658189009, 
       2.5684311538010025`}, {7.135001115963513, 2.480908611991962}, {
       7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}}, {{
       7.107957658189009, 2.5684311538010025`}, {7.135001115963513, 
       2.480908611991962}, {7.135001115963513, 2.480908611991962}, {
       7.107957658189009, 2.5684311538010025`}, {7.107957658189009, 
       2.5684311538010025`}}, {{7.107957658189009, 2.5684311538010025`}, {
       7.135001115963513, 2.480908611991962}, {7.135001115963513, 
       2.480908611991962}, {7.107957658189009, 2.5684311538010025`}, {
       7.107957658189009, 2.5684311538010025`}}, {{7.107957658189009, 
       2.5684311538010025`}, {7.135001115963513, 2.480908611991962}, {
       7.135001115963513, 2.480908611991962}, {7.107957658189009, 
       2.5684311538010025`}, {7.107957658189009, 2.5684311538010025`}}, {{
       6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.898035327942713, 
       2.9677201468426655`}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}, {{6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}}, {{7.1725238067572015`, 
       2.9677201468426655`}, {7.148601299933284, 2.890298146256358}, {
       7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {6.966657447646335, 2.848863148992918}, {
       6.966657447646335, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.10390168705358, 2.848863148992918}, {
       7.148601299933284, 2.890298146256358}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}}, {{
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}, {{6.966657447646335, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.148601299933284, 3.045142147428973}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.148601299933284, 3.045142147428973}, {
       7.10390168705358, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {6.966657447646335, 3.086577144692413}, {
       6.966657447646335, 3.086577144692413}}, {{7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}}, {{
       6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}, {{6.966657447646335, 2.848863148992918}, {
       6.911569281738738, 2.908291647917792}, {6.911569281738738, 
       2.908291647917792}, {6.966657447646335, 2.848863148992918}, {
       6.966657447646335, 2.848863148992918}}, {{6.966657447646335, 
       2.848863148992918}, {6.911569281738738, 2.908291647917792}, {
       6.911569281738738, 2.908291647917792}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}}, {{
       6.966657447646335, 2.848863148992918}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}}, {{6.911569281738738, 2.908291647917792}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.911569281738738, 2.908291647917792}, {
       6.911569281738738, 2.908291647917792}}, {{6.911569281738738, 
       2.908291647917792}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}, {6.911569281738738, 
       2.908291647917792}, {6.911569281738738, 2.908291647917792}}, {{
       6.911569281738738, 2.908291647917792}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 2.908291647917792}, {6.911569281738738, 
       2.908291647917792}}, {{6.911569281738738, 2.908291647917792}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}, {6.911569281738738, 2.908291647917792}, {
       6.911569281738738, 2.908291647917792}}, {{6.898035327942713, 
       2.9677201468426655`}, {6.911569281738738, 3.027148645767539}, {
       6.911569281738738, 3.027148645767539}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}}, {{
       6.898035327942713, 2.9677201468426655`}, {6.911569281738738, 
       3.027148645767539}, {6.911569281738738, 3.027148645767539}, {
       6.898035327942713, 2.9677201468426655`}, {6.898035327942713, 
       2.9677201468426655`}}, {{6.898035327942713, 2.9677201468426655`}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}, {6.898035327942713, 2.9677201468426655`}, {
       6.898035327942713, 2.9677201468426655`}}, {{6.898035327942713, 
       2.9677201468426655`}, {6.911569281738738, 3.027148645767539}, {
       6.911569281738738, 3.027148645767539}, {6.898035327942713, 
       2.9677201468426655`}, {6.898035327942713, 2.9677201468426655`}}, {{
       6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}}, {{6.911569281738738, 3.027148645767539}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}, {6.911569281738738, 3.027148645767539}, {
       6.911569281738738, 3.027148645767539}}, {{6.911569281738738, 
       3.027148645767539}, {6.966657447646335, 3.086577144692413}, {
       6.966657447646335, 3.086577144692413}, {6.911569281738738, 
       3.027148645767539}, {6.911569281738738, 3.027148645767539}}, {{
       6.911569281738738, 3.027148645767539}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}, {
       6.911569281738738, 3.027148645767539}, {6.911569281738738, 
       3.027148645767539}}, {{7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.1725238067572015`, 2.9677201468426655`}}, {{7.1725238067572015`, 
       2.9677201468426655`}, {7.148601299933284, 2.890298146256358}, {
       7.148601299933284, 2.890298146256358}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}}, {{
       7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284, 
       2.890298146256358}, {7.148601299933284, 2.890298146256358}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}}, {{7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.1725238067572015`, 2.9677201468426655`}}, {{7.148601299933284, 
       2.890298146256358}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.148601299933284, 
       2.890298146256358}, {7.148601299933284, 2.890298146256358}}, {{
       7.148601299933284, 2.890298146256358}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}, {
       7.148601299933284, 2.890298146256358}, {7.148601299933284, 
       2.890298146256358}}, {{7.148601299933284, 2.890298146256358}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}, {7.148601299933284, 2.890298146256358}, {
       7.148601299933284, 2.890298146256358}}, {{7.148601299933284, 
       2.890298146256358}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}, {7.148601299933284, 
       2.890298146256358}, {7.148601299933284, 2.890298146256358}}, {{
       7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}, {{7.10390168705358, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.04566812037785, 
       2.8308696473314847`}, {7.10390168705358, 2.848863148992918}, {
       7.10390168705358, 2.848863148992918}}, {{7.10390168705358, 
       2.848863148992918}, {7.04566812037785, 2.8308696473314847`}, {
       7.04566812037785, 2.8308696473314847`}, {7.10390168705358, 
       2.848863148992918}, {7.10390168705358, 2.848863148992918}}, {{
       7.10390168705358, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}, {
       7.10390168705358, 2.848863148992918}, {7.10390168705358, 
       2.848863148992918}}, {{7.04566812037785, 2.8308696473314847`}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}, {7.04566812037785, 2.8308696473314847`}, {
       7.04566812037785, 2.8308696473314847`}}, {{7.04566812037785, 
       2.8308696473314847`}, {6.966657447646335, 2.848863148992918}, {
       6.966657447646335, 2.848863148992918}, {7.04566812037785, 
       2.8308696473314847`}, {7.04566812037785, 2.8308696473314847`}}, {{
       7.04566812037785, 2.8308696473314847`}, {6.966657447646335, 
       2.848863148992918}, {6.966657447646335, 2.848863148992918}, {
       7.04566812037785, 2.8308696473314847`}, {7.04566812037785, 
       2.8308696473314847`}}, {{7.04566812037785, 2.8308696473314847`}, {
       6.966657447646335, 2.848863148992918}, {6.966657447646335, 
       2.848863148992918}, {7.04566812037785, 2.8308696473314847`}, {
       7.04566812037785, 2.8308696473314847`}}, {{6.966657447646335, 
       3.086577144692413}, {7.04566812037785, 3.1045706463538463`}, {
       7.04566812037785, 3.1045706463538463`}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}}, {{
       6.966657447646335, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.04566812037785, 3.1045706463538463`}, {
       6.966657447646335, 3.086577144692413}, {6.966657447646335, 
       3.086577144692413}}, {{6.966657447646335, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}, {6.966657447646335, 3.086577144692413}, {
       6.966657447646335, 3.086577144692413}}, {{6.966657447646335, 
       3.086577144692413}, {7.04566812037785, 3.1045706463538463`}, {
       7.04566812037785, 3.1045706463538463`}, {6.966657447646335, 
       3.086577144692413}, {6.966657447646335, 3.086577144692413}}, {{
       7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}}, {{7.04566812037785, 3.1045706463538463`}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}, {7.04566812037785, 3.1045706463538463`}, {
       7.04566812037785, 3.1045706463538463`}}, {{7.04566812037785, 
       3.1045706463538463`}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}, {7.04566812037785, 
       3.1045706463538463`}, {7.04566812037785, 3.1045706463538463`}}, {{
       7.04566812037785, 3.1045706463538463`}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}, {
       7.04566812037785, 3.1045706463538463`}, {7.04566812037785, 
       3.1045706463538463`}}, {{7.10390168705358, 3.086577144692413}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}}, {{7.10390168705358, 
       3.086577144692413}, {7.148601299933284, 3.045142147428973}, {
       7.148601299933284, 3.045142147428973}, {7.10390168705358, 
       3.086577144692413}, {7.10390168705358, 3.086577144692413}}, {{
       7.10390168705358, 3.086577144692413}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}, {
       7.10390168705358, 3.086577144692413}, {7.10390168705358, 
       3.086577144692413}}, {{7.10390168705358, 3.086577144692413}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}, {7.10390168705358, 3.086577144692413}, {
       7.10390168705358, 3.086577144692413}}, {{7.148601299933284, 
       3.045142147428973}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}}, {{
       7.148601299933284, 3.045142147428973}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.148601299933284, 3.045142147428973}, {7.148601299933284, 
       3.045142147428973}}, {{7.148601299933284, 3.045142147428973}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.1725238067572015`, 
       2.9677201468426655`}, {7.148601299933284, 3.045142147428973}, {
       7.148601299933284, 3.045142147428973}}, {{7.148601299933284, 
       3.045142147428973}, {7.1725238067572015`, 2.9677201468426655`}, {
       7.1725238067572015`, 2.9677201468426655`}, {7.148601299933284, 
       3.045142147428973}, {7.148601299933284, 3.045142147428973}}, {{
       6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.815602554862664, 
       3.4833425711064887`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}, {{6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}}, {{7.085979465081177, 
       3.4833425711064887`}, {7.0624152939812905`, 3.407080276266751}, {
       7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.883196782417293, 3.3662659346835}, {
       6.883196782417293, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {7.018385237526549, 3.3662659346835}, {
       7.0624152939812905`, 3.407080276266751}, {7.085979465081177, 
       3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}}, {{
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}, {{6.883196782417293, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.018385237526549, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.883196782417293, 3.600419207529477}, {
       6.883196782417293, 3.600419207529477}}, {{7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}}, {{
       6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}, {{6.883196782417293, 3.3662659346835}, {
       6.828933783285124, 3.4248042528949942`}, {6.828933783285124, 
       3.4248042528949942`}, {6.883196782417293, 3.3662659346835}, {
       6.883196782417293, 3.3662659346835}}, {{6.883196782417293, 
       3.3662659346835}, {6.828933783285124, 3.4248042528949942`}, {
       6.828933783285124, 3.4248042528949942`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}}, {{
       6.883196782417293, 3.3662659346835}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}}, {{6.828933783285124, 3.4248042528949942`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.828933783285124, 3.4248042528949942`}, {
       6.828933783285124, 3.4248042528949942`}}, {{6.828933783285124, 
       3.4248042528949942`}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}, {6.828933783285124, 
       3.4248042528949942`}, {6.828933783285124, 3.4248042528949942`}}, {{
       6.828933783285124, 3.4248042528949942`}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.4248042528949942`}, {6.828933783285124, 
       3.4248042528949942`}}, {{6.828933783285124, 3.4248042528949942`}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}, {6.828933783285124, 3.4248042528949942`}, {
       6.828933783285124, 3.4248042528949942`}}, {{6.815602554862664, 
       3.4833425711064887`}, {6.828933783285124, 3.541880889317983}, {
       6.828933783285124, 3.541880889317983}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}}, {{
       6.815602554862664, 3.4833425711064887`}, {6.828933783285124, 
       3.541880889317983}, {6.828933783285124, 3.541880889317983}, {
       6.815602554862664, 3.4833425711064887`}, {6.815602554862664, 
       3.4833425711064887`}}, {{6.815602554862664, 3.4833425711064887`}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}, {6.815602554862664, 3.4833425711064887`}, {
       6.815602554862664, 3.4833425711064887`}}, {{6.815602554862664, 
       3.4833425711064887`}, {6.828933783285124, 3.541880889317983}, {
       6.828933783285124, 3.541880889317983}, {6.815602554862664, 
       3.4833425711064887`}, {6.815602554862664, 3.4833425711064887`}}, {{
       6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}}, {{6.828933783285124, 3.541880889317983}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}, {6.828933783285124, 3.541880889317983}, {
       6.828933783285124, 3.541880889317983}}, {{6.828933783285124, 
       3.541880889317983}, {6.883196782417293, 3.600419207529477}, {
       6.883196782417293, 3.600419207529477}, {6.828933783285124, 
       3.541880889317983}, {6.828933783285124, 3.541880889317983}}, {{
       6.828933783285124, 3.541880889317983}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}, {
       6.828933783285124, 3.541880889317983}, {6.828933783285124, 
       3.541880889317983}}, {{7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}, {7.085979465081177, 3.4833425711064887`}, {
       7.085979465081177, 3.4833425711064887`}}, {{7.085979465081177, 
       3.4833425711064887`}, {7.0624152939812905`, 3.407080276266751}, {
       7.0624152939812905`, 3.407080276266751}, {7.085979465081177, 
       3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}}, {{
       7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`, 
       3.407080276266751}, {7.0624152939812905`, 3.407080276266751}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}}, {{7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}, {7.085979465081177, 3.4833425711064887`}, {
       7.085979465081177, 3.4833425711064887`}}, {{7.0624152939812905`, 
       3.407080276266751}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.0624152939812905`, 
       3.407080276266751}, {7.0624152939812905`, 3.407080276266751}}, {{
       7.0624152939812905`, 3.407080276266751}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}, {
       7.0624152939812905`, 3.407080276266751}, {7.0624152939812905`, 
       3.407080276266751}}, {{7.0624152939812905`, 3.407080276266751}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}, {7.0624152939812905`, 3.407080276266751}, {
       7.0624152939812905`, 3.407080276266751}}, {{7.0624152939812905`, 
       3.407080276266751}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}, {7.0624152939812905`, 
       3.407080276266751}, {7.0624152939812905`, 3.407080276266751}}, {{
       7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}, {{7.018385237526549, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.961023952649348, 
       3.3485419580552565`}, {7.018385237526549, 3.3662659346835}, {
       7.018385237526549, 3.3662659346835}}, {{7.018385237526549, 
       3.3662659346835}, {6.961023952649348, 3.3485419580552565`}, {
       6.961023952649348, 3.3485419580552565`}, {7.018385237526549, 
       3.3662659346835}, {7.018385237526549, 3.3662659346835}}, {{
       7.018385237526549, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}, {
       7.018385237526549, 3.3662659346835}, {7.018385237526549, 
       3.3662659346835}}, {{6.961023952649348, 3.3485419580552565`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}, {6.961023952649348, 3.3485419580552565`}, {
       6.961023952649348, 3.3485419580552565`}}, {{6.961023952649348, 
       3.3485419580552565`}, {6.883196782417293, 3.3662659346835}, {
       6.883196782417293, 3.3662659346835}, {6.961023952649348, 
       3.3485419580552565`}, {6.961023952649348, 3.3485419580552565`}}, {{
       6.961023952649348, 3.3485419580552565`}, {6.883196782417293, 
       3.3662659346835}, {6.883196782417293, 3.3662659346835}, {
       6.961023952649348, 3.3485419580552565`}, {6.961023952649348, 
       3.3485419580552565`}}, {{6.961023952649348, 3.3485419580552565`}, {
       6.883196782417293, 3.3662659346835}, {6.883196782417293, 
       3.3662659346835}, {6.961023952649348, 3.3485419580552565`}, {
       6.961023952649348, 3.3485419580552565`}}, {{6.883196782417293, 
       3.600419207529477}, {6.961023952649348, 3.618143184157721}, {
       6.961023952649348, 3.618143184157721}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}}, {{
       6.883196782417293, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.961023952649348, 3.618143184157721}, {
       6.883196782417293, 3.600419207529477}, {6.883196782417293, 
       3.600419207529477}}, {{6.883196782417293, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}, {6.883196782417293, 3.600419207529477}, {
       6.883196782417293, 3.600419207529477}}, {{6.883196782417293, 
       3.600419207529477}, {6.961023952649348, 3.618143184157721}, {
       6.961023952649348, 3.618143184157721}, {6.883196782417293, 
       3.600419207529477}, {6.883196782417293, 3.600419207529477}}, {{
       6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}}, {{6.961023952649348, 3.618143184157721}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}, {6.961023952649348, 3.618143184157721}, {
       6.961023952649348, 3.618143184157721}}, {{6.961023952649348, 
       3.618143184157721}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}, {6.961023952649348, 
       3.618143184157721}, {6.961023952649348, 3.618143184157721}}, {{
       6.961023952649348, 3.618143184157721}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}, {
       6.961023952649348, 3.618143184157721}, {6.961023952649348, 
       3.618143184157721}}, {{7.018385237526549, 3.600419207529477}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}}, {{7.018385237526549, 
       3.600419207529477}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.018385237526549, 
       3.600419207529477}, {7.018385237526549, 3.600419207529477}}, {{
       7.018385237526549, 3.600419207529477}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.018385237526549, 3.600419207529477}, {7.018385237526549, 
       3.600419207529477}}, {{7.018385237526549, 3.600419207529477}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.018385237526549, 3.600419207529477}, {
       7.018385237526549, 3.600419207529477}}, {{7.0624152939812905`, 
       3.5596048659462265`}, {7.085979465081177, 3.4833425711064887`}, {
       7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}}, {{
       7.0624152939812905`, 3.5596048659462265`}, {7.085979465081177, 
       3.4833425711064887`}, {7.085979465081177, 3.4833425711064887`}, {
       7.0624152939812905`, 3.5596048659462265`}, {7.0624152939812905`, 
       3.5596048659462265`}}, {{7.0624152939812905`, 3.5596048659462265`}, {
       7.085979465081177, 3.4833425711064887`}, {7.085979465081177, 
       3.4833425711064887`}, {7.0624152939812905`, 3.5596048659462265`}, {
       7.0624152939812905`, 3.5596048659462265`}}, {{7.0624152939812905`, 
       3.5596048659462265`}, {7.085979465081177, 3.4833425711064887`}, {
       7.085979465081177, 3.4833425711064887`}, {7.0624152939812905`, 
       3.5596048659462265`}, {7.0624152939812905`, 3.5596048659462265`}}, {{
       7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}, {{
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}, {{
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}, {{
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}, {{
       7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}, {{
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}, {{
       7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}, {{
       7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}, {{
       7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}, {{
       7.141476786238058, -4.3549662399197056`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}}, {{
       7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}, {{
       7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}, {{
       7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}, {{
       7.078942738397525, -4.287505206617332}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.287505206617332}, {
       7.078942738397525, -4.287505206617332}}, {{
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}, {{
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}, {{
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}, {{
       7.063579494764186, -4.2200441733149585`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}, {
       7.063579494764186, -4.2200441733149585`}, {
       7.063579494764186, -4.2200441733149585`}}, {{
       7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}, {{
       7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}, {{
       7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}, {{
       7.078942738397525, -4.152583140012585}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.078942738397525, -4.152583140012585}, {
       7.078942738397525, -4.152583140012585}}, {{
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}, {{
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}, {{
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}, {{
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}}, {{
       7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}, {{
       7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}, {{
       7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}, {{
       7.348012715974534, -4.3079307639975175`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.348012715974534, -4.3079307639975175`}, {
       7.348012715974534, -4.3079307639975175`}}, {{
       7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}, {{
       7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}, {{
       7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}, {{
       7.2972713691857995`, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}, {
       7.2972713691857995`, -4.3549662399197056`}, {
       7.2972713691857995`, -4.3549662399197056`}}, {{
       7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}, {{
       7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}, {{
       7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}, {{
       7.231166778763727, -4.375391797299891}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.141476786238058, -4.3549662399197056`}, {
       7.231166778763727, -4.375391797299891}, {
       7.231166778763727, -4.375391797299891}}, {{
       7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}, {{
       7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}, {{
       7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}, {{
       7.141476786238058, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}, {
       7.141476786238058, -4.0851221067102115`}, {
       7.141476786238058, -4.0851221067102115`}}, {{
       7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}, {{
       7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}, {{
       7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}, {{
       7.231166778763727, -4.064696549330026}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.231166778763727, -4.064696549330026}, {
       7.231166778763727, -4.064696549330026}}, {{
       7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}, {{
       7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}, {{
       7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}, {{
       7.2972713691857995`, -4.0851221067102115`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.2972713691857995`, -4.0851221067102115`}, {
       7.2972713691857995`, -4.0851221067102115`}}, {{
       7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}, {{
       7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}, {{
       7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}, {{
       7.348012715974534, -4.1321575826323995`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.375168660659671, -4.2200441733149585`}, {
       7.348012715974534, -4.1321575826323995`}, {
       7.348012715974534, -4.1321575826323995`}}, {{
       7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}, {{
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}, {{
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}, {{
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}, {{
       7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}, {{
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}, {{
       7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}, {{
       7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}, {{
       7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}, {{
       7.238750395085382, -3.897774940918716}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}}, {{
       7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}, {{
       7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}, {{
       7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}, {{
       7.190360145583585, -3.8455720795035147`}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.8455720795035147`}, {
       7.190360145583585, -3.8455720795035147`}}, {{
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}, {{
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}, {{
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}, {{
       7.178471722904312, -3.793369218088314}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}, {
       7.178471722904312, -3.793369218088314}, {
       7.178471722904312, -3.793369218088314}}, {{
       7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}, {{
       7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}, {{
       7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}, {{
       7.190360145583585, -3.741166356673113}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}, {
       7.190360145583585, -3.741166356673113}, {
       7.190360145583585, -3.741166356673113}}, {{
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}, {{
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}, {{
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}, {{
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}}, {{
       7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}, {{
       7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}, {{
       7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}, {{
       7.398572532243688, -3.861377834159937}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}, {
       7.398572532243688, -3.861377834159937}, {
       7.398572532243688, -3.861377834159937}}, {{
       7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}, {{
       7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}, {{
       7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}, {{
       7.359307739447522, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.359307739447522, -3.897774940918716}, {
       7.359307739447522, -3.897774940918716}}, {{
       7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}, {{
       7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}, {{
       7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}, {{
       7.308154523972083, -3.9135806955751384`}, {
       7.238750395085382, -3.897774940918716}, {
       7.238750395085382, -3.897774940918716}, {
       7.308154523972083, -3.9135806955751384`}, {
       7.308154523972083, -3.9135806955751384`}}, {{
       7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}, {{
       7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}, {{
       7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}, {{
       7.238750395085382, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.238750395085382, -3.688963495257912}, {
       7.238750395085382, -3.688963495257912}}, {{
       7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}, {{
       7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}, {{
       7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}, {{
       7.308154523972083, -3.6731577406014893`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}, {
       7.308154523972083, -3.6731577406014893`}, {
       7.308154523972083, -3.6731577406014893`}}, {{
       7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}, {{
       7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}, {{
       7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}, {{
       7.359307739447522, -3.688963495257912}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.359307739447522, -3.688963495257912}, {
       7.359307739447522, -3.688963495257912}}, {{
       7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}, {{
       7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}, {{
       7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}, {{
       7.398572532243688, -3.7253606020166905`}, {
       7.419586411628592, -3.793369218088314}, {
       7.419586411628592, -3.793369218088314}, {
       7.398572532243688, -3.7253606020166905`}, {
       7.398572532243688, -3.7253606020166905`}}, {{
       7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}, {{
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}, {{
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}, {{
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}, {{
       7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}, {{
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}, {{
       7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}, {{
       7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}, {{
       7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}, {{
       7.134193193577856, -3.390594420423469}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}}, {{
       7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}, {{
       7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}, {{
       7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}, {{
       7.069243205645955, -3.3205270978980472`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.3205270978980472`}, {
       7.069243205645955, -3.3205270978980472`}}, {{
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}, {{
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}, {{
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}, {{
       7.053286418534959, -3.2504597753726254`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.053286418534959, -3.2504597753726254`}, {
       7.053286418534959, -3.2504597753726254`}}, {{
       7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}, {{
       7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}, {{
       7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}, {{
       7.069243205645955, -3.1803924528472036`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}, {
       7.069243205645955, -3.1803924528472036`}, {
       7.069243205645955, -3.1803924528472036`}}, {{
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}, {{
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}, {{
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}, {{
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}}, {{
       7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}, {{
       7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}, {{
       7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}, {{
       7.348708431390325, -3.3417417761598553`}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}, {
       7.348708431390325, -3.3417417761598553`}, {
       7.348708431390325, -3.3417417761598553`}}, {{
       7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}, {{
       7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}, {{
       7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}, {{
       7.29600674366365, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}, {
       7.29600674366365, -3.390594420423469}, {
       7.29600674366365, -3.390594420423469}}, {{
       7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}, {{
       7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}, {{
       7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}, {{
       7.227348268825979, -3.411809098685277}, {
       7.134193193577856, -3.390594420423469}, {
       7.134193193577856, -3.390594420423469}, {
       7.227348268825979, -3.411809098685277}, {
       7.227348268825979, -3.411809098685277}}, {{
       7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}, {{
       7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}, {{
       7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}, {{
       7.134193193577856, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.134193193577856, -3.110325130321782}, {
       7.134193193577856, -3.110325130321782}}, {{
       7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}, {{
       7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}, {{
       7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}, {{
       7.227348268825979, -3.0891104520599737`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}, {
       7.227348268825979, -3.0891104520599737`}, {
       7.227348268825979, -3.0891104520599737`}}, {{
       7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}, {{
       7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}, {{
       7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}, {{
       7.29600674366365, -3.110325130321782}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.29600674366365, -3.110325130321782}, {
       7.29600674366365, -3.110325130321782}}, {{
       7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}, {{
       7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}, {{
       7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}, {{
       7.348708431390325, -3.1591777745853955`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.376913518706547, -3.2504597753726254`}, {
       7.348708431390325, -3.1591777745853955`}, {
       7.348708431390325, -3.1591777745853955`}}, {{
       7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}, {{
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}, {{
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}, {{
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}, {{
       7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}, {{
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}, {{
       7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}, {{
       7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}, {{
       7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}, {{
       7.215377332671332, -2.9226149086184288`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}}, {{
       7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}, {{
       7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}, {{
       7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}, {{
       7.154617276703835, -2.8570676379614883`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.8570676379614883`}, {
       7.154617276703835, -2.8570676379614883`}}, {{
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}, {{
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}, {{
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}, {{
       7.139689863954472, -2.791520367304548}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.139689863954472, -2.791520367304548}, {
       7.139689863954472, -2.791520367304548}}, {{
       7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}, {{
       7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}, {{
       7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}, {{
       7.154617276703835, -2.7259730966476075`}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}, {
       7.154617276703835, -2.7259730966476075`}, {
       7.154617276703835, -2.7259730966476075`}}, {{
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}, {{
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}, {{
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}, {{
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}}, {{
       7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}, {{
       7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}, {{
       7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}, {{
       7.416054165268015, -2.8769137546362353`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.416054165268015, -2.8769137546362353`}, {
       7.416054165268015, -2.8769137546362353`}}, {{
       7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}, {{
       7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}, {{
       7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}, {{
       7.366752270105051, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.366752270105051, -2.9226149086184288`}, {
       7.366752270105051, -2.9226149086184288`}}, {{
       7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}, {{
       7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}, {{
       7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}, {{
       7.302522962192725, -2.9424610252931758`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.215377332671332, -2.9226149086184288`}, {
       7.302522962192725, -2.9424610252931758`}, {
       7.302522962192725, -2.9424610252931758`}}, {{
       7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}, {{
       7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}, {{
       7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}, {{
       7.215377332671332, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}, {
       7.215377332671332, -2.660425825990667}, {
       7.215377332671332, -2.660425825990667}}, {{
       7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}, {{
       7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}, {{
       7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}, {{
       7.302522962192725, -2.64057970931592}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}, {
       7.302522962192725, -2.64057970931592}, {
       7.302522962192725, -2.64057970931592}}, {{
       7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}, {{
       7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}, {{
       7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}, {{
       7.366752270105051, -2.660425825990667}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.366752270105051, -2.660425825990667}, {
       7.366752270105051, -2.660425825990667}}, {{
       7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}, {{
       7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}, {{
       7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}, {{
       7.416054165268015, -2.7061269799728604`}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.4424397388219115`, -2.791520367304548}, {
       7.416054165268015, -2.7061269799728604`}, {
       7.416054165268015, -2.7061269799728604`}}, {{
       7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}, {{
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}, {{
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}, {{
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}, {{
       7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}, {{
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}, {{
       7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}, {{
       7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}, {{
       7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}, {{
       7.149424189271316, -2.3804479167914536`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}}, {{
       7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}, {{
       7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}, {{
       7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}, {{
       7.0863246708246015`, -2.3123768601064194`}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.3123768601064194`}, {
       7.0863246708246015`, -2.3123768601064194`}}, {{
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}, {{
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}, {{
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}, {{
       7.070822503469062, -2.244305803421385}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.070822503469062, -2.244305803421385}, {
       7.070822503469062, -2.244305803421385}}, {{
       7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}, {{
       7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}, {{
       7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}, {{
       7.0863246708246015`, -2.176234746736351}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.0863246708246015`, -2.176234746736351}, {
       7.0863246708246015`, -2.176234746736351}}, {{
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}, {{
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}, {{
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}, {{
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}}, {{
       7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}, {{
       7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}, {{
       7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}, {{
       7.357827741549743, -2.332987117705321}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.357827741549743, -2.332987117705321}, {
       7.357827741549743, -2.332987117705321}}, {{
       7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}, {{
       7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}, {{
       7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}, {{
       7.306627560875822, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.306627560875822, -2.3804479167914536`}, {
       7.306627560875822, -2.3804479167914536`}}, {{
       7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}, {{
       7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}, {{
       7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}, {{
       7.239925212846362, -2.4010581743903554`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.149424189271316, -2.3804479167914536`}, {
       7.239925212846362, -2.4010581743903554`}, {
       7.239925212846362, -2.4010581743903554`}}, {{
       7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}, {{
       7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}, {{
       7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}, {{
       7.149424189271316, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}, {
       7.149424189271316, -2.1081636900513168`}, {
       7.149424189271316, -2.1081636900513168`}}, {{
       7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}, {{
       7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}, {{
       7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}, {{
       7.239925212846362, -2.087553432452415}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.239925212846362, -2.087553432452415}, {
       7.239925212846362, -2.087553432452415}}, {{
       7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}, {{
       7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}, {{
       7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}, {{
       7.306627560875822, -2.1081636900513168`}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}, {
       7.306627560875822, -2.1081636900513168`}, {
       7.306627560875822, -2.1081636900513168`}}, {{
       7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}, {{
       7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}, {{
       7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}, {{
       7.357827741549743, -2.155624489137449}, {
       7.385229246678076, -2.244305803421385}, {
       7.385229246678076, -2.244305803421385}, {
       7.357827741549743, -2.155624489137449}, {
       7.357827741549743, -2.155624489137449}}, {{
       7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}, {{
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}, {{
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}, {{
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}, {{
       7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}, {{
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}, {{
       7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}, {{
       7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}, {{
       7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}, {{
       7.168019899759104, -1.9224623430972165`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}}, {{
       7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}, {{
       7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}, {{
       7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}, {{
       7.109356067521128, -1.859176455218297}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.859176455218297}, {
       7.109356067521128, -1.859176455218297}}, {{
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}, {{
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}, {{
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}, {{
       7.094943650953507, -1.7958905673393772`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.094943650953507, -1.7958905673393772`}, {
       7.094943650953507, -1.7958905673393772`}}, {{
       7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}, {{
       7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}, {{
       7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}, {{
       7.109356067521128, -1.7326046794604575`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}, {
       7.109356067521128, -1.7326046794604575`}, {
       7.109356067521128, -1.7326046794604575`}}, {{
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}, {{
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}, {{
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}, {{
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}}, {{
       7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}, {{
       7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}, {{
       7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}, {{
       7.361773375690686, -1.8783378802802724`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.361773375690686, -1.8783378802802724`}, {
       7.361773375690686, -1.8783378802802724`}}, {{
       7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}, {{
       7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}, {{
       7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}, {{
       7.3141723973702994`, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.3141723973702994`, -1.9224623430972165`}, {
       7.3141723973702994`, -1.9224623430972165`}}, {{
       7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}, {{
       7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}, {{
       7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}, {{
       7.25215900248229, -1.9416237681591921`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.168019899759104, -1.9224623430972165`}, {
       7.25215900248229, -1.9416237681591921`}, {
       7.25215900248229, -1.9416237681591921`}}, {{
       7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}, {{
       7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}, {{
       7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}, {{
       7.168019899759104, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.168019899759104, -1.669318791581538}, {
       7.168019899759104, -1.669318791581538}}, {{
       7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}, {{
       7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}, {{
       7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}, {{
       7.25215900248229, -1.6501573665195624`}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.25215900248229, -1.6501573665195624`}, {
       7.25215900248229, -1.6501573665195624`}}, {{
       7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}, {{
       7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}, {{
       7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}, {{
       7.3141723973702994`, -1.669318791581538}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}, {
       7.3141723973702994`, -1.669318791581538}, {
       7.3141723973702994`, -1.669318791581538}}, {{
       7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}, {{
       7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}, {{
       7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}, {{
       7.361773375690686, -1.713443254398482}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.387248646175896, -1.7958905673393772`}, {
       7.361773375690686, -1.713443254398482}, {
       7.361773375690686, -1.713443254398482}}, {{
       7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}, {{
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}, {{
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}, {{
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}, {{
       7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}, {{
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}, {{
       7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}, {{
       7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}, {{
       7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}, {{
       7.185080073559632, -1.423066066856094}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}}, {{
       7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}, {{
       7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}, {{
       7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}, {{
       7.1221601602024736`, -1.3551887661383466`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.3551887661383466`}, {
       7.1221601602024736`, -1.3551887661383466`}}, {{
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}, {{
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}, {{
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}, {{
       7.10670211787712, -1.2873114654205995`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.10670211787712, -1.2873114654205995`}, {
       7.10670211787712, -1.2873114654205995`}}, {{
       7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}, {{
       7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}, {{
       7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}, {{
       7.1221601602024736`, -1.2194341647028524`}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}, {
       7.1221601602024736`, -1.2194341647028524`}, {
       7.1221601602024736`, -1.2194341647028524`}}, {{
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}, {{
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}, {{
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}, {{
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}}, {{
       7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}, {{
       7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}, {{
       7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}, {{
       7.392890430523867, -1.375740359150689}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}, {
       7.392890430523867, -1.375740359150689}, {
       7.392890430523867, -1.375740359150689}}, {{
       7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}, {{
       7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}, {{
       7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}, {{
       7.341835984924659, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}, {
       7.341835984924659, -1.423066066856094}, {
       7.341835984924659, -1.423066066856094}}, {{
       7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}, {{
       7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}, {{
       7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}, {{
       7.275323497000097, -1.443617659868436}, {
       7.185080073559632, -1.423066066856094}, {
       7.185080073559632, -1.423066066856094}, {
       7.275323497000097, -1.443617659868436}, {
       7.275323497000097, -1.443617659868436}}, {{
       7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}, {{
       7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}, {{
       7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}, {{
       7.185080073559632, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}, {
       7.185080073559632, -1.151556863985105}, {
       7.185080073559632, -1.151556863985105}}, {{
       7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}, {{
       7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}, {{
       7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}, {{
       7.275323497000097, -1.131005270972763}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}, {
       7.275323497000097, -1.131005270972763}, {
       7.275323497000097, -1.131005270972763}}, {{
       7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}, {{
       7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}, {{
       7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}, {{
       7.341835984924659, -1.151556863985105}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}, {
       7.341835984924659, -1.151556863985105}, {
       7.341835984924659, -1.151556863985105}}, {{
       7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}, {{
       7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}, {{
       7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}, {{
       7.392890430523867, -1.19888257169051}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.420213940607171, -1.2873114654205995`}, {
       7.392890430523867, -1.19888257169051}, {
       7.392890430523867, -1.19888257169051}}, {{
       7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217376}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}, {{
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}, {{
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}, {{
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}, {{
       7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}, {{
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}, {{
       7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}, {{
       7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}, {{
       7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}, {{
       7.140461327129645, -0.9243101428261493}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}}, {{
       7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}, {{
       7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}, {{
       7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}, {{
       7.065541311402793, -0.8434872655217375}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.8434872655217375}, {
       7.065541311402793, -0.8434872655217375}}, {{
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}, {{
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}, {{
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}, {{
       7.04713510719288, -0.7626643882173257}, {
       7.065541311402793, -0.681841510912914}, {
       7.065541311402793, -0.681841510912914}, {
       7.04713510719288, -0.7626643882173257}, {
       7.04713510719288, -0.7626643882173257}}, {{
       7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}, {{
       7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}, {{
       7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}, {{
       7.065541311402793, -0.6818415109129139}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}, {
       7.065541311402793, -0.6818415109129139}, {
       7.065541311402793, -0.6818415109129139}}, {{
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}, {{
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}, {{
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}, {{
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}}, {{
       7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}, {{
       7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}, {{
       7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}, {{
       7.387905329850791, -0.8679584637409156}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}, {
       7.387905329850791, -0.8679584637409156}, {
       7.387905329850791, -0.8679584637409156}}, {{
       7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}, {{
       7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}, {{
       7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}, {{
       7.327113767003174, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}, {
       7.327113767003174, -0.9243101428261493}, {
       7.327113767003174, -0.9243101428261493}}, {{
       7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}, {{
       7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}, {{
       7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}, {{
       7.247915999945644, -0.9487813410453273}, {
       7.140461327129645, -0.9243101428261493}, {
       7.140461327129645, -0.9243101428261493}, {
       7.247915999945644, -0.9487813410453273}, {
       7.247915999945644, -0.9487813410453273}}, {{
       7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}, {{
       7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}, {{
       7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}, {{
       7.140461327129645, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}, {
       7.140461327129645, -0.6010186336085022}, {
       7.140461327129645, -0.6010186336085022}}, {{
       7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}, {{
       7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}, {{
       7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}, {{
       7.247915999945644, -0.5765474353893242}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}, {
       7.247915999945644, -0.5765474353893242}, {
       7.247915999945644, -0.5765474353893242}}, {{
       7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}, {{
       7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}, {{
       7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}, {{
       7.327113767003174, -0.6010186336085022}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}, {
       7.327113767003174, -0.6010186336085022}, {
       7.327113767003174, -0.6010186336085022}}, {{
       7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}, {{
       7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}, {{
       7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}, {{
       7.387905329850791, -0.6573703126937359}, {
       7.420439986939939, -0.7626643882173257}, {
       7.420439986939939, -0.7626643882173257}, {
       7.387905329850791, -0.6573703126937359}, {
       7.387905329850791, -0.6573703126937359}}, {{
       7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.3510326651394864}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}, {{
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}, {{
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}, {{
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}, {{
       7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}, {{
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}, {{
       7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}, {{
       7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}, {{
       7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}, {{
       7.166868813764986, -0.4168876941543431}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}}, {{
       7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}, {{
       7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}, {{
       7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}, {{
       7.1058234764293395`, -0.35103266513948633`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.35103266513948633`}, {
       7.1058234764293395`, -0.35103266513948633`}}, {{
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}, {{
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}, {{
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}, {{
       7.090825976306549, -0.2851776361246296}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.1058234764293395`, -0.21932260710977286`}, {
       7.090825976306549, -0.2851776361246296}, {
       7.090825976306549, -0.2851776361246296}}, {{
       7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}, {{
       7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}, {{
       7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}, {{
       7.1058234764293395`, -0.21932260710977283`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}, {
       7.1058234764293395`, -0.21932260710977283`}, {
       7.1058234764293395`, -0.21932260710977283`}}, {{
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}, {{
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}, {{
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}, {{
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}}, {{
       7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}, {{
       7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}, {{
       7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}, {{
       7.368487866714291, -0.3709719635473186}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}, {
       7.368487866714291, -0.3709719635473186}, {
       7.368487866714291, -0.3709719635473186}}, {{
       7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}, {{
       7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}, {{
       7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}, {{
       7.318954488681858, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}, {
       7.318954488681858, -0.4168876941543431}, {
       7.318954488681858, -0.4168876941543431}}, {{
       7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}, {{
       7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}, {{
       7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}, {{
       7.254423610526636, -0.4368269925621754}, {
       7.166868813764986, -0.4168876941543431}, {
       7.166868813764986, -0.4168876941543431}, {
       7.254423610526636, -0.4368269925621754}, {
       7.254423610526636, -0.4368269925621754}}, {{
       7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}, {{
       7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}, {{
       7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}, {{
       7.166868813764986, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.166868813764986, -0.1534675780949161}, {
       7.166868813764986, -0.1534675780949161}}, {{
       7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}, {{
       7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}, {{
       7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}, {{
       7.254423610526636, -0.13352827968708383`}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}, {
       7.254423610526636, -0.13352827968708383`}, {
       7.254423610526636, -0.13352827968708383`}}, {{
       7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}, {{
       7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}, {{
       7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}, {{
       7.318954488681858, -0.1534675780949161}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}, {
       7.318954488681858, -0.1534675780949161}, {
       7.318954488681858, -0.1534675780949161}}, {{
       7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}, {{
       7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}, {{
       7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}, {{
       7.368487866714291, -0.1993833087019406}, {
       7.394997326140295, -0.2851776361246296}, {
       7.394997326140295, -0.2851776361246296}, {
       7.368487866714291, -0.1993833087019406}, {
       7.368487866714291, -0.1993833087019406}}, {{7.145692991390315, 
       0.10554771642160712`}, {7.098937185679136, 0.15598735810615977`}, {
       7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.25686664147526506`}, {7.145692991390315, 0.3073062831598177}, {
       7.145692991390315, 0.3073062831598177}, {7.098937185679136, 
       0.256866641475265}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615974`}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}}, {{
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}, {{7.320421035616743, 0.20642699979071238`}, {
       7.300116927415726, 0.14071546342814606`}, {7.262178354207934, 
       0.10554771642160712`}, {7.212752905302511, 0.0902758217435934}, {
       7.145692991390315, 0.10554771642160711`}, {7.145692991390315, 
       0.10554771642160711`}, {7.212752905302511, 0.0902758217435934}, {
       7.262178354207934, 0.10554771642160712`}, {7.300116927415726, 
       0.14071546342814606`}, {7.320421035616743, 0.20642699979071238`}, {
       7.320421035616743, 0.20642699979071238`}}, {{7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}}, {{
       7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.262178354207934, 0.3073062831598177}, {
       7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071238`}, {7.320421035616743, 0.20642699979071238`}, {
       7.300116927415726, 0.2721385361532787}, {7.262178354207934, 
       0.3073062831598177}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}, {{7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}}, {{7.145692991390315, 
       0.10554771642160712`}, {7.098937185679136, 0.15598735810615977`}, {
       7.098937185679136, 0.15598735810615977`}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}}, {{
       7.145692991390315, 0.10554771642160712`}, {7.098937185679136, 
       0.15598735810615977`}, {7.098937185679136, 0.15598735810615977`}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}}, {{7.145692991390315, 0.10554771642160712`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}, {7.145692991390315, 0.10554771642160712`}, {
       7.145692991390315, 0.10554771642160712`}}, {{7.145692991390315, 
       0.10554771642160712`}, {7.098937185679136, 0.15598735810615977`}, {
       7.098937185679136, 0.15598735810615977`}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}}, {{
       7.098937185679136, 0.15598735810615977`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}}, {{7.098937185679136, 0.15598735810615977`}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}, {7.098937185679136, 0.15598735810615977`}, {
       7.098937185679136, 0.15598735810615977`}}, {{7.098937185679136, 
       0.15598735810615977`}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.15598735810615977`}, {7.098937185679136, 0.15598735810615977`}}, {{
       7.098937185679136, 0.15598735810615977`}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.15598735810615977`}, {7.098937185679136, 
       0.15598735810615977`}}, {{7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.256866641475265}, {7.098937185679136, 
       0.256866641475265}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}}, {{7.087450309981506, 
       0.20642699979071238`}, {7.098937185679136, 0.256866641475265}, {
       7.098937185679136, 0.256866641475265}, {7.087450309981506, 
       0.20642699979071238`}, {7.087450309981506, 0.20642699979071238`}}, {{
       7.087450309981506, 0.20642699979071238`}, {7.098937185679136, 
       0.256866641475265}, {7.098937185679136, 0.256866641475265}, {
       7.087450309981506, 0.20642699979071238`}, {7.087450309981506, 
       0.20642699979071238`}}, {{7.087450309981506, 0.20642699979071238`}, {
       7.098937185679136, 0.256866641475265}, {7.098937185679136, 
       0.256866641475265}, {7.087450309981506, 0.20642699979071238`}, {
       7.087450309981506, 0.20642699979071238`}}, {{7.098937185679136, 
       0.25686664147526506`}, {7.145692991390315, 0.3073062831598177}, {
       7.145692991390315, 0.3073062831598177}, {7.098937185679136, 
       0.25686664147526506`}, {7.098937185679136, 0.25686664147526506`}}, {{
       7.098937185679136, 0.25686664147526506`}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}, {
       7.098937185679136, 0.25686664147526506`}, {7.098937185679136, 
       0.25686664147526506`}}, {{7.098937185679136, 0.25686664147526506`}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}, {7.098937185679136, 0.25686664147526506`}, {
       7.098937185679136, 0.25686664147526506`}}, {{7.098937185679136, 
       0.25686664147526506`}, {7.145692991390315, 0.3073062831598177}, {
       7.145692991390315, 0.3073062831598177}, {7.098937185679136, 
       0.25686664147526506`}, {7.098937185679136, 0.25686664147526506`}}, {{
       7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}, {{7.320421035616743, 0.20642699979071238`}, {
       7.300116927415726, 0.14071546342814606`}, {7.300116927415726, 
       0.14071546342814606`}, {7.320421035616743, 0.20642699979071238`}, {
       7.320421035616743, 0.20642699979071238`}}, {{7.320421035616743, 
       0.20642699979071238`}, {7.300116927415726, 0.14071546342814606`}, {
       7.300116927415726, 0.14071546342814606`}, {7.320421035616743, 
       0.20642699979071238`}, {7.320421035616743, 0.20642699979071238`}}, {{
       7.320421035616743, 0.20642699979071238`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}, {
       7.320421035616743, 0.20642699979071238`}, {7.320421035616743, 
       0.20642699979071238`}}, {{7.300116927415726, 0.14071546342814606`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.300116927415726, 0.14071546342814606`}, {
       7.300116927415726, 0.14071546342814606`}}, {{7.300116927415726, 
       0.14071546342814606`}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}, {7.300116927415726, 
       0.14071546342814606`}, {7.300116927415726, 0.14071546342814606`}}, {{
       7.300116927415726, 0.14071546342814606`}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}, {
       7.300116927415726, 0.14071546342814606`}, {7.300116927415726, 
       0.14071546342814606`}}, {{7.300116927415726, 0.14071546342814606`}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}, {7.300116927415726, 0.14071546342814606`}, {
       7.300116927415726, 0.14071546342814606`}}, {{7.262178354207934, 
       0.10554771642160712`}, {7.212752905302511, 0.0902758217435934}, {
       7.212752905302511, 0.0902758217435934}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}}, {{
       7.262178354207934, 0.10554771642160712`}, {7.212752905302511, 
       0.0902758217435934}, {7.212752905302511, 0.0902758217435934}, {
       7.262178354207934, 0.10554771642160712`}, {7.262178354207934, 
       0.10554771642160712`}}, {{7.262178354207934, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}, {7.262178354207934, 0.10554771642160712`}, {
       7.262178354207934, 0.10554771642160712`}}, {{7.262178354207934, 
       0.10554771642160712`}, {7.212752905302511, 0.0902758217435934}, {
       7.212752905302511, 0.0902758217435934}, {7.262178354207934, 
       0.10554771642160712`}, {7.262178354207934, 0.10554771642160712`}}, {{
       7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}}, {{7.212752905302511, 0.0902758217435934}, {
       7.145692991390315, 0.10554771642160712`}, {7.145692991390315, 
       0.10554771642160712`}, {7.212752905302511, 0.0902758217435934}, {
       7.212752905302511, 0.0902758217435934}}, {{7.212752905302511, 
       0.0902758217435934}, {7.145692991390315, 0.10554771642160712`}, {
       7.145692991390315, 0.10554771642160712`}, {7.212752905302511, 
       0.0902758217435934}, {7.212752905302511, 0.0902758217435934}}, {{
       7.212752905302511, 0.0902758217435934}, {7.145692991390315, 
       0.10554771642160712`}, {7.145692991390315, 0.10554771642160712`}, {
       7.212752905302511, 0.0902758217435934}, {7.212752905302511, 
       0.0902758217435934}}, {{7.145692991390315, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}, {7.145692991390315, 0.3073062831598177}, {
       7.145692991390315, 0.3073062831598177}}, {{7.145692991390315, 
       0.3073062831598177}, {7.212752905302511, 0.3225781778378314}, {
       7.212752905302511, 0.3225781778378314}, {7.145692991390315, 
       0.3073062831598177}, {7.145692991390315, 0.3073062831598177}}, {{
       7.145692991390315, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}, {
       7.145692991390315, 0.3073062831598177}, {7.145692991390315, 
       0.3073062831598177}}, {{7.145692991390315, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}, {7.145692991390315, 0.3073062831598177}, {
       7.145692991390315, 0.3073062831598177}}, {{7.212752905302511, 
       0.3225781778378314}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}}, {{
       7.212752905302511, 0.3225781778378314}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}, {
       7.212752905302511, 0.3225781778378314}, {7.212752905302511, 
       0.3225781778378314}}, {{7.212752905302511, 0.3225781778378314}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}, {7.212752905302511, 0.3225781778378314}, {
       7.212752905302511, 0.3225781778378314}}, {{7.212752905302511, 
       0.3225781778378314}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}, {7.212752905302511, 
       0.3225781778378314}, {7.212752905302511, 0.3225781778378314}}, {{
       7.262178354207934, 0.3073062831598177}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}, {{7.262178354207934, 0.3073062831598177}, {
       7.300116927415726, 0.2721385361532787}, {7.300116927415726, 
       0.2721385361532787}, {7.262178354207934, 0.3073062831598177}, {
       7.262178354207934, 0.3073062831598177}}, {{7.262178354207934, 
       0.3073062831598177}, {7.300116927415726, 0.2721385361532787}, {
       7.300116927415726, 0.2721385361532787}, {7.262178354207934, 
       0.3073062831598177}, {7.262178354207934, 0.3073062831598177}}, {{
       7.262178354207934, 0.3073062831598177}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}, {
       7.262178354207934, 0.3073062831598177}, {7.262178354207934, 
       0.3073062831598177}}, {{7.300116927415726, 0.2721385361532787}, {
       7.320421035616743, 0.20642699979071236`}, {7.320421035616743, 
       0.20642699979071236`}, {7.300116927415726, 0.2721385361532787}, {
       7.300116927415726, 0.2721385361532787}}, {{7.300116927415726, 
       0.2721385361532787}, {7.320421035616743, 0.20642699979071236`}, {
       7.320421035616743, 0.20642699979071236`}, {7.300116927415726, 
       0.2721385361532787}, {7.300116927415726, 0.2721385361532787}}, {{
       7.300116927415726, 0.2721385361532787}, {7.320421035616743, 
       0.20642699979071236`}, {7.320421035616743, 0.20642699979071236`}, {
       7.300116927415726, 0.2721385361532787}, {7.300116927415726, 
       0.2721385361532787}}, {{7.300116927415726, 0.2721385361532787}, {
       7.320421035616743, 0.20642699979071236`}, {7.320421035616743, 
       0.20642699979071236`}, {7.300116927415726, 0.2721385361532787}, {
       7.300116927415726, 0.2721385361532787}}, {{7.179586270579003, 
       0.6619229030886622}, {7.11693299303923, 0.7295125600606837}, {
       7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.8646918740047265}, {7.179586270579003, 0.9322815309767478}, {
       7.179586270579003, 0.9322815309767478}, {7.11693299303923, 
       0.8646918740047264}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606835}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}}, {{
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}, {{7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.7090480585668931}, {7.335677897167928, 
       0.6619229030886622}, {7.269447269319737, 0.6414584015948717}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}, {7.269447269319737, 0.6414584015948717}, {
       7.335677897167928, 0.6619229030886622}, {7.38651598926143, 
       0.7090480585668931}, {7.413723710462389, 0.797102217032705}, {
       7.413723710462389, 0.797102217032705}}, {{7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}}, {{
       7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.335677897167928, 0.9322815309767478}, {
       7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.335677897167928, 
       0.9322815309767478}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}, {{7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}}, {{7.179586270579003, 
       0.6619229030886622}, {7.11693299303923, 0.7295125600606837}, {
       7.11693299303923, 0.7295125600606837}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}}, {{
       7.179586270579003, 0.6619229030886622}, {7.11693299303923, 
       0.7295125600606837}, {7.11693299303923, 0.7295125600606837}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}}, {{7.179586270579003, 0.6619229030886622}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}, {7.179586270579003, 0.6619229030886622}, {
       7.179586270579003, 0.6619229030886622}}, {{7.179586270579003, 
       0.6619229030886622}, {7.11693299303923, 0.7295125600606837}, {
       7.11693299303923, 0.7295125600606837}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}}, {{
       7.11693299303923, 0.7295125600606837}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}}, {{7.11693299303923, 0.7295125600606837}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}, {7.11693299303923, 0.7295125600606837}, {
       7.11693299303923, 0.7295125600606837}}, {{7.11693299303923, 
       0.7295125600606837}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.7295125600606837}, {7.11693299303923, 0.7295125600606837}}, {{
       7.11693299303923, 0.7295125600606837}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.7295125600606837}, {7.11693299303923, 
       0.7295125600606837}}, {{7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.8646918740047264}, {7.11693299303923, 
       0.8646918740047264}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}}, {{7.101540457284542, 
       0.797102217032705}, {7.11693299303923, 0.8646918740047264}, {
       7.11693299303923, 0.8646918740047264}, {7.101540457284542, 
       0.797102217032705}, {7.101540457284542, 0.797102217032705}}, {{
       7.101540457284542, 0.797102217032705}, {7.11693299303923, 
       0.8646918740047264}, {7.11693299303923, 0.8646918740047264}, {
       7.101540457284542, 0.797102217032705}, {7.101540457284542, 
       0.797102217032705}}, {{7.101540457284542, 0.797102217032705}, {
       7.11693299303923, 0.8646918740047264}, {7.11693299303923, 
       0.8646918740047264}, {7.101540457284542, 0.797102217032705}, {
       7.101540457284542, 0.797102217032705}}, {{7.11693299303923, 
       0.8646918740047265}, {7.179586270579003, 0.9322815309767478}, {
       7.179586270579003, 0.9322815309767478}, {7.11693299303923, 
       0.8646918740047265}, {7.11693299303923, 0.8646918740047265}}, {{
       7.11693299303923, 0.8646918740047265}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}, {
       7.11693299303923, 0.8646918740047265}, {7.11693299303923, 
       0.8646918740047265}}, {{7.11693299303923, 0.8646918740047265}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}, {7.11693299303923, 0.8646918740047265}, {
       7.11693299303923, 0.8646918740047265}}, {{7.11693299303923, 
       0.8646918740047265}, {7.179586270579003, 0.9322815309767478}, {
       7.179586270579003, 0.9322815309767478}, {7.11693299303923, 
       0.8646918740047265}, {7.11693299303923, 0.8646918740047265}}, {{
       7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}, {{7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.7090480585668931}, {7.38651598926143, 
       0.7090480585668931}, {7.413723710462389, 0.797102217032705}, {
       7.413723710462389, 0.797102217032705}}, {{7.413723710462389, 
       0.797102217032705}, {7.38651598926143, 0.7090480585668931}, {
       7.38651598926143, 0.7090480585668931}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}}, {{
       7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}}, {{7.38651598926143, 0.7090480585668931}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.38651598926143, 0.7090480585668931}, {
       7.38651598926143, 0.7090480585668931}}, {{7.38651598926143, 
       0.7090480585668931}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}, {7.38651598926143, 
       0.7090480585668931}, {7.38651598926143, 0.7090480585668931}}, {{
       7.38651598926143, 0.7090480585668931}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}, {
       7.38651598926143, 0.7090480585668931}, {7.38651598926143, 
       0.7090480585668931}}, {{7.38651598926143, 0.7090480585668931}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}, {7.38651598926143, 0.7090480585668931}, {
       7.38651598926143, 0.7090480585668931}}, {{7.335677897167928, 
       0.6619229030886622}, {7.269447269319737, 0.6414584015948717}, {
       7.269447269319737, 0.6414584015948717}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}}, {{
       7.335677897167928, 0.6619229030886622}, {7.269447269319737, 
       0.6414584015948717}, {7.269447269319737, 0.6414584015948717}, {
       7.335677897167928, 0.6619229030886622}, {7.335677897167928, 
       0.6619229030886622}}, {{7.335677897167928, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}, {7.335677897167928, 0.6619229030886622}, {
       7.335677897167928, 0.6619229030886622}}, {{7.335677897167928, 
       0.6619229030886622}, {7.269447269319737, 0.6414584015948717}, {
       7.269447269319737, 0.6414584015948717}, {7.335677897167928, 
       0.6619229030886622}, {7.335677897167928, 0.6619229030886622}}, {{
       7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}}, {{7.269447269319737, 0.6414584015948717}, {
       7.179586270579003, 0.6619229030886622}, {7.179586270579003, 
       0.6619229030886622}, {7.269447269319737, 0.6414584015948717}, {
       7.269447269319737, 0.6414584015948717}}, {{7.269447269319737, 
       0.6414584015948717}, {7.179586270579003, 0.6619229030886622}, {
       7.179586270579003, 0.6619229030886622}, {7.269447269319737, 
       0.6414584015948717}, {7.269447269319737, 0.6414584015948717}}, {{
       7.269447269319737, 0.6414584015948717}, {7.179586270579003, 
       0.6619229030886622}, {7.179586270579003, 0.6619229030886622}, {
       7.269447269319737, 0.6414584015948717}, {7.269447269319737, 
       0.6414584015948717}}, {{7.179586270579003, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}, {7.179586270579003, 0.9322815309767478}, {
       7.179586270579003, 0.9322815309767478}}, {{7.179586270579003, 
       0.9322815309767478}, {7.269447269319737, 0.9527460324705384}, {
       7.269447269319737, 0.9527460324705384}, {7.179586270579003, 
       0.9322815309767478}, {7.179586270579003, 0.9322815309767478}}, {{
       7.179586270579003, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}, {
       7.179586270579003, 0.9322815309767478}, {7.179586270579003, 
       0.9322815309767478}}, {{7.179586270579003, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}, {7.179586270579003, 0.9322815309767478}, {
       7.179586270579003, 0.9322815309767478}}, {{7.269447269319737, 
       0.9527460324705384}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}}, {{
       7.269447269319737, 0.9527460324705384}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}, {
       7.269447269319737, 0.9527460324705384}, {7.269447269319737, 
       0.9527460324705384}}, {{7.269447269319737, 0.9527460324705384}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}, {7.269447269319737, 0.9527460324705384}, {
       7.269447269319737, 0.9527460324705384}}, {{7.269447269319737, 
       0.9527460324705384}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}, {7.269447269319737, 
       0.9527460324705384}, {7.269447269319737, 0.9527460324705384}}, {{
       7.335677897167928, 0.9322815309767478}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}, {{7.335677897167928, 0.9322815309767478}, {
       7.38651598926143, 0.8851563754985169}, {7.38651598926143, 
       0.8851563754985169}, {7.335677897167928, 0.9322815309767478}, {
       7.335677897167928, 0.9322815309767478}}, {{7.335677897167928, 
       0.9322815309767478}, {7.38651598926143, 0.8851563754985169}, {
       7.38651598926143, 0.8851563754985169}, {7.335677897167928, 
       0.9322815309767478}, {7.335677897167928, 0.9322815309767478}}, {{
       7.335677897167928, 0.9322815309767478}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}, {
       7.335677897167928, 0.9322815309767478}, {7.335677897167928, 
       0.9322815309767478}}, {{7.38651598926143, 0.8851563754985169}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}, {7.38651598926143, 0.8851563754985169}, {
       7.38651598926143, 0.8851563754985169}}, {{7.38651598926143, 
       0.8851563754985169}, {7.413723710462389, 0.797102217032705}, {
       7.413723710462389, 0.797102217032705}, {7.38651598926143, 
       0.8851563754985169}, {7.38651598926143, 0.8851563754985169}}, {{
       7.38651598926143, 0.8851563754985169}, {7.413723710462389, 
       0.797102217032705}, {7.413723710462389, 0.797102217032705}, {
       7.38651598926143, 0.8851563754985169}, {7.38651598926143, 
       0.8851563754985169}}, {{7.38651598926143, 0.8851563754985169}, {
       7.413723710462389, 0.797102217032705}, {7.413723710462389, 
       0.797102217032705}, {7.38651598926143, 0.8851563754985169}, {
       7.38651598926143, 0.8851563754985169}}, {{7.118732973968354, 
       1.1268790948279976`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.118732973968354, 1.41928976254045}, {
       7.118732973968354, 1.41928976254045}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.1999817617561108`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}}, {{
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}}, {{7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.1778480551570418`}, {7.287556351686056, 
       1.1268790948279976`}, {7.215923564290342, 1.1047453882289286`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}, {7.215923564290342, 1.1047453882289286`}, {
       7.287556351686056, 1.1268790948279976`}, {7.342541097578618, 
       1.1778480551570418`}, {7.371968040544907, 1.2730844286842238`}, {
       7.371968040544907, 1.2730844286842238`}}, {{7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}}, {{
       7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.287556351686056, 1.41928976254045}, {
       7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.287556351686056, 
       1.41928976254045}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}, {{7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}}, {{7.118732973968354, 
       1.1268790948279976`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}}, {{
       7.118732973968354, 1.1268790948279976`}, {7.0509693266126545`, 
       1.1999817617561108`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}}, {{7.118732973968354, 1.1268790948279976`}, {
       7.0509693266126545`, 1.1999817617561108`}, {7.0509693266126545`, 
       1.1999817617561108`}, {7.118732973968354, 1.1268790948279976`}, {
       7.118732973968354, 1.1268790948279976`}}, {{7.118732973968354, 
       1.1268790948279976`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}}, {{
       7.0509693266126545`, 1.1999817617561108`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.1999817617561108`}, {7.0509693266126545`, 
       1.1999817617561108`}}, {{7.0509693266126545`, 1.1999817617561108`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.1999817617561108`}, {
       7.0509693266126545`, 1.1999817617561108`}}, {{7.0509693266126545`, 
       1.1999817617561108`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0509693266126545`, 
       1.1999817617561108`}, {7.0509693266126545`, 1.1999817617561108`}}, {{
       7.0509693266126545`, 1.1999817617561108`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.1999817617561108`}, {7.0509693266126545`, 
       1.1999817617561108`}}, {{7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}, {{7.0343212851095025`, 
       1.2730844286842238`}, {7.0509693266126545`, 1.3461870956123367`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0343212851095025`, 
       1.2730844286842238`}, {7.0343212851095025`, 1.2730844286842238`}}, {{
       7.0343212851095025`, 1.2730844286842238`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0509693266126545`, 1.3461870956123367`}, {
       7.0343212851095025`, 1.2730844286842238`}, {7.0343212851095025`, 
       1.2730844286842238`}}, {{7.0343212851095025`, 1.2730844286842238`}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0343212851095025`, 1.2730844286842238`}, {
       7.0343212851095025`, 1.2730844286842238`}}, {{7.0509693266126545`, 
       1.3461870956123367`}, {7.118732973968354, 1.41928976254045}, {
       7.118732973968354, 1.41928976254045}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0509693266126545`, 1.3461870956123367`}}, {{
       7.0509693266126545`, 1.3461870956123367`}, {7.118732973968354, 
       1.41928976254045}, {7.118732973968354, 1.41928976254045}, {
       7.0509693266126545`, 1.3461870956123367`}, {7.0509693266126545`, 
       1.3461870956123367`}}, {{7.0509693266126545`, 1.3461870956123367`}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}, {7.0509693266126545`, 1.3461870956123367`}, {
       7.0509693266126545`, 1.3461870956123367`}}, {{7.0509693266126545`, 
       1.3461870956123367`}, {7.118732973968354, 1.41928976254045}, {
       7.118732973968354, 1.41928976254045}, {7.0509693266126545`, 
       1.3461870956123367`}, {7.0509693266126545`, 1.3461870956123367`}}, {{
       7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}, {{7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.1778480551570418`}, {7.342541097578618, 
       1.1778480551570418`}, {7.371968040544907, 1.2730844286842238`}, {
       7.371968040544907, 1.2730844286842238`}}, {{7.371968040544907, 
       1.2730844286842238`}, {7.342541097578618, 1.1778480551570418`}, {
       7.342541097578618, 1.1778480551570418`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}}, {{
       7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}}, {{7.342541097578618, 1.1778480551570418`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.342541097578618, 1.1778480551570418`}, {
       7.342541097578618, 1.1778480551570418`}}, {{7.342541097578618, 
       1.1778480551570418`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}, {7.342541097578618, 
       1.1778480551570418`}, {7.342541097578618, 1.1778480551570418`}}, {{
       7.342541097578618, 1.1778480551570418`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}, {
       7.342541097578618, 1.1778480551570418`}, {7.342541097578618, 
       1.1778480551570418`}}, {{7.342541097578618, 1.1778480551570418`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}, {7.342541097578618, 1.1778480551570418`}, {
       7.342541097578618, 1.1778480551570418`}}, {{7.287556351686056, 
       1.1268790948279976`}, {7.215923564290342, 1.1047453882289286`}, {
       7.215923564290342, 1.1047453882289286`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}}, {{
       7.287556351686056, 1.1268790948279976`}, {7.215923564290342, 
       1.1047453882289286`}, {7.215923564290342, 1.1047453882289286`}, {
       7.287556351686056, 1.1268790948279976`}, {7.287556351686056, 
       1.1268790948279976`}}, {{7.287556351686056, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}, {7.287556351686056, 1.1268790948279976`}, {
       7.287556351686056, 1.1268790948279976`}}, {{7.287556351686056, 
       1.1268790948279976`}, {7.215923564290342, 1.1047453882289286`}, {
       7.215923564290342, 1.1047453882289286`}, {7.287556351686056, 
       1.1268790948279976`}, {7.287556351686056, 1.1268790948279976`}}, {{
       7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}}, {{7.215923564290342, 1.1047453882289286`}, {
       7.118732973968354, 1.1268790948279976`}, {7.118732973968354, 
       1.1268790948279976`}, {7.215923564290342, 1.1047453882289286`}, {
       7.215923564290342, 1.1047453882289286`}}, {{7.215923564290342, 
       1.1047453882289286`}, {7.118732973968354, 1.1268790948279976`}, {
       7.118732973968354, 1.1268790948279976`}, {7.215923564290342, 
       1.1047453882289286`}, {7.215923564290342, 1.1047453882289286`}}, {{
       7.215923564290342, 1.1047453882289286`}, {7.118732973968354, 
       1.1268790948279976`}, {7.118732973968354, 1.1268790948279976`}, {
       7.215923564290342, 1.1047453882289286`}, {7.215923564290342, 
       1.1047453882289286`}}, {{7.118732973968354, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}, {7.118732973968354, 1.41928976254045}, {
       7.118732973968354, 1.41928976254045}}, {{7.118732973968354, 
       1.41928976254045}, {7.215923564290342, 1.441423469139519}, {
       7.215923564290342, 1.441423469139519}, {7.118732973968354, 
       1.41928976254045}, {7.118732973968354, 1.41928976254045}}, {{
       7.118732973968354, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}, {
       7.118732973968354, 1.41928976254045}, {7.118732973968354, 
       1.41928976254045}}, {{7.118732973968354, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}, {7.118732973968354, 1.41928976254045}, {
       7.118732973968354, 1.41928976254045}}, {{7.215923564290342, 
       1.441423469139519}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}}, {{
       7.215923564290342, 1.441423469139519}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}, {
       7.215923564290342, 1.441423469139519}, {7.215923564290342, 
       1.441423469139519}}, {{7.215923564290342, 1.441423469139519}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}, {7.215923564290342, 1.441423469139519}, {
       7.215923564290342, 1.441423469139519}}, {{7.215923564290342, 
       1.441423469139519}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}, {7.215923564290342, 
       1.441423469139519}, {7.215923564290342, 1.441423469139519}}, {{
       7.287556351686056, 1.41928976254045}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}, {{7.287556351686056, 1.41928976254045}, {
       7.342541097578618, 1.3683208022114057`}, {7.342541097578618, 
       1.3683208022114057`}, {7.287556351686056, 1.41928976254045}, {
       7.287556351686056, 1.41928976254045}}, {{7.287556351686056, 
       1.41928976254045}, {7.342541097578618, 1.3683208022114057`}, {
       7.342541097578618, 1.3683208022114057`}, {7.287556351686056, 
       1.41928976254045}, {7.287556351686056, 1.41928976254045}}, {{
       7.287556351686056, 1.41928976254045}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}, {
       7.287556351686056, 1.41928976254045}, {7.287556351686056, 
       1.41928976254045}}, {{7.342541097578618, 1.3683208022114057`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}, {7.342541097578618, 1.3683208022114057`}, {
       7.342541097578618, 1.3683208022114057`}}, {{7.342541097578618, 
       1.3683208022114057`}, {7.371968040544907, 1.2730844286842238`}, {
       7.371968040544907, 1.2730844286842238`}, {7.342541097578618, 
       1.3683208022114057`}, {7.342541097578618, 1.3683208022114057`}}, {{
       7.342541097578618, 1.3683208022114057`}, {7.371968040544907, 
       1.2730844286842238`}, {7.371968040544907, 1.2730844286842238`}, {
       7.342541097578618, 1.3683208022114057`}, {7.342541097578618, 
       1.3683208022114057`}}, {{7.342541097578618, 1.3683208022114057`}, {
       7.371968040544907, 1.2730844286842238`}, {7.371968040544907, 
       1.2730844286842238`}, {7.342541097578618, 1.3683208022114057`}, {
       7.342541097578618, 1.3683208022114057`}}, {{7.156173080905918, 
       1.5749711292694386`}, {7.090277302685656, 1.6460587598085512`}, {
       7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.7882340208867769`}, {7.156173080905918, 1.8593216514258895`}, {
       7.156173080905918, 1.8593216514258895`}, {7.090277302685656, 
       1.7882340208867769`}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}}, {{
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}, {{7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.624535157137215}, {7.320342931417156, 
       1.5749711292694386`}, {7.250684663957764, 1.5534475265981023`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}, {7.250684663957764, 1.5534475265981023`}, {
       7.320342931417156, 1.5749711292694386`}, {7.373812051841192, 
       1.624535157137215}, {7.402427856672775, 1.717146390347664}, {
       7.402427856672775, 1.717146390347664}}, {{7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}}, {{
       7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.320342931417156, 1.8593216514258895`}, {
       7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.320342931417156, 
       1.8593216514258895`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}, {{7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}}, {{7.156173080905918, 
       1.5749711292694386`}, {7.090277302685656, 1.6460587598085512`}, {
       7.090277302685656, 1.6460587598085512`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}}, {{
       7.156173080905918, 1.5749711292694386`}, {7.090277302685656, 
       1.6460587598085512`}, {7.090277302685656, 1.6460587598085512`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}}, {{7.156173080905918, 1.5749711292694386`}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}, {7.156173080905918, 1.5749711292694386`}, {
       7.156173080905918, 1.5749711292694386`}}, {{7.156173080905918, 
       1.5749711292694386`}, {7.090277302685656, 1.6460587598085512`}, {
       7.090277302685656, 1.6460587598085512`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}}, {{
       7.090277302685656, 1.6460587598085512`}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}}, {{7.090277302685656, 1.6460587598085512`}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}, {7.090277302685656, 1.6460587598085512`}, {
       7.090277302685656, 1.6460587598085512`}}, {{7.090277302685656, 
       1.6460587598085512`}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.6460587598085512`}, {7.090277302685656, 1.6460587598085512`}}, {{
       7.090277302685656, 1.6460587598085512`}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.6460587598085512`}, {7.090277302685656, 
       1.6460587598085512`}}, {{7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}}, {{7.0740881556502995`, 
       1.717146390347664}, {7.090277302685656, 1.7882340208867769`}, {
       7.090277302685656, 1.7882340208867769`}, {7.0740881556502995`, 
       1.717146390347664}, {7.0740881556502995`, 1.717146390347664}}, {{
       7.0740881556502995`, 1.717146390347664}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}, {
       7.0740881556502995`, 1.717146390347664}, {7.0740881556502995`, 
       1.717146390347664}}, {{7.0740881556502995`, 1.717146390347664}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}, {7.0740881556502995`, 1.717146390347664}, {
       7.0740881556502995`, 1.717146390347664}}, {{7.090277302685656, 
       1.7882340208867769`}, {7.156173080905918, 1.8593216514258895`}, {
       7.156173080905918, 1.8593216514258895`}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}}, {{
       7.090277302685656, 1.7882340208867769`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}, {
       7.090277302685656, 1.7882340208867769`}, {7.090277302685656, 
       1.7882340208867769`}}, {{7.090277302685656, 1.7882340208867769`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}, {7.090277302685656, 1.7882340208867769`}, {
       7.090277302685656, 1.7882340208867769`}}, {{7.090277302685656, 
       1.7882340208867769`}, {7.156173080905918, 1.8593216514258895`}, {
       7.156173080905918, 1.8593216514258895`}, {7.090277302685656, 
       1.7882340208867769`}, {7.090277302685656, 1.7882340208867769`}}, {{
       7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}, {{7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.624535157137215}, {7.373812051841192, 
       1.624535157137215}, {7.402427856672775, 1.717146390347664}, {
       7.402427856672775, 1.717146390347664}}, {{7.402427856672775, 
       1.717146390347664}, {7.373812051841192, 1.624535157137215}, {
       7.373812051841192, 1.624535157137215}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}}, {{
       7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}}, {{7.373812051841192, 1.624535157137215}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.373812051841192, 1.624535157137215}, {
       7.373812051841192, 1.624535157137215}}, {{7.373812051841192, 
       1.624535157137215}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}, {7.373812051841192, 
       1.624535157137215}, {7.373812051841192, 1.624535157137215}}, {{
       7.373812051841192, 1.624535157137215}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}, {
       7.373812051841192, 1.624535157137215}, {7.373812051841192, 
       1.624535157137215}}, {{7.373812051841192, 1.624535157137215}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}, {7.373812051841192, 1.624535157137215}, {
       7.373812051841192, 1.624535157137215}}, {{7.320342931417156, 
       1.5749711292694386`}, {7.250684663957764, 1.5534475265981023`}, {
       7.250684663957764, 1.5534475265981023`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}}, {{
       7.320342931417156, 1.5749711292694386`}, {7.250684663957764, 
       1.5534475265981023`}, {7.250684663957764, 1.5534475265981023`}, {
       7.320342931417156, 1.5749711292694386`}, {7.320342931417156, 
       1.5749711292694386`}}, {{7.320342931417156, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}, {7.320342931417156, 1.5749711292694386`}, {
       7.320342931417156, 1.5749711292694386`}}, {{7.320342931417156, 
       1.5749711292694386`}, {7.250684663957764, 1.5534475265981023`}, {
       7.250684663957764, 1.5534475265981023`}, {7.320342931417156, 
       1.5749711292694386`}, {7.320342931417156, 1.5749711292694386`}}, {{
       7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}}, {{7.250684663957764, 1.5534475265981023`}, {
       7.156173080905918, 1.5749711292694386`}, {7.156173080905918, 
       1.5749711292694386`}, {7.250684663957764, 1.5534475265981023`}, {
       7.250684663957764, 1.5534475265981023`}}, {{7.250684663957764, 
       1.5534475265981023`}, {7.156173080905918, 1.5749711292694386`}, {
       7.156173080905918, 1.5749711292694386`}, {7.250684663957764, 
       1.5534475265981023`}, {7.250684663957764, 1.5534475265981023`}}, {{
       7.250684663957764, 1.5534475265981023`}, {7.156173080905918, 
       1.5749711292694386`}, {7.156173080905918, 1.5749711292694386`}, {
       7.250684663957764, 1.5534475265981023`}, {7.250684663957764, 
       1.5534475265981023`}}, {{7.156173080905918, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}, {7.156173080905918, 1.8593216514258895`}, {
       7.156173080905918, 1.8593216514258895`}}, {{7.156173080905918, 
       1.8593216514258895`}, {7.250684663957764, 1.8808452540972258`}, {
       7.250684663957764, 1.8808452540972258`}, {7.156173080905918, 
       1.8593216514258895`}, {7.156173080905918, 1.8593216514258895`}}, {{
       7.156173080905918, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}, {
       7.156173080905918, 1.8593216514258895`}, {7.156173080905918, 
       1.8593216514258895`}}, {{7.156173080905918, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}, {7.156173080905918, 1.8593216514258895`}, {
       7.156173080905918, 1.8593216514258895`}}, {{7.250684663957764, 
       1.8808452540972258`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}}, {{
       7.250684663957764, 1.8808452540972258`}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}, {
       7.250684663957764, 1.8808452540972258`}, {7.250684663957764, 
       1.8808452540972258`}}, {{7.250684663957764, 1.8808452540972258`}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}, {7.250684663957764, 1.8808452540972258`}, {
       7.250684663957764, 1.8808452540972258`}}, {{7.250684663957764, 
       1.8808452540972258`}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}, {7.250684663957764, 
       1.8808452540972258`}, {7.250684663957764, 1.8808452540972258`}}, {{
       7.320342931417156, 1.8593216514258895`}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}, {{7.320342931417156, 1.8593216514258895`}, {
       7.373812051841192, 1.809757623558113}, {7.373812051841192, 
       1.809757623558113}, {7.320342931417156, 1.8593216514258895`}, {
       7.320342931417156, 1.8593216514258895`}}, {{7.320342931417156, 
       1.8593216514258895`}, {7.373812051841192, 1.809757623558113}, {
       7.373812051841192, 1.809757623558113}, {7.320342931417156, 
       1.8593216514258895`}, {7.320342931417156, 1.8593216514258895`}}, {{
       7.320342931417156, 1.8593216514258895`}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}, {
       7.320342931417156, 1.8593216514258895`}, {7.320342931417156, 
       1.8593216514258895`}}, {{7.373812051841192, 1.809757623558113}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}, {7.373812051841192, 1.809757623558113}, {
       7.373812051841192, 1.809757623558113}}, {{7.373812051841192, 
       1.809757623558113}, {7.402427856672775, 1.717146390347664}, {
       7.402427856672775, 1.717146390347664}, {7.373812051841192, 
       1.809757623558113}, {7.373812051841192, 1.809757623558113}}, {{
       7.373812051841192, 1.809757623558113}, {7.402427856672775, 
       1.717146390347664}, {7.402427856672775, 1.717146390347664}, {
       7.373812051841192, 1.809757623558113}, {7.373812051841192, 
       1.809757623558113}}, {{7.373812051841192, 1.809757623558113}, {
       7.402427856672775, 1.717146390347664}, {7.402427856672775, 
       1.717146390347664}, {7.373812051841192, 1.809757623558113}, {
       7.373812051841192, 1.809757623558113}}, {{7.126540974712638, 
       2.1320904620857117`}, {7.064265958989476, 2.1992720544291244`}, {
       7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.33363523911595}, {7.126540974712638, 2.4008168314593625`}, {
       7.126540974712638, 2.4008168314593625`}, {7.064265958989476, 
       2.33363523911595}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}}, {{
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}, {{7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.1789311049634965`}, {7.281690216408867, 
       2.1320904620857117`}, {7.215859448210305, 2.111749512620084}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}, {7.215859448210305, 2.111749512620084}, {
       7.281690216408867, 2.1320904620857117`}, {7.332221379482476, 
       2.1789311049634965`}, {7.359264837256981, 2.266453646772537}, {
       7.359264837256981, 2.266453646772537}}, {{7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}}, {{
       7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.281690216408867, 2.4008168314593625`}, {
       7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.281690216408867, 
       2.4008168314593625`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}, {{7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}}, {{7.126540974712638, 
       2.1320904620857117`}, {7.064265958989476, 2.1992720544291244`}, {
       7.064265958989476, 2.1992720544291244`}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}}, {{
       7.126540974712638, 2.1320904620857117`}, {7.064265958989476, 
       2.1992720544291244`}, {7.064265958989476, 2.1992720544291244`}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}}, {{7.126540974712638, 2.1320904620857117`}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}, {7.126540974712638, 2.1320904620857117`}, {
       7.126540974712638, 2.1320904620857117`}}, {{7.126540974712638, 
       2.1320904620857117`}, {7.064265958989476, 2.1992720544291244`}, {
       7.064265958989476, 2.1992720544291244`}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}}, {{
       7.064265958989476, 2.1992720544291244`}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}}, {{7.064265958989476, 2.1992720544291244`}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}, {7.064265958989476, 2.1992720544291244`}, {
       7.064265958989476, 2.1992720544291244`}}, {{7.064265958989476, 
       2.1992720544291244`}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.1992720544291244`}, {7.064265958989476, 2.1992720544291244`}}, {{
       7.064265958989476, 2.1992720544291244`}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.1992720544291244`}, {7.064265958989476, 
       2.1992720544291244`}}, {{7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}}, {{7.048966353864524, 
       2.266453646772537}, {7.064265958989476, 2.33363523911595}, {
       7.064265958989476, 2.33363523911595}, {7.048966353864524, 
       2.266453646772537}, {7.048966353864524, 2.266453646772537}}, {{
       7.048966353864524, 2.266453646772537}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}, {
       7.048966353864524, 2.266453646772537}, {7.048966353864524, 
       2.266453646772537}}, {{7.048966353864524, 2.266453646772537}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}, {7.048966353864524, 2.266453646772537}, {
       7.048966353864524, 2.266453646772537}}, {{7.064265958989476, 
       2.33363523911595}, {7.126540974712638, 2.4008168314593625`}, {
       7.126540974712638, 2.4008168314593625`}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}}, {{
       7.064265958989476, 2.33363523911595}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}, {
       7.064265958989476, 2.33363523911595}, {7.064265958989476, 
       2.33363523911595}}, {{7.064265958989476, 2.33363523911595}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}, {7.064265958989476, 2.33363523911595}, {
       7.064265958989476, 2.33363523911595}}, {{7.064265958989476, 
       2.33363523911595}, {7.126540974712638, 2.4008168314593625`}, {
       7.126540974712638, 2.4008168314593625`}, {7.064265958989476, 
       2.33363523911595}, {7.064265958989476, 2.33363523911595}}, {{
       7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}, {{7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.1789311049634965`}, {7.332221379482476, 
       2.1789311049634965`}, {7.359264837256981, 2.266453646772537}, {
       7.359264837256981, 2.266453646772537}}, {{7.359264837256981, 
       2.266453646772537}, {7.332221379482476, 2.1789311049634965`}, {
       7.332221379482476, 2.1789311049634965`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}}, {{
       7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}}, {{7.332221379482476, 2.1789311049634965`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.332221379482476, 2.1789311049634965`}, {
       7.332221379482476, 2.1789311049634965`}}, {{7.332221379482476, 
       2.1789311049634965`}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}, {7.332221379482476, 
       2.1789311049634965`}, {7.332221379482476, 2.1789311049634965`}}, {{
       7.332221379482476, 2.1789311049634965`}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}, {
       7.332221379482476, 2.1789311049634965`}, {7.332221379482476, 
       2.1789311049634965`}}, {{7.332221379482476, 2.1789311049634965`}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}, {7.332221379482476, 2.1789311049634965`}, {
       7.332221379482476, 2.1789311049634965`}}, {{7.281690216408867, 
       2.1320904620857117`}, {7.215859448210305, 2.111749512620084}, {
       7.215859448210305, 2.111749512620084}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}}, {{
       7.281690216408867, 2.1320904620857117`}, {7.215859448210305, 
       2.111749512620084}, {7.215859448210305, 2.111749512620084}, {
       7.281690216408867, 2.1320904620857117`}, {7.281690216408867, 
       2.1320904620857117`}}, {{7.281690216408867, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}, {7.281690216408867, 2.1320904620857117`}, {
       7.281690216408867, 2.1320904620857117`}}, {{7.281690216408867, 
       2.1320904620857117`}, {7.215859448210305, 2.111749512620084}, {
       7.215859448210305, 2.111749512620084}, {7.281690216408867, 
       2.1320904620857117`}, {7.281690216408867, 2.1320904620857117`}}, {{
       7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}}, {{7.215859448210305, 2.111749512620084}, {
       7.126540974712638, 2.1320904620857117`}, {7.126540974712638, 
       2.1320904620857117`}, {7.215859448210305, 2.111749512620084}, {
       7.215859448210305, 2.111749512620084}}, {{7.215859448210305, 
       2.111749512620084}, {7.126540974712638, 2.1320904620857117`}, {
       7.126540974712638, 2.1320904620857117`}, {7.215859448210305, 
       2.111749512620084}, {7.215859448210305, 2.111749512620084}}, {{
       7.215859448210305, 2.111749512620084}, {7.126540974712638, 
       2.1320904620857117`}, {7.126540974712638, 2.1320904620857117`}, {
       7.215859448210305, 2.111749512620084}, {7.215859448210305, 
       2.111749512620084}}, {{7.126540974712638, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}, {7.126540974712638, 2.4008168314593625`}, {
       7.126540974712638, 2.4008168314593625`}}, {{7.126540974712638, 
       2.4008168314593625`}, {7.215859448210305, 2.4211577809249905`}, {
       7.215859448210305, 2.4211577809249905`}, {7.126540974712638, 
       2.4008168314593625`}, {7.126540974712638, 2.4008168314593625`}}, {{
       7.126540974712638, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}, {
       7.126540974712638, 2.4008168314593625`}, {7.126540974712638, 
       2.4008168314593625`}}, {{7.126540974712638, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}, {7.126540974712638, 2.4008168314593625`}, {
       7.126540974712638, 2.4008168314593625`}}, {{7.215859448210305, 
       2.4211577809249905`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}}, {{
       7.215859448210305, 2.4211577809249905`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}, {
       7.215859448210305, 2.4211577809249905`}, {7.215859448210305, 
       2.4211577809249905`}}, {{7.215859448210305, 2.4211577809249905`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}, {7.215859448210305, 2.4211577809249905`}, {
       7.215859448210305, 2.4211577809249905`}}, {{7.215859448210305, 
       2.4211577809249905`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}, {7.215859448210305, 
       2.4211577809249905`}, {7.215859448210305, 2.4211577809249905`}}, {{
       7.281690216408867, 2.4008168314593625`}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}, {{7.281690216408867, 2.4008168314593625`}, {
       7.332221379482476, 2.3539761885815778`}, {7.332221379482476, 
       2.3539761885815778`}, {7.281690216408867, 2.4008168314593625`}, {
       7.281690216408867, 2.4008168314593625`}}, {{7.281690216408867, 
       2.4008168314593625`}, {7.332221379482476, 2.3539761885815778`}, {
       7.332221379482476, 2.3539761885815778`}, {7.281690216408867, 
       2.4008168314593625`}, {7.281690216408867, 2.4008168314593625`}}, {{
       7.281690216408867, 2.4008168314593625`}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}, {
       7.281690216408867, 2.4008168314593625`}, {7.281690216408867, 
       2.4008168314593625`}}, {{7.332221379482476, 2.3539761885815778`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}, {7.332221379482476, 2.3539761885815778`}, {
       7.332221379482476, 2.3539761885815778`}}, {{7.332221379482476, 
       2.3539761885815778`}, {7.359264837256981, 2.266453646772537}, {
       7.359264837256981, 2.266453646772537}, {7.332221379482476, 
       2.3539761885815778`}, {7.332221379482476, 2.3539761885815778`}}, {{
       7.332221379482476, 2.3539761885815778`}, {7.359264837256981, 
       2.266453646772537}, {7.359264837256981, 2.266453646772537}, {
       7.332221379482476, 2.3539761885815778`}, {7.332221379482476, 
       2.3539761885815778`}}, {{7.332221379482476, 2.3539761885815778`}, {
       7.359264837256981, 2.266453646772537}, {7.359264837256981, 
       2.266453646772537}, {7.332221379482476, 2.3539761885815778`}, {
       7.332221379482476, 2.3539761885815778`}}, {{7.154535917837162, 
       2.648749167870542}, {7.099447751929565, 2.708177666795416}, {
       7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.8270346646451627`}, {7.154535917837162, 2.8864631635700366`}, {
       7.154535917837162, 2.8864631635700366`}, {7.099447751929565, 
       2.8270346646451627`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}}, {{
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}, {{7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.690184165133982}, {7.291780157244407, 
       2.648749167870542}, {7.233546590568677, 2.6307556662091085`}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}, {7.233546590568677, 2.6307556662091085`}, {
       7.291780157244407, 2.648749167870542}, {7.336479770124111, 
       2.690184165133982}, {7.360402276948029, 2.7676061657202893`}, {
       7.360402276948029, 2.7676061657202893`}}, {{7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}}, {{
       7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.291780157244407, 2.8864631635700366`}, {
       7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.291780157244407, 
       2.8864631635700366`}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}, {{7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}}, {{7.154535917837162, 
       2.648749167870542}, {7.099447751929565, 2.708177666795416}, {
       7.099447751929565, 2.708177666795416}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}}, {{
       7.154535917837162, 2.648749167870542}, {7.099447751929565, 
       2.708177666795416}, {7.099447751929565, 2.708177666795416}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}}, {{7.154535917837162, 2.648749167870542}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}, {7.154535917837162, 2.648749167870542}, {
       7.154535917837162, 2.648749167870542}}, {{7.154535917837162, 
       2.648749167870542}, {7.099447751929565, 2.708177666795416}, {
       7.099447751929565, 2.708177666795416}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}}, {{
       7.099447751929565, 2.708177666795416}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}}, {{7.099447751929565, 2.708177666795416}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}, {7.099447751929565, 2.708177666795416}, {
       7.099447751929565, 2.708177666795416}}, {{7.099447751929565, 
       2.708177666795416}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.708177666795416}, {7.099447751929565, 2.708177666795416}}, {{
       7.099447751929565, 2.708177666795416}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.708177666795416}, {7.099447751929565, 
       2.708177666795416}}, {{7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}}, {{7.08591379813354, 
       2.7676061657202893`}, {7.099447751929565, 2.8270346646451627`}, {
       7.099447751929565, 2.8270346646451627`}, {7.08591379813354, 
       2.7676061657202893`}, {7.08591379813354, 2.7676061657202893`}}, {{
       7.08591379813354, 2.7676061657202893`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}, {
       7.08591379813354, 2.7676061657202893`}, {7.08591379813354, 
       2.7676061657202893`}}, {{7.08591379813354, 2.7676061657202893`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}, {7.08591379813354, 2.7676061657202893`}, {
       7.08591379813354, 2.7676061657202893`}}, {{7.099447751929565, 
       2.8270346646451627`}, {7.154535917837162, 2.8864631635700366`}, {
       7.154535917837162, 2.8864631635700366`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}}, {{
       7.099447751929565, 2.8270346646451627`}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}, {
       7.099447751929565, 2.8270346646451627`}, {7.099447751929565, 
       2.8270346646451627`}}, {{7.099447751929565, 2.8270346646451627`}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}, {7.099447751929565, 2.8270346646451627`}, {
       7.099447751929565, 2.8270346646451627`}}, {{7.099447751929565, 
       2.8270346646451627`}, {7.154535917837162, 2.8864631635700366`}, {
       7.154535917837162, 2.8864631635700366`}, {7.099447751929565, 
       2.8270346646451627`}, {7.099447751929565, 2.8270346646451627`}}, {{
       7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}, {{7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.690184165133982}, {7.336479770124111, 
       2.690184165133982}, {7.360402276948029, 2.7676061657202893`}, {
       7.360402276948029, 2.7676061657202893`}}, {{7.360402276948029, 
       2.7676061657202893`}, {7.336479770124111, 2.690184165133982}, {
       7.336479770124111, 2.690184165133982}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}}, {{
       7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}}, {{7.336479770124111, 2.690184165133982}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.336479770124111, 2.690184165133982}, {
       7.336479770124111, 2.690184165133982}}, {{7.336479770124111, 
       2.690184165133982}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}, {7.336479770124111, 
       2.690184165133982}, {7.336479770124111, 2.690184165133982}}, {{
       7.336479770124111, 2.690184165133982}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}, {
       7.336479770124111, 2.690184165133982}, {7.336479770124111, 
       2.690184165133982}}, {{7.336479770124111, 2.690184165133982}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}, {7.336479770124111, 2.690184165133982}, {
       7.336479770124111, 2.690184165133982}}, {{7.291780157244407, 
       2.648749167870542}, {7.233546590568677, 2.6307556662091085`}, {
       7.233546590568677, 2.6307556662091085`}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}}, {{
       7.291780157244407, 2.648749167870542}, {7.233546590568677, 
       2.6307556662091085`}, {7.233546590568677, 2.6307556662091085`}, {
       7.291780157244407, 2.648749167870542}, {7.291780157244407, 
       2.648749167870542}}, {{7.291780157244407, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}, {7.291780157244407, 2.648749167870542}, {
       7.291780157244407, 2.648749167870542}}, {{7.291780157244407, 
       2.648749167870542}, {7.233546590568677, 2.6307556662091085`}, {
       7.233546590568677, 2.6307556662091085`}, {7.291780157244407, 
       2.648749167870542}, {7.291780157244407, 2.648749167870542}}, {{
       7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}}, {{7.233546590568677, 2.6307556662091085`}, {
       7.154535917837162, 2.648749167870542}, {7.154535917837162, 
       2.648749167870542}, {7.233546590568677, 2.6307556662091085`}, {
       7.233546590568677, 2.6307556662091085`}}, {{7.233546590568677, 
       2.6307556662091085`}, {7.154535917837162, 2.648749167870542}, {
       7.154535917837162, 2.648749167870542}, {7.233546590568677, 
       2.6307556662091085`}, {7.233546590568677, 2.6307556662091085`}}, {{
       7.233546590568677, 2.6307556662091085`}, {7.154535917837162, 
       2.648749167870542}, {7.154535917837162, 2.648749167870542}, {
       7.233546590568677, 2.6307556662091085`}, {7.233546590568677, 
       2.6307556662091085`}}, {{7.154535917837162, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}, {7.154535917837162, 2.8864631635700366`}, {
       7.154535917837162, 2.8864631635700366`}}, {{7.154535917837162, 
       2.8864631635700366`}, {7.233546590568677, 2.90445666523147}, {
       7.233546590568677, 2.90445666523147}, {7.154535917837162, 
       2.8864631635700366`}, {7.154535917837162, 2.8864631635700366`}}, {{
       7.154535917837162, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}, {
       7.154535917837162, 2.8864631635700366`}, {7.154535917837162, 
       2.8864631635700366`}}, {{7.154535917837162, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}, {7.154535917837162, 2.8864631635700366`}, {
       7.154535917837162, 2.8864631635700366`}}, {{7.233546590568677, 
       2.90445666523147}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}}, {{
       7.233546590568677, 2.90445666523147}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}, {
       7.233546590568677, 2.90445666523147}, {7.233546590568677, 
       2.90445666523147}}, {{7.233546590568677, 2.90445666523147}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}, {7.233546590568677, 2.90445666523147}, {
       7.233546590568677, 2.90445666523147}}, {{7.233546590568677, 
       2.90445666523147}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}, {7.233546590568677, 
       2.90445666523147}, {7.233546590568677, 2.90445666523147}}, {{
       7.291780157244407, 2.8864631635700366`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}, {{7.291780157244407, 2.8864631635700366`}, {
       7.336479770124111, 2.8450281663065966`}, {7.336479770124111, 
       2.8450281663065966`}, {7.291780157244407, 2.8864631635700366`}, {
       7.291780157244407, 2.8864631635700366`}}, {{7.291780157244407, 
       2.8864631635700366`}, {7.336479770124111, 2.8450281663065966`}, {
       7.336479770124111, 2.8450281663065966`}, {7.291780157244407, 
       2.8864631635700366`}, {7.291780157244407, 2.8864631635700366`}}, {{
       7.291780157244407, 2.8864631635700366`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}, {
       7.291780157244407, 2.8864631635700366`}, {7.291780157244407, 
       2.8864631635700366`}}, {{7.336479770124111, 2.8450281663065966`}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}, {7.336479770124111, 2.8450281663065966`}, {
       7.336479770124111, 2.8450281663065966`}}, {{7.336479770124111, 
       2.8450281663065966`}, {7.360402276948029, 2.7676061657202893`}, {
       7.360402276948029, 2.7676061657202893`}, {7.336479770124111, 
       2.8450281663065966`}, {7.336479770124111, 2.8450281663065966`}}, {{
       7.336479770124111, 2.8450281663065966`}, {7.360402276948029, 
       2.7676061657202893`}, {7.360402276948029, 2.7676061657202893`}, {
       7.336479770124111, 2.8450281663065966`}, {7.336479770124111, 
       2.8450281663065966`}}, {{7.336479770124111, 2.8450281663065966`}, {
       7.360402276948029, 2.7676061657202893`}, {7.360402276948029, 
       2.7676061657202893`}, {7.336479770124111, 2.8450281663065966`}, {
       7.336479770124111, 2.8450281663065966`}}, {{7.127958962701148, 
       3.1105906386595095`}, {7.059649313425901, 3.1842823263682973`}, {
       7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.331665701785873}, {7.127958962701148, 3.405357389494661}, {
       7.127958962701148, 3.405357389494661}, {7.059649313425901, 
       3.331665701785873}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}}, {{
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}, {{7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.1619702786267223`}, {7.298142625643973, 
       3.1105906386595095`}, {7.22593266094233, 3.0882785909179344`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}, {7.22593266094233, 3.0882785909179344`}, {
       7.298142625643973, 3.1105906386595095`}, {7.353570408149451, 
       3.1619702786267223`}, {7.383234457115386, 3.257974014077085}, {
       7.383234457115386, 3.257974014077085}}, {{7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}}, {{
       7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.298142625643973, 3.405357389494661}, {
       7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.298142625643973, 
       3.405357389494661}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}, {{7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}}, {{7.127958962701148, 
       3.1105906386595095`}, {7.059649313425901, 3.1842823263682973`}, {
       7.059649313425901, 3.1842823263682973`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}}, {{
       7.127958962701148, 3.1105906386595095`}, {7.059649313425901, 
       3.1842823263682973`}, {7.059649313425901, 3.1842823263682973`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}}, {{7.127958962701148, 3.1105906386595095`}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}, {7.127958962701148, 3.1105906386595095`}, {
       7.127958962701148, 3.1105906386595095`}}, {{7.127958962701148, 
       3.1105906386595095`}, {7.059649313425901, 3.1842823263682973`}, {
       7.059649313425901, 3.1842823263682973`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}}, {{
       7.059649313425901, 3.1842823263682973`}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}}, {{7.059649313425901, 3.1842823263682973`}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}, {7.059649313425901, 3.1842823263682973`}, {
       7.059649313425901, 3.1842823263682973`}}, {{7.059649313425901, 
       3.1842823263682973`}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.1842823263682973`}, {7.059649313425901, 3.1842823263682973`}}, {{
       7.059649313425901, 3.1842823263682973`}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.1842823263682973`}, {7.059649313425901, 
       3.1842823263682973`}}, {{7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}}, {{7.042867131229735, 
       3.257974014077085}, {7.059649313425901, 3.331665701785873}, {
       7.059649313425901, 3.331665701785873}, {7.042867131229735, 
       3.257974014077085}, {7.042867131229735, 3.257974014077085}}, {{
       7.042867131229735, 3.257974014077085}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}, {
       7.042867131229735, 3.257974014077085}, {7.042867131229735, 
       3.257974014077085}}, {{7.042867131229735, 3.257974014077085}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}, {7.042867131229735, 3.257974014077085}, {
       7.042867131229735, 3.257974014077085}}, {{7.059649313425901, 
       3.331665701785873}, {7.127958962701148, 3.405357389494661}, {
       7.127958962701148, 3.405357389494661}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}}, {{
       7.059649313425901, 3.331665701785873}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}, {
       7.059649313425901, 3.331665701785873}, {7.059649313425901, 
       3.331665701785873}}, {{7.059649313425901, 3.331665701785873}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}, {7.059649313425901, 3.331665701785873}, {
       7.059649313425901, 3.331665701785873}}, {{7.059649313425901, 
       3.331665701785873}, {7.127958962701148, 3.405357389494661}, {
       7.127958962701148, 3.405357389494661}, {7.059649313425901, 
       3.331665701785873}, {7.059649313425901, 3.331665701785873}}, {{
       7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}, {{7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.1619702786267223`}, {7.353570408149451, 
       3.1619702786267223`}, {7.383234457115386, 3.257974014077085}, {
       7.383234457115386, 3.257974014077085}}, {{7.383234457115386, 
       3.257974014077085}, {7.353570408149451, 3.1619702786267223`}, {
       7.353570408149451, 3.1619702786267223`}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}}, {{
       7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}}, {{7.353570408149451, 3.1619702786267223`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.353570408149451, 3.1619702786267223`}, {
       7.353570408149451, 3.1619702786267223`}}, {{7.353570408149451, 
       3.1619702786267223`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}, {7.353570408149451, 
       3.1619702786267223`}, {7.353570408149451, 3.1619702786267223`}}, {{
       7.353570408149451, 3.1619702786267223`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}, {
       7.353570408149451, 3.1619702786267223`}, {7.353570408149451, 
       3.1619702786267223`}}, {{7.353570408149451, 3.1619702786267223`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}, {7.353570408149451, 3.1619702786267223`}, {
       7.353570408149451, 3.1619702786267223`}}, {{7.298142625643973, 
       3.1105906386595095`}, {7.22593266094233, 3.0882785909179344`}, {
       7.22593266094233, 3.0882785909179344`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}}, {{
       7.298142625643973, 3.1105906386595095`}, {7.22593266094233, 
       3.0882785909179344`}, {7.22593266094233, 3.0882785909179344`}, {
       7.298142625643973, 3.1105906386595095`}, {7.298142625643973, 
       3.1105906386595095`}}, {{7.298142625643973, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}, {7.298142625643973, 3.1105906386595095`}, {
       7.298142625643973, 3.1105906386595095`}}, {{7.298142625643973, 
       3.1105906386595095`}, {7.22593266094233, 3.0882785909179344`}, {
       7.22593266094233, 3.0882785909179344`}, {7.298142625643973, 
       3.1105906386595095`}, {7.298142625643973, 3.1105906386595095`}}, {{
       7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}}, {{7.22593266094233, 3.0882785909179344`}, {
       7.127958962701148, 3.1105906386595095`}, {7.127958962701148, 
       3.1105906386595095`}, {7.22593266094233, 3.0882785909179344`}, {
       7.22593266094233, 3.0882785909179344`}}, {{7.22593266094233, 
       3.0882785909179344`}, {7.127958962701148, 3.1105906386595095`}, {
       7.127958962701148, 3.1105906386595095`}, {7.22593266094233, 
       3.0882785909179344`}, {7.22593266094233, 3.0882785909179344`}}, {{
       7.22593266094233, 3.0882785909179344`}, {7.127958962701148, 
       3.1105906386595095`}, {7.127958962701148, 3.1105906386595095`}, {
       7.22593266094233, 3.0882785909179344`}, {7.22593266094233, 
       3.0882785909179344`}}, {{7.127958962701148, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}, {7.127958962701148, 3.405357389494661}, {
       7.127958962701148, 3.405357389494661}}, {{7.127958962701148, 
       3.405357389494661}, {7.22593266094233, 3.427669437236236}, {
       7.22593266094233, 3.427669437236236}, {7.127958962701148, 
       3.405357389494661}, {7.127958962701148, 3.405357389494661}}, {{
       7.127958962701148, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}, {
       7.127958962701148, 3.405357389494661}, {7.127958962701148, 
       3.405357389494661}}, {{7.127958962701148, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}, {7.127958962701148, 3.405357389494661}, {
       7.127958962701148, 3.405357389494661}}, {{7.22593266094233, 
       3.427669437236236}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}}, {{
       7.22593266094233, 3.427669437236236}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}, {
       7.22593266094233, 3.427669437236236}, {7.22593266094233, 
       3.427669437236236}}, {{7.22593266094233, 3.427669437236236}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}, {7.22593266094233, 3.427669437236236}, {
       7.22593266094233, 3.427669437236236}}, {{7.22593266094233, 
       3.427669437236236}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}, {7.22593266094233, 
       3.427669437236236}, {7.22593266094233, 3.427669437236236}}, {{
       7.298142625643973, 3.405357389494661}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}, {{7.298142625643973, 3.405357389494661}, {
       7.353570408149451, 3.353977749527448}, {7.353570408149451, 
       3.353977749527448}, {7.298142625643973, 3.405357389494661}, {
       7.298142625643973, 3.405357389494661}}, {{7.298142625643973, 
       3.405357389494661}, {7.353570408149451, 3.353977749527448}, {
       7.353570408149451, 3.353977749527448}, {7.298142625643973, 
       3.405357389494661}, {7.298142625643973, 3.405357389494661}}, {{
       7.298142625643973, 3.405357389494661}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}, {
       7.298142625643973, 3.405357389494661}, {7.298142625643973, 
       3.405357389494661}}, {{7.353570408149451, 3.353977749527448}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}, {7.353570408149451, 3.353977749527448}, {
       7.353570408149451, 3.353977749527448}}, {{7.353570408149451, 
       3.353977749527448}, {7.383234457115386, 3.257974014077085}, {
       7.383234457115386, 3.257974014077085}, {7.353570408149451, 
       3.353977749527448}, {7.353570408149451, 3.353977749527448}}, {{
       7.353570408149451, 3.353977749527448}, {7.383234457115386, 
       3.257974014077085}, {7.383234457115386, 3.257974014077085}, {
       7.353570408149451, 3.353977749527448}, {7.353570408149451, 
       3.353977749527448}}, {{7.353570408149451, 3.353977749527448}, {
       7.383234457115386, 3.257974014077085}, {7.383234457115386, 
       3.257974014077085}, {7.353570408149451, 3.353977749527448}, {
       7.353570408149451, 3.353977749527448}}, {{7.214825242898728, 
       3.5728163042497076`}, {7.150356804327845, 3.642364136695691}, {
       7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.7814598015876575`}, {7.214825242898728, 3.8510076340336408`}, {
       7.214825242898728, 3.8510076340336408`}, {7.150356804327845, 
       3.7814598015876575`}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}}, {{
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}, {{7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.6213067473739806`}, {7.375439082035703, 
       3.5728163042497076`}, {7.307289651860536, 3.551758914927997}, {
       7.214825242898729, 3.5728163042497076`}, {7.214825242898729, 
       3.5728163042497076`}, {7.307289651860536, 3.551758914927997}, {
       7.375439082035703, 3.5728163042497076`}, {7.427750031213266, 
       3.6213067473739806`}, {7.455746001604189, 3.711911969141674}, {
       7.455746001604189, 3.711911969141674}}, {{7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}}, {{
       7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.375439082035703, 3.8510076340336408`}, {
       7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.375439082035703, 
       3.8510076340336408`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}, {{7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}}, {{7.214825242898728, 
       3.5728163042497076`}, {7.150356804327845, 3.642364136695691}, {
       7.150356804327845, 3.642364136695691}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}}, {{
       7.214825242898728, 3.5728163042497076`}, {7.150356804327845, 
       3.642364136695691}, {7.150356804327845, 3.642364136695691}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}}, {{7.214825242898728, 3.5728163042497076`}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}, {7.214825242898728, 3.5728163042497076`}, {
       7.214825242898728, 3.5728163042497076`}}, {{7.214825242898728, 
       3.5728163042497076`}, {7.150356804327845, 3.642364136695691}, {
       7.150356804327845, 3.642364136695691}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}}, {{
       7.150356804327845, 3.642364136695691}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}}, {{7.150356804327845, 3.642364136695691}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}, {7.150356804327845, 3.642364136695691}, {
       7.150356804327845, 3.642364136695691}}, {{7.150356804327845, 
       3.642364136695691}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.642364136695691}, {7.150356804327845, 3.642364136695691}}, {{
       7.150356804327845, 3.642364136695691}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.642364136695691}, {7.150356804327845, 
       3.642364136695691}}, {{7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}}, {{7.134518323330242, 
       3.711911969141674}, {7.150356804327845, 3.7814598015876575`}, {
       7.150356804327845, 3.7814598015876575`}, {7.134518323330242, 
       3.711911969141674}, {7.134518323330242, 3.711911969141674}}, {{
       7.134518323330242, 3.711911969141674}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}, {
       7.134518323330242, 3.711911969141674}, {7.134518323330242, 
       3.711911969141674}}, {{7.134518323330242, 3.711911969141674}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}, {7.134518323330242, 3.711911969141674}, {
       7.134518323330242, 3.711911969141674}}, {{7.150356804327845, 
       3.7814598015876575`}, {7.214825242898728, 3.8510076340336408`}, {
       7.214825242898728, 3.8510076340336408`}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}}, {{
       7.150356804327845, 3.7814598015876575`}, {7.214825242898728, 
       3.8510076340336408`}, {7.214825242898728, 3.8510076340336408`}, {
       7.150356804327845, 3.7814598015876575`}, {7.150356804327845, 
       3.7814598015876575`}}, {{7.150356804327845, 3.7814598015876575`}, {
       7.214825242898728, 3.8510076340336408`}, {7.214825242898728, 
       3.8510076340336408`}, {7.150356804327845, 3.7814598015876575`}, {
       7.150356804327845, 3.7814598015876575`}}, {{7.150356804327845, 
       3.7814598015876575`}, {7.214825242898728, 3.8510076340336408`}, {
       7.214825242898728, 3.8510076340336408`}, {7.150356804327845, 
       3.7814598015876575`}, {7.150356804327845, 3.7814598015876575`}}, {{
       7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}, {{7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.6213067473739806`}, {7.427750031213266, 
       3.6213067473739806`}, {7.455746001604189, 3.711911969141674}, {
       7.455746001604189, 3.711911969141674}}, {{7.455746001604189, 
       3.711911969141674}, {7.427750031213266, 3.6213067473739806`}, {
       7.427750031213266, 3.6213067473739806`}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}}, {{
       7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}}, {{7.427750031213266, 3.6213067473739806`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.427750031213266, 3.6213067473739806`}, {
       7.427750031213266, 3.6213067473739806`}}, {{7.427750031213266, 
       3.6213067473739806`}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}, {7.427750031213266, 
       3.6213067473739806`}, {7.427750031213266, 3.6213067473739806`}}, {{
       7.427750031213266, 3.6213067473739806`}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}, {
       7.427750031213266, 3.6213067473739806`}, {7.427750031213266, 
       3.6213067473739806`}}, {{7.427750031213266, 3.6213067473739806`}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}, {7.427750031213266, 3.6213067473739806`}, {
       7.427750031213266, 3.6213067473739806`}}, {{7.375439082035703, 
       3.5728163042497076`}, {7.307289651860536, 3.551758914927997}, {
       7.307289651860536, 3.551758914927997}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}}, {{
       7.375439082035703, 3.5728163042497076`}, {7.307289651860536, 
       3.551758914927997}, {7.307289651860536, 3.551758914927997}, {
       7.375439082035703, 3.5728163042497076`}, {7.375439082035703, 
       3.5728163042497076`}}, {{7.375439082035703, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}, {7.375439082035703, 3.5728163042497076`}, {
       7.375439082035703, 3.5728163042497076`}}, {{7.375439082035703, 
       3.5728163042497076`}, {7.307289651860536, 3.551758914927997}, {
       7.307289651860536, 3.551758914927997}, {7.375439082035703, 
       3.5728163042497076`}, {7.375439082035703, 3.5728163042497076`}}, {{
       7.307289651860536, 3.551758914927997}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}}, {{7.307289651860536, 3.551758914927997}, {
       7.214825242898728, 3.5728163042497076`}, {7.214825242898728, 
       3.5728163042497076`}, {7.307289651860536, 3.551758914927997}, {
       7.307289651860536, 3.551758914927997}}, {{7.307289651860536, 
       3.551758914927997}, {7.214825242898728, 3.5728163042497076`}, {
       7.214825242898728, 3.5728163042497076`}, {7.307289651860536, 
       3.551758914927997}, {7.307289651860536, 3.551758914927997}}, {{
       7.307289651860536, 3.551758914927997}, {7.214825242898728, 
       3.5728163042497076`}, {7.214825242898728, 3.5728163042497076`}, {
       7.307289651860536, 3.551758914927997}, {7.307289651860536, 
       3.551758914927997}}, {{7.214825242898729, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}, {7.214825242898729, 3.8510076340336408`}, {
       7.214825242898729, 3.8510076340336408`}}, {{7.214825242898729, 
       3.8510076340336408`}, {7.307289651860536, 3.8720650233553515`}, {
       7.307289651860536, 3.8720650233553515`}, {7.214825242898729, 
       3.8510076340336408`}, {7.214825242898729, 3.8510076340336408`}}, {{
       7.214825242898729, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}, {
       7.214825242898729, 3.8510076340336408`}, {7.214825242898729, 
       3.8510076340336408`}}, {{7.214825242898729, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}, {7.214825242898729, 3.8510076340336408`}, {
       7.214825242898729, 3.8510076340336408`}}, {{7.307289651860536, 
       3.8720650233553515`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}}, {{
       7.307289651860536, 3.8720650233553515`}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}, {
       7.307289651860536, 3.8720650233553515`}, {7.307289651860536, 
       3.8720650233553515`}}, {{7.307289651860536, 3.8720650233553515`}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}, {7.307289651860536, 3.8720650233553515`}, {
       7.307289651860536, 3.8720650233553515`}}, {{7.307289651860536, 
       3.8720650233553515`}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}, {7.307289651860536, 
       3.8720650233553515`}, {7.307289651860536, 3.8720650233553515`}}, {{
       7.375439082035703, 3.8510076340336408`}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}, {{7.375439082035703, 3.8510076340336408`}, {
       7.427750031213266, 3.802517190909368}, {7.427750031213266, 
       3.802517190909368}, {7.375439082035703, 3.8510076340336408`}, {
       7.375439082035703, 3.8510076340336408`}}, {{7.375439082035703, 
       3.8510076340336408`}, {7.427750031213266, 3.802517190909368}, {
       7.427750031213266, 3.802517190909368}, {7.375439082035703, 
       3.8510076340336408`}, {7.375439082035703, 3.8510076340336408`}}, {{
       7.375439082035703, 3.8510076340336408`}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}, {
       7.375439082035703, 3.8510076340336408`}, {7.375439082035703, 
       3.8510076340336408`}}, {{7.427750031213266, 3.802517190909368}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}, {7.427750031213266, 3.802517190909368}, {
       7.427750031213266, 3.802517190909368}}, {{7.427750031213266, 
       3.802517190909368}, {7.455746001604189, 3.711911969141674}, {
       7.455746001604189, 3.711911969141674}, {7.427750031213266, 
       3.802517190909368}, {7.427750031213266, 3.802517190909368}}, {{
       7.427750031213266, 3.802517190909368}, {7.455746001604189, 
       3.711911969141674}, {7.455746001604189, 3.711911969141674}, {
       7.427750031213266, 3.802517190909368}, {7.427750031213266, 
       3.802517190909368}}, {{7.427750031213266, 3.802517190909368}, {
       7.455746001604189, 3.711911969141674}, {7.455746001604189, 
       3.711911969141674}, {7.427750031213266, 3.802517190909368}, {
       7.427750031213266, 3.802517190909368}}, {{
       7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}, {{
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}, {{
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}, {{
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}, {{
       7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}, {{
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}, {{
       7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}, {{
       7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}, {{
       7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}, {{
       7.448208882511308, -4.623866827109702}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}}, {{
       7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}, {{
       7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}, {{
       7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}, {{
       7.389007580511441, -4.56000112284662}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.56000112284662}, {
       7.389007580511441, -4.56000112284662}}, {{
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}, {{
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}, {{
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}, {{
       7.374463119414756, -4.496135418583537}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}, {
       7.374463119414756, -4.496135418583537}, {
       7.374463119414756, -4.496135418583537}}, {{
       7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}, {{
       7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}, {{
       7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}, {{
       7.389007580511441, -4.432269714320455}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}, {
       7.389007580511441, -4.432269714320455}, {
       7.389007580511441, -4.432269714320455}}, {{
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}, {{
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}, {{
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}, {{
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}}, {{
       7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}, {{
       7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}, {{
       7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}, {{
       7.6437375004784816`, -4.579338102184078}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}, {
       7.6437375004784816`, -4.579338102184078}, {
       7.6437375004784816`, -4.579338102184078}}, {{
       7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}, {{
       7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}, {{
       7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}, {{
       7.59570040870441, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}, {
       7.59570040870441, -4.623866827109702}, {
       7.59570040870441, -4.623866827109702}}, {{
       7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}, {{
       7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}, {{
       7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}, {{
       7.533118855833655, -4.64320380644716}, {
       7.448208882511308, -4.623866827109702}, {
       7.448208882511308, -4.623866827109702}, {
       7.533118855833655, -4.64320380644716}, {
       7.533118855833655, -4.64320380644716}}, {{
       7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}, {{
       7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}, {{
       7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}, {{
       7.448208882511308, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}, {
       7.448208882511308, -4.368404010057373}, {
       7.448208882511308, -4.368404010057373}}, {{
       7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}, {{
       7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}, {{
       7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}, {{
       7.533118855833655, -4.349067030719914}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}, {
       7.533118855833655, -4.349067030719914}, {
       7.533118855833655, -4.349067030719914}}, {{
       7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}, {{
       7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}, {{
       7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}, {{
       7.59570040870441, -4.368404010057373}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.59570040870441, -4.368404010057373}, {
       7.59570040870441, -4.368404010057373}}, {{
       7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}, {{
       7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}, {{
       7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}, {{
       7.6437375004784816`, -4.412932734982997}, {
       7.669446171800962, -4.496135418583537}, {
       7.669446171800962, -4.496135418583537}, {
       7.6437375004784816`, -4.412932734982997}, {
       7.6437375004784816`, -4.412932734982997}}, {{
       7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}, {{
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}, {{
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}, {{
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}, {{
       7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}, {{
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}, {{
       7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}, {{
       7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}, {{
       7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}, {{
       7.421395461044, -4.055182288268128}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}}, {{
       7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}, {{
       7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}, {{
       7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}, {{
       7.373005211542203, -4.002979426852927}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -4.002979426852927}, {
       7.373005211542203, -4.002979426852927}}, {{
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}, {{
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}, {{
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}, {{
       7.36111678886293, -3.9507765654377263`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.36111678886293, -3.9507765654377263`}, {
       7.36111678886293, -3.9507765654377263`}}, {{
       7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}, {{
       7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}, {{
       7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}, {{
       7.373005211542203, -3.8985737040225255`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}, {
       7.373005211542203, -3.8985737040225255`}, {
       7.373005211542203, -3.8985737040225255`}}, {{
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}, {{
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}, {{
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}, {{
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}}, {{
       7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}, {{
       7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}, {{
       7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}, {{
       7.581217598202306, -4.01878518150935}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}, {
       7.581217598202306, -4.01878518150935}, {
       7.581217598202306, -4.01878518150935}}, {{
       7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}, {{
       7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}, {{
       7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}, {{
       7.54195280540614, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}, {
       7.54195280540614, -4.055182288268128}, {
       7.54195280540614, -4.055182288268128}}, {{
       7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}, {{
       7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}, {{
       7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}, {{
       7.490799589930701, -4.070988042924551}, {
       7.421395461044, -4.055182288268128}, {
       7.421395461044, -4.055182288268128}, {
       7.490799589930701, -4.070988042924551}, {
       7.490799589930701, -4.070988042924551}}, {{
       7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}, {{
       7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}, {{
       7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}, {{
       7.421395461044, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.421395461044, -3.846370842607324}, {
       7.421395461044, -3.846370842607324}}, {{
       7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}, {{
       7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}, {{
       7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}, {{
       7.490799589930701, -3.8305650879509017`}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}, {
       7.490799589930701, -3.8305650879509017`}, {
       7.490799589930701, -3.8305650879509017`}}, {{
       7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}, {{
       7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}, {{
       7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}, {{
       7.54195280540614, -3.846370842607324}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}, {
       7.54195280540614, -3.846370842607324}, {
       7.54195280540614, -3.846370842607324}}, {{
       7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}, {{
       7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}, {{
       7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}, {{
       7.581217598202306, -3.882767949366103}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.60223147758721, -3.9507765654377263`}, {
       7.581217598202306, -3.882767949366103}, {
       7.581217598202306, -3.882767949366103}}, {{
       7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}, {{
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}, {{
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}, {{
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}, {{
       7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}, {{
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}, {{
       7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}, {{
       7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}, {{
       7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}, {{
       7.41231666622906, -3.664847832907333}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}}, {{
       7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}, {{
       7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}, {{
       7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}, {{
       7.351425787057235, -3.5991594316367723`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.5991594316367723`}, {
       7.351425787057235, -3.5991594316367723`}}, {{
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}, {{
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}, {{
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}, {{
       7.3364662339166715`, -3.533471030366212}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.3364662339166715`, -3.533471030366212}, {
       7.3364662339166715`, -3.533471030366212}}, {{
       7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}, {{
       7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}, {{
       7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}, {{
       7.351425787057235, -3.4677826290956513`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.351425787057235, -3.4677826290956513`}, {
       7.351425787057235, -3.4677826290956513`}}, {{
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}, {{
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}, {{
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}, {{
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}}, {{
       7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}, {{
       7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}, {{
       7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}, {{
       7.613425578517846, -3.6190482792230614`}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}, {
       7.613425578517846, -3.6190482792230614`}, {
       7.613425578517846, -3.6190482792230614`}}, {{
       7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}, {{
       7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}, {{
       7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}, {{
       7.564017530853837, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}, {
       7.564017530853837, -3.664847832907333}, {
       7.564017530853837, -3.664847832907333}}, {{
       7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}, {{
       7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}, {{
       7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}, {{
       7.499649930049264, -3.684736680493622}, {
       7.41231666622906, -3.664847832907333}, {
       7.41231666622906, -3.664847832907333}, {
       7.499649930049264, -3.684736680493622}, {
       7.499649930049264, -3.684736680493622}}, {{
       7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}, {{
       7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}, {{
       7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}, {{
       7.41231666622906, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.41231666622906, -3.4020942278250907`}, {
       7.41231666622906, -3.4020942278250907`}}, {{
       7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}, {{
       7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}, {{
       7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}, {{
       7.499649930049264, -3.3822053802388017`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.499649930049264, -3.3822053802388017`}, {
       7.499649930049264, -3.3822053802388017`}}, {{
       7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}, {{
       7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}, {{
       7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}, {{
       7.564017530853837, -3.4020942278250907`}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}, {
       7.564017530853837, -3.4020942278250907`}, {
       7.564017530853837, -3.4020942278250907`}}, {{
       7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}, {{
       7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}, {{
       7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}, {{
       7.613425578517846, -3.447893781509362}, {
       7.639867963166226, -3.533471030366212}, {
       7.639867963166226, -3.533471030366212}, {
       7.613425578517846, -3.447893781509362}, {
       7.613425578517846, -3.447893781509362}}, {{
       7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}, {{
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}, {{
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}, {{
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}, {{
       7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}, {{
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}, {{
       7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}, {{
       7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}, {{
       7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}, {{
       7.47454411891115, -3.076828396964744}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}}, {{
       7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}, {{
       7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}, {{
       7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}, {{
       7.422991181527071, -3.0212136631389206`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -3.0212136631389206`}, {
       7.422991181527071, -3.0212136631389206`}}, {{
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}, {{
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}, {{
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}, {{
       7.410325755820653, -2.9655989293130967`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.410325755820653, -2.9655989293130967`}, {
       7.410325755820653, -2.9655989293130967`}}, {{
       7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}, {{
       7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}, {{
       7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}, {{
       7.422991181527071, -2.9099841954872727`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.422991181527071, -2.9099841954872727`}, {
       7.422991181527071, -2.9099841954872727`}}, {{
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}, {{
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}, {{
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}, {{
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}}, {{
       7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}, {{
       7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}, {{
       7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}, {{
       7.644811904556809, -3.0380524496403294`}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}, {
       7.644811904556809, -3.0380524496403294`}, {
       7.644811904556809, -3.0380524496403294`}}, {{
       7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}, {{
       7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}, {{
       7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}, {{
       7.602980845092145, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}, {
       7.602980845092145, -3.076828396964744}, {
       7.602980845092145, -3.076828396964744}}, {{
       7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}, {{
       7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}, {{
       7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}, {{
       7.548484359921063, -3.093667183466153}, {
       7.47454411891115, -3.076828396964744}, {
       7.47454411891115, -3.076828396964744}, {
       7.548484359921063, -3.093667183466153}, {
       7.548484359921063, -3.093667183466153}}, {{
       7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}, {{
       7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}, {{
       7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}, {{
       7.47454411891115, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.47454411891115, -2.8543694616614492`}, {
       7.47454411891115, -2.8543694616614492`}}, {{
       7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}, {{
       7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}, {{
       7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}, {{
       7.548484359921063, -2.8375306751600404`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.548484359921063, -2.8375306751600404`}, {
       7.548484359921063, -2.8375306751600404`}}, {{
       7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}, {{
       7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}, {{
       7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}, {{
       7.602980845092145, -2.8543694616614492`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}, {
       7.602980845092145, -2.8543694616614492`}, {
       7.602980845092145, -2.8543694616614492`}}, {{
       7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}, {{
       7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}, {{
       7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}, {{
       7.644811904556809, -2.893145408985864}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.667199208182643, -2.9655989293130967`}, {
       7.644811904556809, -2.893145408985864}, {
       7.644811904556809, -2.893145408985864}}, {{
       7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}, {{
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}, {{
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}, {{
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}, {{
       7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}, {{
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}, {{
       7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}, {{
       7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}, {{
       7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}, {{
       7.404926970746088, -2.677257375476966}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}}, {{
       7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}, {{
       7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}, {{
       7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}, {{
       7.341263286311495, -2.608577702816945}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.608577702816945}, {
       7.341263286311495, -2.608577702816945}}, {{
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}, {{
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}, {{
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}, {{
       7.32562251574985, -2.539898030156924}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}, {
       7.32562251574985, -2.539898030156924}, {
       7.32562251574985, -2.539898030156924}}, {{
       7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}, {{
       7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}, {{
       7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}, {{
       7.341263286311495, -2.471218357496903}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}, {
       7.341263286311495, -2.471218357496903}, {
       7.341263286311495, -2.471218357496903}}, {{
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}, {{
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}, {{
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}, {{
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}}, {{
       7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}, {{
       7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}, {{
       7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}, {{
       7.615193836704917, -2.6293722345058077`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}, {
       7.615193836704917, -2.6293722345058077`}, {
       7.615193836704917, -2.6293722345058077`}}, {{
       7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}, {{
       7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}, {{
       7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}, {{
       7.563535880738561, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.563535880738561, -2.677257375476966}, {
       7.563535880738561, -2.677257375476966}}, {{
       7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}, {{
       7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}, {{
       7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}, {{
       7.4962371542105615`, -2.6980519071658287`}, {
       7.404926970746088, -2.677257375476966}, {
       7.404926970746088, -2.677257375476966}, {
       7.4962371542105615`, -2.6980519071658287`}, {
       7.4962371542105615`, -2.6980519071658287`}}, {{
       7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}, {{
       7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}, {{
       7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}, {{
       7.404926970746088, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.404926970746088, -2.402538684836882}, {
       7.404926970746088, -2.402538684836882}}, {{
       7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}, {{
       7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}, {{
       7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}, {{
       7.4962371542105615`, -2.3817441531480195`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}, {
       7.4962371542105615`, -2.3817441531480195`}, {
       7.4962371542105615`, -2.3817441531480195`}}, {{
       7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}, {{
       7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}, {{
       7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}, {{
       7.563535880738561, -2.402538684836882}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.563535880738561, -2.402538684836882}, {
       7.563535880738561, -2.402538684836882}}, {{
       7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}, {{
       7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}, {{
       7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}, {{
       7.615193836704917, -2.4504238258080404`}, {
       7.642840335734799, -2.539898030156924}, {
       7.642840335734799, -2.539898030156924}, {
       7.615193836704917, -2.4504238258080404`}, {
       7.615193836704917, -2.4504238258080404`}}, {{
       7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}, {{
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}, {{
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}, {{
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}, {{
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}, {{
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}, {{
       7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}, {{
       7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}, {{
       7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}, {{
       7.4080541493225835`, -2.0892729221036412`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}}, {{
       7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}, {{
       7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}, {{
       7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}, {{
       7.349390317084609, -2.0259870342247215`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -2.0259870342247215`}, {
       7.349390317084609, -2.0259870342247215`}}, {{
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}, {{
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}, {{
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}, {{
       7.334977900516987, -1.9627011463458017`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}, {
       7.334977900516987, -1.9627011463458017`}, {
       7.334977900516987, -1.9627011463458017`}}, {{
       7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}, {{
       7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}, {{
       7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}, {{
       7.349390317084609, -1.899415258466882}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.349390317084609, -1.899415258466882}, {
       7.349390317084609, -1.899415258466882}}, {{
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}, {{
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}, {{
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}, {{
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}}, {{
       7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}, {{
       7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}, {{
       7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}, {{
       7.601807625254166, -2.045148459286697}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.601807625254166, -2.045148459286697}, {
       7.601807625254166, -2.045148459286697}}, {{
       7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}, {{
       7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}, {{
       7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}, {{
       7.554206646933779, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.554206646933779, -2.0892729221036412`}, {
       7.554206646933779, -2.0892729221036412`}}, {{
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}, {{
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}, {{
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}, {{
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4080541493225835`, -2.0892729221036412`}, {
       7.4921932520457695`, -2.1084343471656166`}, {
       7.4921932520457695`, -2.1084343471656166`}}, {{
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}, {{
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}, {{
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}, {{
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4080541493225835`, -1.8361293705879624`}, {
       7.4080541493225835`, -1.8361293705879624`}}, {{
       7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}, {{
       7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}, {{
       7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}, {{
       7.4921932520457695`, -1.8169679455259868`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.4921932520457695`, -1.8169679455259868`}, {
       7.4921932520457695`, -1.8169679455259868`}}, {{
       7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}, {{
       7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}, {{
       7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}, {{
       7.554206646933779, -1.8361293705879624`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.554206646933779, -1.8361293705879624`}, {
       7.554206646933779, -1.8361293705879624`}}, {{
       7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}, {{
       7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}, {{
       7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}, {{
       7.601807625254166, -1.8802538334049066`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.627282895739376, -1.9627011463458017`}, {
       7.601807625254166, -1.8802538334049066`}, {
       7.601807625254166, -1.8802538334049066`}}, {{
       7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}, {{
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}, {{
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}, {{
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}, {{
       7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}, {{
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}, {{
       7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}, {{
       7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}, {{
       7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}, {{
       7.402708807232607, -1.6487370602766425`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}}, {{
       7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}, {{
       7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}, {{
       7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}, {{
       7.339788893875448, -1.5808597595588951`}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.5808597595588951`}, {
       7.339788893875448, -1.5808597595588951`}}, {{
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}, {{
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}, {{
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}, {{
       7.324330851550094, -1.512982458841148}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}, {
       7.324330851550094, -1.512982458841148}, {
       7.324330851550094, -1.512982458841148}}, {{
       7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}, {{
       7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}, {{
       7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}, {{
       7.339788893875448, -1.445105158123401}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.339788893875448, -1.445105158123401}, {
       7.339788893875448, -1.445105158123401}}, {{
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}, {{
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}, {{
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}, {{
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}}, {{
       7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}, {{
       7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}, {{
       7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}, {{
       7.610519164196841, -1.6014113525712375`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.610519164196841, -1.6014113525712375`}, {
       7.610519164196841, -1.6014113525712375`}}, {{
       7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}, {{
       7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}, {{
       7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}, {{
       7.559464718597633, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.559464718597633, -1.6487370602766425`}, {
       7.559464718597633, -1.6487370602766425`}}, {{
       7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}, {{
       7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}, {{
       7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}, {{
       7.492952230673072, -1.6692886532889846`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.402708807232607, -1.6487370602766425`}, {
       7.492952230673072, -1.6692886532889846`}, {
       7.492952230673072, -1.6692886532889846`}}, {{
       7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}, {{
       7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}, {{
       7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}, {{
       7.402708807232607, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.402708807232607, -1.3772278574056536`}, {
       7.402708807232607, -1.3772278574056536`}}, {{
       7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}, {{
       7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}, {{
       7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}, {{
       7.492952230673072, -1.3566762643933115`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.492952230673072, -1.3566762643933115`}, {
       7.492952230673072, -1.3566762643933115`}}, {{
       7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}, {{
       7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}, {{
       7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}, {{
       7.559464718597633, -1.3772278574056536`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.559464718597633, -1.3772278574056536`}, {
       7.559464718597633, -1.3772278574056536`}}, {{
       7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}, {{
       7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}, {{
       7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}, {{
       7.610519164196841, -1.4245535651110586`}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.6378426742801455`, -1.512982458841148}, {
       7.610519164196841, -1.4245535651110586`}, {
       7.610519164196841, -1.4245535651110586`}}, {{
       7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}, {{
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}, {{
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}, {{
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}, {{
       7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}, {{
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}, {{
       7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}, {{
       7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}, {{
       7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}, {{
       7.463984418515872, -1.1164855148163504`}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}}, {{
       7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}, {{
       7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}, {{
       7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}, {{
       7.400655075319542, -1.048166525754908}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -1.048166525754908}, {
       7.400655075319542, -1.048166525754908}}, {{
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}, {{
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}, {{
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}, {{
       7.3850964450650975`, -0.9798475366934658}, {
       7.400655075319542, -0.9115285476320236}, {
       7.400655075319542, -0.9115285476320236}, {
       7.3850964450650975`, -0.9798475366934658}, {
       7.3850964450650975`, -0.9798475366934658}}, {{
       7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}, {{
       7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}, {{
       7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}, {{
       7.400655075319542, -0.9115285476320235}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}, {
       7.400655075319542, -0.9115285476320235}, {
       7.400655075319542, -0.9115285476320235}}, {{
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}, {{
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}, {{
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}, {{
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}}, {{
       7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}, {{
       7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}, {{
       7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}, {{
       7.673147030378277, -1.0688518512371914`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.673147030378277, -1.0688518512371914`}, {
       7.673147030378277, -1.0688518512371914`}}, {{
       7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}, {{
       7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}, {{
       7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}, {{
       7.621760365417418, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.621760365417418, -1.1164855148163504`}, {
       7.621760365417418, -1.1164855148163504`}}, {{
       7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}, {{
       7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}, {{
       7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}, {{
       7.554815070202117, -1.1371708402986336`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.463984418515872, -1.1164855148163504`}, {
       7.554815070202117, -1.1371708402986336`}, {
       7.554815070202117, -1.1371708402986336`}}, {{
       7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}, {{
       7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}, {{
       7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}, {{
       7.463984418515872, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}, {
       7.463984418515872, -0.8432095585705813}, {
       7.463984418515872, -0.8432095585705813}}, {{
       7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}, {{
       7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}, {{
       7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}, {{
       7.554815070202117, -0.822524233088298}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}, {
       7.554815070202117, -0.822524233088298}, {
       7.554815070202117, -0.822524233088298}}, {{
       7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}, {{
       7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}, {{
       7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}, {{
       7.621760365417418, -0.8432095585705813}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}, {
       7.621760365417418, -0.8432095585705813}, {
       7.621760365417418, -0.8432095585705813}}, {{
       7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}, {{
       7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}, {{
       7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}, {{
       7.673147030378277, -0.8908432221497402}, {
       7.700648338868192, -0.9798475366934658}, {
       7.700648338868192, -0.9798475366934658}, {
       7.673147030378277, -0.8908432221497402}, {
       7.673147030378277, -0.8908432221497402}}, {{
       7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}, {{
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}, {{
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}, {{
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}, {{
       7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}, {{
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}, {{
       7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}, {{
       7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}, {{
       7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}, {{
       7.400928329895931, -0.6111461636433988}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}}, {{
       7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}, {{
       7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}, {{
       7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}, {{
       7.339882992560285, -0.5452911346285421}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.5452911346285421}, {
       7.339882992560285, -0.5452911346285421}}, {{
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}, {{
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}, {{
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}, {{
       7.324885492437495, -0.47943610561368527`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.339882992560285, -0.41358107659882853`}, {
       7.324885492437495, -0.47943610561368527`}, {
       7.324885492437495, -0.47943610561368527`}}, {{
       7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}, {{
       7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}, {{
       7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}, {{
       7.339882992560285, -0.4135810765988285}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.339882992560285, -0.4135810765988285}, {
       7.339882992560285, -0.4135810765988285}}, {{
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}, {{
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}, {{
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}, {{
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}}, {{
       7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}, {{
       7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}, {{
       7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}, {{
       7.602547382845236, -0.5652304330363742}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}, {
       7.602547382845236, -0.5652304330363742}, {
       7.602547382845236, -0.5652304330363742}}, {{
       7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}, {{
       7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}, {{
       7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}, {{
       7.553014004812804, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}, {
       7.553014004812804, -0.6111461636433988}, {
       7.553014004812804, -0.6111461636433988}}, {{
       7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}, {{
       7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}, {{
       7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}, {{
       7.488483126657582, -0.6310854620512311}, {
       7.400928329895931, -0.6111461636433988}, {
       7.400928329895931, -0.6111461636433988}, {
       7.488483126657582, -0.6310854620512311}, {
       7.488483126657582, -0.6310854620512311}}, {{
       7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}, {{
       7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}, {{
       7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}, {{
       7.400928329895931, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}, {
       7.400928329895931, -0.34772604758397174`}, {
       7.400928329895931, -0.34772604758397174`}}, {{
       7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}, {{
       7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}, {{
       7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}, {{
       7.488483126657582, -0.3277867491761395}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.488483126657582, -0.3277867491761395}, {
       7.488483126657582, -0.3277867491761395}}, {{
       7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}, {{
       7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}, {{
       7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}, {{
       7.553014004812804, -0.34772604758397174`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.553014004812804, -0.34772604758397174`}, {
       7.553014004812804, -0.34772604758397174`}}, {{
       7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}, {{
       7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}, {{
       7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}, {{
       7.602547382845236, -0.39364177819099627`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.62905684227124, -0.47943610561368527`}, {
       7.602547382845236, -0.39364177819099627`}, {
       7.602547382845236, -0.39364177819099627`}}, {{
       7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.01567372637491203}, {7.446821078417088, 0.07880115516357909}, {
       7.446821078417088, 0.07880115516357909}, {7.388304132282772, 
       0.015673726374912017`}, {7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242215`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}, {{
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}, {{
       7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.17370855999108925`}, {
       7.446821078417088, -0.17370855999108925`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}, {{
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}, {{7.446821078417088, 
       0.07880115516357912}, {7.530749508490825, 0.09791460267344886}, {
       7.592607630434632, 0.07880115516357909}, {7.640089422503983, 
       0.03478717388478175}, {7.665500906443404, -0.047453702413755044`}, {
       7.665500906443404, -0.047453702413755044`}, {7.640089422503983, 
       0.03478717388478175}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}}, {{
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}, {{7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}, {{
       7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}, {{
       7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}, {{
       7.446821078417088, -0.1737085599910892}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}}, {{
       7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}, {{
       7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}, {{
       7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}, {{
       7.388304132282772, -0.11058113120242213`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}, {
       7.388304132282772, -0.11058113120242213`}, {
       7.388304132282772, -0.11058113120242213`}}, {{
       7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}, {{
       7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}, {{
       7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}, {{
       7.373927802408316, -0.04745370241375506}, {7.388304132282772, 
       0.015673726374912017`}, {7.388304132282772, 0.015673726374912017`}, {
       7.373927802408316, -0.04745370241375506}, {
       7.373927802408316, -0.04745370241375506}}, {{7.388304132282772, 
       0.01567372637491203}, {7.446821078417088, 0.07880115516357912}, {
       7.446821078417088, 0.07880115516357912}, {7.388304132282772, 
       0.01567372637491203}, {7.388304132282772, 0.01567372637491203}}, {{
       7.388304132282772, 0.01567372637491203}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}, {
       7.388304132282772, 0.01567372637491203}, {7.388304132282772, 
       0.01567372637491203}}, {{7.388304132282772, 0.01567372637491203}, {
       7.446821078417088, 0.07880115516357912}, {7.446821078417088, 
       0.07880115516357912}, {7.388304132282772, 0.01567372637491203}, {
       7.388304132282772, 0.01567372637491203}}, {{7.388304132282772, 
       0.01567372637491203}, {7.446821078417088, 0.07880115516357912}, {
       7.446821078417088, 0.07880115516357912}, {7.388304132282772, 
       0.01567372637491203}, {7.388304132282772, 0.01567372637491203}}, {{
       7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}, {{
       7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}, {{
       7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}, {{
       7.665500906443404, -0.04745370241375507}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.665500906443404, -0.04745370241375507}, {
       7.665500906443404, -0.04745370241375507}}, {{
       7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}, {{
       7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}, {{
       7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}, {{
       7.640089422503983, -0.12969457871229187`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}, {
       7.640089422503983, -0.12969457871229187`}, {
       7.640089422503983, -0.12969457871229187`}}, {{
       7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}, {{
       7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}, {{
       7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}, {{
       7.592607630434632, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.592607630434632, -0.1737085599910892}, {
       7.592607630434632, -0.1737085599910892}}, {{
       7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}, {{
       7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}, {{
       7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}, {{
       7.530749508490825, -0.19282200750095896`}, {
       7.446821078417088, -0.1737085599910892}, {
       7.446821078417088, -0.1737085599910892}, {
       7.530749508490825, -0.19282200750095896`}, {
       7.530749508490825, -0.19282200750095896`}}, {{7.446821078417088, 
       0.07880115516357912}, {7.530749508490825, 0.09791460267344886}, {
       7.530749508490825, 0.09791460267344886}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}}, {{
       7.446821078417088, 0.07880115516357912}, {7.530749508490825, 
       0.09791460267344886}, {7.530749508490825, 0.09791460267344886}, {
       7.446821078417088, 0.07880115516357912}, {7.446821078417088, 
       0.07880115516357912}}, {{7.446821078417088, 0.07880115516357912}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}, {7.446821078417088, 0.07880115516357912}, {
       7.446821078417088, 0.07880115516357912}}, {{7.446821078417088, 
       0.07880115516357912}, {7.530749508490825, 0.09791460267344886}, {
       7.530749508490825, 0.09791460267344886}, {7.446821078417088, 
       0.07880115516357912}, {7.446821078417088, 0.07880115516357912}}, {{
       7.530749508490825, 0.09791460267344886}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}}, {{7.530749508490825, 0.09791460267344886}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}, {7.530749508490825, 0.09791460267344886}, {
       7.530749508490825, 0.09791460267344886}}, {{7.530749508490825, 
       0.09791460267344886}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}, {7.530749508490825, 
       0.09791460267344886}, {7.530749508490825, 0.09791460267344886}}, {{
       7.530749508490825, 0.09791460267344886}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}, {
       7.530749508490825, 0.09791460267344886}, {7.530749508490825, 
       0.09791460267344886}}, {{7.592607630434632, 0.07880115516357909}, {
       7.640089422503983, 0.03478717388478175}, {7.640089422503983, 
       0.03478717388478175}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}}, {{7.592607630434632, 
       0.07880115516357909}, {7.640089422503983, 0.03478717388478175}, {
       7.640089422503983, 0.03478717388478175}, {7.592607630434632, 
       0.07880115516357909}, {7.592607630434632, 0.07880115516357909}}, {{
       7.592607630434632, 0.07880115516357909}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}, {
       7.592607630434632, 0.07880115516357909}, {7.592607630434632, 
       0.07880115516357909}}, {{7.592607630434632, 0.07880115516357909}, {
       7.640089422503983, 0.03478717388478175}, {7.640089422503983, 
       0.03478717388478175}, {7.592607630434632, 0.07880115516357909}, {
       7.592607630434632, 0.07880115516357909}}, {{7.640089422503983, 
       0.03478717388478175}, {7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}, {{
       7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}, {{
       7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}, {{
       7.640089422503983, 0.03478717388478175}, {
       7.665500906443404, -0.04745370241375508}, {
       7.665500906443404, -0.04745370241375508}, {7.640089422503983, 
       0.03478717388478175}, {7.640089422503983, 0.03478717388478175}}, {{
       7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.2814296434250485`, 
       0.4625898803092296}, {7.299425452323098, 0.3835690763469726}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}, {{7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}}, {{7.646411102938566, 
       0.4625898803092296}, {7.614601857269946, 0.3596435020332054}, {
       7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.372675008303427, 0.3045482723847157}, {
       7.372675008303427, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.555165738060187, 0.3045482723847157}, {
       7.614601857269946, 0.3596435020332054}, {7.646411102938566, 
       0.4625898803092296}, {7.646411102938566, 0.4625898803092296}}, {{
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}, {{7.372675008303427, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.614601857269946, 0.5655362585852538}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}, {7.614601857269946, 0.5655362585852538}, {
       7.555165738060187, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.372675008303427, 0.6206314882337435}, {
       7.372675008303427, 0.6206314882337435}}, {{7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}}, {{
       7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}, {{7.372675008303427, 0.3045482723847157}, {
       7.299425452323098, 0.3835690763469727}, {7.299425452323098, 
       0.3835690763469727}, {7.372675008303427, 0.3045482723847157}, {
       7.372675008303427, 0.3045482723847157}}, {{7.372675008303427, 
       0.3045482723847157}, {7.299425452323098, 0.3835690763469727}, {
       7.299425452323098, 0.3835690763469727}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}}, {{
       7.372675008303427, 0.3045482723847157}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}}, {{7.299425452323098, 0.3835690763469727}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.299425452323098, 0.3835690763469727}, {
       7.299425452323098, 0.3835690763469727}}, {{7.299425452323098, 
       0.3835690763469727}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}, {7.299425452323098, 
       0.3835690763469727}, {7.299425452323098, 0.3835690763469727}}, {{
       7.299425452323098, 0.3835690763469727}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.3835690763469727}, {7.299425452323098, 
       0.3835690763469727}}, {{7.299425452323098, 0.3835690763469727}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}, {7.299425452323098, 0.3835690763469727}, {
       7.299425452323098, 0.3835690763469727}}, {{7.2814296434250485`, 
       0.4625898803092296}, {7.299425452323098, 0.5416106842714865}, {
       7.299425452323098, 0.5416106842714865}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}}, {{
       7.2814296434250485`, 0.4625898803092296}, {7.299425452323098, 
       0.5416106842714865}, {7.299425452323098, 0.5416106842714865}, {
       7.2814296434250485`, 0.4625898803092296}, {7.2814296434250485`, 
       0.4625898803092296}}, {{7.2814296434250485`, 0.4625898803092296}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}, {7.2814296434250485`, 0.4625898803092296}, {
       7.2814296434250485`, 0.4625898803092296}}, {{7.2814296434250485`, 
       0.4625898803092296}, {7.299425452323098, 0.5416106842714865}, {
       7.299425452323098, 0.5416106842714865}, {7.2814296434250485`, 
       0.4625898803092296}, {7.2814296434250485`, 0.4625898803092296}}, {{
       7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}}, {{7.299425452323098, 0.5416106842714865}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}, {7.299425452323098, 0.5416106842714865}, {
       7.299425452323098, 0.5416106842714865}}, {{7.299425452323098, 
       0.5416106842714865}, {7.372675008303427, 0.6206314882337435}, {
       7.372675008303427, 0.6206314882337435}, {7.299425452323098, 
       0.5416106842714865}, {7.299425452323098, 0.5416106842714865}}, {{
       7.299425452323098, 0.5416106842714865}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}, {
       7.299425452323098, 0.5416106842714865}, {7.299425452323098, 
       0.5416106842714865}}, {{7.646411102938566, 0.4625898803092296}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}, {7.646411102938566, 0.4625898803092296}, {
       7.646411102938566, 0.4625898803092296}}, {{7.646411102938566, 
       0.4625898803092296}, {7.614601857269946, 0.3596435020332054}, {
       7.614601857269946, 0.3596435020332054}, {7.646411102938566, 
       0.4625898803092296}, {7.646411102938566, 0.4625898803092296}}, {{
       7.646411102938566, 0.4625898803092296}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}, {
       7.646411102938566, 0.4625898803092296}, {7.646411102938566, 
       0.4625898803092296}}, {{7.646411102938566, 0.4625898803092296}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}, {7.646411102938566, 0.4625898803092296}, {
       7.646411102938566, 0.4625898803092296}}, {{7.614601857269946, 
       0.3596435020332054}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}}, {{
       7.614601857269946, 0.3596435020332054}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}, {
       7.614601857269946, 0.3596435020332054}, {7.614601857269946, 
       0.3596435020332054}}, {{7.614601857269946, 0.3596435020332054}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}, {7.614601857269946, 0.3596435020332054}, {
       7.614601857269946, 0.3596435020332054}}, {{7.614601857269946, 
       0.3596435020332054}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}, {7.614601857269946, 
       0.3596435020332054}, {7.614601857269946, 0.3596435020332054}}, {{
       7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}, {{7.555165738060187, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.477733809952377, 
       0.2806226980709484}, {7.555165738060187, 0.3045482723847157}, {
       7.555165738060187, 0.3045482723847157}}, {{7.555165738060187, 
       0.3045482723847157}, {7.477733809952377, 0.2806226980709484}, {
       7.477733809952377, 0.2806226980709484}, {7.555165738060187, 
       0.3045482723847157}, {7.555165738060187, 0.3045482723847157}}, {{
       7.555165738060187, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}, {
       7.555165738060187, 0.3045482723847157}, {7.555165738060187, 
       0.3045482723847157}}, {{7.477733809952377, 0.2806226980709484}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}, {7.477733809952377, 0.2806226980709484}, {
       7.477733809952377, 0.2806226980709484}}, {{7.477733809952377, 
       0.2806226980709484}, {7.372675008303427, 0.3045482723847157}, {
       7.372675008303427, 0.3045482723847157}, {7.477733809952377, 
       0.2806226980709484}, {7.477733809952377, 0.2806226980709484}}, {{
       7.477733809952377, 0.2806226980709484}, {7.372675008303427, 
       0.3045482723847157}, {7.372675008303427, 0.3045482723847157}, {
       7.477733809952377, 0.2806226980709484}, {7.477733809952377, 
       0.2806226980709484}}, {{7.477733809952377, 0.2806226980709484}, {
       7.372675008303427, 0.3045482723847157}, {7.372675008303427, 
       0.3045482723847157}, {7.477733809952377, 0.2806226980709484}, {
       7.477733809952377, 0.2806226980709484}}, {{7.372675008303427, 
       0.6206314882337435}, {7.477733809952377, 0.6445570625475108}, {
       7.477733809952377, 0.6445570625475108}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}}, {{
       7.372675008303427, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.477733809952377, 0.6445570625475108}, {
       7.372675008303427, 0.6206314882337435}, {7.372675008303427, 
       0.6206314882337435}}, {{7.372675008303427, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}, {7.372675008303427, 0.6206314882337435}, {
       7.372675008303427, 0.6206314882337435}}, {{7.372675008303427, 
       0.6206314882337435}, {7.477733809952377, 0.6445570625475108}, {
       7.477733809952377, 0.6445570625475108}, {7.372675008303427, 
       0.6206314882337435}, {7.372675008303427, 0.6206314882337435}}, {{
       7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}}, {{7.477733809952377, 0.6445570625475108}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}, {7.477733809952377, 0.6445570625475108}, {
       7.477733809952377, 0.6445570625475108}}, {{7.477733809952377, 
       0.6445570625475108}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}, {7.477733809952377, 
       0.6445570625475108}, {7.477733809952377, 0.6445570625475108}}, {{
       7.477733809952377, 0.6445570625475108}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}, {
       7.477733809952377, 0.6445570625475108}, {7.477733809952377, 
       0.6445570625475108}}, {{7.555165738060187, 0.6206314882337435}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}}, {{7.555165738060187, 
       0.6206314882337435}, {7.614601857269946, 0.5655362585852538}, {
       7.614601857269946, 0.5655362585852538}, {7.555165738060187, 
       0.6206314882337435}, {7.555165738060187, 0.6206314882337435}}, {{
       7.555165738060187, 0.6206314882337435}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}, {
       7.555165738060187, 0.6206314882337435}, {7.555165738060187, 
       0.6206314882337435}}, {{7.555165738060187, 0.6206314882337435}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}, {7.555165738060187, 0.6206314882337435}, {
       7.555165738060187, 0.6206314882337435}}, {{7.614601857269946, 
       0.5655362585852538}, {7.646411102938566, 0.46258988030922954`}, {
       7.646411102938566, 0.46258988030922954`}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}}, {{
       7.614601857269946, 0.5655362585852538}, {7.646411102938566, 
       0.46258988030922954`}, {7.646411102938566, 0.46258988030922954`}, {
       7.614601857269946, 0.5655362585852538}, {7.614601857269946, 
       0.5655362585852538}}, {{7.614601857269946, 0.5655362585852538}, {
       7.646411102938566, 0.46258988030922954`}, {7.646411102938566, 
       0.46258988030922954`}, {7.614601857269946, 0.5655362585852538}, {
       7.614601857269946, 0.5655362585852538}}, {{7.614601857269946, 
       0.5655362585852538}, {7.646411102938566, 0.46258988030922954`}, {
       7.646411102938566, 0.46258988030922954`}, {7.614601857269946, 
       0.5655362585852538}, {7.614601857269946, 0.5655362585852538}}, {{
       7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}, {{7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}}, {{7.70006037762723, 
       1.0406343284445707`}, {7.669473461103548, 0.9416438553114584}, {
       7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.436843099124353, 0.8886657618455744}, {
       7.436843099124353, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.612321284792937, 0.8886657618455744}, {
       7.669473461103548, 0.9416438553114584}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}}, {{
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}, {{7.436843099124353, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.669473461103548, 1.1396248015776829`}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}, {7.669473461103548, 1.1396248015776829`}, {
       7.612321284792937, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.436843099124353, 1.192602895043567}, {
       7.436843099124353, 1.192602895043567}}, {{7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}}, {{
       7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}, {{7.436843099124353, 0.8886657618455744}, {
       7.366408292920277, 0.9646500451450726}, {7.366408292920277, 
       0.9646500451450726}, {7.436843099124353, 0.8886657618455744}, {
       7.436843099124353, 0.8886657618455744}}, {{7.436843099124353, 
       0.8886657618455744}, {7.366408292920277, 0.9646500451450726}, {
       7.366408292920277, 0.9646500451450726}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}}, {{
       7.436843099124353, 0.8886657618455744}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}}, {{7.366408292920277, 0.9646500451450726}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.366408292920277, 0.9646500451450726}, {
       7.366408292920277, 0.9646500451450726}}, {{7.366408292920277, 
       0.9646500451450726}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.366408292920277, 
       0.9646500451450726}, {7.366408292920277, 0.9646500451450726}}, {{
       7.366408292920277, 0.9646500451450726}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 0.9646500451450726}, {7.366408292920277, 
       0.9646500451450726}}, {{7.366408292920277, 0.9646500451450726}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.366408292920277, 0.9646500451450726}, {
       7.366408292920277, 0.9646500451450726}}, {{7.3491040062900606`, 
       1.0406343284445707`}, {7.366408292920277, 1.1166186117440688`}, {
       7.366408292920277, 1.1166186117440688`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}}, {{
       7.3491040062900606`, 1.0406343284445707`}, {7.366408292920277, 
       1.1166186117440688`}, {7.366408292920277, 1.1166186117440688`}, {
       7.3491040062900606`, 1.0406343284445707`}, {7.3491040062900606`, 
       1.0406343284445707`}}, {{7.3491040062900606`, 1.0406343284445707`}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}, {7.3491040062900606`, 1.0406343284445707`}, {
       7.3491040062900606`, 1.0406343284445707`}}, {{7.3491040062900606`, 
       1.0406343284445707`}, {7.366408292920277, 1.1166186117440688`}, {
       7.366408292920277, 1.1166186117440688`}, {7.3491040062900606`, 
       1.0406343284445707`}, {7.3491040062900606`, 1.0406343284445707`}}, {{
       7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}}, {{7.366408292920277, 1.1166186117440688`}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}, {7.366408292920277, 1.1166186117440688`}, {
       7.366408292920277, 1.1166186117440688`}}, {{7.366408292920277, 
       1.1166186117440688`}, {7.436843099124353, 1.192602895043567}, {
       7.436843099124353, 1.192602895043567}, {7.366408292920277, 
       1.1166186117440688`}, {7.366408292920277, 1.1166186117440688`}}, {{
       7.366408292920277, 1.1166186117440688`}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}, {
       7.366408292920277, 1.1166186117440688`}, {7.366408292920277, 
       1.1166186117440688`}}, {{7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}, {7.70006037762723, 1.0406343284445707`}, {
       7.70006037762723, 1.0406343284445707`}}, {{7.70006037762723, 
       1.0406343284445707`}, {7.669473461103548, 0.9416438553114584}, {
       7.669473461103548, 0.9416438553114584}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}}, {{
       7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}}, {{7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}, {7.70006037762723, 1.0406343284445707`}, {
       7.70006037762723, 1.0406343284445707`}}, {{7.669473461103548, 
       0.9416438553114584}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}}, {{
       7.669473461103548, 0.9416438553114584}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}, {
       7.669473461103548, 0.9416438553114584}, {7.669473461103548, 
       0.9416438553114584}}, {{7.669473461103548, 0.9416438553114584}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}, {7.669473461103548, 0.9416438553114584}, {
       7.669473461103548, 0.9416438553114584}}, {{7.669473461103548, 
       0.9416438553114584}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}, {7.669473461103548, 
       0.9416438553114584}, {7.669473461103548, 0.9416438553114584}}, {{
       7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}, {{7.612321284792937, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.53786482185211, 
       0.8656595720119603}, {7.612321284792937, 0.8886657618455744}, {
       7.612321284792937, 0.8886657618455744}}, {{7.612321284792937, 
       0.8886657618455744}, {7.53786482185211, 0.8656595720119603}, {
       7.53786482185211, 0.8656595720119603}, {7.612321284792937, 
       0.8886657618455744}, {7.612321284792937, 0.8886657618455744}}, {{
       7.612321284792937, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}, {
       7.612321284792937, 0.8886657618455744}, {7.612321284792937, 
       0.8886657618455744}}, {{7.53786482185211, 0.8656595720119603}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}, {7.53786482185211, 0.8656595720119603}, {
       7.53786482185211, 0.8656595720119603}}, {{7.53786482185211, 
       0.8656595720119603}, {7.436843099124353, 0.8886657618455744}, {
       7.436843099124353, 0.8886657618455744}, {7.53786482185211, 
       0.8656595720119603}, {7.53786482185211, 0.8656595720119603}}, {{
       7.53786482185211, 0.8656595720119603}, {7.436843099124353, 
       0.8886657618455744}, {7.436843099124353, 0.8886657618455744}, {
       7.53786482185211, 0.8656595720119603}, {7.53786482185211, 
       0.8656595720119603}}, {{7.53786482185211, 0.8656595720119603}, {
       7.436843099124353, 0.8886657618455744}, {7.436843099124353, 
       0.8886657618455744}, {7.53786482185211, 0.8656595720119603}, {
       7.53786482185211, 0.8656595720119603}}, {{7.436843099124353, 
       1.192602895043567}, {7.53786482185211, 1.215609084877181}, {
       7.53786482185211, 1.215609084877181}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}}, {{
       7.436843099124353, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.53786482185211, 1.215609084877181}, {
       7.436843099124353, 1.192602895043567}, {7.436843099124353, 
       1.192602895043567}}, {{7.436843099124353, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}, {7.436843099124353, 1.192602895043567}, {
       7.436843099124353, 1.192602895043567}}, {{7.436843099124353, 
       1.192602895043567}, {7.53786482185211, 1.215609084877181}, {
       7.53786482185211, 1.215609084877181}, {7.436843099124353, 
       1.192602895043567}, {7.436843099124353, 1.192602895043567}}, {{
       7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}}, {{7.53786482185211, 1.215609084877181}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}, {7.53786482185211, 1.215609084877181}, {
       7.53786482185211, 1.215609084877181}}, {{7.53786482185211, 
       1.215609084877181}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}, {7.53786482185211, 
       1.215609084877181}, {7.53786482185211, 1.215609084877181}}, {{
       7.53786482185211, 1.215609084877181}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}, {
       7.53786482185211, 1.215609084877181}, {7.53786482185211, 
       1.215609084877181}}, {{7.612321284792937, 1.192602895043567}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}}, {{7.612321284792937, 
       1.192602895043567}, {7.669473461103548, 1.1396248015776829`}, {
       7.669473461103548, 1.1396248015776829`}, {7.612321284792937, 
       1.192602895043567}, {7.612321284792937, 1.192602895043567}}, {{
       7.612321284792937, 1.192602895043567}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}, {
       7.612321284792937, 1.192602895043567}, {7.612321284792937, 
       1.192602895043567}}, {{7.612321284792937, 1.192602895043567}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}, {7.612321284792937, 1.192602895043567}, {
       7.612321284792937, 1.192602895043567}}, {{7.669473461103548, 
       1.1396248015776829`}, {7.70006037762723, 1.0406343284445707`}, {
       7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}}, {{
       7.669473461103548, 1.1396248015776829`}, {7.70006037762723, 
       1.0406343284445707`}, {7.70006037762723, 1.0406343284445707`}, {
       7.669473461103548, 1.1396248015776829`}, {7.669473461103548, 
       1.1396248015776829`}}, {{7.669473461103548, 1.1396248015776829`}, {
       7.70006037762723, 1.0406343284445707`}, {7.70006037762723, 
       1.0406343284445707`}, {7.669473461103548, 1.1396248015776829`}, {
       7.669473461103548, 1.1396248015776829`}}, {{7.669473461103548, 
       1.1396248015776829`}, {7.70006037762723, 1.0406343284445707`}, {
       7.70006037762723, 1.0406343284445707`}, {7.669473461103548, 
       1.1396248015776829`}, {7.669473461103548, 1.1396248015776829`}}, {{
       7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.327795877062711, 
       1.5087252988927673`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}, {{7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}}, {{7.656135578085187, 
       1.5087252988927673`}, {7.627519773253604, 1.4161140656823183`}, {
       7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.40988080231833, 1.3665500378145419`}, {
       7.40988080231833, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.574050652829568, 1.3665500378145419`}, {
       7.627519773253604, 1.4161140656823183`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}}, {{
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}, {{7.40988080231833, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.627519773253604, 1.6013365321032162`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}, {7.627519773253604, 1.6013365321032162`}, {
       7.574050652829568, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.40988080231833, 1.6509005599709927`}, {
       7.40988080231833, 1.6509005599709927`}}, {{7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}}, {{
       7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}, {{7.40988080231833, 1.3665500378145419`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.40988080231833, 1.3665500378145419`}, {
       7.40988080231833, 1.3665500378145419`}}, {{7.40988080231833, 
       1.3665500378145419`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}}, {{
       7.40988080231833, 1.3665500378145419`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}}, {{7.3439850240980675`, 1.4376376683536545`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.3439850240980675`, 1.4376376683536545`}}, {{7.3439850240980675`, 
       1.4376376683536545`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}, {7.3439850240980675`, 
       1.4376376683536545`}, {7.3439850240980675`, 1.4376376683536545`}}, {{
       7.3439850240980675`, 1.4376376683536545`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.4376376683536545`}, {7.3439850240980675`, 
       1.4376376683536545`}}, {{7.3439850240980675`, 1.4376376683536545`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}, {7.3439850240980675`, 1.4376376683536545`}, {
       7.3439850240980675`, 1.4376376683536545`}}, {{7.327795877062711, 
       1.5087252988927673`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}}, {{
       7.327795877062711, 1.5087252988927673`}, {7.3439850240980675`, 
       1.5798129294318801`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.327795877062711, 1.5087252988927673`}, {7.327795877062711, 
       1.5087252988927673`}}, {{7.327795877062711, 1.5087252988927673`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}, {7.327795877062711, 1.5087252988927673`}, {
       7.327795877062711, 1.5087252988927673`}}, {{7.327795877062711, 
       1.5087252988927673`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.327795877062711, 
       1.5087252988927673`}, {7.327795877062711, 1.5087252988927673`}}, {{
       7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}}, {{7.3439850240980675`, 1.5798129294318801`}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}, {7.3439850240980675`, 1.5798129294318801`}, {
       7.3439850240980675`, 1.5798129294318801`}}, {{7.3439850240980675`, 
       1.5798129294318801`}, {7.40988080231833, 1.6509005599709927`}, {
       7.40988080231833, 1.6509005599709927`}, {7.3439850240980675`, 
       1.5798129294318801`}, {7.3439850240980675`, 1.5798129294318801`}}, {{
       7.3439850240980675`, 1.5798129294318801`}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}, {
       7.3439850240980675`, 1.5798129294318801`}, {7.3439850240980675`, 
       1.5798129294318801`}}, {{7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}, {7.656135578085187, 1.5087252988927673`}, {
       7.656135578085187, 1.5087252988927673`}}, {{7.656135578085187, 
       1.5087252988927673`}, {7.627519773253604, 1.4161140656823183`}, {
       7.627519773253604, 1.4161140656823183`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}}, {{
       7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}}, {{7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}, {7.656135578085187, 1.5087252988927673`}, {
       7.656135578085187, 1.5087252988927673`}}, {{7.627519773253604, 
       1.4161140656823183`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}}, {{
       7.627519773253604, 1.4161140656823183`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}, {
       7.627519773253604, 1.4161140656823183`}, {7.627519773253604, 
       1.4161140656823183`}}, {{7.627519773253604, 1.4161140656823183`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}, {7.627519773253604, 1.4161140656823183`}, {
       7.627519773253604, 1.4161140656823183`}}, {{7.627519773253604, 
       1.4161140656823183`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}, {7.627519773253604, 
       1.4161140656823183`}, {7.627519773253604, 1.4161140656823183`}}, {{
       7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}, {{7.574050652829568, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.504392385370176, 
       1.3450264351432055`}, {7.574050652829568, 1.3665500378145419`}, {
       7.574050652829568, 1.3665500378145419`}}, {{7.574050652829568, 
       1.3665500378145419`}, {7.504392385370176, 1.3450264351432055`}, {
       7.504392385370176, 1.3450264351432055`}, {7.574050652829568, 
       1.3665500378145419`}, {7.574050652829568, 1.3665500378145419`}}, {{
       7.574050652829568, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}, {
       7.574050652829568, 1.3665500378145419`}, {7.574050652829568, 
       1.3665500378145419`}}, {{7.504392385370176, 1.3450264351432055`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}, {7.504392385370176, 1.3450264351432055`}, {
       7.504392385370176, 1.3450264351432055`}}, {{7.504392385370176, 
       1.3450264351432055`}, {7.40988080231833, 1.3665500378145419`}, {
       7.40988080231833, 1.3665500378145419`}, {7.504392385370176, 
       1.3450264351432055`}, {7.504392385370176, 1.3450264351432055`}}, {{
       7.504392385370176, 1.3450264351432055`}, {7.40988080231833, 
       1.3665500378145419`}, {7.40988080231833, 1.3665500378145419`}, {
       7.504392385370176, 1.3450264351432055`}, {7.504392385370176, 
       1.3450264351432055`}}, {{7.504392385370176, 1.3450264351432055`}, {
       7.40988080231833, 1.3665500378145419`}, {7.40988080231833, 
       1.3665500378145419`}, {7.504392385370176, 1.3450264351432055`}, {
       7.504392385370176, 1.3450264351432055`}}, {{7.40988080231833, 
       1.6509005599709927`}, {7.504392385370176, 1.672424162642329}, {
       7.504392385370176, 1.672424162642329}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}}, {{
       7.40988080231833, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.504392385370176, 1.672424162642329}, {
       7.40988080231833, 1.6509005599709927`}, {7.40988080231833, 
       1.6509005599709927`}}, {{7.40988080231833, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}, {7.40988080231833, 1.6509005599709927`}, {
       7.40988080231833, 1.6509005599709927`}}, {{7.40988080231833, 
       1.6509005599709927`}, {7.504392385370176, 1.672424162642329}, {
       7.504392385370176, 1.672424162642329}, {7.40988080231833, 
       1.6509005599709927`}, {7.40988080231833, 1.6509005599709927`}}, {{
       7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}}, {{7.504392385370176, 1.672424162642329}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}, {7.504392385370176, 1.672424162642329}, {
       7.504392385370176, 1.672424162642329}}, {{7.504392385370176, 
       1.672424162642329}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}, {7.504392385370176, 
       1.672424162642329}, {7.504392385370176, 1.672424162642329}}, {{
       7.504392385370176, 1.672424162642329}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}, {
       7.504392385370176, 1.672424162642329}, {7.504392385370176, 
       1.672424162642329}}, {{7.574050652829568, 1.6509005599709927`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}}, {{7.574050652829568, 
       1.6509005599709927`}, {7.627519773253604, 1.6013365321032162`}, {
       7.627519773253604, 1.6013365321032162`}, {7.574050652829568, 
       1.6509005599709927`}, {7.574050652829568, 1.6509005599709927`}}, {{
       7.574050652829568, 1.6509005599709927`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}, {
       7.574050652829568, 1.6509005599709927`}, {7.574050652829568, 
       1.6509005599709927`}}, {{7.574050652829568, 1.6509005599709927`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}, {7.574050652829568, 1.6509005599709927`}, {
       7.574050652829568, 1.6509005599709927`}}, {{7.627519773253604, 
       1.6013365321032162`}, {7.656135578085187, 1.5087252988927673`}, {
       7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}}, {{
       7.627519773253604, 1.6013365321032162`}, {7.656135578085187, 
       1.5087252988927673`}, {7.656135578085187, 1.5087252988927673`}, {
       7.627519773253604, 1.6013365321032162`}, {7.627519773253604, 
       1.6013365321032162`}}, {{7.627519773253604, 1.6013365321032162`}, {
       7.656135578085187, 1.5087252988927673`}, {7.656135578085187, 
       1.5087252988927673`}, {7.627519773253604, 1.6013365321032162`}, {
       7.627519773253604, 1.6013365321032162`}}, {{7.627519773253604, 
       1.6013365321032162`}, {7.656135578085187, 1.5087252988927673`}, {
       7.656135578085187, 1.5087252988927673`}, {7.627519773253604, 
       1.6013365321032162`}, {7.627519773253604, 1.6013365321032162`}}, {{
       7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.318478765339333, 
       2.041410893882297}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}, {{7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}}, {{7.667337352127816, 
       2.041410893882297}, {7.6369332639159015`, 1.943012120179557}, {
       7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.405693412036453, 1.8903506946387147`}, {
       7.405693412036453, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.580122705430695, 1.8903506946387147`}, {
       7.6369332639159015`, 1.943012120179557}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}}, {{
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}, {{7.405693412036453, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.6369332639159015`, 2.139809667585037}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}, {7.6369332639159015`, 2.139809667585037}, {
       7.580122705430695, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.405693412036453, 2.1924710931258793`}, {
       7.405693412036453, 2.1924710931258793`}}, {{7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}}, {{
       7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}, {{7.405693412036453, 1.8903506946387147`}, {
       7.335679618414602, 1.9658807942605059`}, {7.335679618414602, 
       1.9658807942605059`}, {7.405693412036453, 1.8903506946387147`}, {
       7.405693412036453, 1.8903506946387147`}}, {{7.405693412036453, 
       1.8903506946387147`}, {7.335679618414602, 1.9658807942605059`}, {
       7.335679618414602, 1.9658807942605059`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}}, {{
       7.405693412036453, 1.8903506946387147`}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}}, {{7.335679618414602, 1.9658807942605059`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.335679618414602, 1.9658807942605059`}, {
       7.335679618414602, 1.9658807942605059`}}, {{7.335679618414602, 
       1.9658807942605059`}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}, {7.335679618414602, 
       1.9658807942605059`}, {7.335679618414602, 1.9658807942605059`}}, {{
       7.335679618414602, 1.9658807942605059`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 1.9658807942605059`}, {7.335679618414602, 
       1.9658807942605059`}}, {{7.335679618414602, 1.9658807942605059`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}, {7.335679618414602, 1.9658807942605059`}, {
       7.335679618414602, 1.9658807942605059`}}, {{7.318478765339333, 
       2.041410893882297}, {7.335679618414602, 2.1169409935040884`}, {
       7.335679618414602, 2.1169409935040884`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}}, {{
       7.318478765339333, 2.041410893882297}, {7.335679618414602, 
       2.1169409935040884`}, {7.335679618414602, 2.1169409935040884`}, {
       7.318478765339333, 2.041410893882297}, {7.318478765339333, 
       2.041410893882297}}, {{7.318478765339333, 2.041410893882297}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}, {7.318478765339333, 2.041410893882297}, {
       7.318478765339333, 2.041410893882297}}, {{7.318478765339333, 
       2.041410893882297}, {7.335679618414602, 2.1169409935040884`}, {
       7.335679618414602, 2.1169409935040884`}, {7.318478765339333, 
       2.041410893882297}, {7.318478765339333, 2.041410893882297}}, {{
       7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}}, {{7.335679618414602, 2.1169409935040884`}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}, {7.335679618414602, 2.1169409935040884`}, {
       7.335679618414602, 2.1169409935040884`}}, {{7.335679618414602, 
       2.1169409935040884`}, {7.405693412036453, 2.1924710931258793`}, {
       7.405693412036453, 2.1924710931258793`}, {7.335679618414602, 
       2.1169409935040884`}, {7.335679618414602, 2.1169409935040884`}}, {{
       7.335679618414602, 2.1169409935040884`}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}, {
       7.335679618414602, 2.1169409935040884`}, {7.335679618414602, 
       2.1169409935040884`}}, {{7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}, {7.667337352127816, 2.041410893882297}, {
       7.667337352127816, 2.041410893882297}}, {{7.667337352127816, 
       2.041410893882297}, {7.6369332639159015`, 1.943012120179557}, {
       7.6369332639159015`, 1.943012120179557}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}}, {{
       7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}}, {{7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}, {7.667337352127816, 2.041410893882297}, {
       7.667337352127816, 2.041410893882297}}, {{7.6369332639159015`, 
       1.943012120179557}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}}, {{
       7.6369332639159015`, 1.943012120179557}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}, {
       7.6369332639159015`, 1.943012120179557}, {7.6369332639159015`, 
       1.943012120179557}}, {{7.6369332639159015`, 1.943012120179557}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}, {7.6369332639159015`, 1.943012120179557}, {
       7.6369332639159015`, 1.943012120179557}}, {{7.6369332639159015`, 
       1.943012120179557}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}, {7.6369332639159015`, 
       1.943012120179557}, {7.6369332639159015`, 1.943012120179557}}, {{
       7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}, {{7.580122705430695, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.50611129387022, 
       1.8674820205577658`}, {7.580122705430695, 1.8903506946387147`}, {
       7.580122705430695, 1.8903506946387147`}}, {{7.580122705430695, 
       1.8903506946387147`}, {7.50611129387022, 1.8674820205577658`}, {
       7.50611129387022, 1.8674820205577658`}, {7.580122705430695, 
       1.8903506946387147`}, {7.580122705430695, 1.8903506946387147`}}, {{
       7.580122705430695, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}, {
       7.580122705430695, 1.8903506946387147`}, {7.580122705430695, 
       1.8903506946387147`}}, {{7.50611129387022, 1.8674820205577658`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}, {7.50611129387022, 1.8674820205577658`}, {
       7.50611129387022, 1.8674820205577658`}}, {{7.50611129387022, 
       1.8674820205577658`}, {7.405693412036453, 1.8903506946387147`}, {
       7.405693412036453, 1.8903506946387147`}, {7.50611129387022, 
       1.8674820205577658`}, {7.50611129387022, 1.8674820205577658`}}, {{
       7.50611129387022, 1.8674820205577658`}, {7.405693412036453, 
       1.8903506946387147`}, {7.405693412036453, 1.8903506946387147`}, {
       7.50611129387022, 1.8674820205577658`}, {7.50611129387022, 
       1.8674820205577658`}}, {{7.50611129387022, 1.8674820205577658`}, {
       7.405693412036453, 1.8903506946387147`}, {7.405693412036453, 
       1.8903506946387147`}, {7.50611129387022, 1.8674820205577658`}, {
       7.50611129387022, 1.8674820205577658`}}, {{7.405693412036453, 
       2.1924710931258793`}, {7.50611129387022, 2.215339767206828}, {
       7.50611129387022, 2.215339767206828}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}}, {{
       7.405693412036453, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.50611129387022, 2.215339767206828}, {
       7.405693412036453, 2.1924710931258793`}, {7.405693412036453, 
       2.1924710931258793`}}, {{7.405693412036453, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}, {7.405693412036453, 2.1924710931258793`}, {
       7.405693412036453, 2.1924710931258793`}}, {{7.405693412036453, 
       2.1924710931258793`}, {7.50611129387022, 2.215339767206828}, {
       7.50611129387022, 2.215339767206828}, {7.405693412036453, 
       2.1924710931258793`}, {7.405693412036453, 2.1924710931258793`}}, {{
       7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}}, {{7.50611129387022, 2.215339767206828}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}, {7.50611129387022, 2.215339767206828}, {
       7.50611129387022, 2.215339767206828}}, {{7.50611129387022, 
       2.215339767206828}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}, {7.50611129387022, 
       2.215339767206828}, {7.50611129387022, 2.215339767206828}}, {{
       7.50611129387022, 2.215339767206828}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}, {
       7.50611129387022, 2.215339767206828}, {7.50611129387022, 
       2.215339767206828}}, {{7.580122705430695, 2.1924710931258793`}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}}, {{7.580122705430695, 
       2.1924710931258793`}, {7.6369332639159015`, 2.139809667585037}, {
       7.6369332639159015`, 2.139809667585037}, {7.580122705430695, 
       2.1924710931258793`}, {7.580122705430695, 2.1924710931258793`}}, {{
       7.580122705430695, 2.1924710931258793`}, {7.6369332639159015`, 
       2.139809667585037}, {7.6369332639159015`, 2.139809667585037}, {
       7.580122705430695, 2.1924710931258793`}, {7.580122705430695, 
       2.1924710931258793`}}, {{7.580122705430695, 2.1924710931258793`}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}, {7.580122705430695, 2.1924710931258793`}, {
       7.580122705430695, 2.1924710931258793`}}, {{7.6369332639159015`, 
       2.139809667585037}, {7.667337352127816, 2.041410893882297}, {
       7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       2.139809667585037}, {7.6369332639159015`, 2.139809667585037}}, {{
       7.6369332639159015`, 2.139809667585037}, {7.667337352127816, 
       2.041410893882297}, {7.667337352127816, 2.041410893882297}, {
       7.6369332639159015`, 2.139809667585037}, {7.6369332639159015`, 
       2.139809667585037}}, {{7.6369332639159015`, 2.139809667585037}, {
       7.667337352127816, 2.041410893882297}, {7.667337352127816, 
       2.041410893882297}, {7.6369332639159015`, 2.139809667585037}, {
       7.6369332639159015`, 2.139809667585037}}, {{7.6369332639159015`, 
       2.139809667585037}, {7.667337352127816, 2.041410893882297}, {
       7.667337352127816, 2.041410893882297}, {7.6369332639159015`, 
       2.139809667585037}, {7.6369332639159015`, 2.139809667585037}}, {{
       7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.285497280330366, 
       2.492196329258979}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}, {{7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}}, {{7.622099977734633, 
       2.492196329258979}, {7.59276402760521, 2.397254441904215}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.369647954681433, 2.3464430857917487`}, {
       7.369647954681433, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.59276402760521, 2.397254441904215}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}}, {{
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}, {{7.369647954681433, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.59276402760521, 2.587138216613743}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}, {7.59276402760521, 2.587138216613743}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.369647954681433, 2.6379495727262094`}, {
       7.369647954681433, 2.6379495727262094`}}, {{7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}}, {{
       7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}, {{7.369647954681433, 2.3464430857917487`}, {
       7.302093843413679, 2.419319707525364}, {7.302093843413679, 
       2.419319707525364}, {7.369647954681433, 2.3464430857917487`}, {
       7.369647954681433, 2.3464430857917487`}}, {{7.369647954681433, 
       2.3464430857917487`}, {7.302093843413679, 2.419319707525364}, {
       7.302093843413679, 2.419319707525364}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}}, {{
       7.369647954681433, 2.3464430857917487`}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}}, {{7.302093843413679, 2.419319707525364}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.302093843413679, 2.419319707525364}, {
       7.302093843413679, 2.419319707525364}}, {{7.302093843413679, 
       2.419319707525364}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}, {7.302093843413679, 
       2.419319707525364}, {7.302093843413679, 2.419319707525364}}, {{
       7.302093843413679, 2.419319707525364}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.419319707525364}, {7.302093843413679, 
       2.419319707525364}}, {{7.302093843413679, 2.419319707525364}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}, {7.302093843413679, 2.419319707525364}, {
       7.302093843413679, 2.419319707525364}}, {{7.285497280330366, 
       2.492196329258979}, {7.302093843413679, 2.5650729509925942`}, {
       7.302093843413679, 2.5650729509925942`}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}}, {{
       7.285497280330366, 2.492196329258979}, {7.302093843413679, 
       2.5650729509925942`}, {7.302093843413679, 2.5650729509925942`}, {
       7.285497280330366, 2.492196329258979}, {7.285497280330366, 
       2.492196329258979}}, {{7.285497280330366, 2.492196329258979}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}, {7.285497280330366, 2.492196329258979}, {
       7.285497280330366, 2.492196329258979}}, {{7.285497280330366, 
       2.492196329258979}, {7.302093843413679, 2.5650729509925942`}, {
       7.302093843413679, 2.5650729509925942`}, {7.285497280330366, 
       2.492196329258979}, {7.285497280330366, 2.492196329258979}}, {{
       7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}}, {{7.302093843413679, 2.5650729509925942`}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}, {7.302093843413679, 2.5650729509925942`}, {
       7.302093843413679, 2.5650729509925942`}}, {{7.302093843413679, 
       2.5650729509925942`}, {7.369647954681433, 2.6379495727262094`}, {
       7.369647954681433, 2.6379495727262094`}, {7.302093843413679, 
       2.5650729509925942`}, {7.302093843413679, 2.5650729509925942`}}, {{
       7.302093843413679, 2.5650729509925942`}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}, {
       7.302093843413679, 2.5650729509925942`}, {7.302093843413679, 
       2.5650729509925942`}}, {{7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}, {7.622099977734633, 2.492196329258979}, {
       7.622099977734633, 2.492196329258979}}, {{7.622099977734633, 
       2.492196329258979}, {7.59276402760521, 2.397254441904215}, {
       7.59276402760521, 2.397254441904215}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}}, {{
       7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}}, {{7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}, {7.622099977734633, 2.492196329258979}, {
       7.622099977734633, 2.492196329258979}}, {{7.59276402760521, 
       2.397254441904215}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}}, {{
       7.59276402760521, 2.397254441904215}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.59276402760521, 2.397254441904215}, {7.59276402760521, 
       2.397254441904215}}, {{7.59276402760521, 2.397254441904215}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.59276402760521, 2.397254441904215}, {
       7.59276402760521, 2.397254441904215}}, {{7.59276402760521, 
       2.397254441904215}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.59276402760521, 
       2.397254441904215}, {7.59276402760521, 2.397254441904215}}, {{
       7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}, {{7.5379493033835665`, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.46653801607861, 
       2.3243778201706}, {7.5379493033835665`, 2.3464430857917487`}, {
       7.5379493033835665`, 2.3464430857917487`}}, {{7.5379493033835665`, 
       2.3464430857917487`}, {7.46653801607861, 2.3243778201706}, {
       7.46653801607861, 2.3243778201706}, {7.5379493033835665`, 
       2.3464430857917487`}, {7.5379493033835665`, 2.3464430857917487`}}, {{
       7.5379493033835665`, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}, {
       7.5379493033835665`, 2.3464430857917487`}, {7.5379493033835665`, 
       2.3464430857917487`}}, {{7.46653801607861, 2.3243778201706}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}, {7.46653801607861, 2.3243778201706}, {
       7.46653801607861, 2.3243778201706}}, {{7.46653801607861, 
       2.3243778201706}, {7.369647954681433, 2.3464430857917487`}, {
       7.369647954681433, 2.3464430857917487`}, {7.46653801607861, 
       2.3243778201706}, {7.46653801607861, 2.3243778201706}}, {{
       7.46653801607861, 2.3243778201706}, {7.369647954681433, 
       2.3464430857917487`}, {7.369647954681433, 2.3464430857917487`}, {
       7.46653801607861, 2.3243778201706}, {7.46653801607861, 
       2.3243778201706}}, {{7.46653801607861, 2.3243778201706}, {
       7.369647954681433, 2.3464430857917487`}, {7.369647954681433, 
       2.3464430857917487`}, {7.46653801607861, 2.3243778201706}, {
       7.46653801607861, 2.3243778201706}}, {{7.369647954681433, 
       2.6379495727262094`}, {7.46653801607861, 2.660014838347358}, {
       7.46653801607861, 2.660014838347358}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}}, {{
       7.369647954681433, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.46653801607861, 2.660014838347358}, {
       7.369647954681433, 2.6379495727262094`}, {7.369647954681433, 
       2.6379495727262094`}}, {{7.369647954681433, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}, {7.369647954681433, 2.6379495727262094`}, {
       7.369647954681433, 2.6379495727262094`}}, {{7.369647954681433, 
       2.6379495727262094`}, {7.46653801607861, 2.660014838347358}, {
       7.46653801607861, 2.660014838347358}, {7.369647954681433, 
       2.6379495727262094`}, {7.369647954681433, 2.6379495727262094`}}, {{
       7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}}, {{7.46653801607861, 2.660014838347358}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.46653801607861, 2.660014838347358}, {
       7.46653801607861, 2.660014838347358}}, {{7.46653801607861, 
       2.660014838347358}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.46653801607861, 
       2.660014838347358}, {7.46653801607861, 2.660014838347358}}, {{
       7.46653801607861, 2.660014838347358}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.46653801607861, 2.660014838347358}, {7.46653801607861, 
       2.660014838347358}}, {{7.5379493033835665`, 2.6379495727262094`}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}}, {{7.5379493033835665`, 
       2.6379495727262094`}, {7.59276402760521, 2.587138216613743}, {
       7.59276402760521, 2.587138216613743}, {7.5379493033835665`, 
       2.6379495727262094`}, {7.5379493033835665`, 2.6379495727262094`}}, {{
       7.5379493033835665`, 2.6379495727262094`}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}, {
       7.5379493033835665`, 2.6379495727262094`}, {7.5379493033835665`, 
       2.6379495727262094`}}, {{7.5379493033835665`, 2.6379495727262094`}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}, {7.5379493033835665`, 2.6379495727262094`}, {
       7.5379493033835665`, 2.6379495727262094`}}, {{7.59276402760521, 
       2.587138216613743}, {7.622099977734633, 2.492196329258979}, {
       7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}}, {{
       7.59276402760521, 2.587138216613743}, {7.622099977734633, 
       2.492196329258979}, {7.622099977734633, 2.492196329258979}, {
       7.59276402760521, 2.587138216613743}, {7.59276402760521, 
       2.587138216613743}}, {{7.59276402760521, 2.587138216613743}, {
       7.622099977734633, 2.492196329258979}, {7.622099977734633, 
       2.492196329258979}, {7.59276402760521, 2.587138216613743}, {
       7.59276402760521, 2.587138216613743}}, {{7.59276402760521, 
       2.587138216613743}, {7.622099977734633, 2.492196329258979}, {
       7.622099977734633, 2.492196329258979}, {7.59276402760521, 
       2.587138216613743}, {7.59276402760521, 2.587138216613743}}, {{
       7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.361037638781139, 
       2.957009823195394}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}, {{7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}}, {{7.647253514682716, 
       2.957009823195394}, {7.622308929489409, 2.8762800023753416`}, {
       7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.432591607756533, 2.8330747134468037`}, {
       7.432591607756533, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.575699545707322, 2.8330747134468037`}, {
       7.622308929489409, 2.8762800023753416`}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}}, {{
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}, {{7.432591607756533, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.622308929489409, 3.037739644015446}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}, {7.622308929489409, 3.037739644015446}, {
       7.575699545707322, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.432591607756533, 3.080944932943984}, {
       7.432591607756533, 3.080944932943984}}, {{7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}}, {{
       7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}, {{7.432591607756533, 2.8330747134468037`}, {
       7.375149824680055, 2.895042268321099}, {7.375149824680055, 
       2.895042268321099}, {7.432591607756533, 2.8330747134468037`}, {
       7.432591607756533, 2.8330747134468037`}}, {{7.432591607756533, 
       2.8330747134468037`}, {7.375149824680055, 2.895042268321099}, {
       7.375149824680055, 2.895042268321099}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}}, {{
       7.432591607756533, 2.8330747134468037`}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}}, {{7.375149824680055, 2.895042268321099}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.375149824680055, 2.895042268321099}, {
       7.375149824680055, 2.895042268321099}}, {{7.375149824680055, 
       2.895042268321099}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}, {7.375149824680055, 
       2.895042268321099}, {7.375149824680055, 2.895042268321099}}, {{
       7.375149824680055, 2.895042268321099}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 2.895042268321099}, {7.375149824680055, 
       2.895042268321099}}, {{7.375149824680055, 2.895042268321099}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}, {7.375149824680055, 2.895042268321099}, {
       7.375149824680055, 2.895042268321099}}, {{7.361037638781139, 
       2.957009823195394}, {7.375149824680055, 3.018977378069689}, {
       7.375149824680055, 3.018977378069689}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}}, {{
       7.361037638781139, 2.957009823195394}, {7.375149824680055, 
       3.018977378069689}, {7.375149824680055, 3.018977378069689}, {
       7.361037638781139, 2.957009823195394}, {7.361037638781139, 
       2.957009823195394}}, {{7.361037638781139, 2.957009823195394}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}, {7.361037638781139, 2.957009823195394}, {
       7.361037638781139, 2.957009823195394}}, {{7.361037638781139, 
       2.957009823195394}, {7.375149824680055, 3.018977378069689}, {
       7.375149824680055, 3.018977378069689}, {7.361037638781139, 
       2.957009823195394}, {7.361037638781139, 2.957009823195394}}, {{
       7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}}, {{7.375149824680055, 3.018977378069689}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}, {7.375149824680055, 3.018977378069689}, {
       7.375149824680055, 3.018977378069689}}, {{7.375149824680055, 
       3.018977378069689}, {7.432591607756533, 3.080944932943984}, {
       7.432591607756533, 3.080944932943984}, {7.375149824680055, 
       3.018977378069689}, {7.375149824680055, 3.018977378069689}}, {{
       7.375149824680055, 3.018977378069689}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}, {
       7.375149824680055, 3.018977378069689}, {7.375149824680055, 
       3.018977378069689}}, {{7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}, {7.647253514682716, 2.957009823195394}, {
       7.647253514682716, 2.957009823195394}}, {{7.647253514682716, 
       2.957009823195394}, {7.622308929489409, 2.8762800023753416`}, {
       7.622308929489409, 2.8762800023753416`}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}}, {{
       7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}}, {{7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}, {7.647253514682716, 2.957009823195394}, {
       7.647253514682716, 2.957009823195394}}, {{7.622308929489409, 
       2.8762800023753416`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}}, {{
       7.622308929489409, 2.8762800023753416`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}, {
       7.622308929489409, 2.8762800023753416`}, {7.622308929489409, 
       2.8762800023753416`}}, {{7.622308929489409, 2.8762800023753416`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}, {7.622308929489409, 2.8762800023753416`}, {
       7.622308929489409, 2.8762800023753416`}}, {{7.622308929489409, 
       2.8762800023753416`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}, {7.622308929489409, 
       2.8762800023753416`}, {7.622308929489409, 2.8762800023753416`}}, {{
       7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}, {{7.575699545707322, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.514977976026318, 
       2.8143124475010466`}, {7.575699545707322, 2.8330747134468037`}, {
       7.575699545707322, 2.8330747134468037`}}, {{7.575699545707322, 
       2.8330747134468037`}, {7.514977976026318, 2.8143124475010466`}, {
       7.514977976026318, 2.8143124475010466`}, {7.575699545707322, 
       2.8330747134468037`}, {7.575699545707322, 2.8330747134468037`}}, {{
       7.575699545707322, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}, {
       7.575699545707322, 2.8330747134468037`}, {7.575699545707322, 
       2.8330747134468037`}}, {{7.514977976026318, 2.8143124475010466`}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}, {7.514977976026318, 2.8143124475010466`}, {
       7.514977976026318, 2.8143124475010466`}}, {{7.514977976026318, 
       2.8143124475010466`}, {7.432591607756533, 2.8330747134468037`}, {
       7.432591607756533, 2.8330747134468037`}, {7.514977976026318, 
       2.8143124475010466`}, {7.514977976026318, 2.8143124475010466`}}, {{
       7.514977976026318, 2.8143124475010466`}, {7.432591607756533, 
       2.8330747134468037`}, {7.432591607756533, 2.8330747134468037`}, {
       7.514977976026318, 2.8143124475010466`}, {7.514977976026318, 
       2.8143124475010466`}}, {{7.514977976026318, 2.8143124475010466`}, {
       7.432591607756533, 2.8330747134468037`}, {7.432591607756533, 
       2.8330747134468037`}, {7.514977976026318, 2.8143124475010466`}, {
       7.514977976026318, 2.8143124475010466`}}, {{7.432591607756533, 
       3.080944932943984}, {7.514977976026318, 3.099707198889741}, {
       7.514977976026318, 3.099707198889741}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}}, {{
       7.432591607756533, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.514977976026318, 3.099707198889741}, {
       7.432591607756533, 3.080944932943984}, {7.432591607756533, 
       3.080944932943984}}, {{7.432591607756533, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}, {7.432591607756533, 3.080944932943984}, {
       7.432591607756533, 3.080944932943984}}, {{7.432591607756533, 
       3.080944932943984}, {7.514977976026318, 3.099707198889741}, {
       7.514977976026318, 3.099707198889741}, {7.432591607756533, 
       3.080944932943984}, {7.432591607756533, 3.080944932943984}}, {{
       7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}}, {{7.514977976026318, 3.099707198889741}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}, {7.514977976026318, 3.099707198889741}, {
       7.514977976026318, 3.099707198889741}}, {{7.514977976026318, 
       3.099707198889741}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}, {7.514977976026318, 
       3.099707198889741}, {7.514977976026318, 3.099707198889741}}, {{
       7.514977976026318, 3.099707198889741}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}, {
       7.514977976026318, 3.099707198889741}, {7.514977976026318, 
       3.099707198889741}}, {{7.575699545707322, 3.080944932943984}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}}, {{7.575699545707322, 
       3.080944932943984}, {7.622308929489409, 3.037739644015446}, {
       7.622308929489409, 3.037739644015446}, {7.575699545707322, 
       3.080944932943984}, {7.575699545707322, 3.080944932943984}}, {{
       7.575699545707322, 3.080944932943984}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}, {
       7.575699545707322, 3.080944932943984}, {7.575699545707322, 
       3.080944932943984}}, {{7.575699545707322, 3.080944932943984}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}, {7.575699545707322, 3.080944932943984}, {
       7.575699545707322, 3.080944932943984}}, {{7.622308929489409, 
       3.037739644015446}, {7.647253514682716, 2.957009823195394}, {
       7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}}, {{
       7.622308929489409, 3.037739644015446}, {7.647253514682716, 
       2.957009823195394}, {7.647253514682716, 2.957009823195394}, {
       7.622308929489409, 3.037739644015446}, {7.622308929489409, 
       3.037739644015446}}, {{7.622308929489409, 3.037739644015446}, {
       7.647253514682716, 2.957009823195394}, {7.647253514682716, 
       2.957009823195394}, {7.622308929489409, 3.037739644015446}, {
       7.622308929489409, 3.037739644015446}}, {{7.622308929489409, 
       3.037739644015446}, {7.647253514682716, 2.957009823195394}, {
       7.647253514682716, 2.957009823195394}, {7.622308929489409, 
       3.037739644015446}, {7.622308929489409, 3.037739644015446}}, {{
       7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.365561454958063, 
       3.4820943594159033`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}, {{7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}}, {{7.6735729516222895`, 
       3.4820943594159033`}, {7.646728811705674, 3.395216883252527}, {
       7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.442564329124119, 3.34872146903146}, {
       7.442564329124119, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.596570077456233, 3.34872146903146}, {
       7.646728811705674, 3.395216883252527}, {7.6735729516222895`, 
       3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}}, {{
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}, {{7.442564329124119, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.646728811705674, 3.5689718355792794`}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}, {7.646728811705674, 3.5689718355792794`}, {
       7.596570077456233, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.442564329124119, 3.6154672498003464`}, {
       7.442564329124119, 3.6154672498003464`}}, {{7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}}, {{
       7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}, {{7.442564329124119, 3.34872146903146}, {
       7.380748297708267, 3.4154079142236817`}, {7.380748297708267, 
       3.4154079142236817`}, {7.442564329124119, 3.34872146903146}, {
       7.442564329124119, 3.34872146903146}}, {{7.442564329124119, 
       3.34872146903146}, {7.380748297708267, 3.4154079142236817`}, {
       7.380748297708267, 3.4154079142236817`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}}, {{
       7.442564329124119, 3.34872146903146}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}}, {{7.380748297708267, 3.4154079142236817`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.380748297708267, 3.4154079142236817`}, {
       7.380748297708267, 3.4154079142236817`}}, {{7.380748297708267, 
       3.4154079142236817`}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}, {7.380748297708267, 
       3.4154079142236817`}, {7.380748297708267, 3.4154079142236817`}}, {{
       7.380748297708267, 3.4154079142236817`}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.4154079142236817`}, {7.380748297708267, 
       3.4154079142236817`}}, {{7.380748297708267, 3.4154079142236817`}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}, {7.380748297708267, 3.4154079142236817`}, {
       7.380748297708267, 3.4154079142236817`}}, {{7.365561454958063, 
       3.4820943594159033`}, {7.380748297708267, 3.548780804608125}, {
       7.380748297708267, 3.548780804608125}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}}, {{
       7.365561454958063, 3.4820943594159033`}, {7.380748297708267, 
       3.548780804608125}, {7.380748297708267, 3.548780804608125}, {
       7.365561454958063, 3.4820943594159033`}, {7.365561454958063, 
       3.4820943594159033`}}, {{7.365561454958063, 3.4820943594159033`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}, {7.365561454958063, 3.4820943594159033`}, {
       7.365561454958063, 3.4820943594159033`}}, {{7.365561454958063, 
       3.4820943594159033`}, {7.380748297708267, 3.548780804608125}, {
       7.380748297708267, 3.548780804608125}, {7.365561454958063, 
       3.4820943594159033`}, {7.365561454958063, 3.4820943594159033`}}, {{
       7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}}, {{7.380748297708267, 3.548780804608125}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}, {7.380748297708267, 3.548780804608125}, {
       7.380748297708267, 3.548780804608125}}, {{7.380748297708267, 
       3.548780804608125}, {7.442564329124119, 3.6154672498003464`}, {
       7.442564329124119, 3.6154672498003464`}, {7.380748297708267, 
       3.548780804608125}, {7.380748297708267, 3.548780804608125}}, {{
       7.380748297708267, 3.548780804608125}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}, {
       7.380748297708267, 3.548780804608125}, {7.380748297708267, 
       3.548780804608125}}, {{7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.6735729516222895`, 3.4820943594159033`}}, {{7.6735729516222895`, 
       3.4820943594159033`}, {7.646728811705674, 3.395216883252527}, {
       7.646728811705674, 3.395216883252527}, {7.6735729516222895`, 
       3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}}, {{
       7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674, 
       3.395216883252527}, {7.646728811705674, 3.395216883252527}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}}, {{7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.6735729516222895`, 3.4820943594159033`}}, {{7.646728811705674, 
       3.395216883252527}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.646728811705674, 
       3.395216883252527}, {7.646728811705674, 3.395216883252527}}, {{
       7.646728811705674, 3.395216883252527}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}, {
       7.646728811705674, 3.395216883252527}, {7.646728811705674, 
       3.395216883252527}}, {{7.646728811705674, 3.395216883252527}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}, {7.646728811705674, 3.395216883252527}, {
       7.646728811705674, 3.395216883252527}}, {{7.646728811705674, 
       3.395216883252527}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}, {7.646728811705674, 
       3.395216883252527}, {7.646728811705674, 3.395216883252527}}, {{
       7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}, {{7.596570077456233, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.531224500456588, 
       3.3285304380603056`}, {7.596570077456233, 3.34872146903146}, {
       7.596570077456233, 3.34872146903146}}, {{7.596570077456233, 
       3.34872146903146}, {7.531224500456588, 3.3285304380603056`}, {
       7.531224500456588, 3.3285304380603056`}, {7.596570077456233, 
       3.34872146903146}, {7.596570077456233, 3.34872146903146}}, {{
       7.596570077456233, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}, {
       7.596570077456233, 3.34872146903146}, {7.596570077456233, 
       3.34872146903146}}, {{7.531224500456588, 3.3285304380603056`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}, {7.531224500456588, 3.3285304380603056`}, {
       7.531224500456588, 3.3285304380603056`}}, {{7.531224500456588, 
       3.3285304380603056`}, {7.442564329124119, 3.34872146903146}, {
       7.442564329124119, 3.34872146903146}, {7.531224500456588, 
       3.3285304380603056`}, {7.531224500456588, 3.3285304380603056`}}, {{
       7.531224500456588, 3.3285304380603056`}, {7.442564329124119, 
       3.34872146903146}, {7.442564329124119, 3.34872146903146}, {
       7.531224500456588, 3.3285304380603056`}, {7.531224500456588, 
       3.3285304380603056`}}, {{7.531224500456588, 3.3285304380603056`}, {
       7.442564329124119, 3.34872146903146}, {7.442564329124119, 
       3.34872146903146}, {7.531224500456588, 3.3285304380603056`}, {
       7.531224500456588, 3.3285304380603056`}}, {{7.442564329124119, 
       3.6154672498003464`}, {7.531224500456588, 3.635658280771501}, {
       7.531224500456588, 3.635658280771501}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}}, {{
       7.442564329124119, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.531224500456588, 3.635658280771501}, {
       7.442564329124119, 3.6154672498003464`}, {7.442564329124119, 
       3.6154672498003464`}}, {{7.442564329124119, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}, {7.442564329124119, 3.6154672498003464`}, {
       7.442564329124119, 3.6154672498003464`}}, {{7.442564329124119, 
       3.6154672498003464`}, {7.531224500456588, 3.635658280771501}, {
       7.531224500456588, 3.635658280771501}, {7.442564329124119, 
       3.6154672498003464`}, {7.442564329124119, 3.6154672498003464`}}, {{
       7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}}, {{7.531224500456588, 3.635658280771501}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}, {7.531224500456588, 3.635658280771501}, {
       7.531224500456588, 3.635658280771501}}, {{7.531224500456588, 
       3.635658280771501}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}, {7.531224500456588, 
       3.635658280771501}, {7.531224500456588, 3.635658280771501}}, {{
       7.531224500456588, 3.635658280771501}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}, {
       7.531224500456588, 3.635658280771501}, {7.531224500456588, 
       3.635658280771501}}, {{7.596570077456233, 3.6154672498003464`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}}, {{7.596570077456233, 
       3.6154672498003464`}, {7.646728811705674, 3.5689718355792794`}, {
       7.646728811705674, 3.5689718355792794`}, {7.596570077456233, 
       3.6154672498003464`}, {7.596570077456233, 3.6154672498003464`}}, {{
       7.596570077456233, 3.6154672498003464`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}, {
       7.596570077456233, 3.6154672498003464`}, {7.596570077456233, 
       3.6154672498003464`}}, {{7.596570077456233, 3.6154672498003464`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}, {7.596570077456233, 3.6154672498003464`}, {
       7.596570077456233, 3.6154672498003464`}}, {{7.646728811705674, 
       3.5689718355792794`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}}, {{
       7.646728811705674, 3.5689718355792794`}, {7.6735729516222895`, 
       3.4820943594159033`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.646728811705674, 3.5689718355792794`}, {7.646728811705674, 
       3.5689718355792794`}}, {{7.646728811705674, 3.5689718355792794`}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.6735729516222895`, 
       3.4820943594159033`}, {7.646728811705674, 3.5689718355792794`}, {
       7.646728811705674, 3.5689718355792794`}}, {{7.646728811705674, 
       3.5689718355792794`}, {7.6735729516222895`, 3.4820943594159033`}, {
       7.6735729516222895`, 3.4820943594159033`}, {7.646728811705674, 
       3.5689718355792794`}, {7.646728811705674, 3.5689718355792794`}}, {{
       7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}, {{
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}, {{
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}, {{
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}, {{
       7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}, {{
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}, {{
       7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}, {{
       7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}, {{
       7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}, {{
       7.649269415507194, -4.408020438984969}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}}, {{
       7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}, {{
       7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}, {{
       7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}, {{
       7.590068113507328, -4.3441547347218865`}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.3441547347218865`}, {
       7.590068113507328, -4.3441547347218865`}}, {{
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}, {{
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}, {{
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}, {{
       7.575523652410642, -4.280289030458804}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}, {
       7.575523652410642, -4.280289030458804}, {
       7.575523652410642, -4.280289030458804}}, {{
       7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}, {{
       7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}, {{
       7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}, {{
       7.590068113507328, -4.216423326195722}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}, {
       7.590068113507328, -4.216423326195722}, {
       7.590068113507328, -4.216423326195722}}, {{
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}, {{
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}, {{
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}, {{
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}}, {{
       7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}, {{
       7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}, {{
       7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}, {{
       7.844798033474368, -4.363491714059345}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}, {
       7.844798033474368, -4.363491714059345}, {
       7.844798033474368, -4.363491714059345}}, {{
       7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}, {{
       7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}, {{
       7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}, {{
       7.796760941700296, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}, {
       7.796760941700296, -4.408020438984969}, {
       7.796760941700296, -4.408020438984969}}, {{
       7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}, {{
       7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}, {{
       7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}, {{
       7.734179388829541, -4.427357418322427}, {
       7.649269415507194, -4.408020438984969}, {
       7.649269415507194, -4.408020438984969}, {
       7.734179388829541, -4.427357418322427}, {
       7.734179388829541, -4.427357418322427}}, {{
       7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}, {{
       7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}, {{
       7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}, {{
       7.649269415507194, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}, {
       7.649269415507194, -4.152557621932639}, {
       7.649269415507194, -4.152557621932639}}, {{
       7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}, {{
       7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}, {{
       7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}, {{
       7.734179388829541, -4.133220642595181}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}, {
       7.734179388829541, -4.133220642595181}, {
       7.734179388829541, -4.133220642595181}}, {{
       7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}, {{
       7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}, {{
       7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}, {{
       7.796760941700296, -4.152557621932639}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.796760941700296, -4.152557621932639}, {
       7.796760941700296, -4.152557621932639}}, {{
       7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}, {{
       7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}, {{
       7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}, {{
       7.844798033474368, -4.1970863468582635`}, {
       7.870506704796848, -4.280289030458804}, {
       7.870506704796848, -4.280289030458804}, {
       7.844798033474368, -4.1970863468582635`}, {
       7.844798033474368, -4.1970863468582635`}}, {{
       7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}, {{
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}, {{
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}, {{
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}, {{
       7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}, {{
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}, {{
       7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}, {{
       7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}, {{
       7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}, {{
       7.662630008062667, -3.8362999842840697`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}}, {{
       7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}, {{
       7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}, {{
       7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}, {{
       7.601739128890842, -3.770611583013509}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.770611583013509}, {
       7.601739128890842, -3.770611583013509}}, {{
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}, {{
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}, {{
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}, {{
       7.5867795757502785`, -3.7049231817429487`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}, {
       7.5867795757502785`, -3.7049231817429487`}, {
       7.5867795757502785`, -3.7049231817429487`}}, {{
       7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}, {{
       7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}, {{
       7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}, {{
       7.601739128890842, -3.639234780472388}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.601739128890842, -3.639234780472388}, {
       7.601739128890842, -3.639234780472388}}, {{
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}, {{
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}, {{
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}, {{
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}}, {{
       7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}, {{
       7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}, {{
       7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}, {{
       7.863738920351453, -3.7905004305997982`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.863738920351453, -3.7905004305997982`}, {
       7.863738920351453, -3.7905004305997982`}}, {{
       7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}, {{
       7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}, {{
       7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}, {{
       7.814330872687444, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.814330872687444, -3.8362999842840697`}, {
       7.814330872687444, -3.8362999842840697`}}, {{
       7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}, {{
       7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}, {{
       7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}, {{
       7.749963271882871, -3.8561888318703588`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.662630008062667, -3.8362999842840697`}, {
       7.749963271882871, -3.8561888318703588`}, {
       7.749963271882871, -3.8561888318703588`}}, {{
       7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}, {{
       7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}, {{
       7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}, {{
       7.662630008062667, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.662630008062667, -3.5735463792018276`}, {
       7.662630008062667, -3.5735463792018276`}}, {{
       7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}, {{
       7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}, {{
       7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}, {{
       7.749963271882871, -3.5536575316155385`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.749963271882871, -3.5536575316155385`}, {
       7.749963271882871, -3.5536575316155385`}}, {{
       7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}, {{
       7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}, {{
       7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}, {{
       7.814330872687444, -3.5735463792018276`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}, {
       7.814330872687444, -3.5735463792018276`}, {
       7.814330872687444, -3.5735463792018276`}}, {{
       7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}, {{
       7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}, {{
       7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}, {{
       7.863738920351453, -3.619345932886099}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.890181304999833, -3.7049231817429487`}, {
       7.863738920351453, -3.619345932886099}, {
       7.863738920351453, -3.619345932886099}}, {{
       7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}, {{
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}, {{
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}, {{
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}, {{
       7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}, {{
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}, {{
       7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}, {{
       7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}, {{
       7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}, {{
       7.644351722298322, -3.3990359760355147`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}}, {{
       7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}, {{
       7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}, {{
       7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}, {{
       7.575480745912052, -3.3247387349004267`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.3247387349004267`}, {
       7.575480745912052, -3.3247387349004267`}}, {{
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}, {{
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}, {{
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}, {{
       7.558560657959543, -3.2504414937653388`}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}, {
       7.558560657959543, -3.2504414937653388`}, {
       7.558560657959543, -3.2504414937653388`}}, {{
       7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}, {{
       7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}, {{
       7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}, {{
       7.575480745912052, -3.176144252630251}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}, {
       7.575480745912052, -3.176144252630251}, {
       7.575480745912052, -3.176144252630251}}, {{
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}, {{
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}, {{
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}, {{
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}}, {{
       7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}, {{
       7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}, {{
       7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}, {{
       7.87181710525371, -3.347234129466831}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.87181710525371, -3.347234129466831}, {
       7.87181710525371, -3.347234129466831}}, {{
       7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}, {{
       7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}, {{
       7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}, {{
       7.81593385097588, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.81593385097588, -3.3990359760355147`}, {
       7.81593385097588, -3.3990359760355147`}}, {{
       7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}, {{
       7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}, {{
       7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}, {{
       7.7431305087455415`, -3.421531370601919}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.644351722298322, -3.3990359760355147`}, {
       7.7431305087455415`, -3.421531370601919}, {
       7.7431305087455415`, -3.421531370601919}}, {{
       7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}, {{
       7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}, {{
       7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}, {{
       7.644351722298322, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.644351722298322, -3.101847011495163}, {
       7.644351722298322, -3.101847011495163}}, {{
       7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}, {{
       7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}, {{
       7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}, {{
       7.7431305087455415`, -3.0793516169287587`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}, {
       7.7431305087455415`, -3.0793516169287587`}, {
       7.7431305087455415`, -3.0793516169287587`}}, {{
       7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}, {{
       7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}, {{
       7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}, {{
       7.81593385097588, -3.101847011495163}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.81593385097588, -3.101847011495163}, {
       7.81593385097588, -3.101847011495163}}, {{
       7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}, {{
       7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}, {{
       7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}, {{
       7.87181710525371, -3.1536488580638466`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.901724915314659, -3.2504414937653388`}, {
       7.87181710525371, -3.1536488580638466`}, {
       7.87181710525371, -3.1536488580638466`}}, {{
       7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}, {{
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}, {{
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}, {{
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}, {{
       7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}, {{
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}, {{
       7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}, {{
       7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}, {{
       7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}, {{
       7.647290909930191, -2.886716543780911}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}}, {{
       7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}, {{
       7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}, {{
       7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}, {{
       7.595737972546112, -2.8311018099550873`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.8311018099550873`}, {
       7.595737972546112, -2.8311018099550873`}}, {{
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}, {{
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}, {{
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}, {{
       7.583072546839693, -2.7754870761292634`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.583072546839693, -2.7754870761292634`}, {
       7.583072546839693, -2.7754870761292634`}}, {{
       7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}, {{
       7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}, {{
       7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}, {{
       7.595737972546112, -2.7198723423034394`}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}, {
       7.595737972546112, -2.7198723423034394`}, {
       7.595737972546112, -2.7198723423034394`}}, {{
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}, {{
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}, {{
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}, {{
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}}, {{
       7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}, {{
       7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}, {{
       7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}, {{
       7.817558695575849, -2.847940596456496}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}, {
       7.817558695575849, -2.847940596456496}, {
       7.817558695575849, -2.847940596456496}}, {{
       7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}, {{
       7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}, {{
       7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}, {{
       7.775727636111186, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.775727636111186, -2.886716543780911}, {
       7.775727636111186, -2.886716543780911}}, {{
       7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}, {{
       7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}, {{
       7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}, {{
       7.7212311509401035`, -2.9035553302823196`}, {
       7.647290909930191, -2.886716543780911}, {
       7.647290909930191, -2.886716543780911}, {
       7.7212311509401035`, -2.9035553302823196`}, {
       7.7212311509401035`, -2.9035553302823196`}}, {{
       7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}, {{
       7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}, {{
       7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}, {{
       7.647290909930191, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.647290909930191, -2.664257608477616}, {
       7.647290909930191, -2.664257608477616}}, {{
       7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}, {{
       7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}, {{
       7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}, {{
       7.7212311509401035`, -2.647418821976207}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}, {
       7.7212311509401035`, -2.647418821976207}, {
       7.7212311509401035`, -2.647418821976207}}, {{
       7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}, {{
       7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}, {{
       7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}, {{
       7.775727636111186, -2.664257608477616}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.775727636111186, -2.664257608477616}, {
       7.775727636111186, -2.664257608477616}}, {{
       7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}, {{
       7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}, {{
       7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}, {{
       7.817558695575849, -2.7030335558020306`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.839945999201683, -2.7754870761292634`}, {
       7.817558695575849, -2.7030335558020306`}, {
       7.817558695575849, -2.7030335558020306`}}, {{
       7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}, {{
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}, {{
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}, {{
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}, {{
       7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}, {{
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}, {{
       7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}, {{
       7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}, {{
       7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}, {{
       7.684303079240637, -2.384840770440784}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}}, {{
       7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}, {{
       7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}, {{
       7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}, {{
       7.623191500462088, -2.318914280896184}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.318914280896184}, {
       7.623191500462088, -2.318914280896184}}, {{
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}, {{
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}, {{
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}, {{
       7.608177726270034, -2.252987791351584}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.608177726270034, -2.252987791351584}, {
       7.608177726270034, -2.252987791351584}}, {{
       7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}, {{
       7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}, {{
       7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}, {{
       7.623191500462088, -2.1870613018069838`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.623191500462088, -2.1870613018069838`}, {
       7.623191500462088, -2.1870613018069838`}}, {{
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}, {{
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}, {{
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}, {{
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}}, {{
       7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}, {{
       7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}, {{
       7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}, {{
       7.8861409128137705`, -2.338875215811482}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}, {
       7.8861409128137705`, -2.338875215811482}, {
       7.8861409128137705`, -2.338875215811482}}, {{
       7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}, {{
       7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}, {{
       7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}, {{
       7.836553785181845, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}, {
       7.836553785181845, -2.384840770440784}, {
       7.836553785181845, -2.384840770440784}}, {{
       7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}, {{
       7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}, {{
       7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}, {{
       7.771952883357865, -2.404801705356082}, {
       7.684303079240637, -2.384840770440784}, {
       7.684303079240637, -2.384840770440784}, {
       7.771952883357865, -2.404801705356082}, {
       7.771952883357865, -2.404801705356082}}, {{
       7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}, {{
       7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}, {{
       7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}, {{
       7.684303079240637, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}, {
       7.684303079240637, -2.1211348122623837`}, {
       7.684303079240637, -2.1211348122623837`}}, {{
       7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}, {{
       7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}, {{
       7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}, {{
       7.771952883357865, -2.101173877347086}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.771952883357865, -2.101173877347086}, {
       7.771952883357865, -2.101173877347086}}, {{
       7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}, {{
       7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}, {{
       7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}, {{
       7.836553785181845, -2.1211348122623837`}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.836553785181845, -2.1211348122623837`}, {
       7.836553785181845, -2.1211348122623837`}}, {{
       7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}, {{
       7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}, {{
       7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}, {{
       7.8861409128137705`, -2.167100366891686}, {
       7.912679138152448, -2.252987791351584}, {
       7.912679138152448, -2.252987791351584}, {
       7.8861409128137705`, -2.167100366891686}, {
       7.8861409128137705`, -2.167100366891686}}, {{
       7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}, {{
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}, {{
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}, {{
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}, {{
       7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}, {{
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}, {{
       7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}, {{
       7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}, {{
       7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}, {{
       7.725159209670655, -1.9135288597863316`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}}, {{
       7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}, {{
       7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}, {{
       7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}, {{
       7.667014418955127, -1.8508029081124124`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.8508029081124124`}, {
       7.667014418955127, -1.8508029081124124`}}, {{
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}, {{
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}, {{
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}, {{
       7.652729519502429, -1.788076956438493}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.652729519502429, -1.788076956438493}, {
       7.652729519502429, -1.788076956438493}}, {{
       7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}, {{
       7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}, {{
       7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}, {{
       7.667014418955127, -1.7253510047645737`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.667014418955127, -1.7253510047645737`}, {
       7.667014418955127, -1.7253510047645737`}}, {{
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}, {{
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}, {{
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}, {{
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}}, {{
       7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}, {{
       7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}, {{
       7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}, {{
       7.917198407906926, -1.8697947981328296`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.917198407906926, -1.8697947981328296`}, {
       7.917198407906926, -1.8697947981328296`}}, {{
       7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}, {{
       7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}, {{
       7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}, {{
       7.870018590007105, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.870018590007105, -1.9135288597863316`}, {
       7.870018590007105, -1.9135288597863316`}}, {{
       7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}, {{
       7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}, {{
       7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}, {{
       7.808553872654588, -1.9325207498067487`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.725159209670655, -1.9135288597863316`}, {
       7.808553872654588, -1.9325207498067487`}, {
       7.808553872654588, -1.9325207498067487`}}, {{
       7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}, {{
       7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}, {{
       7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}, {{
       7.725159209670655, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.725159209670655, -1.6626250530906546`}, {
       7.725159209670655, -1.6626250530906546`}}, {{
       7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}, {{
       7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}, {{
       7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}, {{
       7.808553872654588, -1.6436331630702374`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.808553872654588, -1.6436331630702374`}, {
       7.808553872654588, -1.6436331630702374`}}, {{
       7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}, {{
       7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}, {{
       7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}, {{
       7.870018590007105, -1.6626250530906546`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.870018590007105, -1.6626250530906546`}, {
       7.870018590007105, -1.6626250530906546`}}, {{
       7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}, {{
       7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}, {{
       7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}, {{
       7.917198407906926, -1.7063591147441566`}, {
       7.942448280175331, -1.788076956438493}, {
       7.942448280175331, -1.788076956438493}, {
       7.917198407906926, -1.7063591147441566`}, {
       7.917198407906926, -1.7063591147441566`}}, {{
       7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}, {{
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}, {{
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}, {{
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}, {{
       7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}, {{
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}, {{
       7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}, {{
       7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}, {{
       7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}, {{
       7.701824809281291, -1.389151507163096}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}}, {{
       7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}, {{
       7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}, {{
       7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}, {{
       7.634374451450147, -1.3163868134796253`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.3163868134796253`}, {
       7.634374451450147, -1.3163868134796253`}}, {{
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}, {{
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}, {{
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}, {{
       7.617803378309985, -1.2436221197961543`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.617803378309985, -1.2436221197961543`}, {
       7.617803378309985, -1.2436221197961543`}}, {{
       7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}, {{
       7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}, {{
       7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}, {{
       7.634374451450147, -1.1708574261126834`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.634374451450147, -1.1708574261126834`}, {
       7.634374451450147, -1.1708574261126834`}}, {{
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}, {{
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}, {{
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}, {{
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}}, {{
       7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}, {{
       7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}, {{
       7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}, {{
       7.924598207882299, -1.3384181900140113`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}, {
       7.924598207882299, -1.3384181900140113`}, {
       7.924598207882299, -1.3384181900140113`}}, {{
       7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}, {{
       7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}, {{
       7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}, {{
       7.869867671223901, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.869867671223901, -1.389151507163096}, {
       7.869867671223901, -1.389151507163096}}, {{
       7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}, {{
       7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}, {{
       7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}, {{
       7.798566061425341, -1.4111828836974822`}, {
       7.701824809281291, -1.389151507163096}, {
       7.701824809281291, -1.389151507163096}, {
       7.798566061425341, -1.4111828836974822`}, {
       7.798566061425341, -1.4111828836974822`}}, {{
       7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}, {{
       7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}, {{
       7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}, {{
       7.701824809281291, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.701824809281291, -1.0980927324292127`}, {
       7.701824809281291, -1.0980927324292127`}}, {{
       7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}, {{
       7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}, {{
       7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}, {{
       7.798566061425341, -1.0760613558948264`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.798566061425341, -1.0760613558948264`}, {
       7.798566061425341, -1.0760613558948264`}}, {{
       7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}, {{
       7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}, {{
       7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}, {{
       7.869867671223901, -1.0980927324292127`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.869867671223901, -1.0980927324292127`}, {
       7.869867671223901, -1.0980927324292127`}}, {{
       7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}, {{
       7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}, {{
       7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}, {{
       7.924598207882299, -1.1488260495782974`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.953889102195206, -1.2436221197961543`}, {
       7.924598207882299, -1.1488260495782974`}, {
       7.924598207882299, -1.1488260495782974`}}, {{
       7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}, {{
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}, {{
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}, {{
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}, {{
       7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368931, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}, {{
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}, {{
       7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}, {{
       7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}, {{
       7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}, {{
       7.682543176880408, -0.873380520354154}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}}, {{
       7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}, {{
       7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}, {{
       7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}, {{
       7.623876336980145, -0.8100913878427072}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.8100913878427072}, {
       7.623876336980145, -0.8100913878427072}}, {{
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}, {{
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}, {{
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}, {{
       7.609463181495884, -0.7468022553312602}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}, {
       7.609463181495884, -0.7468022553312602}, {
       7.609463181495884, -0.7468022553312602}}, {{
       7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}, {{
       7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}, {{
       7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}, {{
       7.623876336980145, -0.6835131228198132}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}, {
       7.623876336980145, -0.6835131228198132}, {
       7.623876336980145, -0.6835131228198132}}, {{
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}, {{
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}, {{
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}, {{
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}}, {{
       7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}, {{
       7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}, {{
       7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}, {{
       7.8763065864457165`, -0.8292537953003651}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}, {
       7.8763065864457165`, -0.8292537953003651}, {
       7.8763065864457165`, -0.8292537953003651}}, {{
       7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}, {{
       7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}, {{
       7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}, {{
       7.828703167649454, -0.873380520354154}, {
       7.766686593368932, -0.8925429278118121}, {
       7.766686593368932, -0.8925429278118121}, {
       7.828703167649454, -0.873380520354154}, {
       7.828703167649454, -0.873380520354154}}, {{
       7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}, {{
       7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}, {{
       7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}, {{
       7.766686593368931, -0.8925429278118121}, {
       7.682543176880408, -0.873380520354154}, {
       7.682543176880408, -0.873380520354154}, {
       7.766686593368931, -0.8925429278118121}, {
       7.766686593368931, -0.8925429278118121}}, {{
       7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}, {{
       7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}, {{
       7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}, {{
       7.682543176880408, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}, {
       7.682543176880408, -0.6202239903083664}, {
       7.682543176880408, -0.6202239903083664}}, {{
       7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}, {{
       7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}, {{
       7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}, {{
       7.766686593368932, -0.6010615828507083}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}, {
       7.766686593368932, -0.6010615828507083}, {
       7.766686593368932, -0.6010615828507083}}, {{
       7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}, {{
       7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}, {{
       7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}, {{
       7.828703167649454, -0.6202239903083664}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.828703167649454, -0.6202239903083664}, {
       7.828703167649454, -0.6202239903083664}}, {{
       7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}, {{
       7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}, {{
       7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}, {{
       7.8763065864457165`, -0.6643507153621553}, {
       7.901783163033978, -0.7468022553312602}, {
       7.901783163033978, -0.7468022553312602}, {
       7.8763065864457165`, -0.6643507153621553}, {
       7.8763065864457165`, -0.6643507153621553}}, {{
       7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111716`}, {
       7.67004490551025, -0.10877815610111716`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}, {{
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}, {{
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.3612878712557855}, {
       7.67004490551025, -0.3612878712557855}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}, {{
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}, {{
       7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845128`}, {
       7.888724733536566, -0.23503301367845128`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}, {{
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}, {{
       7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}, {{
       7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}, {{
       7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}, {{
       7.67004490551025, -0.36128787125578543`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}}, {{
       7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}, {{
       7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}, {{
       7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}, {{
       7.611527959375934, -0.29816044246711837`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.29816044246711837`}, {
       7.611527959375934, -0.29816044246711837`}}, {{
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}, {{
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}, {{
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}, {{
       7.597151629501478, -0.2350330136784513}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.611527959375934, -0.17190558488978425`}, {
       7.597151629501478, -0.2350330136784513}, {
       7.597151629501478, -0.2350330136784513}}, {{
       7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}, {{
       7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}, {{
       7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}, {{
       7.611527959375934, -0.17190558488978422`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.611527959375934, -0.17190558488978422`}, {
       7.611527959375934, -0.17190558488978422`}}, {{
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}, {{
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}, {{
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}, {{
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}}, {{
       7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}, {{
       7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}, {{
       7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}, {{
       7.8633132495971445`, -0.31727388997698813`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.8633132495971445`, -0.31727388997698813`}, {
       7.8633132495971445`, -0.31727388997698813`}}, {{
       7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}, {{
       7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}, {{
       7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}, {{
       7.815831457527794, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}, {
       7.815831457527794, -0.36128787125578543`}, {
       7.815831457527794, -0.36128787125578543`}}, {{
       7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}, {{
       7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}, {{
       7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}, {{
       7.753973335583987, -0.3804013187656552}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.67004490551025, -0.36128787125578543`}, {
       7.753973335583987, -0.3804013187656552}, {
       7.753973335583987, -0.3804013187656552}}, {{
       7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}, {{
       7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}, {{
       7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}, {{
       7.67004490551025, -0.10877815610111713`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}, {
       7.67004490551025, -0.10877815610111713`}, {
       7.67004490551025, -0.10877815610111713`}}, {{
       7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}, {{
       7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}, {{
       7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}, {{
       7.753973335583987, -0.0896647085912474}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.753973335583987, -0.0896647085912474}, {
       7.753973335583987, -0.0896647085912474}}, {{
       7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}, {{
       7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}, {{
       7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}, {{
       7.815831457527794, -0.10877815610111716`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.815831457527794, -0.10877815610111716`}, {
       7.815831457527794, -0.10877815610111716`}}, {{
       7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}, {{
       7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}, {{
       7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}, {{
       7.8633132495971445`, -0.15279213737991448`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.888724733536566, -0.23503301367845134`}, {
       7.8633132495971445`, -0.15279213737991448`}, {
       7.8633132495971445`, -0.15279213737991448`}}, {{7.666826849311777, 
       0.06378109101299881}, {7.598592771368875, 0.13739125321137974`}, {
       7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.2846115776081416}, {7.666826849311777, 0.3582217398065225}, {
       7.666826849311777, 0.3582217398065225}, {7.598592771368875, 
       0.2846115776081416}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.1373912532113797}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}}, {{
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}, {{7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.1151038894082094}, {7.836822237153086, 
       0.06378109101299881}, {7.764692158723719, 0.04149372720982844}, {
       7.666826849311777, 0.06378109101299878}, {7.666826849311777, 
       0.06378109101299878}, {7.764692158723719, 0.04149372720982844}, {
       7.836822237153086, 0.06378109101299881}, {7.8921886996047, 
       0.1151038894082094}, {7.921819931073741, 0.21100141540976064`}, {
       7.921819931073741, 0.21100141540976064`}}, {{7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}}, {{
       7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.836822237153086, 0.3582217398065225}, {
       7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.2110014154097607}, {7.921819931073741, 0.2110014154097607}, {
       7.8921886996047, 0.3068989414113119}, {7.836822237153086, 
       0.3582217398065225}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}, {{7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}}, {{7.666826849311777, 
       0.06378109101299881}, {7.598592771368875, 0.13739125321137974`}, {
       7.598592771368875, 0.13739125321137974`}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}}, {{
       7.666826849311777, 0.06378109101299881}, {7.598592771368875, 
       0.13739125321137974`}, {7.598592771368875, 0.13739125321137974`}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}}, {{7.666826849311777, 0.06378109101299881}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}, {7.666826849311777, 0.06378109101299881}, {
       7.666826849311777, 0.06378109101299881}}, {{7.666826849311777, 
       0.06378109101299881}, {7.598592771368875, 0.13739125321137974`}, {
       7.598592771368875, 0.13739125321137974`}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}}, {{
       7.598592771368875, 0.13739125321137974`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}}, {{7.598592771368875, 0.13739125321137974`}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}, {7.598592771368875, 0.13739125321137974`}, {
       7.598592771368875, 0.13739125321137974`}}, {{7.598592771368875, 
       0.13739125321137974`}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.13739125321137974`}, {7.598592771368875, 0.13739125321137974`}}, {{
       7.598592771368875, 0.13739125321137974`}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.13739125321137974`}, {7.598592771368875, 
       0.13739125321137974`}}, {{7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}}, {{7.581829155391122, 
       0.21100141540976067`}, {7.598592771368875, 0.2846115776081416}, {
       7.598592771368875, 0.2846115776081416}, {7.581829155391122, 
       0.21100141540976067`}, {7.581829155391122, 0.21100141540976067`}}, {{
       7.581829155391122, 0.21100141540976067`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}, {
       7.581829155391122, 0.21100141540976067`}, {7.581829155391122, 
       0.21100141540976067`}}, {{7.581829155391122, 0.21100141540976067`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}, {7.581829155391122, 0.21100141540976067`}, {
       7.581829155391122, 0.21100141540976067`}}, {{7.598592771368875, 
       0.2846115776081416}, {7.666826849311777, 0.35822173980652255`}, {
       7.666826849311777, 0.35822173980652255`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}}, {{
       7.598592771368875, 0.2846115776081416}, {7.666826849311777, 
       0.35822173980652255`}, {7.666826849311777, 0.35822173980652255`}, {
       7.598592771368875, 0.2846115776081416}, {7.598592771368875, 
       0.2846115776081416}}, {{7.598592771368875, 0.2846115776081416}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}, {7.598592771368875, 0.2846115776081416}, {
       7.598592771368875, 0.2846115776081416}}, {{7.598592771368875, 
       0.2846115776081416}, {7.666826849311777, 0.35822173980652255`}, {
       7.666826849311777, 0.35822173980652255`}, {7.598592771368875, 
       0.2846115776081416}, {7.598592771368875, 0.2846115776081416}}, {{
       7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}, {{7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.1151038894082094}, {7.8921886996047, 
       0.1151038894082094}, {7.921819931073741, 0.21100141540976064`}, {
       7.921819931073741, 0.21100141540976064`}}, {{7.921819931073741, 
       0.21100141540976064`}, {7.8921886996047, 0.1151038894082094}, {
       7.8921886996047, 0.1151038894082094}, {7.921819931073741, 
       0.21100141540976064`}, {7.921819931073741, 0.21100141540976064`}}, {{
       7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}}, {{7.8921886996047, 0.1151038894082094}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.8921886996047, 0.1151038894082094}, {
       7.8921886996047, 0.1151038894082094}}, {{7.8921886996047, 
       0.1151038894082094}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}, {7.8921886996047, 
       0.1151038894082094}, {7.8921886996047, 0.1151038894082094}}, {{
       7.8921886996047, 0.1151038894082094}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}, {
       7.8921886996047, 0.1151038894082094}, {7.8921886996047, 
       0.1151038894082094}}, {{7.8921886996047, 0.1151038894082094}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}, {7.8921886996047, 0.1151038894082094}, {
       7.8921886996047, 0.1151038894082094}}, {{7.836822237153086, 
       0.06378109101299881}, {7.764692158723719, 0.04149372720982844}, {
       7.764692158723719, 0.04149372720982844}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}}, {{
       7.836822237153086, 0.06378109101299881}, {7.764692158723719, 
       0.04149372720982844}, {7.764692158723719, 0.04149372720982844}, {
       7.836822237153086, 0.06378109101299881}, {7.836822237153086, 
       0.06378109101299881}}, {{7.836822237153086, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}, {7.836822237153086, 0.06378109101299881}, {
       7.836822237153086, 0.06378109101299881}}, {{7.836822237153086, 
       0.06378109101299881}, {7.764692158723719, 0.04149372720982844}, {
       7.764692158723719, 0.04149372720982844}, {7.836822237153086, 
       0.06378109101299881}, {7.836822237153086, 0.06378109101299881}}, {{
       7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}}, {{7.764692158723719, 0.04149372720982844}, {
       7.666826849311777, 0.06378109101299881}, {7.666826849311777, 
       0.06378109101299881}, {7.764692158723719, 0.04149372720982844}, {
       7.764692158723719, 0.04149372720982844}}, {{7.764692158723719, 
       0.04149372720982844}, {7.666826849311777, 0.06378109101299881}, {
       7.666826849311777, 0.06378109101299881}, {7.764692158723719, 
       0.04149372720982844}, {7.764692158723719, 0.04149372720982844}}, {{
       7.764692158723719, 0.04149372720982844}, {7.666826849311777, 
       0.06378109101299881}, {7.666826849311777, 0.06378109101299881}, {
       7.764692158723719, 0.04149372720982844}, {7.764692158723719, 
       0.04149372720982844}}, {{7.666826849311777, 0.35822173980652255`}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}, {7.666826849311777, 0.35822173980652255`}, {
       7.666826849311777, 0.35822173980652255`}}, {{7.666826849311777, 
       0.35822173980652255`}, {7.764692158723719, 0.3805091036096929}, {
       7.764692158723719, 0.3805091036096929}, {7.666826849311777, 
       0.35822173980652255`}, {7.666826849311777, 0.35822173980652255`}}, {{
       7.666826849311777, 0.35822173980652255`}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}, {
       7.666826849311777, 0.35822173980652255`}, {7.666826849311777, 
       0.35822173980652255`}}, {{7.666826849311777, 0.35822173980652255`}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}, {7.666826849311777, 0.35822173980652255`}, {
       7.666826849311777, 0.35822173980652255`}}, {{7.764692158723719, 
       0.3805091036096929}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}}, {{
       7.764692158723719, 0.3805091036096929}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}, {
       7.764692158723719, 0.3805091036096929}, {7.764692158723719, 
       0.3805091036096929}}, {{7.764692158723719, 0.3805091036096929}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}, {7.764692158723719, 0.3805091036096929}, {
       7.764692158723719, 0.3805091036096929}}, {{7.764692158723719, 
       0.3805091036096929}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}, {7.764692158723719, 
       0.3805091036096929}, {7.764692158723719, 0.3805091036096929}}, {{
       7.836822237153086, 0.3582217398065225}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}, {{7.836822237153086, 0.3582217398065225}, {
       7.8921886996047, 0.3068989414113119}, {7.8921886996047, 
       0.3068989414113119}, {7.836822237153086, 0.3582217398065225}, {
       7.836822237153086, 0.3582217398065225}}, {{7.836822237153086, 
       0.3582217398065225}, {7.8921886996047, 0.3068989414113119}, {
       7.8921886996047, 0.3068989414113119}, {7.836822237153086, 
       0.3582217398065225}, {7.836822237153086, 0.3582217398065225}}, {{
       7.836822237153086, 0.3582217398065225}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}, {
       7.836822237153086, 0.3582217398065225}, {7.836822237153086, 
       0.3582217398065225}}, {{7.8921886996047, 0.3068989414113119}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}, {7.8921886996047, 0.3068989414113119}, {
       7.8921886996047, 0.3068989414113119}}, {{7.8921886996047, 
       0.3068989414113119}, {7.921819931073741, 0.21100141540976064`}, {
       7.921819931073741, 0.21100141540976064`}, {7.8921886996047, 
       0.3068989414113119}, {7.8921886996047, 0.3068989414113119}}, {{
       7.8921886996047, 0.3068989414113119}, {7.921819931073741, 
       0.21100141540976064`}, {7.921819931073741, 0.21100141540976064`}, {
       7.8921886996047, 0.3068989414113119}, {7.8921886996047, 
       0.3068989414113119}}, {{7.8921886996047, 0.3068989414113119}, {
       7.921819931073741, 0.21100141540976064`}, {7.921819931073741, 
       0.21100141540976064`}, {7.8921886996047, 0.3068989414113119}, {
       7.8921886996047, 0.3068989414113119}}, {{7.704426849326499, 
       0.6118313882494719}, {7.636700076183877, 0.6848942756878135}, {
       7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.8310200505644966}, {7.704426849326499, 0.9040829380028381}, {
       7.704426849326499, 0.9040829380028381}, {7.636700076183877, 
       0.8310200505644966}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}}, {{
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}, {{7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.6627726133491287}, {7.87315836024769, 
       0.6118313882494719}, {7.8015645524932555`, 0.5897097259107871}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}, {7.8015645524932555`, 0.5897097259107871}, {
       7.87315836024769, 0.6118313882494719}, {7.92811318568415, 
       0.6627726133491287}, {7.957524115708285, 0.757957163126155}, {
       7.957524115708285, 0.757957163126155}}, {{7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}}, {{
       7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.87315836024769, 0.9040829380028381}, {
       7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.87315836024769, 
       0.9040829380028381}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}, {{7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}}, {{7.704426849326499, 
       0.6118313882494719}, {7.636700076183877, 0.6848942756878135}, {
       7.636700076183877, 0.6848942756878135}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}}, {{
       7.704426849326499, 0.6118313882494719}, {7.636700076183877, 
       0.6848942756878135}, {7.636700076183877, 0.6848942756878135}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}}, {{7.704426849326499, 0.6118313882494719}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}, {7.704426849326499, 0.6118313882494719}, {
       7.704426849326499, 0.6118313882494719}}, {{7.704426849326499, 
       0.6118313882494719}, {7.636700076183877, 0.6848942756878135}, {
       7.636700076183877, 0.6848942756878135}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}}, {{
       7.636700076183877, 0.6848942756878135}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}}, {{7.636700076183877, 0.6848942756878135}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}, {7.636700076183877, 0.6848942756878135}, {
       7.636700076183877, 0.6848942756878135}}, {{7.636700076183877, 
       0.6848942756878135}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.6848942756878135}, {7.636700076183877, 0.6848942756878135}}, {{
       7.636700076183877, 0.6848942756878135}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.6848942756878135}, {7.636700076183877, 
       0.6848942756878135}}, {{7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}}, {{7.620061093865903, 
       0.757957163126155}, {7.636700076183877, 0.8310200505644966}, {
       7.636700076183877, 0.8310200505644966}, {7.620061093865903, 
       0.757957163126155}, {7.620061093865903, 0.757957163126155}}, {{
       7.620061093865903, 0.757957163126155}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}, {
       7.620061093865903, 0.757957163126155}, {7.620061093865903, 
       0.757957163126155}}, {{7.620061093865903, 0.757957163126155}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}, {7.620061093865903, 0.757957163126155}, {
       7.620061093865903, 0.757957163126155}}, {{7.636700076183877, 
       0.8310200505644966}, {7.704426849326499, 0.9040829380028381}, {
       7.704426849326499, 0.9040829380028381}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}}, {{
       7.636700076183877, 0.8310200505644966}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}, {
       7.636700076183877, 0.8310200505644966}, {7.636700076183877, 
       0.8310200505644966}}, {{7.636700076183877, 0.8310200505644966}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}, {7.636700076183877, 0.8310200505644966}, {
       7.636700076183877, 0.8310200505644966}}, {{7.636700076183877, 
       0.8310200505644966}, {7.704426849326499, 0.9040829380028381}, {
       7.704426849326499, 0.9040829380028381}, {7.636700076183877, 
       0.8310200505644966}, {7.636700076183877, 0.8310200505644966}}, {{
       7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}, {{7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.6627726133491287}, {7.92811318568415, 
       0.6627726133491287}, {7.957524115708285, 0.757957163126155}, {
       7.957524115708285, 0.757957163126155}}, {{7.957524115708285, 
       0.757957163126155}, {7.92811318568415, 0.6627726133491287}, {
       7.92811318568415, 0.6627726133491287}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}}, {{
       7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}}, {{7.92811318568415, 0.6627726133491287}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.92811318568415, 0.6627726133491287}, {
       7.92811318568415, 0.6627726133491287}}, {{7.92811318568415, 
       0.6627726133491287}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}, {7.92811318568415, 
       0.6627726133491287}, {7.92811318568415, 0.6627726133491287}}, {{
       7.92811318568415, 0.6627726133491287}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}, {
       7.92811318568415, 0.6627726133491287}, {7.92811318568415, 
       0.6627726133491287}}, {{7.92811318568415, 0.6627726133491287}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}, {7.92811318568415, 0.6627726133491287}, {
       7.92811318568415, 0.6627726133491287}}, {{7.87315836024769, 
       0.6118313882494719}, {7.8015645524932555`, 0.5897097259107871}, {
       7.8015645524932555`, 0.5897097259107871}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}}, {{
       7.87315836024769, 0.6118313882494719}, {7.8015645524932555`, 
       0.5897097259107871}, {7.8015645524932555`, 0.5897097259107871}, {
       7.87315836024769, 0.6118313882494719}, {7.87315836024769, 
       0.6118313882494719}}, {{7.87315836024769, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}, {7.87315836024769, 0.6118313882494719}, {
       7.87315836024769, 0.6118313882494719}}, {{7.87315836024769, 
       0.6118313882494719}, {7.8015645524932555`, 0.5897097259107871}, {
       7.8015645524932555`, 0.5897097259107871}, {7.87315836024769, 
       0.6118313882494719}, {7.87315836024769, 0.6118313882494719}}, {{
       7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}}, {{7.8015645524932555`, 0.5897097259107871}, {
       7.704426849326499, 0.6118313882494719}, {7.704426849326499, 
       0.6118313882494719}, {7.8015645524932555`, 0.5897097259107871}, {
       7.8015645524932555`, 0.5897097259107871}}, {{7.8015645524932555`, 
       0.5897097259107871}, {7.704426849326499, 0.6118313882494719}, {
       7.704426849326499, 0.6118313882494719}, {7.8015645524932555`, 
       0.5897097259107871}, {7.8015645524932555`, 0.5897097259107871}}, {{
       7.8015645524932555`, 0.5897097259107871}, {7.704426849326499, 
       0.6118313882494719}, {7.704426849326499, 0.6118313882494719}, {
       7.8015645524932555`, 0.5897097259107871}, {7.8015645524932555`, 
       0.5897097259107871}}, {{7.704426849326499, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}, {7.704426849326499, 0.9040829380028381}, {
       7.704426849326499, 0.9040829380028381}}, {{7.704426849326499, 
       0.9040829380028381}, {7.8015645524932555`, 0.926204600341523}, {
       7.8015645524932555`, 0.926204600341523}, {7.704426849326499, 
       0.9040829380028381}, {7.704426849326499, 0.9040829380028381}}, {{
       7.704426849326499, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}, {
       7.704426849326499, 0.9040829380028381}, {7.704426849326499, 
       0.9040829380028381}}, {{7.704426849326499, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}, {7.704426849326499, 0.9040829380028381}, {
       7.704426849326499, 0.9040829380028381}}, {{7.8015645524932555`, 
       0.926204600341523}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}}, {{
       7.8015645524932555`, 0.926204600341523}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}, {
       7.8015645524932555`, 0.926204600341523}, {7.8015645524932555`, 
       0.926204600341523}}, {{7.8015645524932555`, 0.926204600341523}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}, {7.8015645524932555`, 0.926204600341523}, {
       7.8015645524932555`, 0.926204600341523}}, {{7.8015645524932555`, 
       0.926204600341523}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}, {7.8015645524932555`, 
       0.926204600341523}, {7.8015645524932555`, 0.926204600341523}}, {{
       7.87315836024769, 0.9040829380028381}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}, {{7.87315836024769, 0.9040829380028381}, {
       7.92811318568415, 0.8531417129031813}, {7.92811318568415, 
       0.8531417129031813}, {7.87315836024769, 0.9040829380028381}, {
       7.87315836024769, 0.9040829380028381}}, {{7.87315836024769, 
       0.9040829380028381}, {7.92811318568415, 0.8531417129031813}, {
       7.92811318568415, 0.8531417129031813}, {7.87315836024769, 
       0.9040829380028381}, {7.87315836024769, 0.9040829380028381}}, {{
       7.87315836024769, 0.9040829380028381}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}, {
       7.87315836024769, 0.9040829380028381}, {7.87315836024769, 
       0.9040829380028381}}, {{7.92811318568415, 0.8531417129031813}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}, {7.92811318568415, 0.8531417129031813}, {
       7.92811318568415, 0.8531417129031813}}, {{7.92811318568415, 
       0.8531417129031813}, {7.957524115708285, 0.757957163126155}, {
       7.957524115708285, 0.757957163126155}, {7.92811318568415, 
       0.8531417129031813}, {7.92811318568415, 0.8531417129031813}}, {{
       7.92811318568415, 0.8531417129031813}, {7.957524115708285, 
       0.757957163126155}, {7.957524115708285, 0.757957163126155}, {
       7.92811318568415, 0.8531417129031813}, {7.92811318568415, 
       0.8531417129031813}}, {{7.92811318568415, 0.8531417129031813}, {
       7.957524115708285, 0.757957163126155}, {7.957524115708285, 
       0.757957163126155}, {7.92811318568415, 0.8531417129031813}, {
       7.92811318568415, 0.8531417129031813}}, {{7.713807209888335, 
       1.160347952955769}, {7.658857113081461, 1.2196275044748133`}, {
       7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.3381866075129014`}, {7.713807209888335, 1.3974661590319457`}, {
       7.713807209888335, 1.3974661590319457`}, {7.658857113081461, 
       1.3381866075129014`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}}, {{
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}, {{7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.201679100459168}, {7.850707469996177, 
       1.160347952955769}, {7.792619855832213, 1.1423995489401237`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}, {7.792619855832213, 1.1423995489401237`}, {
       7.850707469996177, 1.160347952955769}, {7.895295050913094, 
       1.201679100459168}, {7.919157600050098, 1.2789070559938573`}, {
       7.919157600050098, 1.2789070559938573`}}, {{7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}}, {{
       7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.850707469996177, 1.3974661590319457`}, {
       7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.850707469996177, 
       1.3974661590319457`}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}, {{7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}}, {{7.713807209888335, 
       1.160347952955769}, {7.658857113081461, 1.2196275044748133`}, {
       7.658857113081461, 1.2196275044748133`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}}, {{
       7.713807209888335, 1.160347952955769}, {7.658857113081461, 
       1.2196275044748133`}, {7.658857113081461, 1.2196275044748133`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}}, {{7.713807209888335, 1.160347952955769}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}, {7.713807209888335, 1.160347952955769}, {
       7.713807209888335, 1.160347952955769}}, {{7.713807209888335, 
       1.160347952955769}, {7.658857113081461, 1.2196275044748133`}, {
       7.658857113081461, 1.2196275044748133`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}}, {{
       7.658857113081461, 1.2196275044748133`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}}, {{7.658857113081461, 1.2196275044748133`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}, {7.658857113081461, 1.2196275044748133`}, {
       7.658857113081461, 1.2196275044748133`}}, {{7.658857113081461, 
       1.2196275044748133`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.2196275044748133`}, {7.658857113081461, 1.2196275044748133`}}, {{
       7.658857113081461, 1.2196275044748133`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.2196275044748133`}, {7.658857113081461, 
       1.2196275044748133`}}, {{7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}}, {{7.645357079834414, 
       1.2789070559938573`}, {7.658857113081461, 1.3381866075129014`}, {
       7.658857113081461, 1.3381866075129014`}, {7.645357079834414, 
       1.2789070559938573`}, {7.645357079834414, 1.2789070559938573`}}, {{
       7.645357079834414, 1.2789070559938573`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}, {
       7.645357079834414, 1.2789070559938573`}, {7.645357079834414, 
       1.2789070559938573`}}, {{7.645357079834414, 1.2789070559938573`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}, {7.645357079834414, 1.2789070559938573`}, {
       7.645357079834414, 1.2789070559938573`}}, {{7.658857113081461, 
       1.3381866075129014`}, {7.713807209888335, 1.3974661590319457`}, {
       7.713807209888335, 1.3974661590319457`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}}, {{
       7.658857113081461, 1.3381866075129014`}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}, {
       7.658857113081461, 1.3381866075129014`}, {7.658857113081461, 
       1.3381866075129014`}}, {{7.658857113081461, 1.3381866075129014`}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}, {7.658857113081461, 1.3381866075129014`}, {
       7.658857113081461, 1.3381866075129014`}}, {{7.658857113081461, 
       1.3381866075129014`}, {7.713807209888335, 1.3974661590319457`}, {
       7.713807209888335, 1.3974661590319457`}, {7.658857113081461, 
       1.3381866075129014`}, {7.658857113081461, 1.3381866075129014`}}, {{
       7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}, {{7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.201679100459168}, {7.895295050913094, 
       1.201679100459168}, {7.919157600050098, 1.2789070559938573`}, {
       7.919157600050098, 1.2789070559938573`}}, {{7.919157600050098, 
       1.2789070559938573`}, {7.895295050913094, 1.201679100459168}, {
       7.895295050913094, 1.201679100459168}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}}, {{
       7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}}, {{7.895295050913094, 1.201679100459168}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.895295050913094, 1.201679100459168}, {
       7.895295050913094, 1.201679100459168}}, {{7.895295050913094, 
       1.201679100459168}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}, {7.895295050913094, 
       1.201679100459168}, {7.895295050913094, 1.201679100459168}}, {{
       7.895295050913094, 1.201679100459168}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}, {
       7.895295050913094, 1.201679100459168}, {7.895295050913094, 
       1.201679100459168}}, {{7.895295050913094, 1.201679100459168}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}, {7.895295050913094, 1.201679100459168}, {
       7.895295050913094, 1.201679100459168}}, {{7.850707469996177, 
       1.160347952955769}, {7.792619855832213, 1.1423995489401237`}, {
       7.792619855832213, 1.1423995489401237`}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}}, {{
       7.850707469996177, 1.160347952955769}, {7.792619855832213, 
       1.1423995489401237`}, {7.792619855832213, 1.1423995489401237`}, {
       7.850707469996177, 1.160347952955769}, {7.850707469996177, 
       1.160347952955769}}, {{7.850707469996177, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}, {7.850707469996177, 1.160347952955769}, {
       7.850707469996177, 1.160347952955769}}, {{7.850707469996177, 
       1.160347952955769}, {7.792619855832213, 1.1423995489401237`}, {
       7.792619855832213, 1.1423995489401237`}, {7.850707469996177, 
       1.160347952955769}, {7.850707469996177, 1.160347952955769}}, {{
       7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}}, {{7.792619855832213, 1.1423995489401237`}, {
       7.713807209888335, 1.160347952955769}, {7.713807209888335, 
       1.160347952955769}, {7.792619855832213, 1.1423995489401237`}, {
       7.792619855832213, 1.1423995489401237`}}, {{7.792619855832213, 
       1.1423995489401237`}, {7.713807209888335, 1.160347952955769}, {
       7.713807209888335, 1.160347952955769}, {7.792619855832213, 
       1.1423995489401237`}, {7.792619855832213, 1.1423995489401237`}}, {{
       7.792619855832213, 1.1423995489401237`}, {7.713807209888335, 
       1.160347952955769}, {7.713807209888335, 1.160347952955769}, {
       7.792619855832213, 1.1423995489401237`}, {7.792619855832213, 
       1.1423995489401237`}}, {{7.713807209888335, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}, {7.713807209888335, 1.3974661590319457`}, {
       7.713807209888335, 1.3974661590319457`}}, {{7.713807209888335, 
       1.3974661590319457`}, {7.792619855832213, 1.415414563047591}, {
       7.792619855832213, 1.415414563047591}, {7.713807209888335, 
       1.3974661590319457`}, {7.713807209888335, 1.3974661590319457`}}, {{
       7.713807209888335, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}, {
       7.713807209888335, 1.3974661590319457`}, {7.713807209888335, 
       1.3974661590319457`}}, {{7.713807209888335, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}, {7.713807209888335, 1.3974661590319457`}, {
       7.713807209888335, 1.3974661590319457`}}, {{7.792619855832213, 
       1.415414563047591}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}}, {{
       7.792619855832213, 1.415414563047591}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}, {
       7.792619855832213, 1.415414563047591}, {7.792619855832213, 
       1.415414563047591}}, {{7.792619855832213, 1.415414563047591}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}, {7.792619855832213, 1.415414563047591}, {
       7.792619855832213, 1.415414563047591}}, {{7.792619855832213, 
       1.415414563047591}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}, {7.792619855832213, 
       1.415414563047591}, {7.792619855832213, 1.415414563047591}}, {{
       7.850707469996177, 1.3974661590319457`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}, {{7.850707469996177, 1.3974661590319457`}, {
       7.895295050913094, 1.3561350115285467`}, {7.895295050913094, 
       1.3561350115285467`}, {7.850707469996177, 1.3974661590319457`}, {
       7.850707469996177, 1.3974661590319457`}}, {{7.850707469996177, 
       1.3974661590319457`}, {7.895295050913094, 1.3561350115285467`}, {
       7.895295050913094, 1.3561350115285467`}, {7.850707469996177, 
       1.3974661590319457`}, {7.850707469996177, 1.3974661590319457`}}, {{
       7.850707469996177, 1.3974661590319457`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}, {
       7.850707469996177, 1.3974661590319457`}, {7.850707469996177, 
       1.3974661590319457`}}, {{7.895295050913094, 1.3561350115285467`}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}, {7.895295050913094, 1.3561350115285467`}, {
       7.895295050913094, 1.3561350115285467`}}, {{7.895295050913094, 
       1.3561350115285467`}, {7.919157600050098, 1.2789070559938573`}, {
       7.919157600050098, 1.2789070559938573`}, {7.895295050913094, 
       1.3561350115285467`}, {7.895295050913094, 1.3561350115285467`}}, {{
       7.895295050913094, 1.3561350115285467`}, {7.919157600050098, 
       1.2789070559938573`}, {7.919157600050098, 1.2789070559938573`}, {
       7.895295050913094, 1.3561350115285467`}, {7.895295050913094, 
       1.3561350115285467`}}, {{7.895295050913094, 1.3561350115285467`}, {
       7.919157600050098, 1.2789070559938573`}, {7.919157600050098, 
       1.2789070559938573`}, {7.895295050913094, 1.3561350115285467`}, {
       7.895295050913094, 1.3561350115285467`}}, {{7.678070286693334, 
       1.5863329718017225`}, {7.607661131855588, 1.662289582693341}, {
       7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.8142028044765781`}, {7.678070286693334, 1.8901594153681966`}, {
       7.678070286693334, 1.8901594153681966`}, {7.607661131855588, 
       1.8142028044765781`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}}, {{
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}, {{7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.853484565673364, 
       1.5863329718017225`}, {7.779055218729718, 1.5633351604990517`}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}, {7.779055218729718, 1.5633351604990517`}, {
       7.853484565673364, 1.5863329718017225`}, {7.9106159279647414`, 
       1.6392917713906703`}, {7.941191705163379, 1.7382461935849596`}, {
       7.941191705163379, 1.7382461935849596`}}, {{7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}}, {{
       7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.853484565673364, 1.8901594153681966`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379, 
       1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.853484565673364, 
       1.8901594153681966`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}, {{7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}}, {{7.678070286693334, 
       1.5863329718017225`}, {7.607661131855588, 1.662289582693341}, {
       7.607661131855588, 1.662289582693341}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}}, {{
       7.678070286693334, 1.5863329718017225`}, {7.607661131855588, 
       1.662289582693341}, {7.607661131855588, 1.662289582693341}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}}, {{7.678070286693334, 1.5863329718017225`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}, {7.678070286693334, 1.5863329718017225`}, {
       7.678070286693334, 1.5863329718017225`}}, {{7.678070286693334, 
       1.5863329718017225`}, {7.607661131855588, 1.662289582693341}, {
       7.607661131855588, 1.662289582693341}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}}, {{
       7.607661131855588, 1.662289582693341}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}}, {{7.607661131855588, 1.662289582693341}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}, {7.607661131855588, 1.662289582693341}, {
       7.607661131855588, 1.662289582693341}}, {{7.607661131855588, 
       1.662289582693341}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.662289582693341}, {7.607661131855588, 1.662289582693341}}, {{
       7.607661131855588, 1.662289582693341}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.662289582693341}, {7.607661131855588, 
       1.662289582693341}}, {{7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}}, {{7.590363147203319, 
       1.7382461935849596`}, {7.607661131855588, 1.8142028044765781`}, {
       7.607661131855588, 1.8142028044765781`}, {7.590363147203319, 
       1.7382461935849596`}, {7.590363147203319, 1.7382461935849596`}}, {{
       7.590363147203319, 1.7382461935849596`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}, {
       7.590363147203319, 1.7382461935849596`}, {7.590363147203319, 
       1.7382461935849596`}}, {{7.590363147203319, 1.7382461935849596`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}, {7.590363147203319, 1.7382461935849596`}, {
       7.590363147203319, 1.7382461935849596`}}, {{7.607661131855588, 
       1.8142028044765781`}, {7.678070286693334, 1.8901594153681966`}, {
       7.678070286693334, 1.8901594153681966`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}}, {{
       7.607661131855588, 1.8142028044765781`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}, {
       7.607661131855588, 1.8142028044765781`}, {7.607661131855588, 
       1.8142028044765781`}}, {{7.607661131855588, 1.8142028044765781`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}, {7.607661131855588, 1.8142028044765781`}, {
       7.607661131855588, 1.8142028044765781`}}, {{7.607661131855588, 
       1.8142028044765781`}, {7.678070286693334, 1.8901594153681966`}, {
       7.678070286693334, 1.8901594153681966`}, {7.607661131855588, 
       1.8142028044765781`}, {7.607661131855588, 1.8142028044765781`}}, {{
       7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`, 
       1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}, {{7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.9106159279647414`, 
       1.6392917713906703`}, {7.941191705163379, 1.7382461935849596`}, {
       7.941191705163379, 1.7382461935849596`}}, {{7.941191705163379, 
       1.7382461935849596`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.941191705163379, 
       1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}}, {{
       7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`, 
       1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}}, {{7.9106159279647414`, 1.6392917713906703`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.9106159279647414`, 1.6392917713906703`}}, {{7.9106159279647414`, 
       1.6392917713906703`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}, {7.9106159279647414`, 
       1.6392917713906703`}, {7.9106159279647414`, 1.6392917713906703`}}, {{
       7.9106159279647414`, 1.6392917713906703`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}, {
       7.9106159279647414`, 1.6392917713906703`}, {7.9106159279647414`, 
       1.6392917713906703`}}, {{7.9106159279647414`, 1.6392917713906703`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}, {7.9106159279647414`, 1.6392917713906703`}, {
       7.9106159279647414`, 1.6392917713906703`}}, {{7.853484565673364, 
       1.5863329718017225`}, {7.779055218729718, 1.5633351604990517`}, {
       7.779055218729718, 1.5633351604990517`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}}, {{
       7.853484565673364, 1.5863329718017225`}, {7.779055218729718, 
       1.5633351604990517`}, {7.779055218729718, 1.5633351604990517`}, {
       7.853484565673364, 1.5863329718017225`}, {7.853484565673364, 
       1.5863329718017225`}}, {{7.853484565673364, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}, {7.853484565673364, 1.5863329718017225`}, {
       7.853484565673364, 1.5863329718017225`}}, {{7.853484565673364, 
       1.5863329718017225`}, {7.779055218729718, 1.5633351604990517`}, {
       7.779055218729718, 1.5633351604990517`}, {7.853484565673364, 
       1.5863329718017225`}, {7.853484565673364, 1.5863329718017225`}}, {{
       7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}}, {{7.779055218729718, 1.5633351604990517`}, {
       7.678070286693334, 1.5863329718017225`}, {7.678070286693334, 
       1.5863329718017225`}, {7.779055218729718, 1.5633351604990517`}, {
       7.779055218729718, 1.5633351604990517`}}, {{7.779055218729718, 
       1.5633351604990517`}, {7.678070286693334, 1.5863329718017225`}, {
       7.678070286693334, 1.5863329718017225`}, {7.779055218729718, 
       1.5633351604990517`}, {7.779055218729718, 1.5633351604990517`}}, {{
       7.779055218729718, 1.5633351604990517`}, {7.678070286693334, 
       1.5863329718017225`}, {7.678070286693334, 1.5863329718017225`}, {
       7.779055218729718, 1.5633351604990517`}, {7.779055218729718, 
       1.5633351604990517`}}, {{7.678070286693334, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}, {7.678070286693334, 1.8901594153681966`}, {
       7.678070286693334, 1.8901594153681966`}}, {{7.678070286693334, 
       1.8901594153681966`}, {7.779055218729718, 1.9131572266708674`}, {
       7.779055218729718, 1.9131572266708674`}, {7.678070286693334, 
       1.8901594153681966`}, {7.678070286693334, 1.8901594153681966`}}, {{
       7.678070286693334, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}, {
       7.678070286693334, 1.8901594153681966`}, {7.678070286693334, 
       1.8901594153681966`}}, {{7.678070286693334, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}, {7.678070286693334, 1.8901594153681966`}, {
       7.678070286693334, 1.8901594153681966`}}, {{7.779055218729718, 
       1.9131572266708674`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}}, {{
       7.779055218729718, 1.9131572266708674`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}, {
       7.779055218729718, 1.9131572266708674`}, {7.779055218729718, 
       1.9131572266708674`}}, {{7.779055218729718, 1.9131572266708674`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}, {7.779055218729718, 1.9131572266708674`}, {
       7.779055218729718, 1.9131572266708674`}}, {{7.779055218729718, 
       1.9131572266708674`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}, {7.779055218729718, 
       1.9131572266708674`}, {7.779055218729718, 1.9131572266708674`}}, {{
       7.853484565673364, 1.8901594153681966`}, {7.9106159279647414`, 
       1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}, {{7.853484565673364, 1.8901594153681966`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.9106159279647414`, 
       1.8372006157792489`}, {7.853484565673364, 1.8901594153681966`}, {
       7.853484565673364, 1.8901594153681966`}}, {{7.853484565673364, 
       1.8901594153681966`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.853484565673364, 
       1.8901594153681966`}, {7.853484565673364, 1.8901594153681966`}}, {{
       7.853484565673364, 1.8901594153681966`}, {7.9106159279647414`, 
       1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.853484565673364, 1.8901594153681966`}, {7.853484565673364, 
       1.8901594153681966`}}, {{7.9106159279647414`, 1.8372006157792489`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.9106159279647414`, 1.8372006157792489`}}, {{7.9106159279647414`, 
       1.8372006157792489`}, {7.941191705163379, 1.7382461935849596`}, {
       7.941191705163379, 1.7382461935849596`}, {7.9106159279647414`, 
       1.8372006157792489`}, {7.9106159279647414`, 1.8372006157792489`}}, {{
       7.9106159279647414`, 1.8372006157792489`}, {7.941191705163379, 
       1.7382461935849596`}, {7.941191705163379, 1.7382461935849596`}, {
       7.9106159279647414`, 1.8372006157792489`}, {7.9106159279647414`, 
       1.8372006157792489`}}, {{7.9106159279647414`, 1.8372006157792489`}, {
       7.941191705163379, 1.7382461935849596`}, {7.941191705163379, 
       1.7382461935849596`}, {7.9106159279647414`, 1.8372006157792489`}, {
       7.9106159279647414`, 1.8372006157792489`}}, {{7.663608688411636, 
       2.14497482286346}, {7.5992516015753955`, 2.214402530300133}, {
       7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.663608688411636, 2.4226856526101517`}, {
       7.663608688411636, 2.4226856526101517`}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}}, {{
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}, {{7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.193381511904724}, {7.8239451107227636`, 
       2.14497482286346}, {7.7559133901964294`, 2.123953804468051}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}, {7.7559133901964294`, 2.123953804468051}, {
       7.8239451107227636`, 2.14497482286346}, {7.876165706929775, 
       2.193381511904724}, {7.904113321878326, 2.283830237736806}, {
       7.904113321878326, 2.283830237736806}}, {{7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}}, {{
       7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`, 
       2.4437066710055606`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}, {{7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}}, {{7.663608688411636, 
       2.14497482286346}, {7.5992516015753955`, 2.214402530300133}, {
       7.5992516015753955`, 2.214402530300133}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}}, {{
       7.663608688411636, 2.14497482286346}, {7.5992516015753955`, 
       2.214402530300133}, {7.5992516015753955`, 2.214402530300133}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}}, {{7.663608688411636, 2.14497482286346}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}, {7.663608688411636, 2.14497482286346}, {
       7.663608688411636, 2.14497482286346}}, {{7.663608688411636, 
       2.14497482286346}, {7.5992516015753955`, 2.214402530300133}, {
       7.5992516015753955`, 2.214402530300133}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}}, {{
       7.5992516015753955`, 2.214402530300133}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}}, {{7.5992516015753955`, 2.214402530300133}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}, {7.5992516015753955`, 2.214402530300133}, {
       7.5992516015753955`, 2.214402530300133}}, {{7.5992516015753955`, 
       2.214402530300133}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.214402530300133}, {7.5992516015753955`, 2.214402530300133}}, {{
       7.5992516015753955`, 2.214402530300133}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.214402530300133}, {7.5992516015753955`, 
       2.214402530300133}}, {{7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}}, {{7.583440477256073, 
       2.283830237736806}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.583440477256073, 
       2.283830237736806}, {7.583440477256073, 2.283830237736806}}, {{
       7.583440477256073, 2.283830237736806}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.583440477256073, 2.283830237736806}, {7.583440477256073, 
       2.283830237736806}}, {{7.583440477256073, 2.283830237736806}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.583440477256073, 2.283830237736806}, {
       7.583440477256073, 2.283830237736806}}, {{7.5992516015753955`, 
       2.3532579451734787`}, {7.663608688411636, 2.4226856526101517`}, {
       7.663608688411636, 2.4226856526101517`}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}}, {{
       7.5992516015753955`, 2.3532579451734787`}, {7.663608688411636, 
       2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}, {
       7.5992516015753955`, 2.3532579451734787`}, {7.5992516015753955`, 
       2.3532579451734787`}}, {{7.5992516015753955`, 2.3532579451734787`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}, {7.5992516015753955`, 2.3532579451734787`}, {
       7.5992516015753955`, 2.3532579451734787`}}, {{7.5992516015753955`, 
       2.3532579451734787`}, {7.663608688411636, 2.4226856526101517`}, {
       7.663608688411636, 2.4226856526101517`}, {7.5992516015753955`, 
       2.3532579451734787`}, {7.5992516015753955`, 2.3532579451734787`}}, {{
       7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}, {{7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.193381511904724}, {7.876165706929775, 
       2.193381511904724}, {7.904113321878326, 2.283830237736806}, {
       7.904113321878326, 2.283830237736806}}, {{7.904113321878326, 
       2.283830237736806}, {7.876165706929775, 2.193381511904724}, {
       7.876165706929775, 2.193381511904724}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}}, {{
       7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}}, {{7.876165706929775, 2.193381511904724}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.876165706929775, 2.193381511904724}, {
       7.876165706929775, 2.193381511904724}}, {{7.876165706929775, 
       2.193381511904724}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}, {7.876165706929775, 
       2.193381511904724}, {7.876165706929775, 2.193381511904724}}, {{
       7.876165706929775, 2.193381511904724}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}, {
       7.876165706929775, 2.193381511904724}, {7.876165706929775, 
       2.193381511904724}}, {{7.876165706929775, 2.193381511904724}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}, {7.876165706929775, 2.193381511904724}, {
       7.876165706929775, 2.193381511904724}}, {{7.8239451107227636`, 
       2.14497482286346}, {7.7559133901964294`, 2.123953804468051}, {
       7.7559133901964294`, 2.123953804468051}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}}, {{
       7.8239451107227636`, 2.14497482286346}, {7.7559133901964294`, 
       2.123953804468051}, {7.7559133901964294`, 2.123953804468051}, {
       7.8239451107227636`, 2.14497482286346}, {7.8239451107227636`, 
       2.14497482286346}}, {{7.8239451107227636`, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}, {7.8239451107227636`, 2.14497482286346}, {
       7.8239451107227636`, 2.14497482286346}}, {{7.8239451107227636`, 
       2.14497482286346}, {7.7559133901964294`, 2.123953804468051}, {
       7.7559133901964294`, 2.123953804468051}, {7.8239451107227636`, 
       2.14497482286346}, {7.8239451107227636`, 2.14497482286346}}, {{
       7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}}, {{7.7559133901964294`, 2.123953804468051}, {
       7.663608688411636, 2.14497482286346}, {7.663608688411636, 
       2.14497482286346}, {7.7559133901964294`, 2.123953804468051}, {
       7.7559133901964294`, 2.123953804468051}}, {{7.7559133901964294`, 
       2.123953804468051}, {7.663608688411636, 2.14497482286346}, {
       7.663608688411636, 2.14497482286346}, {7.7559133901964294`, 
       2.123953804468051}, {7.7559133901964294`, 2.123953804468051}}, {{
       7.7559133901964294`, 2.123953804468051}, {7.663608688411636, 
       2.14497482286346}, {7.663608688411636, 2.14497482286346}, {
       7.7559133901964294`, 2.123953804468051}, {7.7559133901964294`, 
       2.123953804468051}}, {{7.663608688411636, 2.4226856526101517`}, {
       7.7559133901964294`, 2.4437066710055606`}, {7.7559133901964294`, 
       2.4437066710055606`}, {7.663608688411636, 2.4226856526101517`}, {
       7.663608688411636, 2.4226856526101517`}}, {{7.663608688411636, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.7559133901964294`, 2.4437066710055606`}, {7.663608688411636, 
       2.4226856526101517`}, {7.663608688411636, 2.4226856526101517`}}, {{
       7.663608688411636, 2.4226856526101517`}, {7.7559133901964294`, 
       2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.663608688411636, 2.4226856526101517`}, {7.663608688411636, 
       2.4226856526101517`}}, {{7.663608688411636, 2.4226856526101517`}, {
       7.7559133901964294`, 2.4437066710055606`}, {7.7559133901964294`, 
       2.4437066710055606`}, {7.663608688411636, 2.4226856526101517`}, {
       7.663608688411636, 2.4226856526101517`}}, {{7.7559133901964294`, 
       2.4437066710055606`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.7559133901964294`, 
       2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}}, {{
       7.7559133901964294`, 2.4437066710055606`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.7559133901964294`, 2.4437066710055606`}, {7.7559133901964294`, 
       2.4437066710055606`}}, {{7.7559133901964294`, 2.4437066710055606`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.7559133901964294`, 2.4437066710055606`}, {
       7.7559133901964294`, 2.4437066710055606`}}, {{7.7559133901964294`, 
       2.4437066710055606`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.7559133901964294`, 
       2.4437066710055606`}, {7.7559133901964294`, 2.4437066710055606`}}, {{
       7.8239451107227636`, 2.4226856526101517`}, {7.876165706929775, 
       2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}}, {{7.8239451107227636`, 2.4226856526101517`}, {
       7.876165706929775, 2.3742789635688877`}, {7.876165706929775, 
       2.3742789635688877`}, {7.8239451107227636`, 2.4226856526101517`}, {
       7.8239451107227636`, 2.4226856526101517`}}, {{7.8239451107227636`, 
       2.4226856526101517`}, {7.876165706929775, 2.3742789635688877`}, {
       7.876165706929775, 2.3742789635688877`}, {7.8239451107227636`, 
       2.4226856526101517`}, {7.8239451107227636`, 2.4226856526101517`}}, {{
       7.8239451107227636`, 2.4226856526101517`}, {7.876165706929775, 
       2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}, {
       7.8239451107227636`, 2.4226856526101517`}, {7.8239451107227636`, 
       2.4226856526101517`}}, {{7.876165706929775, 2.3742789635688877`}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}, {7.876165706929775, 2.3742789635688877`}, {
       7.876165706929775, 2.3742789635688877`}}, {{7.876165706929775, 
       2.3742789635688877`}, {7.904113321878326, 2.283830237736806}, {
       7.904113321878326, 2.283830237736806}, {7.876165706929775, 
       2.3742789635688877`}, {7.876165706929775, 2.3742789635688877`}}, {{
       7.876165706929775, 2.3742789635688877`}, {7.904113321878326, 
       2.283830237736806}, {7.904113321878326, 2.283830237736806}, {
       7.876165706929775, 2.3742789635688877`}, {7.876165706929775, 
       2.3742789635688877`}}, {{7.876165706929775, 2.3742789635688877`}, {
       7.904113321878326, 2.283830237736806}, {7.904113321878326, 
       2.283830237736806}, {7.876165706929775, 2.3742789635688877`}, {
       7.876165706929775, 2.3742789635688877`}}, {{7.664080670570853, 
       2.6647525776017082`}, {7.606638887494376, 2.7267201324760033`}, {
       7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.8506552422245934`}, {7.664080670570853, 2.9126227970988885`}, {
       7.664080670570853, 2.9126227970988885`}, {7.606638887494376, 
       2.8506552422245934`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}}, {{
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}, {{7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.707957866530246}, {7.807188608521643, 
       2.6647525776017082`}, {7.746467038840638, 2.645990311655951}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}, {7.746467038840638, 2.645990311655951}, {
       7.807188608521643, 2.6647525776017082`}, {7.85379799230373, 
       2.707957866530246}, {7.878742577497037, 2.7886876873502984`}, {
       7.878742577497037, 2.7886876873502984`}}, {{7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}}, {{
       7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.807188608521643, 2.9126227970988885`}, {
       7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.807188608521643, 
       2.9126227970988885`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}, {{7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}}, {{7.664080670570853, 
       2.6647525776017082`}, {7.606638887494376, 2.7267201324760033`}, {
       7.606638887494376, 2.7267201324760033`}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}}, {{
       7.664080670570853, 2.6647525776017082`}, {7.606638887494376, 
       2.7267201324760033`}, {7.606638887494376, 2.7267201324760033`}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}}, {{7.664080670570853, 2.6647525776017082`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}, {7.664080670570853, 2.6647525776017082`}, {
       7.664080670570853, 2.6647525776017082`}}, {{7.664080670570853, 
       2.6647525776017082`}, {7.606638887494376, 2.7267201324760033`}, {
       7.606638887494376, 2.7267201324760033`}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}}, {{
       7.606638887494376, 2.7267201324760033`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}}, {{7.606638887494376, 2.7267201324760033`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}, {7.606638887494376, 2.7267201324760033`}, {
       7.606638887494376, 2.7267201324760033`}}, {{7.606638887494376, 
       2.7267201324760033`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.7267201324760033`}, {7.606638887494376, 2.7267201324760033`}}, {{
       7.606638887494376, 2.7267201324760033`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.7267201324760033`}, {7.606638887494376, 
       2.7267201324760033`}}, {{7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}}, {{7.592526701595459, 
       2.7886876873502984`}, {7.606638887494376, 2.8506552422245934`}, {
       7.606638887494376, 2.8506552422245934`}, {7.592526701595459, 
       2.7886876873502984`}, {7.592526701595459, 2.7886876873502984`}}, {{
       7.592526701595459, 2.7886876873502984`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}, {
       7.592526701595459, 2.7886876873502984`}, {7.592526701595459, 
       2.7886876873502984`}}, {{7.592526701595459, 2.7886876873502984`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}, {7.592526701595459, 2.7886876873502984`}, {
       7.592526701595459, 2.7886876873502984`}}, {{7.606638887494376, 
       2.8506552422245934`}, {7.664080670570853, 2.9126227970988885`}, {
       7.664080670570853, 2.9126227970988885`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}}, {{
       7.606638887494376, 2.8506552422245934`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}, {
       7.606638887494376, 2.8506552422245934`}, {7.606638887494376, 
       2.8506552422245934`}}, {{7.606638887494376, 2.8506552422245934`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}, {7.606638887494376, 2.8506552422245934`}, {
       7.606638887494376, 2.8506552422245934`}}, {{7.606638887494376, 
       2.8506552422245934`}, {7.664080670570853, 2.9126227970988885`}, {
       7.664080670570853, 2.9126227970988885`}, {7.606638887494376, 
       2.8506552422245934`}, {7.606638887494376, 2.8506552422245934`}}, {{
       7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}, {{7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.707957866530246}, {7.85379799230373, 
       2.707957866530246}, {7.878742577497037, 2.7886876873502984`}, {
       7.878742577497037, 2.7886876873502984`}}, {{7.878742577497037, 
       2.7886876873502984`}, {7.85379799230373, 2.707957866530246}, {
       7.85379799230373, 2.707957866530246}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}}, {{
       7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}}, {{7.85379799230373, 2.707957866530246}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.85379799230373, 2.707957866530246}, {
       7.85379799230373, 2.707957866530246}}, {{7.85379799230373, 
       2.707957866530246}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}, {7.85379799230373, 
       2.707957866530246}, {7.85379799230373, 2.707957866530246}}, {{
       7.85379799230373, 2.707957866530246}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}, {
       7.85379799230373, 2.707957866530246}, {7.85379799230373, 
       2.707957866530246}}, {{7.85379799230373, 2.707957866530246}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}, {7.85379799230373, 2.707957866530246}, {
       7.85379799230373, 2.707957866530246}}, {{7.807188608521643, 
       2.6647525776017082`}, {7.746467038840638, 2.645990311655951}, {
       7.746467038840638, 2.645990311655951}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}}, {{
       7.807188608521643, 2.6647525776017082`}, {7.746467038840638, 
       2.645990311655951}, {7.746467038840638, 2.645990311655951}, {
       7.807188608521643, 2.6647525776017082`}, {7.807188608521643, 
       2.6647525776017082`}}, {{7.807188608521643, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}, {7.807188608521643, 2.6647525776017082`}, {
       7.807188608521643, 2.6647525776017082`}}, {{7.807188608521643, 
       2.6647525776017082`}, {7.746467038840638, 2.645990311655951}, {
       7.746467038840638, 2.645990311655951}, {7.807188608521643, 
       2.6647525776017082`}, {7.807188608521643, 2.6647525776017082`}}, {{
       7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}}, {{7.746467038840638, 2.645990311655951}, {
       7.664080670570853, 2.6647525776017082`}, {7.664080670570853, 
       2.6647525776017082`}, {7.746467038840638, 2.645990311655951}, {
       7.746467038840638, 2.645990311655951}}, {{7.746467038840638, 
       2.645990311655951}, {7.664080670570853, 2.6647525776017082`}, {
       7.664080670570853, 2.6647525776017082`}, {7.746467038840638, 
       2.645990311655951}, {7.746467038840638, 2.645990311655951}}, {{
       7.746467038840638, 2.645990311655951}, {7.664080670570853, 
       2.6647525776017082`}, {7.664080670570853, 2.6647525776017082`}, {
       7.746467038840638, 2.645990311655951}, {7.746467038840638, 
       2.645990311655951}}, {{7.664080670570853, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}, {7.664080670570853, 2.9126227970988885`}, {
       7.664080670570853, 2.9126227970988885`}}, {{7.664080670570853, 
       2.9126227970988885`}, {7.746467038840638, 2.9313850630446456`}, {
       7.746467038840638, 2.9313850630446456`}, {7.664080670570853, 
       2.9126227970988885`}, {7.664080670570853, 2.9126227970988885`}}, {{
       7.664080670570853, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}, {
       7.664080670570853, 2.9126227970988885`}, {7.664080670570853, 
       2.9126227970988885`}}, {{7.664080670570853, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}, {7.664080670570853, 2.9126227970988885`}, {
       7.664080670570853, 2.9126227970988885`}}, {{7.746467038840638, 
       2.9313850630446456`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}}, {{
       7.746467038840638, 2.9313850630446456`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}, {
       7.746467038840638, 2.9313850630446456`}, {7.746467038840638, 
       2.9313850630446456`}}, {{7.746467038840638, 2.9313850630446456`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}, {7.746467038840638, 2.9313850630446456`}, {
       7.746467038840638, 2.9313850630446456`}}, {{7.746467038840638, 
       2.9313850630446456`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}, {7.746467038840638, 
       2.9313850630446456`}, {7.746467038840638, 2.9313850630446456`}}, {{
       7.807188608521643, 2.9126227970988885`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}, {{7.807188608521643, 2.9126227970988885`}, {
       7.85379799230373, 2.8694175081703506`}, {7.85379799230373, 
       2.8694175081703506`}, {7.807188608521643, 2.9126227970988885`}, {
       7.807188608521643, 2.9126227970988885`}}, {{7.807188608521643, 
       2.9126227970988885`}, {7.85379799230373, 2.8694175081703506`}, {
       7.85379799230373, 2.8694175081703506`}, {7.807188608521643, 
       2.9126227970988885`}, {7.807188608521643, 2.9126227970988885`}}, {{
       7.807188608521643, 2.9126227970988885`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}, {
       7.807188608521643, 2.9126227970988885`}, {7.807188608521643, 
       2.9126227970988885`}}, {{7.85379799230373, 2.8694175081703506`}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}, {7.85379799230373, 2.8694175081703506`}, {
       7.85379799230373, 2.8694175081703506`}}, {{7.85379799230373, 
       2.8694175081703506`}, {7.878742577497037, 2.7886876873502984`}, {
       7.878742577497037, 2.7886876873502984`}, {7.85379799230373, 
       2.8694175081703506`}, {7.85379799230373, 2.8694175081703506`}}, {{
       7.85379799230373, 2.8694175081703506`}, {7.878742577497037, 
       2.7886876873502984`}, {7.878742577497037, 2.7886876873502984`}, {
       7.85379799230373, 2.8694175081703506`}, {7.85379799230373, 
       2.8694175081703506`}}, {{7.85379799230373, 2.8694175081703506`}, {
       7.878742577497037, 2.7886876873502984`}, {7.878742577497037, 
       2.7886876873502984`}, {7.85379799230373, 2.8694175081703506`}, {
       7.85379799230373, 2.8694175081703506`}}, {{7.655264752380455, 
       3.1259444234816263`}, {7.593448720964602, 3.192630868673848}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602, 
       3.326003759058291}, {7.655264752380455, 3.3926902042505125`}, {
       7.655264752380455, 3.3926902042505125`}, {7.593448720964602, 
       3.326003759058291}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}}, {{
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}}, {{7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.172439837702693}, {7.809270500712569, 
       3.1259444234816263`}, {7.743924923712924, 3.1057533925104717`}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}, {7.743924923712924, 3.1057533925104717`}, {
       7.809270500712569, 3.1259444234816263`}, {7.859429234962009, 
       3.172439837702693}, {7.886273374878625, 3.2593173138660694`}, {
       7.886273374878625, 3.2593173138660694`}}, {{7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}}, {{
       7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.809270500712569, 3.3926902042505125`}, {
       7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.809270500712569, 
       3.3926902042505125`}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}, {{7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}}, {{7.655264752380455, 
       3.1259444234816263`}, {7.593448720964602, 3.192630868673848}, {
       7.593448720964602, 3.192630868673848}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}}, {{
       7.655264752380455, 3.1259444234816263`}, {7.593448720964602, 
       3.192630868673848}, {7.593448720964602, 3.192630868673848}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}}, {{7.655264752380455, 3.1259444234816263`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}, {7.655264752380455, 3.1259444234816263`}, {
       7.655264752380455, 3.1259444234816263`}}, {{7.655264752380455, 
       3.1259444234816263`}, {7.593448720964602, 3.192630868673848}, {
       7.593448720964602, 3.192630868673848}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}}, {{
       7.593448720964602, 3.192630868673848}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}}, {{7.593448720964602, 3.192630868673848}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.593448720964602, 3.192630868673848}, {
       7.593448720964602, 3.192630868673848}}, {{7.593448720964602, 
       3.192630868673848}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602, 
       3.192630868673848}, {7.593448720964602, 3.192630868673848}}, {{
       7.593448720964602, 3.192630868673848}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.192630868673848}, {7.593448720964602, 
       3.192630868673848}}, {{7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}}, {{7.5782618782143985`, 
       3.2593173138660694`}, {7.593448720964602, 3.326003759058291}, {
       7.593448720964602, 3.326003759058291}, {7.5782618782143985`, 
       3.2593173138660694`}, {7.5782618782143985`, 3.2593173138660694`}}, {{
       7.5782618782143985`, 3.2593173138660694`}, {7.593448720964602, 
       3.326003759058291}, {7.593448720964602, 3.326003759058291}, {
       7.5782618782143985`, 3.2593173138660694`}, {7.5782618782143985`, 
       3.2593173138660694`}}, {{7.5782618782143985`, 3.2593173138660694`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}, {7.5782618782143985`, 3.2593173138660694`}, {
       7.5782618782143985`, 3.2593173138660694`}}, {{7.593448720964602, 
       3.326003759058291}, {7.655264752380455, 3.3926902042505125`}, {
       7.655264752380455, 3.3926902042505125`}, {7.593448720964602, 
       3.326003759058291}, {7.593448720964602, 3.326003759058291}}, {{
       7.593448720964602, 3.326003759058291}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}, {
       7.593448720964602, 3.326003759058291}, {7.593448720964602, 
       3.326003759058291}}, {{7.593448720964602, 3.326003759058291}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}, {7.593448720964602, 3.326003759058291}, {
       7.593448720964602, 3.326003759058291}}, {{7.593448720964602, 
       3.326003759058291}, {7.655264752380455, 3.3926902042505125`}, {
       7.655264752380455, 3.3926902042505125`}, {7.593448720964602, 
       3.326003759058291}, {7.593448720964602, 3.326003759058291}}, {{
       7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}, {{7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.172439837702693}, {7.859429234962009, 
       3.172439837702693}, {7.886273374878625, 3.2593173138660694`}, {
       7.886273374878625, 3.2593173138660694`}}, {{7.886273374878625, 
       3.2593173138660694`}, {7.859429234962009, 3.172439837702693}, {
       7.859429234962009, 3.172439837702693}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}}, {{
       7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}}, {{7.859429234962009, 3.172439837702693}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.859429234962009, 3.172439837702693}, {
       7.859429234962009, 3.172439837702693}}, {{7.859429234962009, 
       3.172439837702693}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}, {7.859429234962009, 
       3.172439837702693}, {7.859429234962009, 3.172439837702693}}, {{
       7.859429234962009, 3.172439837702693}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}, {
       7.859429234962009, 3.172439837702693}, {7.859429234962009, 
       3.172439837702693}}, {{7.859429234962009, 3.172439837702693}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}, {7.859429234962009, 3.172439837702693}, {
       7.859429234962009, 3.172439837702693}}, {{7.809270500712569, 
       3.1259444234816263`}, {7.743924923712924, 3.1057533925104717`}, {
       7.743924923712924, 3.1057533925104717`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}}, {{
       7.809270500712569, 3.1259444234816263`}, {7.743924923712924, 
       3.1057533925104717`}, {7.743924923712924, 3.1057533925104717`}, {
       7.809270500712569, 3.1259444234816263`}, {7.809270500712569, 
       3.1259444234816263`}}, {{7.809270500712569, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}, {7.809270500712569, 3.1259444234816263`}, {
       7.809270500712569, 3.1259444234816263`}}, {{7.809270500712569, 
       3.1259444234816263`}, {7.743924923712924, 3.1057533925104717`}, {
       7.743924923712924, 3.1057533925104717`}, {7.809270500712569, 
       3.1259444234816263`}, {7.809270500712569, 3.1259444234816263`}}, {{
       7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}}, {{7.743924923712924, 3.1057533925104717`}, {
       7.655264752380455, 3.1259444234816263`}, {7.655264752380455, 
       3.1259444234816263`}, {7.743924923712924, 3.1057533925104717`}, {
       7.743924923712924, 3.1057533925104717`}}, {{7.743924923712924, 
       3.1057533925104717`}, {7.655264752380455, 3.1259444234816263`}, {
       7.655264752380455, 3.1259444234816263`}, {7.743924923712924, 
       3.1057533925104717`}, {7.743924923712924, 3.1057533925104717`}}, {{
       7.743924923712924, 3.1057533925104717`}, {7.655264752380455, 
       3.1259444234816263`}, {7.655264752380455, 3.1259444234816263`}, {
       7.743924923712924, 3.1057533925104717`}, {7.743924923712924, 
       3.1057533925104717`}}, {{7.655264752380455, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}, {7.655264752380455, 3.3926902042505125`}, {
       7.655264752380455, 3.3926902042505125`}}, {{7.655264752380455, 
       3.3926902042505125`}, {7.743924923712924, 3.412881235221667}, {
       7.743924923712924, 3.412881235221667}, {7.655264752380455, 
       3.3926902042505125`}, {7.655264752380455, 3.3926902042505125`}}, {{
       7.655264752380455, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}, {
       7.655264752380455, 3.3926902042505125`}, {7.655264752380455, 
       3.3926902042505125`}}, {{7.655264752380455, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}, {7.655264752380455, 3.3926902042505125`}, {
       7.655264752380455, 3.3926902042505125`}}, {{7.743924923712924, 
       3.412881235221667}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}}, {{
       7.743924923712924, 3.412881235221667}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}, {
       7.743924923712924, 3.412881235221667}, {7.743924923712924, 
       3.412881235221667}}, {{7.743924923712924, 3.412881235221667}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}, {7.743924923712924, 3.412881235221667}, {
       7.743924923712924, 3.412881235221667}}, {{7.743924923712924, 
       3.412881235221667}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}, {7.743924923712924, 
       3.412881235221667}, {7.743924923712924, 3.412881235221667}}, {{
       7.809270500712569, 3.3926902042505125`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}, {{7.809270500712569, 3.3926902042505125`}, {
       7.859429234962009, 3.3461947900294455`}, {7.859429234962009, 
       3.3461947900294455`}, {7.809270500712569, 3.3926902042505125`}, {
       7.809270500712569, 3.3926902042505125`}}, {{7.809270500712569, 
       3.3926902042505125`}, {7.859429234962009, 3.3461947900294455`}, {
       7.859429234962009, 3.3461947900294455`}, {7.809270500712569, 
       3.3926902042505125`}, {7.809270500712569, 3.3926902042505125`}}, {{
       7.809270500712569, 3.3926902042505125`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}, {
       7.809270500712569, 3.3926902042505125`}, {7.809270500712569, 
       3.3926902042505125`}}, {{7.859429234962009, 3.3461947900294455`}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}, {7.859429234962009, 3.3461947900294455`}, {
       7.859429234962009, 3.3461947900294455`}}, {{7.859429234962009, 
       3.3461947900294455`}, {7.886273374878625, 3.2593173138660694`}, {
       7.886273374878625, 3.2593173138660694`}, {7.859429234962009, 
       3.3461947900294455`}, {7.859429234962009, 3.3461947900294455`}}, {{
       7.859429234962009, 3.3461947900294455`}, {7.886273374878625, 
       3.2593173138660694`}, {7.886273374878625, 3.2593173138660694`}, {
       7.859429234962009, 3.3461947900294455`}, {7.859429234962009, 
       3.3461947900294455`}}, {{7.859429234962009, 3.3461947900294455`}, {
       7.886273374878625, 3.2593173138660694`}, {7.886273374878625, 
       3.2593173138660694`}, {7.859429234962009, 3.3461947900294455`}, {
       7.859429234962009, 3.3461947900294455`}}, {{7.693697229417213, 
       3.6004977876752533`}, {7.628263807688373, 3.6710866331885676`}, {
       7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.8122643242151963`}, {7.693697229417213, 3.8828531697285107`}, {
       7.693697229417213, 3.8828531697285107`}, {7.628263807688373, 
       3.8122643242151963`}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}}, {{
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}, {{7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.856715185252801, 
       3.6004977876752533`}, {7.787545673719978, 3.5791252049581943`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}, {7.787545673719978, 3.5791252049581943`}, {
       7.856715185252801, 3.6004977876752533`}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.938224163170594, 3.741675478701882}, {
       7.938224163170594, 3.741675478701882}}, {{7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}}, {{
       7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.856715185252801, 3.8828531697285107`}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594, 
       3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.856715185252801, 
       3.8828531697285107`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}, {{7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}}, {{7.693697229417213, 
       3.6004977876752533`}, {7.628263807688373, 3.6710866331885676`}, {
       7.628263807688373, 3.6710866331885676`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}}, {{
       7.693697229417213, 3.6004977876752533`}, {7.628263807688373, 
       3.6710866331885676`}, {7.628263807688373, 3.6710866331885676`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}}, {{7.693697229417213, 3.6004977876752533`}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}, {7.693697229417213, 3.6004977876752533`}, {
       7.693697229417213, 3.6004977876752533`}}, {{7.693697229417213, 
       3.6004977876752533`}, {7.628263807688373, 3.6710866331885676`}, {
       7.628263807688373, 3.6710866331885676`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}}, {{
       7.628263807688373, 3.6710866331885676`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}}, {{7.628263807688373, 3.6710866331885676`}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}, {7.628263807688373, 3.6710866331885676`}, {
       7.628263807688373, 3.6710866331885676`}}, {{7.628263807688373, 
       3.6710866331885676`}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.6710866331885676`}, {7.628263807688373, 3.6710866331885676`}}, {{
       7.628263807688373, 3.6710866331885676`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.6710866331885676`}, {7.628263807688373, 
       3.6710866331885676`}}, {{7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}}, {{7.612188251499419, 
       3.741675478701882}, {7.628263807688373, 3.8122643242151963`}, {
       7.628263807688373, 3.8122643242151963`}, {7.612188251499419, 
       3.741675478701882}, {7.612188251499419, 3.741675478701882}}, {{
       7.612188251499419, 3.741675478701882}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}, {
       7.612188251499419, 3.741675478701882}, {7.612188251499419, 
       3.741675478701882}}, {{7.612188251499419, 3.741675478701882}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}, {7.612188251499419, 3.741675478701882}, {
       7.612188251499419, 3.741675478701882}}, {{7.628263807688373, 
       3.8122643242151963`}, {7.693697229417213, 3.8828531697285107`}, {
       7.693697229417213, 3.8828531697285107`}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}}, {{
       7.628263807688373, 3.8122643242151963`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}, {
       7.628263807688373, 3.8122643242151963`}, {7.628263807688373, 
       3.8122643242151963`}}, {{7.628263807688373, 3.8122643242151963`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}, {7.628263807688373, 3.8122643242151963`}, {
       7.628263807688373, 3.8122643242151963`}}, {{7.628263807688373, 
       3.8122643242151963`}, {7.693697229417213, 3.8828531697285107`}, {
       7.693697229417213, 3.8828531697285107`}, {7.628263807688373, 
       3.8122643242151963`}, {7.628263807688373, 3.8122643242151963`}}, {{
       7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}, {{7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.938224163170594, 3.741675478701882}, {
       7.938224163170594, 3.741675478701882}}, {{7.938224163170594, 
       3.741675478701882}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.938224163170594, 
       3.741675478701882}, {7.938224163170594, 3.741675478701882}}, {{
       7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}}, {{7.9098091405966695`, 3.6497140504715087`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.9098091405966695`, 3.6497140504715087`}}, {{7.9098091405966695`, 
       3.6497140504715087`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}, {7.9098091405966695`, 
       3.6497140504715087`}, {7.9098091405966695`, 3.6497140504715087`}}, {{
       7.9098091405966695`, 3.6497140504715087`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}, {
       7.9098091405966695`, 3.6497140504715087`}, {7.9098091405966695`, 
       3.6497140504715087`}}, {{7.9098091405966695`, 3.6497140504715087`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}, {7.9098091405966695`, 3.6497140504715087`}, {
       7.9098091405966695`, 3.6497140504715087`}}, {{7.856715185252801, 
       3.6004977876752533`}, {7.787545673719978, 3.5791252049581943`}, {
       7.787545673719978, 3.5791252049581943`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}}, {{
       7.856715185252801, 3.6004977876752533`}, {7.787545673719978, 
       3.5791252049581943`}, {7.787545673719978, 3.5791252049581943`}, {
       7.856715185252801, 3.6004977876752533`}, {7.856715185252801, 
       3.6004977876752533`}}, {{7.856715185252801, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}, {7.856715185252801, 3.6004977876752533`}, {
       7.856715185252801, 3.6004977876752533`}}, {{7.856715185252801, 
       3.6004977876752533`}, {7.787545673719978, 3.5791252049581943`}, {
       7.787545673719978, 3.5791252049581943`}, {7.856715185252801, 
       3.6004977876752533`}, {7.856715185252801, 3.6004977876752533`}}, {{
       7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}}, {{7.787545673719978, 3.5791252049581943`}, {
       7.693697229417213, 3.6004977876752533`}, {7.693697229417213, 
       3.6004977876752533`}, {7.787545673719978, 3.5791252049581943`}, {
       7.787545673719978, 3.5791252049581943`}}, {{7.787545673719978, 
       3.5791252049581943`}, {7.693697229417213, 3.6004977876752533`}, {
       7.693697229417213, 3.6004977876752533`}, {7.787545673719978, 
       3.5791252049581943`}, {7.787545673719978, 3.5791252049581943`}}, {{
       7.787545673719978, 3.5791252049581943`}, {7.693697229417213, 
       3.6004977876752533`}, {7.693697229417213, 3.6004977876752533`}, {
       7.787545673719978, 3.5791252049581943`}, {7.787545673719978, 
       3.5791252049581943`}}, {{7.693697229417213, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}, {7.693697229417213, 3.8828531697285107`}, {
       7.693697229417213, 3.8828531697285107`}}, {{7.693697229417213, 
       3.8828531697285107`}, {7.787545673719978, 3.9042257524455697`}, {
       7.787545673719978, 3.9042257524455697`}, {7.693697229417213, 
       3.8828531697285107`}, {7.693697229417213, 3.8828531697285107`}}, {{
       7.693697229417213, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}, {
       7.693697229417213, 3.8828531697285107`}, {7.693697229417213, 
       3.8828531697285107`}}, {{7.693697229417213, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}, {7.693697229417213, 3.8828531697285107`}, {
       7.693697229417213, 3.8828531697285107`}}, {{7.787545673719978, 
       3.9042257524455697`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}}, {{
       7.787545673719978, 3.9042257524455697`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}, {
       7.787545673719978, 3.9042257524455697`}, {7.787545673719978, 
       3.9042257524455697`}}, {{7.787545673719978, 3.9042257524455697`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}, {7.787545673719978, 3.9042257524455697`}, {
       7.787545673719978, 3.9042257524455697`}}, {{7.787545673719978, 
       3.9042257524455697`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}, {7.787545673719978, 
       3.9042257524455697`}, {7.787545673719978, 3.9042257524455697`}}, {{
       7.856715185252801, 3.8828531697285107`}, {7.9098091405966695`, 
       3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}, {{7.856715185252801, 3.8828531697285107`}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.9098091405966695`, 
       3.8336369069322553`}, {7.856715185252801, 3.8828531697285107`}, {
       7.856715185252801, 3.8828531697285107`}}, {{7.856715185252801, 
       3.8828531697285107`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.856715185252801, 
       3.8828531697285107`}, {7.856715185252801, 3.8828531697285107`}}, {{
       7.856715185252801, 3.8828531697285107`}, {7.9098091405966695`, 
       3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.856715185252801, 3.8828531697285107`}, {7.856715185252801, 
       3.8828531697285107`}}, {{7.9098091405966695`, 3.8336369069322553`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.9098091405966695`, 3.8336369069322553`}}, {{7.9098091405966695`, 
       3.8336369069322553`}, {7.938224163170594, 3.741675478701882}, {
       7.938224163170594, 3.741675478701882}, {7.9098091405966695`, 
       3.8336369069322553`}, {7.9098091405966695`, 3.8336369069322553`}}, {{
       7.9098091405966695`, 3.8336369069322553`}, {7.938224163170594, 
       3.741675478701882}, {7.938224163170594, 3.741675478701882}, {
       7.9098091405966695`, 3.8336369069322553`}, {7.9098091405966695`, 
       3.8336369069322553`}}, {{7.9098091405966695`, 3.8336369069322553`}, {
       7.938224163170594, 3.741675478701882}, {7.938224163170594, 
       3.741675478701882}, {7.9098091405966695`, 3.8336369069322553`}, {
       7.9098091405966695`, 3.8336369069322553`}}, {{
       7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}, {{
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}, {{
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}, {{
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}, {{
       7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       7.9976736607424375`, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}, {{
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}, {{
       7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}, {{
       7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}, {{
       7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}, {{
       7.898840023619446, -4.651282724699994}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}}, {{
       7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}, {{
       7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}, {{
       7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}, {{
       7.829930804005741, -4.576944227197716}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.576944227197716}, {
       7.829930804005741, -4.576944227197716}}, {{
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}, {{
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}, {{
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}, {{
       7.813001320531261, -4.502605729695437}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}, {
       7.813001320531261, -4.502605729695437}, {
       7.813001320531261, -4.502605729695437}}, {{
       7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}, {{
       7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}, {{
       7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}, {{
       7.829930804005741, -4.428267232193159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}, {
       7.829930804005741, -4.428267232193159}, {
       7.829930804005741, -4.428267232193159}}, {{
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}, {{
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}, {{
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}, {{
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}}, {{
       8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}, {{
       8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}, {{
       8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}, {{
       8.126431715374716, -4.599452113187006}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}, {
       8.126431715374716, -4.599452113187006}, {
       8.126431715374716, -4.599452113187006}}, {{
       8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}, {{
       8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}, {{
       8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}, {{
       8.070517429795817, -4.651282724699994}, {
       7.997673660742438, -4.673790610689284}, {
       7.997673660742438, -4.673790610689284}, {
       8.070517429795817, -4.651282724699994}, {
       8.070517429795817, -4.651282724699994}}, {{
       7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}, {{
       7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}, {{
       7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}, {{
       7.9976736607424375`, -4.673790610689284}, {
       7.898840023619446, -4.651282724699994}, {
       7.898840023619446, -4.651282724699994}, {
       7.9976736607424375`, -4.673790610689284}, {
       7.9976736607424375`, -4.673790610689284}}, {{
       7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}, {{
       7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}, {{
       7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}, {{
       7.898840023619446, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}, {
       7.898840023619446, -4.35392873469088}, {
       7.898840023619446, -4.35392873469088}}, {{
       7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}, {{
       7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}, {{
       7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}, {{
       7.997673660742438, -4.33142084870159}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}, {
       7.997673660742438, -4.33142084870159}, {
       7.997673660742438, -4.33142084870159}}, {{
       8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}, {{
       8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}, {{
       8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}, {{
       8.070517429795817, -4.35392873469088}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}, {
       8.070517429795817, -4.35392873469088}, {
       8.070517429795817, -4.35392873469088}}, {{
       8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}, {{
       8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}, {{
       8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}, {{
       8.126431715374716, -4.405759346203869}, {
       8.156356132884003, -4.502605729695437}, {
       8.156356132884003, -4.502605729695437}, {
       8.126431715374716, -4.405759346203869}, {
       8.126431715374716, -4.405759346203869}}, {{
       7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}, {{
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}, {{
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}, {{
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}, {{
       7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}, {{
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}, {{
       7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}, {{
       7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}, {{
       7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}, {{
       7.961068165704755, -4.100307779304156}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}}, {{
       7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}, {{
       7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}, {{
       7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}, {{
       7.89821741492462, -4.03250509040306}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -4.03250509040306}, {
       7.89821741492462, -4.03250509040306}}, {{
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}, {{
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}, {{
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}, {{
       7.882776364327098, -3.9647024015019636`}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}, {
       7.882776364327098, -3.9647024015019636`}, {
       7.882776364327098, -3.9647024015019636`}}, {{
       7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}, {{
       7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}, {{
       7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}, {{
       7.89821741492462, -3.896899712600867}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}, {
       7.89821741492462, -3.896899712600867}, {
       7.89821741492462, -3.896899712600867}}, {{
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}, {{
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}, {{
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}, {{
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}}, {{
       8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}, {{
       8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}, {{
       8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}, {{
       8.16865009419455, -4.053034092775033}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}, {
       8.16865009419455, -4.053034092775033}, {
       8.16865009419455, -4.053034092775033}}, {{
       8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}, {{
       8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}, {{
       8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}, {{
       8.11765176846007, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}, {
       8.11765176846007, -4.100307779304156}, {
       8.11765176846007, -4.100307779304156}}, {{
       8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}, {{
       8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}, {{
       8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}, {{
       8.051212392128065, -4.12083678167613}, {
       7.961068165704755, -4.100307779304156}, {
       7.961068165704755, -4.100307779304156}, {
       8.051212392128065, -4.12083678167613}, {
       8.051212392128065, -4.12083678167613}}, {{
       7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}, {{
       7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}, {{
       7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}, {{
       7.961068165704755, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}, {
       7.961068165704755, -3.829097023699771}, {
       7.961068165704755, -3.829097023699771}}, {{
       8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}, {{
       8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}, {{
       8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}, {{
       8.051212392128065, -3.8085680213277975`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}, {
       8.051212392128065, -3.8085680213277975`}, {
       8.051212392128065, -3.8085680213277975`}}, {{
       8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}, {{
       8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}, {{
       8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}, {{
       8.11765176846007, -3.829097023699771}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.11765176846007, -3.829097023699771}, {
       8.11765176846007, -3.829097023699771}}, {{
       8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}, {{
       8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}, {{
       8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}, {{
       8.16865009419455, -3.8763707102288936`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.195943569837725, -3.9647024015019636`}, {
       8.16865009419455, -3.8763707102288936`}, {
       8.16865009419455, -3.8763707102288936`}}, {{
       7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}, {{
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}, {{
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}, {{
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}, {{
       7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}, {{
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}, {{
       7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}, {{
       7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}, {{
       7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}, {{
       7.951631436039097, -3.5899059811704452`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}}, {{
       7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}, {{
       7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}, {{
       7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}, {{
       7.889477240011808, -3.522854727767311}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.522854727767311}, {
       7.889477240011808, -3.522854727767311}}, {{
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}, {{
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}, {{
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}, {{
       7.874207317635495, -3.4558034743641772`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.874207317635495, -3.4558034743641772`}, {
       7.874207317635495, -3.4558034743641772`}}, {{
       7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}, {{
       7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}, {{
       7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}, {{
       7.889477240011808, -3.3887522209610434`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.889477240011808, -3.3887522209610434`}, {
       7.889477240011808, -3.3887522209610434`}}, {{
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}, {{
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}, {{
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}, {{
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}}, {{
       8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}, {{
       8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}, {{
       8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}, {{
       8.156912800460846, -3.5431562137771744`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.156912800460846, -3.5431562137771744`}, {
       8.156912800460846, -3.5431562137771744`}}, {{
       8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}, {{
       8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}, {{
       8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}, {{
       8.106479672846302, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.106479672846302, -3.5899059811704452`}, {
       8.106479672846302, -3.5899059811704452`}}, {{
       8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}, {{
       8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}, {{
       8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}, {{
       8.040776622855443, -3.6102074671803086`}, {
       7.951631436039097, -3.5899059811704452`}, {
       7.951631436039097, -3.5899059811704452`}, {
       8.040776622855443, -3.6102074671803086`}, {
       8.040776622855443, -3.6102074671803086`}}, {{
       7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}, {{
       7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}, {{
       7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}, {{
       7.951631436039097, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}, {
       7.951631436039097, -3.3217009675579092`}, {
       7.951631436039097, -3.3217009675579092`}}, {{
       8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}, {{
       8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}, {{
       8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}, {{
       8.040776622855443, -3.301399481548046}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.040776622855443, -3.301399481548046}, {
       8.040776622855443, -3.301399481548046}}, {{
       8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}, {{
       8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}, {{
       8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}, {{
       8.106479672846302, -3.3217009675579092`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}, {
       8.106479672846302, -3.3217009675579092`}, {
       8.106479672846302, -3.3217009675579092`}}, {{
       8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}, {{
       8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}, {{
       8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}, {{
       8.156912800460846, -3.36845073495118}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.183903791249904, -3.4558034743641772`}, {
       8.156912800460846, -3.36845073495118}, {
       8.156912800460846, -3.36845073495118}}, {{
       7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}, {{
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}, {{
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}, {{
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}, {{
       7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}, {{
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}, {{
       7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}, {{
       7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}, {{
       7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}, {{
       7.909947501802559, -3.179447240845397}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}}, {{
       7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}, {{
       7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}, {{
       7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}, {{
       7.8405280535090425`, -3.1045583143344544`}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -3.1045583143344544`}, {
       7.8405280535090425`, -3.1045583143344544`}}, {{
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}, {{
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}, {{
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}, {{
       7.82347321804173, -3.029669387823512}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.82347321804173, -3.029669387823512}, {
       7.82347321804173, -3.029669387823512}}, {{
       7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}, {{
       7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}, {{
       7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}, {{
       7.8405280535090425`, -2.95478046131257}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}, {
       7.8405280535090425`, -2.95478046131257}, {
       7.8405280535090425`, -2.95478046131257}}, {{
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}, {{
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}, {{
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}, {{
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}}, {{
       8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}, {{
       8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}, {{
       8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}, {{
       8.139224364411184, -3.1272328568178698`}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}, {
       8.139224364411184, -3.1272328568178698`}, {
       8.139224364411184, -3.1272328568178698`}}, {{
       8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}, {{
       8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}, {{
       8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}, {{
       8.08289606932422, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}, {
       8.08289606932422, -3.179447240845397}, {
       8.08289606932422, -3.179447240845397}}, {{
       8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}, {{
       8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}, {{
       8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}, {{
       8.00951293876994, -3.202121783328812}, {
       7.909947501802559, -3.179447240845397}, {
       7.909947501802559, -3.179447240845397}, {
       8.00951293876994, -3.202121783328812}, {
       8.00951293876994, -3.202121783328812}}, {{
       7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}, {{
       7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}, {{
       7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}, {{
       7.909947501802559, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}, {
       7.909947501802559, -2.879891534801627}, {
       7.909947501802559, -2.879891534801627}}, {{
       8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}, {{
       8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}, {{
       8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}, {{
       8.00951293876994, -2.8572169923182122`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}, {
       8.00951293876994, -2.8572169923182122`}, {
       8.00951293876994, -2.8572169923182122`}}, {{
       8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}, {{
       8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}, {{
       8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}, {{
       8.08289606932422, -2.879891534801627}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.08289606932422, -2.879891534801627}, {
       8.08289606932422, -2.879891534801627}}, {{
       8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}, {{
       8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}, {{
       8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}, {{
       8.139224364411184, -2.9321059188291545`}, {
       8.169370353085048, -3.029669387823512}, {
       8.169370353085048, -3.029669387823512}, {
       8.139224364411184, -2.9321059188291545`}, {
       8.139224364411184, -2.9321059188291545`}}, {{
       7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}, {{
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}, {{
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}, {{
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}, {{
       7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}, {{
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}, {{
       7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}, {{
       7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}, {{
       7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}, {{
       7.901105658239665, -2.598657868863138}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}}, {{
       7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}, {{
       7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}, {{
       7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}, {{
       7.839994079461116, -2.532731379318538}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.532731379318538}, {
       7.839994079461116, -2.532731379318538}}, {{
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}, {{
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}, {{
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}, {{
       7.824980305269062, -2.466804889773938}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.824980305269062, -2.466804889773938}, {
       7.824980305269062, -2.466804889773938}}, {{
       7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}, {{
       7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}, {{
       7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}, {{
       7.839994079461116, -2.4008784002293377`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.839994079461116, -2.4008784002293377`}, {
       7.839994079461116, -2.4008784002293377`}}, {{
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}, {{
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}, {{
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}, {{
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}}, {{
       8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}, {{
       8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}, {{
       8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}, {{
       8.102943491812798, -2.552692314233836}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}, {
       8.102943491812798, -2.552692314233836}, {
       8.102943491812798, -2.552692314233836}}, {{
       8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}, {{
       8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}, {{
       8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}, {{
       8.053356364180873, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}, {
       8.053356364180873, -2.598657868863138}, {
       8.053356364180873, -2.598657868863138}}, {{
       7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}, {{
       7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}, {{
       7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}, {{
       7.988755462356893, -2.618618803778436}, {
       7.901105658239665, -2.598657868863138}, {
       7.901105658239665, -2.598657868863138}, {
       7.988755462356893, -2.618618803778436}, {
       7.988755462356893, -2.618618803778436}}, {{
       7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}, {{
       7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}, {{
       7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}, {{
       7.901105658239665, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}, {
       7.901105658239665, -2.3349519106847376`}, {
       7.901105658239665, -2.3349519106847376`}}, {{
       7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}, {{
       7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}, {{
       7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}, {{
       7.988755462356893, -2.31499097576944}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}, {
       7.988755462356893, -2.31499097576944}, {
       7.988755462356893, -2.31499097576944}}, {{
       8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}, {{
       8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}, {{
       8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}, {{
       8.053356364180873, -2.3349519106847376`}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}, {
       8.053356364180873, -2.3349519106847376`}, {
       8.053356364180873, -2.3349519106847376`}}, {{
       8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}, {{
       8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}, {{
       8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}, {{
       8.102943491812798, -2.38091746531404}, {
       8.129481717151476, -2.466804889773938}, {
       8.129481717151476, -2.466804889773938}, {
       8.102943491812798, -2.38091746531404}, {
       8.102943491812798, -2.38091746531404}}, {{
       7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}, {{
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}, {{
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}, {{
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}, {{
       7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}, {{
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}, {{
       7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}, {{
       7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}, {{
       7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}, {{
       7.93519949060807, -2.113078454297506}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}}, {{
       7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}, {{
       7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}, {{
       7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}, {{
       7.8770546998925415`, -2.0503525026235865`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -2.0503525026235865`}, {
       7.8770546998925415`, -2.0503525026235865`}}, {{
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}, {{
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}, {{
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}, {{
       7.862769800439844, -1.9876265509496673`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.862769800439844, -1.9876265509496673`}, {
       7.862769800439844, -1.9876265509496673`}}, {{
       7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}, {{
       7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}, {{
       7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}, {{
       7.8770546998925415`, -1.924900599275748}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.8770546998925415`, -1.924900599275748}, {
       7.8770546998925415`, -1.924900599275748}}, {{
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}, {{
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}, {{
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}, {{
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}}, {{
       8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}, {{
       8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}, {{
       8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}, {{
       8.12723868884434, -2.0693443926440036`}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}, {
       8.12723868884434, -2.0693443926440036`}, {
       8.12723868884434, -2.0693443926440036`}}, {{
       8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}, {{
       8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}, {{
       8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}, {{
       8.080058870944521, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}, {
       8.080058870944521, -2.113078454297506}, {
       8.080058870944521, -2.113078454297506}}, {{
       8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}, {{
       8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}, {{
       8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}, {{
       8.018594153592003, -2.132070344317923}, {
       7.93519949060807, -2.113078454297506}, {
       7.93519949060807, -2.113078454297506}, {
       8.018594153592003, -2.132070344317923}, {
       8.018594153592003, -2.132070344317923}}, {{
       7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}, {{
       7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}, {{
       7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}, {{
       7.93519949060807, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}, {
       7.93519949060807, -1.8621746476018288`}, {
       7.93519949060807, -1.8621746476018288`}}, {{
       8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}, {{
       8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}, {{
       8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}, {{
       8.018594153592003, -1.8431827575814117`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.018594153592003, -1.8431827575814117`}, {
       8.018594153592003, -1.8431827575814117`}}, {{
       8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}, {{
       8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}, {{
       8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}, {{
       8.080058870944521, -1.8621746476018288`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.080058870944521, -1.8621746476018288`}, {
       8.080058870944521, -1.8621746476018288`}}, {{
       8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}, {{
       8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}, {{
       8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}, {{
       8.12723868884434, -1.9059087092553308`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.152488561112746, -1.9876265509496673`}, {
       8.12723868884434, -1.9059087092553308`}, {
       8.12723868884434, -1.9059087092553308`}}, {{
       7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}, {{
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}, {{
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}, {{
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}, {{
       7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}, {{
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}, {{
       7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}, {{
       7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}, {{
       7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}, {{
       7.920383610664381, -1.674905720472927}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}}, {{
       7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}, {{
       7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}, {{
       7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}, {{
       7.860504527194832, -1.6103088331203612`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.6103088331203612`}, {
       7.860504527194832, -1.6103088331203612`}}, {{
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}, {{
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}, {{
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}, {{
       7.845793550060749, -1.5457119457677952`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.845793550060749, -1.5457119457677952`}, {
       7.845793550060749, -1.5457119457677952`}}, {{
       7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}, {{
       7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}, {{
       7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}, {{
       7.860504527194832, -1.4811150584152293`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.860504527194832, -1.4811150584152293`}, {
       7.860504527194832, -1.4811150584152293`}}, {{
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}, {{
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}, {{
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}, {{
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}}, {{
       8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}, {{
       8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}, {{
       8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}, {{
       8.118150788757326, -1.6298671968840361`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}, {
       8.118150788757326, -1.6298671968840361`}, {
       8.118150788757326, -1.6298671968840361`}}, {{
       8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}, {{
       8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}, {{
       8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}, {{
       8.069563731871645, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.069563731871645, -1.674905720472927}, {
       8.069563731871645, -1.674905720472927}}, {{
       8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}, {{
       8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}, {{
       8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}, {{
       8.006265697851878, -1.6944640842366019`}, {
       7.920383610664381, -1.674905720472927}, {
       7.920383610664381, -1.674905720472927}, {
       8.006265697851878, -1.6944640842366019`}, {
       8.006265697851878, -1.6944640842366019`}}, {{
       7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}, {{
       7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}, {{
       7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}, {{
       7.920383610664381, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}, {
       7.920383610664381, -1.4165181710626635`}, {
       7.920383610664381, -1.4165181710626635`}}, {{
       8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}, {{
       8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}, {{
       8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}, {{
       8.006265697851878, -1.3969598072989886`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.006265697851878, -1.3969598072989886`}, {
       8.006265697851878, -1.3969598072989886`}}, {{
       8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}, {{
       8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}, {{
       8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}, {{
       8.069563731871645, -1.4165181710626635`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.069563731871645, -1.4165181710626635`}, {
       8.069563731871645, -1.4165181710626635`}}, {{
       8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}, {{
       8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}, {{
       8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}, {{
       8.118150788757326, -1.4615566946515544`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.144153792475276, -1.5457119457677952`}, {
       8.118150788757326, -1.4615566946515544`}, {
       8.118150788757326, -1.4615566946515544`}}, {{
       7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}, {{
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}, {{
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}, {{
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}, {{
       7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}, {{
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}, {{
       7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}, {{
       7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}, {{
       7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}, {{
       7.967847369188011, -1.1540521000388828`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}}, {{
       7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}, {{
       7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}, {{
       7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}, {{
       7.9084384514996, -1.0899624222867548`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -1.0899624222867548`}, {
       7.9084384514996, -1.0899624222867548`}}, {{
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}, {{
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}, {{
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}, {{
       7.893842983783076, -1.0258727445346267`}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}, {
       7.893842983783076, -1.0258727445346267`}, {
       7.893842983783076, -1.0258727445346267`}}, {{
       7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}, {{
       7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}, {{
       7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}, {{
       7.9084384514996, -0.9617830667824987}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}, {
       7.9084384514996, -0.9617830667824987}, {
       7.9084384514996, -0.9617830667824987}}, {{
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}, {{
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}, {{
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}, {{
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}}, {{
       8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}, {{
       8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}, {{
       8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}, {{
       8.16406169519332, -1.1093672153401934`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.16406169519332, -1.1093672153401934`}, {
       8.16406169519332, -1.1093672153401934`}}, {{
       8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}, {{
       8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}, {{
       8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}, {{
       8.11585613999788, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.11585613999788, -1.1540521000388828`}, {
       8.11585613999788, -1.1540521000388828`}}, {{
       8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}, {{
       8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}, {{
       8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}, {{
       8.053055117085918, -1.1734568930923215`}, {
       7.967847369188011, -1.1540521000388828`}, {
       7.967847369188011, -1.1540521000388828`}, {
       8.053055117085918, -1.1734568930923215`}, {
       8.053055117085918, -1.1734568930923215`}}, {{
       7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}, {{
       7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}, {{
       7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}, {{
       7.967847369188011, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}, {
       7.967847369188011, -0.8976933890303707}, {
       7.967847369188011, -0.8976933890303707}}, {{
       8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}, {{
       8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}, {{
       8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}, {{
       8.053055117085918, -0.878288595976932}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}, {
       8.053055117085918, -0.878288595976932}, {
       8.053055117085918, -0.878288595976932}}, {{
       8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}, {{
       8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}, {{
       8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}, {{
       8.11585613999788, -0.8976933890303707}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}, {
       8.11585613999788, -0.8976933890303707}, {
       8.11585613999788, -0.8976933890303707}}, {{
       8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}, {{
       8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}, {{
       8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}, {{
       8.16406169519332, -0.9423782737290601}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.189860525402816, -1.0258727445346267`}, {
       8.16406169519332, -0.9423782737290601}, {
       8.16406169519332, -0.9423782737290601}}, {{
       7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}, {{
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}, {{
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}, {{
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}, {{
       7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804813, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}, {{
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}, {{
       7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}, {{
       7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}, {{
       7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}, {{
       7.87811677631629, -0.6561204485274952}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}}, {{
       7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}, {{
       7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}, {{
       7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}, {{
       7.819449936416027, -0.5928313160160483}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.5928313160160483}, {
       7.819449936416027, -0.5928313160160483}}, {{
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}, {{
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}, {{
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}, {{
       7.805036780931766, -0.5295421835046014}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.805036780931766, -0.5295421835046014}, {
       7.805036780931766, -0.5295421835046014}}, {{
       7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}, {{
       7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}, {{
       7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}, {{
       7.819449936416027, -0.46625305099315445`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.819449936416027, -0.46625305099315445`}, {
       7.819449936416027, -0.46625305099315445`}}, {{
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}, {{
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}, {{
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}, {{
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}}, {{
       8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}, {{
       8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}, {{
       8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}, {{
       8.071880185881598, -0.6119937234737063}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}, {
       8.071880185881598, -0.6119937234737063}, {
       8.071880185881598, -0.6119937234737063}}, {{
       8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}, {{
       8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}, {{
       8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}, {{
       8.024276767085336, -0.6561204485274952}, {
       7.962260192804814, -0.6752828559851533}, {
       7.962260192804814, -0.6752828559851533}, {
       8.024276767085336, -0.6561204485274952}, {
       8.024276767085336, -0.6561204485274952}}, {{
       7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}, {{
       7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}, {{
       7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}, {{
       7.962260192804813, -0.6752828559851533}, {
       7.87811677631629, -0.6561204485274952}, {
       7.87811677631629, -0.6561204485274952}, {
       7.962260192804813, -0.6752828559851533}, {
       7.962260192804813, -0.6752828559851533}}, {{
       7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}, {{
       7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}, {{
       7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}, {{
       7.87811677631629, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.87811677631629, -0.40296391848170754`}, {
       7.87811677631629, -0.40296391848170754`}}, {{
       7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}, {{
       7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}, {{
       7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}, {{
       7.962260192804814, -0.38380151102404947`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}, {
       7.962260192804814, -0.38380151102404947`}, {
       7.962260192804814, -0.38380151102404947`}}, {{
       8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}, {{
       8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}, {{
       8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}, {{
       8.024276767085336, -0.40296391848170754`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.024276767085336, -0.40296391848170754`}, {
       8.024276767085336, -0.40296391848170754`}}, {{
       8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}, {{
       8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}, {{
       8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}, {{
       8.071880185881598, -0.44709064353549643`}, {
       8.09735676246986, -0.5295421835046014}, {
       8.09735676246986, -0.5295421835046014}, {
       8.071880185881598, -0.44709064353549643`}, {
       8.071880185881598, -0.44709064353549643`}}, {{
       7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {7.863071803395718, 
       0.054204351556651174`}, {7.926814382585178, 0.1229691349982274}, {
       7.926814382585178, 0.1229691349982274}, {7.863071803395718, 
       0.05420435155665115}, {7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650139}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}, {{
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}, {{
       8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807766`}, {
       7.926814382585178, -0.15208999876807766`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}, {{
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}, {{7.926814382585178, 
       0.12296913499822743`}, {8.018237721526049, 0.14378943615825315`}, {
       8.08561984750822, 0.1229691349982274}, {8.13734182021833, 
       0.07502465271667688}, {8.16502257996974, -0.014560431884925094`}, {
       8.16502257996974, -0.014560431884925094`}, {8.13734182021833, 
       0.07502465271667688}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {7.926814382585178, 
       0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}}, {{
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}, {{7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}, {{
       7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}, {{
       7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}, {{
       7.926814382585178, -0.15208999876807763`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}}, {{
       7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}, {{
       7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}, {{
       7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}, {{
       7.863071803395718, -0.08332521532650136}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.863071803395718, -0.08332521532650136}, {
       7.863071803395718, -0.08332521532650136}}, {{
       7.847411650123657, -0.014560431884925111`}, {7.863071803395718, 
       0.05420435155665115}, {7.863071803395718, 0.05420435155665115}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}, {{
       7.847411650123657, -0.014560431884925111`}, {7.863071803395718, 
       0.05420435155665115}, {7.863071803395718, 0.05420435155665115}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}, {{
       7.847411650123657, -0.014560431884925111`}, {7.863071803395718, 
       0.05420435155665115}, {7.863071803395718, 0.05420435155665115}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}, {{
       7.847411650123657, -0.014560431884925111`}, {7.863071803395718, 
       0.05420435155665115}, {7.863071803395718, 0.05420435155665115}, {
       7.847411650123657, -0.014560431884925111`}, {
       7.847411650123657, -0.014560431884925111`}}, {{7.863071803395718, 
       0.054204351556651174`}, {7.926814382585178, 0.12296913499822743`}, {
       7.926814382585178, 0.12296913499822743`}, {7.863071803395718, 
       0.054204351556651174`}, {7.863071803395718, 0.054204351556651174`}}, {{
       7.863071803395718, 0.054204351556651174`}, {7.926814382585178, 
       0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}, {
       7.863071803395718, 0.054204351556651174`}, {7.863071803395718, 
       0.054204351556651174`}}, {{7.863071803395718, 0.054204351556651174`}, {
       7.926814382585178, 0.12296913499822743`}, {7.926814382585178, 
       0.12296913499822743`}, {7.863071803395718, 0.054204351556651174`}, {
       7.863071803395718, 0.054204351556651174`}}, {{7.863071803395718, 
       0.054204351556651174`}, {7.926814382585178, 0.12296913499822743`}, {
       7.926814382585178, 0.12296913499822743`}, {7.863071803395718, 
       0.054204351556651174`}, {7.863071803395718, 0.054204351556651174`}}, {{
       8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}, {{
       8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}, {{
       8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}, {{
       8.16502257996974, -0.014560431884925128`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.16502257996974, -0.014560431884925128`}, {
       8.16502257996974, -0.014560431884925128`}}, {{
       8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}, {{
       8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}, {{
       8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}, {{
       8.13734182021833, -0.10414551648652712`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.13734182021833, -0.10414551648652712`}, {
       8.13734182021833, -0.10414551648652712`}}, {{
       8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}, {{
       8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}, {{
       8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}, {{
       8.08561984750822, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}, {
       8.08561984750822, -0.15208999876807763`}, {
       8.08561984750822, -0.15208999876807763`}}, {{
       8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}, {{
       8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}, {{
       8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}, {{
       8.018237721526049, -0.1729102999281034}, {
       7.926814382585178, -0.15208999876807763`}, {
       7.926814382585178, -0.15208999876807763`}, {
       8.018237721526049, -0.1729102999281034}, {
       8.018237721526049, -0.1729102999281034}}, {{7.926814382585178, 
       0.12296913499822743`}, {8.018237721526049, 0.14378943615825315`}, {
       8.018237721526049, 0.14378943615825315`}, {7.926814382585178, 
       0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}}, {{
       7.926814382585178, 0.12296913499822743`}, {8.018237721526049, 
       0.14378943615825315`}, {8.018237721526049, 0.14378943615825315`}, {
       7.926814382585178, 0.12296913499822743`}, {7.926814382585178, 
       0.12296913499822743`}}, {{7.926814382585178, 0.12296913499822743`}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}, {7.926814382585178, 0.12296913499822743`}, {
       7.926814382585178, 0.12296913499822743`}}, {{7.926814382585178, 
       0.12296913499822743`}, {8.018237721526049, 0.14378943615825315`}, {
       8.018237721526049, 0.14378943615825315`}, {7.926814382585178, 
       0.12296913499822743`}, {7.926814382585178, 0.12296913499822743`}}, {{
       8.018237721526049, 0.14378943615825315`}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}}, {{8.018237721526049, 0.14378943615825315`}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}, {8.018237721526049, 0.14378943615825315`}, {
       8.018237721526049, 0.14378943615825315`}}, {{8.018237721526049, 
       0.14378943615825315`}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}, {8.018237721526049, 
       0.14378943615825315`}, {8.018237721526049, 0.14378943615825315`}}, {{
       8.018237721526049, 0.14378943615825315`}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}, {
       8.018237721526049, 0.14378943615825315`}, {8.018237721526049, 
       0.14378943615825315`}}, {{8.08561984750822, 0.1229691349982274}, {
       8.13734182021833, 0.07502465271667688}, {8.13734182021833, 
       0.07502465271667688}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}}, {{8.08561984750822, 
       0.1229691349982274}, {8.13734182021833, 0.07502465271667688}, {
       8.13734182021833, 0.07502465271667688}, {8.08561984750822, 
       0.1229691349982274}, {8.08561984750822, 0.1229691349982274}}, {{
       8.08561984750822, 0.1229691349982274}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}, {
       8.08561984750822, 0.1229691349982274}, {8.08561984750822, 
       0.1229691349982274}}, {{8.08561984750822, 0.1229691349982274}, {
       8.13734182021833, 0.07502465271667688}, {8.13734182021833, 
       0.07502465271667688}, {8.08561984750822, 0.1229691349982274}, {
       8.08561984750822, 0.1229691349982274}}, {{8.13734182021833, 
       0.07502465271667688}, {8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}, {{
       8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}, {{
       8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}, {{
       8.13734182021833, 0.07502465271667688}, {
       8.16502257996974, -0.014560431884925137`}, {
       8.16502257996974, -0.014560431884925137`}, {8.13734182021833, 
       0.07502465271667688}, {8.13734182021833, 0.07502465271667688}}, {{
       7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393822}, {7.9355805510604105`, 0.6555045023393822}, {
       7.868670330282623, 0.5833225024843558}, {7.852231956966521, 
       0.5111405026293293}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}, {{7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}}, {{8.185626333342082, 
       0.5111405026293293}, {8.156569998160558, 0.41710355173542646`}, {
       8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {7.9355805510604105`, 0.3667765029192763}, {
       7.9355805510604105`, 0.3667765029192763}, {8.031547107019723, 
       0.34492155188039997`}, {8.10227773924819, 0.3667765029192764}, {
       8.156569998160558, 0.41710355173542646`}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}}, {{
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}, {{7.9355805510604105`, 0.6555045023393823}, {
       8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.156569998160558, 0.6051774535232322}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}, {8.156569998160558, 0.6051774535232322}, {
       8.10227773924819, 0.6555045023393822}, {8.031547107019723, 
       0.6773594533782586}, {7.9355805510604105`, 0.6555045023393823}, {
       7.9355805510604105`, 0.6555045023393823}}, {{8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}}, {{
       7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}, {{7.9355805510604105`, 0.3667765029192764}, {
       7.868670330282623, 0.4389585027743028}, {7.868670330282623, 
       0.4389585027743028}, {7.9355805510604105`, 0.3667765029192764}, {
       7.9355805510604105`, 0.3667765029192764}}, {{7.9355805510604105`, 
       0.3667765029192764}, {7.868670330282623, 0.4389585027743028}, {
       7.868670330282623, 0.4389585027743028}, {7.9355805510604105`, 
       0.3667765029192764}, {7.9355805510604105`, 0.3667765029192764}}, {{
       7.9355805510604105`, 0.3667765029192764}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}}, {{7.868670330282623, 0.4389585027743028}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.868670330282623, 0.4389585027743028}, {
       7.868670330282623, 0.4389585027743028}}, {{7.868670330282623, 
       0.4389585027743028}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}, {7.868670330282623, 
       0.4389585027743028}, {7.868670330282623, 0.4389585027743028}}, {{
       7.868670330282623, 0.4389585027743028}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.4389585027743028}, {7.868670330282623, 
       0.4389585027743028}}, {{7.868670330282623, 0.4389585027743028}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}, {7.868670330282623, 0.4389585027743028}, {
       7.868670330282623, 0.4389585027743028}}, {{7.852231956966521, 
       0.5111405026293293}, {7.868670330282623, 0.5833225024843558}, {
       7.868670330282623, 0.5833225024843558}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}}, {{
       7.852231956966521, 0.5111405026293293}, {7.868670330282623, 
       0.5833225024843558}, {7.868670330282623, 0.5833225024843558}, {
       7.852231956966521, 0.5111405026293293}, {7.852231956966521, 
       0.5111405026293293}}, {{7.852231956966521, 0.5111405026293293}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}, {7.852231956966521, 0.5111405026293293}, {
       7.852231956966521, 0.5111405026293293}}, {{7.852231956966521, 
       0.5111405026293293}, {7.868670330282623, 0.5833225024843558}, {
       7.868670330282623, 0.5833225024843558}, {7.852231956966521, 
       0.5111405026293293}, {7.852231956966521, 0.5111405026293293}}, {{
       7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}}, {{7.868670330282623, 0.5833225024843558}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}, {7.868670330282623, 0.5833225024843558}, {
       7.868670330282623, 0.5833225024843558}}, {{7.868670330282623, 
       0.5833225024843558}, {7.9355805510604105`, 0.6555045023393823}, {
       7.9355805510604105`, 0.6555045023393823}, {7.868670330282623, 
       0.5833225024843558}, {7.868670330282623, 0.5833225024843558}}, {{
       7.868670330282623, 0.5833225024843558}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}, {
       7.868670330282623, 0.5833225024843558}, {7.868670330282623, 
       0.5833225024843558}}, {{8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}, {8.185626333342082, 0.5111405026293293}, {
       8.185626333342082, 0.5111405026293293}}, {{8.185626333342082, 
       0.5111405026293293}, {8.156569998160558, 0.41710355173542646`}, {
       8.156569998160558, 0.41710355173542646`}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}}, {{
       8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}}, {{8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}, {8.185626333342082, 0.5111405026293293}, {
       8.185626333342082, 0.5111405026293293}}, {{8.156569998160558, 
       0.41710355173542646`}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}}, {{
       8.156569998160558, 0.41710355173542646`}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}, {
       8.156569998160558, 0.41710355173542646`}, {8.156569998160558, 
       0.41710355173542646`}}, {{8.156569998160558, 0.41710355173542646`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}, {8.156569998160558, 0.41710355173542646`}, {
       8.156569998160558, 0.41710355173542646`}}, {{8.156569998160558, 
       0.41710355173542646`}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}, {8.156569998160558, 
       0.41710355173542646`}, {8.156569998160558, 0.41710355173542646`}}, {{
       8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}, {{8.10227773924819, 0.3667765029192764}, {
       8.031547107019723, 0.34492155188039997`}, {8.031547107019723, 
       0.34492155188039997`}, {8.10227773924819, 0.3667765029192764}, {
       8.10227773924819, 0.3667765029192764}}, {{8.10227773924819, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}, {8.10227773924819, 
       0.3667765029192764}, {8.10227773924819, 0.3667765029192764}}, {{
       8.10227773924819, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}, {
       8.10227773924819, 0.3667765029192764}, {8.10227773924819, 
       0.3667765029192764}}, {{8.031547107019723, 0.34492155188039997`}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}}, {{8.031547107019723, 
       0.34492155188039997`}, {7.9355805510604105`, 0.3667765029192764}, {
       7.9355805510604105`, 0.3667765029192764}, {8.031547107019723, 
       0.34492155188039997`}, {8.031547107019723, 0.34492155188039997`}}, {{
       8.031547107019723, 0.34492155188039997`}, {7.9355805510604105`, 
       0.3667765029192764}, {7.9355805510604105`, 0.3667765029192764}, {
       8.031547107019723, 0.34492155188039997`}, {8.031547107019723, 
       0.34492155188039997`}}, {{8.031547107019723, 0.34492155188039997`}, {
       7.9355805510604105`, 0.3667765029192764}, {7.9355805510604105`, 
       0.3667765029192764}, {8.031547107019723, 0.34492155188039997`}, {
       8.031547107019723, 0.34492155188039997`}}, {{7.9355805510604105`, 
       0.6555045023393823}, {8.031547107019723, 0.6773594533782586}, {
       8.031547107019723, 0.6773594533782586}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}}, {{
       7.9355805510604105`, 0.6555045023393823}, {8.031547107019723, 
       0.6773594533782586}, {8.031547107019723, 0.6773594533782586}, {
       7.9355805510604105`, 0.6555045023393823}, {7.9355805510604105`, 
       0.6555045023393823}}, {{7.9355805510604105`, 0.6555045023393823}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}, {7.9355805510604105`, 0.6555045023393823}, {
       7.9355805510604105`, 0.6555045023393823}}, {{7.9355805510604105`, 
       0.6555045023393823}, {8.031547107019723, 0.6773594533782586}, {
       8.031547107019723, 0.6773594533782586}, {7.9355805510604105`, 
       0.6555045023393823}, {7.9355805510604105`, 0.6555045023393823}}, {{
       8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}}, {{8.031547107019723, 0.6773594533782586}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}, {8.031547107019723, 0.6773594533782586}, {
       8.031547107019723, 0.6773594533782586}}, {{8.031547107019723, 
       0.6773594533782586}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}, {8.031547107019723, 
       0.6773594533782586}, {8.031547107019723, 0.6773594533782586}}, {{
       8.031547107019723, 0.6773594533782586}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}, {
       8.031547107019723, 0.6773594533782586}, {8.031547107019723, 
       0.6773594533782586}}, {{8.10227773924819, 0.6555045023393822}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}}, {{8.10227773924819, 
       0.6555045023393822}, {8.156569998160558, 0.6051774535232322}, {
       8.156569998160558, 0.6051774535232322}, {8.10227773924819, 
       0.6555045023393822}, {8.10227773924819, 0.6555045023393822}}, {{
       8.10227773924819, 0.6555045023393822}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}, {
       8.10227773924819, 0.6555045023393822}, {8.10227773924819, 
       0.6555045023393822}}, {{8.10227773924819, 0.6555045023393822}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}, {8.10227773924819, 0.6555045023393822}, {
       8.10227773924819, 0.6555045023393822}}, {{8.156569998160558, 
       0.6051774535232322}, {8.185626333342082, 0.5111405026293293}, {
       8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}}, {{
       8.156569998160558, 0.6051774535232322}, {8.185626333342082, 
       0.5111405026293293}, {8.185626333342082, 0.5111405026293293}, {
       8.156569998160558, 0.6051774535232322}, {8.156569998160558, 
       0.6051774535232322}}, {{8.156569998160558, 0.6051774535232322}, {
       8.185626333342082, 0.5111405026293293}, {8.185626333342082, 
       0.5111405026293293}, {8.156569998160558, 0.6051774535232322}, {
       8.156569998160558, 0.6051774535232322}}, {{8.156569998160558, 
       0.6051774535232322}, {8.185626333342082, 0.5111405026293293}, {
       8.185626333342082, 0.5111405026293293}, {8.156569998160558, 
       0.6051774535232322}, {8.156569998160558, 0.6051774535232322}}, {{
       7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.866596322918788, 
       1.043764089413193}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}, {{7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}}, {{8.195425492504594, 
       1.043764089413193}, {8.166767028997146, 0.9510147970916263}, {
       8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {7.9488036153152395`, 0.9013768822298682}, {
       7.9488036153152395`, 0.9013768822298682}, {8.043456090402469, 
       0.8798211934999639}, {8.113218200108143, 0.9013768822298683}, {
       8.166767028997146, 0.9510147970916263}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}}, {{
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}, {{7.9488036153152395`, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.166767028997146, 1.1365133817347597`}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}, {8.166767028997146, 1.1365133817347597`}, {
       8.113218200108143, 1.1861512965965177`}, {8.043456090402469, 
       1.2077069853264222`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.9488036153152395`, 1.1861512965965177`}}, {{8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}}, {{
       7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}, {{7.9488036153152395`, 0.9013768822298683}, {
       7.882809603735457, 0.9725704858215306}, {7.882809603735457, 
       0.9725704858215306}, {7.9488036153152395`, 0.9013768822298683}, {
       7.9488036153152395`, 0.9013768822298683}}, {{7.9488036153152395`, 
       0.9013768822298683}, {7.882809603735457, 0.9725704858215306}, {
       7.882809603735457, 0.9725704858215306}, {7.9488036153152395`, 
       0.9013768822298683}, {7.9488036153152395`, 0.9013768822298683}}, {{
       7.9488036153152395`, 0.9013768822298683}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}}, {{7.882809603735457, 0.9725704858215306}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.882809603735457, 0.9725704858215306}, {
       7.882809603735457, 0.9725704858215306}}, {{7.882809603735457, 
       0.9725704858215306}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}, {7.882809603735457, 
       0.9725704858215306}, {7.882809603735457, 0.9725704858215306}}, {{
       7.882809603735457, 0.9725704858215306}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 0.9725704858215306}, {7.882809603735457, 
       0.9725704858215306}}, {{7.882809603735457, 0.9725704858215306}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}, {7.882809603735457, 0.9725704858215306}, {
       7.882809603735457, 0.9725704858215306}}, {{7.866596322918788, 
       1.043764089413193}, {7.882809603735457, 1.1149576930048553`}, {
       7.882809603735457, 1.1149576930048553`}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}}, {{
       7.866596322918788, 1.043764089413193}, {7.882809603735457, 
       1.1149576930048553`}, {7.882809603735457, 1.1149576930048553`}, {
       7.866596322918788, 1.043764089413193}, {7.866596322918788, 
       1.043764089413193}}, {{7.866596322918788, 1.043764089413193}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}, {7.866596322918788, 1.043764089413193}, {
       7.866596322918788, 1.043764089413193}}, {{7.866596322918788, 
       1.043764089413193}, {7.882809603735457, 1.1149576930048553`}, {
       7.882809603735457, 1.1149576930048553`}, {7.866596322918788, 
       1.043764089413193}, {7.866596322918788, 1.043764089413193}}, {{
       7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}}, {{7.882809603735457, 1.1149576930048553`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.882809603735457, 1.1149576930048553`}, {
       7.882809603735457, 1.1149576930048553`}}, {{7.882809603735457, 
       1.1149576930048553`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.882809603735457, 
       1.1149576930048553`}, {7.882809603735457, 1.1149576930048553`}}, {{
       7.882809603735457, 1.1149576930048553`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.882809603735457, 1.1149576930048553`}, {7.882809603735457, 
       1.1149576930048553`}}, {{8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}, {8.195425492504594, 1.043764089413193}, {
       8.195425492504594, 1.043764089413193}}, {{8.195425492504594, 
       1.043764089413193}, {8.166767028997146, 0.9510147970916263}, {
       8.166767028997146, 0.9510147970916263}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}}, {{
       8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}}, {{8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}, {8.195425492504594, 1.043764089413193}, {
       8.195425492504594, 1.043764089413193}}, {{8.166767028997146, 
       0.9510147970916263}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}}, {{
       8.166767028997146, 0.9510147970916263}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}, {
       8.166767028997146, 0.9510147970916263}, {8.166767028997146, 
       0.9510147970916263}}, {{8.166767028997146, 0.9510147970916263}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}, {8.166767028997146, 0.9510147970916263}, {
       8.166767028997146, 0.9510147970916263}}, {{8.166767028997146, 
       0.9510147970916263}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}, {8.166767028997146, 
       0.9510147970916263}, {8.166767028997146, 0.9510147970916263}}, {{
       8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}, {{8.113218200108143, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {8.043456090402469, 
       0.8798211934999639}, {8.113218200108143, 0.9013768822298683}, {
       8.113218200108143, 0.9013768822298683}}, {{8.113218200108143, 
       0.9013768822298683}, {8.043456090402469, 0.8798211934999639}, {
       8.043456090402469, 0.8798211934999639}, {8.113218200108143, 
       0.9013768822298683}, {8.113218200108143, 0.9013768822298683}}, {{
       8.113218200108143, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}, {
       8.113218200108143, 0.9013768822298683}, {8.113218200108143, 
       0.9013768822298683}}, {{8.043456090402469, 0.8798211934999639}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}, {8.043456090402469, 0.8798211934999639}, {
       8.043456090402469, 0.8798211934999639}}, {{8.043456090402469, 
       0.8798211934999639}, {7.9488036153152395`, 0.9013768822298683}, {
       7.9488036153152395`, 0.9013768822298683}, {8.043456090402469, 
       0.8798211934999639}, {8.043456090402469, 0.8798211934999639}}, {{
       8.043456090402469, 0.8798211934999639}, {7.9488036153152395`, 
       0.9013768822298683}, {7.9488036153152395`, 0.9013768822298683}, {
       8.043456090402469, 0.8798211934999639}, {8.043456090402469, 
       0.8798211934999639}}, {{8.043456090402469, 0.8798211934999639}, {
       7.9488036153152395`, 0.9013768822298683}, {7.9488036153152395`, 
       0.9013768822298683}, {8.043456090402469, 0.8798211934999639}, {
       8.043456090402469, 0.8798211934999639}}, {{7.9488036153152395`, 
       1.1861512965965177`}, {8.043456090402469, 1.2077069853264222`}, {
       8.043456090402469, 1.2077069853264222`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}}, {{
       7.9488036153152395`, 1.1861512965965177`}, {8.043456090402469, 
       1.2077069853264222`}, {8.043456090402469, 1.2077069853264222`}, {
       7.9488036153152395`, 1.1861512965965177`}, {7.9488036153152395`, 
       1.1861512965965177`}}, {{7.9488036153152395`, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}, {7.9488036153152395`, 1.1861512965965177`}, {
       7.9488036153152395`, 1.1861512965965177`}}, {{7.9488036153152395`, 
       1.1861512965965177`}, {8.043456090402469, 1.2077069853264222`}, {
       8.043456090402469, 1.2077069853264222`}, {7.9488036153152395`, 
       1.1861512965965177`}, {7.9488036153152395`, 1.1861512965965177`}}, {{
       8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}}, {{8.043456090402469, 1.2077069853264222`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}, {8.043456090402469, 1.2077069853264222`}, {
       8.043456090402469, 1.2077069853264222`}}, {{8.043456090402469, 
       1.2077069853264222`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}, {8.043456090402469, 
       1.2077069853264222`}, {8.043456090402469, 1.2077069853264222`}}, {{
       8.043456090402469, 1.2077069853264222`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}, {
       8.043456090402469, 1.2077069853264222`}, {8.043456090402469, 
       1.2077069853264222`}}, {{8.113218200108143, 1.1861512965965177`}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}}, {{8.113218200108143, 
       1.1861512965965177`}, {8.166767028997146, 1.1365133817347597`}, {
       8.166767028997146, 1.1365133817347597`}, {8.113218200108143, 
       1.1861512965965177`}, {8.113218200108143, 1.1861512965965177`}}, {{
       8.113218200108143, 1.1861512965965177`}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}, {
       8.113218200108143, 1.1861512965965177`}, {8.113218200108143, 
       1.1861512965965177`}}, {{8.113218200108143, 1.1861512965965177`}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}, {8.113218200108143, 1.1861512965965177`}, {
       8.113218200108143, 1.1861512965965177`}}, {{8.166767028997146, 
       1.1365133817347597`}, {8.195425492504594, 1.043764089413193}, {
       8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}}, {{
       8.166767028997146, 1.1365133817347597`}, {8.195425492504594, 
       1.043764089413193}, {8.195425492504594, 1.043764089413193}, {
       8.166767028997146, 1.1365133817347597`}, {8.166767028997146, 
       1.1365133817347597`}}, {{8.166767028997146, 1.1365133817347597`}, {
       8.195425492504594, 1.043764089413193}, {8.195425492504594, 
       1.043764089413193}, {8.166767028997146, 1.1365133817347597`}, {
       8.166767028997146, 1.1365133817347597`}}, {{8.166767028997146, 
       1.1365133817347597`}, {8.195425492504594, 1.043764089413193}, {
       8.195425492504594, 1.043764089413193}, {8.166767028997146, 
       1.1365133817347597`}, {8.166767028997146, 1.1365133817347597`}}, {{
       7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`, 
       1.404466680805723}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.847350158338827, 
       1.463746232324767}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}, {{7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}}, {{8.12115067855451, 
       1.463746232324767}, {8.097288129417507, 1.3865182767900777`}, {
       8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.915800288392748, 1.3451871292866786`}, {
       7.915800288392748, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {8.052700548500589, 1.3451871292866786`}, {
       8.097288129417507, 1.3865182767900777`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}}, {{
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}, {{7.915800288392748, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.097288129417507, 1.5409741878594563`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}, {8.097288129417507, 1.5409741878594563`}, {
       8.052700548500589, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.915800288392748, 1.5823053353628553`}, {
       7.915800288392748, 1.5823053353628553`}}, {{8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}}, {{
       7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`, 
       1.404466680805723}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}, {{7.915800288392748, 1.3451871292866786`}, {
       7.8608501915858735`, 1.404466680805723}, {7.8608501915858735`, 
       1.404466680805723}, {7.915800288392748, 1.3451871292866786`}, {
       7.915800288392748, 1.3451871292866786`}}, {{7.915800288392748, 
       1.3451871292866786`}, {7.8608501915858735`, 1.404466680805723}, {
       7.8608501915858735`, 1.404466680805723}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}}, {{
       7.915800288392748, 1.3451871292866786`}, {7.8608501915858735`, 
       1.404466680805723}, {7.8608501915858735`, 1.404466680805723}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}}, {{7.8608501915858735`, 1.404466680805723}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.8608501915858735`, 1.404466680805723}, {
       7.8608501915858735`, 1.404466680805723}}, {{7.8608501915858735`, 
       1.404466680805723}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}, {7.8608501915858735`, 
       1.404466680805723}, {7.8608501915858735`, 1.404466680805723}}, {{
       7.8608501915858735`, 1.404466680805723}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.404466680805723}, {7.8608501915858735`, 
       1.404466680805723}}, {{7.8608501915858735`, 1.404466680805723}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}, {7.8608501915858735`, 1.404466680805723}, {
       7.8608501915858735`, 1.404466680805723}}, {{7.847350158338827, 
       1.463746232324767}, {7.8608501915858735`, 1.523025783843811}, {
       7.8608501915858735`, 1.523025783843811}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}}, {{
       7.847350158338827, 1.463746232324767}, {7.8608501915858735`, 
       1.523025783843811}, {7.8608501915858735`, 1.523025783843811}, {
       7.847350158338827, 1.463746232324767}, {7.847350158338827, 
       1.463746232324767}}, {{7.847350158338827, 1.463746232324767}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}, {7.847350158338827, 1.463746232324767}, {
       7.847350158338827, 1.463746232324767}}, {{7.847350158338827, 
       1.463746232324767}, {7.8608501915858735`, 1.523025783843811}, {
       7.8608501915858735`, 1.523025783843811}, {7.847350158338827, 
       1.463746232324767}, {7.847350158338827, 1.463746232324767}}, {{
       7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}}, {{7.8608501915858735`, 1.523025783843811}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}, {7.8608501915858735`, 1.523025783843811}, {
       7.8608501915858735`, 1.523025783843811}}, {{7.8608501915858735`, 
       1.523025783843811}, {7.915800288392748, 1.5823053353628553`}, {
       7.915800288392748, 1.5823053353628553`}, {7.8608501915858735`, 
       1.523025783843811}, {7.8608501915858735`, 1.523025783843811}}, {{
       7.8608501915858735`, 1.523025783843811}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}, {
       7.8608501915858735`, 1.523025783843811}, {7.8608501915858735`, 
       1.523025783843811}}, {{8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}, {8.12115067855451, 1.463746232324767}, {
       8.12115067855451, 1.463746232324767}}, {{8.12115067855451, 
       1.463746232324767}, {8.097288129417507, 1.3865182767900777`}, {
       8.097288129417507, 1.3865182767900777`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}}, {{
       8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}}, {{8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}, {8.12115067855451, 1.463746232324767}, {
       8.12115067855451, 1.463746232324767}}, {{8.097288129417507, 
       1.3865182767900777`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}}, {{
       8.097288129417507, 1.3865182767900777`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}, {
       8.097288129417507, 1.3865182767900777`}, {8.097288129417507, 
       1.3865182767900777`}}, {{8.097288129417507, 1.3865182767900777`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}, {8.097288129417507, 1.3865182767900777`}, {
       8.097288129417507, 1.3865182767900777`}}, {{8.097288129417507, 
       1.3865182767900777`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}, {8.097288129417507, 
       1.3865182767900777`}, {8.097288129417507, 1.3865182767900777`}}, {{
       8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}, {{8.052700548500589, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.994612934336626, 
       1.3272387252710334`}, {8.052700548500589, 1.3451871292866786`}, {
       8.052700548500589, 1.3451871292866786`}}, {{8.052700548500589, 
       1.3451871292866786`}, {7.994612934336626, 1.3272387252710334`}, {
       7.994612934336626, 1.3272387252710334`}, {8.052700548500589, 
       1.3451871292866786`}, {8.052700548500589, 1.3451871292866786`}}, {{
       8.052700548500589, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}, {
       8.052700548500589, 1.3451871292866786`}, {8.052700548500589, 
       1.3451871292866786`}}, {{7.994612934336626, 1.3272387252710334`}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}, {7.994612934336626, 1.3272387252710334`}, {
       7.994612934336626, 1.3272387252710334`}}, {{7.994612934336626, 
       1.3272387252710334`}, {7.915800288392748, 1.3451871292866786`}, {
       7.915800288392748, 1.3451871292866786`}, {7.994612934336626, 
       1.3272387252710334`}, {7.994612934336626, 1.3272387252710334`}}, {{
       7.994612934336626, 1.3272387252710334`}, {7.915800288392748, 
       1.3451871292866786`}, {7.915800288392748, 1.3451871292866786`}, {
       7.994612934336626, 1.3272387252710334`}, {7.994612934336626, 
       1.3272387252710334`}}, {{7.994612934336626, 1.3272387252710334`}, {
       7.915800288392748, 1.3451871292866786`}, {7.915800288392748, 
       1.3451871292866786`}, {7.994612934336626, 1.3272387252710334`}, {
       7.994612934336626, 1.3272387252710334`}}, {{7.915800288392748, 
       1.5823053353628553`}, {7.994612934336626, 1.6002537393785006`}, {
       7.994612934336626, 1.6002537393785006`}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}}, {{
       7.915800288392748, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.994612934336626, 1.6002537393785006`}, {
       7.915800288392748, 1.5823053353628553`}, {7.915800288392748, 
       1.5823053353628553`}}, {{7.915800288392748, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}, {7.915800288392748, 1.5823053353628553`}, {
       7.915800288392748, 1.5823053353628553`}}, {{7.915800288392748, 
       1.5823053353628553`}, {7.994612934336626, 1.6002537393785006`}, {
       7.994612934336626, 1.6002537393785006`}, {7.915800288392748, 
       1.5823053353628553`}, {7.915800288392748, 1.5823053353628553`}}, {{
       7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}}, {{7.994612934336626, 1.6002537393785006`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}, {7.994612934336626, 1.6002537393785006`}, {
       7.994612934336626, 1.6002537393785006`}}, {{7.994612934336626, 
       1.6002537393785006`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}, {7.994612934336626, 
       1.6002537393785006`}, {7.994612934336626, 1.6002537393785006`}}, {{
       7.994612934336626, 1.6002537393785006`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}, {
       7.994612934336626, 1.6002537393785006`}, {7.994612934336626, 
       1.6002537393785006`}}, {{8.052700548500589, 1.5823053353628553`}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}}, {{8.052700548500589, 
       1.5823053353628553`}, {8.097288129417507, 1.5409741878594563`}, {
       8.097288129417507, 1.5409741878594563`}, {8.052700548500589, 
       1.5823053353628553`}, {8.052700548500589, 1.5823053353628553`}}, {{
       8.052700548500589, 1.5823053353628553`}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}, {
       8.052700548500589, 1.5823053353628553`}, {8.052700548500589, 
       1.5823053353628553`}}, {{8.052700548500589, 1.5823053353628553`}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}, {8.052700548500589, 1.5823053353628553`}, {
       8.052700548500589, 1.5823053353628553`}}, {{8.097288129417507, 
       1.5409741878594563`}, {8.12115067855451, 1.463746232324767}, {
       8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}}, {{
       8.097288129417507, 1.5409741878594563`}, {8.12115067855451, 
       1.463746232324767}, {8.12115067855451, 1.463746232324767}, {
       8.097288129417507, 1.5409741878594563`}, {8.097288129417507, 
       1.5409741878594563`}}, {{8.097288129417507, 1.5409741878594563`}, {
       8.12115067855451, 1.463746232324767}, {8.12115067855451, 
       1.463746232324767}, {8.097288129417507, 1.5409741878594563`}, {
       8.097288129417507, 1.5409741878594563`}}, {{8.097288129417507, 
       1.5409741878594563`}, {8.12115067855451, 1.463746232324767}, {
       8.12115067855451, 1.463746232324767}, {8.097288129417507, 
       1.5409741878594563`}, {8.097288129417507, 1.5409741878594563`}}, {{
       7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.899837626166705, 
       1.9584664909151566`}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}, {{7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}}, {{8.183464255091854, 
       1.9584664909151566`}, {8.158745330657535, 1.8784669910243939`}, {
       8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {7.970744283397993, 1.8356525579956955`}, {
       7.970744283397993, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.112557597860567, 1.8356525579956955`}, {
       8.158745330657535, 1.8784669910243939`}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}}, {{
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}, {{7.970744283397993, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.158745330657535, 2.038465990805919}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}, {8.158745330657535, 2.038465990805919}, {
       8.112557597860567, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {7.970744283397993, 2.0812804238346176`}, {
       7.970744283397993, 2.0812804238346176`}}, {{8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}}, {{
       7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}, {{7.970744283397993, 1.8356525579956955`}, {
       7.913822146419702, 1.897059524455426}, {7.913822146419702, 
       1.897059524455426}, {7.970744283397993, 1.8356525579956955`}, {
       7.970744283397993, 1.8356525579956955`}}, {{7.970744283397993, 
       1.8356525579956955`}, {7.913822146419702, 1.897059524455426}, {
       7.913822146419702, 1.897059524455426}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}}, {{
       7.970744283397993, 1.8356525579956955`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}}, {{7.913822146419702, 1.897059524455426}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.913822146419702, 1.897059524455426}, {
       7.913822146419702, 1.897059524455426}}, {{7.913822146419702, 
       1.897059524455426}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}, {7.913822146419702, 
       1.897059524455426}, {7.913822146419702, 1.897059524455426}}, {{
       7.913822146419702, 1.897059524455426}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 1.897059524455426}, {7.913822146419702, 
       1.897059524455426}}, {{7.913822146419702, 1.897059524455426}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}, {7.913822146419702, 1.897059524455426}, {
       7.913822146419702, 1.897059524455426}}, {{7.899837626166705, 
       1.9584664909151566`}, {7.913822146419702, 2.019873457374887}, {
       7.913822146419702, 2.019873457374887}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}}, {{
       7.899837626166705, 1.9584664909151566`}, {7.913822146419702, 
       2.019873457374887}, {7.913822146419702, 2.019873457374887}, {
       7.899837626166705, 1.9584664909151566`}, {7.899837626166705, 
       1.9584664909151566`}}, {{7.899837626166705, 1.9584664909151566`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}, {7.899837626166705, 1.9584664909151566`}, {
       7.899837626166705, 1.9584664909151566`}}, {{7.899837626166705, 
       1.9584664909151566`}, {7.913822146419702, 2.019873457374887}, {
       7.913822146419702, 2.019873457374887}, {7.899837626166705, 
       1.9584664909151566`}, {7.899837626166705, 1.9584664909151566`}}, {{
       7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}}, {{7.913822146419702, 2.019873457374887}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}, {7.913822146419702, 2.019873457374887}, {
       7.913822146419702, 2.019873457374887}}, {{7.913822146419702, 
       2.019873457374887}, {7.970744283397993, 2.0812804238346176`}, {
       7.970744283397993, 2.0812804238346176`}, {7.913822146419702, 
       2.019873457374887}, {7.913822146419702, 2.019873457374887}}, {{
       7.913822146419702, 2.019873457374887}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}, {
       7.913822146419702, 2.019873457374887}, {7.913822146419702, 
       2.019873457374887}}, {{8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}, {8.183464255091854, 1.9584664909151566`}, {
       8.183464255091854, 1.9584664909151566`}}, {{8.183464255091854, 
       1.9584664909151566`}, {8.158745330657535, 1.8784669910243939`}, {
       8.158745330657535, 1.8784669910243939`}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}}, {{
       8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}}, {{8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}, {8.183464255091854, 1.9584664909151566`}, {
       8.183464255091854, 1.9584664909151566`}}, {{8.158745330657535, 
       1.8784669910243939`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}}, {{
       8.158745330657535, 1.8784669910243939`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}, {
       8.158745330657535, 1.8784669910243939`}, {8.158745330657535, 
       1.8784669910243939`}}, {{8.158745330657535, 1.8784669910243939`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}, {8.158745330657535, 1.8784669910243939`}, {
       8.158745330657535, 1.8784669910243939`}}, {{8.158745330657535, 
       1.8784669910243939`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}, {8.158745330657535, 
       1.8784669910243939`}, {8.158745330657535, 1.8784669910243939`}}, {{
       8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}, {{8.112557597860567, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.052385344810604, 
       1.8170600245646633`}, {8.112557597860567, 1.8356525579956955`}, {
       8.112557597860567, 1.8356525579956955`}}, {{8.112557597860567, 
       1.8356525579956955`}, {8.052385344810604, 1.8170600245646633`}, {
       8.052385344810604, 1.8170600245646633`}, {8.112557597860567, 
       1.8356525579956955`}, {8.112557597860567, 1.8356525579956955`}}, {{
       8.112557597860567, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}, {
       8.112557597860567, 1.8356525579956955`}, {8.112557597860567, 
       1.8356525579956955`}}, {{8.052385344810604, 1.8170600245646633`}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}, {8.052385344810604, 1.8170600245646633`}, {
       8.052385344810604, 1.8170600245646633`}}, {{8.052385344810604, 
       1.8170600245646633`}, {7.970744283397993, 1.8356525579956955`}, {
       7.970744283397993, 1.8356525579956955`}, {8.052385344810604, 
       1.8170600245646633`}, {8.052385344810604, 1.8170600245646633`}}, {{
       8.052385344810604, 1.8170600245646633`}, {7.970744283397993, 
       1.8356525579956955`}, {7.970744283397993, 1.8356525579956955`}, {
       8.052385344810604, 1.8170600245646633`}, {8.052385344810604, 
       1.8170600245646633`}}, {{8.052385344810604, 1.8170600245646633`}, {
       7.970744283397993, 1.8356525579956955`}, {7.970744283397993, 
       1.8356525579956955`}, {8.052385344810604, 1.8170600245646633`}, {
       8.052385344810604, 1.8170600245646633`}}, {{7.970744283397993, 
       2.0812804238346176`}, {8.052385344810604, 2.09987295726565}, {
       8.052385344810604, 2.09987295726565}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}}, {{
       7.970744283397993, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.052385344810604, 2.09987295726565}, {
       7.970744283397993, 2.0812804238346176`}, {7.970744283397993, 
       2.0812804238346176`}}, {{7.970744283397993, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}, {7.970744283397993, 2.0812804238346176`}, {
       7.970744283397993, 2.0812804238346176`}}, {{7.970744283397993, 
       2.0812804238346176`}, {8.052385344810604, 2.09987295726565}, {
       8.052385344810604, 2.09987295726565}, {7.970744283397993, 
       2.0812804238346176`}, {7.970744283397993, 2.0812804238346176`}}, {{
       8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}}, {{8.052385344810604, 2.09987295726565}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}, {8.052385344810604, 2.09987295726565}, {
       8.052385344810604, 2.09987295726565}}, {{8.052385344810604, 
       2.09987295726565}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}, {8.052385344810604, 
       2.09987295726565}, {8.052385344810604, 2.09987295726565}}, {{
       8.052385344810604, 2.09987295726565}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}, {
       8.052385344810604, 2.09987295726565}, {8.052385344810604, 
       2.09987295726565}}, {{8.112557597860567, 2.0812804238346176`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}}, {{8.112557597860567, 
       2.0812804238346176`}, {8.158745330657535, 2.038465990805919}, {
       8.158745330657535, 2.038465990805919}, {8.112557597860567, 
       2.0812804238346176`}, {8.112557597860567, 2.0812804238346176`}}, {{
       8.112557597860567, 2.0812804238346176`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}, {
       8.112557597860567, 2.0812804238346176`}, {8.112557597860567, 
       2.0812804238346176`}}, {{8.112557597860567, 2.0812804238346176`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}, {8.112557597860567, 2.0812804238346176`}, {
       8.112557597860567, 2.0812804238346176`}}, {{8.158745330657535, 
       2.038465990805919}, {8.183464255091854, 1.9584664909151566`}, {
       8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}}, {{
       8.158745330657535, 2.038465990805919}, {8.183464255091854, 
       1.9584664909151566`}, {8.183464255091854, 1.9584664909151566`}, {
       8.158745330657535, 2.038465990805919}, {8.158745330657535, 
       2.038465990805919}}, {{8.158745330657535, 2.038465990805919}, {
       8.183464255091854, 1.9584664909151566`}, {8.183464255091854, 
       1.9584664909151566`}, {8.158745330657535, 2.038465990805919}, {
       8.158745330657535, 2.038465990805919}}, {{8.158745330657535, 
       2.038465990805919}, {8.183464255091854, 1.9584664909151566`}, {
       8.183464255091854, 1.9584664909151566`}, {8.158745330657535, 
       2.038465990805919}, {8.158745330657535, 2.038465990805919}}, {{
       7.9294845227575665`, 2.3384155489917986`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.9294845227575665`, 2.6006838643860903`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.853774181511164, 
       2.4695497066889445`}, {7.8687061052805785`, 2.4039826278403713`}, {
       7.9294845227575665`, 2.3384155489917986`}, {7.9294845227575665`, 
       2.3384155489917986`}}, {{7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}}, {{8.156615546496772, 
       2.4695497066889445`}, {8.130221999300465, 2.384130513727771}, {
       8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.080905205250371, 2.3384155489917986`}, {
       8.130221999300465, 2.384130513727771}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}}, {{
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}, {{7.9294845227575665`, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.130221999300465, 2.554968899650118}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}, {8.130221999300465, 2.554968899650118}, {
       8.080905205250371, 2.6006838643860903`}, {8.016656487430861, 
       2.6205359784986912`}, {7.9294845227575665`, 2.6006838643860903`}, {
       7.9294845227575665`, 2.6006838643860903`}}, {{8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}}, {{
       7.9294845227575665`, 2.3384155489917986`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.8687061052805785`, 2.4039826278403713`}, {
       7.9294845227575665`, 2.3384155489917986`}, {7.9294845227575665`, 
       2.3384155489917986`}}, {{7.9294845227575665`, 2.3384155489917986`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}}, {{7.9294845227575665`, 
       2.3384155489917986`}, {7.8687061052805785`, 2.4039826278403713`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.9294845227575665`, 
       2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}}, {{
       7.9294845227575665`, 2.3384155489917986`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.8687061052805785`, 2.4039826278403713`}, {
       7.9294845227575665`, 2.3384155489917986`}, {7.9294845227575665`, 
       2.3384155489917986`}}, {{7.8687061052805785`, 2.4039826278403713`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.8687061052805785`, 2.4039826278403713`}, {
       7.8687061052805785`, 2.4039826278403713`}}, {{7.8687061052805785`, 
       2.4039826278403713`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`, 
       2.4039826278403713`}, {7.8687061052805785`, 2.4039826278403713`}}, {{
       7.8687061052805785`, 2.4039826278403713`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.4039826278403713`}, {7.8687061052805785`, 
       2.4039826278403713`}}, {{7.8687061052805785`, 2.4039826278403713`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}, {7.8687061052805785`, 2.4039826278403713`}, {
       7.8687061052805785`, 2.4039826278403713`}}, {{7.853774181511164, 
       2.4695497066889445`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}}, {{
       7.853774181511164, 2.4695497066889445`}, {7.8687061052805785`, 
       2.5351167855375176`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.853774181511164, 2.4695497066889445`}, {7.853774181511164, 
       2.4695497066889445`}}, {{7.853774181511164, 2.4695497066889445`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.8687061052805785`, 
       2.5351167855375176`}, {7.853774181511164, 2.4695497066889445`}, {
       7.853774181511164, 2.4695497066889445`}}, {{7.853774181511164, 
       2.4695497066889445`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.853774181511164, 
       2.4695497066889445`}, {7.853774181511164, 2.4695497066889445`}}, {{
       7.8687061052805785`, 2.5351167855375176`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.9294845227575665`, 2.6006838643860903`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.8687061052805785`, 
       2.5351167855375176`}}, {{7.8687061052805785`, 2.5351167855375176`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.8687061052805785`, 2.5351167855375176`}, {
       7.8687061052805785`, 2.5351167855375176`}}, {{7.8687061052805785`, 
       2.5351167855375176`}, {7.9294845227575665`, 2.6006838643860903`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.8687061052805785`, 
       2.5351167855375176`}, {7.8687061052805785`, 2.5351167855375176`}}, {{
       7.8687061052805785`, 2.5351167855375176`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.9294845227575665`, 2.6006838643860903`}, {
       7.8687061052805785`, 2.5351167855375176`}, {7.8687061052805785`, 
       2.5351167855375176`}}, {{8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}, {8.156615546496772, 2.4695497066889445`}, {
       8.156615546496772, 2.4695497066889445`}}, {{8.156615546496772, 
       2.4695497066889445`}, {8.130221999300465, 2.384130513727771}, {
       8.130221999300465, 2.384130513727771}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}}, {{
       8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}}, {{8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}, {8.156615546496772, 2.4695497066889445`}, {
       8.156615546496772, 2.4695497066889445`}}, {{8.130221999300465, 
       2.384130513727771}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}}, {{
       8.130221999300465, 2.384130513727771}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}, {
       8.130221999300465, 2.384130513727771}, {8.130221999300465, 
       2.384130513727771}}, {{8.130221999300465, 2.384130513727771}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}, {8.130221999300465, 2.384130513727771}, {
       8.130221999300465, 2.384130513727771}}, {{8.130221999300465, 
       2.384130513727771}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}, {8.130221999300465, 
       2.384130513727771}, {8.130221999300465, 2.384130513727771}}, {{
       8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}, {{8.080905205250371, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.016656487430861, 
       2.3185634348791977`}, {8.080905205250371, 2.3384155489917986`}, {
       8.080905205250371, 2.3384155489917986`}}, {{8.080905205250371, 
       2.3384155489917986`}, {8.016656487430861, 2.3185634348791977`}, {
       8.016656487430861, 2.3185634348791977`}, {8.080905205250371, 
       2.3384155489917986`}, {8.080905205250371, 2.3384155489917986`}}, {{
       8.080905205250371, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}, {
       8.080905205250371, 2.3384155489917986`}, {8.080905205250371, 
       2.3384155489917986`}}, {{8.016656487430861, 2.3185634348791977`}, {
       7.9294845227575665`, 2.3384155489917986`}, {7.9294845227575665`, 
       2.3384155489917986`}, {8.016656487430861, 2.3185634348791977`}, {
       8.016656487430861, 2.3185634348791977`}}, {{8.016656487430861, 
       2.3185634348791977`}, {7.9294845227575665`, 2.3384155489917986`}, {
       7.9294845227575665`, 2.3384155489917986`}, {8.016656487430861, 
       2.3185634348791977`}, {8.016656487430861, 2.3185634348791977`}}, {{
       8.016656487430861, 2.3185634348791977`}, {7.9294845227575665`, 
       2.3384155489917986`}, {7.9294845227575665`, 2.3384155489917986`}, {
       8.016656487430861, 2.3185634348791977`}, {8.016656487430861, 
       2.3185634348791977`}}, {{8.016656487430861, 2.3185634348791977`}, {
       7.9294845227575665`, 2.3384155489917986`}, {7.9294845227575665`, 
       2.3384155489917986`}, {8.016656487430861, 2.3185634348791977`}, {
       8.016656487430861, 2.3185634348791977`}}, {{7.9294845227575665`, 
       2.6006838643860903`}, {8.016656487430861, 2.6205359784986912`}, {
       8.016656487430861, 2.6205359784986912`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.9294845227575665`, 2.6006838643860903`}}, {{
       7.9294845227575665`, 2.6006838643860903`}, {8.016656487430861, 
       2.6205359784986912`}, {8.016656487430861, 2.6205359784986912`}, {
       7.9294845227575665`, 2.6006838643860903`}, {7.9294845227575665`, 
       2.6006838643860903`}}, {{7.9294845227575665`, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}, {7.9294845227575665`, 2.6006838643860903`}, {
       7.9294845227575665`, 2.6006838643860903`}}, {{7.9294845227575665`, 
       2.6006838643860903`}, {8.016656487430861, 2.6205359784986912`}, {
       8.016656487430861, 2.6205359784986912`}, {7.9294845227575665`, 
       2.6006838643860903`}, {7.9294845227575665`, 2.6006838643860903`}}, {{
       8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}}, {{8.016656487430861, 2.6205359784986912`}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}, {8.016656487430861, 2.6205359784986912`}, {
       8.016656487430861, 2.6205359784986912`}}, {{8.016656487430861, 
       2.6205359784986912`}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}, {8.016656487430861, 
       2.6205359784986912`}, {8.016656487430861, 2.6205359784986912`}}, {{
       8.016656487430861, 2.6205359784986912`}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}, {
       8.016656487430861, 2.6205359784986912`}, {8.016656487430861, 
       2.6205359784986912`}}, {{8.080905205250371, 2.6006838643860903`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}}, {{8.080905205250371, 
       2.6006838643860903`}, {8.130221999300465, 2.554968899650118}, {
       8.130221999300465, 2.554968899650118}, {8.080905205250371, 
       2.6006838643860903`}, {8.080905205250371, 2.6006838643860903`}}, {{
       8.080905205250371, 2.6006838643860903`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}, {
       8.080905205250371, 2.6006838643860903`}, {8.080905205250371, 
       2.6006838643860903`}}, {{8.080905205250371, 2.6006838643860903`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}, {8.080905205250371, 2.6006838643860903`}, {
       8.080905205250371, 2.6006838643860903`}}, {{8.130221999300465, 
       2.554968899650118}, {8.156615546496772, 2.4695497066889445`}, {
       8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}}, {{
       8.130221999300465, 2.554968899650118}, {8.156615546496772, 
       2.4695497066889445`}, {8.156615546496772, 2.4695497066889445`}, {
       8.130221999300465, 2.554968899650118}, {8.130221999300465, 
       2.554968899650118}}, {{8.130221999300465, 2.554968899650118}, {
       8.156615546496772, 2.4695497066889445`}, {8.156615546496772, 
       2.4695497066889445`}, {8.130221999300465, 2.554968899650118}, {
       8.130221999300465, 2.554968899650118}}, {{8.130221999300465, 
       2.554968899650118}, {8.156615546496772, 2.4695497066889445`}, {
       8.156615546496772, 2.4695497066889445`}, {8.130221999300465, 
       2.554968899650118}, {8.130221999300465, 2.554968899650118}}, {{
       7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.841089024788153, 
       3.038135878738669}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}, {{7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}}, {{8.149369285343628, 
       3.038135878738669}, {8.122501721835429, 2.9511825952472925`}, {
       8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {7.918159089927022, 2.9046466101755053`}, {
       7.918159089927022, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.07229922020476, 2.9046466101755053`}, {
       8.122501721835429, 2.9511825952472925`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}}, {{
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}, {{7.918159089927022, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.122501721835429, 3.1250891622300454`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}, {8.122501721835429, 3.1250891622300454`}, {
       8.07229922020476, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {7.918159089927022, 3.1716251473018326`}, {
       7.918159089927022, 3.1716251473018326`}}, {{8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}}, {{
       7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}, {{7.918159089927022, 2.9046466101755053`}, {
       7.85628911923512, 2.971391244457087}, {7.85628911923512, 
       2.971391244457087}, {7.918159089927022, 2.9046466101755053`}, {
       7.918159089927022, 2.9046466101755053`}}, {{7.918159089927022, 
       2.9046466101755053`}, {7.85628911923512, 2.971391244457087}, {
       7.85628911923512, 2.971391244457087}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}}, {{
       7.918159089927022, 2.9046466101755053`}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}}, {{7.85628911923512, 2.971391244457087}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.85628911923512, 2.971391244457087}, {
       7.85628911923512, 2.971391244457087}}, {{7.85628911923512, 
       2.971391244457087}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}, {7.85628911923512, 
       2.971391244457087}, {7.85628911923512, 2.971391244457087}}, {{
       7.85628911923512, 2.971391244457087}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 2.971391244457087}, {7.85628911923512, 
       2.971391244457087}}, {{7.85628911923512, 2.971391244457087}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}, {7.85628911923512, 2.971391244457087}, {
       7.85628911923512, 2.971391244457087}}, {{7.841089024788153, 
       3.038135878738669}, {7.85628911923512, 3.104880513020251}, {
       7.85628911923512, 3.104880513020251}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}}, {{
       7.841089024788153, 3.038135878738669}, {7.85628911923512, 
       3.104880513020251}, {7.85628911923512, 3.104880513020251}, {
       7.841089024788153, 3.038135878738669}, {7.841089024788153, 
       3.038135878738669}}, {{7.841089024788153, 3.038135878738669}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}, {7.841089024788153, 3.038135878738669}, {
       7.841089024788153, 3.038135878738669}}, {{7.841089024788153, 
       3.038135878738669}, {7.85628911923512, 3.104880513020251}, {
       7.85628911923512, 3.104880513020251}, {7.841089024788153, 
       3.038135878738669}, {7.841089024788153, 3.038135878738669}}, {{
       7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}}, {{7.85628911923512, 3.104880513020251}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}, {7.85628911923512, 3.104880513020251}, {
       7.85628911923512, 3.104880513020251}}, {{7.85628911923512, 
       3.104880513020251}, {7.918159089927022, 3.1716251473018326`}, {
       7.918159089927022, 3.1716251473018326`}, {7.85628911923512, 
       3.104880513020251}, {7.85628911923512, 3.104880513020251}}, {{
       7.85628911923512, 3.104880513020251}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}, {
       7.85628911923512, 3.104880513020251}, {7.85628911923512, 
       3.104880513020251}}, {{8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}, {8.149369285343628, 3.038135878738669}, {
       8.149369285343628, 3.038135878738669}}, {{8.149369285343628, 
       3.038135878738669}, {8.122501721835429, 2.9511825952472925`}, {
       8.122501721835429, 2.9511825952472925`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}}, {{
       8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}}, {{8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}, {8.149369285343628, 3.038135878738669}, {
       8.149369285343628, 3.038135878738669}}, {{8.122501721835429, 
       2.9511825952472925`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}}, {{
       8.122501721835429, 2.9511825952472925`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}, {
       8.122501721835429, 2.9511825952472925`}, {8.122501721835429, 
       2.9511825952472925`}}, {{8.122501721835429, 2.9511825952472925`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}, {8.122501721835429, 2.9511825952472925`}, {
       8.122501721835429, 2.9511825952472925`}}, {{8.122501721835429, 
       2.9511825952472925`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}, {8.122501721835429, 
       2.9511825952472925`}, {8.122501721835429, 2.9511825952472925`}}, {{
       8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}, {{8.07229922020476, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.006896624127124, 
       2.8844379609657107`}, {8.07229922020476, 2.9046466101755053`}, {
       8.07229922020476, 2.9046466101755053`}}, {{8.07229922020476, 
       2.9046466101755053`}, {8.006896624127124, 2.8844379609657107`}, {
       8.006896624127124, 2.8844379609657107`}, {8.07229922020476, 
       2.9046466101755053`}, {8.07229922020476, 2.9046466101755053`}}, {{
       8.07229922020476, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}, {
       8.07229922020476, 2.9046466101755053`}, {8.07229922020476, 
       2.9046466101755053`}}, {{8.006896624127124, 2.8844379609657107`}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}, {8.006896624127124, 2.8844379609657107`}, {
       8.006896624127124, 2.8844379609657107`}}, {{8.006896624127124, 
       2.8844379609657107`}, {7.918159089927022, 2.9046466101755053`}, {
       7.918159089927022, 2.9046466101755053`}, {8.006896624127124, 
       2.8844379609657107`}, {8.006896624127124, 2.8844379609657107`}}, {{
       8.006896624127124, 2.8844379609657107`}, {7.918159089927022, 
       2.9046466101755053`}, {7.918159089927022, 2.9046466101755053`}, {
       8.006896624127124, 2.8844379609657107`}, {8.006896624127124, 
       2.8844379609657107`}}, {{8.006896624127124, 2.8844379609657107`}, {
       7.918159089927022, 2.9046466101755053`}, {7.918159089927022, 
       2.9046466101755053`}, {8.006896624127124, 2.8844379609657107`}, {
       8.006896624127124, 2.8844379609657107`}}, {{7.918159089927022, 
       3.1716251473018326`}, {8.006896624127124, 3.1918337965116272`}, {
       8.006896624127124, 3.1918337965116272`}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}}, {{
       7.918159089927022, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.006896624127124, 3.1918337965116272`}, {
       7.918159089927022, 3.1716251473018326`}, {7.918159089927022, 
       3.1716251473018326`}}, {{7.918159089927022, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}, {7.918159089927022, 3.1716251473018326`}, {
       7.918159089927022, 3.1716251473018326`}}, {{7.918159089927022, 
       3.1716251473018326`}, {8.006896624127124, 3.1918337965116272`}, {
       8.006896624127124, 3.1918337965116272`}, {7.918159089927022, 
       3.1716251473018326`}, {7.918159089927022, 3.1716251473018326`}}, {{
       8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}}, {{8.006896624127124, 3.1918337965116272`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}, {8.006896624127124, 3.1918337965116272`}, {
       8.006896624127124, 3.1918337965116272`}}, {{8.006896624127124, 
       3.1918337965116272`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}, {8.006896624127124, 
       3.1918337965116272`}, {8.006896624127124, 3.1918337965116272`}}, {{
       8.006896624127124, 3.1918337965116272`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}, {
       8.006896624127124, 3.1918337965116272`}, {8.006896624127124, 
       3.1918337965116272`}}, {{8.07229922020476, 3.1716251473018326`}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}}, {{8.07229922020476, 
       3.1716251473018326`}, {8.122501721835429, 3.1250891622300454`}, {
       8.122501721835429, 3.1250891622300454`}, {8.07229922020476, 
       3.1716251473018326`}, {8.07229922020476, 3.1716251473018326`}}, {{
       8.07229922020476, 3.1716251473018326`}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}, {
       8.07229922020476, 3.1716251473018326`}, {8.07229922020476, 
       3.1716251473018326`}}, {{8.07229922020476, 3.1716251473018326`}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}, {8.07229922020476, 3.1716251473018326`}, {
       8.07229922020476, 3.1716251473018326`}}, {{8.122501721835429, 
       3.1250891622300454`}, {8.149369285343628, 3.038135878738669}, {
       8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}}, {{
       8.122501721835429, 3.1250891622300454`}, {8.149369285343628, 
       3.038135878738669}, {8.149369285343628, 3.038135878738669}, {
       8.122501721835429, 3.1250891622300454`}, {8.122501721835429, 
       3.1250891622300454`}}, {{8.122501721835429, 3.1250891622300454`}, {
       8.149369285343628, 3.038135878738669}, {8.149369285343628, 
       3.038135878738669}, {8.122501721835429, 3.1250891622300454`}, {
       8.122501721835429, 3.1250891622300454`}}, {{8.122501721835429, 
       3.1250891622300454`}, {8.149369285343628, 3.038135878738669}, {
       8.149369285343628, 3.038135878738669}, {8.122501721835429, 
       3.1250891622300454`}, {8.122501721835429, 3.1250891622300454`}}, {{
       7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.814945896958113, 
       3.486354596462882}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}, {{7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}}, {{8.140981808629288, 
       3.486354596462882}, {8.112566786055362, 3.394393168232509}, {
       8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.896454874875906, 3.3451769054362535`}, {
       7.896454874875906, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {8.059472830711494, 3.3451769054362535`}, {
       8.112566786055362, 3.394393168232509}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}}, {{
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}, {{7.896454874875906, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.112566786055362, 3.5783160246932555`}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}, {8.112566786055362, 3.5783160246932555`}, {
       8.059472830711494, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.896454874875906, 3.627532287489511}, {
       7.896454874875906, 3.627532287489511}}, {{8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}}, {{
       7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}, {{7.896454874875906, 3.3451769054362535`}, {
       7.831021453147066, 3.415765750949568}, {7.831021453147066, 
       3.415765750949568}, {7.896454874875906, 3.3451769054362535`}, {
       7.896454874875906, 3.3451769054362535`}}, {{7.896454874875906, 
       3.3451769054362535`}, {7.831021453147066, 3.415765750949568}, {
       7.831021453147066, 3.415765750949568}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}}, {{
       7.896454874875906, 3.3451769054362535`}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}}, {{7.831021453147066, 3.415765750949568}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.831021453147066, 3.415765750949568}, {
       7.831021453147066, 3.415765750949568}}, {{7.831021453147066, 
       3.415765750949568}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}, {7.831021453147066, 
       3.415765750949568}, {7.831021453147066, 3.415765750949568}}, {{
       7.831021453147066, 3.415765750949568}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.415765750949568}, {7.831021453147066, 
       3.415765750949568}}, {{7.831021453147066, 3.415765750949568}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}, {7.831021453147066, 3.415765750949568}, {
       7.831021453147066, 3.415765750949568}}, {{7.814945896958113, 
       3.486354596462882}, {7.831021453147066, 3.5569434419761965`}, {
       7.831021453147066, 3.5569434419761965`}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}}, {{
       7.814945896958113, 3.486354596462882}, {7.831021453147066, 
       3.5569434419761965`}, {7.831021453147066, 3.5569434419761965`}, {
       7.814945896958113, 3.486354596462882}, {7.814945896958113, 
       3.486354596462882}}, {{7.814945896958113, 3.486354596462882}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}, {7.814945896958113, 3.486354596462882}, {
       7.814945896958113, 3.486354596462882}}, {{7.814945896958113, 
       3.486354596462882}, {7.831021453147066, 3.5569434419761965`}, {
       7.831021453147066, 3.5569434419761965`}, {7.814945896958113, 
       3.486354596462882}, {7.814945896958113, 3.486354596462882}}, {{
       7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}}, {{7.831021453147066, 3.5569434419761965`}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}, {7.831021453147066, 3.5569434419761965`}, {
       7.831021453147066, 3.5569434419761965`}}, {{7.831021453147066, 
       3.5569434419761965`}, {7.896454874875906, 3.627532287489511}, {
       7.896454874875906, 3.627532287489511}, {7.831021453147066, 
       3.5569434419761965`}, {7.831021453147066, 3.5569434419761965`}}, {{
       7.831021453147066, 3.5569434419761965`}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}, {
       7.831021453147066, 3.5569434419761965`}, {7.831021453147066, 
       3.5569434419761965`}}, {{8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}, {8.140981808629288, 3.486354596462882}, {
       8.140981808629288, 3.486354596462882}}, {{8.140981808629288, 
       3.486354596462882}, {8.112566786055362, 3.394393168232509}, {
       8.112566786055362, 3.394393168232509}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}}, {{
       8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}}, {{8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}, {8.140981808629288, 3.486354596462882}, {
       8.140981808629288, 3.486354596462882}}, {{8.112566786055362, 
       3.394393168232509}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}}, {{
       8.112566786055362, 3.394393168232509}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}, {
       8.112566786055362, 3.394393168232509}, {8.112566786055362, 
       3.394393168232509}}, {{8.112566786055362, 3.394393168232509}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}, {8.112566786055362, 3.394393168232509}, {
       8.112566786055362, 3.394393168232509}}, {{8.112566786055362, 
       3.394393168232509}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}, {8.112566786055362, 
       3.394393168232509}, {8.112566786055362, 3.394393168232509}}, {{
       8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}, {{8.059472830711494, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.990303319178672, 
       3.3238043227191945`}, {8.059472830711494, 3.3451769054362535`}, {
       8.059472830711494, 3.3451769054362535`}}, {{8.059472830711494, 
       3.3451769054362535`}, {7.990303319178672, 3.3238043227191945`}, {
       7.990303319178672, 3.3238043227191945`}, {8.059472830711494, 
       3.3451769054362535`}, {8.059472830711494, 3.3451769054362535`}}, {{
       8.059472830711494, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}, {
       8.059472830711494, 3.3451769054362535`}, {8.059472830711494, 
       3.3451769054362535`}}, {{7.990303319178672, 3.3238043227191945`}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}, {7.990303319178672, 3.3238043227191945`}, {
       7.990303319178672, 3.3238043227191945`}}, {{7.990303319178672, 
       3.3238043227191945`}, {7.896454874875906, 3.3451769054362535`}, {
       7.896454874875906, 3.3451769054362535`}, {7.990303319178672, 
       3.3238043227191945`}, {7.990303319178672, 3.3238043227191945`}}, {{
       7.990303319178672, 3.3238043227191945`}, {7.896454874875906, 
       3.3451769054362535`}, {7.896454874875906, 3.3451769054362535`}, {
       7.990303319178672, 3.3238043227191945`}, {7.990303319178672, 
       3.3238043227191945`}}, {{7.990303319178672, 3.3238043227191945`}, {
       7.896454874875906, 3.3451769054362535`}, {7.896454874875906, 
       3.3451769054362535`}, {7.990303319178672, 3.3238043227191945`}, {
       7.990303319178672, 3.3238043227191945`}}, {{7.896454874875906, 
       3.627532287489511}, {7.990303319178672, 3.64890487020657}, {
       7.990303319178672, 3.64890487020657}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}}, {{
       7.896454874875906, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.990303319178672, 3.64890487020657}, {
       7.896454874875906, 3.627532287489511}, {7.896454874875906, 
       3.627532287489511}}, {{7.896454874875906, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}, {7.896454874875906, 3.627532287489511}, {
       7.896454874875906, 3.627532287489511}}, {{7.896454874875906, 
       3.627532287489511}, {7.990303319178672, 3.64890487020657}, {
       7.990303319178672, 3.64890487020657}, {7.896454874875906, 
       3.627532287489511}, {7.896454874875906, 3.627532287489511}}, {{
       7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}}, {{7.990303319178672, 3.64890487020657}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}, {7.990303319178672, 3.64890487020657}, {
       7.990303319178672, 3.64890487020657}}, {{7.990303319178672, 
       3.64890487020657}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}, {7.990303319178672, 
       3.64890487020657}, {7.990303319178672, 3.64890487020657}}, {{
       7.990303319178672, 3.64890487020657}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}, {
       7.990303319178672, 3.64890487020657}, {7.990303319178672, 
       3.64890487020657}}, {{8.059472830711494, 3.627532287489511}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}}, {{8.059472830711494, 
       3.627532287489511}, {8.112566786055362, 3.5783160246932555`}, {
       8.112566786055362, 3.5783160246932555`}, {8.059472830711494, 
       3.627532287489511}, {8.059472830711494, 3.627532287489511}}, {{
       8.059472830711494, 3.627532287489511}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}, {
       8.059472830711494, 3.627532287489511}, {8.059472830711494, 
       3.627532287489511}}, {{8.059472830711494, 3.627532287489511}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}, {8.059472830711494, 3.627532287489511}, {
       8.059472830711494, 3.627532287489511}}, {{8.112566786055362, 
       3.5783160246932555`}, {8.140981808629288, 3.486354596462882}, {
       8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}}, {{
       8.112566786055362, 3.5783160246932555`}, {8.140981808629288, 
       3.486354596462882}, {8.140981808629288, 3.486354596462882}, {
       8.112566786055362, 3.5783160246932555`}, {8.112566786055362, 
       3.5783160246932555`}}, {{8.112566786055362, 3.5783160246932555`}, {
       8.140981808629288, 3.486354596462882}, {8.140981808629288, 
       3.486354596462882}, {8.112566786055362, 3.5783160246932555`}, {
       8.112566786055362, 3.5783160246932555`}}, {{8.112566786055362, 
       3.5783160246932555`}, {8.140981808629288, 3.486354596462882}, {
       8.140981808629288, 3.486354596462882}, {8.112566786055362, 
       3.5783160246932555`}, {8.112566786055362, 3.5783160246932555`}}, {{
       8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.192760208613171, -4.109970277582169}, {
       8.192760208613171, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}, {{
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}, {{
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.192760208613173, -4.4385048630411585`}, {
       8.192760208613173, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}, {{
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}, {{
       8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}, {{
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}, {{
       8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}, {{
       8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}, {{
       8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}, {{
       8.192760208613171, -4.4385048630411585`}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}}, {{
       8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}, {{
       8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}, {{
       8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}, {{
       8.116625155239927, -4.356371216676411}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.356371216676411}, {
       8.116625155239927, -4.356371216676411}}, {{
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}, {{
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}, {{
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}, {{
       8.097920442936747, -4.274237570311664}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}, {
       8.097920442936747, -4.274237570311664}, {
       8.097920442936747, -4.274237570311664}}, {{
       8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}, {{
       8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}, {{
       8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}, {{
       8.116625155239927, -4.192103923946917}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}, {
       8.116625155239927, -4.192103923946917}, {
       8.116625155239927, -4.192103923946917}}, {{
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}, {{
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}, {{
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}, {{
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}}, {{
       8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}, {{
       8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}, {{
       8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}, {{
       8.44421720807175, -4.381239283833752}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.44421720807175, -4.381239283833752}, {
       8.44421720807175, -4.381239283833752}}, {{
       8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}, {{
       8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}, {{
       8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}, {{
       8.382439739966022, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}, {
       8.382439739966022, -4.4385048630411585`}, {
       8.382439739966022, -4.4385048630411585`}}, {{
       8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}, {{
       8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}, {{
       8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}, {{
       8.301957559557113, -4.463372930198499}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.192760208613171, -4.4385048630411585`}, {
       8.301957559557113, -4.463372930198499}, {
       8.301957559557113, -4.463372930198499}}, {{
       8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}, {{
       8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}, {{
       8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}, {{
       8.192760208613173, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}, {
       8.192760208613173, -4.109970277582169}, {
       8.192760208613173, -4.109970277582169}}, {{
       8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}, {{
       8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}, {{
       8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}, {{
       8.301957559557113, -4.085102210424829}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}, {
       8.301957559557113, -4.085102210424829}, {
       8.301957559557113, -4.085102210424829}}, {{
       8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}, {{
       8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}, {{
       8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}, {{
       8.382439739966022, -4.109970277582169}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}, {
       8.382439739966022, -4.109970277582169}, {
       8.382439739966022, -4.109970277582169}}, {{
       8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}, {{
       8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}, {{
       8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}, {{
       8.44421720807175, -4.167235856789576}, {
       8.477279505642446, -4.274237570311664}, {
       8.477279505642446, -4.274237570311664}, {
       8.44421720807175, -4.167235856789576}, {
       8.44421720807175, -4.167235856789576}}, {{
       8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}, {{
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}, {{
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}, {{
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}, {{
       8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}, {{
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}, {{
       8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}, {{
       8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}, {{
       8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}, {{
       8.204698380148029, -3.903538835571515}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}}, {{
       8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}, {{
       8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}, {{
       8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}, {{
       8.141847629367895, -3.8357361466704187`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.8357361466704187`}, {
       8.141847629367895, -3.8357361466704187`}}, {{
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}, {{
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}, {{
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}, {{
       8.126406578770373, -3.767933457769322}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.126406578770373, -3.767933457769322}, {
       8.126406578770373, -3.767933457769322}}, {{
       8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}, {{
       8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}, {{
       8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}, {{
       8.141847629367895, -3.7001307688682257`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.141847629367895, -3.7001307688682257`}, {
       8.141847629367895, -3.7001307688682257`}}, {{
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}, {{
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}, {{
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}, {{
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}}, {{
       8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}, {{
       8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}, {{
       8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}, {{
       8.412280308637825, -3.8562651490423923`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}, {
       8.412280308637825, -3.8562651490423923`}, {
       8.412280308637825, -3.8562651490423923`}}, {{
       8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}, {{
       8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}, {{
       8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}, {{
       8.361281982903344, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.361281982903344, -3.903538835571515}, {
       8.361281982903344, -3.903538835571515}}, {{
       8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}, {{
       8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}, {{
       8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}, {{
       8.29484260657134, -3.9240678379434883`}, {
       8.204698380148029, -3.903538835571515}, {
       8.204698380148029, -3.903538835571515}, {
       8.29484260657134, -3.9240678379434883`}, {
       8.29484260657134, -3.9240678379434883`}}, {{
       8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}, {{
       8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}, {{
       8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}, {{
       8.204698380148029, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}, {
       8.204698380148029, -3.6323280799671296`}, {
       8.204698380148029, -3.6323280799671296`}}, {{
       8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}, {{
       8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}, {{
       8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}, {{
       8.29484260657134, -3.611799077595156}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.29484260657134, -3.611799077595156}, {
       8.29484260657134, -3.611799077595156}}, {{
       8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}, {{
       8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}, {{
       8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}, {{
       8.361281982903344, -3.6323280799671296`}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}, {
       8.361281982903344, -3.6323280799671296`}, {
       8.361281982903344, -3.6323280799671296`}}, {{
       8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}, {{
       8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}, {{
       8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}, {{
       8.412280308637825, -3.679601766496252}, {
       8.439573784281, -3.767933457769322}, {
       8.439573784281, -3.767933457769322}, {
       8.412280308637825, -3.679601766496252}, {
       8.412280308637825, -3.679601766496252}}, {{
       8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}, {{
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}, {{
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}, {{
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}, {{
       8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}, {{
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}, {{
       8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}, {{
       8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}, {{
       8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}, {{
       8.218324101293048, -3.4324673325833053`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}}, {{
       8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}, {{
       8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}, {{
       8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}, {{
       8.156169905265758, -3.365416079180171}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.365416079180171}, {
       8.156169905265758, -3.365416079180171}}, {{
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}, {{
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}, {{
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}, {{
       8.140899982889445, -3.2983648257770373`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.140899982889445, -3.2983648257770373`}, {
       8.140899982889445, -3.2983648257770373`}}, {{
       8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}, {{
       8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}, {{
       8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}, {{
       8.156169905265758, -3.2313135723739035`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.156169905265758, -3.2313135723739035`}, {
       8.156169905265758, -3.2313135723739035`}}, {{
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}, {{
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}, {{
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}, {{
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}}, {{
       8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}, {{
       8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}, {{
       8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}, {{
       8.423605465714797, -3.385717565190035}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.423605465714797, -3.385717565190035}, {
       8.423605465714797, -3.385717565190035}}, {{
       8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}, {{
       8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}, {{
       8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}, {{
       8.373172338100252, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.373172338100252, -3.4324673325833053`}, {
       8.373172338100252, -3.4324673325833053`}}, {{
       8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}, {{
       8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}, {{
       8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}, {{
       8.307469288109393, -3.4527688185931686`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.218324101293048, -3.4324673325833053`}, {
       8.307469288109393, -3.4527688185931686`}, {
       8.307469288109393, -3.4527688185931686`}}, {{
       8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}, {{
       8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}, {{
       8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}, {{
       8.218324101293048, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}, {
       8.218324101293048, -3.1642623189707693`}, {
       8.218324101293048, -3.1642623189707693`}}, {{
       8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}, {{
       8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}, {{
       8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}, {{
       8.307469288109393, -3.143960832960906}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.307469288109393, -3.143960832960906}, {
       8.307469288109393, -3.143960832960906}}, {{
       8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}, {{
       8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}, {{
       8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}, {{
       8.373172338100252, -3.1642623189707693`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.373172338100252, -3.1642623189707693`}, {
       8.373172338100252, -3.1642623189707693`}}, {{
       8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}, {{
       8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}, {{
       8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}, {{
       8.423605465714797, -3.2110120863640397`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.450596456503854, -3.2983648257770373`}, {
       8.423605465714797, -3.2110120863640397`}, {
       8.423605465714797, -3.2110120863640397`}}, {{
       8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}, {{
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}, {{
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}, {{
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}, {{
       8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}, {{
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}, {{
       8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}, {{
       8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}, {{
       8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}, {{
       8.188368275353428, -2.950208353873222}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}}, {{
       8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}, {{
       8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}, {{
       8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}, {{
       8.113368853447914, -2.8692998140689716`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.8692998140689716`}, {
       8.113368853447914, -2.8692998140689716`}}, {{
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}, {{
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}, {{
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}, {{
       8.09494314088198, -2.788391274264721}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.09494314088198, -2.788391274264721}, {
       8.09494314088198, -2.788391274264721}}, {{
       8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}, {{
       8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}, {{
       8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}, {{
       8.113368853447914, -2.7074827344604704`}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}, {
       8.113368853447914, -2.7074827344604704`}, {
       8.113368853447914, -2.7074827344604704`}}, {{
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}, {{
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}, {{
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}, {{
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}}, {{
       8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}, {{
       8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}, {{
       8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}, {{
       8.43607453886694, -2.893796948806168}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}, {
       8.43607453886694, -2.893796948806168}, {
       8.43607453886694, -2.893796948806168}}, {{
       8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}, {{
       8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}, {{
       8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}, {{
       8.375218544296322, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}, {
       8.375218544296322, -2.950208353873222}, {
       8.375218544296322, -2.950208353873222}}, {{
       8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}, {{
       8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}, {{
       8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}, {{
       8.29593683715977, -2.974705488610418}, {
       8.188368275353428, -2.950208353873222}, {
       8.188368275353428, -2.950208353873222}, {
       8.29593683715977, -2.974705488610418}, {
       8.29593683715977, -2.974705488610418}}, {{
       8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}, {{
       8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}, {{
       8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}, {{
       8.188368275353428, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}, {
       8.188368275353428, -2.62657419465622}, {
       8.188368275353428, -2.62657419465622}}, {{
       8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}, {{
       8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}, {{
       8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}, {{
       8.29593683715977, -2.602077059919024}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}, {
       8.29593683715977, -2.602077059919024}, {
       8.29593683715977, -2.602077059919024}}, {{
       8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}, {{
       8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}, {{
       8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}, {{
       8.375218544296322, -2.62657419465622}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}, {
       8.375218544296322, -2.62657419465622}, {
       8.375218544296322, -2.62657419465622}}, {{
       8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}, {{
       8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}, {{
       8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}, {{
       8.43607453886694, -2.682985599723274}, {
       8.46864367876777, -2.788391274264721}, {
       8.46864367876777, -2.788391274264721}, {
       8.43607453886694, -2.682985599723274}, {
       8.43607453886694, -2.682985599723274}}, {{
       8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}, {{
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}, {{
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}, {{
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}, {{
       8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}, {{
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}, {{
       8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}, {{
       8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}, {{
       8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}, {{
       8.154980072481466, -2.3802510774403176`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}}, {{
       8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}, {{
       8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}, {{
       8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}, {{
       8.087104563711513, -2.3070277356662148`}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.3070277356662148`}, {
       8.087104563711513, -2.3070277356662148`}}, {{
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}, {{
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}, {{
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}, {{
       8.070429040312982, -2.233804393892112}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}, {
       8.070429040312982, -2.233804393892112}, {
       8.070429040312982, -2.233804393892112}}, {{
       8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}, {{
       8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}, {{
       8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}, {{
       8.087104563711513, -2.160581052118009}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.087104563711513, -2.160581052118009}, {
       8.087104563711513, -2.160581052118009}}, {{
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}, {{
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}, {{
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}, {{
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}}, {{
       8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}, {{
       8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}, {{
       8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}, {{
       8.379157649245533, -2.3291979796687365`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.379157649245533, -2.3291979796687365`}, {
       8.379157649245533, -2.3291979796687365`}}, {{
       8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}, {{
       8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}, {{
       8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}, {{
       8.324082136818435, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.324082136818435, -2.3802510774403176`}, {
       8.324082136818435, -2.3802510774403176`}}, {{
       8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}, {{
       8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}, {{
       8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}, {{
       8.252331100992807, -2.4024213214428394`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.154980072481466, -2.3802510774403176`}, {
       8.252331100992807, -2.4024213214428394`}, {
       8.252331100992807, -2.4024213214428394`}}, {{
       8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}, {{
       8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}, {{
       8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}, {{
       8.154980072481466, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.154980072481466, -2.0873577103439063`}, {
       8.154980072481466, -2.0873577103439063`}}, {{
       8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}, {{
       8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}, {{
       8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}, {{
       8.252331100992807, -2.0651874663413845`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.252331100992807, -2.0651874663413845`}, {
       8.252331100992807, -2.0651874663413845`}}, {{
       8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}, {{
       8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}, {{
       8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}, {{
       8.324082136818435, -2.0873577103439063`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.324082136818435, -2.0873577103439063`}, {
       8.324082136818435, -2.0873577103439063`}}, {{
       8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}, {{
       8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}, {{
       8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}, {{
       8.379157649245533, -2.1384108081154873`}, {
       8.408633168986919, -2.233804393892112}, {
       8.408633168986919, -2.233804393892112}, {
       8.379157649245533, -2.1384108081154873`}, {
       8.379157649245533, -2.1384108081154873`}}, {{
       8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}, {{
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}, {{
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}, {{
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}, {{
       8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}, {{
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}, {{
       8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}, {{
       8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}, {{
       8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}, {{
       8.138274204066942, -1.878725551599182}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}}, {{
       8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}, {{
       8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}, {{
       8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}, {{
       8.078395120597392, -1.8141286642466163`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.8141286642466163`}, {
       8.078395120597392, -1.8141286642466163`}}, {{
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}, {{
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}, {{
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}, {{
       8.063684143463309, -1.7495317768940504`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.063684143463309, -1.7495317768940504`}, {
       8.063684143463309, -1.7495317768940504`}}, {{
       8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}, {{
       8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}, {{
       8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}, {{
       8.078395120597392, -1.6849348895414844`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.078395120597392, -1.6849348895414844`}, {
       8.078395120597392, -1.6849348895414844`}}, {{
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}, {{
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}, {{
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}, {{
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}}, {{
       8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}, {{
       8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}, {{
       8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}, {{
       8.336041382159888, -1.8336870280102913`}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}, {
       8.336041382159888, -1.8336870280102913`}, {
       8.336041382159888, -1.8336870280102913`}}, {{
       8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}, {{
       8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}, {{
       8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}, {{
       8.287454325274204, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}, {
       8.287454325274204, -1.878725551599182}, {
       8.287454325274204, -1.878725551599182}}, {{
       8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}, {{
       8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}, {{
       8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}, {{
       8.22415629125444, -1.898283915362857}, {
       8.138274204066942, -1.878725551599182}, {
       8.138274204066942, -1.878725551599182}, {
       8.22415629125444, -1.898283915362857}, {
       8.22415629125444, -1.898283915362857}}, {{
       8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}, {{
       8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}, {{
       8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}, {{
       8.138274204066942, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.138274204066942, -1.6203380021889187`}, {
       8.138274204066942, -1.6203380021889187`}}, {{
       8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}, {{
       8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}, {{
       8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}, {{
       8.22415629125444, -1.6007796384252437`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.22415629125444, -1.6007796384252437`}, {
       8.22415629125444, -1.6007796384252437`}}, {{
       8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}, {{
       8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}, {{
       8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}, {{
       8.287454325274204, -1.6203380021889187`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.287454325274204, -1.6203380021889187`}, {
       8.287454325274204, -1.6203380021889187`}}, {{
       8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}, {{
       8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}, {{
       8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}, {{
       8.336041382159888, -1.6653765257778095`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.362044385877837, -1.7495317768940504`}, {
       8.336041382159888, -1.6653765257778095`}, {
       8.336041382159888, -1.6653765257778095`}}, {{
       8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}, {{
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}, {{
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}, {{
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}, {{
       8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}, {{
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}, {{
       8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}, {{
       8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}, {{
       8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}, {{
       8.184515811533325, -1.355747838809561}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}}, {{
       8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}, {{
       8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}, {{
       8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}, {{
       8.125106893844913, -1.291658161057433}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.291658161057433}, {
       8.125106893844913, -1.291658161057433}}, {{
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}, {{
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}, {{
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}, {{
       8.11051142612839, -1.2275684833053049`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.11051142612839, -1.2275684833053049`}, {
       8.11051142612839, -1.2275684833053049`}}, {{
       8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}, {{
       8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}, {{
       8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}, {{
       8.125106893844913, -1.1634788055531768`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.125106893844913, -1.1634788055531768`}, {
       8.125106893844913, -1.1634788055531768`}}, {{
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}, {{
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}, {{
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}, {{
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}}, {{
       8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}, {{
       8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}, {{
       8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}, {{
       8.380730137538634, -1.3110629541108716`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}, {
       8.380730137538634, -1.3110629541108716`}, {
       8.380730137538634, -1.3110629541108716`}}, {{
       8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}, {{
       8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}, {{
       8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}, {{
       8.332524582343195, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.332524582343195, -1.355747838809561}, {
       8.332524582343195, -1.355747838809561}}, {{
       8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}, {{
       8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}, {{
       8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}, {{
       8.269723559431233, -1.3751526318629996`}, {
       8.184515811533325, -1.355747838809561}, {
       8.184515811533325, -1.355747838809561}, {
       8.269723559431233, -1.3751526318629996`}, {
       8.269723559431233, -1.3751526318629996`}}, {{
       8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}, {{
       8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}, {{
       8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}, {{
       8.184515811533325, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.184515811533325, -1.0993891278010488`}, {
       8.184515811533325, -1.0993891278010488`}}, {{
       8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}, {{
       8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}, {{
       8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}, {{
       8.269723559431233, -1.0799843347476101`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.269723559431233, -1.0799843347476101`}, {
       8.269723559431233, -1.0799843347476101`}}, {{
       8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}, {{
       8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}, {{
       8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}, {{
       8.332524582343195, -1.0993891278010488`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.332524582343195, -1.0993891278010488`}, {
       8.332524582343195, -1.0993891278010488`}}, {{
       8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}, {{
       8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}, {{
       8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}, {{
       8.380730137538634, -1.1440740124997382`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.40652896774813, -1.2275684833053049`}, {
       8.380730137538634, -1.1440740124997382`}, {
       8.380730137538634, -1.1440740124997382`}}, {{
       8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}, {{
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}, {{
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}, {{
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}, {{
       8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}, {{
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}, {{
       8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}, {{
       8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}, {{
       8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}, {{
       8.190221155968628, -0.9163786397586562}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}}, {{
       8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}, {{
       8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}, {{
       8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}, {{
       8.1192616576781, -0.8398283244887367}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.8398283244887367}, {
       8.1192616576781, -0.8398283244887367}}, {{
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}, {{
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}, {{
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}, {{
       8.10182846571335, -0.7632780092188172}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}, {
       8.10182846571335, -0.7632780092188172}, {
       8.10182846571335, -0.7632780092188172}}, {{
       8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}, {{
       8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}, {{
       8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}, {{
       8.1192616576781, -0.6867276939488977}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}, {
       8.1192616576781, -0.6867276939488977}, {
       8.1192616576781, -0.6867276939488977}}, {{
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}, {{
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}, {{
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}, {{
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}}, {{
       8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}, {{
       8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}, {{
       8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}, {{
       8.424584458188265, -0.8630058950131718}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}, {
       8.424584458188265, -0.8630058950131718}, {
       8.424584458188265, -0.8630058950131718}}, {{
       8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}, {{
       8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}, {{
       8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}, {{
       8.367006536479183, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}, {
       8.367006536479183, -0.9163786397586562}, {
       8.367006536479183, -0.9163786397586562}}, {{
       8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}, {{
       8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}, {{
       8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}, {{
       8.29199542280535, -0.9395562102830913}, {
       8.190221155968628, -0.9163786397586562}, {
       8.190221155968628, -0.9163786397586562}, {
       8.29199542280535, -0.9395562102830913}, {
       8.29199542280535, -0.9395562102830913}}, {{
       8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}, {{
       8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}, {{
       8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}, {{
       8.190221155968628, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}, {
       8.190221155968628, -0.6101773786789781}, {
       8.190221155968628, -0.6101773786789781}}, {{
       8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}, {{
       8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}, {{
       8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}, {{
       8.29199542280535, -0.586999808154543}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}, {
       8.29199542280535, -0.586999808154543}, {
       8.29199542280535, -0.586999808154543}}, {{
       8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}, {{
       8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}, {{
       8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}, {{
       8.367006536479183, -0.6101773786789781}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}, {
       8.367006536479183, -0.6101773786789781}, {
       8.367006536479183, -0.6101773786789781}}, {{
       8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}, {{
       8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}, {{
       8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}, {{
       8.424584458188265, -0.6635501234244625}, {
       8.45539922673446, -0.7632780092188172}, {
       8.45539922673446, -0.7632780092188172}, {
       8.424584458188265, -0.6635501234244625}, {
       8.424584458188265, -0.6635501234244625}}, {{
       8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.0879278476739053}, {
       8.181359566928423, -0.0879278476739053}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937394}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}, {{
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}, {{
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}, {{
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}, {{
       8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.2360349742204613}, {
       8.437888635070092, -0.2360349742204613}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}, {{
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}, {{
       8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}, {{
       8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}, {{
       8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}, {{
       8.181359566928423, -0.3841421007670174}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}}, {{
       8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}, {{
       8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}, {{
       8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}, {{
       8.112714471503683, -0.3100885374937393}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.3100885374937393}, {
       8.112714471503683, -0.3100885374937393}}, {{
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}, {{
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}, {{
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}, {{
       8.095849877547867, -0.23603497422046132`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.112714471503683, -0.16198141094718332`}, {
       8.095849877547867, -0.23603497422046132`}, {
       8.095849877547867, -0.23603497422046132`}}, {{
       8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}, {{
       8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}, {{
       8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}, {{
       8.112714471503683, -0.16198141094718327`}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}, {
       8.112714471503683, -0.16198141094718327`}, {
       8.112714471503683, -0.16198141094718327`}}, {{
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}, {{
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}, {{
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}, {{
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}}, {{
       8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}, {{
       8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}, {{
       8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}, {{
       8.408078915747044, -0.3325101523401327}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}, {
       8.408078915747044, -0.3325101523401327}, {
       8.408078915747044, -0.3325101523401327}}, {{
       8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}, {{
       8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}, {{
       8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}, {{
       8.352378945689535, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.352378945689535, -0.3841421007670174}, {
       8.352378945689535, -0.3841421007670174}}, {{
       8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}, {{
       8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}, {{
       8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}, {{
       8.27981438167621, -0.40656371561341076`}, {
       8.181359566928423, -0.3841421007670174}, {
       8.181359566928423, -0.3841421007670174}, {
       8.27981438167621, -0.40656371561341076`}, {
       8.27981438167621, -0.40656371561341076`}}, {{
       8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}, {{
       8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}, {{
       8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}, {{
       8.181359566928423, -0.08792784767390527}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}, {
       8.181359566928423, -0.08792784767390527}, {
       8.181359566928423, -0.08792784767390527}}, {{
       8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}, {{
       8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}, {{
       8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}, {{
       8.27981438167621, -0.06550623282751192}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}, {
       8.27981438167621, -0.06550623282751192}, {
       8.27981438167621, -0.06550623282751192}}, {{
       8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}, {{
       8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}, {{
       8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}, {{
       8.352378945689535, -0.0879278476739053}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.352378945689535, -0.0879278476739053}, {
       8.352378945689535, -0.0879278476739053}}, {{
       8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}, {{
       8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}, {{
       8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}, {{
       8.408078915747044, -0.13955979610078995`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.437888635070092, -0.23603497422046135`}, {
       8.408078915747044, -0.13955979610078995`}, {
       8.408078915747044, -0.13955979610078995`}}, {{8.144016249758415, 
       0.07964271720908606}, {8.080273670568955, 0.14840750065066233`}, {
       8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.28593706753381487`}, {8.144016249758415, 0.3547018509753911}, {
       8.144016249758415, 0.3547018509753911}, {8.080273670568955, 
       0.2859370675338148}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066227`}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}}, {{
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}, {{8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.12758719949063657`}, {8.302821714681457, 
       0.07964271720908606}, {8.235439588699286, 0.0588224160490603}, {
       8.144016249758415, 0.07964271720908603}, {8.144016249758415, 
       0.07964271720908603}, {8.235439588699286, 0.0588224160490603}, {
       8.302821714681457, 0.07964271720908606}, {8.354543687391567, 
       0.12758719949063657`}, {8.382224447142978, 0.21717228409223854`}, {
       8.382224447142978, 0.21717228409223854`}}, {{8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}}, {{
       8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.302821714681457, 0.3547018509753911}, {
       8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.2171722840922386}, {8.382224447142978, 0.2171722840922386}, {
       8.354543687391567, 0.30675736869384057`}, {8.302821714681457, 
       0.3547018509753911}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}, {{8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}}, {{8.144016249758415, 
       0.07964271720908606}, {8.080273670568955, 0.14840750065066233`}, {
       8.080273670568955, 0.14840750065066233`}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}}, {{
       8.144016249758415, 0.07964271720908606}, {8.080273670568955, 
       0.14840750065066233`}, {8.080273670568955, 0.14840750065066233`}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}}, {{8.144016249758415, 0.07964271720908606}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}, {8.144016249758415, 0.07964271720908606}, {
       8.144016249758415, 0.07964271720908606}}, {{8.144016249758415, 
       0.07964271720908606}, {8.080273670568955, 0.14840750065066233`}, {
       8.080273670568955, 0.14840750065066233`}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}}, {{
       8.080273670568955, 0.14840750065066233`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}}, {{8.080273670568955, 0.14840750065066233`}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}, {8.080273670568955, 0.14840750065066233`}, {
       8.080273670568955, 0.14840750065066233`}}, {{8.080273670568955, 
       0.14840750065066233`}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.14840750065066233`}, {8.080273670568955, 0.14840750065066233`}}, {{
       8.080273670568955, 0.14840750065066233`}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.14840750065066233`}, {8.080273670568955, 
       0.14840750065066233`}}, {{8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.2859370675338148}, {8.080273670568955, 
       0.2859370675338148}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}}, {{8.064613517296895, 
       0.21717228409223857`}, {8.080273670568955, 0.2859370675338148}, {
       8.080273670568955, 0.2859370675338148}, {8.064613517296895, 
       0.21717228409223857`}, {8.064613517296895, 0.21717228409223857`}}, {{
       8.064613517296895, 0.21717228409223857`}, {8.080273670568955, 
       0.2859370675338148}, {8.080273670568955, 0.2859370675338148}, {
       8.064613517296895, 0.21717228409223857`}, {8.064613517296895, 
       0.21717228409223857`}}, {{8.064613517296895, 0.21717228409223857`}, {
       8.080273670568955, 0.2859370675338148}, {8.080273670568955, 
       0.2859370675338148}, {8.064613517296895, 0.21717228409223857`}, {
       8.064613517296895, 0.21717228409223857`}}, {{8.080273670568955, 
       0.28593706753381487`}, {8.144016249758415, 0.3547018509753911}, {
       8.144016249758415, 0.3547018509753911}, {8.080273670568955, 
       0.28593706753381487`}, {8.080273670568955, 0.28593706753381487`}}, {{
       8.080273670568955, 0.28593706753381487`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}, {
       8.080273670568955, 0.28593706753381487`}, {8.080273670568955, 
       0.28593706753381487`}}, {{8.080273670568955, 0.28593706753381487`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}, {8.080273670568955, 0.28593706753381487`}, {
       8.080273670568955, 0.28593706753381487`}}, {{8.080273670568955, 
       0.28593706753381487`}, {8.144016249758415, 0.3547018509753911}, {
       8.144016249758415, 0.3547018509753911}, {8.080273670568955, 
       0.28593706753381487`}, {8.080273670568955, 0.28593706753381487`}}, {{
       8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}, {{8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.12758719949063657`}, {8.354543687391567, 
       0.12758719949063657`}, {8.382224447142978, 0.21717228409223854`}, {
       8.382224447142978, 0.21717228409223854`}}, {{8.382224447142978, 
       0.21717228409223854`}, {8.354543687391567, 0.12758719949063657`}, {
       8.354543687391567, 0.12758719949063657`}, {8.382224447142978, 
       0.21717228409223854`}, {8.382224447142978, 0.21717228409223854`}}, {{
       8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}}, {{8.354543687391567, 0.12758719949063657`}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.354543687391567, 0.12758719949063657`}, {
       8.354543687391567, 0.12758719949063657`}}, {{8.354543687391567, 
       0.12758719949063657`}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}, {8.354543687391567, 
       0.12758719949063657`}, {8.354543687391567, 0.12758719949063657`}}, {{
       8.354543687391567, 0.12758719949063657`}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}, {
       8.354543687391567, 0.12758719949063657`}, {8.354543687391567, 
       0.12758719949063657`}}, {{8.354543687391567, 0.12758719949063657`}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}, {8.354543687391567, 0.12758719949063657`}, {
       8.354543687391567, 0.12758719949063657`}}, {{8.302821714681457, 
       0.07964271720908606}, {8.235439588699286, 0.0588224160490603}, {
       8.235439588699286, 0.0588224160490603}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}}, {{
       8.302821714681457, 0.07964271720908606}, {8.235439588699286, 
       0.0588224160490603}, {8.235439588699286, 0.0588224160490603}, {
       8.302821714681457, 0.07964271720908606}, {8.302821714681457, 
       0.07964271720908606}}, {{8.302821714681457, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}, {8.302821714681457, 0.07964271720908606}, {
       8.302821714681457, 0.07964271720908606}}, {{8.302821714681457, 
       0.07964271720908606}, {8.235439588699286, 0.0588224160490603}, {
       8.235439588699286, 0.0588224160490603}, {8.302821714681457, 
       0.07964271720908606}, {8.302821714681457, 0.07964271720908606}}, {{
       8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}}, {{8.235439588699286, 0.0588224160490603}, {
       8.144016249758415, 0.07964271720908606}, {8.144016249758415, 
       0.07964271720908606}, {8.235439588699286, 0.0588224160490603}, {
       8.235439588699286, 0.0588224160490603}}, {{8.235439588699286, 
       0.0588224160490603}, {8.144016249758415, 0.07964271720908606}, {
       8.144016249758415, 0.07964271720908606}, {8.235439588699286, 
       0.0588224160490603}, {8.235439588699286, 0.0588224160490603}}, {{
       8.235439588699286, 0.0588224160490603}, {8.144016249758415, 
       0.07964271720908606}, {8.144016249758415, 0.07964271720908606}, {
       8.235439588699286, 0.0588224160490603}, {8.235439588699286, 
       0.0588224160490603}}, {{8.144016249758415, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}, {8.144016249758415, 0.3547018509753911}, {
       8.144016249758415, 0.3547018509753911}}, {{8.144016249758415, 
       0.3547018509753911}, {8.235439588699286, 0.37552215213541684`}, {
       8.235439588699286, 0.37552215213541684`}, {8.144016249758415, 
       0.3547018509753911}, {8.144016249758415, 0.3547018509753911}}, {{
       8.144016249758415, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}, {
       8.144016249758415, 0.3547018509753911}, {8.144016249758415, 
       0.3547018509753911}}, {{8.144016249758415, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}, {8.144016249758415, 0.3547018509753911}, {
       8.144016249758415, 0.3547018509753911}}, {{8.235439588699286, 
       0.37552215213541684`}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}}, {{
       8.235439588699286, 0.37552215213541684`}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}, {
       8.235439588699286, 0.37552215213541684`}, {8.235439588699286, 
       0.37552215213541684`}}, {{8.235439588699286, 0.37552215213541684`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}, {8.235439588699286, 0.37552215213541684`}, {
       8.235439588699286, 0.37552215213541684`}}, {{8.235439588699286, 
       0.37552215213541684`}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}, {8.235439588699286, 
       0.37552215213541684`}, {8.235439588699286, 0.37552215213541684`}}, {{
       8.302821714681457, 0.3547018509753911}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}, {{8.302821714681457, 0.3547018509753911}, {
       8.354543687391567, 0.30675736869384057`}, {8.354543687391567, 
       0.30675736869384057`}, {8.302821714681457, 0.3547018509753911}, {
       8.302821714681457, 0.3547018509753911}}, {{8.302821714681457, 
       0.3547018509753911}, {8.354543687391567, 0.30675736869384057`}, {
       8.354543687391567, 0.30675736869384057`}, {8.302821714681457, 
       0.3547018509753911}, {8.302821714681457, 0.3547018509753911}}, {{
       8.302821714681457, 0.3547018509753911}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}, {
       8.302821714681457, 0.3547018509753911}, {8.302821714681457, 
       0.3547018509753911}}, {{8.354543687391567, 0.30675736869384057`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}, {8.354543687391567, 0.30675736869384057`}, {
       8.354543687391567, 0.30675736869384057`}}, {{8.354543687391567, 
       0.30675736869384057`}, {8.382224447142978, 0.21717228409223854`}, {
       8.382224447142978, 0.21717228409223854`}, {8.354543687391567, 
       0.30675736869384057`}, {8.354543687391567, 0.30675736869384057`}}, {{
       8.354543687391567, 0.30675736869384057`}, {8.382224447142978, 
       0.21717228409223854`}, {8.382224447142978, 0.21717228409223854`}, {
       8.354543687391567, 0.30675736869384057`}, {8.354543687391567, 
       0.30675736869384057`}}, {{8.354543687391567, 0.30675736869384057`}, {
       8.382224447142978, 0.21717228409223854`}, {8.382224447142978, 
       0.21717228409223854`}, {8.354543687391567, 0.30675736869384057`}, {
       8.354543687391567, 0.30675736869384057`}}, {{8.139432808846635, 
       0.6334419398575452}, {8.073438797266855, 0.7046355434492074}, {
       8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.8470227506325322}, {8.139432808846635, 0.9182163542241945}, {
       8.139432808846635, 0.9182163542241945}, {8.073438797266855, 
       0.8470227506325322}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}}, {{
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}, {{8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.6830798547193031}, {8.30384739363954, 
       0.6334419398575452}, {8.234085283933865, 0.6118862511276407}, {
       8.139432808846635, 0.633441939857545}, {8.139432808846635, 
       0.633441939857545}, {8.234085283933865, 0.6118862511276407}, {
       8.30384739363954, 0.6334419398575452}, {8.357396222528543, 
       0.6830798547193031}, {8.38605468603599, 0.7758291470408698}, {
       8.38605468603599, 0.7758291470408698}}, {{8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}}, {{
       8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.30384739363954, 0.9182163542241945}, {
       8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.30384739363954, 
       0.9182163542241945}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}, {{8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}}, {{8.139432808846635, 
       0.6334419398575452}, {8.073438797266855, 0.7046355434492074}, {
       8.073438797266855, 0.7046355434492074}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}}, {{
       8.139432808846635, 0.6334419398575452}, {8.073438797266855, 
       0.7046355434492074}, {8.073438797266855, 0.7046355434492074}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}}, {{8.139432808846635, 0.6334419398575452}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}, {8.139432808846635, 0.6334419398575452}, {
       8.139432808846635, 0.6334419398575452}}, {{8.139432808846635, 
       0.6334419398575452}, {8.073438797266855, 0.7046355434492074}, {
       8.073438797266855, 0.7046355434492074}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}}, {{
       8.073438797266855, 0.7046355434492074}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}}, {{8.073438797266855, 0.7046355434492074}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}, {8.073438797266855, 0.7046355434492074}, {
       8.073438797266855, 0.7046355434492074}}, {{8.073438797266855, 
       0.7046355434492074}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.7046355434492074}, {8.073438797266855, 0.7046355434492074}}, {{
       8.073438797266855, 0.7046355434492074}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.7046355434492074}, {8.073438797266855, 
       0.7046355434492074}}, {{8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}}, {{8.057225516450185, 
       0.7758291470408698}, {8.073438797266855, 0.8470227506325322}, {
       8.073438797266855, 0.8470227506325322}, {8.057225516450185, 
       0.7758291470408698}, {8.057225516450185, 0.7758291470408698}}, {{
       8.057225516450185, 0.7758291470408698}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}, {
       8.057225516450185, 0.7758291470408698}, {8.057225516450185, 
       0.7758291470408698}}, {{8.057225516450185, 0.7758291470408698}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}, {8.057225516450185, 0.7758291470408698}, {
       8.057225516450185, 0.7758291470408698}}, {{8.073438797266855, 
       0.8470227506325322}, {8.139432808846635, 0.9182163542241946}, {
       8.139432808846635, 0.9182163542241946}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}}, {{
       8.073438797266855, 0.8470227506325322}, {8.139432808846635, 
       0.9182163542241946}, {8.139432808846635, 0.9182163542241946}, {
       8.073438797266855, 0.8470227506325322}, {8.073438797266855, 
       0.8470227506325322}}, {{8.073438797266855, 0.8470227506325322}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}, {8.073438797266855, 0.8470227506325322}, {
       8.073438797266855, 0.8470227506325322}}, {{8.073438797266855, 
       0.8470227506325322}, {8.139432808846635, 0.9182163542241946}, {
       8.139432808846635, 0.9182163542241946}, {8.073438797266855, 
       0.8470227506325322}, {8.073438797266855, 0.8470227506325322}}, {{
       8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}, {{8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.6830798547193031}, {8.357396222528543, 
       0.6830798547193031}, {8.38605468603599, 0.7758291470408698}, {
       8.38605468603599, 0.7758291470408698}}, {{8.38605468603599, 
       0.7758291470408698}, {8.357396222528543, 0.6830798547193031}, {
       8.357396222528543, 0.6830798547193031}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}}, {{
       8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}}, {{8.357396222528543, 0.6830798547193031}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.357396222528543, 0.6830798547193031}, {
       8.357396222528543, 0.6830798547193031}}, {{8.357396222528543, 
       0.6830798547193031}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}, {8.357396222528543, 
       0.6830798547193031}, {8.357396222528543, 0.6830798547193031}}, {{
       8.357396222528543, 0.6830798547193031}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}, {
       8.357396222528543, 0.6830798547193031}, {8.357396222528543, 
       0.6830798547193031}}, {{8.357396222528543, 0.6830798547193031}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}, {8.357396222528543, 0.6830798547193031}, {
       8.357396222528543, 0.6830798547193031}}, {{8.30384739363954, 
       0.6334419398575452}, {8.234085283933865, 0.6118862511276407}, {
       8.234085283933865, 0.6118862511276407}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}}, {{
       8.30384739363954, 0.6334419398575452}, {8.234085283933865, 
       0.6118862511276407}, {8.234085283933865, 0.6118862511276407}, {
       8.30384739363954, 0.6334419398575452}, {8.30384739363954, 
       0.6334419398575452}}, {{8.30384739363954, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}, {8.30384739363954, 0.6334419398575452}, {
       8.30384739363954, 0.6334419398575452}}, {{8.30384739363954, 
       0.6334419398575452}, {8.234085283933865, 0.6118862511276407}, {
       8.234085283933865, 0.6118862511276407}, {8.30384739363954, 
       0.6334419398575452}, {8.30384739363954, 0.6334419398575452}}, {{
       8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}}, {{8.234085283933865, 0.6118862511276407}, {
       8.139432808846635, 0.6334419398575452}, {8.139432808846635, 
       0.6334419398575452}, {8.234085283933865, 0.6118862511276407}, {
       8.234085283933865, 0.6118862511276407}}, {{8.234085283933865, 
       0.6118862511276407}, {8.139432808846635, 0.6334419398575452}, {
       8.139432808846635, 0.6334419398575452}, {8.234085283933865, 
       0.6118862511276407}, {8.234085283933865, 0.6118862511276407}}, {{
       8.234085283933865, 0.6118862511276407}, {8.139432808846635, 
       0.6334419398575452}, {8.139432808846635, 0.6334419398575452}, {
       8.234085283933865, 0.6118862511276407}, {8.234085283933865, 
       0.6118862511276407}}, {{8.139432808846635, 0.9182163542241946}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}, {8.139432808846635, 0.9182163542241946}, {
       8.139432808846635, 0.9182163542241946}}, {{8.139432808846635, 
       0.9182163542241946}, {8.234085283933865, 0.9397720429540989}, {
       8.234085283933865, 0.9397720429540989}, {8.139432808846635, 
       0.9182163542241946}, {8.139432808846635, 0.9182163542241946}}, {{
       8.139432808846635, 0.9182163542241946}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}, {
       8.139432808846635, 0.9182163542241946}, {8.139432808846635, 
       0.9182163542241946}}, {{8.139432808846635, 0.9182163542241946}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}, {8.139432808846635, 0.9182163542241946}, {
       8.139432808846635, 0.9182163542241946}}, {{8.234085283933865, 
       0.9397720429540989}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}}, {{
       8.234085283933865, 0.9397720429540989}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}, {
       8.234085283933865, 0.9397720429540989}, {8.234085283933865, 
       0.9397720429540989}}, {{8.234085283933865, 0.9397720429540989}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}, {8.234085283933865, 0.9397720429540989}, {
       8.234085283933865, 0.9397720429540989}}, {{8.234085283933865, 
       0.9397720429540989}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}, {8.234085283933865, 
       0.9397720429540989}, {8.234085283933865, 0.9397720429540989}}, {{
       8.30384739363954, 0.9182163542241945}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}, {{8.30384739363954, 0.9182163542241945}, {
       8.357396222528543, 0.8685784393624365}, {8.357396222528543, 
       0.8685784393624365}, {8.30384739363954, 0.9182163542241945}, {
       8.30384739363954, 0.9182163542241945}}, {{8.30384739363954, 
       0.9182163542241945}, {8.357396222528543, 0.8685784393624365}, {
       8.357396222528543, 0.8685784393624365}, {8.30384739363954, 
       0.9182163542241945}, {8.30384739363954, 0.9182163542241945}}, {{
       8.30384739363954, 0.9182163542241945}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}, {
       8.30384739363954, 0.9182163542241945}, {8.30384739363954, 
       0.9182163542241945}}, {{8.357396222528543, 0.8685784393624365}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}, {8.357396222528543, 0.8685784393624365}, {
       8.357396222528543, 0.8685784393624365}}, {{8.357396222528543, 
       0.8685784393624365}, {8.38605468603599, 0.7758291470408698}, {
       8.38605468603599, 0.7758291470408698}, {8.357396222528543, 
       0.8685784393624365}, {8.357396222528543, 0.8685784393624365}}, {{
       8.357396222528543, 0.8685784393624365}, {8.38605468603599, 
       0.7758291470408698}, {8.38605468603599, 0.7758291470408698}, {
       8.357396222528543, 0.8685784393624365}, {8.357396222528543, 
       0.8685784393624365}}, {{8.357396222528543, 0.8685784393624365}, {
       8.38605468603599, 0.7758291470408698}, {8.38605468603599, 
       0.7758291470408698}, {8.357396222528543, 0.8685784393624365}, {
       8.357396222528543, 0.8685784393624365}}, {{8.206669870646468, 
       1.12703710845965}, {8.135395227908342, 1.203927398044503}, {
       8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.3577079772142093`}, {8.206669870646468, 1.4345982667990624`}, {
       8.206669870646468, 1.4345982667990624`}, {8.135395227908342, 
       1.3577079772142093`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}}, {{
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}, {{8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.1806468915800514`}, {8.384240388206003, 
       1.12703710845965}, {8.308896136100358, 1.1037566019951985`}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}, {8.308896136100358, 1.1037566019951985`}, {
       8.384240388206003, 1.12703710845965}, {8.442074024270006, 
       1.1806468915800514`}, {8.473025646985768, 1.2808176876293562`}, {
       8.473025646985768, 1.2808176876293562`}}, {{8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}}, {{
       8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.384240388206003, 1.4345982667990624`}, {
       8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.384240388206003, 
       1.4345982667990624`}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}, {{8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}}, {{8.206669870646468, 
       1.12703710845965}, {8.135395227908342, 1.203927398044503}, {
       8.135395227908342, 1.203927398044503}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}}, {{
       8.206669870646468, 1.12703710845965}, {8.135395227908342, 
       1.203927398044503}, {8.135395227908342, 1.203927398044503}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}}, {{8.206669870646468, 1.12703710845965}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}, {8.206669870646468, 1.12703710845965}, {
       8.206669870646468, 1.12703710845965}}, {{8.206669870646468, 
       1.12703710845965}, {8.135395227908342, 1.203927398044503}, {
       8.135395227908342, 1.203927398044503}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}}, {{
       8.135395227908342, 1.203927398044503}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}}, {{8.135395227908342, 1.203927398044503}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}, {8.135395227908342, 1.203927398044503}, {
       8.135395227908342, 1.203927398044503}}, {{8.135395227908342, 
       1.203927398044503}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.203927398044503}, {8.135395227908342, 1.203927398044503}}, {{
       8.135395227908342, 1.203927398044503}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.203927398044503}, {8.135395227908342, 
       1.203927398044503}}, {{8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}}, {{8.117884611866703, 
       1.2808176876293562`}, {8.135395227908342, 1.3577079772142093`}, {
       8.135395227908342, 1.3577079772142093`}, {8.117884611866703, 
       1.2808176876293562`}, {8.117884611866703, 1.2808176876293562`}}, {{
       8.117884611866703, 1.2808176876293562`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}, {
       8.117884611866703, 1.2808176876293562`}, {8.117884611866703, 
       1.2808176876293562`}}, {{8.117884611866703, 1.2808176876293562`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}, {8.117884611866703, 1.2808176876293562`}, {
       8.117884611866703, 1.2808176876293562`}}, {{8.135395227908342, 
       1.3577079772142093`}, {8.206669870646468, 1.4345982667990624`}, {
       8.206669870646468, 1.4345982667990624`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}}, {{
       8.135395227908342, 1.3577079772142093`}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}, {
       8.135395227908342, 1.3577079772142093`}, {8.135395227908342, 
       1.3577079772142093`}}, {{8.135395227908342, 1.3577079772142093`}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}, {8.135395227908342, 1.3577079772142093`}, {
       8.135395227908342, 1.3577079772142093`}}, {{8.135395227908342, 
       1.3577079772142093`}, {8.206669870646468, 1.4345982667990624`}, {
       8.206669870646468, 1.4345982667990624`}, {8.135395227908342, 
       1.3577079772142093`}, {8.135395227908342, 1.3577079772142093`}}, {{
       8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}, {{8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.1806468915800514`}, {8.442074024270006, 
       1.1806468915800514`}, {8.473025646985768, 1.2808176876293562`}, {
       8.473025646985768, 1.2808176876293562`}}, {{8.473025646985768, 
       1.2808176876293562`}, {8.442074024270006, 1.1806468915800514`}, {
       8.442074024270006, 1.1806468915800514`}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}}, {{
       8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}}, {{8.442074024270006, 1.1806468915800514`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.442074024270006, 1.1806468915800514`}, {
       8.442074024270006, 1.1806468915800514`}}, {{8.442074024270006, 
       1.1806468915800514`}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}, {8.442074024270006, 
       1.1806468915800514`}, {8.442074024270006, 1.1806468915800514`}}, {{
       8.442074024270006, 1.1806468915800514`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}, {
       8.442074024270006, 1.1806468915800514`}, {8.442074024270006, 
       1.1806468915800514`}}, {{8.442074024270006, 1.1806468915800514`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}, {8.442074024270006, 1.1806468915800514`}, {
       8.442074024270006, 1.1806468915800514`}}, {{8.384240388206003, 
       1.12703710845965}, {8.308896136100358, 1.1037566019951985`}, {
       8.308896136100358, 1.1037566019951985`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}}, {{
       8.384240388206003, 1.12703710845965}, {8.308896136100358, 
       1.1037566019951985`}, {8.308896136100358, 1.1037566019951985`}, {
       8.384240388206003, 1.12703710845965}, {8.384240388206003, 
       1.12703710845965}}, {{8.384240388206003, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}, {8.384240388206003, 1.12703710845965}, {
       8.384240388206003, 1.12703710845965}}, {{8.384240388206003, 
       1.12703710845965}, {8.308896136100358, 1.1037566019951985`}, {
       8.308896136100358, 1.1037566019951985`}, {8.384240388206003, 
       1.12703710845965}, {8.384240388206003, 1.12703710845965}}, {{
       8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}}, {{8.308896136100358, 1.1037566019951985`}, {
       8.206669870646468, 1.12703710845965}, {8.206669870646468, 
       1.12703710845965}, {8.308896136100358, 1.1037566019951985`}, {
       8.308896136100358, 1.1037566019951985`}}, {{8.308896136100358, 
       1.1037566019951985`}, {8.206669870646468, 1.12703710845965}, {
       8.206669870646468, 1.12703710845965}, {8.308896136100358, 
       1.1037566019951985`}, {8.308896136100358, 1.1037566019951985`}}, {{
       8.308896136100358, 1.1037566019951985`}, {8.206669870646468, 
       1.12703710845965}, {8.206669870646468, 1.12703710845965}, {
       8.308896136100358, 1.1037566019951985`}, {8.308896136100358, 
       1.1037566019951985`}}, {{8.206669870646468, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}, {8.206669870646468, 1.4345982667990624`}, {
       8.206669870646468, 1.4345982667990624`}}, {{8.206669870646468, 
       1.4345982667990624`}, {8.308896136100358, 1.457878773263514}, {
       8.308896136100358, 1.457878773263514}, {8.206669870646468, 
       1.4345982667990624`}, {8.206669870646468, 1.4345982667990624`}}, {{
       8.206669870646468, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}, {
       8.206669870646468, 1.4345982667990624`}, {8.206669870646468, 
       1.4345982667990624`}}, {{8.206669870646468, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}, {8.206669870646468, 1.4345982667990624`}, {
       8.206669870646468, 1.4345982667990624`}}, {{8.308896136100358, 
       1.457878773263514}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}}, {{
       8.308896136100358, 1.457878773263514}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}, {
       8.308896136100358, 1.457878773263514}, {8.308896136100358, 
       1.457878773263514}}, {{8.308896136100358, 1.457878773263514}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}, {8.308896136100358, 1.457878773263514}, {
       8.308896136100358, 1.457878773263514}}, {{8.308896136100358, 
       1.457878773263514}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}, {8.308896136100358, 
       1.457878773263514}, {8.308896136100358, 1.457878773263514}}, {{
       8.384240388206003, 1.4345982667990624`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}, {{8.384240388206003, 1.4345982667990624`}, {
       8.442074024270006, 1.380988483678661}, {8.442074024270006, 
       1.380988483678661}, {8.384240388206003, 1.4345982667990624`}, {
       8.384240388206003, 1.4345982667990624`}}, {{8.384240388206003, 
       1.4345982667990624`}, {8.442074024270006, 1.380988483678661}, {
       8.442074024270006, 1.380988483678661}, {8.384240388206003, 
       1.4345982667990624`}, {8.384240388206003, 1.4345982667990624`}}, {{
       8.384240388206003, 1.4345982667990624`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}, {
       8.384240388206003, 1.4345982667990624`}, {8.384240388206003, 
       1.4345982667990624`}}, {{8.442074024270006, 1.380988483678661}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}, {8.442074024270006, 1.380988483678661}, {
       8.442074024270006, 1.380988483678661}}, {{8.442074024270006, 
       1.380988483678661}, {8.473025646985768, 1.2808176876293562`}, {
       8.473025646985768, 1.2808176876293562`}, {8.442074024270006, 
       1.380988483678661}, {8.442074024270006, 1.380988483678661}}, {{
       8.442074024270006, 1.380988483678661}, {8.473025646985768, 
       1.2808176876293562`}, {8.473025646985768, 1.2808176876293562`}, {
       8.442074024270006, 1.380988483678661}, {8.442074024270006, 
       1.380988483678661}}, {{8.442074024270006, 1.380988483678661}, {
       8.473025646985768, 1.2808176876293562`}, {8.473025646985768, 
       1.2808176876293562`}, {8.442074024270006, 1.380988483678661}, {
       8.442074024270006, 1.380988483678661}}, {{8.163133469722204, 
       1.6272527844330726`}, {8.106211332743912, 1.6886597508928032`}, {
       8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.8114736838122643`}, {8.163133469722204, 1.8728806502719948`}, {
       8.163133469722204, 1.8728806502719948`}, {8.106211332743912, 
       1.8114736838122643`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}}, {{
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}, {{8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.670067217461771}, {8.304946784184779, 
       1.6272527844330726`}, {8.244774531134816, 1.6086602510020405`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}, {8.244774531134816, 1.6086602510020405`}, {
       8.304946784184779, 1.6272527844330726`}, {8.351134516981746, 
       1.670067217461771}, {8.375853441416066, 1.7500667173525337`}, {
       8.375853441416066, 1.7500667173525337`}}, {{8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}}, {{
       8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.304946784184779, 1.8728806502719948`}, {
       8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.304946784184779, 
       1.8728806502719948`}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}, {{8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}}, {{8.163133469722204, 
       1.6272527844330726`}, {8.106211332743912, 1.6886597508928032`}, {
       8.106211332743912, 1.6886597508928032`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}}, {{
       8.163133469722204, 1.6272527844330726`}, {8.106211332743912, 
       1.6886597508928032`}, {8.106211332743912, 1.6886597508928032`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}}, {{8.163133469722204, 1.6272527844330726`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}, {8.163133469722204, 1.6272527844330726`}, {
       8.163133469722204, 1.6272527844330726`}}, {{8.163133469722204, 
       1.6272527844330726`}, {8.106211332743912, 1.6886597508928032`}, {
       8.106211332743912, 1.6886597508928032`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}}, {{
       8.106211332743912, 1.6886597508928032`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}}, {{8.106211332743912, 1.6886597508928032`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}, {8.106211332743912, 1.6886597508928032`}, {
       8.106211332743912, 1.6886597508928032`}}, {{8.106211332743912, 
       1.6886597508928032`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.6886597508928032`}, {8.106211332743912, 1.6886597508928032`}}, {{
       8.106211332743912, 1.6886597508928032`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.6886597508928032`}, {8.106211332743912, 
       1.6886597508928032`}}, {{8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}}, {{8.092226812490917, 
       1.7500667173525337`}, {8.106211332743912, 1.8114736838122643`}, {
       8.106211332743912, 1.8114736838122643`}, {8.092226812490917, 
       1.7500667173525337`}, {8.092226812490917, 1.7500667173525337`}}, {{
       8.092226812490917, 1.7500667173525337`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}, {
       8.092226812490917, 1.7500667173525337`}, {8.092226812490917, 
       1.7500667173525337`}}, {{8.092226812490917, 1.7500667173525337`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}, {8.092226812490917, 1.7500667173525337`}, {
       8.092226812490917, 1.7500667173525337`}}, {{8.106211332743912, 
       1.8114736838122643`}, {8.163133469722204, 1.8728806502719948`}, {
       8.163133469722204, 1.8728806502719948`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}}, {{
       8.106211332743912, 1.8114736838122643`}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}, {
       8.106211332743912, 1.8114736838122643`}, {8.106211332743912, 
       1.8114736838122643`}}, {{8.106211332743912, 1.8114736838122643`}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}, {8.106211332743912, 1.8114736838122643`}, {
       8.106211332743912, 1.8114736838122643`}}, {{8.106211332743912, 
       1.8114736838122643`}, {8.163133469722204, 1.8728806502719948`}, {
       8.163133469722204, 1.8728806502719948`}, {8.106211332743912, 
       1.8114736838122643`}, {8.106211332743912, 1.8114736838122643`}}, {{
       8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}, {{8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.670067217461771}, {8.351134516981746, 
       1.670067217461771}, {8.375853441416066, 1.7500667173525337`}, {
       8.375853441416066, 1.7500667173525337`}}, {{8.375853441416066, 
       1.7500667173525337`}, {8.351134516981746, 1.670067217461771}, {
       8.351134516981746, 1.670067217461771}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}}, {{
       8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}}, {{8.351134516981746, 1.670067217461771}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.351134516981746, 1.670067217461771}, {
       8.351134516981746, 1.670067217461771}}, {{8.351134516981746, 
       1.670067217461771}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}, {8.351134516981746, 
       1.670067217461771}, {8.351134516981746, 1.670067217461771}}, {{
       8.351134516981746, 1.670067217461771}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}, {
       8.351134516981746, 1.670067217461771}, {8.351134516981746, 
       1.670067217461771}}, {{8.351134516981746, 1.670067217461771}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}, {8.351134516981746, 1.670067217461771}, {
       8.351134516981746, 1.670067217461771}}, {{8.304946784184779, 
       1.6272527844330726`}, {8.244774531134816, 1.6086602510020405`}, {
       8.244774531134816, 1.6086602510020405`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}}, {{
       8.304946784184779, 1.6272527844330726`}, {8.244774531134816, 
       1.6086602510020405`}, {8.244774531134816, 1.6086602510020405`}, {
       8.304946784184779, 1.6272527844330726`}, {8.304946784184779, 
       1.6272527844330726`}}, {{8.304946784184779, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}, {8.304946784184779, 1.6272527844330726`}, {
       8.304946784184779, 1.6272527844330726`}}, {{8.304946784184779, 
       1.6272527844330726`}, {8.244774531134816, 1.6086602510020405`}, {
       8.244774531134816, 1.6086602510020405`}, {8.304946784184779, 
       1.6272527844330726`}, {8.304946784184779, 1.6272527844330726`}}, {{
       8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}}, {{8.244774531134816, 1.6086602510020405`}, {
       8.163133469722204, 1.6272527844330726`}, {8.163133469722204, 
       1.6272527844330726`}, {8.244774531134816, 1.6086602510020405`}, {
       8.244774531134816, 1.6086602510020405`}}, {{8.244774531134816, 
       1.6086602510020405`}, {8.163133469722204, 1.6272527844330726`}, {
       8.163133469722204, 1.6272527844330726`}, {8.244774531134816, 
       1.6086602510020405`}, {8.244774531134816, 1.6086602510020405`}}, {{
       8.244774531134816, 1.6086602510020405`}, {8.163133469722204, 
       1.6272527844330726`}, {8.163133469722204, 1.6272527844330726`}, {
       8.244774531134816, 1.6086602510020405`}, {8.244774531134816, 
       1.6086602510020405`}}, {{8.163133469722204, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}, {8.163133469722204, 1.8728806502719948`}, {
       8.163133469722204, 1.8728806502719948`}}, {{8.163133469722204, 
       1.8728806502719948`}, {8.244774531134816, 1.891473183703027}, {
       8.244774531134816, 1.891473183703027}, {8.163133469722204, 
       1.8728806502719948`}, {8.163133469722204, 1.8728806502719948`}}, {{
       8.163133469722204, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}, {
       8.163133469722204, 1.8728806502719948`}, {8.163133469722204, 
       1.8728806502719948`}}, {{8.163133469722204, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}, {8.163133469722204, 1.8728806502719948`}, {
       8.163133469722204, 1.8728806502719948`}}, {{8.244774531134816, 
       1.891473183703027}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}}, {{
       8.244774531134816, 1.891473183703027}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}, {
       8.244774531134816, 1.891473183703027}, {8.244774531134816, 
       1.891473183703027}}, {{8.244774531134816, 1.891473183703027}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}, {8.244774531134816, 1.891473183703027}, {
       8.244774531134816, 1.891473183703027}}, {{8.244774531134816, 
       1.891473183703027}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}, {8.244774531134816, 
       1.891473183703027}, {8.244774531134816, 1.891473183703027}}, {{
       8.304946784184779, 1.8728806502719948`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}, {{8.304946784184779, 1.8728806502719948`}, {
       8.351134516981746, 1.8300662172432964`}, {8.351134516981746, 
       1.8300662172432964`}, {8.304946784184779, 1.8728806502719948`}, {
       8.304946784184779, 1.8728806502719948`}}, {{8.304946784184779, 
       1.8728806502719948`}, {8.351134516981746, 1.8300662172432964`}, {
       8.351134516981746, 1.8300662172432964`}, {8.304946784184779, 
       1.8728806502719948`}, {8.304946784184779, 1.8728806502719948`}}, {{
       8.304946784184779, 1.8728806502719948`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}, {
       8.304946784184779, 1.8728806502719948`}, {8.304946784184779, 
       1.8728806502719948`}}, {{8.351134516981746, 1.8300662172432964`}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}, {8.351134516981746, 1.8300662172432964`}, {
       8.351134516981746, 1.8300662172432964`}}, {{8.351134516981746, 
       1.8300662172432964`}, {8.375853441416066, 1.7500667173525337`}, {
       8.375853441416066, 1.7500667173525337`}, {8.351134516981746, 
       1.8300662172432964`}, {8.351134516981746, 1.8300662172432964`}}, {{
       8.351134516981746, 1.8300662172432964`}, {8.375853441416066, 
       1.7500667173525337`}, {8.375853441416066, 1.7500667173525337`}, {
       8.351134516981746, 1.8300662172432964`}, {8.351134516981746, 
       1.8300662172432964`}}, {{8.351134516981746, 1.8300662172432964`}, {
       8.375853441416066, 1.7500667173525337`}, {8.375853441416066, 
       1.7500667173525337`}, {8.351134516981746, 1.8300662172432964`}, {
       8.351134516981746, 1.8300662172432964`}}, {{8.136754606654145, 
       2.117616987701533}, {8.075976189177158, 2.1831840665501057`}, {
       8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.314318224247252}, {8.136754606654145, 2.3798853030958247`}, {
       8.136754606654145, 2.3798853030958247`}, {8.075976189177158, 
       2.314318224247252}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}}, {{
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}, {{8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.163331952437505}, {8.28817528914695, 
       2.117616987701533}, {8.223926571327441, 2.097764873588932}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}, {8.223926571327441, 2.097764873588932}, {
       8.28817528914695, 2.117616987701533}, {8.337492083197045, 
       2.163331952437505}, {8.363885630393352, 2.248751145398679}, {
       8.363885630393352, 2.248751145398679}}, {{8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}}, {{
       8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.28817528914695, 2.3798853030958247`}, {
       8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.28817528914695, 
       2.3798853030958247`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}, {{8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}}, {{8.136754606654145, 
       2.117616987701533}, {8.075976189177158, 2.1831840665501057`}, {
       8.075976189177158, 2.1831840665501057`}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}}, {{
       8.136754606654145, 2.117616987701533}, {8.075976189177158, 
       2.1831840665501057`}, {8.075976189177158, 2.1831840665501057`}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}}, {{8.136754606654145, 2.117616987701533}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}, {8.136754606654145, 2.117616987701533}, {
       8.136754606654145, 2.117616987701533}}, {{8.136754606654145, 
       2.117616987701533}, {8.075976189177158, 2.1831840665501057`}, {
       8.075976189177158, 2.1831840665501057`}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}}, {{
       8.075976189177158, 2.1831840665501057`}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}}, {{8.075976189177158, 2.1831840665501057`}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}, {8.075976189177158, 2.1831840665501057`}, {
       8.075976189177158, 2.1831840665501057`}}, {{8.075976189177158, 
       2.1831840665501057`}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.1831840665501057`}, {8.075976189177158, 2.1831840665501057`}}, {{
       8.075976189177158, 2.1831840665501057`}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.1831840665501057`}, {8.075976189177158, 
       2.1831840665501057`}}, {{8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}}, {{8.061044265407745, 
       2.248751145398679}, {8.075976189177158, 2.314318224247252}, {
       8.075976189177158, 2.314318224247252}, {8.061044265407745, 
       2.248751145398679}, {8.061044265407745, 2.248751145398679}}, {{
       8.061044265407745, 2.248751145398679}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}, {
       8.061044265407745, 2.248751145398679}, {8.061044265407745, 
       2.248751145398679}}, {{8.061044265407745, 2.248751145398679}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}, {8.061044265407745, 2.248751145398679}, {
       8.061044265407745, 2.248751145398679}}, {{8.075976189177158, 
       2.314318224247252}, {8.136754606654145, 2.3798853030958247`}, {
       8.136754606654145, 2.3798853030958247`}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}}, {{
       8.075976189177158, 2.314318224247252}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}, {
       8.075976189177158, 2.314318224247252}, {8.075976189177158, 
       2.314318224247252}}, {{8.075976189177158, 2.314318224247252}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}, {8.075976189177158, 2.314318224247252}, {
       8.075976189177158, 2.314318224247252}}, {{8.075976189177158, 
       2.314318224247252}, {8.136754606654145, 2.3798853030958247`}, {
       8.136754606654145, 2.3798853030958247`}, {8.075976189177158, 
       2.314318224247252}, {8.075976189177158, 2.314318224247252}}, {{
       8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}, {{8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.163331952437505}, {8.337492083197045, 
       2.163331952437505}, {8.363885630393352, 2.248751145398679}, {
       8.363885630393352, 2.248751145398679}}, {{8.363885630393352, 
       2.248751145398679}, {8.337492083197045, 2.163331952437505}, {
       8.337492083197045, 2.163331952437505}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}}, {{
       8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}}, {{8.337492083197045, 2.163331952437505}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.337492083197045, 2.163331952437505}, {
       8.337492083197045, 2.163331952437505}}, {{8.337492083197045, 
       2.163331952437505}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}, {8.337492083197045, 
       2.163331952437505}, {8.337492083197045, 2.163331952437505}}, {{
       8.337492083197045, 2.163331952437505}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}, {
       8.337492083197045, 2.163331952437505}, {8.337492083197045, 
       2.163331952437505}}, {{8.337492083197045, 2.163331952437505}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}, {8.337492083197045, 2.163331952437505}, {
       8.337492083197045, 2.163331952437505}}, {{8.28817528914695, 
       2.117616987701533}, {8.223926571327441, 2.097764873588932}, {
       8.223926571327441, 2.097764873588932}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}}, {{
       8.28817528914695, 2.117616987701533}, {8.223926571327441, 
       2.097764873588932}, {8.223926571327441, 2.097764873588932}, {
       8.28817528914695, 2.117616987701533}, {8.28817528914695, 
       2.117616987701533}}, {{8.28817528914695, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}, {8.28817528914695, 2.117616987701533}, {
       8.28817528914695, 2.117616987701533}}, {{8.28817528914695, 
       2.117616987701533}, {8.223926571327441, 2.097764873588932}, {
       8.223926571327441, 2.097764873588932}, {8.28817528914695, 
       2.117616987701533}, {8.28817528914695, 2.117616987701533}}, {{
       8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}}, {{8.223926571327441, 2.097764873588932}, {
       8.136754606654145, 2.117616987701533}, {8.136754606654145, 
       2.117616987701533}, {8.223926571327441, 2.097764873588932}, {
       8.223926571327441, 2.097764873588932}}, {{8.223926571327441, 
       2.097764873588932}, {8.136754606654145, 2.117616987701533}, {
       8.136754606654145, 2.117616987701533}, {8.223926571327441, 
       2.097764873588932}, {8.223926571327441, 2.097764873588932}}, {{
       8.223926571327441, 2.097764873588932}, {8.136754606654145, 
       2.117616987701533}, {8.136754606654145, 2.117616987701533}, {
       8.223926571327441, 2.097764873588932}, {8.223926571327441, 
       2.097764873588932}}, {{8.136754606654145, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}, {8.136754606654145, 2.3798853030958247`}, {
       8.136754606654145, 2.3798853030958247`}}, {{8.136754606654145, 
       2.3798853030958247`}, {8.223926571327441, 2.3997374172084256`}, {
       8.223926571327441, 2.3997374172084256`}, {8.136754606654145, 
       2.3798853030958247`}, {8.136754606654145, 2.3798853030958247`}}, {{
       8.136754606654145, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}, {
       8.136754606654145, 2.3798853030958247`}, {8.136754606654145, 
       2.3798853030958247`}}, {{8.136754606654145, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}, {8.136754606654145, 2.3798853030958247`}, {
       8.136754606654145, 2.3798853030958247`}}, {{8.223926571327441, 
       2.3997374172084256`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}}, {{
       8.223926571327441, 2.3997374172084256`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}, {
       8.223926571327441, 2.3997374172084256`}, {8.223926571327441, 
       2.3997374172084256`}}, {{8.223926571327441, 2.3997374172084256`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}, {8.223926571327441, 2.3997374172084256`}, {
       8.223926571327441, 2.3997374172084256`}}, {{8.223926571327441, 
       2.3997374172084256`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}, {8.223926571327441, 
       2.3997374172084256`}, {8.223926571327441, 2.3997374172084256`}}, {{
       8.28817528914695, 2.3798853030958247`}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}, {{8.28817528914695, 2.3798853030958247`}, {
       8.337492083197045, 2.3341703383598524`}, {8.337492083197045, 
       2.3341703383598524`}, {8.28817528914695, 2.3798853030958247`}, {
       8.28817528914695, 2.3798853030958247`}}, {{8.28817528914695, 
       2.3798853030958247`}, {8.337492083197045, 2.3341703383598524`}, {
       8.337492083197045, 2.3341703383598524`}, {8.28817528914695, 
       2.3798853030958247`}, {8.28817528914695, 2.3798853030958247`}}, {{
       8.28817528914695, 2.3798853030958247`}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}, {
       8.28817528914695, 2.3798853030958247`}, {8.28817528914695, 
       2.3798853030958247`}}, {{8.337492083197045, 2.3341703383598524`}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}, {8.337492083197045, 2.3341703383598524`}, {
       8.337492083197045, 2.3341703383598524`}}, {{8.337492083197045, 
       2.3341703383598524`}, {8.363885630393352, 2.248751145398679}, {
       8.363885630393352, 2.248751145398679}, {8.337492083197045, 
       2.3341703383598524`}, {8.337492083197045, 2.3341703383598524`}}, {{
       8.337492083197045, 2.3341703383598524`}, {8.363885630393352, 
       2.248751145398679}, {8.363885630393352, 2.248751145398679}, {
       8.337492083197045, 2.3341703383598524`}, {8.337492083197045, 
       2.3341703383598524`}}, {{8.337492083197045, 2.3341703383598524`}, {
       8.363885630393352, 2.248751145398679}, {8.363885630393352, 
       2.248751145398679}, {8.337492083197045, 2.3341703383598524`}, {
       8.337492083197045, 2.3341703383598524`}}, {{8.147424796089721, 
       2.591045089851107}, {8.074478892973671, 2.669738316490339}, {
       8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.827124769768803}, {8.147424796089721, 2.9058179964080346`}, {
       8.147424796089721, 2.9058179964080346`}, {8.074478892973671, 
       2.8271247697688024`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.6697383164903385`}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}}, {{
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}, {{8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.645911924609457}, {8.329159018423963, 
       2.591045089851107}, {8.252048081023087, 2.567218697970225}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}, {8.252048081023087, 2.567218697970225}, {
       8.329159018423963, 2.591045089851107}, {8.388348747773769, 
       2.645911924609457}, {8.420026129591086, 2.7484315431295707`}, {
       8.420026129591086, 2.7484315431295707`}}, {{8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}}, {{
       8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.329159018423963, 2.9058179964080346`}, {
       8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.329159018423963, 
       2.9058179964080346`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}, {{8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}}, {{8.147424796089721, 
       2.591045089851107}, {8.074478892973671, 2.669738316490339}, {
       8.074478892973671, 2.669738316490339}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}}, {{
       8.147424796089721, 2.591045089851107}, {8.074478892973671, 
       2.669738316490339}, {8.074478892973671, 2.669738316490339}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}}, {{8.147424796089721, 2.591045089851107}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}, {8.147424796089721, 2.591045089851107}, {
       8.147424796089721, 2.591045089851107}}, {{8.147424796089721, 
       2.591045089851107}, {8.074478892973671, 2.669738316490339}, {
       8.074478892973671, 2.669738316490339}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}}, {{
       8.074478892973671, 2.669738316490339}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}}, {{8.074478892973671, 2.669738316490339}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}, {8.074478892973671, 2.669738316490339}, {
       8.074478892973671, 2.669738316490339}}, {{8.074478892973671, 
       2.669738316490339}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.669738316490339}, {8.074478892973671, 2.669738316490339}}, {{
       8.074478892973671, 2.669738316490339}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.669738316490339}, {8.074478892973671, 
       2.669738316490339}}, {{8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.8271247697688024`}, {8.074478892973671, 
       2.8271247697688024`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}}, {{8.056557684922598, 
       2.7484315431295707`}, {8.074478892973671, 2.8271247697688024`}, {
       8.074478892973671, 2.8271247697688024`}, {8.056557684922598, 
       2.7484315431295707`}, {8.056557684922598, 2.7484315431295707`}}, {{
       8.056557684922598, 2.7484315431295707`}, {8.074478892973671, 
       2.8271247697688024`}, {8.074478892973671, 2.8271247697688024`}, {
       8.056557684922598, 2.7484315431295707`}, {8.056557684922598, 
       2.7484315431295707`}}, {{8.056557684922598, 2.7484315431295707`}, {
       8.074478892973671, 2.8271247697688024`}, {8.074478892973671, 
       2.8271247697688024`}, {8.056557684922598, 2.7484315431295707`}, {
       8.056557684922598, 2.7484315431295707`}}, {{8.074478892973671, 
       2.827124769768803}, {8.147424796089721, 2.9058179964080346`}, {
       8.147424796089721, 2.9058179964080346`}, {8.074478892973671, 
       2.827124769768803}, {8.074478892973671, 2.827124769768803}}, {{
       8.074478892973671, 2.827124769768803}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}, {
       8.074478892973671, 2.827124769768803}, {8.074478892973671, 
       2.827124769768803}}, {{8.074478892973671, 2.827124769768803}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}, {8.074478892973671, 2.827124769768803}, {
       8.074478892973671, 2.827124769768803}}, {{8.074478892973671, 
       2.827124769768803}, {8.147424796089721, 2.9058179964080346`}, {
       8.147424796089721, 2.9058179964080346`}, {8.074478892973671, 
       2.827124769768803}, {8.074478892973671, 2.827124769768803}}, {{
       8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}, {{8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.645911924609457}, {8.388348747773769, 
       2.645911924609457}, {8.420026129591086, 2.7484315431295707`}, {
       8.420026129591086, 2.7484315431295707`}}, {{8.420026129591086, 
       2.7484315431295707`}, {8.388348747773769, 2.645911924609457}, {
       8.388348747773769, 2.645911924609457}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}}, {{
       8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}}, {{8.388348747773769, 2.645911924609457}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.388348747773769, 2.645911924609457}, {
       8.388348747773769, 2.645911924609457}}, {{8.388348747773769, 
       2.645911924609457}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}, {8.388348747773769, 
       2.645911924609457}, {8.388348747773769, 2.645911924609457}}, {{
       8.388348747773769, 2.645911924609457}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}, {
       8.388348747773769, 2.645911924609457}, {8.388348747773769, 
       2.645911924609457}}, {{8.388348747773769, 2.645911924609457}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}, {8.388348747773769, 2.645911924609457}, {
       8.388348747773769, 2.645911924609457}}, {{8.329159018423963, 
       2.591045089851107}, {8.252048081023087, 2.567218697970225}, {
       8.252048081023087, 2.567218697970225}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}}, {{
       8.329159018423963, 2.591045089851107}, {8.252048081023087, 
       2.567218697970225}, {8.252048081023087, 2.567218697970225}, {
       8.329159018423963, 2.591045089851107}, {8.329159018423963, 
       2.591045089851107}}, {{8.329159018423963, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}, {8.329159018423963, 2.591045089851107}, {
       8.329159018423963, 2.591045089851107}}, {{8.329159018423963, 
       2.591045089851107}, {8.252048081023087, 2.567218697970225}, {
       8.252048081023087, 2.567218697970225}, {8.329159018423963, 
       2.591045089851107}, {8.329159018423963, 2.591045089851107}}, {{
       8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}}, {{8.252048081023087, 2.567218697970225}, {
       8.147424796089721, 2.591045089851107}, {8.147424796089721, 
       2.591045089851107}, {8.252048081023087, 2.567218697970225}, {
       8.252048081023087, 2.567218697970225}}, {{8.252048081023087, 
       2.567218697970225}, {8.147424796089721, 2.591045089851107}, {
       8.147424796089721, 2.591045089851107}, {8.252048081023087, 
       2.567218697970225}, {8.252048081023087, 2.567218697970225}}, {{
       8.252048081023087, 2.567218697970225}, {8.147424796089721, 
       2.591045089851107}, {8.147424796089721, 2.591045089851107}, {
       8.252048081023087, 2.567218697970225}, {8.252048081023087, 
       2.567218697970225}}, {{8.147424796089721, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}, {8.147424796089721, 2.9058179964080346`}, {
       8.147424796089721, 2.9058179964080346`}}, {{8.147424796089721, 
       2.9058179964080346`}, {8.252048081023087, 2.9296443882889163`}, {
       8.252048081023087, 2.9296443882889163`}, {8.147424796089721, 
       2.9058179964080346`}, {8.147424796089721, 2.9058179964080346`}}, {{
       8.147424796089721, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}, {
       8.147424796089721, 2.9058179964080346`}, {8.147424796089721, 
       2.9058179964080346`}}, {{8.147424796089721, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}, {8.147424796089721, 2.9058179964080346`}, {
       8.147424796089721, 2.9058179964080346`}}, {{8.252048081023087, 
       2.9296443882889163`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}}, {{
       8.252048081023087, 2.9296443882889163`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}, {
       8.252048081023087, 2.9296443882889163`}, {8.252048081023087, 
       2.9296443882889163`}}, {{8.252048081023087, 2.9296443882889163`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}, {8.252048081023087, 2.9296443882889163`}, {
       8.252048081023087, 2.9296443882889163`}}, {{8.252048081023087, 
       2.9296443882889163`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}, {8.252048081023087, 
       2.9296443882889163`}, {8.252048081023087, 2.9296443882889163`}}, {{
       8.329159018423963, 2.9058179964080346`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}, {{8.329159018423963, 2.9058179964080346`}, {
       8.388348747773769, 2.8509511616496845`}, {8.388348747773769, 
       2.8509511616496845`}, {8.329159018423963, 2.9058179964080346`}, {
       8.329159018423963, 2.9058179964080346`}}, {{8.329159018423963, 
       2.9058179964080346`}, {8.388348747773769, 2.8509511616496845`}, {
       8.388348747773769, 2.8509511616496845`}, {8.329159018423963, 
       2.9058179964080346`}, {8.329159018423963, 2.9058179964080346`}}, {{
       8.329159018423963, 2.9058179964080346`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}, {
       8.329159018423963, 2.9058179964080346`}, {8.329159018423963, 
       2.9058179964080346`}}, {{8.388348747773769, 2.8509511616496845`}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}, {8.388348747773769, 2.8509511616496845`}, {
       8.388348747773769, 2.8509511616496845`}}, {{8.388348747773769, 
       2.8509511616496845`}, {8.420026129591086, 2.7484315431295707`}, {
       8.420026129591086, 2.7484315431295707`}, {8.388348747773769, 
       2.8509511616496845`}, {8.388348747773769, 2.8509511616496845`}}, {{
       8.388348747773769, 2.8509511616496845`}, {8.420026129591086, 
       2.7484315431295707`}, {8.420026129591086, 2.7484315431295707`}, {
       8.388348747773769, 2.8509511616496845`}, {8.388348747773769, 
       2.8509511616496845`}}, {{8.388348747773769, 2.8509511616496845`}, {
       8.420026129591086, 2.7484315431295707`}, {8.420026129591086, 
       2.7484315431295707`}, {8.388348747773769, 2.8509511616496845`}, {
       8.388348747773769, 2.8509511616496845`}}, {{8.153601472936804, 
       3.103653151100236}, {8.091731502244903, 3.1703977853818177`}, {
       8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.3038870539449814`}, {8.153601472936804, 3.3706316882265632`}, {
       8.153601472936804, 3.3706316882265632`}, {8.091731502244903, 
       3.3038870539449814`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}}, {{
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}, {{8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.150189136172023}, {8.307741603214543, 
       3.103653151100236}, {8.242339007136907, 3.0834445018904413`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}, {8.242339007136907, 3.0834445018904413`}, {
       8.307741603214543, 3.103653151100236}, {8.357944104845211, 
       3.150189136172023}, {8.38481166835341, 3.2371424196633996`}, {
       8.38481166835341, 3.2371424196633996`}}, {{8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}}, {{
       8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.307741603214543, 3.3706316882265632`}, {
       8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.307741603214543, 
       3.3706316882265632`}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}, {{8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}}, {{8.153601472936804, 
       3.103653151100236}, {8.091731502244903, 3.1703977853818177`}, {
       8.091731502244903, 3.1703977853818177`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}}, {{
       8.153601472936804, 3.103653151100236}, {8.091731502244903, 
       3.1703977853818177`}, {8.091731502244903, 3.1703977853818177`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}}, {{8.153601472936804, 3.103653151100236}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}, {8.153601472936804, 3.103653151100236}, {
       8.153601472936804, 3.103653151100236}}, {{8.153601472936804, 
       3.103653151100236}, {8.091731502244903, 3.1703977853818177`}, {
       8.091731502244903, 3.1703977853818177`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}}, {{
       8.091731502244903, 3.1703977853818177`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}}, {{8.091731502244903, 3.1703977853818177`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}, {8.091731502244903, 3.1703977853818177`}, {
       8.091731502244903, 3.1703977853818177`}}, {{8.091731502244903, 
       3.1703977853818177`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.1703977853818177`}, {8.091731502244903, 3.1703977853818177`}}, {{
       8.091731502244903, 3.1703977853818177`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.1703977853818177`}, {8.091731502244903, 
       3.1703977853818177`}}, {{8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}}, {{8.076531407797937, 
       3.2371424196633996`}, {8.091731502244903, 3.3038870539449814`}, {
       8.091731502244903, 3.3038870539449814`}, {8.076531407797937, 
       3.2371424196633996`}, {8.076531407797937, 3.2371424196633996`}}, {{
       8.076531407797937, 3.2371424196633996`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}, {
       8.076531407797937, 3.2371424196633996`}, {8.076531407797937, 
       3.2371424196633996`}}, {{8.076531407797937, 3.2371424196633996`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}, {8.076531407797937, 3.2371424196633996`}, {
       8.076531407797937, 3.2371424196633996`}}, {{8.091731502244903, 
       3.3038870539449814`}, {8.153601472936804, 3.3706316882265632`}, {
       8.153601472936804, 3.3706316882265632`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}}, {{
       8.091731502244903, 3.3038870539449814`}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}, {
       8.091731502244903, 3.3038870539449814`}, {8.091731502244903, 
       3.3038870539449814`}}, {{8.091731502244903, 3.3038870539449814`}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}, {8.091731502244903, 3.3038870539449814`}, {
       8.091731502244903, 3.3038870539449814`}}, {{8.091731502244903, 
       3.3038870539449814`}, {8.153601472936804, 3.3706316882265632`}, {
       8.153601472936804, 3.3706316882265632`}, {8.091731502244903, 
       3.3038870539449814`}, {8.091731502244903, 3.3038870539449814`}}, {{
       8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}, {{8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.150189136172023}, {8.357944104845211, 
       3.150189136172023}, {8.38481166835341, 3.2371424196633996`}, {
       8.38481166835341, 3.2371424196633996`}}, {{8.38481166835341, 
       3.2371424196633996`}, {8.357944104845211, 3.150189136172023}, {
       8.357944104845211, 3.150189136172023}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}}, {{
       8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}}, {{8.357944104845211, 3.150189136172023}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.357944104845211, 3.150189136172023}, {
       8.357944104845211, 3.150189136172023}}, {{8.357944104845211, 
       3.150189136172023}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}, {8.357944104845211, 
       3.150189136172023}, {8.357944104845211, 3.150189136172023}}, {{
       8.357944104845211, 3.150189136172023}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}, {
       8.357944104845211, 3.150189136172023}, {8.357944104845211, 
       3.150189136172023}}, {{8.357944104845211, 3.150189136172023}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}, {8.357944104845211, 3.150189136172023}, {
       8.357944104845211, 3.150189136172023}}, {{8.307741603214543, 
       3.103653151100236}, {8.242339007136907, 3.0834445018904413`}, {
       8.242339007136907, 3.0834445018904413`}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}}, {{
       8.307741603214543, 3.103653151100236}, {8.242339007136907, 
       3.0834445018904413`}, {8.242339007136907, 3.0834445018904413`}, {
       8.307741603214543, 3.103653151100236}, {8.307741603214543, 
       3.103653151100236}}, {{8.307741603214543, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}, {8.307741603214543, 3.103653151100236}, {
       8.307741603214543, 3.103653151100236}}, {{8.307741603214543, 
       3.103653151100236}, {8.242339007136907, 3.0834445018904413`}, {
       8.242339007136907, 3.0834445018904413`}, {8.307741603214543, 
       3.103653151100236}, {8.307741603214543, 3.103653151100236}}, {{
       8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}}, {{8.242339007136907, 3.0834445018904413`}, {
       8.153601472936804, 3.103653151100236}, {8.153601472936804, 
       3.103653151100236}, {8.242339007136907, 3.0834445018904413`}, {
       8.242339007136907, 3.0834445018904413`}}, {{8.242339007136907, 
       3.0834445018904413`}, {8.153601472936804, 3.103653151100236}, {
       8.153601472936804, 3.103653151100236}, {8.242339007136907, 
       3.0834445018904413`}, {8.242339007136907, 3.0834445018904413`}}, {{
       8.242339007136907, 3.0834445018904413`}, {8.153601472936804, 
       3.103653151100236}, {8.153601472936804, 3.103653151100236}, {
       8.242339007136907, 3.0834445018904413`}, {8.242339007136907, 
       3.0834445018904413`}}, {{8.153601472936804, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}, {8.153601472936804, 3.3706316882265632`}, {
       8.153601472936804, 3.3706316882265632`}}, {{8.153601472936804, 
       3.3706316882265632`}, {8.242339007136907, 3.390840337436358}, {
       8.242339007136907, 3.390840337436358}, {8.153601472936804, 
       3.3706316882265632`}, {8.153601472936804, 3.3706316882265632`}}, {{
       8.153601472936804, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}, {
       8.153601472936804, 3.3706316882265632`}, {8.153601472936804, 
       3.3706316882265632`}}, {{8.153601472936804, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}, {8.153601472936804, 3.3706316882265632`}, {
       8.153601472936804, 3.3706316882265632`}}, {{8.242339007136907, 
       3.390840337436358}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}}, {{
       8.242339007136907, 3.390840337436358}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}, {
       8.242339007136907, 3.390840337436358}, {8.242339007136907, 
       3.390840337436358}}, {{8.242339007136907, 3.390840337436358}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}, {8.242339007136907, 3.390840337436358}, {
       8.242339007136907, 3.390840337436358}}, {{8.242339007136907, 
       3.390840337436358}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}, {8.242339007136907, 
       3.390840337436358}, {8.242339007136907, 3.390840337436358}}, {{
       8.307741603214543, 3.3706316882265632`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}, {{8.307741603214543, 3.3706316882265632`}, {
       8.357944104845211, 3.324095703154776}, {8.357944104845211, 
       3.324095703154776}, {8.307741603214543, 3.3706316882265632`}, {
       8.307741603214543, 3.3706316882265632`}}, {{8.307741603214543, 
       3.3706316882265632`}, {8.357944104845211, 3.324095703154776}, {
       8.357944104845211, 3.324095703154776}, {8.307741603214543, 
       3.3706316882265632`}, {8.307741603214543, 3.3706316882265632`}}, {{
       8.307741603214543, 3.3706316882265632`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}, {
       8.307741603214543, 3.3706316882265632`}, {8.307741603214543, 
       3.3706316882265632`}}, {{8.357944104845211, 3.324095703154776}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}, {8.357944104845211, 3.324095703154776}, {
       8.357944104845211, 3.324095703154776}}, {{8.357944104845211, 
       3.324095703154776}, {8.38481166835341, 3.2371424196633996`}, {
       8.38481166835341, 3.2371424196633996`}, {8.357944104845211, 
       3.324095703154776}, {8.357944104845211, 3.324095703154776}}, {{
       8.357944104845211, 3.324095703154776}, {8.38481166835341, 
       3.2371424196633996`}, {8.38481166835341, 3.2371424196633996`}, {
       8.357944104845211, 3.324095703154776}, {8.357944104845211, 
       3.324095703154776}}, {{8.357944104845211, 3.324095703154776}, {
       8.38481166835341, 3.2371424196633996`}, {8.38481166835341, 
       3.2371424196633996`}, {8.357944104845211, 3.324095703154776}, {
       8.357944104845211, 3.324095703154776}}, {{8.18965751132395, 
       3.5932634932466447`}, {8.10207204708563, 3.6877497151341636`}, {
       8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.8767221589092014`}, {8.18965751132395, 3.9712083807967202`}, {
       8.18965751132395, 3.9712083807967202`}, {8.10207204708563, 
       3.8767221589092014`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}}, {{
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}, {{8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.659141589045283}, {8.407864093889831, 
       3.5932634932466447`}, {8.315277711905317, 3.5646553671577643`}, {
       8.18965751132395, 3.5932634932466443`}, {8.18965751132395, 
       3.5932634932466443`}, {8.315277711905317, 3.5646553671577643`}, {
       8.407864093889831, 3.5932634932466447`}, {8.478932648829726, 
       3.659141589045283}, {8.51696738517277, 3.7822359370216825`}, {
       8.51696738517277, 3.7822359370216825`}}, {{8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}}, {{
       8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.407864093889831, 3.9712083807967202`}, {
       8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.407864093889831, 
       3.9712083807967202`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}, {{8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}}, {{8.18965751132395, 
       3.5932634932466447`}, {8.10207204708563, 3.6877497151341636`}, {
       8.10207204708563, 3.6877497151341636`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}}, {{
       8.18965751132395, 3.5932634932466447`}, {8.10207204708563, 
       3.6877497151341636`}, {8.10207204708563, 3.6877497151341636`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}}, {{8.18965751132395, 3.5932634932466447`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}, {8.18965751132395, 3.5932634932466447`}, {
       8.18965751132395, 3.5932634932466447`}}, {{8.18965751132395, 
       3.5932634932466447`}, {8.10207204708563, 3.6877497151341636`}, {
       8.10207204708563, 3.6877497151341636`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}}, {{
       8.10207204708563, 3.6877497151341636`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}}, {{8.10207204708563, 3.6877497151341636`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}, {8.10207204708563, 3.6877497151341636`}, {
       8.10207204708563, 3.6877497151341636`}}, {{8.10207204708563, 
       3.6877497151341636`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.6877497151341636`}, {8.10207204708563, 3.6877497151341636`}}, {{
       8.10207204708563, 3.6877497151341636`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.6877497151341636`}, {8.10207204708563, 
       3.6877497151341636`}}, {{8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}}, {{8.080554220041012, 
       3.7822359370216825`}, {8.10207204708563, 3.8767221589092014`}, {
       8.10207204708563, 3.8767221589092014`}, {8.080554220041012, 
       3.7822359370216825`}, {8.080554220041012, 3.7822359370216825`}}, {{
       8.080554220041012, 3.7822359370216825`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}, {
       8.080554220041012, 3.7822359370216825`}, {8.080554220041012, 
       3.7822359370216825`}}, {{8.080554220041012, 3.7822359370216825`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}, {8.080554220041012, 3.7822359370216825`}, {
       8.080554220041012, 3.7822359370216825`}}, {{8.10207204708563, 
       3.8767221589092014`}, {8.18965751132395, 3.9712083807967207`}, {
       8.18965751132395, 3.9712083807967207`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}}, {{
       8.10207204708563, 3.8767221589092014`}, {8.18965751132395, 
       3.9712083807967207`}, {8.18965751132395, 3.9712083807967207`}, {
       8.10207204708563, 3.8767221589092014`}, {8.10207204708563, 
       3.8767221589092014`}}, {{8.10207204708563, 3.8767221589092014`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}, {8.10207204708563, 3.8767221589092014`}, {
       8.10207204708563, 3.8767221589092014`}}, {{8.10207204708563, 
       3.8767221589092014`}, {8.18965751132395, 3.9712083807967207`}, {
       8.18965751132395, 3.9712083807967207`}, {8.10207204708563, 
       3.8767221589092014`}, {8.10207204708563, 3.8767221589092014`}}, {{
       8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}, {{8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.659141589045283}, {8.478932648829726, 
       3.659141589045283}, {8.51696738517277, 3.7822359370216825`}, {
       8.51696738517277, 3.7822359370216825`}}, {{8.51696738517277, 
       3.7822359370216825`}, {8.478932648829726, 3.659141589045283}, {
       8.478932648829726, 3.659141589045283}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}}, {{
       8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}}, {{8.478932648829726, 3.659141589045283}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.478932648829726, 3.659141589045283}, {
       8.478932648829726, 3.659141589045283}}, {{8.478932648829726, 
       3.659141589045283}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}, {8.478932648829726, 
       3.659141589045283}, {8.478932648829726, 3.659141589045283}}, {{
       8.478932648829726, 3.659141589045283}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}, {
       8.478932648829726, 3.659141589045283}, {8.478932648829726, 
       3.659141589045283}}, {{8.478932648829726, 3.659141589045283}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}, {8.478932648829726, 3.659141589045283}, {
       8.478932648829726, 3.659141589045283}}, {{8.407864093889831, 
       3.5932634932466447`}, {8.315277711905317, 3.5646553671577643`}, {
       8.315277711905317, 3.5646553671577643`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}}, {{
       8.407864093889831, 3.5932634932466447`}, {8.315277711905317, 
       3.5646553671577643`}, {8.315277711905317, 3.5646553671577643`}, {
       8.407864093889831, 3.5932634932466447`}, {8.407864093889831, 
       3.5932634932466447`}}, {{8.407864093889831, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}, {8.407864093889831, 3.5932634932466447`}, {
       8.407864093889831, 3.5932634932466447`}}, {{8.407864093889831, 
       3.5932634932466447`}, {8.315277711905317, 3.5646553671577643`}, {
       8.315277711905317, 3.5646553671577643`}, {8.407864093889831, 
       3.5932634932466447`}, {8.407864093889831, 3.5932634932466447`}}, {{
       8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}}, {{8.315277711905317, 3.5646553671577643`}, {
       8.18965751132395, 3.5932634932466447`}, {8.18965751132395, 
       3.5932634932466447`}, {8.315277711905317, 3.5646553671577643`}, {
       8.315277711905317, 3.5646553671577643`}}, {{8.315277711905317, 
       3.5646553671577643`}, {8.18965751132395, 3.5932634932466447`}, {
       8.18965751132395, 3.5932634932466447`}, {8.315277711905317, 
       3.5646553671577643`}, {8.315277711905317, 3.5646553671577643`}}, {{
       8.315277711905317, 3.5646553671577643`}, {8.18965751132395, 
       3.5932634932466447`}, {8.18965751132395, 3.5932634932466447`}, {
       8.315277711905317, 3.5646553671577643`}, {8.315277711905317, 
       3.5646553671577643`}}, {{8.18965751132395, 3.9712083807967207`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}, {8.18965751132395, 3.9712083807967207`}, {
       8.18965751132395, 3.9712083807967207`}}, {{8.18965751132395, 
       3.9712083807967207`}, {8.315277711905317, 3.9998165068856006`}, {
       8.315277711905317, 3.9998165068856006`}, {8.18965751132395, 
       3.9712083807967207`}, {8.18965751132395, 3.9712083807967207`}}, {{
       8.18965751132395, 3.9712083807967207`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}, {
       8.18965751132395, 3.9712083807967207`}, {8.18965751132395, 
       3.9712083807967207`}}, {{8.18965751132395, 3.9712083807967207`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}, {8.18965751132395, 3.9712083807967207`}, {
       8.18965751132395, 3.9712083807967207`}}, {{8.315277711905317, 
       3.9998165068856006`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}}, {{
       8.315277711905317, 3.9998165068856006`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}, {
       8.315277711905317, 3.9998165068856006`}, {8.315277711905317, 
       3.9998165068856006`}}, {{8.315277711905317, 3.9998165068856006`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}, {8.315277711905317, 3.9998165068856006`}, {
       8.315277711905317, 3.9998165068856006`}}, {{8.315277711905317, 
       3.9998165068856006`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}, {8.315277711905317, 
       3.9998165068856006`}, {8.315277711905317, 3.9998165068856006`}}, {{
       8.407864093889831, 3.9712083807967202`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}, {{8.407864093889831, 3.9712083807967202`}, {
       8.478932648829726, 3.9053302849980818`}, {8.478932648829726, 
       3.9053302849980818`}, {8.407864093889831, 3.9712083807967202`}, {
       8.407864093889831, 3.9712083807967202`}}, {{8.407864093889831, 
       3.9712083807967202`}, {8.478932648829726, 3.9053302849980818`}, {
       8.478932648829726, 3.9053302849980818`}, {8.407864093889831, 
       3.9712083807967202`}, {8.407864093889831, 3.9712083807967202`}}, {{
       8.407864093889831, 3.9712083807967202`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}, {
       8.407864093889831, 3.9712083807967202`}, {8.407864093889831, 
       3.9712083807967202`}}, {{8.478932648829726, 3.9053302849980818`}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}, {8.478932648829726, 3.9053302849980818`}, {
       8.478932648829726, 3.9053302849980818`}}, {{8.478932648829726, 
       3.9053302849980818`}, {8.51696738517277, 3.7822359370216825`}, {
       8.51696738517277, 3.7822359370216825`}, {8.478932648829726, 
       3.9053302849980818`}, {8.478932648829726, 3.9053302849980818`}}, {{
       8.478932648829726, 3.9053302849980818`}, {8.51696738517277, 
       3.7822359370216825`}, {8.51696738517277, 3.7822359370216825`}, {
       8.478932648829726, 3.9053302849980818`}, {8.478932648829726, 
       3.9053302849980818`}}, {{8.478932648829726, 3.9053302849980818`}, {
       8.51696738517277, 3.7822359370216825`}, {8.51696738517277, 
       3.7822359370216825`}, {8.478932648829726, 3.9053302849980818`}, {
       8.478932648829726, 3.9053302849980818`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIIGZYc0MBBygPFnzQQB0QO4+Ojq8epneGGP
l0/IPiz6UezDwidJPyH/ELKPUPgQch8R4UuufwAQKIsK
      "]],
     FontColor->GrayLevel[0.]]}, 
   {Hue[7.771561172376095*^-17], AbsoluteThickness[0.5], 
    LineBox[{{-4., -0.25}, {2.1127640255203746`, -0.25}}]}, 
   {Hue[0.00045348068087927015`], AbsoluteThickness[0.5], 
    LineBox[{{2.1127640255203746`, -0.25}, {
     2.4259501914628054`, -0.2572716062589913}}]}, 
   {Hue[0.5488454962124836], AbsoluteThickness[0.5], 
    LineBox[{{2.4259501914628054`, -0.2572716062589913}, {
     2.1274545181025806`, -0.3523441247937115}}]}, 
   {Hue[7.771561172376095*^-17], AbsoluteThickness[0.5], 
    LineBox[{{-3.999999999999999, -0.125}, {1.7955815896174605`, -0.125}}]}, 
   {Hue[0.0007636097364797423], AbsoluteThickness[0.5], 
    LineBox[{{1.7955815896174605`, -0.125}, {
     2.135266781912374, -0.0993121233692342}}]}, 
   {Hue[0.49650276949629957`], AbsoluteThickness[0.5], 
    LineBox[{{2.135266781912374, -0.0993121233692342}, {1.9248237126640428`, 
     0.16856772185166147`}}]}, 
   {Hue[7.771561172376095*^-17], AbsoluteThickness[0.5], 
    LineBox[{{-3.999999999999999, 0.}, {1.7667114977152143`, 0.}}]}, 
   {Hue[0.00043520595190883467`], AbsoluteThickness[0.5], 
    LineBox[{{1.7667114977152143`, 0.}, {
     2.150944362608001, -0.005238618880454463}}]}, 
   {Hue[0.5529864655456317], AbsoluteThickness[0.5], 
    LineBox[{{2.150944362608001, -0.005238618880454463}, {
     1.7730587304746952`, -0.07498664120871038}}]}, 
   {Hue[7.771561172376095*^-17], AbsoluteThickness[0.5], 
    LineBox[{{-3.999999999999999, 0.125}, {1.8328552920063783`, 0.125}}]}, 
   {Hue[0.0017715097382845046`], AbsoluteThickness[0.5], 
    LineBox[{{1.8328552920063783`, 0.125}, {2.1181627424688507`, 
     0.08712038710563419}}]}, 
   {Hue[0.4127343649407532], AbsoluteThickness[0.5], 
    LineBox[{{2.1181627424688507`, 0.08712038710563419}, {
     2.0487927506178134`, -0.19220560630173106`}}]}, 
   {Hue[7.771561172376095*^-17], AbsoluteThickness[0.5], 
    LineBox[{{-4., 0.25}, {2.558032037010379, 0.25}}]}, 
   {Hue[0.0004277041865397124], AbsoluteThickness[0.5], 
    LineBox[{{2.558032037010379, 0.25}, {2.912578437095371, 
     0.24779166802428124`}}]}, 
   {Hue[0.5547372406092943], AbsoluteThickness[0.5], 
    LineBox[{{2.912578437095371, 0.24779166802428124`}, {2.5592653538990517`, 
     0.21816242932916147`}}]}, 
   {Hue[0.5483920155316047], AbsoluteThickness[0.5], 
    LineBox[{{2.1127640255203746`, -0.25}, {
     2.0076203620122395`, -0.20824930402508604`}}]}, 
   {Hue[0.5507454451272613], AbsoluteThickness[0.5], 
    LineBox[{{2.0076203620122395`, -0.208249304025086}, {
     1.7718595590752455`, -0.07063522489757539}}]}, 
   {Hue[0.0009069613617583072], AbsoluteThickness[0.5], 
    LineBox[{{2.4259501914628054`, -0.2572716062589913}, {
     2.6127698193528897`, -0.2659515011648166}}]}, 
   {Hue[0.0013487131765793413`], AbsoluteThickness[0.5], 
    LineBox[{{2.6127698193528897`, -0.2659515011648166}, {
     2.923559343513412, -0.2748835103448492}}]}, 
   {Hue[0.552390380608976], AbsoluteThickness[0.5], 
    LineBox[{{2.923559343513412, -0.2748835103448492}, {
     2.6249803105953595`, -0.188162865642236}}]}, 
   {Hue[0.5492989768933628], AbsoluteThickness[0.5], 
    LineBox[{{2.1274545181025806`, -0.3523441247937115}, {
     2.1259954781353176`, -0.35277179815711646`}}]}, 
   {Hue[0.5498508359275578], AbsoluteThickness[0.5], 
    LineBox[{{2.1259954781353176`, -0.35277179815711646`}, {
     1.8423013513061834`, -0.45101505306758705`}}]}, 
   {Hue[0.0015272194729594067`], AbsoluteThickness[0.5], 
    LineBox[{{2.135266781912374, -0.0993121233692342}, {
     2.3240327199001403`, -0.07059797237112558}}]}, 
   {Hue[0.0019826862263466857`], AbsoluteThickness[0.5], 
    LineBox[{{2.3240327199001403`, -0.07059797237112558}, {
     2.658822775515672, -0.011412840366224457`}}]}, 
   {Hue[0.5499328403752252], AbsoluteThickness[0.5], 
    LineBox[{{2.658822775515672, -0.011412840366224457`}, {
     2.3236160568858866`, 0.045364945562254545`}}]}, 
   {Hue[0.000870411903817514], AbsoluteThickness[0.5], 
    LineBox[{{2.150944362608001, -0.005238618880454463}, {
     2.313803893850049, -0.009680288046376613}}]}, 
   {Hue[0.0012962873896615655`], AbsoluteThickness[0.5], 
    LineBox[{{2.313803893850049, -0.009680288046376613}, {
     2.6587020790362366`, -0.01851452903178915}}]}, 
   {Hue[0.5560391227445284], AbsoluteThickness[0.5], 
    LineBox[{{2.6587020790362366`, -0.01851452903178915}, {
     2.3141142722736756`, -0.0014251934952107404`}}]}, 
   {Hue[0.4109628552024701], AbsoluteThickness[0.5], 
    LineBox[{{1.8328552920063783`, 0.125}, {1.9426703885671657`, 
     0.8392028198096113}}]}, 
   {Hue[0.41140387488550517`], AbsoluteThickness[0.5], 
    LineBox[{{1.9426703885671657`, 0.8392028198096113}, {1.9993256474516456`, 
     1.1695401550859315`}}]}, 
   {Hue[0.003543019476568776], AbsoluteThickness[0.5], 
    LineBox[{{2.1181627424688507`, 0.08712038710563419}, {2.319675195136532, 
     0.032651562739059024`}}]}, 
   {Hue[0.003968758672631123], AbsoluteThickness[0.5], 
    LineBox[{{2.319675195136532, 0.032651562739059024`}, {
     2.6527791481303082`, -0.05729985255017759}}]}, 
   {Hue[0.5587439616390015], AbsoluteThickness[0.5], 
    LineBox[{{2.6527791481303082`, -0.05729985255017758}, {2.319992034918037, 
     0.03381676444397883}}]}, 
   {Hue[0.41450587467903754`], AbsoluteThickness[0.5], 
    LineBox[{{2.0487927506178134`, -0.192205606301731}, {
     2.0093503052780974`, -0.2922853161677385}}]}, 
   {Hue[0.41501887224036405`], AbsoluteThickness[0.5], 
    LineBox[{{2.0093503052780974`, -0.2922853161677385}, {
     1.9091076330999854`, -0.5803303184084534}}]}, 
   {Hue[0.5543095364227544], AbsoluteThickness[0.5], 
    LineBox[{{2.558032037010379, 0.25}, {2.3229323276325826`, 
     0.27414706205994865`}}]}, 
   {Hue[0.5547392700269924], AbsoluteThickness[0.5], 
    LineBox[{{2.3229323276325826`, 0.27414706205994865`}, {
     2.0837373856700006`, 0.2965721905668172}}]}, 
   {Hue[0.0008554083730792694], AbsoluteThickness[0.5], 
    LineBox[{{2.912578437095371, 0.24779166802428124`}, {3.073248412097843, 
     0.24579008849078676`}}]}, 
   {Hue[0.0012925785580262692`], AbsoluteThickness[0.5], 
    LineBox[{{3.073248412097843, 0.24579008849078676`}, {3.399813728198413, 
     0.2466113626966644}}]}, 
   {Hue[0.5533884746650897], AbsoluteThickness[0.5], 
    LineBox[{{3.399813728198413, 0.2466113626966644}, {3.0806086874881093`, 
     0.3155586045292405}}]}, 
   {Hue[0.5551649447958338], AbsoluteThickness[0.5], 
    LineBox[{{2.5592653538990517`, 0.21816242932916147`}, {2.292331012643494, 
     0.1974504597020513}}]}, 
   {Hue[0.556632355976416], AbsoluteThickness[0.5], 
    LineBox[{{2.292331012643494, 0.19745045970205133`}, {2.106427525397316, 
     0.20533776692545216`}}]}, 
   {Hue[0.5519486287941553], AbsoluteThickness[0.5], 
    LineBox[{{2.6127698193528897`, -0.2659515011648166}, {
     2.424124676076124, -0.3126963457436936}}]}, 
   {Hue[0.5525630940628875], AbsoluteThickness[0.5], 
    LineBox[{{2.424124676076124, -0.3126963457436936}, {
     2.1357250002546952`, -0.3665895580508329}}]}, 
   {Hue[0.0017904649914002979`], AbsoluteThickness[0.5], 
    LineBox[{{2.923559343513412, -0.2748835103448492}, {
     3.104467331972319, -0.2768800339853606}}]}, 
   {Hue[0.002216582986678528], AbsoluteThickness[0.5], 
    LineBox[{{3.104467331972319, -0.2768800339853606}, {
     3.4214213610013307`, -0.281248032490434}}]}, 
   {Hue[0.5569018501660403], AbsoluteThickness[0.5], 
    LineBox[{{3.4214213610013307`, -0.281248032490434}, {
     3.1045432022585056`, -0.28944366793990434`}}]}, 
   {Hue[0.5528321324237969], AbsoluteThickness[0.5], 
    LineBox[{{2.6249803105953595`, -0.18816286564223594`}, {
     2.556561544703055, -0.16959731711586057`}}]}, 
   {Hue[0.5547723290985516], AbsoluteThickness[0.5], 
    LineBox[{{2.556561544703055, -0.16959731711586057`}, {
     2.3239945151432475`, -0.07049200596932091}}]}, 
   {Hue[0.5494773736218385], AbsoluteThickness[0.5], 
    LineBox[{{2.3240327199001403`, -0.07059797237112558}, {
     2.233759746287192, -0.12492596974958306`}}]}, 
   {Hue[0.561410043520388], AbsoluteThickness[0.5], 
    LineBox[{{2.233759746287192, -0.12492596974958306`}, {
     2.1124825428004854`, -0.25151119439344705`}}]}, 
   {Hue[0.0024381529797338096`], AbsoluteThickness[0.5], 
    LineBox[{{2.658822775515672, -0.011412840366224454`}, {2.90318260910804, 
     0.03786499491150414}}]}, 
   {Hue[0.0036206008660191187`], AbsoluteThickness[0.5], 
    LineBox[{{2.90318260910804, 0.03786499491150414}, {3.1632711812755328`, 
     0.06218687659698784}}]}, 
   {Hue[0.45525514377500287`], AbsoluteThickness[0.5], 
    LineBox[{{3.1632711812755328`, 0.06218687659698784}, {
     3.1081009385622327`, -0.19314401385656332`}}]}, 
   {Hue[0.5503883071286123], AbsoluteThickness[0.5], 
    LineBox[{{2.3236160568858866`, 0.045364945562254524`}, {
     2.1263925009973885`, 0.07391712180493983}}]}, 
   {Hue[0.5513437758654088], AbsoluteThickness[0.5], 
    LineBox[{{2.1263925009973885`, 0.07391712180493983}, {1.801637750962374, 
     0.0909286432501734}}]}, 
   {Hue[0.5556132472586842], AbsoluteThickness[0.5], 
    LineBox[{{2.313803893850049, -0.009680288046376613}, {
     2.151268715776132, -0.009679287126228958}}]}, 
   {Hue[0.5560418183787721], AbsoluteThickness[0.5], 
    LineBox[{{2.151268715776132, -0.009679287126228958}, {
     1.7657163286955608`, -0.012558466677348954`}}]}, 
   {Hue[0.0017221628755056172`], AbsoluteThickness[0.5], 
    LineBox[{{2.6587020790362366`, -0.01851452903178915}, {
     2.881636141688381, -0.02385496870220436}}]}, 
   {Hue[0.002156853251958246], AbsoluteThickness[0.5], 
    LineBox[{{2.881636141688381, -0.02385496870220436}, {
     3.2037873722442782`, -0.035847574029720955`}}]}, 
   {Hue[0.554827978753967], AbsoluteThickness[0.5], 
    LineBox[{{3.2037873722442782`, -0.035847574029720955`}, {
     2.8852083221361045`, -0.08516924029713531}}]}, 
   {Hue[0.5564649982303723], AbsoluteThickness[0.5], 
    LineBox[{{2.3141142722736756`, -0.0014251934952107422`}, {
     2.1495936008526306`, 0.006460582257849193}}]}, 
   {Hue[0.5569198209626814], AbsoluteThickness[0.5], 
    LineBox[{{2.1495936008526306`, 0.006460582257849193}, {
     1.7691195403203088`, 0.015645224902844018`}}]}, 
   {Hue[0.41184489456854045`], AbsoluteThickness[0.5], 
    LineBox[{{1.9993256474516456`, 1.1695401550859315`}, {2.0343356261239776`,
      1.3544248274465642`}}]}, 
   {Hue[0.4123834889102629], AbsoluteThickness[0.5], 
    LineBox[{{2.0343356261239776`, 1.3544248274465642`}, {2.0839186303727533`,
      1.7028364018565363`}}]}, 
   {Hue[0.5583182224429393], AbsoluteThickness[0.5], 
    LineBox[{{2.319675195136532, 0.03265156273905903}, {2.1188720290742795`, 
     0.08607108391522586}}]}, 
   {Hue[0.5600241236417228], AbsoluteThickness[0.5], 
    LineBox[{{2.1188720290742795`, 0.08607108391522586}, {1.8314453717792814`,
      0.12377842271242047`}}]}, 
   {Hue[0.0043944978686935475`], AbsoluteThickness[0.5], 
    LineBox[{{2.6527791481303082`, -0.05729985255017761}, {
     2.79990122282203, -0.09699046576834963}}]}, 
   {Hue[0.10481177922507533`], AbsoluteThickness[0.5], 
    LineBox[{{2.79990122282203, -0.09699046576834963}, {
     2.9150423177560985`, -0.19440789933803385`}}]}, 
   {Hue[0.15183293628250705`], AbsoluteThickness[0.5], 
    LineBox[{{2.9150423177560985`, -0.19440789933803385`}, {
     2.894679541453818, -0.34385014720383394`}}]}, 
   {Hue[0.19885409333993737`], AbsoluteThickness[0.5], 
    LineBox[{{2.894679541453818, -0.34385014720383394`}, {
     2.7576720265777537`, -0.40691018980931426`}}]}, 
   {Hue[0.24587525039737038`], AbsoluteThickness[0.5], 
    LineBox[{{2.7576720265777537`, -0.40691018980931426`}, {
     2.630910274720593, -0.32518451225309175`}}]}, 
   {Hue[0.2928964074548023], AbsoluteThickness[0.5], 
    LineBox[{{2.630910274720593, -0.32518451225309175`}, {
     2.631795599894003, -0.17436394235210873`}}]}, 
   {Hue[0.339917564512234], AbsoluteThickness[0.5], 
    LineBox[{{2.631795599894003, -0.17436394235210873`}, {
     2.759508051780453, -0.09413204259228064}}]}, 
   {Hue[0.3869387215696643], AbsoluteThickness[0.5], 
    LineBox[{{2.759508051780453, -0.09413204259228064}, {
     2.895765818654777, -0.15879616767212998`}}]}, 
   {Hue[0.43395987862709606`], AbsoluteThickness[0.5], 
    LineBox[{{2.895765818654777, -0.15879616767213}, {
     2.914372783462938, -0.3084671700959389}}]}, 
   {Hue[0.4809810356845246], AbsoluteThickness[0.5], 
    LineBox[{{2.914372783462938, -0.3084671700959389}, {
     2.7980959710665956`, -0.40452616761759647`}}]}, 
   {Hue[0.5280021927419529], AbsoluteThickness[0.5], 
    LineBox[{{2.7980959710665956`, -0.40452616761759647`}, {
     2.6546259929035054`, -0.3580074243864826}}]}, 
   {Hue[0.5750233497993833], AbsoluteThickness[0.5], 
    LineBox[{{2.6546259929035054`, -0.3580074243864826}, {
     2.6168386077163492`, -0.21199461115888443`}}]}, 
   {Hue[0.6220445068568089], AbsoluteThickness[0.5], 
    LineBox[{{2.6168386077163492`, -0.21199461115888443`}, {
     2.719730875809533, -0.10171855177807249`}}]}, 
   {Hue[0.6690656639142334], AbsoluteThickness[0.5], 
    LineBox[{{2.719730875809533, -0.10171855177807249`}, {
     2.868008378331917, -0.12931221684171135`}}]}, 
   {Hue[0.559169700835064], AbsoluteThickness[0.5], 
    LineBox[{{2.319992034918037, 0.033816764443978825`}, {2.116538301938748, 
     0.08946910845944882}}]}, 
   {Hue[0.5610605057312945], AbsoluteThickness[0.5], 
    LineBox[{{2.116538301938748, 0.08946910845944882}, {1.8346844121442663`, 
     0.12654975919679765`}}]}, 
   {Hue[0.4155318698016904], AbsoluteThickness[0.5], 
    LineBox[{{1.9091076330999854`, -0.5803303184084534}, {
     1.8119977437452552`, -0.9006206950138466}}]}, 
   {Hue[0.42503936586032254`], AbsoluteThickness[0.5], 
    LineBox[{{1.8119977437452552`, -0.9006206950138466}, {
     1.8018011396577056`, -1.1183919787170418`}}]}, 
   {Hue[0.6695609726331824], AbsoluteThickness[0.5], 
    LineBox[{{1.8018011396577056`, -1.1183919787170418`}, {
     2.00170660501016, -1.2053753545015808`}}]}, 
   {Hue[0.552951304480143], AbsoluteThickness[0.5], 
    LineBox[{{3.073248412097843, 0.24579008849078676`}, {2.9094313914959384`, 
     0.20696131870238113`}}]}, 
   {Hue[0.5535405326527859], AbsoluteThickness[0.5], 
    LineBox[{{2.9094313914959384`, 0.20696131870238113`}, {2.583890468575638, 
     0.1482986747359068}}]}, 
   {Hue[0.0017297487429731916`], AbsoluteThickness[0.5], 
    LineBox[{{3.399813728198413, 0.2466113626966644}, {3.6064559994873058`, 
     0.2502252477492219}}]}, 
   {Hue[0.002194767250856955], AbsoluteThickness[0.5], 
    LineBox[{{3.6064559994873058`, 0.2502252477492219}, {3.9247116005841693`, 
     0.24702765492979742`}}]}, 
   {Hue[0.5480464715780181], AbsoluteThickness[0.5], 
    LineBox[{{3.9247116005841693`, 0.24702765492979742`}, {
     3.6293152753750264`, 0.12854616573296565`}}]}, 
   {Hue[0.5538256448500366], AbsoluteThickness[0.5], 
    LineBox[{{3.0806086874881093`, 0.3155586045292405}, {2.8685697810949113`, 
     0.35804603131386536`}}]}, 
   {Hue[0.5560216207025619], AbsoluteThickness[0.5], 
    LineBox[{{2.8685697810949113`, 0.35804603131386536`}, {
     2.6147917660552222`, 0.37122626800455527`}}]}, 
   {Hue[0.5531775593316197], AbsoluteThickness[0.5], 
    LineBox[{{2.1357250002546952`, -0.3665895580508329}, {
     1.8496955326228355`, -0.4029893226713026}}]}, 
   {Hue[0.5564757321707613], AbsoluteThickness[0.5], 
    LineBox[{{3.104467331972319, -0.2768800339853606}, {
     2.924616881863474, -0.2667684340582788}}]}, 
   {Hue[0.556903149805121], AbsoluteThickness[0.5], 
    LineBox[{{2.924616881863474, -0.2667684340582788}, {
     2.6120467293170537`, -0.24738904626157562`}}]}, 
   {Hue[0.0026427009819566805`], AbsoluteThickness[0.5], 
    LineBox[{{3.4214213610013307`, -0.281248032490434}, {
     3.5434652618805855`, -0.28326498215030116`}}]}, 
   {Hue[0.0031226622572329775`], AbsoluteThickness[0.5], 
    LineBox[{{3.5434652618805855`, -0.28326498215030116`}, {
     3.8757812559160145`, -0.2780495004277372}}]}, 
   {Hue[0.545776685166689], AbsoluteThickness[0.5], 
    LineBox[{{3.8757812559160145`, -0.2780495004277372}, {
     3.5750548532847786`, -0.13654066006138604`}}]}, 
   {Hue[0.5573279681613185], AbsoluteThickness[0.5], 
    LineBox[{{3.1045432022585056`, -0.28944366793990434`}, {
     2.9193998150194322`, -0.29372370368908596`}}]}, 
   {Hue[0.5578286806512796], AbsoluteThickness[0.5], 
    LineBox[{{2.9193998150194322`, -0.29372370368908596`}, {
     2.616877028383441, -0.28931765125057995`}}]}, 
   {Hue[0.5567125257733062], AbsoluteThickness[0.5], 
    LineBox[{{2.3239945151432475`, -0.0704920059693209}, {2.141969443752394, 
     0.03879114436170143}}]}, 
   {Hue[0.5584633457354379], AbsoluteThickness[0.5], 
    LineBox[{{2.141969443752394, 0.03879114436170143}, {1.8773585995962323`, 
     0.15362823761233957`}}]}, 
   {Hue[0.5733427134189379], AbsoluteThickness[0.5], 
    LineBox[{{2.1124825428004854`, -0.25151119439344705`}, {
     2.079197831219021, -0.31259339057328156`}}]}, 
   {Hue[0.5737686200731301], AbsoluteThickness[0.5], 
    LineBox[{{2.079197831219021, -0.31259339057328156`}, {
     1.9267200549402579`, -0.5911945978857394}}]}, 
   {Hue[0.4540726958887176], AbsoluteThickness[0.5], 
    LineBox[{{2.90318260910804, 0.03786499491150411}, {2.874901913118524, 
     0.13142607975244086`}}]}, 
   {Hue[0.45492056515026214`], AbsoluteThickness[0.5], 
    LineBox[{{2.874901913118524, 0.13142607975244086`}, {2.7622248693232323`, 
     0.41631709778256265`}}]}, 
   {Hue[0.004803048752304351], AbsoluteThickness[0.5], 
    LineBox[{{3.1632711812755328`, 0.062186876596987836`}, {
     3.3100786095726473`, 0.06035069546005109}}]}, 
   {Hue[0.0054746971803453885`], AbsoluteThickness[0.5], 
    LineBox[{{3.3100786095726473`, 0.06035069546005109}, {3.6022093444589047`,
      0.03749369301241477}}]}, 
   {Hue[0.5141718334529484], AbsoluteThickness[0.5], 
    LineBox[{{3.6022093444589047`, 0.03749369301241477}, {
     3.3968280558869637`, -0.17150710873390634`}}]}, 
   {Hue[0.4564375916612881], AbsoluteThickness[0.5], 
    LineBox[{{3.1081009385622327`, -0.19314401385656338`}, {
     3.0667053208597768`, -0.3186679920469224}}]}, 
   {Hue[0.4568731270957279], AbsoluteThickness[0.5], 
    LineBox[{{3.0667053208597768`, -0.3186679920469224}, {
     2.9649285533031984`, -0.6134772229300739}}]}, 
   {Hue[0.5543932883775147], AbsoluteThickness[0.5], 
    LineBox[{{2.881636141688381, -0.02385496870220436}, {2.653002530324489, 
     0.0324047820952084}}]}, 
   {Hue[0.5550650750834262], AbsoluteThickness[0.5], 
    LineBox[{{2.653002530324489, 0.0324047820952084}, {2.3450883007764545`, 
     0.08706352969269653}}]}, 
   {Hue[0.0025915436284107973`], AbsoluteThickness[0.5], 
    LineBox[{{3.2037873722442782`, -0.035847574029720955`}, {
     3.2905575292584075`, -0.04023043264333406}}]}, 
   {Hue[0.003042726474612356], AbsoluteThickness[0.5], 
    LineBox[{{3.2905575292584075`, -0.04023043264333406}, {
     3.609633783120697, -0.04923777551696405}}]}, 
   {Hue[0.5519483907732118], AbsoluteThickness[0.5], 
    LineBox[{{3.609633783120697, -0.04923777551696405}, {3.309374483600623, 
     0.05909108054710495}}]}, 
   {Hue[0.5552626691304197], AbsoluteThickness[0.5], 
    LineBox[{{2.8852083221361045`, -0.08516924029713532}, {
     2.8005649658677365`, -0.09712664712301394}}]}, 
   {Hue[0.5654414397076012], AbsoluteThickness[0.5], 
    LineBox[{{2.8005649658677365`, -0.09712664712301394}, {
     2.637645811585075, -0.16469114809284577`}}]}, 
   {Hue[0.4129220832519855], AbsoluteThickness[0.5], 
    LineBox[{{2.0839186303727533`, 1.7028364018565363`}, {2.10569795729307, 
     1.9300083447122593`}}]}, 
   {Hue[0.4141813091207292], AbsoluteThickness[0.5], 
    LineBox[{{2.10569795729307, 1.9300083447122593`}, {2.102461859205979, 
     2.1562317376470186`}}]}, 
   {Hue[0.051415654926123475`], AbsoluteThickness[0.5], 
    LineBox[{{2.79990122282203, -0.09699046576834963}, {
     2.893677752371144, -0.10990895486888261`}}]}, 
   {Hue[0.05215073209931745], AbsoluteThickness[0.5], 
    LineBox[{{2.893677752371144, -0.10990895486888261`}, {
     3.181085325990492, -0.12840888647190216`}}]}, 
   {Hue[0.5517347391984527], AbsoluteThickness[0.5], 
    LineBox[{{3.181085325990492, -0.12840888647190216`}, {3.0289284939016827`,
      0.11611853385509385`}}]}, 
   {Hue[0.20522906058145438`], AbsoluteThickness[0.5], 
    LineBox[{{2.9150423177560985`, -0.19440789933803382`}, {
     2.96711383599892, -0.3079810804127304}}]}, 
   {Hue[0.20568986735283568`], AbsoluteThickness[0.5], 
    LineBox[{{2.96711383599892, -0.3079810804127304}, {
     3.088168964008861, -0.5912649484564494}}]}, 
   {Hue[0.2522502176388882], AbsoluteThickness[0.5], 
    LineBox[{{2.894679541453818, -0.34385014720383394`}, {
     2.8912229334269237`, -0.3491942764146966}}]}, 
   {Hue[0.27603937828419595`], AbsoluteThickness[0.5], 
    LineBox[{{2.8912229334269237`, -0.3491942764146966}, {
     2.8507909856469564`, -0.5054658364537917}}]}, 
   {Hue[0.43456410992162403`], AbsoluteThickness[0.5], 
    LineBox[{{2.8507909856469564`, -0.5054658364537917}, {
     2.9697753636248185`, -0.6145449851283009}}]}, 
   {Hue[0.593088841559052], AbsoluteThickness[0.5], 
    LineBox[{{2.9697753636248185`, -0.6145449851283009}, {
     3.1219530154623865`, -0.5607165060532004}}]}, 
   {Hue[0.29927137469631393`], AbsoluteThickness[0.5], 
    LineBox[{{2.7576720265777537`, -0.40691018980931426`}, {
     2.662545880429595, -0.40621175248829583`}}]}, 
   {Hue[0.3008771825951896], AbsoluteThickness[0.5], 
    LineBox[{{2.662545880429595, -0.40621175248829583`}, {
     2.4070687179466166`, -0.43658181800023843`}}]}, 
   {Hue[0.34629253175374913`], AbsoluteThickness[0.5], 
    LineBox[{{2.630910274720593, -0.32518451225309175`}, {
     2.537904434842158, -0.17665364798338945`}}]}, 
   {Hue[0.3467706077940522], AbsoluteThickness[0.5], 
    LineBox[{{2.537904434842158, -0.17665364798338945`}, {2.368483232834614, 
     0.11398432479574981`}}]}, 
   {Hue[0.393313688811181], AbsoluteThickness[0.5], 
    LineBox[{{2.631795599894003, -0.17436394235210873`}, {2.7452261818578667`,
      0.06374704200147421}}]}, 
   {Hue[0.39398421210665663`], AbsoluteThickness[0.5], 
    LineBox[{{2.7452261818578667`, 0.06374704200147421}, {2.8643308325337173`,
      0.36270171708584437`}}]}, 
   {Hue[0.4403348458686151], AbsoluteThickness[0.5], 
    LineBox[{{2.759508051780453, -0.09413204259228064}, {
     2.883740543028006, -0.07887324623468389}}]}, 
   {Hue[0.4407662795115466], AbsoluteThickness[0.5], 
    LineBox[{{2.883740543028006, -0.07887324623468389}, {
     3.203802886812453, -0.03611776050100776}}]}, 
   {Hue[0.4873560029260434], AbsoluteThickness[0.5], 
    LineBox[{{2.895765818654777, -0.15879616767213}, {
     3.0161781283364646`, -0.30498977192181964`}}]}, 
   {Hue[0.4887238566270001], AbsoluteThickness[0.5], 
    LineBox[{{3.0161781283364646`, -0.30498977192181964`}, {
     3.1494918633726963`, -0.5112867536126003}}]}, 
   {Hue[0.5343771599834802], AbsoluteThickness[0.5], 
    LineBox[{{2.914372783462938, -0.3084671700959389}, {
     2.90503295776152, -0.3371285556567378}}]}, 
   {Hue[0.5371419047471904], AbsoluteThickness[0.5], 
    LineBox[{{2.90503295776152, -0.3371285556567378}, {
     2.871982401942352, -0.5498559767359249}}]}, 
   {Hue[0.581398317040909], AbsoluteThickness[0.5], 
    LineBox[{{2.7980959710665956`, -0.40452616761759647`}, {
     2.6862914003730283`, -0.4332850866475508}}]}, 
   {Hue[0.5819361687588419], AbsoluteThickness[0.5], 
    LineBox[{{2.6862914003730283`, -0.4332850866475508}, {
     2.378476833234662, -0.5276295677511588}}]}, 
   {Hue[0.6284194740983343], AbsoluteThickness[0.5], 
    LineBox[{{2.6546259929035054`, -0.3580074243864826}, {
     2.4682578289883628`, -0.18360407421001324`}}]}, 
   {Hue[0.6306572274115819], AbsoluteThickness[0.5], 
    LineBox[{{2.4682578289883628`, -0.18360407421001324`}, {2.315092610963029,
      0.0091447722561885}}]}, 
   {Hue[0.6754406311557724], AbsoluteThickness[0.5], 
    LineBox[{{2.6168386077163492`, -0.2119946111588844}, {
     2.6394536607824683`, -0.0914570159361184}}]}, 
   {Hue[0.6896463913942871], AbsoluteThickness[0.5], 
    LineBox[{{2.6394536607824683`, -0.0914570159361184}, {2.622054233494193, 
     0.09443254007223806}}]}, 
   {Hue[0.4345468619189546], AbsoluteThickness[0.5], 
    LineBox[{{1.8018011396577056`, -1.1183919787170418`}, {
     1.8592586684786345`, -1.4006685999193}}]}, 
   {Hue[0.43591627507139696`], AbsoluteThickness[0.5], 
    LineBox[{{1.8592586684786345`, -1.4006685999193}, {
     1.9364210674153588`, -1.6365415157717687`}}]}, 
   {Hue[0.6790684686918144], AbsoluteThickness[0.5], 
    LineBox[{{2.00170660501016, -1.2053753545015808`}, {
     2.0936847539366026`, -1.2204847803997199`}}]}, 
   {Hue[0.6795564274587674], AbsoluteThickness[0.5], 
    LineBox[{{2.0936847539366026`, -1.2204847803997199`}, {
     2.39520196229301, -1.2807444982206344`}}]}, 
   {Hue[0.5541297608254289], AbsoluteThickness[0.5], 
    LineBox[{{2.583890468575638, 0.1482986747359068}, {2.5576669750859877`, 
     0.14503434741320664`}}]}, 
   {Hue[0.5575201829814191], AbsoluteThickness[0.5], 
    LineBox[{{2.5576669750859877`, 0.14503434741320664`}, {
     2.3390376223938767`, 0.0778256770712906}}]}, 
   {Hue[0.5475814530701348], AbsoluteThickness[0.5], 
    LineBox[{{3.6064559994873058`, 0.2502252477492219}, {3.3711252631169453`, 
     0.3578898232506408}}]}, 
   {Hue[0.5512736485377909], AbsoluteThickness[0.5], 
    LineBox[{{3.3711252631169453`, 0.3578898232506408}, {3.163112543782475, 
     0.41077303885399297`}}]}, 
   {Hue[0.002659785758740718], AbsoluteThickness[0.5], 
    LineBox[{{3.9247116005841693`, 0.24702765492979742`}, {4.137799101792625, 
     0.23901591793919452`}}]}, 
   {Hue[0.003114381133469124], AbsoluteThickness[0.5], 
    LineBox[{{4.137799101792625, 0.23901591793919452`}, {4.458919883037919, 
     0.2345480953266712}}]}, 
   {Hue[0.5512581613557035], AbsoluteThickness[0.5], 
    LineBox[{{4.458919883037919, 0.2345480953266712}, {4.157438834832033, 
     0.34521740073320406`}}]}, 
   {Hue[0.5485114900859018], AbsoluteThickness[0.5], 
    LineBox[{{3.6293152753750264`, 0.12854616573296562`}, {3.5577195242134, 
     0.10209359097244658`}}]}, 
   {Hue[0.5491739537028587], AbsoluteThickness[0.5], 
    LineBox[{{3.5577195242134, 0.10209359097244658`}, {
     3.28918747727866, -0.017303697673489746`}}]}, 
   {Hue[0.5582175965550873], AbsoluteThickness[0.5], 
    LineBox[{{2.6147917660552222`, 0.37122626800455527`}, {2.304389947701526, 
     0.3419692136910909}}]}, 
   {Hue[0.558851126484607], AbsoluteThickness[0.5], 
    LineBox[{{2.304389947701526, 0.3419692136910909}, {2.0861034215346206`, 
     0.3079172392465792}}]}, 
   {Hue[0.5573305674394808], AbsoluteThickness[0.5], 
    LineBox[{{2.6120467293170537`, -0.24738904626157562`}, {
     2.4209334332661214`, -0.2344349846595283}}]}, 
   {Hue[0.5578655355055138], AbsoluteThickness[0.5], 
    LineBox[{{2.4209334332661214`, -0.2344349846595283}, {
     2.118770664382901, -0.22760592327198906`}}]}, 
   {Hue[0.5452967238914114], AbsoluteThickness[0.5], 
    LineBox[{{3.5434652618805855`, -0.28326498215030116`}, {
     3.3995778339476956`, -0.36251136894303304`}}]}, 
   {Hue[0.5489172558917376], AbsoluteThickness[0.5], 
    LineBox[{{3.3995778339476956`, -0.36251136894303304`}, {
     3.2025839489157106`, -0.4288049429660969}}]}, 
   {Hue[0.003602623532509197], AbsoluteThickness[0.5], 
    LineBox[{{3.8757812559160145`, -0.2780495004277372}, {
     4.089326623485351, -0.26781048511789524`}}]}, 
   {Hue[0.004037476601281864], AbsoluteThickness[0.5], 
    LineBox[{{4.089326623485351, -0.26781048511789524`}, {
     4.44366091119333, -0.24606642188724137`}}]}, 
   {Hue[0.5566707624592098], AbsoluteThickness[0.5], 
    LineBox[{{4.443660911193329, -0.24606642188724137`}, {
     4.0917121264165885`, -0.1996159684397834}}]}, 
   {Hue[0.5462566464419653], AbsoluteThickness[0.5], 
    LineBox[{{3.5750548532847786`, -0.13654066006138604`}, {
     3.565947610199564, -0.13260833996771543`}}]}, 
   {Hue[0.5468007973896173], AbsoluteThickness[0.5], 
    LineBox[{{3.565947610199564, -0.13260833996771543`}, {3.2905571289939726`,
      0.001928755298810654}}]}, 
   {Hue[0.5583293931412405], AbsoluteThickness[0.5], 
    LineBox[{{2.616877028383441, -0.28931765125057995`}, {
     2.4275608571584364`, -0.27941877458710385`}}]}, 
   {Hue[0.5587573925416945], AbsoluteThickness[0.5], 
    LineBox[{{2.4275608571584364`, -0.27941877458710385`}, {
     2.1106335737452513`, -0.2649692001902707}}]}, 
   {Hue[0.45576843441180676`], AbsoluteThickness[0.5], 
    LineBox[{{2.7622248693232323`, 0.41631709778256265`}, {
     2.6861441636232404`, 0.5699843270078706}}]}, 
   {Hue[0.4579311639516031], AbsoluteThickness[0.5], 
    LineBox[{{2.6861441636232404`, 0.5699843270078706}, {2.6128401480347785`, 
     0.79506859551028}}]}, 
   {Hue[0.5135001850249078], AbsoluteThickness[0.5], 
    LineBox[{{3.3100786095726473`, 0.06035069546005106}, {3.281792556780452, 
     0.1059810220101009}}]}, 
   {Hue[0.5139873067441981], AbsoluteThickness[0.5], 
    LineBox[{{3.281792556780452, 0.1059810220101009}, {3.123113647653839, 
     0.38266568030804693`}}]}, 
   {Hue[0.0061463456083865825`], AbsoluteThickness[0.5], 
    LineBox[{{3.6022093444589047`, 0.03749369301241477}, {
     3.867118161654867, -0.000827049134308741}}]}, 
   {Hue[0.006649843691595513], AbsoluteThickness[0.5], 
    LineBox[{{3.867118161654867, -0.000827049134308741}, {
     4.178207872079298, -0.033711910596277775`}}]}, 
   {Hue[0.5444641111882742], AbsoluteThickness[0.5], 
    LineBox[{{4.178207872079298, -0.033711910596277775`}, {
     3.9278123021409157`, 0.15379883736383768`}}]}, 
   {Hue[0.5148434818809894], AbsoluteThickness[0.5], 
    LineBox[{{3.3968280558869637`, -0.17150710873390634`}, {
     3.3854547003163193`, -0.1816557887830481}}]}, 
   {Hue[0.5152705090917479], AbsoluteThickness[0.5], 
    LineBox[{{3.3854547003163193`, -0.1816557887830481}, {
     3.147990332444739, -0.3914075574131119}}]}, 
   {Hue[0.4573086625301678], AbsoluteThickness[0.5], 
    LineBox[{{2.9649285533031984`, -0.6134772229300739}, {
     2.9248546268284077`, -0.7245393065918662}}]}, 
   {Hue[0.4593796832558999], AbsoluteThickness[0.5], 
    LineBox[{{2.9248546268284077`, -0.7245393065918662}, {
     2.8264778851710934`, -0.9097068276500264}}]}, 
   {Hue[0.5557368617893378], AbsoluteThickness[0.5], 
    LineBox[{{2.3450883007764545`, 0.08706352969269653}, {2.095416939503906, 
     0.114661375752255}}]}, 
   {Hue[0.5577264009948194], AbsoluteThickness[0.5], 
    LineBox[{{2.095416939503906, 0.114661375752255}, {1.8139587979114136`, 
     0.10638609312081997`}}]}, 
   {Hue[0.5514972079270115], AbsoluteThickness[0.5], 
    LineBox[{{3.2905575292584075`, -0.04023043264333406}, {
     3.2023592512403254`, -0.06868246954089802}}]}, 
   {Hue[0.5521177411544949], AbsoluteThickness[0.5], 
    LineBox[{{3.2023592512403254`, -0.06868246954089802}, {
     2.9133523588598997`, -0.14341571318165494`}}]}, 
   {Hue[0.0034939093208139925`], AbsoluteThickness[0.5], 
    LineBox[{{3.609633783120697, -0.04923777551696405}, {
     3.8840956388206975`, -0.050877881843199954`}}]}, 
   {Hue[0.004159258500479912], AbsoluteThickness[0.5], 
    LineBox[{{3.8840956388206975`, -0.050877881843199954`}, {
     4.178271993579385, -0.03354829259387179}}]}, 
   {Hue[0.5138081632433316], AbsoluteThickness[0.5], 
    LineBox[{{4.178271993579385, -0.03354829259387179}, {3.9739709830355316`, 
     0.17882199594343742`}}]}, 
   {Hue[0.5523995736194134], AbsoluteThickness[0.5], 
    LineBox[{{3.309374483600623, 0.059091080547104935`}, {2.9065021897117678`,
      0.1943910913636679}}]}, 
   {Hue[0.5528279000653532], AbsoluteThickness[0.5], 
    LineBox[{{2.9065021897117678`, 0.1943910913636679}, {2.5697062869040908`, 
     0.3048288744290709}}]}, 
   {Hue[0.5756202102847827], AbsoluteThickness[0.5], 
    LineBox[{{2.637645811585075, -0.1646911480928458}, {
     2.4197915097386202`, -0.32890305261522873`}}]}, 
   {Hue[0.5782192898230851], AbsoluteThickness[0.5], 
    LineBox[{{2.4197915097386202`, -0.32890305261522873`}, {
     2.2250819916405074`, -0.4325277158377946}}]}, 
   {Hue[0.415440534989473], AbsoluteThickness[0.5], 
    LineBox[{{2.102461859205979, 2.1562317376470186`}, {2.099876240882289, 
     2.1769449162396737`}}]}, 
   {Hue[0.43457696664598205`], AbsoluteThickness[0.5], 
    LineBox[{{2.099876240882289, 2.1769449162396737`}, {2.126381851767329, 
     2.3236770434731717`}}]}, 
   {Hue[0.6129122438657709], AbsoluteThickness[0.5], 
    LineBox[{{2.126381851767329, 2.3236770434731717`}, {2.269401871266669, 
     2.365845024137}}]}, 
   {Hue[0.5509996620252591], AbsoluteThickness[0.5], 
    LineBox[{{2.893677752371144, -0.10990895486888264`}, {
     2.875467355774854, -0.13582248561146287`}}]}, 
   {Hue[0.5514396498521081], AbsoluteThickness[0.5], 
    LineBox[{{2.875467355774854, -0.13582248561146287`}, {
     2.692317020218175, -0.3874077199047137}}]}, 
   {Hue[0.052885809272511505`], AbsoluteThickness[0.5], 
    LineBox[{{3.181085325990492, -0.12840888647190216`}, {
     3.226010589740139, -0.12803431837791418`}}]}, 
   {Hue[0.07555063654746243], AbsoluteThickness[0.5], 
    LineBox[{{3.226010589740139, -0.12803431837791418`}, {
     3.3822058596000195`, -0.17782156733975377`}}]}, 
   {Hue[0.2384410261219607], AbsoluteThickness[0.5], 
    LineBox[{{3.3822058596000195`, -0.17782156733975374`}, {
     3.410806438783458, -0.33924566515715215`}}]}, 
   {Hue[0.40133141569645897`], AbsoluteThickness[0.5], 
    LineBox[{{3.410806438783458, -0.33924566515715215`}, {
     3.2812244386144633`, -0.43966597046435485`}}]}, 
   {Hue[0.5642218052709571], AbsoluteThickness[0.5], 
    LineBox[{{3.2812244386144633`, -0.43966597046435485`}, {
     3.132045856605864, -0.3716844791914156}}]}, 
   {Hue[0.5524698163716467], AbsoluteThickness[0.5], 
    LineBox[{{3.0289284939016827`, 0.11611853385509385`}, {
     2.9077520561216486`, 0.2825824569357716}}]}, 
   {Hue[0.5601381993193649], AbsoluteThickness[0.5], 
    LineBox[{{2.9077520561216486`, 0.2825824569357716}, {2.7505362038827297`, 
     0.4177193052925571}}]}, 
   {Hue[0.20615067412421692`], AbsoluteThickness[0.5], 
    LineBox[{{3.088168964008861, -0.5912649484564494}, {
     3.1154518062164924`, -0.660012099245597}}]}, 
   {Hue[0.206644392196742], AbsoluteThickness[0.5], 
    LineBox[{{3.1154518062164924`, -0.660012099245597}, {
     3.2400343877105398`, -0.9437469192977916}}]}, 
   {Hue[0.41077494927631686`], AbsoluteThickness[0.5], 
    LineBox[{{2.8912229334269237`, -0.3491942764146966}, {
     2.8898375745696994`, -0.35005625651296285`}}]}, 
   {Hue[0.4221915538646185], AbsoluteThickness[0.5], 
    LineBox[{{2.8898375745696994`, -0.35005625651296285`}, {
     2.7234410453299605`, -0.4006132907740559}}]}, 
   {Hue[0.6491075870135149], AbsoluteThickness[0.5], 
    LineBox[{{2.7234410453299605`, -0.4006132907740559}, {
     2.6128173190127457`, -0.26642607144224856`}}]}, 
   {Hue[0.29982853892950406`], AbsoluteThickness[0.5], 
    LineBox[{{2.8507909856469564`, -0.5054658364537917}, {
     2.8602651829859194`, -0.6450473083065291}}]}, 
   {Hue[0.30064293141388015`], AbsoluteThickness[0.5], 
    LineBox[{{2.8602651829859194`, -0.6450473083065291}, {
     2.8571311772373402`, -0.8971899453798242}}]}, 
   {Hue[0.45835327056693215`], AbsoluteThickness[0.5], 
    LineBox[{{2.9697753636248185`, -0.6145449851283009}, {
     3.1006952143281095`, -0.6731743370335496}}]}, 
   {Hue[0.4588896121297793], AbsoluteThickness[0.5], 
    LineBox[{{3.1006952143281095`, -0.6731743370335496}, {
     3.372567902996115, -0.8100452142830538}}]}, 
   {Hue[0.6168780022043598], AbsoluteThickness[0.5], 
    LineBox[{{3.1219530154623865`, -0.5607165060532004}, {
     3.2770741903575558`, -0.44009365096981334`}}]}, 
   {Hue[0.6199596521154258], AbsoluteThickness[0.5], 
    LineBox[{{3.2770741903575558`, -0.44009365096981334`}, {
     3.421423806264096, -0.2825810055807319}}]}, 
   {Hue[0.3024829904940653], AbsoluteThickness[0.5], 
    LineBox[{{2.4070687179466166`, -0.43658181800023843`}, {
     2.152125032608691, -0.5000481764794545}}]}, 
   {Hue[0.3032354006114786], AbsoluteThickness[0.5], 
    LineBox[{{2.152125032608691, -0.5000481764794545}, {
     1.875067271831618, -0.5474952523845649}}]}, 
   {Hue[0.3472486838343553], AbsoluteThickness[0.5], 
    LineBox[{{2.368483232834614, 0.11398432479574983`}, {2.309663236636938, 
     0.222657943979428}}]}, 
   {Hue[0.34807226700698723`], AbsoluteThickness[0.5], 
    LineBox[{{2.309663236636938, 0.222657943979428}, {2.195596374572923, 
     0.3978620967099139}}]}, 
   {Hue[0.3946547354021322], AbsoluteThickness[0.5], 
    LineBox[{{2.8643308325337173`, 0.36270171708584437`}, {2.900043065425697, 
     0.47278923929874483`}}]}, 
   {Hue[0.3961082986021014], AbsoluteThickness[0.5], 
    LineBox[{{2.900043065425697, 0.47278923929874483`}, {2.9975989904754834`, 
     0.6838805315256868}}]}, 
   {Hue[0.44119771315447814`], AbsoluteThickness[0.5], 
    LineBox[{{3.203802886812453, -0.03611776050100776}, {
     3.28924334775571, -0.023782234943400607`}}]}, 
   {Hue[0.4416334429892695], AbsoluteThickness[0.5], 
    LineBox[{{3.28924334775571, -0.023782234943400607`}, {3.6081986565921556`,
      0.017716622596220213`}}]}, 
   {Hue[0.49009171032795684`], AbsoluteThickness[0.5], 
    LineBox[{{3.1494918633726963`, -0.5112867536126003}, {
     3.2060915398081464`, -0.6259770921026919}}]}, 
   {Hue[0.4906643563659059], AbsoluteThickness[0.5], 
    LineBox[{{3.2060915398081464`, -0.6259770921026919}, {
     3.324794887888377, -0.9016303589318032}}]}, 
   {Hue[0.5399066495109004], AbsoluteThickness[0.5], 
    LineBox[{{2.871982401942352, -0.5498559767359249}, {
     2.872679627263457, -0.6531503090129064}}]}, 
   {Hue[0.5408047254722294], AbsoluteThickness[0.5], 
    LineBox[{{2.872679627263457, -0.6531503090129064}, {
     2.852834309821224, -0.8994567877210135}}]}, 
   {Hue[0.5824740204767749], AbsoluteThickness[0.5], 
    LineBox[{{2.378476833234662, -0.5276295677511588}, {
     2.2996089305445397`, -0.5557987953187706}}]}, 
   {Hue[0.5835863700056602], AbsoluteThickness[0.5], 
    LineBox[{{2.2996089305445397`, -0.5557987953187706}, {
     2.0556988280270816`, -0.6720451299826989}}]}, 
   {Hue[0.6328949807248296], AbsoluteThickness[0.5], 
    LineBox[{{2.315092610963029, 0.009144772256188483}, {2.227838764293722, 
     0.1600029986747119}}]}, 
   {Hue[0.6334019735422625], AbsoluteThickness[0.5], 
    LineBox[{{2.227838764293722, 0.16000299867471193`}, {2.1197516504485256`, 
     0.3650022290104738}}]}, 
   {Hue[0.43728568822383956`], AbsoluteThickness[0.5], 
    LineBox[{{1.9364210674153588`, -1.6365415157717687`}, {
     2.0031105618124663`, -1.7813742765050393`}}]}, 
   {Hue[0.43778328450416315`], AbsoluteThickness[0.5], 
    LineBox[{{2.0031105618124663`, -1.7813742765050393`}, {
     2.1295875536393534`, -2.0850810008378438`}}]}, 
   {Hue[0.6800443862257206], AbsoluteThickness[0.5], 
    LineBox[{{2.39520196229301, -1.2807444982206344`}, {
     2.7084083146864972`, -1.3546397342405074`}}]}, 
   {Hue[0.6874305122741383], AbsoluteThickness[0.5], 
    LineBox[{{2.7084083146864972`, -1.3546397342405074`}, {
     2.883111229732781, -1.3551477014158069`}}]}, 
   {Hue[0.5609106051374093], AbsoluteThickness[0.5], 
    LineBox[{{2.3390376223938767`, 0.0778256770712906}, {
     2.1516003160355877`, -0.018008625703762077`}}]}, 
   {Hue[0.5615282818057467], AbsoluteThickness[0.5], 
    LineBox[{{2.1516003160355877`, -0.018008625703762077`}, {
     1.825433283496981, -0.16133456345766564`}}]}, 
   {Hue[0.5549658440054472], AbsoluteThickness[0.5], 
    LineBox[{{3.163112543782475, 0.41077303885399297`}, {3.1187853711573306`, 
     0.41382921380282534`}}]}, 
   {Hue[0.5570933860265853], AbsoluteThickness[0.5], 
    LineBox[{{3.1187853711573306`, 0.41382921380282534`}, {2.907374819709145, 
     0.45947675539319044`}}]}, 
   {Hue[0.5508035659809748], AbsoluteThickness[0.5], 
    LineBox[{{4.137799101792625, 0.23901591793919452`}, {3.916711992644869, 
     0.15889920640094707`}}]}, 
   {Hue[0.5519077031003967], AbsoluteThickness[0.5], 
    LineBox[{{3.916711992644869, 0.15889920640094707`}, {3.6593759916094317`, 
     0.09416279696687695}}]}, 
   {Hue[0.003568976508197374], AbsoluteThickness[0.5], 
    LineBox[{{4.458919883037919, 0.2345480953266712}, {4.601695693919178, 
     0.23594106116083657`}}]}, 
   {Hue[0.004057832676331763], AbsoluteThickness[0.5], 
    LineBox[{{4.601695693919178, 0.23594106116083657`}, {4.863813492830697, 
     0.24759556150123316`}}]}, 
   {Hue[0.5448554373205053], AbsoluteThickness[0.5], 
    LineBox[{{4.863813492830697, 0.24759556150123316`}, {4.62690327886765, 
     0.360356895319112}}]}, 
   {Hue[0.551712756730432], AbsoluteThickness[0.5], 
    LineBox[{{4.157438834832033, 0.34521740073320406`}, {4.0393369924525055`, 
     0.38542566704704917`}}]}, 
   {Hue[0.5546122546116525], AbsoluteThickness[0.5], 
    LineBox[{{4.0393369924525055`, 0.38542566704704917`}, {
     3.8408596442645777`, 0.49184255073406646`}}]}, 
   {Hue[0.5498364173198157], AbsoluteThickness[0.5], 
    LineBox[{{3.28918747727866, -0.017303697673489746`}, {
     3.203151668905432, -0.062406231516592386`}}]}, 
   {Hue[0.5506399422281121], AbsoluteThickness[0.5], 
    LineBox[{{3.203151668905432, -0.062406231516592386`}, {
     2.943179205514489, -0.17343081245111755`}}]}, 
   {Hue[0.5525377878920638], AbsoluteThickness[0.5], 
    LineBox[{{3.2025839489157106`, -0.4288049429660969}, {
     3.155730904396003, -0.43568596989353253`}}]}, 
   {Hue[0.5529637228623392], AbsoluteThickness[0.5], 
    LineBox[{{3.155730904396003, -0.43568596989353253`}, {
     2.8457390881039912`, -0.4818399527270362}}]}, 
   {Hue[0.5562359093904364], AbsoluteThickness[0.5], 
    LineBox[{{4.089326623485351, -0.26781048511789524`}, {
     3.853854508835581, -0.33226461177809724`}}]}, 
   {Hue[0.5577871609628355], AbsoluteThickness[0.5], 
    LineBox[{{3.853854508835581, -0.33226461177809724`}, {
     3.595680938826611, -0.3696341643313581}}]}, 
   {Hue[0.0044723296700544535`], AbsoluteThickness[0.5], 
    LineBox[{{4.443660911193329, -0.24606642188724137`}, {
     4.561078049033883, -0.23728288732784375`}}]}, 
   {Hue[0.004901073737088302], AbsoluteThickness[0.5], 
    LineBox[{{4.561078049033883, -0.23728288732784375`}, {
     4.882724830949978, -0.2157101776218346}}]}, 
   {Hue[0.5589650443900821], AbsoluteThickness[0.5], 
    LineBox[{{4.882724830949978, -0.2157101776218346}, {
     4.565450186581573, -0.2727963770218793}}]}, 
   {Hue[0.5571056155279823], AbsoluteThickness[0.5], 
    LineBox[{{4.0917121264165885`, -0.1996159684397834}, {
     3.86485221912155, -0.17275738849884076`}}]}, 
   {Hue[0.5578246564403309], AbsoluteThickness[0.5], 
    LineBox[{{3.8648522191215497`, -0.17275738849884076`}, {
     3.5603716232746945`, -0.1584630835711247}}]}, 
   {Hue[0.5473449483372693], AbsoluteThickness[0.5], 
    LineBox[{{3.2905571289939726`, 0.0019287552988106471`}, {
     3.1363680938544887`, 0.08641579324362264}}]}, 
   {Hue[0.6022182831713276], AbsoluteThickness[0.5], 
    LineBox[{{3.1363680938544887`, 0.08641579324362264}, {2.9788411309941583`,
      0.10377410675835899`}}]}, 
   {Hue[0.6905844215156138], AbsoluteThickness[0.5], 
    LineBox[{{2.9788411309941583`, 0.10377410675835899`}, {
     2.881947764099218, -0.02163614213637218}}]}, 
   {Hue[0.46009389349139945`], AbsoluteThickness[0.5], 
    LineBox[{{2.6128401480347785`, 0.79506859551028}, {2.5853601224432254`, 
     0.9551921831815049}}]}, 
   {Hue[0.47375315515658095`], AbsoluteThickness[0.5], 
    LineBox[{{2.5853601224432254`, 0.9551921831815049}, {2.527720714492665, 
     1.075856030541967}}]}, 
   {Hue[0.6835924970968067], AbsoluteThickness[0.5], 
    LineBox[{{2.527720714492665, 1.075856030541967}, {2.394035160157421, 
     1.0726563476204143`}}]}, 
   {Hue[0.5144744284634886], AbsoluteThickness[0.5], 
    LineBox[{{3.123113647653839, 0.38266568030804693`}, {3.1096356842061024`, 
     0.4081490613162878}}]}, 
   {Hue[0.5149009923494225], AbsoluteThickness[0.5], 
    LineBox[{{3.1096356842061024`, 0.4081490613162878}, {2.968222391413082, 
     0.6729311245888335}}]}, 
   {Hue[0.5439606131050643], AbsoluteThickness[0.5], 
    LineBox[{{3.867118161654867, -0.0008270491343087549}, {
     3.7263045216905155`, -0.07244013916517267}}]}, 
   {Hue[0.5470343729075304], AbsoluteThickness[0.5], 
    LineBox[{{3.7263045216905155`, -0.07244013916517267}, {
     3.541589023775747, -0.20949551165862135`}}]}, 
   {Hue[0.007153341774804366], AbsoluteThickness[0.5], 
    LineBox[{{4.178207872079298, -0.033711910596277775`}, {
     4.414345705749566, -0.04955096768005578}}]}, 
   {Hue[0.00805340309060366], AbsoluteThickness[0.5], 
    LineBox[{{4.414345705749566, -0.04955096768005578}, {
     4.6752375112675155`, -0.04424713697000389}}]}, 
   {Hue[0.4872000804890601], AbsoluteThickness[0.5], 
    LineBox[{{4.6752375112675155`, -0.04424713697000389}, {4.552088136111562, 
     0.18581132561139008`}}]}, 
   {Hue[0.5449676092714832], AbsoluteThickness[0.5], 
    LineBox[{{3.9278123021409157`, 0.15379883736383768`}, {3.917478678094005, 
     0.16093582122586633`}}]}, 
   {Hue[0.5454436949126942], AbsoluteThickness[0.5], 
    LineBox[{{3.917478678094005, 0.16093582122586633`}, {3.651467429611502, 
     0.3327005360937112}}]}, 
   {Hue[0.5156975363025063], AbsoluteThickness[0.5], 
    LineBox[{{3.147990332444739, -0.3914075574131119}, {
     3.1434103314895157`, -0.39541210481392797`}}]}, 
   {Hue[0.516190273788837], AbsoluteThickness[0.5], 
    LineBox[{{3.1434103314895157`, -0.39541210481392797`}, {
     2.907862025084542, -0.5869738626792271}}]}, 
   {Hue[0.461450703981632], AbsoluteThickness[0.5], 
    LineBox[{{2.8264778851710934`, -0.9097068276500264}, {
     2.5016056641142006`, -1.3548685654469694`}}]}, 
   {Hue[0.4621007418692555], AbsoluteThickness[0.5], 
    LineBox[{{2.5016056641142006`, -1.3548685654469694`}, {
     2.35570033438134, -1.5837474344316935`}}]}, 
   {Hue[0.5527382743819781], AbsoluteThickness[0.5], 
    LineBox[{{2.9133523588598997`, -0.14341571318165494`}, {
     2.887625280808972, -0.14847126756027945`}}]}, 
   {Hue[0.5534278794882094], AbsoluteThickness[0.5], 
    LineBox[{{2.887625280808972, -0.14847126756027945`}, {
     2.6147227615855937`, -0.22156981704220616`}}]}, 
   {Hue[0.5131428140636671], AbsoluteThickness[0.5], 
    LineBox[{{3.8840956388206975`, -0.05087788184319994}, {
     3.834271656041847, -0.12634194896048567`}}]}, 
   {Hue[0.5136147153642349], AbsoluteThickness[0.5], 
    LineBox[{{3.834271656041847, -0.12634194896048567`}, {
     3.642263659963334, -0.3991251146934466}}]}, 
   {Hue[0.004824607680145754], AbsoluteThickness[0.5], 
    LineBox[{{4.178271993579385, -0.03354829259387179}, {
     4.395356238859942, -0.006566566343232112}}]}, 
   {Hue[0.005264929983053678], AbsoluteThickness[0.5], 
    LineBox[{{4.395356238859942, -0.006566566343232112}, {4.696163978052853, 
     0.03599324733908506}}]}, 
   {Hue[0.5566343460696986], AbsoluteThickness[0.5], 
    LineBox[{{4.696163978052853, 0.03599324733908506}, {4.3939401671095935`, 
     0.06693515739578867}}]}, 
   {Hue[0.5144735124229973], AbsoluteThickness[0.5], 
    LineBox[{{3.9739709830355316`, 0.17882199594343742`}, {
     3.9274458396089726`, 0.22129895143242684`}}]}, 
   {Hue[0.5157597478099399], AbsoluteThickness[0.5], 
    LineBox[{{3.9274458396089726`, 0.22129895143242684`}, {
     3.7192798596902503`, 0.3726534066930124}}]}, 
   {Hue[0.553256226511293], AbsoluteThickness[0.5], 
    LineBox[{{2.5697062869040908`, 0.3048288744290709}, {2.1610706878248056`, 
     0.435597539910583}}]}, 
   {Hue[0.5536938874348292], AbsoluteThickness[0.5], 
    LineBox[{{2.1610706878248056`, 0.435597539910583}, {1.932082784350391, 
     0.5050359174822743}}]}, 
   {Hue[0.5808183693613874], AbsoluteThickness[0.5], 
    LineBox[{{2.2250819916405074`, -0.4325277158377946}, {
     2.15987250306611, -0.4550270669348026}}]}, 
   {Hue[0.5813538430684428], AbsoluteThickness[0.5], 
    LineBox[{{2.15987250306611, -0.4550270669348026}, {
     1.870059276253556, -0.5405844397897467}}]}, 
   {Hue[0.5937758122092603], AbsoluteThickness[0.5], 
    LineBox[{{2.099876240882289, 2.1769449162396737`}, {2.012722759063111, 
     2.2980595005706794`}}]}, 
   {Hue[0.5943140287609612], AbsoluteThickness[0.5], 
    LineBox[{{2.012722759063111, 2.2980595005706794`}, {1.8255432740145598`, 
     2.5849777346123637`}}]}, 
   {Hue[0.4537133983024908], AbsoluteThickness[0.5], 
    LineBox[{{2.126381851767329, 2.3236770434731717`}, {2.394582847652897, 
     2.8368221229078006`}}]}, 
   {Hue[0.45414147130492083`], AbsoluteThickness[0.5], 
    LineBox[{{2.394582847652897, 2.8368221229078006`}, {2.539535605388227, 
     3.118803240781984}}]}, 
   {Hue[0.6320486755222798], AbsoluteThickness[0.5], 
    LineBox[{{2.269401871266669, 2.365845024137}, {2.5728352662174636`, 
     2.360933948708636}}]}, 
   {Hue[0.632959635533551], AbsoluteThickness[0.5], 
    LineBox[{{2.5728352662174636`, 2.360933948708636}, {2.8745288686319053`, 
     2.329345282810011}}]}, 
   {Hue[0.5518796376789573], AbsoluteThickness[0.5], 
    LineBox[{{2.692317020218175, -0.3874077199047137}, {
     2.671468717273042, -0.41506330538264413`}}]}, 
   {Hue[0.552328358775181], AbsoluteThickness[0.5], 
    LineBox[{{2.671468717273042, -0.41506330538264413`}, {
     2.4642846093936406`, -0.6781277275165812}}]}, 
   {Hue[0.21577619884700946`], AbsoluteThickness[0.5], 
    LineBox[{{3.226010589740139, -0.12803431837791418`}, {
     3.3049471924321416`, -0.08878793102320465}}]}, 
   {Hue[0.21620212678711112`], AbsoluteThickness[0.5], 
    LineBox[{{3.3049471924321416`, -0.08878793102320465}, {3.59467493209646, 
     0.054559260150850386`}}]}, 
   {Hue[0.09821546382241343], AbsoluteThickness[0.5], 
    LineBox[{{3.3822058596000195`, -0.17782156733975374`}, {
     3.547583474048439, -0.2972583673152678}}]}, 
   {Hue[0.10075494473347935`], AbsoluteThickness[0.5], 
    LineBox[{{3.547583474048439, -0.2972583673152678}, {
     3.7596736669957997`, -0.4050348677060538}}]}, 
   {Hue[0.47560574218309576`], AbsoluteThickness[0.5], 
    LineBox[{{3.7596736669957997`, -0.4050348677060538}, {
     3.873238678908653, -0.19598699747015022`}}]}, 
   {Hue[0.2611058533969117], AbsoluteThickness[0.5], 
    LineBox[{{3.410806438783458, -0.33924566515715215`}, {
     3.3982370456249846`, -0.427450549110732}}]}, 
   {Hue[0.26472167520243667`], AbsoluteThickness[0.5], 
    LineBox[{{3.3982370456249846`, -0.427450549110732}, {
     3.406262040715667, -0.6432924089884682}}]}, 
   {Hue[0.6042991025702559], AbsoluteThickness[0.5], 
    LineBox[{{3.406262040715667, -0.6432924089884682}, {
     3.621100528052757, -0.6655754379656301}}]}, 
   {Hue[0.42399624297141], AbsoluteThickness[0.5], 
    LineBox[{{3.2812244386144633`, -0.43966597046435485`}, {
     3.156043472742417, -0.48428206603470975`}}]}, 
   {Hue[0.42465550077320097`], AbsoluteThickness[0.5], 
    LineBox[{{3.156043472742417, -0.48428206603470975`}, {
     2.881791696373951, -0.5626418522506015}}]}, 
   {Hue[0.5868866325459081], AbsoluteThickness[0.5], 
    LineBox[{{3.132045856605864, -0.3716844791914156}, {
     3.125364466560241, -0.36552847847123454`}}]}, 
   {Hue[0.6217400293854936], AbsoluteThickness[0.5], 
    LineBox[{{3.125364466560241, -0.36552847847123454`}, {
     2.980226787964247, -0.3056509227480123}}]}, 
   {Hue[0.5678065822670831], AbsoluteThickness[0.5], 
    LineBox[{{2.7505362038827297`, 0.4177193052925571}, {2.6305755548862746`, 
     0.4799402163165737}}]}, 
   {Hue[0.5682454723620126], AbsoluteThickness[0.5], 
    LineBox[{{2.6305755548862746`, 0.4799402163165737}, {2.344349507463681, 
     0.6226168878589597}}]}, 
   {Hue[0.20713811026926707`], AbsoluteThickness[0.5], 
    LineBox[{{3.2400343877105398`, -0.9437469192977916}, {
     3.325123325737031, -1.1200389717686674`}}]}, 
   {Hue[0.21592259216759763`], AbsoluteThickness[0.5], 
    LineBox[{{3.325123325737031, -1.1200389717686674`}, {
     3.364476345721229, -1.3064607354402753`}}]}, 
   {Hue[0.46810335337905185`], AbsoluteThickness[0.5], 
    LineBox[{{3.364476345721229, -1.3064607354402753`}, {
     3.2027793780617917`, -1.4072368476993442`}}]}, 
   {Hue[0.6376909824252127], AbsoluteThickness[0.5], 
    LineBox[{{2.8898375745696994`, -0.35005625651296285`}, {
     2.889522218422938, -0.3508912418278203}}]}, 
   {Hue[0.6443286758533234], AbsoluteThickness[0.5], 
    LineBox[{{2.889522218422938, -0.3508912418278203}, {
     2.8634269383364326`, -0.5359268083990747}}]}, 
   {Hue[0.43360815845292], AbsoluteThickness[0.5], 
    LineBox[{{2.7234410453299605`, -0.4006132907740559}, {
     2.6586965246346144`, -0.40277356925606367`}}]}, 
   {Hue[0.4351587311326295], AbsoluteThickness[0.5], 
    LineBox[{{2.6586965246346144`, -0.40277356925606367`}, {
     2.4028506685559146`, -0.4432108649801812}}]}, 
   {Hue[0.6605241916018165], AbsoluteThickness[0.5], 
    LineBox[{{2.6128173190127457`, -0.26642607144224856`}, {
     2.5664734532807705`, -0.16479273065591432`}}]}, 
   {Hue[0.6609522402400873], AbsoluteThickness[0.5], 
    LineBox[{{2.5664734532807705`, -0.16479273065591432`}, {2.421376778529907,
      0.14780057953291653`}}]}, 
   {Hue[0.30145732389825625`], AbsoluteThickness[0.5], 
    LineBox[{{2.8571311772373402`, -0.8971899453798242}, {
     2.8563113942277067`, -0.9060147464990681}}]}, 
   {Hue[0.3046941304343226], AbsoluteThickness[0.5], 
    LineBox[{{2.8563113942277067`, -0.9060147464990682}, {
     2.8715242600189383`, -1.0989808790739592`}}]}, 
   {Hue[0.6553044963580161], AbsoluteThickness[0.5], 
    LineBox[{{2.8715242600189383`, -1.0989808790739592`}, {
     3.06501006817152, -1.104512754889161}}]}, 
   {Hue[0.45942595369262645`], AbsoluteThickness[0.5], 
    LineBox[{{3.372567902996115, -0.8100452142830538}, {
     3.4277821105117194`, -0.8410562120338377}}]}, 
   {Hue[0.45990393050820844`], AbsoluteThickness[0.5], 
    LineBox[{{3.4277821105117194`, -0.8410562120338377}, {
     3.702329385580309, -1.0068929084054716`}}]}, 
   {Hue[0.6230413020264919], AbsoluteThickness[0.5], 
    LineBox[{{3.421423806264096, -0.2825810055807319}, {
     3.4903916595599216`, -0.1758711010087941}}]}, 
   {Hue[0.6245786522945052], AbsoluteThickness[0.5], 
    LineBox[{{3.4903916595599216`, -0.1758711010087941}, {3.5983048157285022`,
      0.04699756291471004}}]}, 
   {Hue[0.3488958501796191], AbsoluteThickness[0.5], 
    LineBox[{{2.195596374572923, 0.3978620967099139}, {2.1619972585588854`, 
     0.44132213920690205`}}]}, 
   {Hue[0.3502240660124829], AbsoluteThickness[0.5], 
    LineBox[{{2.1619972585588854`, 0.4413221392069021}, {2.0297050967594505`, 
     0.5773459705747525}}]}, 
   {Hue[0.3975618618020706], AbsoluteThickness[0.5], 
    LineBox[{{2.9975989904754834`, 0.6838805315256868}, {3.085373554616704, 
     0.8263604625381721}}]}, 
   {Hue[0.39976570693950186`], AbsoluteThickness[0.5], 
    LineBox[{{3.085373554616704, 0.8263604625381721}, {3.184498913930864, 
     1.0569230663444962`}}]}, 
   {Hue[0.44206917282406094`], AbsoluteThickness[0.5], 
    LineBox[{{3.6081986565921556`, 0.017716622596220213`}, {
     3.8664668858935545`, 0.047648253738065985`}}]}, 
   {Hue[0.4425456119820022], AbsoluteThickness[0.5], 
    LineBox[{{3.8664668858935545`, 0.047648253738065985`}, {4.18194095109985, 
     0.0742725784541767}}]}, 
   {Hue[0.49123700240385476`], AbsoluteThickness[0.5], 
    LineBox[{{3.324794887888377, -0.9016303589318031}, {
     3.4849000553862717`, -1.333765589463227}}]}, 
   {Hue[0.4916774928144509], AbsoluteThickness[0.5], 
    LineBox[{{3.4849000553862717`, -1.333765589463227}, {
     3.5970617274515204`, -1.6530476159983183`}}]}, 
   {Hue[0.5417028014335583], AbsoluteThickness[0.5], 
    LineBox[{{2.852834309821224, -0.8994567877210135}, {
     2.850290088783619, -0.9144996643947538}}]}, 
   {Hue[0.5484910416133296], AbsoluteThickness[0.5], 
    LineBox[{{2.850290088783619, -0.9144996643947538}, {
     2.859768874381566, -1.0863859974867898`}}]}, 
   {Hue[0.6339089663596952], AbsoluteThickness[0.5], 
    LineBox[{{2.1197516504485256`, 0.3650022290104738}, {2.119693188743627, 
     0.3651244829758437}}]}, 
   {Hue[0.6343835237967073], AbsoluteThickness[0.5], 
    LineBox[{{2.119693188743627, 0.3651244829758437}, {2.0118250519628877`, 
     0.5740150132060365}}]}, 
   {Hue[0.4382808807844868], AbsoluteThickness[0.5], 
    LineBox[{{2.1295875536393534`, -2.0850810008378438`}, {
     2.1464827735478753`, -2.130283941301259}}]}, 
   {Hue[0.4389946795135438], AbsoluteThickness[0.5], 
    LineBox[{{2.1464827735478753`, -2.130283941301259}, {
     2.272689901367994, -2.406890875590992}}]}, 
   {Hue[0.6948166383225558], AbsoluteThickness[0.5], 
    LineBox[{{2.883111229732781, -1.3551477014158069`}, {
     3.0622490638126414`, -1.3139816614583502`}}]}, 
   {Hue[0.6952828911454324], AbsoluteThickness[0.5], 
    LineBox[{{3.0622490638126414`, -1.3139816614583502`}, {
     3.377512319861927, -1.2321933568162822`}}]}, 
   {Hue[0.5592209280477233], AbsoluteThickness[0.5], 
    LineBox[{{2.907374819709145, 0.45947675539319044`}, {2.6382246554234308`, 
     0.559702902574437}}]}, 
   {Hue[0.559906327550012], AbsoluteThickness[0.5], 
    LineBox[{{2.6382246554234308`, 0.559702902574437}, {2.359727162854879, 
     0.6425911505519412}}]}, 
   {Hue[0.5530118402198186], AbsoluteThickness[0.5], 
    LineBox[{{3.6593759916094317`, 0.09416279696687695}, {3.576828693306439, 
     0.08208842290350196}}]}, 
   {Hue[0.5537234326671152], AbsoluteThickness[0.5], 
    LineBox[{{3.576828693306439, 0.08208842290350196}, {3.294046053076269, 
     0.020225647945753017`}}]}, 
   {Hue[0.5443665811523712], AbsoluteThickness[0.5], 
    LineBox[{{4.601695693919178, 0.23594106116083657`}, {4.52097514242711, 
     0.18445403627848816`}}]}, 
   {Hue[0.5508394124214476], AbsoluteThickness[0.5], 
    LineBox[{{4.52097514242711, 0.18445403627848816`}, {4.391688530534574, 
     0.05475793269206992}}]}, 
   {Hue[0.004546688844466151], AbsoluteThickness[0.5], 
    LineBox[{{4.863813492830697, 0.24759556150123316`}, {5.052304038930609, 
     0.26253844878662325`}}]}, 
   {Hue[0.004994393487956761], AbsoluteThickness[0.5], 
    LineBox[{{5.052304038930609, 0.26253844878662325`}, {5.366837784262577, 
     0.2809346659719588}}]}, 
   {Hue[0.5546825707383343], AbsoluteThickness[0.5], 
    LineBox[{{5.366837784262577, 0.2809346659719588}, {5.071370206889851, 
     0.17153261626183142`}}]}, 
   {Hue[0.5453442934886397], AbsoluteThickness[0.5], 
    LineBox[{{4.62690327886765, 0.360356895319112}, {4.624103367446432, 
     0.36157235674118404`}}]}, 
   {Hue[0.5461090738500974], AbsoluteThickness[0.5], 
    LineBox[{{4.624103367446432, 0.3615723567411841}, {4.413134841465163, 
     0.47279008433949365`}}]}, 
   {Hue[0.5575117524928732], AbsoluteThickness[0.5], 
    LineBox[{{3.8408596442645777`, 0.49184255073406646`}, {3.197732837515151, 
     0.9870466172241239}}]}, 
   {Hue[0.5584163647238793], AbsoluteThickness[0.5], 
    LineBox[{{3.197732837515151, 0.9870466172241239}, {2.94598757631634, 
     1.1478827614274043`}}]}, 
   {Hue[0.5514434671364085], AbsoluteThickness[0.5], 
    LineBox[{{2.943179205514489, -0.17343081245111755`}, {
     2.9107638883722635`, -0.18433107360470816`}}]}, 
   {Hue[0.5518787332050002], AbsoluteThickness[0.5], 
    LineBox[{{2.9107638883722635`, -0.18433107360470816`}, {
     2.6164943479978957`, -0.2877852582944216}}]}, 
   {Hue[0.5533896578326145], AbsoluteThickness[0.5], 
    LineBox[{{2.8457390881039912`, -0.4818399527270362}, {
     2.714645631809393, -0.5016236144179985}}]}, 
   {Hue[0.5538158014545294], AbsoluteThickness[0.5], 
    LineBox[{{2.714645631809393, -0.5016236144179985}, {
     2.379923875036063, -0.5531084053751678}}]}, 
   {Hue[0.5593384125352346], AbsoluteThickness[0.5], 
    LineBox[{{3.595680938826611, -0.36963416433135804`}, {
     3.5636009124317947`, -0.3702860050126534}}]}, 
   {Hue[0.5787935381814001], AbsoluteThickness[0.5], 
    LineBox[{{3.5636009124317947`, -0.3702860050126534}, {
     3.3999600924020617`, -0.42534677111738073`}}]}, 
   {Hue[0.5585363003230467], AbsoluteThickness[0.5], 
    LineBox[{{4.561078049033883, -0.23728288732784375`}, {
     4.443560485795432, -0.23119222338034892`}}]}, 
   {Hue[0.5589696447350025], AbsoluteThickness[0.5], 
    LineBox[{{4.443560485795432, -0.23119222338034892`}, {
     4.088567434479197, -0.21714319302586768`}}]}, 
   {Hue[0.00532981780412215], AbsoluteThickness[0.5], 
    LineBox[{{4.882724830949978, -0.2157101776218346}, {
     5.099609525107984, -0.2028400501221107}}]}, 
   {Hue[0.005757051057269635], AbsoluteThickness[0.5], 
    LineBox[{{5.099609525107984, -0.2028400501221107}, {
     5.45849530149234, -0.1834995929831887}}]}, 
   {Hue[0.560177994388936], AbsoluteThickness[0.5], 
    LineBox[{{5.45849530149234, -0.1834995929831887}, {
     5.102228077869781, -0.2308991620278369}}]}, 
   {Hue[0.5593937884571158], AbsoluteThickness[0.5], 
    LineBox[{{4.565450186581573, -0.2727963770218793}, {
     4.434942807589305, -0.29524240487108444`}}]}, 
   {Hue[0.5600466817658839], AbsoluteThickness[0.5], 
    LineBox[{{4.434942807589305, -0.29524240487108444`}, {
     4.111587846946577, -0.32998986952944287`}}]}, 
   {Hue[0.5585436973526794], AbsoluteThickness[0.5], 
    LineBox[{{3.5603716232746945`, -0.15846308357112476`}, {
     3.5316042194690076`, -0.1591542120435735}}]}, 
   {Hue[0.5628671268579857], AbsoluteThickness[0.5], 
    LineBox[{{3.5316042194690076`, -0.1591542120435735}, {
     3.3286352578910163`, -0.12497559861961947`}}]}, 
   {Hue[0.6357110866815519], AbsoluteThickness[0.5], 
    LineBox[{{3.1363680938544887`, 0.08641579324362264}, {2.9024358384691284`,
      0.30043174420794533`}}]}, 
   {Hue[0.6402894077546302], AbsoluteThickness[0.5], 
    LineBox[{{2.9024358384691284`, 0.30043174420794533`}, {
     2.7111134817882525`, 0.4167285499341622}}]}, 
   {Hue[0.657091618005383], AbsoluteThickness[0.5], 
    LineBox[{{2.9788411309941583`, 0.10377410675835898`}, {
     2.6573189686911025`, 0.010704642089690963`}}]}, 
   {Hue[0.6575345022333006], AbsoluteThickness[0.5], 
    LineBox[{{2.6573189686911025`, 0.01070464208969096}, {
     2.327054826720669, -0.07837704179538471}}]}, 
   {Hue[0.6699332354316281], AbsoluteThickness[0.5], 
    LineBox[{{2.5853601224432254`, 0.9551921831815049}, {2.6462008017539094`, 
     1.0886347210078553`}}]}, 
   {Hue[0.670420481912706], AbsoluteThickness[0.5], 
    LineBox[{{2.6462008017539094`, 1.0886347210078553`}, {2.7980117033982843`,
      1.3934937632431754`}}]}, 
   {Hue[0.48741241682176284`], AbsoluteThickness[0.5], 
    LineBox[{{2.527720714492665, 1.075856030541967}, {2.411896279701458, 
     1.2075654729496559`}}]}, 
   {Hue[0.48867815404655485`], AbsoluteThickness[0.5], 
    LineBox[{{2.411896279701458, 1.2075654729496559`}, {2.2167912434514574`, 
     1.3854501205427079`}}]}, 
   {Hue[0.6972517587619887], AbsoluteThickness[0.5], 
    LineBox[{{2.394035160157421, 1.0726563476204143`}, {2.1604790001355156`, 
     1.0005099379772664`}}]}, 
   {Hue[0.6977522253567564], AbsoluteThickness[0.5], 
    LineBox[{{2.1604790001355156`, 1.0005099379772664`}, {1.8455432951950819`,
      0.9160594491701124}}]}, 
   {Hue[0.5153275562353563], AbsoluteThickness[0.5], 
    LineBox[{{2.968222391413082, 0.6729311245888335}, {2.913485151457912, 
     0.7744319591682558}}]}, 
   {Hue[0.5587701015100149], AbsoluteThickness[0.5], 
    LineBox[{{2.913485151457912, 0.7744319591682558}, {2.7892122502709484`, 
     0.8800256381185261}}]}, 
   {Hue[0.6655525135582868], AbsoluteThickness[0.5], 
    LineBox[{{2.7892122502709484`, 0.8800256381185261}, {2.634964058056545, 
     0.8270985731869998}}]}, 
   {Hue[0.5501081327099966], AbsoluteThickness[0.5], 
    LineBox[{{3.541589023775747, -0.20949551165862135`}, {
     3.4055773568163827`, -0.3512927744534235}}]}, 
   {Hue[0.56251026603746], AbsoluteThickness[0.5], 
    LineBox[{{3.4055773568163827`, -0.3512927744534235}, {
     3.256000404042675, -0.44057824634312104`}}]}, 
   {Hue[0.4863000191732601], AbsoluteThickness[0.5], 
    LineBox[{{4.414345705749566, -0.04955096768005579}, {
     4.390368460734918, -0.11257656008242053`}}]}, 
   {Hue[0.48687789870910636`], AbsoluteThickness[0.5], 
    LineBox[{{4.390368460734918, -0.11257656008242053`}, {
     4.255423947588227, -0.4178763946195362}}]}, 
   {Hue[0.008953464406402954], AbsoluteThickness[0.5], 
    LineBox[{{4.6752375112675155`, -0.04424713697000389}, {
     4.832990028820486, -0.027202559478235418`}}]}, 
   {Hue[0.009420608890903848], AbsoluteThickness[0.5], 
    LineBox[{{4.832990028820486, -0.027202559478235418`}, {5.142277007576213, 
     0.015084314234047203`}}]}, 
   {Hue[0.554811132106112], AbsoluteThickness[0.5], 
    LineBox[{{5.142277007576213, 0.015084314234047203`}, {4.841050843674852, 
     0.09699532141546516}}]}, 
   {Hue[0.48810014180485933`], AbsoluteThickness[0.5], 
    LineBox[{{4.552088136111562, 0.18581132561139013`}, {4.292890033019404, 
     0.5824814896451496}}]}, 
   {Hue[0.4886553298951897], AbsoluteThickness[0.5], 
    LineBox[{{4.292890033019404, 0.5824814896451496}, {4.135107583682478, 
     0.851803323964645}}]}, 
   {Hue[0.545919780553905], AbsoluteThickness[0.5], 
    LineBox[{{3.651467429611502, 0.3327005360937112}, {3.5700175713809337`, 
     0.3817758798723022}}]}, 
   {Hue[0.5464214026071911], AbsoluteThickness[0.5], 
    LineBox[{{3.5700175713809337`, 0.3817758798723022}, {3.323730969453257, 
     0.5431940404835234}}]}, 
   {Hue[0.5166830112751679], AbsoluteThickness[0.5], 
    LineBox[{{2.907862025084542, -0.5869738626792271}, {
     2.8425739252236153`, -0.6363062573030404}}]}, 
   {Hue[0.5173966060078463], AbsoluteThickness[0.5], 
    LineBox[{{2.8425739252236153`, -0.6363062573030404}, {
     2.647240616143315, -0.8067402342174992}}]}, 
   {Hue[0.462750779756879], AbsoluteThickness[0.5], 
    LineBox[{{2.35570033438134, -1.5837474344316935`}, {
     2.352646354106483, -1.5892770037072403`}}]}, 
   {Hue[0.4631812161402474], AbsoluteThickness[0.5], 
    LineBox[{{2.352646354106483, -1.5892770037072403`}, {
     2.2067239820607925`, -1.8475836609360137`}}]}, 
   {Hue[0.5541174845944405], AbsoluteThickness[0.5], 
    LineBox[{{2.6147227615855937`, -0.22156981704220616`}, {
     2.427457317686343, -0.2855852585677745}}]}, 
   {Hue[0.5546580896811195], AbsoluteThickness[0.5], 
    LineBox[{{2.427457317686343, -0.2855852585677745}, {
     2.137913604408115, -0.3698563574285671}}]}, 
   {Hue[0.5140866166648025], AbsoluteThickness[0.5], 
    LineBox[{{3.642263659963334, -0.3991251146934465}, {
     3.6358936209485457`, -0.40762523087737623`}}]}, 
   {Hue[0.5145175821381128], AbsoluteThickness[0.5], 
    LineBox[{{3.6358936209485457`, -0.40762523087737623`}, {
     3.436229181584975, -0.6684990164912772}}]}, 
   {Hue[0.5561940237667913], AbsoluteThickness[0.5], 
    LineBox[{{4.395356238859942, -0.006566566343232105}, {
     4.265420315855151, -0.061506355305580296`}}]}, 
   {Hue[0.5635336773471739], AbsoluteThickness[0.5], 
    LineBox[{{4.265420315855151, -0.061506355305580296`}, {
     4.095849981618464, -0.18471435265044758`}}]}, 
   {Hue[0.005705252285961526], AbsoluteThickness[0.5], 
    LineBox[{{4.696163978052853, 0.03599324733908506}, {4.827177397331684, 
     0.05679308296902605}}]}, 
   {Hue[0.006239001803258748], AbsoluteThickness[0.5], 
    LineBox[{{4.827177397331684, 0.05679308296902605}, {5.128533593031247, 
     0.0908711003166565}}]}, 
   {Hue[0.5381556263079548], AbsoluteThickness[0.5], 
    LineBox[{{5.128533593031247, 0.0908711003166565}, {
     4.903471101928317, -0.1124113215781109}}]}, 
   {Hue[0.5570746683726064], AbsoluteThickness[0.5], 
    LineBox[{{4.3939401671095935`, 0.06693515739578867}, {4.178002950172783, 
     0.08536252434372511}}]}, 
   {Hue[0.5577009585845665], AbsoluteThickness[0.5], 
    LineBox[{{4.178002950172783, 0.08536252434372511}, {3.879600942422269, 
     0.09292330051576538}}]}, 
   {Hue[0.5170459831968824], AbsoluteThickness[0.5], 
    LineBox[{{3.7192798596902503`, 0.3726534066930124}, {3.6089133658190238`, 
     0.4354649213826718}}]}, 
   {Hue[0.5174808017990004], AbsoluteThickness[0.5], 
    LineBox[{{3.6089133658190238`, 0.4354649213826718}, {3.342914782957088, 
     0.5821823124342869}}]}, 
   {Hue[0.4545695443073508], AbsoluteThickness[0.5], 
    LineBox[{{2.539535605388227, 3.118803240781984}, {2.6616546941078543`, 
     3.360383408662256}}]}, 
   {Hue[0.4815094499557487], AbsoluteThickness[0.5], 
    LineBox[{{2.6616546941078543`, 3.360383408662256}, {2.685800171831928, 
     3.5359848590544467`}}]}, 
   {Hue[0.6289395970582363], AbsoluteThickness[0.5], 
    LineBox[{{2.685800171831928, 3.5359848590544467`}, {2.543333627930828, 
     3.641446498256768}}]}, 
   {Hue[0.6338705955448221], AbsoluteThickness[0.5], 
    LineBox[{{2.8745288686319053`, 2.329345282810011}, {3.140078688774631, 
     2.2775956541387714`}}]}, 
   {Hue[0.6343043681080311], AbsoluteThickness[0.5], 
    LineBox[{{3.140078688774631, 2.2775956541387714`}, {3.4556780529837225`, 
     2.2119663284869953`}}]}, 
   {Hue[0.5527770798714047], AbsoluteThickness[0.5], 
    LineBox[{{2.4642846093936406`, -0.6781277275165812}, {
     2.1526412923877722`, -1.0570498925188245`}}]}, 
   {Hue[0.5575980996091968], AbsoluteThickness[0.5], 
    LineBox[{{2.1526412923877722`, -1.0570498925188245`}, {
     1.966398076144971, -1.2089410540504004`}}]}, 
   {Hue[0.2166280547272126], AbsoluteThickness[0.5], 
    LineBox[{{3.59467493209646, 0.054559260150850414`}, {3.6652740289866825`, 
     0.08931846231204346}}]}, 
   {Hue[0.21724035861654317`], AbsoluteThickness[0.5], 
    LineBox[{{3.6652740289866825`, 0.08931846231204346}, {3.926254772380242, 
     0.23714258983438735`}}]}, 
   {Hue[0.4730662612720304], AbsoluteThickness[0.5], 
    LineBox[{{3.547583474048439, -0.2972583673152678}, {
     3.527251480654367, -0.3660566636848601}}]}, 
   {Hue[0.4735570081637097], AbsoluteThickness[0.5], 
    LineBox[{{3.527251480654367, -0.3660566636848601}, {
     3.4475719938049676`, -0.6752983326234485}}]}, 
   {Hue[0.1032944256445451], AbsoluteThickness[0.5], 
    LineBox[{{3.7596736669957997`, -0.4050348677060538}, {
     3.8394007095310134`, -0.43099971803285975`}}]}, 
   {Hue[0.10372851025947896`], AbsoluteThickness[0.5], 
    LineBox[{{3.8394007095310134`, -0.43099971803285975`}, {
     4.1276760372185155`, -0.5289829712411999}}]}, 
   {Hue[0.6565406511589658], AbsoluteThickness[0.5], 
    LineBox[{{4.1276760372185155`, -0.5289829712411999}, {
     3.826325649756949, -0.4854935881760177}}]}, 
   {Hue[0.47814522309416163`], AbsoluteThickness[0.5], 
    LineBox[{{3.873238678908653, -0.19598699747015022`}, {
     3.911617891753305, -0.08828846718218916}}]}, 
   {Hue[0.4787589200197369], AbsoluteThickness[0.5], 
    LineBox[{{3.911617891753305, -0.08828846718218916}, {4.028467560567511, 
     0.18779466351870366`}}]}, 
   {Hue[0.6006832807647311], AbsoluteThickness[0.5], 
    LineBox[{{3.3982370456249846`, -0.427450549110732}, {
     3.1456321215557606`, -0.521491541242063}}]}, 
   {Hue[0.6019186872999284], AbsoluteThickness[0.5], 
    LineBox[{{3.1456321215557606`, -0.521491541242063}, {
     2.902658125512283, -0.5829526845220596}}]}, 
   {Hue[0.2683374970079618], AbsoluteThickness[0.5], 
    LineBox[{{3.406262040715667, -0.6432924089884682}, {
     3.4460516111940622`, -0.8247379710095081}}]}, 
   {Hue[0.2689393235910691], AbsoluteThickness[0.5], 
    LineBox[{{3.4460516111940622`, -0.8247379710095081}, {
     3.528110754789435, -1.1187054312706255`}}]}, 
   {Hue[0.6079149243757809], AbsoluteThickness[0.5], 
    LineBox[{{3.621100528052757, -0.6655754379656301}, {
     3.650760544491235, -0.6633359667398288}}]}, 
   {Hue[0.6086370594915008], AbsoluteThickness[0.5], 
    LineBox[{{3.650760544491235, -0.6633359667398288}, {
     3.9237016326017686`, -0.6622169298386851}}]}, 
   {Hue[0.4253147585749921], AbsoluteThickness[0.5], 
    LineBox[{{2.881791696373951, -0.5626418522506015}, {
     2.7015451573763554`, -0.6018592453669857}}]}, 
   {Hue[0.42623776454564993`], AbsoluteThickness[0.5], 
    LineBox[{{2.7015451573763554`, -0.6018592453669857}, {
     2.4164793224120062`, -0.6377326923707514}}]}, 
   {Hue[0.6565934262250789], AbsoluteThickness[0.5], 
    LineBox[{{2.980226787964247, -0.3056509227480123}, {
     2.916351216619701, -0.3032177506683417}}]}, 
   {Hue[0.6570954772638599], AbsoluteThickness[0.5], 
    LineBox[{{2.916351216619701, -0.3032177506683417}, {
     2.6148457965722054`, -0.2802372320933436}}]}, 
   {Hue[0.4593188714807237], AbsoluteThickness[0.5], 
    LineBox[{{3.325123325737031, -1.1200389717686674`}, {
     3.6686838376901174`, -1.2584119795638173`}}]}, 
   {Hue[0.45977421158168325`], AbsoluteThickness[0.5], 
    LineBox[{{3.6686838376901174`, -1.2584119795638173`}, {
     3.913148743137577, -1.3501274316586929`}}]}, 
   {Hue[0.22470707406592852`], AbsoluteThickness[0.5], 
    LineBox[{{3.364476345721229, -1.3064607354402753`}, {
     3.3597839160694156`, -1.44608838718729}}]}, 
   {Hue[0.2392052310114193], AbsoluteThickness[0.5], 
    LineBox[{{3.3597839160694156`, -1.44608838718729}, {
     3.404758582282697, -1.6245889339018431`}}]}, 
   {Hue[0.4434141759057953], AbsoluteThickness[0.5], 
    LineBox[{{3.404758582282697, -1.6245889339018431`}, {
     3.585753712333707, -1.6581437945960604`}}]}, 
   {Hue[0.6476231208001705], AbsoluteThickness[0.5], 
    LineBox[{{3.585753712333707, -1.6581437945960604`}, {
     3.6917251644964177`, -1.5076272934909767`}}]}, 
   {Hue[0.47688783527738265`], AbsoluteThickness[0.5], 
    LineBox[{{3.2027793780617917`, -1.4072368476993442`}, {
     3.1530530975158455`, -1.4234784587965}}]}, 
   {Hue[0.4773591206484959], AbsoluteThickness[0.5], 
    LineBox[{{3.1530530975158455`, -1.4234784587965}, {
     2.853986630803454, -1.5310542021293299`}}]}, 
   {Hue[0.6509663692814341], AbsoluteThickness[0.5], 
    LineBox[{{2.8634269383364326`, -0.5359268083990747}, {
     2.872947894497436, -0.6533461617698819}}]}, 
   {Hue[0.6520651182120174], AbsoluteThickness[0.5], 
    LineBox[{{2.872947894497436, -0.6533461617698819}, {
     2.8682116188913134`, -0.8904418122849334}}]}, 
   {Hue[0.436709303812339], AbsoluteThickness[0.5], 
    LineBox[{{2.4028506685559146`, -0.4432108649801812}, {
     2.1453749663414388`, -0.5172935656179435}}]}, 
   {Hue[0.43780466523306627`], AbsoluteThickness[0.5], 
    LineBox[{{2.1453749663414388`, -0.5172935656179435}, {
     1.8893781927186855`, -0.5637406615155127}}]}, 
   {Hue[0.6613802888783579], AbsoluteThickness[0.5], 
    LineBox[{{2.421376778529907, 0.14780057953291648`}, {2.0848988899183234`, 
     0.8600705597837346}}]}, 
   {Hue[0.6618218872562139], AbsoluteThickness[0.5], 
    LineBox[{{2.0848988899183234`, 0.8600705597837346}, {1.93646642329049, 
     1.1604636241787327`}}]}, 
   {Hue[0.6520676898219507], AbsoluteThickness[0.5], 
    LineBox[{{2.8563113942277067`, -0.9060147464990682}, {
     2.6590917828332916`, -0.9796268613576786}}]}, 
   {Hue[0.6524960864234179], AbsoluteThickness[0.5], 
    LineBox[{{2.6590917828332916`, -0.9796268613576786}, {
     2.323013605671346, -1.102302956667121}}]}, 
   {Hue[0.3079309369703889], AbsoluteThickness[0.5], 
    LineBox[{{2.8715242600189383`, -1.0989808790739592`}, {
     2.873714024527968, -1.1075574786325388`}}]}, 
   {Hue[0.3093582859505262], AbsoluteThickness[0.5], 
    LineBox[{{2.873714024527968, -1.1075574786325388`}, {
     2.9041303709002455`, -1.3367621444720923`}}]}, 
   {Hue[0.6585413028940826], AbsoluteThickness[0.5], 
    LineBox[{{3.06501006817152, -1.104512754889161}, {
     3.1337602342913367`, -1.0946334971989096`}}]}, 
   {Hue[0.6686925505487339], AbsoluteThickness[0.5], 
    LineBox[{{3.1337602342913367`, -1.0946334971989096`}, {
     3.3196439732192724`, -1.1151366902667224`}}]}, 
   {Hue[0.4603819073237904], AbsoluteThickness[0.5], 
    LineBox[{{3.702329385580309, -1.0068929084054716`}, {
     4.102488736641865, -1.2662271189659744`}}]}, 
   {Hue[0.46240660848811005`], AbsoluteThickness[0.5], 
    LineBox[{{4.102488736641865, -1.2662271189659744`}, {
     4.314732828897232, -1.3647014255731107`}}]}, 
   {Hue[0.6261160025625185], AbsoluteThickness[0.5], 
    LineBox[{{3.5983048157285022`, 0.04699756291471005}, {3.6271987218824817`,
      0.13188481588282688`}}]}, 
   {Hue[0.6271476342952961], AbsoluteThickness[0.5], 
    LineBox[{{3.6271987218824817`, 0.13188481588282688`}, {
     3.7380596307648384`, 0.3770099726867892}}]}, 
   {Hue[0.4019695520769332], AbsoluteThickness[0.5], 
    LineBox[{{3.184498913930864, 1.0569230663444962`}, {3.2110021984759407`, 
     1.1565761042478018`}}]}, 
   {Hue[0.4024594808542398], AbsoluteThickness[0.5], 
    LineBox[{{3.2110021984759407`, 1.1565761042478018`}, {3.2900232611704388`,
      1.4167222917943556`}}]}, 
   {Hue[0.44302205113994353`], AbsoluteThickness[0.5], 
    LineBox[{{4.18194095109985, 0.0742725784541767}, {4.399527802886471, 
     0.08581798388051413}}]}, 
   {Hue[0.4435934656149077], AbsoluteThickness[0.5], 
    LineBox[{{4.399527802886471, 0.08581798388051413}, {4.686655972207478, 
     0.08622165667632628}}]}, 
   {Hue[0.492117983225047], AbsoluteThickness[0.5], 
    LineBox[{{3.5970617274515204`, -1.6530476159983183`}, {
     3.609664447845367, -1.6909714176717814`}}]}, 
   {Hue[0.4927046969929398], AbsoluteThickness[0.5], 
    LineBox[{{3.609664447845367, -1.6909714176717814`}, {
     3.701726199437293, -1.9249280219652776`}}]}, 
   {Hue[0.5552792817931009], AbsoluteThickness[0.5], 
    LineBox[{{2.859768874381566, -1.0863859974867898`}, {
     2.86429380862148, -1.1022577637447124`}}]}, 
   {Hue[0.5565186005676112], AbsoluteThickness[0.5], 
    LineBox[{{2.86429380862148, -1.1022577637447124`}, {
     2.9042565557686557`, -1.3366287201462415`}}]}, 
   {Hue[0.43970847824260084`], AbsoluteThickness[0.5], 
    LineBox[{{2.272689901367994, -2.406890875590992}, {
     2.3641695446853777`, -2.574972567250669}}]}, 
   {Hue[0.4464141790416345], AbsoluteThickness[0.5], 
    LineBox[{{2.3641695446853777`, -2.574972567250669}, {
     2.4178316117145657`, -2.76395252762504}}]}, 
   {Hue[0.695749143968309], AbsoluteThickness[0.5], 
    LineBox[{{3.377512319861927, -1.2321933568162822`}, {
     3.8699237235192574`, -1.0896455538483851`}}]}, 
   {Hue[0.6962245306778939], AbsoluteThickness[0.5], 
    LineBox[{{3.8699237235192574`, -1.0896455538483851`}, {
     4.16892785441982, -0.9929907739235758}}]}, 
   {Hue[0.5544350251144119], AbsoluteThickness[0.5], 
    LineBox[{{3.294046053076269, 0.02022564794575301}, {
     3.199595311365762, -0.0074974731096858}}]}, 
   {Hue[0.5548626463057367], AbsoluteThickness[0.5], 
    LineBox[{{3.199595311365762, -0.007497473109685807}, {
     2.8886082715334696`, -0.09672276121696254}}]}, 
   {Hue[0.5573122436905241], AbsoluteThickness[0.5], 
    LineBox[{{4.391688530534574, 0.05475793269206994}, {
     4.313812186746252, -0.06819121057106275}}]}, 
   {Hue[0.5578065806894049], AbsoluteThickness[0.5], 
    LineBox[{{4.313812186746252, -0.06819121057106278}, {
     4.139731794760239, -0.3663097366997461}}]}, 
   {Hue[0.5542348660948434], AbsoluteThickness[0.5], 
    LineBox[{{5.052304038930609, 0.26253844878662325`}, {4.860845239375469, 
     0.31315589606819444`}}]}, 
   {Hue[0.5549719030109445], AbsoluteThickness[0.5], 
    LineBox[{{4.860845239375469, 0.31315589606819444`}, {4.624630986044441, 
     0.3575187712072745}}]}, 
   {Hue[0.0054420981314472925`], AbsoluteThickness[0.5], 
    LineBox[{{5.366837784262577, 0.2809346659719588}, {5.606135787528658, 
     0.2899677338398846}}]}, 
   {Hue[0.006439796866649472], AbsoluteThickness[0.5], 
    LineBox[{{5.606135787528658, 0.2899677338398846}, {5.80240178051527, 
     0.27883532549148554`}}]}, 
   {Hue[0.47519854915516535`], AbsoluteThickness[0.5], 
    LineBox[{{5.80240178051527, 0.27883532549148554`}, {5.714880889201981, 
     0.1028115654407929}}]}, 
   {Hue[0.5551302753818249], AbsoluteThickness[0.5], 
    LineBox[{{5.071370206889851, 0.17153261626183142`}, {5.0570832393391365`, 
     0.16657623791668075`}}]}, 
   {Hue[0.5563756758032831], AbsoluteThickness[0.5], 
    LineBox[{{5.0570832393391365`, 0.16657623791668075`}, {4.827330676204318, 
     0.05754612118601029}}]}, 
   {Hue[0.5468738542115552], AbsoluteThickness[0.5], 
    LineBox[{{4.413134841465163, 0.47279008433949365`}, {4.241543286461828, 
     0.5805474701352541}}]}, 
   {Hue[0.5526744949233534], AbsoluteThickness[0.5], 
    LineBox[{{4.241543286461828, 0.5805474701352541}, {4.097475443932673, 
     0.7208337304881111}}]}, 
   {Hue[0.5593209769548854], AbsoluteThickness[0.5], 
    LineBox[{{2.94598757631634, 1.1478827614274043`}, {2.9234153347442238`, 
     1.1596590187524582`}}]}, 
   {Hue[0.5597567854433619], AbsoluteThickness[0.5], 
    LineBox[{{2.9234153347442238`, 1.1596590187524582`}, {2.6118007358316233`,
      1.3167000521527832`}}]}, 
   {Hue[0.5523139992735919], AbsoluteThickness[0.5], 
    LineBox[{{2.6164943479978957`, -0.2877852582944216}, {
     2.4017729769768796`, -0.3665889202946273}}]}, 
   {Hue[0.5546084873155535], AbsoluteThickness[0.5], 
    LineBox[{{2.4017729769768796`, -0.3665889202946273}, {
     2.1808079802576663`, -0.4120780166734417}}]}, 
   {Hue[0.5542419450764442], AbsoluteThickness[0.5], 
    LineBox[{{2.379923875036063, -0.5531084053751678}, {
     2.312327405990303, -0.5637019394473732}}]}, 
   {Hue[0.5557432989708464], AbsoluteThickness[0.5], 
    LineBox[{{2.312327405990303, -0.5637019394473732}, {
     2.0674070199659016`, -0.6332743526596728}}]}, 
   {Hue[0.5982486638275654], AbsoluteThickness[0.5], 
    LineBox[{{3.3999600924020617`, -0.42534677111738073`}, {
     2.9321760121152374`, -0.7655784154566689}}]}, 
   {Hue[0.5990664796184508], AbsoluteThickness[0.5], 
    LineBox[{{2.9321760121152374`, -0.7655784154566689}, {
     2.7171692241329706`, -0.8969059450956611}}]}, 
   {Hue[0.5594029891469586], AbsoluteThickness[0.5], 
    LineBox[{{4.088567434479197, -0.21714319302586768`}, {
     3.8768004977137083`, -0.2113545063465883}}]}, 
   {Hue[0.5598628698417752], AbsoluteThickness[0.5], 
    LineBox[{{3.8768004977137083`, -0.2113545063465883}, {
     3.5413379486093546`, -0.2108104658748517}}]}, 
   {Hue[0.5597507611357863], AbsoluteThickness[0.5], 
    LineBox[{{5.099609525107984, -0.2028400501221107}, {
     4.8790982045941975`, -0.19621721650896845`}}]}, 
   {Hue[0.560237875950374], AbsoluteThickness[0.5], 
    LineBox[{{4.8790982045941975`, -0.19621721650896845`}, {
     4.5655808598014005`, -0.1975298447301149}}]}, 
   {Hue[0.006184284310417121], AbsoluteThickness[0.5], 
    LineBox[{{5.45849530149234, -0.1834995929831887}, {
     5.702517598633818, -0.17167844815684608`}}]}, 
   {Hue[0.011410815057517076`], AbsoluteThickness[0.5], 
    LineBox[{{5.702517598633818, -0.17167844815684608`}, {
     5.867734521894159, -0.19759486877790677`}}]}, 
   {Hue[0.3144518497799333], AbsoluteThickness[0.5], 
    LineBox[{{5.867734521894159, -0.19759486877790677`}, {
     5.881621584375135, -0.3642545282191471}}]}, 
   {Hue[0.6174928845023495], AbsoluteThickness[0.5], 
    LineBox[{{5.881621584375135, -0.3642545282191471}, {
     5.722972346301242, -0.4171573811478312}}]}, 
   {Hue[0.5606052276420835], AbsoluteThickness[0.5], 
    LineBox[{{5.102228077869781, -0.2308991620278369}, {
     4.882211946206031, -0.25895553035957136`}}]}, 
   {Hue[0.5610912102383925], AbsoluteThickness[0.5], 
    LineBox[{{4.882211946206031, -0.25895553035957136`}, {
     4.569886903469295, -0.2880637755968388}}]}, 
   {Hue[0.560699575074652], AbsoluteThickness[0.5], 
    LineBox[{{4.111587846946577, -0.3299898695294428}, {
     3.84764579321074, -0.34155071773923656`}}]}, 
   {Hue[0.5616674950800133], AbsoluteThickness[0.5], 
    LineBox[{{3.84764579321074, -0.34155071773923656`}, {
     3.561407551752648, -0.32764244287447597`}}]}, 
   {Hue[0.5671905563632919], AbsoluteThickness[0.5], 
    LineBox[{{3.3286352578910163`, -0.12497559861961946`}, {
     3.2008760616089726`, -0.07722529242717524}}]}, 
   {Hue[0.5676357230434639], AbsoluteThickness[0.5], 
    LineBox[{{3.2008760616089726`, -0.07722529242717524}, {2.898342925452778, 
     0.029180812310742994`}}]}, 
   {Hue[0.6448677288277086], AbsoluteThickness[0.5], 
    LineBox[{{2.7111134817882525`, 0.4167285499341622}, {2.616872095993363, 
     0.4512776995221469}}]}, 
   {Hue[0.6453225747255039], AbsoluteThickness[0.5], 
    LineBox[{{2.616872095993363, 0.4512776995221469}, {2.3216116719021582`, 
     0.5675537950524521}}]}, 
   {Hue[0.6579773864612183], AbsoluteThickness[0.5], 
    LineBox[{{2.327054826720669, -0.07837704179538471}, {
     2.117771746683905, -0.1307367370540217}}]}, 
   {Hue[0.6596551489062331], AbsoluteThickness[0.5], 
    LineBox[{{2.117771746683905, -0.1307367370540217}, {
     1.828934746370603, -0.16458716458333686`}}]}, 
   {Hue[0.6709077283937837], AbsoluteThickness[0.5], 
    LineBox[{{2.7980117033982843`, 1.3934937632431754`}, {2.82597737240743, 
     1.445141512435483}}]}, 
   {Hue[0.6720382776166899], AbsoluteThickness[0.5], 
    LineBox[{{2.82597737240743, 1.445141512435483}, {2.9841841247841243`, 
     1.6768638078438518`}}]}, 
   {Hue[0.4899438912713469], AbsoluteThickness[0.5], 
    LineBox[{{2.2167912434514574`, 1.3854501205427079`}, {2.1540597854103885`,
      1.4310965143762735`}}]}, 
   {Hue[0.49036998422269124`], AbsoluteThickness[0.5], 
    LineBox[{{2.1540597854103885`, 1.4310965143762735`}, {1.8540552920855577`,
      1.6481790350858472`}}]}, 
   {Hue[0.6221099682836317], AbsoluteThickness[0.5], 
    LineBox[{{2.913485151457912, 0.7744319591682558}, {2.8935418342225865`, 
     0.8710614893840449}}]}, 
   {Hue[0.625632519965274], AbsoluteThickness[0.5], 
    LineBox[{{2.8935418342225865`, 0.8710614893840449}, {2.8874035734091468`, 
     1.10198434706606}}]}, 
   {Hue[0.6022126467846753], AbsoluteThickness[0.5], 
    LineBox[{{2.7892122502709484`, 0.8800256381185261}, {2.5846821033899388`, 
     0.9506332016911754}}]}, 
   {Hue[0.602659621492767], AbsoluteThickness[0.5], 
    LineBox[{{2.5846821033899388`, 0.9506332016911754}, {2.352983524652996, 
     1.0253794253453705`}}]}, 
   {Hue[0.5749123993649233], AbsoluteThickness[0.5], 
    LineBox[{{3.256000404042675, -0.44057824634312104`}, {
     3.1576366157122564`, -0.4678099558354448}}]}, 
   {Hue[0.5754196272960939], AbsoluteThickness[0.5], 
    LineBox[{{3.1576366157122564`, -0.4678099558354448}, {
     2.8639326359109543`, -0.5368481393736253}}]}, 
   {Hue[0.4874557782449527], AbsoluteThickness[0.5], 
    LineBox[{{4.255423947588227, -0.4178763946195362}, {
     4.036738308826849, -0.8496232596296852}}]}, 
   {Hue[0.48795205709548317`], AbsoluteThickness[0.5], 
    LineBox[{{4.036738308826849, -0.8496232596296852}, {
     3.906321006824047, -1.1323062654716896`}}]}, 
   {Hue[0.5543439876216101], AbsoluteThickness[0.5], 
    LineBox[{{4.832990028820486, -0.02720255947823541}, {
     4.75427543344803, -0.07716007618682391}}]}, 
   {Hue[0.5558111913218743], AbsoluteThickness[0.5], 
    LineBox[{{4.75427543344803, -0.07716007618682394}, {
     4.56106779556066, -0.23511651421186447`}}]}, 
   {Hue[0.00988775337540474], AbsoluteThickness[0.5], 
    LineBox[{{5.142277007576213, 0.015084314234047207`}, {5.42537494225042, 
     0.061972026157283644`}}]}, 
   {Hue[0.010389178017309653`], AbsoluteThickness[0.5], 
    LineBox[{{5.42537494225042, 0.061972026157283644`}, {5.650799368953584, 
     0.0905921834868246}}]}, 
   {Hue[0.5486205893304849], AbsoluteThickness[0.5], 
    LineBox[{{5.650799368953584, 0.0905921834868246}, {
     5.470897539825824, -0.04822646596815339}}]}, 
   {Hue[0.5552782765906129], AbsoluteThickness[0.5], 
    LineBox[{{4.841050843674852, 0.09699532141546516}, {4.6491923023454085`, 
     0.143388082775297}}]}, 
   {Hue[0.559037259557577], AbsoluteThickness[0.5], 
    LineBox[{{4.6491923023454085`, 0.143388082775297}, {4.450118751470528, 
     0.15453265875445632`}}]}, 
   {Hue[0.4892105179855201], AbsoluteThickness[0.5], 
    LineBox[{{4.135107583682478, 0.851803323964645}, {4.108834939470362, 
     0.9021312097453184}}]}, 
   {Hue[0.48963634489523333`], AbsoluteThickness[0.5], 
    LineBox[{{4.108834939470362, 0.9021312097453185}, {3.961918265434178, 
     1.182649410057742}}]}, 
   {Hue[0.5469230246604772], AbsoluteThickness[0.5], 
    LineBox[{{3.323730969453257, 0.5431940404835234}, {3.2765449932879607`, 
     0.5767427377148219}}]}, 
   {Hue[0.5489883956224629], AbsoluteThickness[0.5], 
    LineBox[{{3.2765449932879607`, 0.5767427377148219}, {3.118905256025041, 
     0.726560353059262}}]}, 
   {Hue[0.5181102007405246], AbsoluteThickness[0.5], 
    LineBox[{{2.647240616143315, -0.8067402342174992}, {
     2.577317499304449, -0.8769965616946857}}]}, 
   {Hue[0.5185901824564385], AbsoluteThickness[0.5], 
    LineBox[{{2.577317499304449, -0.8769965616946857}, {
     2.3392208896889843`, -1.1321674856164217`}}]}, 
   {Hue[0.46361165252361575`], AbsoluteThickness[0.5], 
    LineBox[{{2.2067239820607925`, -1.8475836609360137`}, {
     2.1840774098726543`, -1.8867865369329238`}}]}, 
   {Hue[0.46458087640451945`], AbsoluteThickness[0.5], 
    LineBox[{{2.1840774098726543`, -1.8867865369329238`}, {
     2.0188747524139967`, -2.120032197837451}}]}, 
   {Hue[0.5551986947677985], AbsoluteThickness[0.5], 
    LineBox[{{2.137913604408115, -0.3698563574285671}, {
     2.13772734196492, -0.36990135851255124`}}]}, 
   {Hue[0.5556972752056559], AbsoluteThickness[0.5], 
    LineBox[{{2.13772734196492, -0.36990135851255124`}, {
     1.8423154086426972`, -0.45300126496994053`}}]}, 
   {Hue[0.5149485476114233], AbsoluteThickness[0.5], 
    LineBox[{{3.436229181584975, -0.6684990164912772}, {
     3.3708432532166763`, -0.7521577090783749}}]}, 
   {Hue[0.5159965133906628], AbsoluteThickness[0.5], 
    LineBox[{{3.3708432532166763`, -0.7521577090783749}, {
     3.188392959968137, -0.9436891312701828}}]}, 
   {Hue[0.5708733309275567], AbsoluteThickness[0.5], 
    LineBox[{{4.095849981618464, -0.18471435265044756`}, {
     3.9598442902255067`, -0.3416338978443101}}]}, 
   {Hue[0.5725126482016497], AbsoluteThickness[0.5], 
    LineBox[{{3.9598442902255067`, -0.3416338978443101}, {
     3.8316990547305285`, -0.5342167478353262}}]}, 
   {Hue[0.5376218767906582], AbsoluteThickness[0.5], 
    LineBox[{{4.827177397331684, 0.05679308296902605}, {4.671214238066102, 
     0.1533250819963855}}]}, 
   {Hue[0.6087527173849946], AbsoluteThickness[0.5], 
    LineBox[{{4.671214238066102, 0.1533250819963855}, {4.596740882042578, 
     0.26127015676321136`}}]}, 
   {Hue[0.6781141914512306], AbsoluteThickness[0.5], 
    LineBox[{{4.596740882042578, 0.26127015676321136`}, {4.648865638540726, 
     0.3816089688058395}}]}, 
   {Hue[0.006772751320555969], AbsoluteThickness[0.5], 
    LineBox[{{5.128533593031247, 0.09087110031665652}, {5.172024960391357, 
     0.09382262051315829}}]}, 
   {Hue[0.019097168051549138`], AbsoluteThickness[0.5], 
    LineBox[{{5.172024960391357, 0.09382262051315829}, {5.33742565993638, 
     0.151464732174096}}]}, 
   {Hue[0.23870450076368638`], AbsoluteThickness[0.5], 
    LineBox[{{5.33742565993638, 0.151464732174096}, {5.349869868094014, 
     0.3261792024678993}}]}, 
   {Hue[0.4583118334758238], AbsoluteThickness[0.5], 
    LineBox[{{5.349869868094014, 0.3261792024678993}, {5.194308683863191, 
     0.4066821366219967}}]}, 
   {Hue[0.6779191661879621], AbsoluteThickness[0.5], 
    LineBox[{{5.194308683863191, 0.4066821366219967}, {5.058863748367576, 
     0.29562055957888445`}}]}, 
   {Hue[0.538689375825252], AbsoluteThickness[0.5], 
    LineBox[{{4.903471101928317, -0.1124113215781109}, {
     4.858938172292427, -0.14914736691011363`}}]}, 
   {Hue[0.5391271654541213], AbsoluteThickness[0.5], 
    LineBox[{{4.858938172292427, -0.14914736691011363`}, {
     4.608285783322222, -0.34952187283997316`}}]}, 
   {Hue[0.5583272487965266], AbsoluteThickness[0.5], 
    LineBox[{{3.879600942422269, 0.09292330051576538}, {3.8692769414660475`, 
     0.09256733071978662}}]}, 
   {Hue[0.5604448980952849], AbsoluteThickness[0.5], 
    LineBox[{{3.8692769414660475`, 0.09256733071978662}, {3.6367806213443363`,
      0.11802196092701508`}}]}, 
   {Hue[0.5179156204011184], AbsoluteThickness[0.5], 
    LineBox[{{3.342914782957088, 0.5821823124342869}, {3.3295939083772343`, 
     0.5892994309250794}}]}, 
   {Hue[0.5188817149518523], AbsoluteThickness[0.5], 
    LineBox[{{3.3295939083772343`, 0.5892994309250794}, {3.1189126181110796`, 
     0.7282035471707415}}]}, 
   {Hue[0.601999691409838], AbsoluteThickness[0.5], 
    LineBox[{{2.6616546941078543`, 3.360383408662256}, {2.850141650565729, 
     3.517648208755739}}]}, 
   {Hue[0.6027685376266578], AbsoluteThickness[0.5], 
    LineBox[{{2.850141650565729, 3.517648208755739}, {3.0716192585720115`, 
     3.6755469904960334`}}]}, 
   {Hue[0.5084493556041464], AbsoluteThickness[0.5], 
    LineBox[{{2.685800171831928, 3.5359848590544467`}, {2.674447045659083, 
     3.5935420250603416`}}]}, 
   {Hue[0.5090660565692565], AbsoluteThickness[0.5], 
    LineBox[{{2.674447045659083, 3.5935420250603416`}, {2.6300443294614073`, 
     3.9173555973417025`}}]}, 
   {Hue[0.6558795027066334], AbsoluteThickness[0.5], 
    LineBox[{{2.543333627930828, 3.641446498256768}, {2.3729099646591956`, 
     3.6952574273286736`}}]}, 
   {Hue[0.6563254596871463], AbsoluteThickness[0.5], 
    LineBox[{{2.3729099646591956`, 3.6952574273286736`}, {2.0851231123706127`,
      3.779878566618073}}]}, 
   {Hue[0.6347381406712401], AbsoluteThickness[0.5], 
    LineBox[{{3.4556780529837225`, 2.2119663284869953`}, {3.5733976108464542`,
      2.185939241906808}}]}, 
   {Hue[0.6353585576819492], AbsoluteThickness[0.5], 
    LineBox[{{3.5733976108464542`, 2.185939241906808}, {3.813303709540879, 
     2.1475676316072554`}}]}, 
   {Hue[0.2178526625058737], AbsoluteThickness[0.5], 
    LineBox[{{3.926254772380242, 0.2371425898343873}, {4.595951501012071, 
     0.6694413043944741}}]}, 
   {Hue[0.21833084792237303`], AbsoluteThickness[0.5], 
    LineBox[{{4.595951501012071, 0.6694413043944741}, {4.858487167708719, 
     0.8273537714638362}}]}, 
   {Hue[0.47404775505538893`], AbsoluteThickness[0.5], 
    LineBox[{{3.4475719938049676`, -0.6752983326234485}, {
     3.4041392821881984`, -0.8722971995988552}}]}, 
   {Hue[0.48662644031169117`], AbsoluteThickness[0.5], 
    LineBox[{{3.4041392821881984`, -0.8722971995988552}, {
     3.4135500914377803`, -1.0524968311817386`}}]}, 
   {Hue[0.6561065665440332], AbsoluteThickness[0.5], 
    LineBox[{{3.8394007095310134`, -0.43099971803285975`}, {
     3.7806236941805005`, -0.39697314291557895`}}]}, 
   {Hue[0.6569555422418499], AbsoluteThickness[0.5], 
    LineBox[{{3.7806236941805005`, -0.39697314291557895`}, {
     3.538957731198718, -0.22880409005405572`}}]}, 
   {Hue[0.10416259487441276`], AbsoluteThickness[0.5], 
    LineBox[{{4.1276760372185155`, -0.5289829712411999}, {
     4.358494859437787, -0.6107486741147179}}]}, 
   {Hue[0.1055661646118427], AbsoluteThickness[0.5], 
    LineBox[{{4.358494859437787, -0.6107486741147179}, {
     4.600833452354866, -0.6658299499796387}}]}, 
   {Hue[0.5399384175566165], AbsoluteThickness[0.5], 
    LineBox[{{4.600833452354866, -0.6658299499796387}, {
     4.6023213729189525`, -0.41731490685280387`}}]}, 
   {Hue[0.6569747357738996], AbsoluteThickness[0.5], 
    LineBox[{{3.826325649756949, -0.4854935881760177}, {
     3.676099057010194, -0.4618462247349159}}]}, 
   {Hue[0.6577762601116705], AbsoluteThickness[0.5], 
    LineBox[{{3.676099057010194, -0.4618462247349159}, {
     3.38927552078789, -0.43969249874601113`}}]}, 
   {Hue[0.4793726169453121], AbsoluteThickness[0.5], 
    LineBox[{{4.028467560567511, 0.18779466351870366`}, {4.223817104062298, 
     0.5836419242159948}}]}, 
   {Hue[0.4798406089236121], AbsoluteThickness[0.5], 
    LineBox[{{4.223817104062298, 0.5836419242159948}, {4.358808429733142, 
     0.8780625970519161}}]}, 
   {Hue[0.6031540938351255], AbsoluteThickness[0.5], 
    LineBox[{{2.902658125512283, -0.5829526845220596}, {
     2.6965387593996546`, -0.6118154978332071}}]}, 
   {Hue[0.6040559887863615], AbsoluteThickness[0.5], 
    LineBox[{{2.6965387593996546`, -0.6118154978332071}, {
     2.408238468149282, -0.6267284163405217}}]}, 
   {Hue[0.26954115017417624`], AbsoluteThickness[0.5], 
    LineBox[{{3.528110754789435, -1.1187054312706255`}, {
     3.608166766539203, -1.353535850804943}}]}, 
   {Hue[0.2713177341076922], AbsoluteThickness[0.5], 
    LineBox[{{3.608166766539203, -1.353535850804943}, {
     3.657724852266612, -1.6026496459086574`}}]}, 
   {Hue[0.6819932674575423], AbsoluteThickness[0.5], 
    LineBox[{{3.657724852266612, -1.6026496459086574`}, {
     3.404671635664303, -1.6245072839138393`}}]}, 
   {Hue[0.6093591946072207], AbsoluteThickness[0.5], 
    LineBox[{{3.9237016326017686`, -0.6622169298386851}, {
     4.152349189811985, -0.6775964721340085}}]}, 
   {Hue[0.6102187817740935], AbsoluteThickness[0.5], 
    LineBox[{{4.152349189811985, -0.6775964721340085}, {
     4.415046585483993, -0.7176293577921055}}]}, 
   {Hue[0.42716077051630774`], AbsoluteThickness[0.5], 
    LineBox[{{2.4164793224120062`, -0.6377326923707514}, {
     2.3725994873179994`, -0.6393188408307626}}]}, 
   {Hue[0.4276841424012997], AbsoluteThickness[0.5], 
    LineBox[{{2.3725994873179994`, -0.6393188408307626}, {
     2.057236045360976, -0.6642455881227427}}]}, 
   {Hue[0.657597528302641], AbsoluteThickness[0.5], 
    LineBox[{{2.6148457965722054`, -0.2802372320933436}, {
     2.426137487843602, -0.2586173491707849}}]}, 
   {Hue[0.6580723382132412], AbsoluteThickness[0.5], 
    LineBox[{{2.426137487843602, -0.2586173491707849}, {
     2.1170653404762017`, -0.23278758243140396`}}]}, 
   {Hue[0.46022955168264285`], AbsoluteThickness[0.5], 
    LineBox[{{3.913148743137577, -1.3501274316586929`}, {
     3.9269164874432256`, -1.3549195230532967`}}]}, 
   {Hue[0.46176136395927075`], AbsoluteThickness[0.5], 
    LineBox[{{3.9269164874432256`, -1.3549195230532967`}, {
     4.10912079822532, -1.4446411213961046`}}]}, 
   {Hue[0.42891601896030573`], AbsoluteThickness[0.5], 
    LineBox[{{3.3597839160694156`, -1.44608838718729}, {
     3.272512283899342, -1.5700472752329944`}}]}, 
   {Hue[0.4295708430054045], AbsoluteThickness[0.5], 
    LineBox[{{3.272512283899342, -1.5700472752329944`}, {
     3.1177500524423447`, -1.8225206149839357`}}]}, 
   {Hue[0.25370338795691044`], AbsoluteThickness[0.5], 
    LineBox[{{3.404758582282697, -1.6245889339018431`}, {
     3.538787637338851, -1.854796485434874}}]}, 
   {Hue[0.2547194510855044], AbsoluteThickness[0.5], 
    LineBox[{{3.538787637338851, -1.854796485434874}, {
     3.632558011882688, -2.0583933154866663`}}]}, 
   {Hue[0.45791233285128646`], AbsoluteThickness[0.5], 
    LineBox[{{3.585753712333707, -1.6581437945960604`}, {
     4.105838273343717, -1.6074815919482695`}}]}, 
   {Hue[0.45960879532327953`], AbsoluteThickness[0.5], 
    LineBox[{{4.105838273343717, -1.6074815919482695`}, {
     4.378475268704884, -1.6162362186082115`}}]}, 
   {Hue[0.6621212777456617], AbsoluteThickness[0.5], 
    LineBox[{{3.6917251644964177`, -1.5076272934909767`}, {
     3.730177796688385, -1.3964632065864526`}}]}, 
   {Hue[0.662582170509661], AbsoluteThickness[0.5], 
    LineBox[{{3.730177796688385, -1.3964632065864526`}, {
     3.821696238909865, -1.1526604325629248`}}]}, 
   {Hue[0.47783040601960913`], AbsoluteThickness[0.5], 
    LineBox[{{2.853986630803454, -1.5310542021293299`}, {
     2.7529673014329443`, -1.57080553709767}}]}, 
   {Hue[0.48076436889226964`], AbsoluteThickness[0.5], 
    LineBox[{{2.7529673014329443`, -1.57080553709767}, {
     2.559203234888376, -1.6868709258443206`}}]}, 
   {Hue[0.6531638671426006], AbsoluteThickness[0.5], 
    LineBox[{{2.8682116188913134`, -0.8904418122849334}, {
     2.867950080483461, -0.8925953302247663}}]}, 
   {Hue[0.6553361722105696], AbsoluteThickness[0.5], 
    LineBox[{{2.867950080483461, -0.8925953302247663}, {
     2.8730020110747887`, -1.1003668465527434`}}]}, 
   {Hue[0.6529244830248851], AbsoluteThickness[0.5], 
    LineBox[{{2.323013605671346, -1.102302956667121}, {
     2.2459179620371623`, -1.129813681216803}}]}, 
   {Hue[0.6602932392435917], AbsoluteThickness[0.5], 
    LineBox[{{2.2459179620371623`, -1.129813681216803}, {
     2.089410817075282, -1.2304323340849581`}}]}, 
   {Hue[0.3107856349306635], AbsoluteThickness[0.5], 
    LineBox[{{2.9041303709002455`, -1.3367621444720923`}, {
     2.9048649256244583`, -1.389649999584975}}]}, 
   {Hue[0.311942847040752], AbsoluteThickness[0.5], 
    LineBox[{{2.9048649256244583`, -1.389649999584975}, {
     2.935912691191382, -1.651069283213759}}]}, 
   {Hue[0.6788437982033855], AbsoluteThickness[0.5], 
    LineBox[{{3.3196439732192724`, -1.1151366902667224`}, {
     3.6710020674797237`, -1.2483665922592184`}}]}, 
   {Hue[0.6792766100788853], AbsoluteThickness[0.5], 
    LineBox[{{3.6710020674797237`, -1.2483665922592184`}, {
     3.918951591892472, -1.3390557961691687`}}]}, 
   {Hue[0.46443130965242957`], AbsoluteThickness[0.5], 
    LineBox[{{4.314732828897232, -1.3647014255731107`}, {
     4.423067329879084, -1.3974779517178655`}}]}, 
   {Hue[0.46498325008895725`], AbsoluteThickness[0.5], 
    LineBox[{{4.423067329879084, -1.3974779517178655`}, {
     4.691658144714841, -1.4931085690101118`}}]}, 
   {Hue[0.6281792660280736], AbsoluteThickness[0.5], 
    LineBox[{{3.7380596307648384`, 0.3770099726867892}, {3.832038425765837, 
     0.5406200164655531}}]}, 
   {Hue[0.6315770682124153], AbsoluteThickness[0.5], 
    LineBox[{{3.832038425765837, 0.5406200164655531}, {3.9725118789970666`, 
     0.7087801534216872}}]}, 
   {Hue[0.40294940963154646`], AbsoluteThickness[0.5], 
    LineBox[{{3.2900232611704388`, 1.4167222917943556`}, {3.327645798186028, 
     1.5266111617326357`}}]}, 
   {Hue[0.4884875594950248], AbsoluteThickness[0.5], 
    LineBox[{{3.327645798186028, 1.5266111617326357`}, {3.420554636972327, 
     1.624991612196975}}]}, 
   {Hue[0.5454428357256776], AbsoluteThickness[0.5], 
    LineBox[{{3.420554636972327, 1.624991612196975}, {3.5533476311223793`, 
     1.5989764999956206`}}]}, 
   {Hue[0.6023981119563285], AbsoluteThickness[0.5], 
    LineBox[{{3.5533476311223793`, 1.5989764999956206`}, {3.6022662895061597`,
      1.4728110125590168`}}]}, 
   {Hue[0.6593533881869813], AbsoluteThickness[0.5], 
    LineBox[{{3.6022662895061597`, 1.4728110125590168`}, {3.5217201094888617`,
      1.36407703331239}}]}, 
   {Hue[0.4441648800898717], AbsoluteThickness[0.5], 
    LineBox[{{4.686655972207478, 0.08622165667632628}, {4.833290596950009, 
     0.07885446348947601}}]}, 
   {Hue[0.4446603019922383], AbsoluteThickness[0.5], 
    LineBox[{{4.833290596950009, 0.07885446348947601}, {5.140339659344384, 
     0.052205694886659035`}}]}, 
   {Hue[0.49329141076083255`], AbsoluteThickness[0.5], 
    LineBox[{{3.701726199437293, -1.9249280219652776`}, {
     3.774431903123745, -2.0839019487441774`}}]}, 
   {Hue[0.4938054891307955], AbsoluteThickness[0.5], 
    LineBox[{{3.774431903123745, -2.0839019487441774`}, {
     3.8720681809039266`, -2.322657671991838}}]}, 
   {Hue[0.5577579193421213], AbsoluteThickness[0.5], 
    LineBox[{{2.9042565557686557`, -1.3366287201462415`}, {
     2.9073113574141582`, -1.387440713557524}}]}, 
   {Hue[0.5587219622255137], AbsoluteThickness[0.5], 
    LineBox[{{2.9073113574141582`, -1.387440713557524}, {
     2.9487020877182073`, -1.6574727549187507`}}]}, 
   {Hue[0.4531198798406681], AbsoluteThickness[0.5], 
    LineBox[{{2.4178316117145657`, -2.76395252762504}, {
     2.420975009366921, -2.821126710842657}}]}, 
   {Hue[0.453597903099323], AbsoluteThickness[0.5], 
    LineBox[{{2.420975009366921, -2.821126710842657}, {
     2.446499526372531, -3.1152064832394233`}}]}, 
   {Hue[0.6966999173874788], AbsoluteThickness[0.5], 
    LineBox[{{4.16892785441982, -0.9929907739235758}, {
     4.365355900173894, -0.9227278830523508}}]}, 
   {Hue[0.6976125972275194], AbsoluteThickness[0.5], 
    LineBox[{{4.365355900173894, -0.9227278830523508}, {
     4.619315111137644, -0.8564596706259909}}]}, 
   {Hue[0.5552902674970615], AbsoluteThickness[0.5], 
    LineBox[{{2.8886082715334696`, -0.09672276121696258}, {
     2.8391718109797033`, -0.11058097270279177`}}]}, 
   {Hue[0.556882192227468], AbsoluteThickness[0.5], 
    LineBox[{{2.8391718109797033`, -0.11058097270279177`}, {
     2.6193811803709934`, -0.20309558844714137`}}]}, 
   {Hue[0.5583009176882857], AbsoluteThickness[0.5], 
    LineBox[{{4.139731794760239, -0.3663097366997461}, {
     4.112028482091762, -0.4179467646648945}}]}, 
   {Hue[0.5590600021661076], AbsoluteThickness[0.5], 
    LineBox[{{4.112028482091762, -0.4179467646648945}, {
     3.9668532887671657`, -0.6457135222833759}}]}, 
   {Hue[0.5557089399270455], AbsoluteThickness[0.5], 
    LineBox[{{4.624630986044441, 0.3575187712072745}, {4.6188246774659145`, 
     0.3581766695356152}}]}, 
   {Hue[0.5578284727694276], AbsoluteThickness[0.5], 
    LineBox[{{4.6188246774659145`, 0.3581766695356152}, {4.430309945507265, 
     0.40759959654872513`}}]}, 
   {Hue[0.4742008504199631], AbsoluteThickness[0.5], 
    LineBox[{{5.606135787528658, 0.2899677338398846}, {5.588174563523812, 
     0.359238660529973}}]}, 
   {Hue[0.47471229622295], AbsoluteThickness[0.5], 
    LineBox[{{5.588174563523812, 0.359238660529973}, {5.489704000916934, 
     0.6846141681359501}}]}, 
   {Hue[0.0074374956018515735`], AbsoluteThickness[0.5], 
    LineBox[{{5.80240178051527, 0.27883532549148554`}, {6.083630051505965, 
     0.23602948535822793`}}]}, 
   {Hue[0.008128973865447597], AbsoluteThickness[0.5], 
    LineBox[{{6.083630051505965, 0.23602948535822793`}, {6.379705168606001, 
     0.21135111313521757`}}]}, 
   {Hue[0.5138874078311882], AbsoluteThickness[0.5], 
    LineBox[{{6.379705168606001, 0.21135111313521757`}, {6.214542856328803, 
     0.45831448617791504`}}]}, 
   {Hue[0.4761962478903675], AbsoluteThickness[0.5], 
    LineBox[{{5.714880889201981, 0.10281156544079291`}, {
     5.649320955848732, -0.002739609921357973}}]}, 
   {Hue[0.5250496065961963], AbsoluteThickness[0.5], 
    LineBox[{{5.649320955848732, -0.002739609921357973}, {
     5.555955809801064, -0.0712701993743239}}]}, 
   {Hue[0.62243732918482], AbsoluteThickness[0.5], 
    LineBox[{{5.555955809801064, -0.0712701993743239}, {
     5.449065813704587, -0.0266829711383324}}]}, 
   {Hue[0.5576210762247412], AbsoluteThickness[0.5], 
    LineBox[{{4.827330676204318, 0.05754612118601029}, {
     4.681544972068932, -0.032286753882691394`}}]}, 
   {Hue[0.5606212915324753], AbsoluteThickness[0.5], 
    LineBox[{{4.681544972068932, -0.032286753882691394`}, {
     4.489582650202485, -0.11029224565434309`}}]}, 
   {Hue[0.5584751356351516], AbsoluteThickness[0.5], 
    LineBox[{{4.097475443932673, 0.7208337304881112}, {3.9838632461017345`, 
     0.8914965534861593}}]}, 
   {Hue[0.5605957115119908], AbsoluteThickness[0.5], 
    LineBox[{{3.9838632461017345`, 0.8914965534861593}, {3.8858884438484855`, 
     1.0976063891738956`}}]}, 
   {Hue[0.5601925939318385], AbsoluteThickness[0.5], 
    LineBox[{{2.6118007358316233`, 1.3167000521527832`}, {2.5674561156632167`,
      1.3382716709556859`}}]}, 
   {Hue[0.5610027704359555], AbsoluteThickness[0.5], 
    LineBox[{{2.5674561156632167`, 1.3382716709556859`}, {2.309603031135666, 
     1.4902461794867519`}}]}, 
   {Hue[0.5569029753575151], AbsoluteThickness[0.5], 
    LineBox[{{2.1808079802576663`, -0.4120780166734417}, {
     2.15545322079969, -0.41345654092281875`}}]}, 
   {Hue[0.5573548400798112], AbsoluteThickness[0.5], 
    LineBox[{{2.15545322079969, -0.41345654092281875`}, {
     1.842863952109734, -0.4375276940997859}}]}, 
   {Hue[0.5998842954093363], AbsoluteThickness[0.5], 
    LineBox[{{2.7171692241329706`, -0.8969059450956611}, {
     2.639164156689087, -0.9363165367966183}}]}, 
   {Hue[0.6003171318287173], AbsoluteThickness[0.5], 
    LineBox[{{2.639164156689087, -0.9363165367966183}, {
     2.3224815078507897`, -1.101038790960875}}]}, 
   {Hue[0.5603227505365919], AbsoluteThickness[0.5], 
    LineBox[{{3.5413379486093546`, -0.2108104658748517}, {
     3.4060344310255406`, -0.21406986107076148`}}]}, 
   {Hue[0.5609073441753621], AbsoluteThickness[0.5], 
    LineBox[{{3.4060344310255406`, -0.21406986107076148`}, {
     3.1109370133830767`, -0.23707735179789627`}}]}, 
   {Hue[0.5607249907649616], AbsoluteThickness[0.5], 
    LineBox[{{4.5655808598014005`, -0.1975298447301149}, {
     4.439788905500518, -0.20236243872953158`}}]}, 
   {Hue[0.5611739214126737], AbsoluteThickness[0.5], 
    LineBox[{{4.439788905500518, -0.20236243872953158`}, {
     4.08787877627355, -0.22337916764957746`}}]}, 
   {Hue[0.30922531903283235`], AbsoluteThickness[0.5], 
    LineBox[{{5.702517598633818, -0.17167844815684608`}, {5.853426138252766, 
     0.04969917077403267}}]}, 
   {Hue[0.31555341945189835`], AbsoluteThickness[0.5], 
    LineBox[{{5.853426138252766, 0.04969917077403267}, {6.0055110608117905`, 
     0.19277953444732226`}}]}, 
   {Hue[0.5997588318822199], AbsoluteThickness[0.5], 
    LineBox[{{6.0055110608117905`, 0.19277953444732226`}, {6.18536227430891, 
     0.08668827588998902}}]}, 
   {Hue[0.016637345804617107`], AbsoluteThickness[0.5], 
    LineBox[{{5.867734521894159, -0.19759486877790677`}, {
     6.050295898339915, -0.26622712950699384`}}]}, 
   {Hue[0.017128708585694683`], AbsoluteThickness[0.5], 
    LineBox[{{6.050295898339915, -0.26622712950699384`}, {
     6.355896908252572, -0.36894669237902145`}}]}, 
   {Hue[0.5574092808570826], AbsoluteThickness[0.5], 
    LineBox[{{6.355896908252572, -0.36894669237902145`}, {
     6.136359912938414, -0.13283910346098607`}}]}, 
   {Hue[0.31967838052703335`], AbsoluteThickness[0.5], 
    LineBox[{{5.881621584375135, -0.3642545282191471}, {
     5.880576987048086, -0.3728549880629183}}]}, 
   {Hue[0.3207629497649398], AbsoluteThickness[0.5], 
    LineBox[{{5.880576987048086, -0.3728549880629183}, {
     5.875945003217774, -0.5949615059093728}}]}, 
   {Hue[0.6227194152494495], AbsoluteThickness[0.5], 
    LineBox[{{5.722972346301242, -0.4171573811478312}, {
     5.616144718781824, -0.4298069927652411}}]}, 
   {Hue[0.6235966182422905], AbsoluteThickness[0.5], 
    LineBox[{{5.616144718781824, -0.4298069927652411}, {
     5.344039490435745, -0.48591835998499344`}}]}, 
   {Hue[0.5615771928347014], AbsoluteThickness[0.5], 
    LineBox[{{4.569886903469295, -0.2880637755968388}, {
     4.434675356873373, -0.2960539438506471}}]}, 
   {Hue[0.5621282727701337], AbsoluteThickness[0.5], 
    LineBox[{{4.434675356873373, -0.2960539438506471}, {
     4.097481238300387, -0.299737363066368}}]}, 
   {Hue[0.5626354150853746], AbsoluteThickness[0.5], 
    LineBox[{{3.561407551752648, -0.32764244287447597`}, {
     3.41939276060714, -0.30750254841879165`}}]}, 
   {Hue[0.5630614331915978], AbsoluteThickness[0.5], 
    LineBox[{{3.41939276060714, -0.30750254841879165`}, {
     3.105638605352165, -0.26225224344970033`}}]}, 
   {Hue[0.5680808897236359], AbsoluteThickness[0.5], 
    LineBox[{{2.898342925452778, 0.029180812310742987`}, {2.778345549486945, 
     0.06877776224319604}}]}, 
   {Hue[0.5712664160936818], AbsoluteThickness[0.5], 
    LineBox[{{2.778345549486945, 0.06877776224319604}, {2.568411495720702, 
     0.18047726527403585`}}]}, 
   {Hue[0.6731688268395962], AbsoluteThickness[0.5], 
    LineBox[{{2.9841841247841243`, 1.6768638078438518`}, {3.117699378265805, 
     1.8347913607720507`}}]}, 
   {Hue[0.6877991729635896], AbsoluteThickness[0.5], 
    LineBox[{{3.117699378265805, 1.8347913607720507`}, {3.268492560244888, 
     1.9352819592946946`}}]}, 
   {Hue[0.6291550716469164], AbsoluteThickness[0.5], 
    LineBox[{{2.8874035734091468`, 1.10198434706606}, {2.887449872943879, 
     1.1022899036128233`}}]}, 
   {Hue[0.631831232857616], AbsoluteThickness[0.5], 
    LineBox[{{2.887449872943879, 1.1022899036128233`}, {2.8854229835062424`, 
     1.3445766453704884`}}]}, 
   {Hue[0.6031065962008586], AbsoluteThickness[0.5], 
    LineBox[{{2.352983524652996, 1.0253794253453705`}, {2.249696488794336, 
     1.056394346033337}}]}, 
   {Hue[0.6157986414944191], AbsoluteThickness[0.5], 
    LineBox[{{2.249696488794336, 1.056394346033337}, {2.095806171912908, 
     1.1532179287161608`}}]}, 
   {Hue[0.5759268552272646], AbsoluteThickness[0.5], 
    LineBox[{{2.8639326359109543`, -0.5368481393736253}, {
     2.713467245044289, -0.5660440896065622}}]}, 
   {Hue[0.5764951034756369], AbsoluteThickness[0.5], 
    LineBox[{{2.713467245044289, -0.5660440896065622}, {
     2.39844159893543, -0.6106232241671039}}]}, 
   {Hue[0.4884483359460136], AbsoluteThickness[0.5], 
    LineBox[{{3.906321006824047, -1.1323062654716896`}, {
     3.8852554195257696`, -1.1827389718227694`}}]}, 
   {Hue[0.48895628668738084`], AbsoluteThickness[0.5], 
    LineBox[{{3.8852554195257696`, -1.1827389718227694`}, {
     3.777796139669795, -1.4139609534634872`}}]}, 
   {Hue[0.5572783950221386], AbsoluteThickness[0.5], 
    LineBox[{{4.56106779556066, -0.23511651421186464`}, {
     3.967658122058808, -0.8524789571623566}}]}, 
   {Hue[0.560714501151795], AbsoluteThickness[0.5], 
    LineBox[{{3.967658122058808, -0.8524789571623566}, {
     3.849149842548062, -1.0293495579235188`}}]}, 
   {Hue[0.5481191646885799], AbsoluteThickness[0.5], 
    LineBox[{{5.42537494225042, 0.061972026157283644`}, {5.304397687310537, 
     0.11929295955857647`}}]}, 
   {Hue[0.548790323934742], AbsoluteThickness[0.5], 
    LineBox[{{5.304397687310537, 0.11929295955857647`}, {5.052079245964702, 
     0.2597675699394751}}]}, 
   {Hue[0.01089060265921472], AbsoluteThickness[0.5], 
    LineBox[{{5.650799368953584, 0.0905921834868246}, {5.876356930755097, 
     0.1105920866189265}}]}, 
   {Hue[0.011789883183438798`], AbsoluteThickness[0.5], 
    LineBox[{{5.876356930755097, 0.1105920866189265}, {6.172968734051336, 
     0.11094685658488307`}}]}, 
   {Hue[0.4910241185068139], AbsoluteThickness[0.5], 
    LineBox[{{6.172968734051336, 0.11094685658488307`}, {
     6.038493071214998, -0.15342973810742924`}}]}, 
   {Hue[0.5491220139723899], AbsoluteThickness[0.5], 
    LineBox[{{5.470897539825824, -0.04822646596815339}, {
     5.418190620269498, -0.08580323697562137}}]}, 
   {Hue[0.5495514562608557], AbsoluteThickness[0.5], 
    LineBox[{{5.418190620269498, -0.08580323697562137}, {
     5.127664539460259, -0.29669689633058144`}}]}, 
   {Hue[0.5627962425245411], AbsoluteThickness[0.5], 
    LineBox[{{4.450118751470528, 0.15453265875445632`}, {4.415038708784628, 
     0.15011022740439023`}}]}, 
   {Hue[0.5648476373144309], AbsoluteThickness[0.5], 
    LineBox[{{4.415038708784628, 0.15011022740439023`}, {4.17884045828004, 
     0.15390276751304777`}}]}, 
   {Hue[0.49006217180494654`], AbsoluteThickness[0.5], 
    LineBox[{{3.961918265434178, 1.182649410057742}, {3.9346815413347658`, 
     1.234485531893573}}]}, 
   {Hue[0.4910883876027773], AbsoluteThickness[0.5], 
    LineBox[{{3.9346815413347658`, 1.234485531893573}, {3.799354920747861, 
     1.4409970567599784`}}]}, 
   {Hue[0.5510537665844488], AbsoluteThickness[0.5], 
    LineBox[{{3.118905256025041, 0.726560353059262}, {3.04779821112955, 
     0.8165098876755629}}]}, 
   {Hue[0.5517541217756736], AbsoluteThickness[0.5], 
    LineBox[{{3.04779821112955, 0.8165098876755629}, {2.8698612323523696`, 
     1.0765758586714012`}}]}, 
   {Hue[0.5190701641723524], AbsoluteThickness[0.5], 
    LineBox[{{2.3392208896889843`, -1.1321674856164217`}, {
     2.320615047003065, -1.1534423194458296`}}]}, 
   {Hue[0.5195161647232847], AbsoluteThickness[0.5], 
    LineBox[{{2.320615047003065, -1.1534423194458296`}, {
     2.118928434575832, -1.3935297356595264`}}]}, 
   {Hue[0.5170444791699026], AbsoluteThickness[0.5], 
    LineBox[{{3.188392959968137, -0.9436891312701828}, {
     3.115655933499415, -1.0064573367535519`}}]}, 
   {Hue[0.518467674229064], AbsoluteThickness[0.5], 
    LineBox[{{3.115655933499415, -1.0064573367535519`}, {
     2.929004074294489, -1.1325443527887518`}}]}, 
   {Hue[0.5741519654757428], AbsoluteThickness[0.5], 
    LineBox[{{3.8316990547305285`, -0.5342167478353262}, {
     3.8088579683475716`, -0.5803032488379569}}]}, 
   {Hue[0.574662903364073], AbsoluteThickness[0.5], 
    LineBox[{{3.8088579683475716`, -0.5803032488379569}, {
     3.6890129616128897`, -0.8486157778786014}}]}, 
   {Hue[0.6069833508568957], AbsoluteThickness[0.5], 
    LineBox[{{4.671214238066102, 0.1533250819963855}, {4.45897888811776, 
     0.23486896075928332`}}]}, 
   {Hue[0.6074359182548449], AbsoluteThickness[0.5], 
    LineBox[{{4.45897888811776, 0.23486896075928332`}, {4.156346114532212, 
     0.3432818260722784}}]}, 
   {Hue[0.6798835579793323], AbsoluteThickness[0.5], 
    LineBox[{{4.596740882042578, 0.2612701567632114}, {4.581036695530303, 
     0.34236245204477206`}}]}, 
   {Hue[0.6803114043623604], AbsoluteThickness[0.5], 
    LineBox[{{4.581036695530303, 0.34236245204477206`}, {4.527971539218784, 
     0.6072143106863449}}]}, 
   {Hue[0.22638008403269227`], AbsoluteThickness[0.5], 
    LineBox[{{5.172024960391357, 0.09382262051315826}, {
     5.657993430367667, -0.21182939409498394`}}]}, 
   {Hue[0.22680786827273106`], AbsoluteThickness[0.5], 
    LineBox[{{5.657993430367667, -0.21182939409498394`}, {
     5.885949883471024, -0.35723309909215906`}}]}, 
   {Hue[0.031421584782542075`], AbsoluteThickness[0.5], 
    LineBox[{{5.33742565993638, 0.151464732174096}, {5.814332689017396, 
     0.47977919888561227`}}]}, 
   {Hue[0.03189193873703744], AbsoluteThickness[0.5], 
    LineBox[{{5.814332689017396, 0.47977919888561227`}, {6.063272486932564, 
     0.6406139204466312}}]}, 
   {Hue[0.5765902120912334], AbsoluteThickness[0.5], 
    LineBox[{{6.063272486932564, 0.6406139204466312}, {5.900502463026397, 
     0.39293519717141584`}}]}, 
   {Hue[0.25102891749467937`], AbsoluteThickness[0.5], 
    LineBox[{{5.349869868094014, 0.3261792024678993}, {5.325758429858825, 
     0.4473185515895287}}]}, 
   {Hue[0.29207925333228657`], AbsoluteThickness[0.5], 
    LineBox[{{5.325758429858825, 0.4473185515895287}, {5.355565649340609, 
     0.6203018755264587}}]}, 
   {Hue[0.40348824883127166`], AbsoluteThickness[0.5], 
    LineBox[{{5.355565649340609, 0.6203018755264587}, {5.5197294109188535`, 
     0.6824465460782085}}]}, 
   {Hue[0.5148972443302572], AbsoluteThickness[0.5], 
    LineBox[{{5.5197294109188535`, 0.6824465460782085}, {5.656615742674742, 
     0.5725655519440045}}]}, 
   {Hue[0.6263062398292403], AbsoluteThickness[0.5], 
    LineBox[{{5.656615742674742, 0.5725655519440045}, {5.631447752982558, 
     0.3988466036730744}}]}, 
   {Hue[0.47063625020681676`], AbsoluteThickness[0.5], 
    LineBox[{{5.194308683863191, 0.4066821366219967}, {5.118603276280793, 
     0.4228159872561075}}]}, 
   {Hue[0.47170536059483636`], AbsoluteThickness[0.5], 
    LineBox[{{5.118603276280793, 0.4228159872561075}, {4.880551338398568, 
     0.4988150731865516}}]}, 
   {Hue[0.690243582918955], AbsoluteThickness[0.5], 
    LineBox[{{5.058863748367576, 0.29562055957888445`}, {4.980239354207359, 
     0.1846494297748205}}]}, 
   {Hue[0.691140801888059], AbsoluteThickness[0.5], 
    LineBox[{{4.980239354207359, 0.1846494297748205}, {
     4.84299846720296, -0.049940750232974965`}}]}, 
   {Hue[0.5395649550829907], AbsoluteThickness[0.5], 
    LineBox[{{4.608285783322222, -0.34952187283997316`}, {
     4.555038706822461, -0.3907630311883966}}]}, 
   {Hue[0.540337500246656], AbsoluteThickness[0.5], 
    LineBox[{{4.555038706822461, -0.3907630311883966}, {
     4.34700134445252, -0.5789553218145679}}]}, 
   {Hue[0.5625625473940432], AbsoluteThickness[0.5], 
    LineBox[{{3.6367806213443363`, 0.11802196092701508`}, {
     3.3801469301897336`, 0.18425309256150912`}}]}, 
   {Hue[0.5630396012571152], AbsoluteThickness[0.5], 
    LineBox[{{3.3801469301897336`, 0.18425309256150912`}, {
     3.0725684008248644`, 0.2740096849335018}}]}, 
   {Hue[0.5198478095025865], AbsoluteThickness[0.5], 
    LineBox[{{3.1189126181110796`, 0.7282035471707415}, {3.0104078891660384`, 
     0.8150689015521221}}]}, 
   {Hue[0.5224917952582494], AbsoluteThickness[0.5], 
    LineBox[{{3.0104078891660384`, 0.8150689015521221}, {2.847081356518059, 
     0.9947497714701601}}]}, 
   {Hue[0.6035373838434778], AbsoluteThickness[0.5], 
    LineBox[{{3.0716192585720115`, 3.6755469904960334`}, {3.081597470297206, 
     3.6815739833345407`}}]}, 
   {Hue[0.6039637733707303], AbsoluteThickness[0.5], 
    LineBox[{{3.081597470297206, 3.6815739833345407`}, {3.345213415297582, 
     3.842096546976099}}]}, 
   {Hue[0.6359789746926581], AbsoluteThickness[0.5], 
    LineBox[{{3.813303709540879, 2.1475676316072554`}, {3.9825610794742907`, 
     2.130652206180436}}]}, 
   {Hue[0.6415295281022574], AbsoluteThickness[0.5], 
    LineBox[{{3.9825610794742907`, 2.130652206180436}, {4.176427305759655, 
     2.0690125506442825`}}]}, 
   {Hue[0.21880903333887236`], AbsoluteThickness[0.5], 
    LineBox[{{4.858487167708719, 0.8273537714638362}, {4.916602973915236, 
     0.8598470769447775}}]}, 
   {Hue[0.2194845650266156], AbsoluteThickness[0.5], 
    LineBox[{{4.916602973915236, 0.8598470769447775}, {5.1690733120909025`, 
     1.0237648843604898`}}]}, 
   {Hue[0.6917101570410373], AbsoluteThickness[0.5], 
    LineBox[{{3.4041392821881984`, -0.8722971995988552}, {
     3.1725798256426727`, -1.079901024339459}}]}, 
   {Hue[0.696161080244825], AbsoluteThickness[0.5], 
    LineBox[{{3.1725798256426727`, -1.079901024339459}, {
     3.0456609318068164`, -1.2478815607713794`}}]}, 
   {Hue[0.4992051255679934], AbsoluteThickness[0.5], 
    LineBox[{{3.4135500914377803`, -1.0524968311817386`}, {
     3.5060951127479636`, -1.3304990771785374`}}]}, 
   {Hue[0.49967320432473245`], AbsoluteThickness[0.5], 
    LineBox[{{3.5060951127479636`, -1.3304990771785374`}, {
     3.6024832624423326`, -1.6502409005511096`}}]}, 
   {Hue[0.6578045179396665], AbsoluteThickness[0.5], 
    LineBox[{{3.538957731198718, -0.22880409005405572`}, {
     3.478111567120606, -0.17846929615146628`}}]}, 
   {Hue[0.6588950055795253], AbsoluteThickness[0.5], 
    LineBox[{{3.478111567120606, -0.17846929615146628`}, {3.2918436485988076`,
      0.01009084793180725}}]}, 
   {Hue[0.5385348478191879], AbsoluteThickness[0.5], 
    LineBox[{{4.358494859437787, -0.6107486741147179}, {
     4.348276758490083, -0.6411701595239672}}]}, 
   {Hue[0.5389898283089849], AbsoluteThickness[0.5], 
    LineBox[{{4.348276758490083, -0.6411701595239672}, {
     4.244555074199106, -0.9272088835943274}}]}, 
   {Hue[0.10696973434927265`], AbsoluteThickness[0.5], 
    LineBox[{{4.600833452354866, -0.6658299499796387}, {
     4.625227443494833, -0.6684387225817305}}]}, 
   {Hue[0.10742017262311046`], AbsoluteThickness[0.5], 
    LineBox[{{4.625227443494833, -0.6684387225817305}, {
     4.923333318329216, -0.7069458565037545}}]}, 
   {Hue[0.6564928382068367], AbsoluteThickness[0.5], 
    LineBox[{{4.923333318329216, -0.7069458565037545}, {
     4.627881837446199, -0.7622480663844974}}]}, 
   {Hue[0.5413419872940465], AbsoluteThickness[0.5], 
    LineBox[{{4.6023213729189525`, -0.4173149068528038}, {
     4.5927590599142825`, -0.3314971465376052}}]}, 
   {Hue[0.5451338818810124], AbsoluteThickness[0.5], 
    LineBox[{{4.5927590599142825`, -0.3314971465376052}, {
     4.607648526404189, -0.12199100739837174`}}]}, 
   {Hue[0.6585777844494414], AbsoluteThickness[0.5], 
    LineBox[{{3.38927552078789, -0.43969249874601113`}, {
     3.2790029448461997`, -0.4399086236115707}}]}, 
   {Hue[0.4803086009019122], AbsoluteThickness[0.5], 
    LineBox[{{4.358808429733142, 0.8780625970519161}, {4.369944659386892, 
     0.9043023405903808}}]}, 
   {Hue[0.48101547566551894`], AbsoluteThickness[0.5], 
    LineBox[{{4.369944659386892, 0.9043023405903808}, {4.514833667562003, 
     1.1888460390126574`}}]}, 
   {Hue[0.6049578837375974], AbsoluteThickness[0.5], 
    LineBox[{{2.408238468149282, -0.6267284163405217}, {
     2.366253558386984, -0.6252262681055519}}]}, 
   {Hue[0.6056344851972705], AbsoluteThickness[0.5], 
    LineBox[{{2.366253558386984, -0.6252262681055519}, {
     2.0669455851804406`, -0.634328785358245}}]}, 
   {Hue[0.680216683524027], AbsoluteThickness[0.5], 
    LineBox[{{3.608166766539203, -1.353535850804943}, {
     3.679619873608959, -1.3409461221520196`}}]}, 
   {Hue[0.6807045380208022], AbsoluteThickness[0.5], 
    LineBox[{{3.679619873608959, -1.3409461221520198`}, {
     3.9312459353057614`, -1.2876252974689892`}}]}, 
   {Hue[0.273094318041208], AbsoluteThickness[0.5], 
    LineBox[{{3.657724852266612, -1.6026496459086574`}, {
     3.6614950174398464`, -1.6613000935482993`}}]}, 
   {Hue[0.2735627453611099], AbsoluteThickness[0.5], 
    LineBox[{{3.6614950174398464`, -1.6613000935482993`}, {
     3.685972228083325, -1.9241054060328329`}}]}, 
   {Hue[0.6837698513910582], AbsoluteThickness[0.5], 
    LineBox[{{3.404671635664303, -1.6245072839138393`}, {
     3.3734001626310546`, -1.623067206485889}}]}, 
   {Hue[0.6850910273491386], AbsoluteThickness[0.5], 
    LineBox[{{3.3734001626310546`, -1.623067206485889}, {
     3.117575945181301, -1.640233749714779}}]}, 
   {Hue[0.6110783689409662], AbsoluteThickness[0.5], 
    LineBox[{{4.415046585483993, -0.7176293577921055}, {
     4.630590738654077, -0.7693028201492835}}]}, 
   {Hue[0.6119559562356434], AbsoluteThickness[0.5], 
    LineBox[{{4.630590738654077, -0.7693028201492835}, {
     4.888492077164564, -0.8082187171203536}}]}, 
   {Hue[0.4632931762358986], AbsoluteThickness[0.5], 
    LineBox[{{4.10912079822532, -1.4446411213961046`}, {
     4.275935973062567, -1.5539770392409054`}}]}, 
   {Hue[0.4719610205052014], AbsoluteThickness[0.5], 
    LineBox[{{4.275935973062567, -1.5539770392409054`}, {
     4.41806302484586, -1.7065470066360144`}}]}, 
   {Hue[0.43022566705050336`], AbsoluteThickness[0.5], 
    LineBox[{{3.1177500524423447`, -1.8225206149839357`}, {
     3.090099235627775, -1.8748137741319342`}}]}, 
   {Hue[0.4306795297702606], AbsoluteThickness[0.5], 
    LineBox[{{3.090099235627775, -1.8748137741319342`}, {
     2.9579559449828845`, -2.139513212225649}}]}, 
   {Hue[0.25573551421409835`], AbsoluteThickness[0.5], 
    LineBox[{{3.632558011882688, -2.0583933154866663`}, {
     3.6675625860991246`, -2.1586294422286616`}}]}, 
   {Hue[0.25708291420174256`], AbsoluteThickness[0.5], 
    LineBox[{{3.6675625860991246`, -2.1586294422286616`}, {
     3.7594955820012133`, -2.3488083803487703`}}]}, 
   {Hue[0.6955660013966334], AbsoluteThickness[0.5], 
    LineBox[{{3.7594955820012133`, -2.3488083803487703`}, {
     3.922677810625731, -2.214676860931591}}]}, 
   {Hue[0.4613052577952726], AbsoluteThickness[0.5], 
    LineBox[{{4.378475268704884, -1.6162362186082115`}, {
     4.493891831072366, -1.635016642800704}}]}, 
   {Hue[0.5012307591201123], AbsoluteThickness[0.5], 
    LineBox[{{4.493891831072366, -1.635016642800704}, {
     4.640684498725204, -1.6047332476398435`}}]}, 
   {Hue[0.6149302459544501], AbsoluteThickness[0.5], 
    LineBox[{{4.640684498725204, -1.6047332476398435`}, {
     4.688873477396695, -1.4628072329924087`}}]}, 
   {Hue[0.6630430632736601], AbsoluteThickness[0.5], 
    LineBox[{{3.821696238909865, -1.1526604325629248`}, {
     3.8577027091048848`, -1.063850307660305}}]}, 
   {Hue[0.6646383742540617], AbsoluteThickness[0.5], 
    LineBox[{{3.8577027091048848`, -1.063850307660305}, {
     3.9772987022268946`, -0.8502517025034315}}]}, 
   {Hue[0.48369833176493027`], AbsoluteThickness[0.5], 
    LineBox[{{2.559203234888376, -1.6868709258443206`}, {
     2.408264582502991, -1.8151653361856517`}}]}, 
   {Hue[0.5007088543941759], AbsoluteThickness[0.5], 
    LineBox[{{2.408264582502991, -1.8151653361856517`}, {
     2.3155688537700714`, -1.9588219134480227`}}]}, 
   {Hue[0.6899465269222028], AbsoluteThickness[0.5], 
    LineBox[{{2.3155688537700714`, -1.9588219134480227`}, {
     2.40442555072409, -2.104884221120085}}]}, 
   {Hue[0.6575084772785386], AbsoluteThickness[0.5], 
    LineBox[{{2.8730020110747887`, -1.1003668465527434`}, {
     2.8742933769180397`, -1.1079135434678675`}}]}, 
   {Hue[0.658639483890664], AbsoluteThickness[0.5], 
    LineBox[{{2.8742933769180397`, -1.1079135434678675`}, {
     2.890424990927794, -1.3495218622198144`}}]}, 
   {Hue[0.6676619954622982], AbsoluteThickness[0.5], 
    LineBox[{{2.089410817075282, -1.2304323340849581`}, {
     1.9930668204445674`, -1.329628485580383}}]}, 
   {Hue[0.6689255461939801], AbsoluteThickness[0.5], 
    LineBox[{{1.9930668204445674`, -1.329628485580383}, {
     1.8383271638022058`, -1.5287182147375722`}}]}, 
   {Hue[0.3131000591508405], AbsoluteThickness[0.5], 
    LineBox[{{2.935912691191382, -1.651069283213759}, {
     2.9877584806776367`, -1.8801868712306966`}}]}, 
   {Hue[0.3135504538312844], AbsoluteThickness[0.5], 
    LineBox[{{2.9877584806776367`, -1.8801868712306966`}, {
     3.0594783829231895`, -2.167723706190133}}]}, 
   {Hue[0.6797094219543853], AbsoluteThickness[0.5], 
    LineBox[{{3.918951591892472, -1.3390557961691687`}, {
     3.945350051698607, -1.3483597554917697`}}]}, 
   {Hue[0.6823522297643246], AbsoluteThickness[0.5], 
    LineBox[{{3.945350051698607, -1.3483597554917697`}, {
     4.106628239325418, -1.4357922851091753`}}]}, 
   {Hue[0.465535190525485], AbsoluteThickness[0.5], 
    LineBox[{{4.691658144714841, -1.4931085690101118`}, {
     5.100390472608285, -1.6612668235434698`}}]}, 
   {Hue[0.4659641349411161], AbsoluteThickness[0.5], 
    LineBox[{{5.100390472608285, -1.6612668235434698`}, {
     5.415202649119567, -1.7878682216365545`}}]}, 
   {Hue[0.6349748703967569], AbsoluteThickness[0.5], 
    LineBox[{{3.9725118789970666`, 0.7087801534216872}, {4.12293781258284, 
     0.8355655893116718}}]}, 
   {Hue[0.6495905705568231], AbsoluteThickness[0.5], 
    LineBox[{{4.12293781258284, 0.8355655893116718}, {4.285859043544527, 
     0.9081781341026135}}]}, 
   {Hue[0.45990468586219646`], AbsoluteThickness[0.5], 
    LineBox[{{3.327645798186028, 1.5266111617326357`}, {3.343488212244283, 
     1.615542692753511}}]}, 
   {Hue[0.46076600479531843`], AbsoluteThickness[0.5], 
    LineBox[{{3.343488212244283, 1.615542692753511}, {3.370068131493477, 
     1.9033762508974692`}}]}, 
   {Hue[0.5740257093584996], AbsoluteThickness[0.5], 
    LineBox[{{3.420554636972327, 1.624991612196975}, {3.6244915108490656`, 
     1.7081190612293942`}}]}, 
   {Hue[0.574454917128885], AbsoluteThickness[0.5], 
    LineBox[{{3.6244915108490656`, 1.7081190612293942`}, {3.9242728975315964`,
      1.8332146008240688`}}]}, 
   {Hue[0.630980985589155], AbsoluteThickness[0.5], 
    LineBox[{{3.5533476311223793`, 1.5989764999956206`}, {3.7765398764046854`,
      1.4395031294317788`}}]}, 
   {Hue[0.6324526457670435], AbsoluteThickness[0.5], 
    LineBox[{{3.7765398764046854`, 1.4395031294317788`}, {3.946164021575585, 
     1.2844890717897035`}}]}, 
   {Hue[0.6879362618198033], AbsoluteThickness[0.5], 
    LineBox[{{3.6022662895061597`, 1.4728110125590168`}, {3.584748917837993, 
     1.1661120784672403`}}]}, 
   {Hue[0.6884057580925176], AbsoluteThickness[0.5], 
    LineBox[{{3.584748917837993, 1.1661120784672403`}, {3.55829559609031, 
     0.8595563076237973}}]}, 
   {Hue[0.44515572389460495`], AbsoluteThickness[0.5], 
    LineBox[{{5.140339659344384, 0.052205694886659035`}, {5.427853769261302, 
     0.016677685465870045`}}]}, 
   {Hue[0.44570058990202027`], AbsoluteThickness[0.5], 
    LineBox[{{5.427853769261302, 0.01667768546587005}, {
     5.65040251137322, -0.00026439436886650097`}}]}, 
   {Hue[0.49431956750075845`], AbsoluteThickness[0.5], 
    LineBox[{{3.8720681809039266`, -2.322657671991838}, {
     3.882423865490295, -2.351255032773621}}]}, 
   {Hue[0.49480768239890804`], AbsoluteThickness[0.5], 
    LineBox[{{3.882423865490295, -2.351255032773621}, {
     4.0007009067673565`, -2.6457469755984353`}}]}, 
   {Hue[0.5596860051089062], AbsoluteThickness[0.5], 
    LineBox[{{2.9487020877182073`, -1.6574727549187507`}, {
     3.0028239045132943`, -1.8747281371269058`}}]}, 
   {Hue[0.5601136226940789], AbsoluteThickness[0.5], 
    LineBox[{{3.0028239045132943`, -1.8747281371269058`}, {
     3.0770466976978823`, -2.1651213922742842`}}]}, 
   {Hue[0.4540759263579779], AbsoluteThickness[0.5], 
    LineBox[{{2.446499526372531, -3.1152064832394233`}, {
     2.4749792768777676`, -3.3549650811761835`}}]}, 
   {Hue[0.45454532626777655`], AbsoluteThickness[0.5], 
    LineBox[{{2.4749792768777676`, -3.3549650811761835`}, {
     2.5199841757546992`, -3.658441505248175}}]}, 
   {Hue[0.6985252770675602], AbsoluteThickness[0.5], 
    LineBox[{{4.619315111137644, -0.8564596706259909}, {
     4.696042927228392, -0.8435274932869876}}]}, 
   {Hue[0.5584741169578746], AbsoluteThickness[0.5], 
    LineBox[{{2.6193811803709934`, -0.20309558844714137`}, {
     2.4233268542310498`, -0.3162652831867068}}]}, 
   {Hue[0.5597176144826743], AbsoluteThickness[0.5], 
    LineBox[{{2.4233268542310498`, -0.3162652831867068}, {
     2.191158388374107, -0.41840464889941}}]}, 
   {Hue[0.5598190866439294], AbsoluteThickness[0.5], 
    LineBox[{{3.9668532887671657`, -0.6457135222833759}, {
     3.9343561787237142`, -0.6891342168323227}}]}, 
   {Hue[0.5607397173460535], AbsoluteThickness[0.5], 
    LineBox[{{3.9343561787237142`, -0.6891342168323227}, {
     3.7610427009530354`, -0.8822667943443048}}]}, 
   {Hue[0.5599480056118097], AbsoluteThickness[0.5], 
    LineBox[{{4.430309945507265, 0.40759959654872513`}, {4.160902616567299, 
     0.5214946304642419}}]}, 
   {Hue[0.5604259310804055], AbsoluteThickness[0.5], 
    LineBox[{{4.160902616567299, 0.5214946304642419}, {3.860113543550259, 
     0.6375884398370821}}]}, 
   {Hue[0.4752237420259369], AbsoluteThickness[0.5], 
    LineBox[{{5.489704000916934, 0.6846141681359501}, {5.438277004428439, 
     0.8327968258478752}}]}, 
   {Hue[0.47653513939244646`], AbsoluteThickness[0.5], 
    LineBox[{{5.438277004428439, 0.8327968258478752}, {5.38021458278824, 
     1.0906175044387005`}}]}, 
   {Hue[0.513195929567591], AbsoluteThickness[0.5], 
    LineBox[{{6.083630051505965, 0.23602948535822793`}, {6.047717421962875, 
     0.19232895759077506`}}]}, 
   {Hue[0.5139433397993136], AbsoluteThickness[0.5], 
    LineBox[{{6.047717421962875, 0.19232895759077506`}, {
     5.870121868130655, -0.05961255879158245}}]}, 
   {Hue[0.00882045212904362], AbsoluteThickness[0.5], 
    LineBox[{{6.379705168606001, 0.21135111313521757`}, {6.590677442245429, 
     0.20812971951996803`}}]}, 
   {Hue[0.009278796829326462], AbsoluteThickness[0.5], 
    LineBox[{{6.590677442245429, 0.20812971951996803`}, {6.906678759422676, 
     0.211246986456126}}]}, 
   {Hue[0.5565920800487736], AbsoluteThickness[0.5], 
    LineBox[{{6.906678759422676, 0.211246986456126}, {6.609649810813796, 
     0.3191374563745098}}]}, 
   {Hue[0.5145788860947843], AbsoluteThickness[0.5], 
    LineBox[{{6.214542856328803, 0.45831448617791504`}, {5.747350705233158, 
     1.0635890113563573`}}]}, 
   {Hue[0.5157010180626388], AbsoluteThickness[0.5], 
    LineBox[{{5.747350705233158, 1.0635890113563573`}, {5.59299939465222, 
     1.3125030865390837`}}]}, 
   {Hue[0.573583970478989], AbsoluteThickness[0.5], 
    LineBox[{{5.649320955848732, -0.0027396099213580216`}, {
     5.535643275386137, -0.38223664764872534`}}]}, 
   {Hue[0.5740115824341686], AbsoluteThickness[0.5], 
    LineBox[{{5.535643275386137, -0.38223664764872534`}, {
     5.444611446185284, -0.6929959059756299}}]}, 
   {Hue[0.573902965302024], AbsoluteThickness[0.5], 
    LineBox[{{5.555955809801064, -0.07127019937432388}, {
     5.430972150277841, -0.10336759960020481`}}]}, 
   {Hue[0.5744122627154618], AbsoluteThickness[0.5], 
    LineBox[{{5.430972150277841, -0.10336759960020481`}, {
     5.09960666396196, -0.20263652920874714`}}]}, 
   {Hue[0.6712906878906473], AbsoluteThickness[0.5], 
    LineBox[{{5.449065813704587, -0.0266829711383324}, {5.302203442142425, 
     0.11773121631525402`}}]}, 
   {Hue[0.6717425816277862], AbsoluteThickness[0.5], 
    LineBox[{{5.302203442142425, 0.11773121631525402`}, {5.083034158466247, 
     0.34319043854749637`}}]}, 
   {Hue[0.5636215068402094], AbsoluteThickness[0.5], 
    LineBox[{{4.489582650202485, -0.11029224565434309`}, {
     4.405244675359398, -0.12912586696165454`}}]}, 
   {Hue[0.5642346992958858], AbsoluteThickness[0.5], 
    LineBox[{{4.405244675359398, -0.12912586696165454`}, {
     4.088283777122726, -0.21947621618495605`}}]}, 
   {Hue[0.5627162873888301], AbsoluteThickness[0.5], 
    LineBox[{{3.8858884438484855`, 1.0976063891738956`}, {3.866448858815247, 
     1.1604202226962617`}}]}, 
   {Hue[0.5631673553205376], AbsoluteThickness[0.5], 
    LineBox[{{3.866448858815247, 1.1604202226962617`}, {3.773403834189214, 
     1.4390195578662737`}}]}, 
   {Hue[0.5618129469400724], AbsoluteThickness[0.5], 
    LineBox[{{2.309603031135666, 1.4902461794867519`}, {2.182089527668697, 
     1.5798244498716976`}}]}, 
   {Hue[0.5634945189364367], AbsoluteThickness[0.5], 
    LineBox[{{2.182089527668697, 1.5798244498716976`}, {1.9352542784906013`, 
     1.7095132569930545`}}]}, 
   {Hue[0.6007499682480982], AbsoluteThickness[0.5], 
    LineBox[{{2.3224815078507897`, -1.101038790960875}, {
     2.2646451231156, -1.1319958242778214`}}]}, 
   {Hue[0.602822816566202], AbsoluteThickness[0.5], 
    LineBox[{{2.2646451231156, -1.1319958242778214`}, {
     2.0798972234408013`, -1.2677146944102125`}}]}, 
   {Hue[0.5614919378141324], AbsoluteThickness[0.5], 
    LineBox[{{3.1109370133830767`, -0.23707735179789627`}, {
     2.925062481063994, -0.261667744730206}}]}, 
   {Hue[0.5619496417529377], AbsoluteThickness[0.5], 
    LineBox[{{2.925062481063994, -0.261667744730206}, {
     2.6182960162572573`, -0.2945068410030104}}]}, 
   {Hue[0.561622852060386], AbsoluteThickness[0.5], 
    LineBox[{{4.08787877627355, -0.22337916764957746`}, {
     3.879592153017307, -0.24026715799244538`}}]}, 
   {Hue[0.5620522671136592], AbsoluteThickness[0.5], 
    LineBox[{{3.879592153017307, -0.24026715799244538`}, {
     3.5399591889736883`, -0.26489687244185695`}}]}, 
   {Hue[0.5934307314631508], AbsoluteThickness[0.5], 
    LineBox[{{5.853426138252766, 0.04969917077403266}, {5.815687934264919, 
     0.1948381277314646}}]}, 
   {Hue[0.5985240314985573], AbsoluteThickness[0.5], 
    LineBox[{{5.815687934264919, 0.1948381277314646}, {5.751284335995613, 
     0.3259559402273181}}]}, 
   {Hue[0.3218815198709642], AbsoluteThickness[0.5], 
    LineBox[{{6.0055110608117905`, 0.19277953444732226`}, {6.082624388014831, 
     0.23872404989158563`}}]}, 
   {Hue[0.32233495408944157`], AbsoluteThickness[0.5], 
    LineBox[{{6.082624388014831, 0.23872404989158563`}, {6.365860326445304, 
     0.3986955411822051}}]}, 
   {Hue[0.6060869323012855], AbsoluteThickness[0.5], 
    LineBox[{{6.18536227430891, 0.08668827588998901}, {
     6.544083054466651, -0.24784274250400343`}}]}, 
   {Hue[0.6076623835975695], AbsoluteThickness[0.5], 
    LineBox[{{6.544083054466651, -0.24784274250400343`}, {
     6.748148862507564, -0.39541102626146724`}}]}, 
   {Hue[0.5569179180760032], AbsoluteThickness[0.5], 
    LineBox[{{6.050295898339915, -0.26622712950699384`}, {
     5.903762321632245, -0.2972401894334063}}]}, 
   {Hue[0.5573996305592613], AbsoluteThickness[0.5], 
    LineBox[{{5.903762321632245, -0.2972401894334063}, {
     5.644357374999236, -0.3433321752423258}}]}, 
   {Hue[0.017620071366772336`], AbsoluteThickness[0.5], 
    LineBox[{{6.355896908252572, -0.36894669237902145`}, {
     6.4593922062783875`, -0.39970969740432877`}}]}, 
   {Hue[0.018767914025177822`], AbsoluteThickness[0.5], 
    LineBox[{{6.4593922062783875`, -0.39970969740432877`}, {
     6.711100601330648, -0.5039738371437783}}]}, 
   {Hue[0.47339518958642834`], AbsoluteThickness[0.5], 
    LineBox[{{6.711100601330648, -0.5039738371437783}, {
     6.532447146665552, -0.7096703857575524}}]}, 
   {Hue[0.5579006436381603], AbsoluteThickness[0.5], 
    LineBox[{{6.136359912938414, -0.13283910346098607`}, {
     6.1254263737431245`, -0.1218833375120944}}]}, 
   {Hue[0.5583479144206023], AbsoluteThickness[0.5], 
    LineBox[{{6.1254263737431245`, -0.1218833375120944}, {5.887407975189091, 
     0.1265978920130639}}]}, 
   {Hue[0.3218475190028463], AbsoluteThickness[0.5], 
    LineBox[{{5.875945003217774, -0.5949615059093728}, {
     5.877926254118313, -0.6199367657061011}}]}, 
   {Hue[0.32402845100377803`], AbsoluteThickness[0.5], 
    LineBox[{{5.877926254118313, -0.6199367657061011}, {
     5.863548148369162, -0.8366170819102412}}]}, 
   {Hue[0.6244738212351315], AbsoluteThickness[0.5], 
    LineBox[{{5.344039490435745, -0.48591835998499344`}, {
     5.154133060056807, -0.5423532363019634}}]}, 
   {Hue[0.6251031503589797], AbsoluteThickness[0.5], 
    LineBox[{{5.154133060056807, -0.5423532363019634}, {
     4.881744033491794, -0.6057437883419731}}]}, 
   {Hue[0.5626793527055658], AbsoluteThickness[0.5], 
    LineBox[{{4.097481238300387, -0.299737363066368}, {
     3.8723479805416647`, -0.29136336809064733`}}]}, 
   {Hue[0.5631573438634628], AbsoluteThickness[0.5], 
    LineBox[{{3.8723479805416647`, -0.29136336809064733`}, {
     3.5404812991039813`, -0.2684872827588861}}]}, 
   {Hue[0.5634874512978207], AbsoluteThickness[0.5], 
    LineBox[{{3.105638605352165, -0.26225224344970033`}, {
     2.9247497935416993`, -0.23572842542046596`}}]}, 
   {Hue[0.5639591355325653], AbsoluteThickness[0.5], 
    LineBox[{{2.9247497935416993`, -0.23572842542046596`}, {
     2.6203011791254833`, -0.20029352774899306`}}]}, 
   {Hue[0.5744519424637277], AbsoluteThickness[0.5], 
    LineBox[{{2.568411495720702, 0.1804772652740359}, {2.15517864728671, 
     0.5006695403901495}}]}, 
   {Hue[0.577903412451464], AbsoluteThickness[0.5], 
    LineBox[{{2.15517864728671, 0.5006695403901495}, {2.01432323401041, 
     0.5746505030769323}}]}, 
   {Hue[0.6345073940683157], AbsoluteThickness[0.5], 
    LineBox[{{2.8854229835062424`, 1.3445766453704884`}, {2.8813031283245842`,
      1.36899994557733}}]}, 
   {Hue[0.6361084269023524], AbsoluteThickness[0.5], 
    LineBox[{{2.8813031283245842`, 1.36899994557733}, {2.870397008874397, 
     1.6307519888895676`}}]}, 
   {Hue[0.5770633517240092], AbsoluteThickness[0.5], 
    LineBox[{{2.39844159893543, -0.6106232241671039}, {
     2.360035767592123, -0.6140696104020353}}]}, 
   {Hue[0.5776842806200776], AbsoluteThickness[0.5], 
    LineBox[{{2.360035767592123, -0.6140696104020353}, {
     2.058438474557272, -0.6592073737932721}}]}, 
   {Hue[0.48946423742874806`], AbsoluteThickness[0.5], 
    LineBox[{{3.777796139669795, -1.4139609534634872`}, {
     3.6483163546680166`, -1.6660886939191841`}}]}, 
   {Hue[0.4913239554695843], AbsoluteThickness[0.5], 
    LineBox[{{3.6483163546680166`, -1.6660886939191841`}, {
     3.5820683415800003`, -1.8537877721970721`}}]}, 
   {Hue[0.5641506072814512], AbsoluteThickness[0.5], 
    LineBox[{{3.849149842548062, -1.0293495579235188`}, {
     3.7956742754435266`, -1.1507111441762146`}}]}, 
   {Hue[0.5647527014304524], AbsoluteThickness[0.5], 
    LineBox[{{3.7956742754435266`, -1.1507111441762146`}, {
     3.709388235693219, -1.3808876643716252`}}]}, 
   {Hue[0.549461483180904], AbsoluteThickness[0.5], 
    LineBox[{{5.052079245964702, 0.2597675699394751}, {4.681040063767725, 
     0.49943756591530175`}}]}, 
   {Hue[0.5507483679213937], AbsoluteThickness[0.5], 
    LineBox[{{4.681040063767725, 0.49943756591530175`}, {4.489073907865542, 
     0.5950766676842536}}]}, 
   {Hue[0.4901248379825901], AbsoluteThickness[0.5], 
    LineBox[{{5.876356930755097, 0.1105920866189265}, {5.6457475880368175`, 
     0.6785499694128545}}]}, 
   {Hue[0.5073524257812927], AbsoluteThickness[0.5], 
    LineBox[{{5.6457475880368175`, 0.6785499694128545}, {5.631088149896384, 
     0.8385164759481247}}]}, 
   {Hue[0.6954106172187253], AbsoluteThickness[0.5], 
    LineBox[{{5.631088149896384, 0.8385164759481247}, {5.768520103200874, 
     0.9216828186030982}}]}, 
   {Hue[0.01268916370766303], AbsoluteThickness[0.5], 
    LineBox[{{6.172968734051336, 0.11094685658488307`}, {6.351008764662692, 
     0.09558942924380087}}]}, 
   {Hue[0.013189074319495052`], AbsoluteThickness[0.5], 
    LineBox[{{6.351008764662692, 0.09558942924380087}, {6.658755460510132, 
     0.05737962459451889}}]}, 
   {Hue[0.5517261784874734], AbsoluteThickness[0.5], 
    LineBox[{{6.658755460510132, 0.05737962459451889}, {
     6.37343419891526, -0.06411027481388319}}]}, 
   {Hue[0.4919233990310382], AbsoluteThickness[0.5], 
    LineBox[{{6.038493071214998, -0.15342973810742921`}, {
     5.911045130385123, -0.3577156926216511}}]}, 
   {Hue[0.493911828140917], AbsoluteThickness[0.5], 
    LineBox[{{5.911045130385123, -0.3577156926216511}, {
     5.83085128764644, -0.5380957120762455}}]}, 
   {Hue[0.5499808985493215], AbsoluteThickness[0.5], 
    LineBox[{{5.127664539460259, -0.2966968963305815}, {
     5.0334988405531345`, -0.3662880840140268}}]}, 
   {Hue[0.5511753422770967], AbsoluteThickness[0.5], 
    LineBox[{{5.0334988405531345`, -0.3662880840140268}, {
     4.853067619218262, -0.5319858436932144}}]}, 
   {Hue[0.5668990321043207], AbsoluteThickness[0.5], 
    LineBox[{{4.17884045828004, 0.15390276751304777`}, {4.110542179507974, 
     0.16475068770041637`}}]}, 
   {Hue[0.5750362673292685], AbsoluteThickness[0.5], 
    LineBox[{{4.110542179507974, 0.16475068770041637`}, {3.9231244316696787`, 
     0.1500245799578376}}]}, 
   {Hue[0.49211460340060803`], AbsoluteThickness[0.5], 
    LineBox[{{3.799354920747861, 1.4409970567599784`}, {3.2955446640194834`, 
     2.0686348593542383`}}]}, 
   {Hue[0.4930992497264394], AbsoluteThickness[0.5], 
    LineBox[{{3.2955446640194834`, 2.0686348593542383`}, {3.1464122814938253`,
      2.294827687433493}}]}, 
   {Hue[0.5524544769668983], AbsoluteThickness[0.5], 
    LineBox[{{2.8698612323523696`, 1.0765758586714012`}, {2.866086394904157, 
     1.0830015107858038`}}]}, 
   {Hue[0.5528913646023014], AbsoluteThickness[0.5], 
    LineBox[{{2.866086394904157, 1.0830015107858038`}, {2.6850031078020384`, 
     1.3810664311501255`}}]}, 
   {Hue[0.5199621652742168], AbsoluteThickness[0.5], 
    LineBox[{{2.118928434575832, -1.3935297356595264`}, {
     2.118710025917069, -1.3938004803007846`}}]}, 
   {Hue[0.5204399360442525], AbsoluteThickness[0.5], 
    LineBox[{{2.118710025917069, -1.3938004803007846`}, {
     1.9172721961292385`, -1.627974229620578}}]}, 
   {Hue[0.5198908692882256], AbsoluteThickness[0.5], 
    LineBox[{{2.929004074294489, -1.1325443527887518`}, {
     2.9120653435332056`, -1.141282273382352}}]}, 
   {Hue[0.520348052637859], AbsoluteThickness[0.5], 
    LineBox[{{2.9120653435332056`, -1.141282273382352}, {
     2.6551277581314388`, -1.2819615155214237`}}]}, 
   {Hue[0.5751738412524032], AbsoluteThickness[0.5], 
    LineBox[{{3.6890129616128897`, -0.8486157778786014}, {
     3.682931884982731, -0.8638400726062192}}]}, 
   {Hue[0.5760010538135241], AbsoluteThickness[0.5], 
    LineBox[{{3.682931884982731, -0.8638400726062192}, {
     3.5558797961049655`, -1.1194146227351671`}}]}, 
   {Hue[0.6078884856527941], AbsoluteThickness[0.5], 
    LineBox[{{4.156346114532212, 0.34328182607227853`}, {4.033760501022038, 
     0.38406263856498557`}}]}, 
   {Hue[0.6113867262104825], AbsoluteThickness[0.5], 
    LineBox[{{4.033760501022038, 0.38406263856498557`}, {3.8421737822766593`, 
     0.48814242677025454`}}]}, 
   {Hue[0.6807392507453885], AbsoluteThickness[0.5], 
    LineBox[{{4.527971539218784, 0.607214310686345}, {4.480669052804616, 
     0.8356460718586293}}]}, 
   {Hue[0.6812941067645283], AbsoluteThickness[0.5], 
    LineBox[{{4.480669052804616, 0.8356460718586293}, {4.42862881417021, 
     1.1677981280042782`}}]}, 
   {Hue[0.22723565251276961`], AbsoluteThickness[0.5], 
    LineBox[{{5.885949883471024, -0.35723309909215906`}, {
     5.89623007775836, -0.3638826659056231}}]}, 
   {Hue[0.2279636869544646], AbsoluteThickness[0.5], 
    LineBox[{{5.89623007775836, -0.3638826659056231}, {
     6.0888198408907535`, -0.509087346887523}}]}, 
   {Hue[0.5761198581367386], AbsoluteThickness[0.5], 
    LineBox[{{5.814332689017396, 0.47977919888561227`}, {5.662405603354884, 
     0.46014259618992714`}}]}, 
   {Hue[0.576687742279302], AbsoluteThickness[0.5], 
    LineBox[{{5.662405603354884, 0.46014259618992714`}, {5.331036141480083, 
     0.43440371871406613`}}]}, 
   {Hue[0.0323622926915328], AbsoluteThickness[0.5], 
    LineBox[{{6.063272486932564, 0.6406139204466312}, {6.168707870190123, 
     0.7044346993321874}}]}, 
   {Hue[0.03288958338746792], AbsoluteThickness[0.5], 
    LineBox[{{6.168707870190123, 0.7044346993321874}, {6.390696414649381, 
     0.8259269231903855}}]}, 
   {Hue[0.5660367394227256], AbsoluteThickness[0.5], 
    LineBox[{{6.390696414649381, 0.8259269231903855}, {6.2773038381337765`, 
     0.5996938621221518}}]}, 
   {Hue[0.5770605660457288], AbsoluteThickness[0.5], 
    LineBox[{{5.900502463026397, 0.3929351971714158}, {5.80988919427705, 
     0.2634829157633373}}]}, 
   {Hue[0.5778464739967138], AbsoluteThickness[0.5], 
    LineBox[{{5.80988919427705, 0.2634829157633373}, {5.678708830785832, 
     0.10399460194394178`}}]}, 
   {Hue[0.3624379129936652], AbsoluteThickness[0.5], 
    LineBox[{{5.325758429858825, 0.4473185515895287}, {5.239365103076668, 
     0.6052606464441351}}]}, 
   {Hue[0.3631217752774123], AbsoluteThickness[0.5], 
    LineBox[{{5.239365103076668, 0.6052606464441351}, {5.124219868265759, 
     0.8540168356435488}}]}, 
   {Hue[0.33312958916989455`], AbsoluteThickness[0.5], 
    LineBox[{{5.355565649340609, 0.6203018755264587}, {5.474982828420318, 
     0.8205423536782108}}]}, 
   {Hue[0.3336474296414701], AbsoluteThickness[0.5], 
    LineBox[{{5.474982828420318, 0.8205423536782108}, {5.627558265465269, 
     1.1023901501768565`}}]}, 
   {Hue[0.4445385846688792], AbsoluteThickness[0.5], 
    LineBox[{{5.5197294109188535`, 0.6824465460782085}, {5.643342404405741, 
     0.6818004991820871}}]}, 
   {Hue[0.44542075593655417`], AbsoluteThickness[0.5], 
    LineBox[{{5.643342404405741, 0.6818004991820871}, {5.901827376639639, 
     0.7026977449744137}}]}, 
   {Hue[0.5559475801678658], AbsoluteThickness[0.5], 
    LineBox[{{5.656615742674742, 0.5725655519440045}, {5.904986986916398, 
     0.14602038691662506`}}]}, 
   {Hue[0.5564160911907334], AbsoluteThickness[0.5], 
    LineBox[{{5.904986986916398, 0.14602038691662506`}, {
     6.0847646027038245`, -0.1432964755629171}}]}, 
   {Hue[0.6673565756668498], AbsoluteThickness[0.5], 
    LineBox[{{5.631447752982558, 0.3988466036730744}, {5.493604033759469, 
     0.152983516341128}}]}, 
   {Hue[0.669695212490156], AbsoluteThickness[0.5], 
    LineBox[{{5.493604033759469, 0.152983516341128}, {
     5.434727678601125, -0.0029458516034635007`}}]}, 
   {Hue[0.4727744709828559], AbsoluteThickness[0.5], 
    LineBox[{{4.880551338398568, 0.4988150731865516}, {4.735195870659007, 
     0.5616596025354434}}]}, 
   {Hue[0.48299615712069793`], AbsoluteThickness[0.5], 
    LineBox[{{4.735195870659007, 0.5616596025354434}, {4.595710983080952, 
     0.6701799540556097}}]}, 
   {Hue[0.6920380208571629], AbsoluteThickness[0.5], 
    LineBox[{{4.84299846720296, -0.04994075023297498}, {
     4.817103078307372, -0.10462579906548702`}}]}, 
   {Hue[0.6924899685004177], AbsoluteThickness[0.5], 
    LineBox[{{4.817103078307372, -0.10462579906548702`}, {
     4.674250786502676, -0.38948985289584725`}}]}, 
   {Hue[0.5411100454103215], AbsoluteThickness[0.5], 
    LineBox[{{4.34700134445252, -0.5789553218145679}, {
     4.3039757710480675`, -0.6243056652611636}}]}, 
   {Hue[0.541848091622843], AbsoluteThickness[0.5], 
    LineBox[{{4.3039757710480675`, -0.6243056652611636}, {
     4.130175497242424, -0.836534761950043}}]}, 
   {Hue[0.5635166551201871], AbsoluteThickness[0.5], 
    LineBox[{{3.0725684008248644`, 0.2740096849335018}, {2.8857565039580595`, 
     0.33494412575052684`}}]}, 
   {Hue[0.5653674650841511], AbsoluteThickness[0.5], 
    LineBox[{{2.8857565039580595`, 0.33494412575052684`}, {
     2.6276591148379738`, 0.38203807166035864`}}]}, 
   {Hue[0.5251357810139126], AbsoluteThickness[0.5], 
    LineBox[{{2.847081356518059, 0.9947497714701601}, {2.8083444174073224`, 
     1.0539006698836104`}}]}, 
   {Hue[0.5256345464144337], AbsoluteThickness[0.5], 
    LineBox[{{2.8083444174073224`, 1.0539006698836104`}, {2.6333777841405603`,
      1.3440773710913354`}}]}, 
   {Hue[0.6470800815118566], AbsoluteThickness[0.5], 
    LineBox[{{4.176427305759655, 2.0690125506442825`}, {4.376728088314324, 
     1.955369505557155}}]}, 
   {Hue[0.647959849089237], AbsoluteThickness[0.5], 
    LineBox[{{4.376728088314324, 1.955369505557155}, {4.62820524562636, 
     1.839923874231776}}]}, 
   {Hue[0.22016009671435882`], AbsoluteThickness[0.5], 
    LineBox[{{5.1690733120909025`, 1.0237648843604898`}, {5.238447625736557, 
     1.0756212731133092`}}]}, 
   {Hue[0.22273121741321408`], AbsoluteThickness[0.5], 
    LineBox[{{5.238447625736557, 1.0756212731133092`}, {5.399957867021137, 
     1.2412600681482033`}}]}, 
   {Hue[0.5963429803930695], AbsoluteThickness[0.5], 
    LineBox[{{5.399957867021137, 1.2412600681482033`}, {5.239538837030485, 
     1.4079559087599995`}}]}, 
   {Hue[0.5001412830814714], AbsoluteThickness[0.5], 
    LineBox[{{3.6024832624423326`, -1.6502409005511096`}, {
     3.6127572950326963`, -1.6882146506195064`}}]}, 
   {Hue[0.5007527887013861], AbsoluteThickness[0.5], 
    LineBox[{{3.6127572950326963`, -1.6882146506195064`}, {
     3.6916147073175045`, -1.9246129787405968`}}]}, 
   {Hue[0.6599854932193842], AbsoluteThickness[0.5], 
    LineBox[{{3.2918436485988076`, 0.010090847931807256`}, {
     3.2188500771961888`, 0.10055800918180291`}}]}, 
   {Hue[0.6613573754550772], AbsoluteThickness[0.5], 
    LineBox[{{3.2188500771961888`, 0.10055800918180291`}, {
     3.0814552922410883`, 0.31804368693933216`}}]}, 
   {Hue[0.5394448087987818], AbsoluteThickness[0.5], 
    LineBox[{{4.244555074199106, -0.9272088835943274}, {
     4.189598441960406, -1.0681920654257433`}}]}, 
   {Hue[0.5408368682037362], AbsoluteThickness[0.5], 
    LineBox[{{4.189598441960406, -1.0681920654257433`}, {
     4.126122685019454, -1.3114282228787153`}}]}, 
   {Hue[0.6560423999330004], AbsoluteThickness[0.5], 
    LineBox[{{4.625227443494833, -0.6684387225817305}, {
     4.607980625724978, -0.6598102339203807}}]}, 
   {Hue[0.6565918450522559], AbsoluteThickness[0.5], 
    LineBox[{{4.607980625724978, -0.6598102339203807}, {
     4.345038459366062, -0.5121475061791779}}]}, 
   {Hue[0.10787061089694844`], AbsoluteThickness[0.5], 
    LineBox[{{4.923333318329216, -0.7069458565037545}, {
     5.065454829973004, -0.72848129990667}}]}, 
   {Hue[0.10830116984296922`], AbsoluteThickness[0.5], 
    LineBox[{{5.065454829973004, -0.72848129990667}, {
     5.357362093461914, -0.7756270656992569}}]}, 
   {Hue[0.6619379867342362], AbsoluteThickness[0.5], 
    LineBox[{{5.357362093461914, -0.7756270656992569}, {
     5.061729395410321, -0.7698062794560154}}]}, 
   {Hue[0.6569432764806746], AbsoluteThickness[0.5], 
    LineBox[{{4.627881837446199, -0.7622480663844974}, {
     4.424868435919616, -0.7956593350008494}}]}, 
   {Hue[0.6574405030289635], AbsoluteThickness[0.5], 
    LineBox[{{4.424868435919616, -0.7956593350008494}, {
     4.128800288579424, -0.833250016072965}}]}, 
   {Hue[0.5489257764679784], AbsoluteThickness[0.5], 
    LineBox[{{4.607648526404189, -0.12199100739837174`}, {
     4.612453529835503, -0.10339574742235769`}}]}, 
   {Hue[0.5500564884095273], AbsoluteThickness[0.5], 
    LineBox[{{4.612453529835503, -0.10339574742235769`}, {4.6496974352814595`,
      0.14290047671376765`}}]}, 
   {Hue[0.48172235042912565`], AbsoluteThickness[0.5], 
    LineBox[{{4.514833667562003, 1.1888460390126574`}, {4.612291445608525, 
     1.351212030839751}}]}, 
   {Hue[0.4896601608635961], AbsoluteThickness[0.5], 
    LineBox[{{4.612291445608525, 1.351212030839751}, {4.658508659323962, 
     1.4972493899619872`}}]}, 
   {Hue[0.6811923925175776], AbsoluteThickness[0.5], 
    LineBox[{{3.9312459353057614`, -1.2876252974689892`}, {
     4.097244862655516, -1.2464344638438127`}}]}, 
   {Hue[0.6816198514503116], AbsoluteThickness[0.5], 
    LineBox[{{4.097244862655516, -1.2464344638438127`}, {
     4.409837262754884, -1.1707992179284101`}}]}, 
   {Hue[0.2740311726810118], AbsoluteThickness[0.5], 
    LineBox[{{3.685972228083325, -1.9241054060328329`}, {
     3.7086041929232803`, -2.10938699041422}}]}, 
   {Hue[0.2747181575396762], AbsoluteThickness[0.5], 
    LineBox[{{3.7086041929232803`, -2.10938699041422}, {
     3.7541351821824978`, -2.347514892343267}}]}, 
   {Hue[0.6864122033072191], AbsoluteThickness[0.5], 
    LineBox[{{3.117575945181301, -1.640233749714779}, {
     3.1087042772191835`, -1.6418483356213742`}}]}, 
   {Hue[0.6924538198646443], AbsoluteThickness[0.5], 
    LineBox[{{3.1087042772191835`, -1.6418483356213742`}, {
     2.9123954804207255`, -1.6351259247744385`}}]}, 
   {Hue[0.6128335435303205], AbsoluteThickness[0.5], 
    LineBox[{{4.888492077164564, -0.8082187171203536}, {
     5.073268746021479, -0.8201041966715055}}]}, 
   {Hue[0.6134621144642698], AbsoluteThickness[0.5], 
    LineBox[{{5.073268746021479, -0.8201041966715055}, {
     5.345750469609945, -0.8212289355226178}}]}, 
   {Hue[0.4806288647745043], AbsoluteThickness[0.5], 
    LineBox[{{4.41806302484586, -1.7065470066360144`}, {
     4.49911896659892, -1.851679953608143}}]}, 
   {Hue[0.4813120938577114], AbsoluteThickness[0.5], 
    LineBox[{{4.49911896659892, -1.851679953608143}, {
     4.627307438079834, -2.12228259545615}}]}, 
   {Hue[0.431133392490018], AbsoluteThickness[0.5], 
    LineBox[{{2.9579559449828845`, -2.139513212225649}, {
     2.8523206524902855`, -2.364098849167237}}]}, 
   {Hue[0.4411673609320912], AbsoluteThickness[0.5], 
    LineBox[{{2.8523206524902855`, -2.364098849167237}, {
     2.815830903486109, -2.55594132571844}}]}, 
   {Hue[0.6804862872369641], AbsoluteThickness[0.5], 
    LineBox[{{2.815830903486109, -2.55594132571844}, {
     2.9811804319450563`, -2.659838250745559}}]}, 
   {Hue[0.6942186014089894], AbsoluteThickness[0.5], 
    LineBox[{{3.6675625860991246`, -2.1586294422286616`}, {
     3.4291162655354643`, -2.239469627042665}}]}, 
   {Hue[0.6950132934708446], AbsoluteThickness[0.5], 
    LineBox[{{3.4291162655354643`, -2.239469627042665}, {
     3.174684591772575, -2.304015985541804}}]}, 
   {Hue[0.2584303141893867], AbsoluteThickness[0.5], 
    LineBox[{{3.7594955820012133`, -2.3488083803487703`}, {
     3.8195908178875135`, -2.443692796492915}}]}, 
   {Hue[0.2596857523410716], AbsoluteThickness[0.5], 
    LineBox[{{3.8195908178875135`, -2.443692796492915}, {
     3.9822924954212557`, -2.647266869484903}}]}, 
   {Hue[0.6969134013842776], AbsoluteThickness[0.5], 
    LineBox[{{3.922677810625731, -2.214676860931591}, {
     3.9729095272810566`, -2.162718005762304}}]}, 
   {Hue[0.6980372881340375], AbsoluteThickness[0.5], 
    LineBox[{{3.9729095272810566`, -2.162718005762304}, {
     4.108242267291991, -1.9905267220817782`}}]}, 
   {Hue[0.5750047446296116], AbsoluteThickness[0.5], 
    LineBox[{{4.493891831072366, -1.635016642800704}, {
     4.604215129690398, -1.6913113533980142`}}]}, 
   {Hue[0.5755583728020303], AbsoluteThickness[0.5], 
    LineBox[{{4.604215129690398, -1.6913113533980142`}, {
     4.863991183118428, -1.8083411027019698`}}]}, 
   {Hue[0.5411562604449526], AbsoluteThickness[0.5], 
    LineBox[{{4.640684498725204, -1.6047332476398435`}, {
     4.642562500312342, -1.6035342780655648`}}]}, 
   {Hue[0.5580418946957684], AbsoluteThickness[0.5], 
    LineBox[{{4.642562500312342, -1.6035342780655648`}, {
     4.796808953780004, -1.5599280197935799`}}]}, 
   {Hue[0.6548557472792916], AbsoluteThickness[0.5], 
    LineBox[{{4.688873477396695, -1.4628072329924087`}, {
     4.6852798442241586`, -1.3668394027312545`}}]}, 
   {Hue[0.6553108091610513], AbsoluteThickness[0.5], 
    LineBox[{{4.6852798442241586`, -1.3668394027312545`}, {
     4.681087795242165, -1.0580064164404768`}}]}, 
   {Hue[0.6662336852344631], AbsoluteThickness[0.5], 
    LineBox[{{3.9772987022268946`, -0.8502517025034314}, {
     4.298367111153296, -0.41509259950448807`}}]}, 
   {Hue[0.6677722342018179], AbsoluteThickness[0.5], 
    LineBox[{{4.298367111153296, -0.41509259950448807`}, {
     4.432364446435175, -0.1770811752163187}}]}, 
   {Hue[0.6729360042929594], AbsoluteThickness[0.5], 
    LineBox[{{2.408264582502991, -1.8151653361856517`}, {
     2.373023901187726, -1.8212680177925058`}}]}, 
   {Hue[0.6758094004713938], AbsoluteThickness[0.5], 
    LineBox[{{2.373023901187726, -1.8212680177925058`}, {
     2.1701607142796377`, -1.8229015240089685`}}]}, 
   {Hue[0.5177193770234221], AbsoluteThickness[0.5], 
    LineBox[{{2.3155688537700714`, -1.9588219134480227`}, {
     2.284398825798986, -2.0673189792744315`}}]}, 
   {Hue[0.5181931153348855], AbsoluteThickness[0.5], 
    LineBox[{{2.284398825798986, -2.0673189792744315`}, {
     2.2024714748527536`, -2.3889895874343257`}}]}, 
   {Hue[0.6597704905027895], AbsoluteThickness[0.5], 
    LineBox[{{2.890424990927794, -1.3495218622198144`}, {
     2.888334727030539, -1.4073379479149346`}}]}, 
   {Hue[0.6620676978747272], AbsoluteThickness[0.5], 
    LineBox[{{2.888334727030539, -1.4073379479149346`}, {
     2.914275163247531, -1.6366332465281692`}}]}, 
   {Hue[0.31400084851172827`], AbsoluteThickness[0.5], 
    LineBox[{{3.0594783829231895`, -2.167723706190133}, {
     3.12144852818539, -2.394864652958372}}]}, 
   {Hue[0.32821749437008213`], AbsoluteThickness[0.5], 
    LineBox[{{3.12144852818539, -2.394864652958372}, {
     3.119104264678842, -2.5822848304466968`}}]}, 
   {Hue[0.5342760471963801], AbsoluteThickness[0.5], 
    LineBox[{{3.119104264678842, -2.5822848304466968`}, {
     2.9475709771586023`, -2.657837128715128}}]}, 
   {Hue[0.6849950375742639], AbsoluteThickness[0.5], 
    LineBox[{{4.106628239325418, -1.4357922851091753`}, {
     4.256660577538383, -1.550964289170336}}]}, 
   {Hue[0.6883370723184086], AbsoluteThickness[0.5], 
    LineBox[{{4.256660577538383, -1.550964289170336}, {
     4.419765201579433, -1.7286422782580313`}}]}, 
   {Hue[0.46639307935674734`], AbsoluteThickness[0.5], 
    LineBox[{{5.415202649119567, -1.7878682216365545`}, {
     5.443196687537184, -1.7988682802640326`}}]}, 
   {Hue[0.46821682627330913`], AbsoluteThickness[0.5], 
    LineBox[{{5.443196687537184, -1.7988682802640326`}, {
     5.663290294957805, -1.9214822302777352`}}]}, 
   {Hue[0.6642062707168898], AbsoluteThickness[0.5], 
    LineBox[{{4.285859043544527, 0.9081781341026135}, {4.360350720439801, 
     0.9185393423307469}}]}, 
   {Hue[0.6647789080113531], AbsoluteThickness[0.5], 
    LineBox[{{4.360350720439801, 0.9185393423307469}, {4.6882749155741, 
     0.9816098085967916}}]}, 
   {Hue[0.46162732372844045`], AbsoluteThickness[0.5], 
    LineBox[{{3.370068131493477, 1.9033762508974692`}, {3.3715214080586713`, 
     2.0879197101809366`}}]}, 
   {Hue[0.4622981872586132], AbsoluteThickness[0.5], 
    LineBox[{{3.3715214080586713`, 2.0879197101809366`}, {3.3546256980405174`,
      2.3808843500681465`}}]}, 
   {Hue[0.5748841248992703], AbsoluteThickness[0.5], 
    LineBox[{{3.9242728975315964`, 1.8332146008240688`}, {3.9415345333345044`,
      1.8405858683502696`}}]}, 
   {Hue[0.5756008920939817], AbsoluteThickness[0.5], 
    LineBox[{{3.9415345333345044`, 1.8405858683502696`}, {4.205825463110479, 
     1.9762624042413246`}}]}, 
   {Hue[0.633924305944932], AbsoluteThickness[0.5], 
    LineBox[{{3.946164021575585, 1.2844890717897035`}, {4.0194011420108, 
     1.1993426411155585`}}]}, 
   {Hue[0.6347834437727232], AbsoluteThickness[0.5], 
    LineBox[{{4.0194011420108, 1.1993426411155585`}, {4.179197258372445, 
     0.9784740411895227}}]}, 
   {Hue[0.688875254365232], AbsoluteThickness[0.5], 
    LineBox[{{3.55829559609031, 0.8595563076237973}, {3.532307632658917, 
     0.6347756692586674}}]}, 
   {Hue[0.689382568433419], AbsoluteThickness[0.5], 
    LineBox[{{3.532307632658917, 0.6347756692586674}, {3.48715066872307, 
     0.3445153482649548}}]}, 
   {Hue[0.44624545590943576`], AbsoluteThickness[0.5], 
    LineBox[{{5.650402511373219, -0.00026439436886650097`}, {
     5.85282719842263, -0.006139501371709585}}]}, 
   {Hue[0.44669614106470246`], AbsoluteThickness[0.5], 
    LineBox[{{5.85282719842263, -0.006139501371709585}, {
     6.1963346818738945`, -0.008538856457317345}}]}, 
   {Hue[0.4952957972970577], AbsoluteThickness[0.5], 
    LineBox[{{4.0007009067673565`, -2.6457469755984353`}, {
     4.132270317725416, -2.9432460650626786`}}]}, 
   {Hue[0.5039236455281503], AbsoluteThickness[0.5], 
    LineBox[{{4.132270317725416, -2.9432460650626786`}, {
     4.159975472202784, -3.0989407535553397`}}]}, 
   {Hue[0.5605412402792517], AbsoluteThickness[0.5], 
    LineBox[{{3.0770466976978823`, -2.1651213922742842`}, {
     3.1870270496919186`, -2.584746029569485}}]}, 
   {Hue[0.5609689555434454], AbsoluteThickness[0.5], 
    LineBox[{{3.1870270496919186`, -2.584746029569485}, {
     3.2730173394766404`, -2.9046761845102966`}}]}, 
   {Hue[0.4550147261775752], AbsoluteThickness[0.5], 
    LineBox[{{2.5199841757546992`, -3.658441505248175}, {
     2.56009584356527, -3.8837050131582704`}}]}, 
   {Hue[0.4555283530483082], AbsoluteThickness[0.5], 
    LineBox[{{2.56009584356527, -3.8837050131582704`}, {
     2.602437569396929, -4.194131974136274}}]}, 
   {Hue[0.5609611120074741], AbsoluteThickness[0.5], 
    LineBox[{{2.191158388374107, -0.41840464889941}, {
     2.158375088080025, -0.42873978652758626`}}]}, 
   {Hue[0.561407946000959], AbsoluteThickness[0.5], 
    LineBox[{{2.158375088080025, -0.42873978652758626`}, {
     1.8567806597384564`, -0.5171364579243246}}]}, 
   {Hue[0.5616603480481777], AbsoluteThickness[0.5], 
    LineBox[{{3.7610427009530354`, -0.8822667943443048}, {
     3.7088529947186935`, -0.930940766957243}}]}, 
   {Hue[0.5624888717416499], AbsoluteThickness[0.5], 
    LineBox[{{3.7088529947186935`, -0.930940766957243}, {
     3.4850570713722866`, -1.1079220474040337`}}]}, 
   {Hue[0.5609038565490013], AbsoluteThickness[0.5], 
    LineBox[{{3.860113543550259, 0.6375884398370821}, {3.8289701024699894`, 
     0.6484903469257306}}]}, 
   {Hue[0.5621328649048054], AbsoluteThickness[0.5], 
    LineBox[{{3.8289701024699894`, 0.6484903469257306}, {3.601868804990173, 
     0.7567996658167186}}]}, 
   {Hue[0.47784653675895594`], AbsoluteThickness[0.5], 
    LineBox[{{5.38021458278824, 1.0906175044387005`}, {5.373515997875146, 
     1.151844174817426}}]}, 
   {Hue[0.4798136415538631], AbsoluteThickness[0.5], 
    LineBox[{{5.373515997875146, 1.151844174817426}, {5.313934695919415, 
     1.3874193316373804`}}]}, 
   {Hue[0.5146907500310363], AbsoluteThickness[0.5], 
    LineBox[{{5.870121868130655, -0.05961255879158245}, {
     5.809484420426245, -0.16073952838595962`}}]}, 
   {Hue[0.5151596584077912], AbsoluteThickness[0.5], 
    LineBox[{{5.809484420426245, -0.16073952838595962`}, {
     5.679808093140753, -0.3918620507205312}}]}, 
   {Hue[0.55613373534849], AbsoluteThickness[0.5], 
    LineBox[{{6.590677442245429, 0.20812971951996806`}, {6.544912726505813, 
     0.18914245229177507`}}]}, 
   {Hue[0.5581178882598273], AbsoluteThickness[0.5], 
    LineBox[{{6.544912726505813, 0.18914245229177507`}, {6.3430457979828425`, 
     0.07016369287567986}}]}, 
   {Hue[0.00973714152960915], AbsoluteThickness[0.5], 
    LineBox[{{6.906678759422676, 0.211246986456126}, {7.087986891189276, 
     0.21759480145191668`}}]}, 
   {Hue[0.01017596491178122], AbsoluteThickness[0.5], 
    LineBox[{{7.087986891189276, 0.21759480145191668`}, {7.319376887406318, 
     0.22198867453246562`}}]}, 
   {Hue[0.5618901904933108], AbsoluteThickness[0.5], 
    LineBox[{{7.319376887406318, 0.22198867453246562`}, {7.095082754191072, 
     0.16495554139748614`}}]}, 
   {Hue[0.5570504247490563], AbsoluteThickness[0.5], 
    LineBox[{{6.609649810813796, 0.3191374563745098}, {6.363432845356262, 
     0.401628812733406}}]}, 
   {Hue[0.5605304330661204], AbsoluteThickness[0.5], 
    LineBox[{{6.363432845356262, 0.401628812733406}, {6.148122205885629, 
     0.4335401879191241}}]}, 
   {Hue[0.5168231500304932], AbsoluteThickness[0.5], 
    LineBox[{{5.59299939465222, 1.3125030865390837`}, {5.541707581442242, 
     1.417934870409982}}]}, 
   {Hue[0.5175039023307373], AbsoluteThickness[0.5], 
    LineBox[{{5.541707581442242, 1.417934870409982}, {5.4587923720161955`, 
     1.6218890784596587`}}]}, 
   {Hue[0.5744391943893483], AbsoluteThickness[0.5], 
    LineBox[{{5.444611446185284, -0.6929959059756299}, {
     5.381042662723705, -0.914998549432168}}]}, 
   {Hue[0.578625911490068], AbsoluteThickness[0.5], 
    LineBox[{{5.381042662723705, -0.914998549432168}, {
     5.362678335162021, -1.1179709096707855`}}]}, 
   {Hue[0.5749215601288996], AbsoluteThickness[0.5], 
    LineBox[{{5.09960666396196, -0.20263652920874714`}, {
     4.878023154734634, -0.2787211096237342}}]}, 
   {Hue[0.5757497740542795], AbsoluteThickness[0.5], 
    LineBox[{{4.878023154734634, -0.2787211096237342}, {
     4.606621202127479, -0.34783073187943775`}}]}, 
   {Hue[0.672194475364925], AbsoluteThickness[0.5], 
    LineBox[{{5.083034158466247, 0.3431904385474963}, {5.038028273181621, 
     0.391626815161942}}]}, 
   {Hue[0.6731677485670073], AbsoluteThickness[0.5], 
    LineBox[{{5.038028273181621, 0.391626815161942}, {4.8826669138680225`, 
     0.5934691598521935}}]}, 
   {Hue[0.5648478917515621], AbsoluteThickness[0.5], 
    LineBox[{{4.088283777122726, -0.21947621618495605`}, {
     3.8711310970836608`, -0.2952343364726256}}]}, 
   {Hue[0.5657823526356057], AbsoluteThickness[0.5], 
    LineBox[{{3.8711310970836608`, -0.2952343364726256}, {
     3.5911545444452124`, -0.3654615380331688}}]}, 
   {Hue[0.5636184232522452], AbsoluteThickness[0.5], 
    LineBox[{{3.773403834189214, 1.4390195578662737`}, {3.704533382763098, 
     1.630947344766586}}]}, 
   {Hue[0.5648927274834338], AbsoluteThickness[0.5], 
    LineBox[{{3.704533382763098, 1.630947344766586}, {3.6446062161021278`, 
     1.8825090394868036`}}]}, 
   {Hue[0.6048956648843057], AbsoluteThickness[0.5], 
    LineBox[{{2.0798972234408013`, -1.2677146944102125`}, {
     2.014980163411804, -1.331386669884642}}]}, 
   {Hue[0.605814779384515], AbsoluteThickness[0.5], 
    LineBox[{{2.014980163411804, -1.331386669884642}, {
     1.8404418216938554`, -1.5359674409462236`}}]}, 
   {Hue[0.562407345691743], AbsoluteThickness[0.5], 
    LineBox[{{2.6182960162572573`, -0.2945068410030104}, {
     2.424596975120967, -0.31037793814297476`}}]}, 
   {Hue[0.5628943899029648], AbsoluteThickness[0.5], 
    LineBox[{{2.424596975120967, -0.31037793814297476`}, {
     2.1165059804624176`, -0.32504229334610085`}}]}, 
   {Hue[0.5624816821669324], AbsoluteThickness[0.5], 
    LineBox[{{3.5399591889736883`, -0.26489687244185695`}, {
     3.4211267697531293`, -0.27249825840653596`}}]}, 
   {Hue[0.5629074234848128], AbsoluteThickness[0.5], 
    LineBox[{{3.4211267697531293`, -0.27249825840653596`}, {
     3.1047214691705607`, -0.2926370896595295}}]}, 
   {Hue[0.6036173315339636], AbsoluteThickness[0.5], 
    LineBox[{{5.751284335995613, 0.3259559402273181}, {5.657984108686636, 
     0.446478655518895}}]}, 
   {Hue[0.6043693381882519], AbsoluteThickness[0.5], 
    LineBox[{{5.657984108686636, 0.446478655518895}, {5.448436678281294, 
     0.6791752295443908}}]}, 
   {Hue[0.32278838830791895`], AbsoluteThickness[0.5], 
    LineBox[{{6.365860326445304, 0.3986955411822051}, {6.399462197280588, 
     0.41665895727280067`}}]}, 
   {Hue[0.3234766683044144], AbsoluteThickness[0.5], 
    LineBox[{{6.399462197280588, 0.41665895727280067`}, {6.6022014788616845`, 
     0.543333230433746}}]}, 
   {Hue[0.6092378348938534], AbsoluteThickness[0.5], 
    LineBox[{{6.748148862507564, -0.39541102626146724`}, {
     6.7957216000277745`, -0.42150261657790944`}}]}, 
   {Hue[0.6097468354894122], AbsoluteThickness[0.5], 
    LineBox[{{6.7957216000277745`, -0.4215026165779094}, {
     7.079945371131511, -0.5630432144626165}}]}, 
   {Hue[0.5578813430425194], AbsoluteThickness[0.5], 
    LineBox[{{5.644357374999236, -0.34333217524232584`}, {
     5.121607110774971, -0.41866835468593677`}}]}, 
   {Hue[0.5586167020731465], AbsoluteThickness[0.5], 
    LineBox[{{5.121607110774971, -0.41866835468593677`}, {
     4.857273294312428, -0.47660715974112944`}}]}, 
   {Hue[0.4722473469280214], AbsoluteThickness[0.5], 
    LineBox[{{6.4593922062783875`, -0.39970969740432877`}, {
     6.507636113101844, -0.12533369549193635`}}]}, 
   {Hue[0.4727123575436713], AbsoluteThickness[0.5], 
    LineBox[{{6.507636113101844, -0.12533369549193635`}, {6.553628810836328, 
     0.18631471371293812`}}]}, 
   {Hue[0.019915756683583308`], AbsoluteThickness[0.5], 
    LineBox[{{6.711100601330648, -0.5039738371437783}, {
     6.8597589669056225`, -0.5845111883421094}}]}, 
   {Hue[0.06522959559331039], AbsoluteThickness[0.5], 
    LineBox[{{6.8597589669056225`, -0.5845111883421094}, {
     7.0215085740187915`, -0.6041830145675023}}]}, 
   {Hue[0.1686058237797156], AbsoluteThickness[0.5], 
    LineBox[{{7.0215085740187915`, -0.6041830145675025}, {
     7.121331801914947, -0.47539932258478895`}}]}, 
   {Hue[0.27198205196612163`], AbsoluteThickness[0.5], 
    LineBox[{{7.121331801914947, -0.47539932258478895`}, {
     7.061947064780103, -0.3236647874791256}}]}, 
   {Hue[0.37535828015252853`], AbsoluteThickness[0.5], 
    LineBox[{{7.061947064780103, -0.3236647874791255}, {
     6.901227079449604, -0.2968505661838745}}]}, 
   {Hue[0.478734508338936], AbsoluteThickness[0.5], 
    LineBox[{{6.901227079449604, -0.2968505661838745}, {
     6.795799670673987, -0.42108815158847496`}}]}, 
   {Hue[0.5821107365253456], AbsoluteThickness[0.5], 
    LineBox[{{6.795799670673987, -0.42108815158847496`}, {
     6.848407914690187, -0.5753032248136253}}]}, 
   {Hue[0.6854869647117557], AbsoluteThickness[0.5], 
    LineBox[{{6.848407914690187, -0.5753032248136253}, {
     7.007783048579525, -0.6092072488529924}}]}, 
   {Hue[0.4745430322448338], AbsoluteThickness[0.5], 
    LineBox[{{6.532447146665552, -0.7096703857575524}, {
     6.161143711772242, -1.0568652845849815`}}]}, 
   {Hue[0.48484725629506287`], AbsoluteThickness[0.5], 
    LineBox[{{6.161143711772242, -1.0568652845849815`}, {
     6.0105014419181435`, -1.1387971523378122`}}]}, 
   {Hue[0.5587951852030444], AbsoluteThickness[0.5], 
    LineBox[{{5.887407975189091, 0.12659789201306393`}, {5.8171533208345965`, 
     0.2030150123576955}}]}, 
   {Hue[0.5598142406050841], AbsoluteThickness[0.5], 
    LineBox[{{5.8171533208345965`, 0.2030150123576955}, {5.67150071752314, 
     0.3337724871545907}}]}, 
   {Hue[0.3262093830047097], AbsoluteThickness[0.5], 
    LineBox[{{5.863548148369162, -0.8366170819102412}, {
     5.816846533643727, -1.0539344144347782`}}]}, 
   {Hue[0.3266536441395736], AbsoluteThickness[0.5], 
    LineBox[{{5.816846533643727, -1.0539344144347782`}, {
     5.744708750988866, -1.36105880486681}}]}, 
   {Hue[0.6257324794828281], AbsoluteThickness[0.5], 
    LineBox[{{4.881744033491794, -0.6057437883419731}, {
     4.88099641562392, -0.6058709227361528}}]}, 
   {Hue[0.6265501181544454], AbsoluteThickness[0.5], 
    LineBox[{{4.88099641562392, -0.6058709227361528}, {
     4.624479354899302, -0.6710780395384429}}]}, 
   {Hue[0.5636353350213598], AbsoluteThickness[0.5], 
    LineBox[{{3.5404812991039813`, -0.2684872827588861}, {
     3.419288323495405, -0.2562702823495849}}]}, 
   {Hue[0.5641174792466075], AbsoluteThickness[0.5], 
    LineBox[{{3.419288323495405, -0.2562702823495849}, {
     3.1114390916148045`, -0.23541988300681682`}}]}, 
   {Hue[0.5644308197673097], AbsoluteThickness[0.5], 
    LineBox[{{2.6203011791254833`, -0.20029352774899306`}, {
     2.3927747979010747`, -0.18064460415434458`}}]}, 
   {Hue[0.5656964433169215], AbsoluteThickness[0.5], 
    LineBox[{{2.3927747979010747`, -0.18064460415434458`}, {
     2.1400932147905727`, -0.18672780883631174`}}]}, 
   {Hue[0.6377094597363893], AbsoluteThickness[0.5], 
    LineBox[{{2.870397008874397, 1.6307519888895676`}, {2.8724302395960923`, 
     1.6549497281318695`}}]}, 
   {Hue[0.63898283688982], AbsoluteThickness[0.5], 
    LineBox[{{2.8724302395960923`, 1.6549497281318695`}, {2.8658227818164175`,
      1.9015669098053969`}}]}, 
   {Hue[0.49318367351042053`], AbsoluteThickness[0.5], 
    LineBox[{{3.5820683415800003`, -1.8537877721970721`}, {
     3.579135963428278, -1.8679500883750972`}}]}, 
   {Hue[0.4936677927186507], AbsoluteThickness[0.5], 
    LineBox[{{3.579135963428278, -1.8679500883750972`}, {
     3.5174645163758904`, -2.1226483777070975`}}]}, 
   {Hue[0.5653547955794537], AbsoluteThickness[0.5], 
    LineBox[{{3.709388235693219, -1.3808876643716252`}, {
     3.6860012761239473`, -1.4558860443863368`}}]}, 
   {Hue[0.5685155667661295], AbsoluteThickness[0.5], 
    LineBox[{{3.6860012761239473`, -1.4558860443863368`}, {
     3.581996321967224, -1.6596235775315171`}}]}, 
   {Hue[0.5520352526618836], AbsoluteThickness[0.5], 
    LineBox[{{4.489073907865542, 0.5950766676842536}, {4.383574054910636, 
     0.6336957855760125}}]}, 
   {Hue[0.5525906390260515], AbsoluteThickness[0.5], 
    LineBox[{{4.383574054910636, 0.6336957855760125}, {4.096071977898986, 
     0.7551747960106177}}]}, 
   {Hue[0.6781830294200187], AbsoluteThickness[0.5], 
    LineBox[{{5.6457475880368175`, 0.6785499694128545}, {5.453227416526891, 
     0.8266542044246511}}]}, 
   {Hue[0.6905359869292301], AbsoluteThickness[0.5], 
    LineBox[{{5.453227416526891, 0.8266542044246511}, {5.34236063677792, 
     0.9733113153617713}}]}, 
   {Hue[0.5245800135799946], AbsoluteThickness[0.5], 
    LineBox[{{5.631088149896384, 0.8385164759481247}, {5.63949186800222, 
     0.8793593747739528}}]}, 
   {Hue[0.5294703907017849], AbsoluteThickness[0.5], 
    LineBox[{{5.63949186800222, 0.8793593747739528}, {5.6402367800379976`, 
     1.08815690498474}}]}, 
   {Hue[0.5512262678756418], AbsoluteThickness[0.5], 
    LineBox[{{6.351008764662692, 0.09558942924380087}, {6.2959224466860615`, 
     0.14078496816846517`}}]}, 
   {Hue[0.5519249408997847], AbsoluteThickness[0.5], 
    LineBox[{{6.2959224466860615`, 0.14078496816846517`}, {6.080184529658962, 
     0.34411165867974286`}}]}, 
   {Hue[0.013688984931327074`], AbsoluteThickness[0.5], 
    LineBox[{{6.658755460510132, 0.05737962459451889}, {6.924415968292159, 
     0.014232069097353403`}}]}, 
   {Hue[0.014271659870905373`], AbsoluteThickness[0.5], 
    LineBox[{{6.924415968292159, 0.014232069097353403`}, {
     7.140810999442389, -0.009139763499933944}}]}, 
   {Hue[0.5373250791436736], AbsoluteThickness[0.5], 
    LineBox[{{7.140810999442389, -0.009139763499933944}, {6.995028133708599, 
     0.15247832992994254`}}]}, 
   {Hue[0.5522260890993054], AbsoluteThickness[0.5], 
    LineBox[{{6.37343419891526, -0.06411027481388323}, {
     6.241753510492888, -0.1144383188094662}}]}, 
   {Hue[0.5561413159252785], AbsoluteThickness[0.5], 
    LineBox[{{6.241753510492888, -0.1144383188094662}, {
     6.0581550421641595`, -0.2267892024788038}}]}, 
   {Hue[0.4959002572507959], AbsoluteThickness[0.5], 
    LineBox[{{5.83085128764644, -0.5380957120762455}, {
     5.818958602315082, -0.5796267956796102}}]}, 
   {Hue[0.4963311521092982], AbsoluteThickness[0.5], 
    LineBox[{{5.818958602315082, -0.5796267956796102}, {
     5.732869587020897, -0.8692068730169819}}]}, 
   {Hue[0.552369786004872], AbsoluteThickness[0.5], 
    LineBox[{{4.853067619218262, -0.5319858436932144}, {
     4.821656929000865, -0.5676892235960838}}]}, 
   {Hue[0.5529239379629618], AbsoluteThickness[0.5], 
    LineBox[{{4.821656929000865, -0.5676892235960838}, {
     4.64254879794832, -0.7924339567347299}}]}, 
   {Hue[0.5831735025542163], AbsoluteThickness[0.5], 
    LineBox[{{3.9231244316696787`, 0.1500245799578376}, {3.9111712151653513`, 
     0.1461383431619765}}]}, 
   {Hue[0.5844632205919951], AbsoluteThickness[0.5], 
    LineBox[{{3.9111712151653513`, 0.1461383431619765}, {3.659211858918392, 
     0.0943043927186046}}]}, 
   {Hue[0.4940838960522709], AbsoluteThickness[0.5], 
    LineBox[{{3.1464122814938253`, 2.294827687433493}, {3.1231197742293375`, 
     2.338559669418198}}]}, 
   {Hue[0.4945109869728687], AbsoluteThickness[0.5], 
    LineBox[{{3.1231197742293375`, 2.338559669418198}, {2.945014995196864, 
     2.668828096426528}}]}, 
   {Hue[0.5533282522377043], AbsoluteThickness[0.5], 
    LineBox[{{2.6850031078020384`, 1.3810664311501255`}, {2.6469826206758427`,
      1.4416125148005607`}}]}, 
   {Hue[0.5545299750425315], AbsoluteThickness[0.5], 
    LineBox[{{2.6469826206758427`, 1.4416125148005607`}, {2.476023371459086, 
     1.6584951030482828`}}]}, 
   {Hue[0.5208052359874925], AbsoluteThickness[0.5], 
    LineBox[{{2.6551277581314388`, -1.2819615155214237`}, {
     2.5217957333967527`, -1.3593020382410783`}}]}, 
   {Hue[0.5220658502578562], AbsoluteThickness[0.5], 
    LineBox[{{2.5217957333967527`, -1.3593020382410783`}, {
     2.3312063484307086`, -1.4999002297019763`}}]}, 
   {Hue[0.5768282663746449], AbsoluteThickness[0.5], 
    LineBox[{{3.5558797961049655`, -1.1194146227351671`}, {
     3.3954907836808794`, -1.38537089418688}}]}, 
   {Hue[0.6052029276144328], AbsoluteThickness[0.5], 
    LineBox[{{3.3954907836808794`, -1.38537089418688}, {
     3.3599145706950297`, -1.5548617201969486`}}]}, 
   {Hue[0.6148849667681708], AbsoluteThickness[0.5], 
    LineBox[{{3.8421737822766593`, 0.48814242677025454`}, {
     3.1972439079964463`, 1.0034503164989559`}}]}, 
   {Hue[0.6161127241487192], AbsoluteThickness[0.5], 
    LineBox[{{3.1972439079964463`, 1.0034503164989559`}, {2.9602221674844222`,
      1.1540114668579144`}}]}, 
   {Hue[0.6818489627836679], AbsoluteThickness[0.5], 
    LineBox[{{4.42862881417021, 1.1677981280042782`}, {4.380866014363352, 
     1.6140040533972866`}}]}, 
   {Hue[0.6825180282577167], AbsoluteThickness[0.5], 
    LineBox[{{4.380866014363352, 1.6140040533972866`}, {4.329214207984857, 
     1.9115102076511834`}}]}, 
   {Hue[0.22869172139615965`], AbsoluteThickness[0.5], 
    LineBox[{{6.0888198408907535`, -0.509087346887523}, {
     6.211677744429976, -0.6163894575373122}}]}, 
   {Hue[0.22971289783126253`], AbsoluteThickness[0.5], 
    LineBox[{{6.211677744429976, -0.6163894575373122}, {
     6.385813343037616, -0.8007384408652852}}]}, 
   {Hue[0.6961263189636883], AbsoluteThickness[0.5], 
    LineBox[{{6.385813343037616, -0.8007384408652852}, {
     6.149057944270961, -0.8915934655548454}}]}, 
   {Hue[0.5772556264218653], AbsoluteThickness[0.5], 
    LineBox[{{5.331036141480083, 0.43440371871406613`}, {5.126063788159133, 
     0.42897075092588544`}}]}, 
   {Hue[0.5791197338845557], AbsoluteThickness[0.5], 
    LineBox[{{5.126063788159133, 0.42897075092588544`}, {4.903282921475007, 
     0.45330115643859137`}}]}, 
   {Hue[0.5655094487267908], AbsoluteThickness[0.5], 
    LineBox[{{6.168707870190123, 0.7044346993321874}, {5.91512515863538, 
     0.742294218086224}}]}, 
   {Hue[0.5659362377394328], AbsoluteThickness[0.5], 
    LineBox[{{5.91512515863538, 0.742294218086224}, {5.615916617633362, 
     0.7883604035597219}}]}, 
   {Hue[0.03341687408340305], AbsoluteThickness[0.5], 
    LineBox[{{6.390696414649381, 0.8259269231903855}, {6.457251081365736, 
     0.8586702875957664}}]}, 
   {Hue[0.03753094135692544], AbsoluteThickness[0.5], 
    LineBox[{{6.457251081365736, 0.8586702875957664}, {6.633311975540082, 
     0.9910358286032771}}]}, 
   {Hue[0.36427385604900614`], AbsoluteThickness[0.5], 
    LineBox[{{6.633311975540082, 0.9910358286032771}, {6.534017491234703, 
     1.187653936340612}}]}, 
   {Hue[0.6910167707410869], AbsoluteThickness[0.5], 
    LineBox[{{6.534017491234703, 1.187653936340612}, {6.322986907177667, 
     1.1245336741720537`}}]}, 
   {Hue[0.5665640301186606], AbsoluteThickness[0.5], 
    LineBox[{{6.2773038381337765`, 0.5996938621221518}, {6.196573871352, 
     0.45474777908979636`}}]}, 
   {Hue[0.5678256049939043], AbsoluteThickness[0.5], 
    LineBox[{{6.196573871352, 0.45474777908979636`}, {6.0947501980414245`, 
     0.21267797780915598`}}]}, 
   {Hue[0.5786323819476988], AbsoluteThickness[0.5], 
    LineBox[{{5.678708830785832, 0.10399460194394178`}, {5.654840793626469, 
     0.07917825046820735}}]}, 
   {Hue[0.579322569008483], AbsoluteThickness[0.5], 
    LineBox[{{5.654840793626469, 0.07917825046820735}, {
     5.497715611292318, -0.06346646839174999}}]}, 
   {Hue[0.3638056375611593], AbsoluteThickness[0.5], 
    LineBox[{{5.124219868265759, 0.8540168356435488}, {5.115317248191118, 
     0.8772102403515882}}]}, 
   {Hue[0.36434512869858177`], AbsoluteThickness[0.5], 
    LineBox[{{5.115317248191118, 0.8772102403515882}, {4.988715817088353, 
     1.1665499100954557`}}]}, 
   {Hue[0.3341652701130456], AbsoluteThickness[0.5], 
    LineBox[{{5.627558265465269, 1.1023901501768565`}, {5.633306830446589, 
     1.1141522888800592`}}]}, 
   {Hue[0.33467459716231185`], AbsoluteThickness[0.5], 
    LineBox[{{5.633306830446589, 1.1141522888800592`}, {5.797235705250813, 
     1.4183387294107068`}}]}, 
   {Hue[0.4463029272042291], AbsoluteThickness[0.5], 
    LineBox[{{5.901827376639639, 0.7026977449744137}, {6.167184646375237, 
     0.747310495996958}}]}, 
   {Hue[0.44679915897993844`], AbsoluteThickness[0.5], 
    LineBox[{{6.167184646375237, 0.747310495996958}, {6.421426550193103, 
     0.7805466356618064}}]}, 
   {Hue[0.556884602213601], AbsoluteThickness[0.5], 
    LineBox[{{6.0847646027038245`, -0.14329647556291714`}, {
     6.0973722618515245`, -0.1623439309763534}}]}, 
   {Hue[0.5573451053018973], AbsoluteThickness[0.5], 
    LineBox[{{6.0973722618515245`, -0.1623439309763534}, {
     6.284860161404516, -0.43023501789939184`}}]}, 
   {Hue[0.6720338493134621], AbsoluteThickness[0.5], 
    LineBox[{{5.434727678601125, -0.0029458516034635007`}, {
     5.417222820382125, -0.084639451768628}}]}, 
   {Hue[0.672991634437459], AbsoluteThickness[0.5], 
    LineBox[{{5.417222820382125, -0.084639451768628}, {
     5.326968466468267, -0.3736555013707233}}]}, 
   {Hue[0.4932178432585397], AbsoluteThickness[0.5], 
    LineBox[{{4.595710983080952, 0.6701799540556097}, {4.465564992671714, 
     0.8390872479939172}}]}, 
   {Hue[0.4954615472166034], AbsoluteThickness[0.5], 
    LineBox[{{4.465564992671714, 0.8390872479939172}, {4.341750870855744, 
     1.060831492884444}}]}, 
   {Hue[0.6929419161436724], AbsoluteThickness[0.5], 
    LineBox[{{4.674250786502676, -0.38948985289584725`}, {
     4.637897558259059, -0.4580739133566057}}]}, 
   {Hue[0.6936603580508525], AbsoluteThickness[0.5], 
    LineBox[{{4.637897558259059, -0.4580739133566057}, {
     4.487015805575227, -0.699662499662393}}]}, 
   {Hue[0.5425861378353646], AbsoluteThickness[0.5], 
    LineBox[{{4.130175497242424, -0.836534761950043}, {
     4.101812842604181, -0.8768356392889218}}]}, 
   {Hue[0.5430118845168245], AbsoluteThickness[0.5], 
    LineBox[{{4.101812842604181, -0.8768356392889218}, {
     3.9164323230041678`, -1.139991194594669}}]}, 
   {Hue[0.5672182750481151], AbsoluteThickness[0.5], 
    LineBox[{{2.6276591148379738`, 0.38203807166035864`}, {
     2.5408578051680704`, 0.38600427893246997`}}]}, 
   {Hue[0.5731338402983888], AbsoluteThickness[0.5], 
    LineBox[{{2.5408578051680704`, 0.38600427893246997`}, {
     2.3521208504642495`, 0.43589151963717293`}}]}, 
   {Hue[0.5261333118149548], AbsoluteThickness[0.5], 
    LineBox[{{2.6333777841405603`, 1.3440773710913354`}, {2.614423833204095, 
     1.378331862968407}}]}, 
   {Hue[0.5266857173314953], AbsoluteThickness[0.5], 
    LineBox[{{2.614423833204095, 1.378331862968407}, {2.4437335460181555`, 
     1.6544157791955885`}}]}, 
   {Hue[0.6488396166666175], AbsoluteThickness[0.5], 
    LineBox[{{4.62820524562636, 1.839923874231776}, {4.636677011712868, 
     1.8368825418940304`}}]}, 
   {Hue[0.6498449892193243], AbsoluteThickness[0.5], 
    LineBox[{{4.636677011712868, 1.8368825418940304`}, {4.869629650825194, 
     1.7273331919212014`}}]}, 
   {Hue[0.5937718596942155], AbsoluteThickness[0.5], 
    LineBox[{{5.238447625736557, 1.0756212731133092`}, {5.34344157488771, 
     1.0061028238653411`}}]}, 
   {Hue[0.5943887111401597], AbsoluteThickness[0.5], 
    LineBox[{{5.34344157488771, 1.0061028238653411`}, {5.610340754814613, 
     0.8510274613887285}}]}, 
   {Hue[0.22530233811206932`], AbsoluteThickness[0.5], 
    LineBox[{{5.399957867021137, 1.2412600681482033`}, {5.526487052426518, 
     1.4197549120545678`}}]}, 
   {Hue[0.22590034843733625`], AbsoluteThickness[0.5], 
    LineBox[{{5.526487052426518, 1.4197549120545678`}, {5.646870754836509, 
     1.611395584622147}}]}, 
   {Hue[0.5989141010919249], AbsoluteThickness[0.5], 
    LineBox[{{5.239538837030485, 1.4079559087599995`}, {5.167147987199185, 
     1.4628117845580182`}}]}, 
   {Hue[0.5995231305777545], AbsoluteThickness[0.5], 
    LineBox[{{5.167147987199185, 1.4628117845580182`}, {4.907534514553818, 
     1.6370403767861952`}}]}, 
   {Hue[0.5013642943213006], AbsoluteThickness[0.5], 
    LineBox[{{3.6916147073175045`, -1.9246129787405968`}, {
     3.756429092525939, -2.087022812512189}}]}, 
   {Hue[0.5018050160672031], AbsoluteThickness[0.5], 
    LineBox[{{3.756429092525939, -2.087022812512189}, {
     3.8510372941153292`, -2.336410278495186}}]}, 
   {Hue[0.6627292576907704], AbsoluteThickness[0.5], 
    LineBox[{{3.0814552922410883`, 0.31804368693933216`}, {3.047437500887373, 
     0.38883413305968484`}}]}, 
   {Hue[0.6632697737363622], AbsoluteThickness[0.5], 
    LineBox[{{3.047437500887373, 0.38883413305968484`}, {2.9359289657834458`, 
     0.6512504397556205}}]}, 
   {Hue[0.5422289276086908], AbsoluteThickness[0.5], 
    LineBox[{{4.126122685019454, -1.3114282228787153`}, {
     4.108068929066292, -1.4406153398004986`}}]}, 
   {Hue[0.549154936236652], AbsoluteThickness[0.5], 
    LineBox[{{4.108068929066292, -1.4406153398004986`}, {
     4.0523272998872395`, -1.5873938866769715`}}]}, 
   {Hue[0.6571412901715115], AbsoluteThickness[0.5], 
    LineBox[{{4.345038459366062, -0.5121475061791778}, {
     3.878125227059027, -0.21974452491794855`}}]}, 
   {Hue[0.6581765930179994], AbsoluteThickness[0.5], 
    LineBox[{{3.878125227059027, -0.21974452491794855`}, {
     3.6251648598083506`, -0.09359509504172728}}]}, 
   {Hue[0.6615074277882168], AbsoluteThickness[0.5], 
    LineBox[{{5.065454829973004, -0.72848129990667}, {
     4.9205599248913465`, -0.6820181320352567}}]}, 
   {Hue[0.6621815225259988], AbsoluteThickness[0.5], 
    LineBox[{{4.9205599248913465`, -0.6820181320352567}, {
     4.65313489774091, -0.6153147808135092}}]}, 
   {Hue[0.10873172878899008`], AbsoluteThickness[0.5], 
    LineBox[{{5.357362093461914, -0.7756270656992569}, {
     5.656939835973803, -0.8270111988208106}}]}, 
   {Hue[0.11114970606712593`], AbsoluteThickness[0.5], 
    LineBox[{{5.656939835973803, -0.8270111988208106}, {
     5.870005463793433, -0.8307930425086424}}]}, 
   {Hue[0.4909084435843912], AbsoluteThickness[0.5], 
    LineBox[{{5.870005463793433, -0.8307930425086424}, {
     5.8759427225185705`, -0.617776580565714}}]}, 
   {Hue[0.6623685456802569], AbsoluteThickness[0.5], 
    LineBox[{{5.061729395410321, -0.7698062794560154}, {
     4.9134170143162805`, -0.7654403376325448}}]}, 
   {Hue[0.6628884009567189], AbsoluteThickness[0.5], 
    LineBox[{{4.9134170143162805`, -0.7654403376325448}, {
     4.622790526138344, -0.7446440540314844}}]}, 
   {Hue[0.6579377295772525], AbsoluteThickness[0.5], 
    LineBox[{{4.128800288579424, -0.833250016072965}, {
     3.8767025775762196`, -0.8558647357359751}}]}, 
   {Hue[0.6616052440693005], AbsoluteThickness[0.5], 
    LineBox[{{3.8767025775762196`, -0.8558647357359751}, {
     3.6774921984421023`, -0.8378468841760504}}]}, 
   {Hue[0.551187200351076], AbsoluteThickness[0.5], 
    LineBox[{{4.6496974352814595`, 0.14290047671376765`}, {4.650782582534821, 
     0.16583023319331258`}}]}, 
   {Hue[0.5519938848306968], AbsoluteThickness[0.5], 
    LineBox[{{4.650782582534821, 0.1658302331933126}, {4.68060824893424, 
     0.39978430627769856`}}]}, 
   {Hue[0.49759797129806654`], AbsoluteThickness[0.5], 
    LineBox[{{4.658508659323962, 1.4972493899619872`}, {4.663070475648077, 
     1.5601370263849086`}}]}, 
   {Hue[0.4980889218839748], AbsoluteThickness[0.5], 
    LineBox[{{4.663070475648077, 1.5601370263849086`}, {4.69523575231666, 
     1.857802092706485}}]}, 
   {Hue[0.6820473103830456], AbsoluteThickness[0.5], 
    LineBox[{{4.409837262754884, -1.1707992179284101`}, {
     4.575139323577902, -1.1318208711245508`}}]}, 
   {Hue[0.6833463073163456], AbsoluteThickness[0.5], 
    LineBox[{{4.575139323577902, -1.1318208711245508`}, {
     4.821468072990681, -1.1022051021929802`}}]}, 
   {Hue[0.2754051423983407], AbsoluteThickness[0.5], 
    LineBox[{{3.7541351821824978`, -2.347514892343267}, {
     3.8298592617490637`, -2.636467469865507}}]}, 
   {Hue[0.27935464579673563`], AbsoluteThickness[0.5], 
    LineBox[{{3.8298592617490637`, -2.636467469865507}, {
     3.844106404249119, -2.835043982688627}}]}, 
   {Hue[0.6101526824484714], AbsoluteThickness[0.5], 
    LineBox[{{3.844106404249119, -2.835043982688627}, {
     3.6506009616470347`, -2.881854838243501}}]}, 
   {Hue[0.6984954364220695], AbsoluteThickness[0.5], 
    LineBox[{{2.9123954804207255`, -1.6351259247744385`}, {
     2.8360595230684265`, -1.6157573308095037`}}]}, 
   {Hue[0.6140906853982193], AbsoluteThickness[0.5], 
    LineBox[{{5.345750469609945, -0.8212289355226178}, {
     5.6390335918246395`, -0.8047939153970187}}]}, 
   {Hue[0.6147972989450432], AbsoluteThickness[0.5], 
    LineBox[{{5.6390335918246395`, -0.8047939153970187}, {
     5.908520275783111, -0.770776987131925}}]}, 
   {Hue[0.4819953229409187], AbsoluteThickness[0.5], 
    LineBox[{{4.627307438079834, -2.12228259545615}, {
     4.647610286387004, -2.1737924801970254`}}]}, 
   {Hue[0.4829010629438232], AbsoluteThickness[0.5], 
    LineBox[{{4.647610286387004, -2.1737924801970254`}, {
     4.759350624138714, -2.397524817396238}}]}, 
   {Hue[0.6704523187948915], AbsoluteThickness[0.5], 
    LineBox[{{2.8523206524902855`, -2.364098849167237}, {
     2.6837717795392795`, -2.442784475729262}}]}, 
   {Hue[0.6709112867929043], AbsoluteThickness[0.5], 
    LineBox[{{2.6837717795392795`, -2.442784475729262}, {
     2.392528527900002, -2.5698542075256747`}}]}, 
   {Hue[0.4512013293741645], AbsoluteThickness[0.5], 
    LineBox[{{2.815830903486109, -2.55594132571844}, {
     2.818023672780237, -2.5903020992488566`}}]}, 
   {Hue[0.4518474238352864], AbsoluteThickness[0.5], 
    LineBox[{{2.818023672780237, -2.5903020992488566`}, {
     2.818440757102986, -2.9068905224662767`}}]}, 
   {Hue[0.6905202556790375], AbsoluteThickness[0.5], 
    LineBox[{{2.9811804319450563`, -2.659838250745559}, {
     3.079619050461156, -2.6912961367214048`}}]}, 
   {Hue[0.6909460221558491], AbsoluteThickness[0.5], 
    LineBox[{{3.079619050461156, -2.6912961367214048`}, {
     3.3954200126965945`, -2.79248520467191}}]}, 
   {Hue[0.6958079855326997], AbsoluteThickness[0.5], 
    LineBox[{{3.174684591772575, -2.304015985541804}, {
     3.04134106322779, -2.326908931008197}}]}, 
   {Hue[0.6989729348361582], AbsoluteThickness[0.5], 
    LineBox[{{3.04134106322779, -2.326908931008197}, {
     2.8222605672688674`, -2.404365730792778}}]}, 
   {Hue[0.2609411904927565], AbsoluteThickness[0.5], 
    LineBox[{{3.9822924954212557`, -2.647266869484903}, {
     4.313168765872235, -2.9790996616669476`}}]}, 
   {Hue[0.2625267551578963], AbsoluteThickness[0.5], 
    LineBox[{{4.313168765872235, -2.9790996616669476`}, {
     4.489646047168143, -3.116630314613028}}]}, 
   {Hue[0.6846344451475594], AbsoluteThickness[0.5], 
    LineBox[{{4.489646047168143, -3.116630314613028}, {
     4.597279339524464, -2.920482447711782}}]}, 
   {Hue[0.6991611748837976], AbsoluteThickness[0.5], 
    LineBox[{{4.108242267291991, -1.990526722081778}, {
     4.166600481751203, -1.8982096358165381`}}]}, 
   {Hue[0.699605959455655], AbsoluteThickness[0.5], 
    LineBox[{{4.166600481751203, -1.8982096358165381`}, {
     4.352793269977804, -1.5906987649911009`}}]}, 
   {Hue[0.576112000974449], AbsoluteThickness[0.5], 
    LineBox[{{4.863991183118428, -1.8083411027019698`}, {
     4.946995793420551, -1.8409864386077008`}}]}, 
   {Hue[0.5832988357572548], AbsoluteThickness[0.5], 
    LineBox[{{4.946995793420551, -1.8409864386077008`}, {
     5.098308273176926, -1.9448383094879411`}}]}, 
   {Hue[0.5749275289465848], AbsoluteThickness[0.5], 
    LineBox[{{4.796808953780004, -1.5599280197935799`}, {
     4.941733274327429, -1.5624161419099463`}}]}, 
   {Hue[0.5767402718485544], AbsoluteThickness[0.5], 
    LineBox[{{4.941733274327429, -1.5624161419099463`}, {
     5.151781546088394, -1.5378741536955851`}}]}, 
   {Hue[0.6557658710428109], AbsoluteThickness[0.5], 
    LineBox[{{4.681087795242165, -1.0580064164404768`}, {
     4.683376102524628, -0.8354753739379034}}]}, 
   {Hue[0.6566000374050838], AbsoluteThickness[0.5], 
    LineBox[{{4.683376102524628, -0.8354753739379034}, {
     4.70764611345942, -0.5730184513659031}}]}, 
   {Hue[0.6693107831691726], AbsoluteThickness[0.5], 
    LineBox[{{4.432364446435175, -0.17708117521631872`}, {
     4.46471757308307, -0.09834214714619913}}]}, 
   {Hue[0.6697533934897586], AbsoluteThickness[0.5], 
    LineBox[{{4.46471757308307, -0.09834214714619913}, {4.585127898928671, 
     0.18020603720124698`}}]}, 
   {Hue[0.6786827966498283], AbsoluteThickness[0.5], 
    LineBox[{{2.1701607142796377`, -1.8229015240089685`}, {
     2.132186421641535, -1.8169536446752192`}}]}, 
   {Hue[0.6826316011053669], AbsoluteThickness[0.5], 
    LineBox[{{2.132186421641535, -1.8169536446752192`}, {
     1.9123453334589247`, -1.8233963906524737`}}]}, 
   {Hue[0.5186668536463489], AbsoluteThickness[0.5], 
    LineBox[{{2.2024714748527536`, -2.3889895874343257`}, {
     2.1779574249714164`, -2.499116623971192}}]}, 
   {Hue[0.5710389217478511], AbsoluteThickness[0.5], 
    LineBox[{{2.1779574249714164`, -2.499116623971192}, {
     2.083725719993325, -2.6349061399545337`}}]}, 
   {Hue[0.6629920557039886], AbsoluteThickness[0.5], 
    LineBox[{{2.083725719993325, -2.6349061399545337`}, {
     1.918747978957984, -2.624868618500295}}]}, 
   {Hue[0.6643649052466649], AbsoluteThickness[0.5], 
    LineBox[{{2.914275163247531, -1.6366332465281692`}, {
     2.980347121589751, -1.8835698746006577`}}]}, 
   {Hue[0.6648199099269856], AbsoluteThickness[0.5], 
    LineBox[{{2.980347121589751, -1.8835698746006577`}, {
     3.063560221494452, -2.167307965963537}}]}, 
   {Hue[0.5200594013380287], AbsoluteThickness[0.5], 
    LineBox[{{3.12144852818539, -2.394864652958372}, {
     3.5724521351669014`, -2.7894315192618366`}}]}, 
   {Hue[0.5233952137558913], AbsoluteThickness[0.5], 
    LineBox[{{3.5724521351669014`, -2.7894315192618366`}, {
     3.7475481239844357`, -2.895688577383207}}]}, 
   {Hue[0.3424341402284363], AbsoluteThickness[0.5], 
    LineBox[{{3.119104264678842, -2.5822848304466968`}, {
     3.0979552348114527`, -2.6528065159336616`}}]}, 
   {Hue[0.35771266952907077`], AbsoluteThickness[0.5], 
    LineBox[{{3.0979552348114527`, -2.6528065159336616`}, {
     3.096753592915335, -2.830849048264424}}]}, 
   {Hue[0.5569893919314253], AbsoluteThickness[0.5], 
    LineBox[{{3.096753592915335, -2.830849048264424}, {
     3.257534113929122, -2.9073357224275256`}}]}, 
   {Hue[0.5484926930547345], AbsoluteThickness[0.5], 
    LineBox[{{2.9475709771586023`, -2.657837128715128}, {
     2.8992604985573753`, -2.6644498343034493`}}]}, 
   {Hue[0.5490378526908404], AbsoluteThickness[0.5], 
    LineBox[{{2.8992604985573753`, -2.6644498343034493`}, {
     2.5764440754740203`, -2.7242116310163853`}}]}, 
   {Hue[0.6916791070625531], AbsoluteThickness[0.5], 
    LineBox[{{4.419765201579433, -1.7286422782580313`}, {
     4.498493986895751, -1.8516802617659731`}}]}, 
   {Hue[0.6924446430178658], AbsoluteThickness[0.5], 
    LineBox[{{4.498493986895751, -1.8516802617659731`}, {
     4.636998230898286, -2.1091392321176685`}}]}, 
   {Hue[0.47004057318987086`], AbsoluteThickness[0.5], 
    LineBox[{{5.663290294957805, -1.9214822302777352`}, {
     6.118086194839593, -2.261617561017786}}]}, 
   {Hue[0.47179953801058605`], AbsoluteThickness[0.5], 
    LineBox[{{6.118086194839593, -2.261617561017786}, {
     6.334093200644581, -2.3826157206719287`}}]}, 
   {Hue[0.6653515453058163], AbsoluteThickness[0.5], 
    LineBox[{{4.6882749155741, 0.9816098085967916}, {4.839081752218967, 
     1.0188056192394725`}}]}, 
   {Hue[0.6658805897075203], AbsoluteThickness[0.5], 
    LineBox[{{4.839081752218967, 1.0188056192394725`}, {5.150049919215277, 
     1.08116621558647}}]}, 
   {Hue[0.462969050788786], AbsoluteThickness[0.5], 
    LineBox[{{3.3546256980405174`, 2.3808843500681465`}, {3.3525630358932155`,
      2.397556956073795}}]}, 
   {Hue[0.4657995627420896], AbsoluteThickness[0.5], 
    LineBox[{{3.3525630358932155`, 2.397556956073795}, {3.3610820068575955`, 
     2.614000154795933}}]}, 
   {Hue[0.576317659288693], AbsoluteThickness[0.5], 
    LineBox[{{4.205825463110479, 1.9762624042413246`}, {4.5832884339769695`, 
     2.2050812061464558`}}]}, 
   {Hue[0.5767707710506251], AbsoluteThickness[0.5], 
    LineBox[{{4.5832884339769695`, 2.2050812061464558`}, {4.8535427023504045`,
      2.3605031245314656`}}]}, 
   {Hue[0.6356425816005143], AbsoluteThickness[0.5], 
    LineBox[{{4.179197258372445, 0.9784740411895227}, {4.223091396210183, 
     0.9056260653059286}}]}, 
   {Hue[0.6361480056708085], AbsoluteThickness[0.5], 
    LineBox[{{4.223091396210183, 0.9056260653059286}, {4.37677651463605, 
     0.6266283101321687}}]}, 
   {Hue[0.689889882501606], AbsoluteThickness[0.5], 
    LineBox[{{3.48715066872307, 0.3445153482649548}, {3.447542608168152, 
     0.14245845625661901`}}]}, 
   {Hue[0.6903514965160881], AbsoluteThickness[0.5], 
    LineBox[{{3.447542608168152, 0.14245845625661901`}, {
     3.3946744094985775`, -0.1707267178292357}}]}, 
   {Hue[0.4471468262199693], AbsoluteThickness[0.5], 
    LineBox[{{6.1963346818738945`, -0.008538856457317348}, {
     6.344577042355006, -0.00630823204222921}}]}, 
   {Hue[0.4476205362743797], AbsoluteThickness[0.5], 
    LineBox[{{6.344577042355006, -0.00630823204222921}, {6.658009207031597, 
     0.007931799029019738}}]}, 
   {Hue[0.5125514937592428], AbsoluteThickness[0.5], 
    LineBox[{{4.159975472202784, -3.0989407535553397`}, {
     4.158416611562826, -3.1231934870565636`}}]}, 
   {Hue[0.513219665220651], AbsoluteThickness[0.5], 
    LineBox[{{4.158416611562826, -3.1231934870565636`}, {
     4.158659041478283, -3.3728156841394825`}}]}, 
   {Hue[0.5613966708076392], AbsoluteThickness[0.5], 
    LineBox[{{3.2730173394766404`, -2.9046761845102966`}, {
     3.342179031668642, -3.155728737553207}}]}, 
   {Hue[0.5624780573492046], AbsoluteThickness[0.5], 
    LineBox[{{3.342179031668642, -3.155728737553207}, {
     3.385155537038344, -3.4076008000197104`}}]}, 
   {Hue[0.4560419799190411], AbsoluteThickness[0.5], 
    LineBox[{{2.602437569396929, -4.194131974136274}, {
     2.6169926665779757`, -4.347036104619345}}]}, 
   {Hue[0.45672952860159105`], AbsoluteThickness[0.5], 
    LineBox[{{2.6169926665779757`, -4.347036104619345}, {
     2.6254031923217167`, -4.653204148378009}}]}, 
   {Hue[0.563317395435122], AbsoluteThickness[0.5], 
    LineBox[{{3.4850570713722866`, -1.1079220474040337`}, {
     3.3681912055842185`, -1.1857773319851659`}}]}, 
   {Hue[0.5637915467755714], AbsoluteThickness[0.5], 
    LineBox[{{3.3681912055842185`, -1.1857773319851659`}, {
     3.0927632679401023`, -1.3573781824534155`}}]}, 
   {Hue[0.5633618732606095], AbsoluteThickness[0.5], 
    LineBox[{{3.601868804990173, 0.7567996658167186}, {3.1969442503680185`, 
     1.0069061628518408`}}]}, 
   {Hue[0.5642905622848848], AbsoluteThickness[0.5], 
    LineBox[{{3.1969442503680185`, 1.0069061628518408`}, {2.9312094990036774`,
      1.1398332344078586`}}]}, 
   {Hue[0.4817807463487703], AbsoluteThickness[0.5], 
    LineBox[{{5.313934695919415, 1.3874193316373804`}, {5.211872455092598, 
     1.638223919034388}}]}, 
   {Hue[0.48229522266811936`], AbsoluteThickness[0.5], 
    LineBox[{{5.211872455092598, 1.638223919034388}, {5.127535395790679, 
     1.8724386251257839`}}]}, 
   {Hue[0.5156285667845463], AbsoluteThickness[0.5], 
    LineBox[{{5.679808093140753, -0.3918620507205312}, {
     5.6411569027383806`, -0.46565847487042944`}}]}, 
   {Hue[0.5164807615882869], AbsoluteThickness[0.5], 
    LineBox[{{5.6411569027383806`, -0.46565847487042944`}, {
     5.49129132604285, -0.7015811815232789}}]}, 
   {Hue[0.5601020411711647], AbsoluteThickness[0.5], 
    LineBox[{{6.3430457979828425`, 0.07016369287567986}, {
     6.17910470812607, -0.06022460475333573}}]}, 
   {Hue[0.5666617726361135], AbsoluteThickness[0.5], 
    LineBox[{{6.17910470812607, -0.06022460475333573}, {
     5.992221850657239, -0.15089870761409435`}}]}, 
   {Hue[0.5614513671111375], AbsoluteThickness[0.5], 
    LineBox[{{7.087986891189276, 0.21759480145191668`}, {6.907598860680265, 
     0.2592682251028486}}]}, 
   {Hue[0.5619866082913002], AbsoluteThickness[0.5], 
    LineBox[{{6.907598860680265, 0.2592682251028486}, {6.607074278039562, 
     0.3145455153825057}}]}, 
   {Hue[0.010614788293953292`], AbsoluteThickness[0.5], 
    LineBox[{{7.319376887406318, 0.22198867453246562`}, {7.582237084307932, 
     0.2227711079651515}}]}, 
   {Hue[0.011044459125325055`], AbsoluteThickness[0.5], 
    LineBox[{{7.582237084307932, 0.2227711079651515}, {7.921537613865878, 
     0.22079455298073367`}}]}, 
   {Hue[0.5648900786507601], AbsoluteThickness[0.5], 
    LineBox[{{7.921537613865878, 0.22079455298073367`}, {7.584716518663563, 
     0.1798030178225848}}]}, 
   {Hue[0.5623290138754828], AbsoluteThickness[0.5], 
    LineBox[{{7.095082754191072, 0.16495554139748614`}, {7.063144396718614, 
     0.15737654836511356`}}]}, 
   {Hue[0.5676472871905633], AbsoluteThickness[0.5], 
    LineBox[{{7.063144396718614, 0.15737654836511356`}, {6.933148401881306, 
     0.09646057320997259}}]}, 
   {Hue[0.5640104413831845], AbsoluteThickness[0.5], 
    LineBox[{{6.148122205885629, 0.4335401879191241}, {6.067023630212871, 
     0.43118750469933487`}}]}, 
   {Hue[0.565331946649609], AbsoluteThickness[0.5], 
    LineBox[{{6.067023630212871, 0.43118750469933487`}, {5.8288862326272355`, 
     0.4512466157806782}}]}, 
   {Hue[0.5181846546309814], AbsoluteThickness[0.5], 
    LineBox[{{5.4587923720161955`, 1.6218890784596587`}, {5.308739561621707, 
     2.075482989516793}}]}, 
   {Hue[0.5186161530578036], AbsoluteThickness[0.5], 
    LineBox[{{5.308739561621707, 2.075482989516793}, {5.199950278683737, 
     2.392965765523268}}]}, 
   {Hue[0.5828126285907876], AbsoluteThickness[0.5], 
    LineBox[{{5.362678335162021, -1.1179709096707855`}, {
     5.369735385117873, -1.189444327106259}}]}, 
   {Hue[0.585096101198631], AbsoluteThickness[0.5], 
    LineBox[{{5.369735385117873, -1.189444327106259}, {
     5.359614317133042, -1.391765475164945}}]}, 
   {Hue[0.5765779879796594], AbsoluteThickness[0.5], 
    LineBox[{{4.606621202127479, -0.34783073187943775`}, {
     4.362952104949437, -0.38913829442149306`}}]}, 
   {Hue[0.5834851671791761], AbsoluteThickness[0.5], 
    LineBox[{{4.362952104949437, -0.38913829442149306`}, {
     4.151868026960023, -0.3773117468062892}}]}, 
   {Hue[0.6741410217690894], AbsoluteThickness[0.5], 
    LineBox[{{4.8826669138680225`, 0.5934691598521935}, {4.866681049463422, 
     0.618781076287932}}]}, 
   {Hue[0.674652076861654], AbsoluteThickness[0.5], 
    LineBox[{{4.866681049463422, 0.618781076287932}, {4.6953265593375875`, 
     0.8674399510744397}}]}, 
   {Hue[0.5667168135196491], AbsoluteThickness[0.5], 
    LineBox[{{3.5911545444452124`, -0.3654615380331688}, {
     3.56231214834262, -0.36999355140420676`}}]}, 
   {Hue[0.5751998839449063], AbsoluteThickness[0.5], 
    LineBox[{{3.56231214834262, -0.36999355140420676`}, {
     3.3871360582173686`, -0.44300214135031607`}}]}, 
   {Hue[0.5661670317146222], AbsoluteThickness[0.5], 
    LineBox[{{3.6446062161021278`, 1.8825090394868036`}, {3.6396034524632177`,
      1.9229104040329967`}}]}, 
   {Hue[0.5673414835978364], AbsoluteThickness[0.5], 
    LineBox[{{3.6396034524632177`, 1.9229104040329967`}, {3.591380863477616, 
     2.1302632880614265`}}]}, 
   {Hue[0.5633814341141865], AbsoluteThickness[0.5], 
    LineBox[{{2.1165059804624176`, -0.32504229334610085`}, {
     2.098306720530449, -0.32528561211178064`}}]}, 
   {Hue[0.5654152867044999], AbsoluteThickness[0.5], 
    LineBox[{{2.098306720530449, -0.32528561211178064`}, {
     1.8703696917116817`, -0.3607321474066407}}]}, 
   {Hue[0.563333164802693], AbsoluteThickness[0.5], 
    LineBox[{{3.1047214691705607`, -0.2926370896595295}, {
     2.915851640981832, -0.30459829599286553`}}]}, 
   {Hue[0.5639132482307062], AbsoluteThickness[0.5], 
    LineBox[{{2.915851640981832, -0.30459829599286553`}, {
     2.622754223526307, -0.3075982666622284}}]}, 
   {Hue[0.6051213448425401], AbsoluteThickness[0.5], 
    LineBox[{{5.448436678281294, 0.6791752295443908}, {5.391031476344939, 
     0.7341044085637806}}]}, 
   {Hue[0.6059680070141047], AbsoluteThickness[0.5], 
    LineBox[{{5.391031476344939, 0.7341044085637806}, {5.187270329503395, 
     0.8990030806879106}}]}, 
   {Hue[0.32416494830090975`], AbsoluteThickness[0.5], 
    LineBox[{{6.6022014788616845`, 0.543333230433746}, {6.674022119346498, 
     0.5952590042609207}}]}, 
   {Hue[0.3247086086535847], AbsoluteThickness[0.5], 
    LineBox[{{6.674022119346498, 0.5952590042609207}, {6.9340664185270295`, 
     0.8024390340462325}}]}, 
   {Hue[0.6102558360849709], AbsoluteThickness[0.5], 
    LineBox[{{7.079945371131511, -0.5630432144626165}, {
     7.151419499006523, -0.5951692003176565}}]}, 
   {Hue[0.6112915430619257], AbsoluteThickness[0.5], 
    LineBox[{{7.151419499006523, -0.5951692003176565}, {
     7.419914154845707, -0.7486637029729192}}]}, 
   {Hue[0.5593520611037736], AbsoluteThickness[0.5], 
    LineBox[{{4.857273294312428, -0.47660715974112944`}, {
     4.661037432143194, -0.5348293235370507}}]}, 
   {Hue[0.559827618517671], AbsoluteThickness[0.5], 
    LineBox[{{4.661037432143194, -0.5348293235370507}, {
     4.360158156711748, -0.6140657618613021}}]}, 
   {Hue[0.4731773681593212], AbsoluteThickness[0.5], 
    LineBox[{{6.553628810836328, 0.18631471371293812`}, {6.58699624325022, 
     0.46541177321978666`}}]}, 
   {Hue[0.481518312249483], AbsoluteThickness[0.5], 
    LineBox[{{6.58699624325022, 0.46541177321978666`}, {6.568855167801231, 
     0.6174263452611388}}]}, 
   {Hue[0.12329198486998504`], AbsoluteThickness[0.5], 
    LineBox[{{6.8597589669056225`, -0.5845111883421094}, {
     7.047251138791663, -0.7692447908416671}}]}, 
   {Hue[0.12478920863145938`], AbsoluteThickness[0.5], 
    LineBox[{{7.047251138791663, -0.7692447908416671}, {
     7.274855582689736, -0.9447428047327998}}]}, 
   {Hue[0.5526623603842702], AbsoluteThickness[0.5], 
    LineBox[{{7.274855582689736, -0.9447428047327998}, {
     7.405088008018428, -0.68853419606617}}]}, 
   {Hue[0.11054343450303554`], AbsoluteThickness[0.5], 
    LineBox[{{7.0215085740187915`, -0.6041830145675025}, {
     7.331432026539258, -0.5235769144612856}}]}, 
   {Hue[0.11097037345262428`], AbsoluteThickness[0.5], 
    LineBox[{{7.331432026539258, -0.5235769144612856}, {
     7.625251836471496, -0.4456293654410927}}]}, 
   {Hue[0.6654610015506596], AbsoluteThickness[0.5], 
    LineBox[{{7.625251836471496, -0.4456293654410927}, {
     7.326681774497503, -0.50274170386037}}]}, 
   {Hue[0.2139196626894402], AbsoluteThickness[0.5], 
    LineBox[{{7.121331801914947, -0.47539932258478895`}, {
     7.143302799879868, -0.40010426162515683`}}]}, 
   {Hue[0.2145134466205717], AbsoluteThickness[0.5], 
    LineBox[{{7.143302799879868, -0.40010426162515683`}, {
     7.237436178702556, -0.1331905586621232}}]}, 
   {Hue[0.31729589087584575`], AbsoluteThickness[0.5], 
    LineBox[{{7.061947064780103, -0.32366478747912547`}, {6.670298616074795, 
     0.09799194837375624}}]}, 
   {Hue[0.32963860789185717`], AbsoluteThickness[0.5], 
    LineBox[{{6.670298616074795, 0.09799194837375624}, {6.588640046746528, 
     0.2545280016118804}}]}, 
   {Hue[0.5491045416688308], AbsoluteThickness[0.5], 
    LineBox[{{6.588640046746528, 0.2545280016118804}, {6.70010912973207, 
     0.3914451351141221}}]}, 
   {Hue[0.4206721190622524], AbsoluteThickness[0.5], 
    LineBox[{{6.901227079449604, -0.2968505661838745}, {
     6.857840135934705, -0.3061052317638444}}]}, 
   {Hue[0.4216137497299177], AbsoluteThickness[0.5], 
    LineBox[{{6.857840135934705, -0.3061052317638444}, {
     6.580784619648193, -0.33943437615787486`}}]}, 
   {Hue[0.5240483472486586], AbsoluteThickness[0.5], 
    LineBox[{{6.795799670673987, -0.42108815158847496`}, {
     6.7137162811633875`, -0.6621395895620075}}]}, 
   {Hue[0.5250797299225589], AbsoluteThickness[0.5], 
    LineBox[{{6.7137162811633875`, -0.6621395895620075}, {
     6.6583235910616, -0.8970555104361322}}]}, 
   {Hue[0.6274245754350681], AbsoluteThickness[0.5], 
    LineBox[{{6.848407914690187, -0.5753032248136253}, {
     7.056081023794649, -0.8197566372306931}}]}, 
   {Hue[0.635044063819357], AbsoluteThickness[0.5], 
    LineBox[{{7.056081023794649, -0.8197566372306931}, {
     7.231723758310917, -0.9493054182367564}}]}, 
   {Hue[0.4951514803452915], AbsoluteThickness[0.5], 
    LineBox[{{6.0105014419181435`, -1.1387971523378122`}, {
     5.9139128967380685`, -1.1628863253329773`}}]}, 
   {Hue[0.4955772570244997], AbsoluteThickness[0.5], 
    LineBox[{{5.9139128967380685`, -1.1628863253329773`}, {
     5.6050158203060105`, -1.2402184750410594`}}]}, 
   {Hue[0.5608332960071238], AbsoluteThickness[0.5], 
    LineBox[{{5.67150071752314, 0.3337724871545906}, {5.611970892964753, 
     0.3777017553576152}}]}, 
   {Hue[0.5612870737579033], AbsoluteThickness[0.5], 
    LineBox[{{5.611970892964753, 0.3777017553576152}, {5.3361431345765595`, 
     0.5913632073700996}}]}, 
   {Hue[0.32709790527443755`], AbsoluteThickness[0.5], 
    LineBox[{{5.744708750988866, -1.36105880486681}, {
     5.685105597842329, -1.5947586963055598`}}]}, 
   {Hue[0.3284074043194825], AbsoluteThickness[0.5], 
    LineBox[{{5.685105597842329, -1.5947586963055598`}, {
     5.650917631972628, -1.8422377313187681`}}]}, 
   {Hue[0.6273677568260629], AbsoluteThickness[0.5], 
    LineBox[{{4.624479354899302, -0.6710780395384429}, {
     4.422187058400199, -0.74023656056404}}]}, 
   {Hue[0.6278011172819341], AbsoluteThickness[0.5], 
    LineBox[{{4.422187058400199, -0.74023656056404}, {
     4.130008610497084, -0.8361472547711477}}]}, 
   {Hue[0.5645996234718551], AbsoluteThickness[0.5], 
    LineBox[{{3.1114390916148045`, -0.23541988300681682`}, {
     2.9239476008717684`, -0.22889532789014136`}}]}, 
   {Hue[0.5650486372220049], AbsoluteThickness[0.5], 
    LineBox[{{2.9239476008717684`, -0.22889532789014136`}, {
     2.614163523778884, -0.22471450999179662`}}]}, 
   {Hue[0.5669620668665334], AbsoluteThickness[0.5], 
    LineBox[{{2.1400932147905727`, -0.1867278088363117}, {
     2.0271780552320076`, -0.2019824272690139}}]}, 
   {Hue[0.5892125177704396], AbsoluteThickness[0.5], 
    LineBox[{{2.0271780552320076`, -0.20198242726901386`}, {
     1.8304753136753826`, -0.16596815799168405`}}]}, 
   {Hue[0.6402562140432506], AbsoluteThickness[0.5], 
    LineBox[{{2.8658227818164175`, 1.9015669098053969`}, {2.8641655264552797`,
      1.9135523928239926`}}]}, 
   {Hue[0.6483046607934736], AbsoluteThickness[0.5], 
    LineBox[{{2.8641655264552797`, 1.9135523928239926`}, {2.881737090212462, 
     2.092805913949266}}]}, 
   {Hue[0.49415191192688085`], AbsoluteThickness[0.5], 
    LineBox[{{3.5174645163758904`, -2.1226483777070975`}, {
     3.445628801632013, -2.3812476655277433`}}]}, 
   {Hue[0.4951149009262521], AbsoluteThickness[0.5], 
    LineBox[{{3.445628801632013, -2.3812476655277433`}, {
     3.3995055904530043`, -2.636188301325462}}]}, 
   {Hue[0.5716763379528051], AbsoluteThickness[0.5], 
    LineBox[{{3.581996321967224, -1.6596235775315171`}, {
     3.289243568805538, -2.0514093347246676`}}]}, 
   {Hue[0.5725138078008681], AbsoluteThickness[0.5], 
    LineBox[{{3.289243568805538, -2.0514093347246676`}, {
     3.151431641888265, -2.2714605875411995`}}]}, 
   {Hue[0.5531460253902195], AbsoluteThickness[0.5], 
    LineBox[{{4.096071977898986, 0.7551747960106177}, {3.9005686133016293`, 
     0.8492881976405247}}]}, 
   {Hue[0.5548536623108222], AbsoluteThickness[0.5], 
    LineBox[{{3.9005686133016293`, 0.8492881976405247}, {3.6765229598425995`, 
     0.9232911848113989}}]}, 
   {Hue[0.5343607678235752], AbsoluteThickness[0.5], 
    LineBox[{{5.6402367800379976`, 1.08815690498474}, {5.63549679522608, 
     1.1120563156931798`}}]}, 
   {Hue[0.5368622048785235], AbsoluteThickness[0.5], 
    LineBox[{{5.63549679522608, 1.1120563156931798`}, {5.625084372092422, 
     1.3630723316337565`}}]}, 
   {Hue[0.5526236139239279], AbsoluteThickness[0.5], 
    LineBox[{{6.080184529658962, 0.34411165867974286`}, {6.027824971635724, 
     0.40073416734157097`}}]}, 
   {Hue[0.5530994162270448], AbsoluteThickness[0.5], 
    LineBox[{{6.027824971635724, 0.40073416734157097`}, {5.833932766430492, 
     0.6239058158992945}}]}, 
   {Hue[0.5367424042040962], AbsoluteThickness[0.5], 
    LineBox[{{6.924415968292159, 0.014232069097353417`}, {
     6.791590530096343, -0.09210893578412988}}]}, 
   {Hue[0.537286441681784], AbsoluteThickness[0.5], 
    LineBox[{{6.791590530096343, -0.09210893578412988}, {
     6.556519117282773, -0.29908340372148595`}}]}, 
   {Hue[0.014854334810483748`], AbsoluteThickness[0.5], 
    LineBox[{{7.140810999442389, -0.00913976349993395}, {
     7.376184534640388, -0.021901606971034125`}}]}, 
   {Hue[0.015291395533337315`], AbsoluteThickness[0.5], 
    LineBox[{{7.376184534640388, -0.021901606971034125`}, {
     7.665395403713867, -0.04190837758023675}}]}, 
   {Hue[0.5674126139807105], AbsoluteThickness[0.5], 
    LineBox[{{7.665395403713867, -0.04190837758023675}, {
     7.378542320629571, -0.08384292640910168}}]}, 
   {Hue[0.537907754083252], AbsoluteThickness[0.5], 
    LineBox[{{6.995028133708599, 0.15247832992994254`}, {6.908973835902174, 
     0.23819696919777036`}}]}, 
   {Hue[0.5392635848370501], AbsoluteThickness[0.5], 
    LineBox[{{6.908973835902174, 0.23819696919777036`}, {6.711169099433256, 
     0.3945024455774354}}]}, 
   {Hue[0.5600565427512516], AbsoluteThickness[0.5], 
    LineBox[{{6.0581550421641595`, -0.2267892024788038}, {
     5.913851295330558, -0.3567727003198258}}]}, 
   {Hue[0.5666111208281276], AbsoluteThickness[0.5], 
    LineBox[{{5.913851295330558, -0.3567727003198258}, {
     5.820255949106423, -0.48858284303473215`}}]}, 
   {Hue[0.4967620469678003], AbsoluteThickness[0.5], 
    LineBox[{{5.732869587020897, -0.8692068730169819}, {
     5.670828404956931, -1.0704512739289835`}}]}, 
   {Hue[0.4987386242088662], AbsoluteThickness[0.5], 
    LineBox[{{5.670828404956931, -1.0704512739289835`}, {
     5.6337905741186995`, -1.2999852137950616`}}]}, 
   {Hue[0.5534780899210514], AbsoluteThickness[0.5], 
    LineBox[{{4.64254879794832, -0.7924339567347299}, {
     4.605080000950214, -0.8444522482292016}}]}, 
   {Hue[0.5539040212170887], AbsoluteThickness[0.5], 
    LineBox[{{4.605080000950214, -0.8444522482292016}, {
     4.424173611960548, -1.094570091895105}}]}, 
   {Hue[0.585752938629774], AbsoluteThickness[0.5], 
    LineBox[{{3.659211858918392, 0.0943043927186046}, {3.573223313797668, 
     0.08641921372800435}}]}, 
   {Hue[0.586616902618851], AbsoluteThickness[0.5], 
    LineBox[{{3.573223313797668, 0.08641921372800435}, {3.299535040210844, 
     0.03778306556821842}}]}, 
   {Hue[0.49493807789346655`], AbsoluteThickness[0.5], 
    LineBox[{{2.945014995196864, 2.668828096426528}, {2.8804921609870364`, 
     2.7870097354207974`}}]}, 
   {Hue[0.5118266656340777], AbsoluteThickness[0.5], 
    LineBox[{{2.8804921609870364`, 2.7870097354207974`}, {2.762849233458325, 
     2.903008534409641}}]}, 
   {Hue[0.5557316978473588], AbsoluteThickness[0.5], 
    LineBox[{{2.476023371459086, 1.6584951030482828`}, {2.4147378285802525`, 
     1.7211494618533236`}}]}, 
   {Hue[0.556314568780705], AbsoluteThickness[0.5], 
    LineBox[{{2.4147378285802525`, 1.7211494618533236`}, {2.2281201940078454`,
      1.89257377653644}}]}, 
   {Hue[0.52332646452822], AbsoluteThickness[0.5], 
    LineBox[{{2.3312063484307086`, -1.4999002297019763`}, {
     2.260689832418649, -1.5650080593056777`}}]}, 
   {Hue[0.5253136172816749], AbsoluteThickness[0.5], 
    LineBox[{{2.260689832418649, -1.5650080593056777`}, {
     2.1233083744543126`, -1.7328768819654647`}}]}, 
   {Hue[0.6335775888542219], AbsoluteThickness[0.5], 
    LineBox[{{3.3599145706950297`, -1.5548617201969486`}, {
     3.3680078017403714`, -1.6173119783696994`}}]}, 
   {Hue[0.6358081110606698], AbsoluteThickness[0.5], 
    LineBox[{{3.3680078017403714`, -1.6173119783696994`}, {
     3.363831360862437, -1.8492813491459832`}}]}, 
   {Hue[0.6173404815292675], AbsoluteThickness[0.5], 
    LineBox[{{2.9602221674844222`, 1.1540114668579144`}, {2.927109677829994, 
     1.1703219123709157`}}]}, 
   {Hue[0.617784990692006], AbsoluteThickness[0.5], 
    LineBox[{{2.927109677829994, 1.1703219123709157`}, {2.6125442720845693`, 
     1.3178554042208324`}}]}, 
   {Hue[0.6831870937317654], AbsoluteThickness[0.5], 
    LineBox[{{4.329214207984857, 1.9115102076511834`}, {4.285865139958835, 
     2.090847554986275}}]}, 
   {Hue[0.6836147138935295], AbsoluteThickness[0.5], 
    LineBox[{{4.285865139958835, 2.090847554986275}, {4.206355265611557, 
     2.4112220048845603`}}]}, 
   {Hue[0.6951051425285859], AbsoluteThickness[0.5], 
    LineBox[{{6.211677744429976, -0.6163894575373122}, {
     6.343621031407625, -0.38559940596056097`}}]}, 
   {Hue[0.2307340742663654], AbsoluteThickness[0.5], 
    LineBox[{{6.385813343037616, -0.8007384408652852}, {
     6.4274537877647475`, -0.8542866201684862}}]}, 
   {Hue[0.2311649410370516], AbsoluteThickness[0.5], 
    LineBox[{{6.4274537877647475`, -0.8542866201684862}, {
     6.617216360486333, -1.103440813219886}}]}, 
   {Hue[0.6971474953987912], AbsoluteThickness[0.5], 
    LineBox[{{6.149057944270961, -0.8915934655548454}, {
     6.145460188991373, -0.8925909295882021}}]}, 
   {Hue[0.6977113294241774], AbsoluteThickness[0.5], 
    LineBox[{{6.145460188991373, -0.8925909295882021}, {
     5.872944468098668, -0.983138323159591}}]}, 
   {Hue[0.5809838413472459], AbsoluteThickness[0.5], 
    LineBox[{{4.903282921475007, 0.45330115643859137`}, {4.678752992372336, 
     0.5092149971547992}}]}, 
   {Hue[0.5816674004762886], AbsoluteThickness[0.5], 
    LineBox[{{4.678752992372336, 0.5092149971547992}, {4.438382574062238, 
     0.5522306874715751}}]}, 
   {Hue[0.5663630267520748], AbsoluteThickness[0.5], 
    LineBox[{{5.615916617633362, 0.7883604035597219}, {5.375989449646333, 
     0.8264196427686917}}]}, 
   {Hue[0.567251950274215], AbsoluteThickness[0.5], 
    LineBox[{{5.375989449646333, 0.8264196427686917}, {5.117142692425293, 
     0.8447991803608269}}]}, 
   {Hue[0.36015978877548316`], AbsoluteThickness[0.5], 
    LineBox[{{6.457251081365736, 0.8586702875957664}, {6.596416104710718, 
     0.7710976264845274}}]}, 
   {Hue[0.3607245693191855], AbsoluteThickness[0.5], 
    LineBox[{{6.596416104710718, 0.7710976264845274}, {6.884034215623186, 
     0.6097740896126957}}]}, 
   {Hue[0.04164500863044768], AbsoluteThickness[0.5], 
    LineBox[{{6.633311975540082, 0.9910358286032771}, {6.740235285145381, 
     1.108447458216327}}]}, 
   {Hue[0.04316712013691499], AbsoluteThickness[0.5], 
    LineBox[{{6.740235285145381, 1.108447458216327}, {6.884812681670207, 
     1.312480342715655}}]}, 
   {Hue[0.4693820279365511], AbsoluteThickness[0.5], 
    LineBox[{{6.884812681670207, 1.312480342715655}, {6.658311462265483, 
     1.4184484471206409`}}]}, 
   {Hue[0.36838792332252857`], AbsoluteThickness[0.5], 
    LineBox[{{6.534017491234703, 1.187653936340612}, {6.243415806087014, 
     1.5658995001003173`}}]}, 
   {Hue[0.36988029864742145`], AbsoluteThickness[0.5], 
    LineBox[{{6.243415806087014, 1.5658995001003173`}, {6.118381507736386, 
     1.7772714597820631`}}]}, 
   {Hue[0.6951308380146093], AbsoluteThickness[0.5], 
    LineBox[{{6.322986907177667, 1.1245336741720537`}, {6.182067102269615, 
     1.0515111446851404`}}]}, 
   {Hue[0.6955659972518388], AbsoluteThickness[0.5], 
    LineBox[{{6.182067102269615, 1.0515111446851404`}, {5.8884647147814535`, 
     0.8942694870676567}}]}, 
   {Hue[0.5690871798691479], AbsoluteThickness[0.5], 
    LineBox[{{6.0947501980414245`, 0.21267797780915598`}, {6.085881764096544, 
     0.18275899738607737`}}]}, 
   {Hue[0.569516701381314], AbsoluteThickness[0.5], 
    LineBox[{{6.085881764096544, 0.18275899738607737`}, {
     5.984355056188853, -0.14921037953537808`}}]}, 
   {Hue[0.5800127560692672], AbsoluteThickness[0.5], 
    LineBox[{{5.497715611292318, -0.06346646839174999}, {
     5.436223237985344, -0.11212266548318356`}}]}, 
   {Hue[0.5804575545518661], AbsoluteThickness[0.5], 
    LineBox[{{5.436223237985344, -0.11212266548318356`}, {
     5.152637510081604, -0.32774920781132155`}}]}, 
   {Hue[0.36488461983600423`], AbsoluteThickness[0.5], 
    LineBox[{{4.988715817088353, 1.1665499100954557`}, {4.886921392254257, 
     1.3728332114621355`}}]}, 
   {Hue[0.37386161337973745`], AbsoluteThickness[0.5], 
    LineBox[{{4.886921392254257, 1.3728332114621355`}, {4.845676480993952, 
     1.5615731203059107`}}]}, 
   {Hue[0.6239403858259412], AbsoluteThickness[0.5], 
    LineBox[{{4.845676480993952, 1.5615731203059107`}, {5.008490448504686, 
     1.665570754310925}}]}, 
   {Hue[0.33518392421157817`], AbsoluteThickness[0.5], 
    LineBox[{{5.797235705250813, 1.4183387294107068`}, {5.863320507914815, 
     1.5301046893547892`}}]}, 
   {Hue[0.3399461092388896], AbsoluteThickness[0.5], 
    LineBox[{{5.863320507914815, 1.5301046893547892`}, {5.994643541699184, 
     1.676407225241591}}]}, 
   {Hue[0.6521854986718976], AbsoluteThickness[0.5], 
    LineBox[{{5.994643541699184, 1.676407225241591}, {6.165654880057569, 
     1.5794263335045395`}}]}, 
   {Hue[0.447295390755648], AbsoluteThickness[0.5], 
    LineBox[{{6.421426550193103, 0.7805466356618064}, {6.602955962106214, 
     0.7975533321945779}}]}, 
   {Hue[0.4478740847741224], AbsoluteThickness[0.5], 
    LineBox[{{6.602955962106214, 0.7975533321945779}, {6.930740076554839, 
     0.8108765891669804}}]}, 
   {Hue[0.5578056083901937], AbsoluteThickness[0.5], 
    LineBox[{{6.284860161404516, -0.43023501789939184`}, {
     6.380728518743348, -0.5599221020672285}}]}, 
   {Hue[0.5614884644186334], AbsoluteThickness[0.5], 
    LineBox[{{6.380728518743348, -0.5599221020672285}, {
     6.5406831974877795`, -0.7102179869740982}}]}, 
   {Hue[0.6739494195614559], AbsoluteThickness[0.5], 
    LineBox[{{5.326968466468267, -0.3736555013707233}, {
     5.226524701079233, -0.6150619754002532}}]}, 
   {Hue[0.6744391859389879], AbsoluteThickness[0.5], 
    LineBox[{{5.226524701079233, -0.6150619754002532}, {
     5.125415144913388, -0.8841962275164095}}]}, 
   {Hue[0.49770525117466696`], AbsoluteThickness[0.5], 
    LineBox[{{4.341750870855744, 1.060831492884444}, {4.317499556337579, 
     1.1248754437067097`}}]}, 
   {Hue[0.49813308526190314`], AbsoluteThickness[0.5], 
    LineBox[{{4.317499556337579, 1.1248754437067097`}, {4.203576005412313, 
     1.4199855581134393`}}]}, 
   {Hue[0.6943787999580325], AbsoluteThickness[0.5], 
    LineBox[{{4.487015805575227, -0.6996624996623929}, {
     4.426000241050343, -0.7834989073421664}}]}, 
   {Hue[0.6973995944244284], AbsoluteThickness[0.5], 
    LineBox[{{4.426000241050343, -0.7834989073421664}, {
     4.276848442066255, -0.9295627438714951}}]}, 
   {Hue[0.5434376311982843], AbsoluteThickness[0.5], 
    LineBox[{{3.9164323230041678`, -1.139991194594669}, {
     3.8858973901438985`, -1.183295031312924}}]}, 
   {Hue[0.5438713799715444], AbsoluteThickness[0.5], 
    LineBox[{{3.8858973901438985`, -1.183295031312924}, {
     3.731131227648466, -1.3970354950296164`}}]}, 
   {Hue[0.5272381228480358], AbsoluteThickness[0.5], 
    LineBox[{{2.4437335460181555`, 1.6544157791955885`}, {2.407907336051848, 
     1.7065504096304975`}}]}, 
   {Hue[0.5278742674542214], AbsoluteThickness[0.5], 
    LineBox[{{2.407907336051848, 1.7065504096304975`}, {2.2547892872798143`, 
     1.9025457792927671`}}]}, 
   {Hue[0.6508503617720311], AbsoluteThickness[0.5], 
    LineBox[{{4.869629650825194, 1.7273331919212014`}, {4.976835846299343, 
     1.663871195984099}}]}, 
   {Hue[0.6528074036148507], AbsoluteThickness[0.5], 
    LineBox[{{4.976835846299343, 1.663871195984099}, {5.170094767464559, 
     1.5098442027278975`}}]}, 
   {Hue[0.5950055625861037], AbsoluteThickness[0.5], 
    LineBox[{{5.610340754814613, 0.8510274613887285}, {5.631913672327946, 
     0.8401273050376032}}]}, 
   {Hue[0.5954314015031756], AbsoluteThickness[0.5], 
    LineBox[{{5.631913672327946, 0.8401273050376032}, {5.9020523769772115`, 
     0.703151117335844}}]}, 
   {Hue[0.22649835876260319`], AbsoluteThickness[0.5], 
    LineBox[{{5.646870754836509, 1.611395584622147}, {5.649313888923236, 
     1.6158139553797166`}}]}, 
   {Hue[0.22692487457089747`], AbsoluteThickness[0.5], 
    LineBox[{{5.649313888923236, 1.6158139553797166`}, {5.767975194850903, 
     1.8284378160510175`}}]}, 
   {Hue[0.6001321600635844], AbsoluteThickness[0.5], 
    LineBox[{{4.907534514553818, 1.6370403767861952`}, {4.865205521483473, 
     1.6620515822433917`}}]}, 
   {Hue[0.6006088678498376], AbsoluteThickness[0.5], 
    LineBox[{{4.865205521483473, 1.6620515822433917`}, {4.601124041665893, 
     1.8071508805746772`}}]}, 
   {Hue[0.5022457378131056], AbsoluteThickness[0.5], 
    LineBox[{{3.8510372941153292`, -2.336410278495186}, {
     3.862486322976546, -2.368221980018479}}]}, 
   {Hue[0.502848667427869], AbsoluteThickness[0.5], 
    LineBox[{{3.862486322976546, -2.368221980018479}, {
     3.9811237150976506`, -2.647292914116017}}]}, 
   {Hue[0.663810289781954], AbsoluteThickness[0.5], 
    LineBox[{{2.9359289657834453`, 0.6512504397556205}, {2.921181960295954, 
     0.6909507332212274}}]}, 
   {Hue[0.6677036029720668], AbsoluteThickness[0.5], 
    LineBox[{{2.921181960295954, 0.6909507332212274}, {2.811514271687862, 
     0.8741671093533059}}]}, 
   {Hue[0.5560809448646135], AbsoluteThickness[0.5], 
    LineBox[{{4.0523272998872395`, -1.5873938866769715`}, {
     3.7010950787337107`, -2.1153461607328077`}}]}, 
   {Hue[0.5718759866575358], AbsoluteThickness[0.5], 
    LineBox[{{3.7010950787337107`, -2.1153461607328077`}, {
     3.658635096782899, -2.2527279496753203`}}]}, 
   {Hue[0.6592118958644873], AbsoluteThickness[0.5], 
    LineBox[{{3.6251648598083506`, -0.09359509504172728}, {
     3.5990552459675036`, -0.08359688740290355}}]}, 
   {Hue[0.6596391125688009], AbsoluteThickness[0.5], 
    LineBox[{{3.5990552459675036`, -0.08359688740290355}, {
     3.2980096486091233`, 0.0335520886546169}}]}, 
   {Hue[0.6628556172637807], AbsoluteThickness[0.5], 
    LineBox[{{4.65313489774091, -0.6153147808135092}, {
     4.643645793118172, -0.613602047655031}}]}, 
   {Hue[0.6633523704314883], AbsoluteThickness[0.5], 
    LineBox[{{4.643645793118172, -0.6136020476550309}, {
     4.342554262668123, -0.5477632918580002}}]}, 
   {Hue[0.4884904663062568], AbsoluteThickness[0.5], 
    LineBox[{{5.656939835973803, -0.8270111988208106}, {
     5.690704485161195, -1.0590633290589926`}}]}, 
   {Hue[0.4889921607582947], AbsoluteThickness[0.5], 
    LineBox[{{5.690704485161195, -1.0590633290589926`}, {
     5.746437075150045, -1.3612129173120575`}}]}, 
   {Hue[0.11356768334526202`], AbsoluteThickness[0.5], 
    LineBox[{{5.870005463793433, -0.8307930425086424}, {
     6.08832949528107, -0.8012782666559674}}]}, 
   {Hue[0.1139999558977166], AbsoluteThickness[0.5], 
    LineBox[{{6.08832949528107, -0.8012782666559674}, {
     6.389303826403369, -0.7571104548669387}}]}, 
   {Hue[0.6672351076572267], AbsoluteThickness[0.5], 
    LineBox[{{6.389303826403369, -0.7571104548669387}, {
     6.085153021935675, -0.7517595919084489}}]}, 
   {Hue[0.49332642086252715`], AbsoluteThickness[0.5], 
    LineBox[{{5.8759427225185705`, -0.617776580565714}, {
     5.872798425943898, -0.5926019625609962}}]}, 
   {Hue[0.49467967662649576`], AbsoluteThickness[0.5], 
    LineBox[{{5.872798425943898, -0.5926019625609962}, {
     5.870742468842931, -0.3800593202050162}}]}, 
   {Hue[0.6634082562331809], AbsoluteThickness[0.5], 
    LineBox[{{4.622790526138344, -0.7446440540314844}, {
     4.41640722232809, -0.7211307791076224}}]}, 
   {Hue[0.6640446886169974], AbsoluteThickness[0.5], 
    LineBox[{{4.41640722232809, -0.7211307791076224}, {
     4.1337574383450395`, -0.7063389609053039}}]}, 
   {Hue[0.6652727585613487], AbsoluteThickness[0.5], 
    LineBox[{{3.6774921984421023`, -0.8378468841760504}, {
     3.6545538155352855`, -0.8315017465443733}}]}, 
   {Hue[0.6708563881124958], AbsoluteThickness[0.5], 
    LineBox[{{3.6545538155352855`, -0.8315017465443733}, {
     3.4537259624844996`, -0.8191926370733296}}]}, 
   {Hue[0.5528005693103174], AbsoluteThickness[0.5], 
    LineBox[{{4.68060824893424, 0.39978430627769856`}, {4.715033096843936, 
     0.5642677456482419}}]}, 
   {Hue[0.5532264308256194], AbsoluteThickness[0.5], 
    LineBox[{{4.715033096843936, 0.5642677456482419}, {4.778917222020252, 
     0.8719208358525892}}]}, 
   {Hue[0.49857987246988295`], AbsoluteThickness[0.5], 
    LineBox[{{4.69523575231666, 1.857802092706485}, {4.730408969984653, 
     2.1023158336919185`}}]}, 
   {Hue[0.49901994624199536`], AbsoluteThickness[0.5], 
    LineBox[{{4.730408969984653, 2.1023158336919185`}, {4.769874076981561, 
     2.41357687793816}}]}, 
   {Hue[0.6846453042496456], AbsoluteThickness[0.5], 
    LineBox[{{4.821468072990681, -1.1022051021929802`}, {
     4.925173430417934, -1.1014026176839045`}}]}, 
   {Hue[0.685806770123348], AbsoluteThickness[0.5], 
    LineBox[{{4.925173430417934, -1.1014026176839042`}, {
     5.163621605349954, -1.0745105326239368`}}]}, 
   {Hue[0.6062031790500778], AbsoluteThickness[0.5], 
    LineBox[{{3.8298592617490637`, -2.636467469865507}, {
     4.139115436590112, -2.7249868964881845`}}]}, 
   {Hue[0.6066609292009834], AbsoluteThickness[0.5], 
    LineBox[{{4.139115436590112, -2.7249868964881845`}, {
     4.419077733814899, -2.79762915124042}}]}, 
   {Hue[0.28330414919513075`], AbsoluteThickness[0.5], 
    LineBox[{{3.844106404249119, -2.835043982688627}, {
     3.8098322666788738`, -3.1369196140134696`}}]}, 
   {Hue[0.283730323421093], AbsoluteThickness[0.5], 
    LineBox[{{3.8098322666788738`, -3.1369196140134696`}, {
     3.77483995949091, -3.4372416890708823`}}]}, 
   {Hue[0.6141021858468665], AbsoluteThickness[0.5], 
    LineBox[{{3.6506009616470347`, -2.881854838243501}, {
     3.625530218191791, -2.8831766159864194`}}]}, 
   {Hue[0.6147251445165606], AbsoluteThickness[0.5], 
    LineBox[{{3.625530218191791, -2.8831766159864194`}, {
     3.3341557215325435`, -2.9159524939842534`}}]}, 
   {Hue[0.6155039124918671], AbsoluteThickness[0.5], 
    LineBox[{{5.908520275783111, -0.770776987131925}, {
     6.087692479161484, -0.7353608866130028}}]}, 
   {Hue[0.6160737113767364], AbsoluteThickness[0.5], 
    LineBox[{{6.087692479161484, -0.7353608866130028}, {
     6.3712516550442695`, -0.6942983855546734}}]}, 
   {Hue[0.48380680294672784`], AbsoluteThickness[0.5], 
    LineBox[{{4.759350624138714, -2.397524817396238}, {
     4.834596255186881, -2.5199955510787393`}}]}, 
   {Hue[0.5157390461035375], AbsoluteThickness[0.5], 
    LineBox[{{4.834596255186881, -2.5199955510787393`}, {
     4.950187313867133, -2.612343339894973}}]}, 
   {Hue[0.6483164226519367], AbsoluteThickness[0.5], 
    LineBox[{{4.950187313867133, -2.612343339894973}, {
     5.087484378227502, -2.5572169118944763`}}]}, 
   {Hue[0.6713702547909172], AbsoluteThickness[0.5], 
    LineBox[{{2.392528527900002, -2.5698542075256743`}, {
     2.3694639462540885`, -2.5792283277292483`}}]}, 
   {Hue[0.6720241261523842], AbsoluteThickness[0.5], 
    LineBox[{{2.3694639462540885`, -2.5792283277292483`}, {
     2.0985167850331248`, -2.7099219934700547`}}]}, 
   {Hue[0.45249351829640827`], AbsoluteThickness[0.5], 
    LineBox[{{2.818440757102986, -2.9068905224662767`}, {
     2.8047726632252297`, -3.130331615290844}}]}, 
   {Hue[0.453007384781427], AbsoluteThickness[0.5], 
    LineBox[{{2.8047726632252297`, -3.130331615290844}, {
     2.7741997609281652`, -3.4296035592425302`}}]}, 
   {Hue[0.6913717886326607], AbsoluteThickness[0.5], 
    LineBox[{{3.3954200126965945`, -2.79248520467191}, {
     3.4436114221675216`, -2.807967787033419}}]}, 
   {Hue[0.6942684937706556], AbsoluteThickness[0.5], 
    LineBox[{{3.4436114221675216`, -2.807967787033419}, {
     3.6364897111645367`, -2.9071129544851435`}}]}, 
   {Hue[0.6830488804824191], AbsoluteThickness[0.5], 
    LineBox[{{4.313168765872235, -2.9790996616669476`}, {
     4.202609072056595, -3.1110878127485306`}}]}, 
   {Hue[0.684469446739873], AbsoluteThickness[0.5], 
    LineBox[{{4.202609072056595, -3.1110878127485306`}, {
     4.0854239787760145`, -3.2901286060772734`}}]}, 
   {Hue[0.264112319823036], AbsoluteThickness[0.5], 
    LineBox[{{4.489646047168143, -3.116630314613028}, {
     4.619932011821929, -3.194224376888309}}]}, 
   {Hue[0.2645414360719368], AbsoluteThickness[0.5], 
    LineBox[{{4.619932011821929, -3.194224376888309}, {
     4.901432935913149, -3.3587805302606646`}}]}, 
   {Hue[0.6862200098126993], AbsoluteThickness[0.5], 
    LineBox[{{4.597279339524464, -2.920482447711782}, {
     4.619664075461835, -2.863951148217881}}]}, 
   {Hue[0.6871201833878235], AbsoluteThickness[0.5], 
    LineBox[{{4.619664075461835, -2.863951148217881}, {
     4.739387967081124, -2.624916473155098}}]}, 
   {Hue[0.5904856705400607], AbsoluteThickness[0.5], 
    LineBox[{{5.098308273176926, -1.9448383094879411`}, {
     5.208689887518962, -2.0651185244568993`}}]}, 
   {Hue[0.5914952964877856], AbsoluteThickness[0.5], 
    LineBox[{{5.208689887518962, -2.0651185244568993`}, {
     5.379193407445641, -2.2906600165561555`}}]}, 
   {Hue[0.5785530147505238], AbsoluteThickness[0.5], 
    LineBox[{{5.151781546088394, -1.5378741536955851`}, {
     5.384121180623599, -1.4785997014901833`}}]}, 
   {Hue[0.5791631476827405], AbsoluteThickness[0.5], 
    LineBox[{{5.384121180623599, -1.4785997014901833`}, {
     5.671137349615453, -1.4227318946946022`}}]}, 
   {Hue[0.6574342037673567], AbsoluteThickness[0.5], 
    LineBox[{{4.70764611345942, -0.5730184513659031}, {
     4.738778916540884, -0.39604638420909954`}}]}, 
   {Hue[0.6579211859328445], AbsoluteThickness[0.5], 
    LineBox[{{4.738778916540884, -0.39604638420909954`}, {
     4.782519145789811, -0.08557373594640758}}]}, 
   {Hue[0.6701960038103446], AbsoluteThickness[0.5], 
    LineBox[{{4.585127898928671, 0.180206037201247}, {4.605463469554898, 
     0.22499760769273952`}}]}, 
   {Hue[0.6714992061090547], AbsoluteThickness[0.5], 
    LineBox[{{4.605463469554898, 0.22499760769273952`}, {4.715144946531152, 
     0.40867876489360544`}}]}, 
   {Hue[0.6106199876024905], AbsoluteThickness[0.5], 
    LineBox[{{2.1779574249714164`, -2.499116623971192}, {
     2.179925930006793, -2.5633858022752656`}}]}, 
   {Hue[0.6112898409847004], AbsoluteThickness[0.5], 
    LineBox[{{2.179925930006793, -2.5633858022752656`}, {
     2.208607427758521, -2.861293254471109}}]}, 
   {Hue[0.6652749146073065], AbsoluteThickness[0.5], 
    LineBox[{{3.063560221494452, -2.167307965963537}, {
     3.1960408896719756`, -2.5821602609180547`}}]}, 
   {Hue[0.6657031826845502], AbsoluteThickness[0.5], 
    LineBox[{{3.1960408896719756`, -2.5821602609180547`}, {
     3.2945611804798833`, -2.8983584553729904`}}]}, 
   {Hue[0.5267310261737537], AbsoluteThickness[0.5], 
    LineBox[{{3.7475481239844357`, -2.895688577383207}, {
     3.9214933364708435`, -2.9635820206121504`}}]}, 
   {Hue[0.5271963229755259], AbsoluteThickness[0.5], 
    LineBox[{{3.9214933364708435`, -2.9635820206121504`}, {
     4.170027974209632, -3.0685900421039163`}}]}, 
   {Hue[0.541710862630793], AbsoluteThickness[0.5], 
    LineBox[{{3.0979552348114527`, -2.6528065159336616`}, {
     2.9059651171970415`, -2.819553992134947}}]}, 
   {Hue[0.5477748909161617], AbsoluteThickness[0.5], 
    LineBox[{{2.9059651171970415`, -2.819553992134947}, {
     2.7223676682001012`, -2.920004077798222}}]}, 
   {Hue[0.37299119882970555`], AbsoluteThickness[0.5], 
    LineBox[{{3.096753592915335, -2.830849048264424}, {
     3.1046030695778013`, -2.858367870732684}}]}, 
   {Hue[0.3749610127240136], AbsoluteThickness[0.5], 
    LineBox[{{3.1046030695778013`, -2.858367870732684}, {
     3.1397138318901696`, -3.1092943360337797`}}]}, 
   {Hue[0.5722679212320602], AbsoluteThickness[0.5], 
    LineBox[{{3.257534113929122, -2.9073357224275256`}, {
     3.3331504839547654`, -2.919494121973757}}]}, 
   {Hue[0.5727021037510398], AbsoluteThickness[0.5], 
    LineBox[{{3.3331504839547654`, -2.919494121973757}, {
     3.6454506149446466`, -2.9738439926653393`}}]}, 
   {Hue[0.5495830123269464], AbsoluteThickness[0.5], 
    LineBox[{{2.5764440754740203`, -2.7242116310163853`}, {
     2.4188720144048537`, -2.7611183393223877`}}]}, 
   {Hue[0.5503583649391216], AbsoluteThickness[0.5], 
    LineBox[{{2.4188720144048537`, -2.7611183393223877`}, {
     2.132068257041967, -2.8054809508304213`}}]}, 
   {Hue[0.6932101789731787], AbsoluteThickness[0.5], 
    LineBox[{{4.636998230898286, -2.1091392321176685`}, {
     4.658777072803844, -2.1581856674111295`}}]}, 
   {Hue[0.6938406171431875], AbsoluteThickness[0.5], 
    LineBox[{{4.658777072803844, -2.1581856674111295`}, {
     4.782949065983467, -2.397720483839051}}]}, 
   {Hue[0.47355850283130135`], AbsoluteThickness[0.5], 
    LineBox[{{6.334093200644581, -2.3826157206719287`}, {
     6.381110233220679, -2.4013443145992484`}}]}, 
   {Hue[0.47398786486697453`], AbsoluteThickness[0.5], 
    LineBox[{{6.381110233220679, -2.4013443145992484`}, {
     6.702686771898657, -2.5263018619795266`}}]}, 
   {Hue[0.6664096341092242], AbsoluteThickness[0.5], 
    LineBox[{{5.150049919215277, 1.08116621558647}, {5.177336118799574, 
     1.085401957006159}}]}, 
   {Hue[0.6707203998856437], AbsoluteThickness[0.5], 
    LineBox[{{5.177336118799574, 1.085401957006159}, {5.376679783355897, 
     1.1569622305002074`}}]}, 
   {Hue[0.4686300746953932], AbsoluteThickness[0.5], 
    LineBox[{{3.3610820068575955`, 2.614000154795933}, {3.36240589717739, 
     2.6204723398224194`}}]}, 
   {Hue[0.4695342422014556], AbsoluteThickness[0.5], 
    LineBox[{{3.36240589717739, 2.6204723398224194`}, {3.393132125598578, 
     2.8884812846905206`}}]}, 
   {Hue[0.5772238828125571], AbsoluteThickness[0.5], 
    LineBox[{{4.8535427023504045`, 2.3605031245314656`}, {4.971645971724266, 
     2.4248461124836718`}}]}, 
   {Hue[0.5778685494015937], AbsoluteThickness[0.5], 
    LineBox[{{4.971645971724266, 2.4248461124836718`}, {5.185498344552433, 
     2.5592406364249785`}}]}, 
   {Hue[0.6366534297411026], AbsoluteThickness[0.5], 
    LineBox[{{4.37677651463605, 0.6266283101321687}, {4.425354604790293, 
     0.5297268463516591}}]}, 
   {Hue[0.6376517090004015], AbsoluteThickness[0.5], 
    LineBox[{{4.425354604790293, 0.5297268463516591}, {4.545082436945182, 
     0.3383877295897794}}]}, 
   {Hue[0.6908131105305704], AbsoluteThickness[0.5], 
    LineBox[{{3.3946744094985775`, -0.1707267178292357}, {
     3.391925748971242, -0.19010628348707892`}}]}, 
   {Hue[0.6922940622589959], AbsoluteThickness[0.5], 
    LineBox[{{3.391925748971242, -0.19010628348707892`}, {
     3.3287267644932, -0.4264155101671486}}]}, 
   {Hue[0.4480942463287901], AbsoluteThickness[0.5], 
    LineBox[{{6.658009207031597, 0.007931799029019734}, {6.921679151031007, 
     0.027944864807012266`}}]}, 
   {Hue[0.4485227981975446], AbsoluteThickness[0.5], 
    LineBox[{{6.921679151031007, 0.027944864807012266`}, {7.153508861361645, 
     0.047278897802333214`}}]}, 
   {Hue[0.5138878366820592], AbsoluteThickness[0.5], 
    LineBox[{{4.158659041478283, -3.3728156841394825`}, {
     4.159798710578394, -3.390024389540497}}]}, 
   {Hue[0.5178634274854432], AbsoluteThickness[0.5], 
    LineBox[{{4.159798710578394, -3.390024389540497}, {
     4.1384242233903406`, -3.5688021548918365`}}]}, 
   {Hue[0.5635594438907701], AbsoluteThickness[0.5], 
    LineBox[{{3.385155537038344, -3.4076008000197104`}, {
     3.399914627102696, -3.620595353636067}}]}, 
   {Hue[0.5648488487938387], AbsoluteThickness[0.5], 
    LineBox[{{3.399914627102696, -3.620595353636067}, {
     3.388278171736167, -3.8958529084869706`}}]}, 
   {Hue[0.5642656981160208], AbsoluteThickness[0.5], 
    LineBox[{{3.0927632679401023`, -1.3573781824534155`}, {
     3.084417851879482, -1.3622309027494566`}}]}, 
   {Hue[0.5650945232765309], AbsoluteThickness[0.5], 
    LineBox[{{3.084417851879482, -1.3622309027494566`}, {
     2.853115957234686, -1.5232593587173808`}}]}, 
   {Hue[0.5652192513091602], AbsoluteThickness[0.5], 
    LineBox[{{2.9312094990036774`, 1.1398332344078586`}, {2.917188626002788, 
     1.1453416915987837`}}]}, 
   {Hue[0.5656498648902901], AbsoluteThickness[0.5], 
    LineBox[{{2.917188626002788, 1.1453416915987837`}, {2.5928210776853198`, 
     1.2764604228296812`}}]}, 
   {Hue[0.48280969898746856`], AbsoluteThickness[0.5], 
    LineBox[{{5.127535395790679, 1.8724386251257839`}, {5.1272683121383205`, 
     1.8732876189014493`}}]}, 
   {Hue[0.48346093657575934`], AbsoluteThickness[0.5], 
    LineBox[{{5.1272683121383205`, 1.8732876189014493`}, {5.042157102366224, 
     2.0941287884800523`}}]}, 
   {Hue[0.5173329563920275], AbsoluteThickness[0.5], 
    LineBox[{{5.49129132604285, -0.7015811815232788}, {
     5.027030407564333, -1.313077799105559}}]}, 
   {Hue[0.5184237268118669], AbsoluteThickness[0.5], 
    LineBox[{{5.027030407564333, -1.313077799105559}, {
     4.905125729378626, -1.5123648390582447`}}]}, 
   {Hue[0.5732215041010621], AbsoluteThickness[0.5], 
    LineBox[{{5.992221850657239, -0.15089870761409435`}, {
     5.852792852761765, -0.1837763574250832}}]}, 
   {Hue[0.574195131669324], AbsoluteThickness[0.5], 
    LineBox[{{5.852792852761765, -0.1837763574250832}, {
     5.63754680200265, -0.2561349097010347}}]}, 
   {Hue[0.5625218494714629], AbsoluteThickness[0.5], 
    LineBox[{{6.607074278039562, 0.3145455153825057}, {6.39516881989554, 
     0.34370940324106264`}}]}, 
   {Hue[0.5631215258263558], AbsoluteThickness[0.5], 
    LineBox[{{6.39516881989554, 0.34370940324106264`}, {6.089936220661324, 
     0.3684093933369444}}]}, 
   {Hue[0.5644604078193883], AbsoluteThickness[0.5], 
    LineBox[{{7.582237084307932, 0.2227711079651515}, {7.306254591935352, 
     0.26210175652611545`}}]}, 
   {Hue[0.5653666267078926], AbsoluteThickness[0.5], 
    LineBox[{{7.306254591935352, 0.26210175652611545`}, {7.108184989612472, 
     0.272764367993269}}]}, 
   {Hue[0.01147412995669682], AbsoluteThickness[0.5], 
    LineBox[{{7.921537613865878, 0.22079455298073367`}, {8.064620880166169, 
     0.21870149092733096`}}]}, 
   {Hue[0.011899884898450286`], AbsoluteThickness[0.5], 
    LineBox[{{8.064620880166169, 0.21870149092733096`}, {8.382197538319517, 
     0.21424896194859802`}}]}, 
   {Hue[0.5666713478727178], AbsoluteThickness[0.5], 
    LineBox[{{8.382197538319517, 0.21424896194859802`}, {8.064672211011958, 
     0.22148949620949657`}}]}, 
   {Hue[0.5653197494821319], AbsoluteThickness[0.5], 
    LineBox[{{7.584716518663563, 0.1798030178225848}, {7.304846980143382, 
     0.14823982078343428`}}]}, 
   {Hue[0.5662159050263145], AbsoluteThickness[0.5], 
    LineBox[{{7.304846980143382, 0.14823982078343428`}, {7.10609724167968, 
     0.14320927168507647`}}]}, 
   {Hue[0.5729655605056437], AbsoluteThickness[0.5], 
    LineBox[{{6.933148401881306, 0.09646057320997259}, {
     6.711362086038876, -0.06985597601722168}}]}, 
   {Hue[0.5751019138431643], AbsoluteThickness[0.5], 
    LineBox[{{6.711362086038876, -0.06985597601722168}, {
     6.543616646454833, -0.23831446840583612`}}]}, 
   {Hue[0.5666534519160334], AbsoluteThickness[0.5], 
    LineBox[{{5.8288862326272355`, 0.4512466157806782}, {5.667261353323545, 
     0.4835172055030531}}]}, 
   {Hue[0.5670818758626938], AbsoluteThickness[0.5], 
    LineBox[{{5.667261353323545, 0.4835172055030531}, {5.3202913979563125`, 
     0.5501724962177167}}]}, 
   {Hue[0.5190476514846257], AbsoluteThickness[0.5], 
    LineBox[{{5.199950278683737, 2.392965765523268}, {5.170914492178902, 
     2.474848490124418}}]}, 
   {Hue[0.5202497433796957], AbsoluteThickness[0.5], 
    LineBox[{{5.170914492178902, 2.474848490124418}, {5.074791017464291, 
     2.675062659666707}}]}, 
   {Hue[0.5873795738064742], AbsoluteThickness[0.5], 
    LineBox[{{5.359614317133042, -1.391765475164945}, {
     5.326118249605564, -1.5583892920249665`}}]}, 
   {Hue[0.5878340162632278], AbsoluteThickness[0.5], 
    LineBox[{{5.326118249605564, -1.5583892920249665`}, {
     5.252347783747108, -1.8852261730103013`}}]}, 
   {Hue[0.5903923463786928], AbsoluteThickness[0.5], 
    LineBox[{{4.151868026960023, -0.3773117468062892}, {
     3.870709612005648, -0.296504522084487}}]}, 
   {Hue[0.590819566627727], AbsoluteThickness[0.5], 
    LineBox[{{3.870709612005648, -0.29650452208448697`}, {
     3.5435802907958855`, -0.20056608856929817`}}]}, 
   {Hue[0.6751631319542185], AbsoluteThickness[0.5], 
    LineBox[{{4.6953265593375875`, 0.8674399510744397}, {4.661295962718338, 
     0.9128173126012273}}]}, 
   {Hue[0.6756893053761379], AbsoluteThickness[0.5], 
    LineBox[{{4.661295962718338, 0.9128173126012273}, {4.445671154172447, 
     1.1757887914132055`}}]}, 
   {Hue[0.5836829543701636], AbsoluteThickness[0.5], 
    LineBox[{{3.3871360582173686`, -0.44300214135031607`}, {
     2.9320668264638527`, -0.7775306053711669}}]}, 
   {Hue[0.5846991922171081], AbsoluteThickness[0.5], 
    LineBox[{{2.9320668264638527`, -0.7775306053711669}, {
     2.725208535629809, -0.901041010762715}}]}, 
   {Hue[0.5685159354810506], AbsoluteThickness[0.5], 
    LineBox[{{3.591380863477616, 2.1302632880614265`}, {3.515552957934069, 
     2.3489265045569163`}}]}, 
   {Hue[0.5689440960340326], AbsoluteThickness[0.5], 
    LineBox[{{3.515552957934069, 2.3489265045569163`}, {3.413989583946645, 
     2.648475393853868}}]}, 
   {Hue[0.5644933316587194], AbsoluteThickness[0.5], 
    LineBox[{{2.622754223526307, -0.3075982666622284}, {
     2.426377366243477, -0.29919294938638963`}}]}, 
   {Hue[0.5649238239704089], AbsoluteThickness[0.5], 
    LineBox[{{2.426377366243477, -0.29919294938638963`}, {
     2.109959880802911, -0.2825813678668214}}]}, 
   {Hue[0.6068146691856692], AbsoluteThickness[0.5], 
    LineBox[{{5.187270329503395, 0.8990030806879106}, {5.151396980453808, 
     0.9234076708920554}}]}, 
   {Hue[0.6072498485242678], AbsoluteThickness[0.5], 
    LineBox[{{5.151396980453808, 0.9234076708920554}, {4.875287251962306, 
     1.105796215809494}}]}, 
   {Hue[0.3252522690062596], AbsoluteThickness[0.5], 
    LineBox[{{6.9340664185270295`, 0.8024390340462325}, {6.978293046308611, 
     0.8411875642283762}}]}, 
   {Hue[0.32610917966726755`], AbsoluteThickness[0.5], 
    LineBox[{{6.978293046308611, 0.8411875642283762}, {7.164988653108599, 
     1.0346971075157592`}}]}, 
   {Hue[0.6123272500388806], AbsoluteThickness[0.5], 
    LineBox[{{7.419914154845707, -0.7486637029729192}, {
     7.524991922598124, -0.8230880450004867}}]}, 
   {Hue[0.6139731386613977], AbsoluteThickness[0.5], 
    LineBox[{{7.524991922598124, -0.8230880450004867}, {
     7.70057827198202, -0.9845491140092091}}]}, 
   {Hue[0.5603031759315684], AbsoluteThickness[0.5], 
    LineBox[{{4.360158156711748, -0.6140657618613021}, {
     4.309825880534159, -0.6256695257545333}}]}, 
   {Hue[0.5651883235059583], AbsoluteThickness[0.5], 
    LineBox[{{4.309825880534159, -0.6256695257545333}, {
     4.134279919881224, -0.7053021782523812}}]}, 
   {Hue[0.48985925633964467`], AbsoluteThickness[0.5], 
    LineBox[{{6.568855167801231, 0.6174263452611388}, {6.47891313061962, 
     0.8589072396970899}}]}, 
   {Hue[0.4903497997452795], AbsoluteThickness[0.5], 
    LineBox[{{6.47891313061962, 0.8589072396970899}, {6.373795229262254, 
     1.1746088336009244`}}]}, 
   {Hue[0.5511651366227945], AbsoluteThickness[0.5], 
    LineBox[{{7.047251138791663, -0.7692447908416671}, {
     6.954909652835719, -0.8740451190435472}}]}, 
   {Hue[0.5522803351442933], AbsoluteThickness[0.5], 
    LineBox[{{6.954909652835719, -0.8740451190435472}, {
     6.816792275529389, -1.0673424449995488`}}]}, 
   {Hue[0.12628643239293358`], AbsoluteThickness[0.5], 
    LineBox[{{7.274855582689736, -0.9447428047327998}, {
     7.3884426023262675`, -1.0121691934008297`}}]}, 
   {Hue[0.1274826040215956], AbsoluteThickness[0.5], 
    LineBox[{{7.3884426023262675`, -1.0121691934008297`}, {
     7.619354980106846, -1.1178463161520402`}}]}, 
   {Hue[0.5779546154652422], AbsoluteThickness[0.5], 
    LineBox[{{7.619354980106846, -1.1178463161520402`}, {
     7.652132399103486, -0.8660253057315965}}]}, 
   {Hue[0.5541595841457444], AbsoluteThickness[0.5], 
    LineBox[{{7.405088008018428, -0.68853419606617}, {
     7.428705157216245, -0.6236596986221365}}]}, 
   {Hue[0.554585834634833], AbsoluteThickness[0.5], 
    LineBox[{{7.428705157216245, -0.6236596986221365}, {
     7.531818170287938, -0.3375845677858367}}]}, 
   {Hue[0.6650340626010691], AbsoluteThickness[0.5], 
    LineBox[{{7.331432026539258, -0.5235769144612856}, {
     6.8596625734269665`, -0.687546041497782}}]}, 
   {Hue[0.6657434235921013], AbsoluteThickness[0.5], 
    LineBox[{{6.8596625734269665`, -0.687546041497782}, {
     6.6198885477207385`, -0.7901631905955421}}]}, 
   {Hue[0.11139731240221304`], AbsoluteThickness[0.5], 
    LineBox[{{7.625251836471496, -0.44562936544109266`}, {
     8.114315363349343, -0.31333269510986894`}}]}, 
   {Hue[0.11185583281178212`], AbsoluteThickness[0.5], 
    LineBox[{{8.114315363349343, -0.31333269510986894`}, {
     8.436859022371637, -0.21729711559681503`}}]}, 
   {Hue[0.6591303626315547], AbsoluteThickness[0.5], 
    LineBox[{{8.436859022371637, -0.21729711559681503`}, {
     8.101141691585351, -0.19382120629324912`}}]}, 
   {Hue[0.6658879405002484], AbsoluteThickness[0.5], 
    LineBox[{{7.326681774497503, -0.50274170386037}, {
     7.091454236238349, -0.5489261620671531}}]}, 
   {Hue[0.6674332340809163], AbsoluteThickness[0.5], 
    LineBox[{{7.091454236238349, -0.5489261620671531}, {
     6.839485511703017, -0.5667677846538254}}]}, 
   {Hue[0.21510723055170328`], AbsoluteThickness[0.5], 
    LineBox[{{7.237436178702556, -0.1331905586621232}, {7.41243410083308, 
     0.2875126681804459}}]}, 
   {Hue[0.21554184043887314`], AbsoluteThickness[0.5], 
    LineBox[{{7.41243410083308, 0.2875126681804459}, {7.547538327762724, 
     0.6247962430662376}}]}, 
   {Hue[0.536761824652817], AbsoluteThickness[0.5], 
    LineBox[{{6.670298616074795, 0.09799194837375624}, {6.645278857986541, 
     0.10289562315684021`}}]}, 
   {Hue[0.5376458083521785], AbsoluteThickness[0.5], 
    LineBox[{{6.645278857986541, 0.10289562315684021`}, {6.372021675903593, 
     0.13238409920163033`}}]}, 
   {Hue[0.3419813249078683], AbsoluteThickness[0.5], 
    LineBox[{{6.588640046746528, 0.25452800161188044`}, {6.551953831481576, 
     0.4240430708894138}}]}, 
   {Hue[0.3425933503542005], AbsoluteThickness[0.5], 
    LineBox[{{6.551953831481576, 0.4240430708894138}, {6.486355752910804, 
     0.660196213855839}}]}, 
   {Hue[0.5614472586848419], AbsoluteThickness[0.5], 
    LineBox[{{6.70010912973207, 0.3914451351141221}, {6.844539518929539, 
     0.494512176608419}}]}, 
   {Hue[0.5632902279042378], AbsoluteThickness[0.5], 
    LineBox[{{6.844539518929539, 0.494512176608419}, {7.054642597348615, 
     0.6053018194401824}}]}, 
   {Hue[0.4225553803975829], AbsoluteThickness[0.5], 
    LineBox[{{6.580784619648193, -0.33943437615787486`}, {
     6.368422368312877, -0.345656036402722}}]}, 
   {Hue[0.4231616084554448], AbsoluteThickness[0.5], 
    LineBox[{{6.368422368312877, -0.345656036402722}, {
     6.060392843487193, -0.3371234386571548}}]}, 
   {Hue[0.526111112596459], AbsoluteThickness[0.5], 
    LineBox[{{6.6583235910616, -0.8970555104361322}, {
     6.655359383722886, -0.9188906085702385}}]}, 
   {Hue[0.5291467947082754], AbsoluteThickness[0.5], 
    LineBox[{{6.655359383722886, -0.9188906085702385}, {
     6.5922612783590395`, -1.1214510933541992`}}]}, 
   {Hue[0.6426635522036457], AbsoluteThickness[0.5], 
    LineBox[{{7.231723758310917, -0.9493054182367564}, {
     7.389492981479547, -1.0168340999199963`}}]}, 
   {Hue[0.6435724038684827], AbsoluteThickness[0.5], 
    LineBox[{{7.389492981479547, -1.0168340999199963`}, {
     7.644668080063981, -1.1003916668096594`}}]}, 
   {Hue[0.4960030337037076], AbsoluteThickness[0.5], 
    LineBox[{{5.6050158203060105`, -1.2402184750410594`}, {
     5.407006009017045, -1.2899781463952928`}}]}, 
   {Hue[0.4964908844707003], AbsoluteThickness[0.5], 
    LineBox[{{5.407006009017045, -1.2899781463952928`}, {
     5.136569387834561, -1.3481263393754064`}}]}, 
   {Hue[0.5617408515086828], AbsoluteThickness[0.5], 
    LineBox[{{5.3361431345765595`, 0.5913632073700996}, {5.302840728556142, 
     0.6184264711166763}}]}, 
   {Hue[0.5623737059616677], AbsoluteThickness[0.5], 
    LineBox[{{5.302840728556142, 0.6184264711166763}, {5.09764295044793, 
     0.8069563336040951}}]}, 
   {Hue[0.3297169033645273], AbsoluteThickness[0.5], 
    LineBox[{{5.650917631972628, -1.8422377313187681`}, {
     5.649877445151607, -1.8841143747183111`}}]}, 
   {Hue[0.3343258523032618], AbsoluteThickness[0.5], 
    LineBox[{{5.649877445151607, -1.8841143747183111`}, {
     5.603119379416055, -2.093129075304882}}]}, 
   {Hue[0.6498036593994835], AbsoluteThickness[0.5], 
    LineBox[{{5.603119379416055, -2.093129075304882}, {
     5.388956161530407, -2.0903762808177735`}}]}, 
   {Hue[0.6282344777378055], AbsoluteThickness[0.5], 
    LineBox[{{4.130008610497084, -0.8361472547711477}, {
     4.063943350889782, -0.8569416972857944}}]}, 
   {Hue[0.6304033473930938], AbsoluteThickness[0.5], 
    LineBox[{{4.063943350889782, -0.8569416972857944}, {
     3.855931511382925, -0.9574232958730357}}]}, 
   {Hue[0.5654976509721549], AbsoluteThickness[0.5], 
    LineBox[{{2.614163523778884, -0.22471450999179662`}, {
     2.4182448310438884`, -0.22624172498988013`}}]}, 
   {Hue[0.5660185888427676], AbsoluteThickness[0.5], 
    LineBox[{{2.4182448310438884`, -0.22624172498988013`}, {
     2.1146467287569317`, -0.24144351625385335`}}]}, 
   {Hue[0.6563531075436968], AbsoluteThickness[0.5], 
    LineBox[{{2.881737090212462, 2.092805913949266}, {2.9618721634561296`, 
     2.3246186922607284`}}]}, 
   {Hue[0.6567793730153767], AbsoluteThickness[0.5], 
    LineBox[{{2.9618721634561296`, 2.3246186922607284`}, {3.0856647969255224`,
      2.6790102014619053`}}]}, 
   {Hue[0.49607788992562335`], AbsoluteThickness[0.5], 
    LineBox[{{3.3995055904530043`, -2.636188301325462}, {
     3.3947316024082386`, -2.6909189070382675`}}]}, 
   {Hue[0.5032045994653446], AbsoluteThickness[0.5], 
    LineBox[{{3.3947316024082386`, -2.6909189070382675`}, {
     3.334437716689853, -2.877104597143399}}]}, 
   {Hue[0.5733512776489312], AbsoluteThickness[0.5], 
    LineBox[{{3.151431641888265, -2.2714605875411995`}, {
     3.1012223674970163`, -2.3685419072028107`}}]}, 
   {Hue[0.573876009912325], AbsoluteThickness[0.5], 
    LineBox[{{3.1012223674970163`, -2.3685419072028107`}, {
     2.9366521158743493`, -2.65574954324112}}]}, 
   {Hue[0.5565612992314249], AbsoluteThickness[0.5], 
    LineBox[{{3.6765229598425995`, 0.9232911848113989}, {3.6678868086100143`, 
     0.9249466491803073}}]}, 
   {Hue[0.5571506020874912], AbsoluteThickness[0.5], 
    LineBox[{{3.6678868086100143`, 0.9249466491803073}, {3.3835902858217612`, 
     0.9956791318545444}}]}, 
   {Hue[0.5393636419334719], AbsoluteThickness[0.5], 
    LineBox[{{5.625084372092422, 1.3630723316337565`}, {5.6354124765762235`, 
     1.454183630932477}}]}, 
   {Hue[0.5414634612565753], AbsoluteThickness[0.5], 
    LineBox[{{5.6354124765762235`, 1.454183630932477}, {5.630120900243981, 
     1.6299670195362055`}}]}, 
   {Hue[0.5535752185301617], AbsoluteThickness[0.5], 
    LineBox[{{5.833932766430492, 0.6239058158992945}, {5.827538219754784, 
     0.6317439401075853}}]}, 
   {Hue[0.5540587833150955], AbsoluteThickness[0.5], 
    LineBox[{{5.827538219754784, 0.6317439401075853}, {5.648999733444483, 
     0.8660752230173452}}]}, 
   {Hue[0.5378304791594718], AbsoluteThickness[0.5], 
    LineBox[{{6.556519117282773, -0.299083403721486}, {
     6.230502784303588, -0.6144111025568006}}]}, 
   {Hue[0.5394981230118358], AbsoluteThickness[0.5], 
    LineBox[{{6.230502784303588, -0.6144111025568006}, {
     6.086873768027755, -0.7942341793969764}}]}, 
   {Hue[0.5669755532578583], AbsoluteThickness[0.5], 
    LineBox[{{7.376184534640388, -0.021901606971034132`}, {7.153528443089851, 
     0.04653381958580968}}]}, 
   {Hue[0.5674872040108522], AbsoluteThickness[0.5], 
    LineBox[{{7.153528443089851, 0.04653381958580968}, {6.93710557949533, 
     0.10363846861624737`}}]}, 
   {Hue[0.015728456256190803`], AbsoluteThickness[0.5], 
    LineBox[{{7.665395403713867, -0.04190837758023675}, {
     7.853392189340278, -0.057731229564030526`}}]}, 
   {Hue[0.016264590612853923`], AbsoluteThickness[0.5], 
    LineBox[{{7.853392189340278, -0.057731229564030526`}, {
     8.155250926625996, -0.06940656844503204}}]}, 
   {Hue[0.5477306270703501], AbsoluteThickness[0.5], 
    LineBox[{{8.155250926625996, -0.06940656844503204}, {7.917834223081918, 
     0.11737758423387704`}}]}, 
   {Hue[0.567849674703564], AbsoluteThickness[0.5], 
    LineBox[{{7.378542320629571, -0.08384292640910168}, {
     6.852025153601197, -0.15281730055393547`}}]}, 
   {Hue[0.5684091634258505], AbsoluteThickness[0.5], 
    LineBox[{{6.852025153601197, -0.15281730055393547`}, {
     6.545723155960326, -0.20850682246037056`}}]}, 
   {Hue[0.5406194155908483], AbsoluteThickness[0.5], 
    LineBox[{{6.711169099433256, 0.3945024455774354}, {6.589314903173201, 
     0.4698892987223492}}]}, 
   {Hue[0.5410520102783856], AbsoluteThickness[0.5], 
    LineBox[{{6.589314903173201, 0.4698892987223492}, {6.36304839370805, 
     0.6062653595749425}}]}, 
   {Hue[0.5731656989050037], AbsoluteThickness[0.5], 
    LineBox[{{5.820255949106423, -0.48858284303473215`}, {
     5.785588399370819, -0.5711879300760457}}]}, 
   {Hue[0.5736472664088464], AbsoluteThickness[0.5], 
    LineBox[{{5.785588399370819, -0.5711879300760457}, {
     5.680424676690819, -0.8466646712201136}}]}, 
   {Hue[0.500715201449932], AbsoluteThickness[0.5], 
    LineBox[{{5.6337905741186995`, -1.2999852137950616`}, {
     5.632079041417458, -1.38178150764621}}]}, 
   {Hue[0.5015548210419379], AbsoluteThickness[0.5], 
    LineBox[{{5.632079041417458, -1.38178150764621}, {
     5.6038834307540535`, -1.6537191819558945`}}]}, 
   {Hue[0.554329952513126], AbsoluteThickness[0.5], 
    LineBox[{{4.424173611960548, -1.094570091895105}, {
     4.394737187714038, -1.1351006498188552`}}]}, 
   {Hue[0.5549159709530535], AbsoluteThickness[0.5], 
    LineBox[{{4.394737187714038, -1.1351006498188552`}, {
     4.205381702818821, -1.368260993376091}}]}, 
   {Hue[0.5874808666079282], AbsoluteThickness[0.5], 
    LineBox[{{3.299535040210844, 0.037783065568218414`}, {3.194416006151179, 
     0.009785795479887893}}]}, 
   {Hue[0.5879122659044081], AbsoluteThickness[0.5], 
    LineBox[{{3.194416006151179, 0.009785795479887893}, {
     2.8832770731809365`, -0.07660942884350001}}]}, 
   {Hue[0.6848455107024484], AbsoluteThickness[0.5], 
    LineBox[{{2.8804921609870364`, 2.7870097354207974`}, {2.8884939147208075`,
      3.0133181906001587`}}]}, 
   {Hue[0.5287152533746888], AbsoluteThickness[0.5], 
    LineBox[{{2.762849233458325, 2.903008534409641}, {2.6188510478346263`, 
     2.979015479498398}}]}, 
   {Hue[0.5293505276988681], AbsoluteThickness[0.5], 
    LineBox[{{2.6188510478346263`, 2.979015479498398}, {2.3535659318525837`, 
     3.098971023063012}}]}, 
   {Hue[0.5568974397140513], AbsoluteThickness[0.5], 
    LineBox[{{2.2281201940078454`, 1.89257377653644}, {2.138542806022979, 
     1.9664354350672955`}}]}, 
   {Hue[0.5573359291570114], AbsoluteThickness[0.5], 
    LineBox[{{2.138542806022979, 1.9664354350672955`}, {1.9180050689671857`, 
     2.1425003823834583`}}]}, 
   {Hue[0.5273007700351298], AbsoluteThickness[0.5], 
    LineBox[{{2.1233083744543126`, -1.7328768819654647`}, {
     2.0877255889465727`, -1.7913794124426747`}}]}, 
   {Hue[0.5277503754349872], AbsoluteThickness[0.5], 
    LineBox[{{2.0877255889465727`, -1.7913794124426747`}, {
     1.919184824223381, -2.082431313001163}}]}, 
   {Hue[0.6380386332671177], AbsoluteThickness[0.5], 
    LineBox[{{3.363831360862437, -1.8492813491459832`}, {
     3.329063053662368, -2.058235811526472}}]}, 
   {Hue[0.6384793434403244], AbsoluteThickness[0.5], 
    LineBox[{{3.329063053662368, -2.058235811526472}, {
     3.275170746944, -2.35107506194573}}]}, 
   {Hue[0.6182294998547446], AbsoluteThickness[0.5], 
    LineBox[{{2.6125442720845693`, 1.3178554042208324`}, {2.567150187468464, 
     1.3380946935344948`}}]}, 
   {Hue[0.6191096667000869], AbsoluteThickness[0.5], 
    LineBox[{{2.5671501874684637`, 1.3380946935344948`}, {2.3096873381154195`,
      1.4804703639468886`}}]}, 
   {Hue[0.6840423340552935], AbsoluteThickness[0.5], 
    LineBox[{{4.206355265611557, 2.4112220048845603`}, {4.189401318201478, 
     2.4777975051477337`}}]}, 
   {Hue[0.6897982033857398], AbsoluteThickness[0.5], 
    LineBox[{{4.189401318201478, 2.4777975051477337`}, {4.097753882116313, 
     2.6627006355976346`}}]}, 
   {Hue[0.2315958078077378], AbsoluteThickness[0.5], 
    LineBox[{{6.617216360486333, -1.103440813219886}, {
     6.680968846800999, -1.1889146534065755`}}]}, 
   {Hue[0.23203002479188978`], AbsoluteThickness[0.5], 
    LineBox[{{6.680968846800999, -1.1889146534065755`}, {
     6.854859612651246, -1.4158809044572065`}}]}, 
   {Hue[0.6982751634495634], AbsoluteThickness[0.5], 
    LineBox[{{5.872944468098668, -0.983138323159591}, {
     5.646826523332288, -1.071133640981482}}]}, 
   {Hue[0.6992014698364668], AbsoluteThickness[0.5], 
    LineBox[{{5.646826523332288, -1.071133640981482}, {
     5.387570549266287, -1.1461960392745785`}}]}, 
   {Hue[0.5823509596053313], AbsoluteThickness[0.5], 
    LineBox[{{4.438382574062238, 0.5522306874715751}, {4.158230330618155, 
     0.5832009083599954}}]}, 
   {Hue[0.582874995077631], AbsoluteThickness[0.5], 
    LineBox[{{4.158230330618155, 0.5832009083599954}, {3.8428988406362716`, 
     0.6044286511249765}}]}, 
   {Hue[0.5681408737963551], AbsoluteThickness[0.5], 
    LineBox[{{5.117142692425293, 0.8447991803608269}, {5.058644728216683, 
     0.8438897851774761}}]}, 
   {Hue[0.5802809066630502], AbsoluteThickness[0.5], 
    LineBox[{{5.058644728216683, 0.8438897851774761}, {4.881230150565236, 
     0.8893525885189948}}]}, 
   {Hue[0.36128934986288774`], AbsoluteThickness[0.5], 
    LineBox[{{6.884034215623186, 0.6097740896126957}, {6.918480506580063, 
     0.5926788258253725}}]}, 
   {Hue[0.36207314411442476`], AbsoluteThickness[0.5], 
    LineBox[{{6.918480506580063, 0.5926788258253725}, {7.160383146799558, 
     0.44830521292346964`}}]}, 
   {Hue[0.46785991643008257`], AbsoluteThickness[0.5], 
    LineBox[{{6.740235285145381, 1.108447458216327}, {6.859778358838186, 
     1.0131255677531301`}}]}, 
   {Hue[0.46858945287809], AbsoluteThickness[0.5], 
    LineBox[{{6.859778358838186, 1.0131255677531301`}, {7.08910715380312, 
     0.8558616229079116}}]}, 
   {Hue[0.044689231643382385`], AbsoluteThickness[0.5], 
    LineBox[{{6.884812681670207, 1.312480342715655}, {6.923585226531508, 
     1.384430231900378}}]}, 
   {Hue[0.04516265694721942], AbsoluteThickness[0.5], 
    LineBox[{{6.923585226531508, 1.384430231900378}, {7.043024463711233, 
     1.623098242003608}}]}, 
   {Hue[0.5892028907454069], AbsoluteThickness[0.5], 
    LineBox[{{7.043024463711233, 1.623098242003608}, {6.835134065659889, 
     1.4557371568530757`}}]}, 
   {Hue[0.47090413944301845`], AbsoluteThickness[0.5], 
    LineBox[{{6.658311462265483, 1.4184484471206409`}, {6.638295502307215, 
     1.4249792929059466`}}]}, 
   {Hue[0.4713632666549661], AbsoluteThickness[0.5], 
    LineBox[{{6.638295502307215, 1.4249792929059466`}, {6.342768709801086, 
     1.5297899636793373`}}]}, 
   {Hue[0.3713726739723142], AbsoluteThickness[0.5], 
    LineBox[{{6.118381507736386, 1.7772714597820631`}, {6.09295264477291, 
     1.835262990529705}}]}, 
   {Hue[0.3717985127132653], AbsoluteThickness[0.5], 
    LineBox[{{6.09295264477291, 1.835262990529705}, {5.952148635015081, 
     2.15513423952321}}]}, 
   {Hue[0.6960011564890681], AbsoluteThickness[0.5], 
    LineBox[{{5.8884647147814535`, 0.8942694870676567}, {5.867660392123844, 
     0.8827607497484701}}]}, 
   {Hue[0.6965193720694975], AbsoluteThickness[0.5], 
    LineBox[{{5.867660392123844, 0.8827607497484701}, {5.619785094200908, 
     0.7318271963025047}}]}, 
   {Hue[0.5699462228934804], AbsoluteThickness[0.5], 
    LineBox[{{5.984355056188853, -0.14921037953537808`}, {
     5.919440170879919, -0.35509462386936186`}}]}, 
   {Hue[0.5707263506709411], AbsoluteThickness[0.5], 
    LineBox[{{5.919440170879919, -0.35509462386936186`}, {
     5.865621530831638, -0.5866494900579388}}]}, 
   {Hue[0.580902353034465], AbsoluteThickness[0.5], 
    LineBox[{{5.152637510081604, -0.32774920781132155`}, {
     5.0778250151962165`, -0.38238870893449306`}}]}, 
   {Hue[0.5815016169891808], AbsoluteThickness[0.5], 
    LineBox[{{5.0778250151962165`, -0.38238870893449306`}, {
     4.859288194084859, -0.5615708727200162}}]}, 
   {Hue[0.6149633922822083], AbsoluteThickness[0.5], 
    LineBox[{{4.886921392254257, 1.3728332114621355`}, {4.6648380633273865`, 
     1.4618966382192495`}}]}, 
   {Hue[0.6155494497834867], AbsoluteThickness[0.5], 
    LineBox[{{4.6648380633273865`, 1.4618966382192495`}, {4.432049029638953, 
     1.5409692291594008`}}]}, 
   {Hue[0.38283860692347066`], AbsoluteThickness[0.5], 
    LineBox[{{4.845676480993952, 1.5615731203059107`}, {4.84738733291554, 
     1.6224025247299223`}}]}, 
   {Hue[0.38647111712986093`], AbsoluteThickness[0.5], 
    LineBox[{{4.84738733291554, 1.6224025247299223`}, {4.816965700845403, 
     1.8224660042968313`}}]}, 
   {Hue[0.6329173793696744], AbsoluteThickness[0.5], 
    LineBox[{{5.008490448504686, 1.665570754310925}, {5.096457546179576, 
     1.695227060697871}}]}, 
   {Hue[0.6334008263835721], AbsoluteThickness[0.5], 
    LineBox[{{5.096457546179576, 1.695227060697871}, {5.332743116346129, 
     1.7837260496438638`}}]}, 
   {Hue[0.6474233136445866], AbsoluteThickness[0.5], 
    LineBox[{{5.863320507914815, 1.5301046893547892`}, {5.8097074882255475`, 
     1.6481958356080768`}}]}, 
   {Hue[0.6481050571763327], AbsoluteThickness[0.5], 
    LineBox[{{5.8097074882255475`, 1.6481958356080768`}, {5.705553518259504, 
     1.8420885461279697`}}]}, 
   {Hue[0.34470829426620103`], AbsoluteThickness[0.5], 
    LineBox[{{5.994643541699184, 1.676407225241591}, {6.114863826484781, 
     1.7662512258584027`}}]}, 
   {Hue[0.34686897053219534`], AbsoluteThickness[0.5], 
    LineBox[{{6.114863826484781, 1.7662512258584027`}, {6.316102591298726, 
     1.8753983615424614`}}]}, 
   {Hue[0.6569476836992091], AbsoluteThickness[0.5], 
    LineBox[{{6.165654880057569, 1.5794263335045395`}, {6.569633618390602, 
     1.2298058870980035`}}]}, 
   {Hue[0.6596370014881919], AbsoluteThickness[0.5], 
    LineBox[{{6.569633618390602, 1.2298058870980035`}, {6.760855510741436, 
     1.1114263012140602`}}]}, 
   {Hue[0.4484527787925966], AbsoluteThickness[0.5], 
    LineBox[{{6.930740076554839, 0.8108765891669804}, {7.101978904717851, 
     0.8087933978937691}}]}, 
   {Hue[0.44888148293122326`], AbsoluteThickness[0.5], 
    LineBox[{{7.101978904717851, 0.8087933978937691}, {7.413626211545165, 
     0.8026183772118229}}]}, 
   {Hue[0.5651713204470733], AbsoluteThickness[0.5], 
    LineBox[{{6.5406831974877795`, -0.7102179869740982}, {
     6.623760346531092, -0.7639764148780857}}]}, 
   {Hue[0.5656922811957267], AbsoluteThickness[0.5], 
    LineBox[{{6.623760346531092, -0.7639764148780857}, {
     6.863820121383281, -0.905305332431093}}]}, 
   {Hue[0.6749289523165197], AbsoluteThickness[0.5], 
    LineBox[{{5.125415144913388, -0.8841962275164095}, {
     5.125379655519111, -0.8843017445566536}}]}, 
   {Hue[0.6754485964795204], AbsoluteThickness[0.5], 
    LineBox[{{5.125379655519111, -0.8843017445566536}, {
     5.023689501919517, -1.149297355242544}}]}, 
   {Hue[0.4985609193491393], AbsoluteThickness[0.5], 
    LineBox[{{4.203576005412313, 1.4199855581134393`}, {4.161363715889605, 
     1.5272745324007335`}}]}, 
   {Hue[0.5411911831670049], AbsoluteThickness[0.5], 
    LineBox[{{4.161363715889605, 1.5272745324007335`}, {4.061493392925861, 
     1.6355256124272228`}}]}, 
   {Hue[0.6495088584318681], AbsoluteThickness[0.5], 
    LineBox[{{4.061493392925861, 1.6355256124272228`}, {3.9174558718880723`, 
     1.6047754861010994`}}]}, 
   {Hue[0.5443051287448045], AbsoluteThickness[0.5], 
    LineBox[{{3.731131227648466, -1.3970354950296164`}, {
     3.6863645789762614`, -1.4572555582956506`}}]}, 
   {Hue[0.5453001366437408], AbsoluteThickness[0.5], 
    LineBox[{{3.6863645789762614`, -1.4572555582956506`}, {
     3.49572223780299, -1.6688055850099464`}}]}, 
   {Hue[0.5285104120604069], AbsoluteThickness[0.5], 
    LineBox[{{2.2547892872798143`, 1.9025457792927671`}, {2.1572377053334204`,
      2.012808042133223}}]}, 
   {Hue[0.5294174081774181], AbsoluteThickness[0.5], 
    LineBox[{{2.1572377053334204`, 2.012808042133223}, {1.9817586770943016`, 
     2.1791415740487627`}}]}, 
   {Hue[0.6547644454576703], AbsoluteThickness[0.5], 
    LineBox[{{5.170094767464559, 1.5098442027278975`}, {5.270689602738074, 
     1.4038925722977584`}}]}, 
   {Hue[0.6576417069511922], AbsoluteThickness[0.5], 
    LineBox[{{5.270689602738074, 1.4038925722977584`}, {5.397977320594125, 
     1.2162146887117604`}}]}, 
   {Hue[0.5958572404202475], AbsoluteThickness[0.5], 
    LineBox[{{5.9020523769772115`, 0.703151117335844}, {5.938824013055946, 
     0.6844398831084526}}]}, 
   {Hue[0.5987877271815225], AbsoluteThickness[0.5], 
    LineBox[{{5.938824013055946, 0.6844398831084526}, {6.104549679442639, 
     0.562226095591961}}]}, 
   {Hue[0.22735139037919172`], AbsoluteThickness[0.5], 
    LineBox[{{5.767975194850903, 1.8284378160510175`}, {5.847842256073196, 
     1.9702383832908335`}}]}, 
   {Hue[0.22954834704002158`], AbsoluteThickness[0.5], 
    LineBox[{{5.847842256073196, 1.9702383832908335`}, {6.00103433816739, 
     2.1680960143317805`}}]}, 
   {Hue[0.6189111011653153], AbsoluteThickness[0.5], 
    LineBox[{{6.00103433816739, 2.1680960143317805`}, {6.194973486697652, 
     2.009972446054161}}]}, 
   {Hue[0.6010855756360907], AbsoluteThickness[0.5], 
    LineBox[{{4.601124041665893, 1.8071508805746772`}, {4.580358864978631, 
     1.8177291014349504`}}]}, 
   {Hue[0.6026665048018904], AbsoluteThickness[0.5], 
    LineBox[{{4.580358864978631, 1.8177291014349504`}, {4.376677541611813, 
     1.955825988121902}}]}, 
   {Hue[0.5034515970426325], AbsoluteThickness[0.5], 
    LineBox[{{3.9811237150976506`, -2.647292914116017}, {
     4.12306646405391, -2.9348914861190902`}}]}, 
   {Hue[0.509989021080639], AbsoluteThickness[0.5], 
    LineBox[{{4.12306646405391, -2.9348914861190902`}, {
     4.16190678633962, -3.094605185222496}}]}, 
   {Hue[0.6715969161621796], AbsoluteThickness[0.5], 
    LineBox[{{2.811514271687862, 0.8741671093533059}, {2.4077963546482186`, 
     1.3316290382385152`}}]}, 
   {Hue[0.67871006733965], AbsoluteThickness[0.5], 
    LineBox[{{2.4077963546482186`, 1.3316290382385152`}, {2.311117948387541, 
     1.5098506513105614`}}]}, 
   {Hue[0.5876710284504623], AbsoluteThickness[0.5], 
    LineBox[{{3.658635096782899, -2.2527279496753203`}, {
     3.6556373114209566`, -2.4931348620462384`}}]}, 
   {Hue[0.6130888399336156], AbsoluteThickness[0.5], 
    LineBox[{{3.6556373114209566`, -2.4931348620462384`}, {
     3.6031581148806473`, -2.6419793554143336`}}]}, 
   {Hue[0.6600663292731145], AbsoluteThickness[0.5], 
    LineBox[{{3.2980096486091233`, 0.03355208865461687}, {2.904934390723699, 
     0.1889641153331204}}]}, 
   {Hue[0.6604968156966206], AbsoluteThickness[0.5], 
    LineBox[{{2.904934390723699, 0.1889641153331204}, {2.574441327653942, 
     0.3159516341114863}}]}, 
   {Hue[0.6638491235991959], AbsoluteThickness[0.5], 
    LineBox[{{4.342554262668123, -0.5477632918580002}, {
     4.131895304527277, -0.49352764015586553`}}]}, 
   {Hue[0.6643249903484261], AbsoluteThickness[0.5], 
    LineBox[{{4.131895304527277, -0.49352764015586553`}, {
     3.8407227659974126`, -0.42811834502949636`}}]}, 
   {Hue[0.48949385521033256`], AbsoluteThickness[0.5], 
    LineBox[{{5.746437075150045, -1.3612129173120575`}, {
     5.794703921812166, -1.5767365376454026`}}]}, 
   {Hue[0.49007505803645574`], AbsoluteThickness[0.5], 
    LineBox[{{5.794703921812166, -1.5767365376454026`}, {
     5.843853134092717, -1.8680757517200894`}}]}, 
   {Hue[0.6668028351047742], AbsoluteThickness[0.5], 
    LineBox[{{6.08832949528107, -0.8012782666559674}, {
     5.633900585214751, -0.9520456545211144}}]}, 
   {Hue[0.6672518032439598], AbsoluteThickness[0.5], 
    LineBox[{{5.633900585214751, -0.9520456545211144}, {
     5.337331765095499, -1.0574923060641015`}}]}, 
   {Hue[0.11443222845017095`], AbsoluteThickness[0.5], 
    LineBox[{{6.389303826403369, -0.7571104548669387}, {
     6.644688666771838, -0.71667040456841}}]}, 
   {Hue[0.11566548402913165`], AbsoluteThickness[0.5], 
    LineBox[{{6.644688666771838, -0.71667040456841}, {
     6.877243573350921, -0.7053760519435339}}]}, 
   {Hue[0.5630620092665914], AbsoluteThickness[0.5], 
    LineBox[{{6.877243573350921, -0.7053760519435339}, {
     6.823064262317305, -0.9318135692217979}}]}, 
   {Hue[0.6676673802096812], AbsoluteThickness[0.5], 
    LineBox[{{6.085153021935675, -0.7517595919084489}, {
     5.913953233248015, -0.7506887440582566}}]}, 
   {Hue[0.6681209006280178], AbsoluteThickness[0.5], 
    LineBox[{{5.913953233248015, -0.7506887440582566}, {
     5.615337731456239, -0.7418814461021419}}]}, 
   {Hue[0.49603293239046437`], AbsoluteThickness[0.5], 
    LineBox[{{5.870742468842931, -0.3800593202050162}, {
     5.870919416803717, -0.3783788533341169}}]}, 
   {Hue[0.4986513286454301], AbsoluteThickness[0.5], 
    LineBox[{{5.870919416803717, -0.3783788533341169}, {
     5.86108654714832, -0.19092774276253627`}}]}, 
   {Hue[0.6646811210008141], AbsoluteThickness[0.5], 
    LineBox[{{4.1337574383450395`, -0.7063389609053039}, {
     3.9385629154008903`, -0.7080705838406547}}]}, 
   {Hue[0.6651232329673464], AbsoluteThickness[0.5], 
    LineBox[{{3.9385629154008903`, -0.7080705838406547}, {
     3.635416973861742, -0.7161856778330311}}]}, 
   {Hue[0.676440017663643], AbsoluteThickness[0.5], 
    LineBox[{{3.4537259624844996`, -0.8191926370733296}, {
     3.3676045350525445`, -0.8319830220373302}}]}, 
   {Hue[0.6770434434601893], AbsoluteThickness[0.5], 
    LineBox[{{3.3676045350525445`, -0.8319830220373302}, {
     3.072047963040112, -0.8589125605820825}}]}, 
   {Hue[0.5536522923409214], AbsoluteThickness[0.5], 
    LineBox[{{4.778917222020252, 0.8719208358525892}, {4.851768790063694, 
     1.2255517907296583`}}]}, 
   {Hue[0.5678838726523477], AbsoluteThickness[0.5], 
    LineBox[{{4.851768790063694, 1.2255517907296583`}, {4.84097892522051, 
     1.367685994691264}}]}, 
   {Hue[0.4994600200141077], AbsoluteThickness[0.5], 
    LineBox[{{4.769874076981561, 2.41357687793816}, {4.7925997236708975`, 
     2.620541101588686}}]}, 
   {Hue[0.5000064968759206], AbsoluteThickness[0.5], 
    LineBox[{{4.7925997236708975`, 2.620541101588686}, {4.811182674721449, 
     2.9193828574586274`}}]}, 
   {Hue[0.6869682359970503], AbsoluteThickness[0.5], 
    LineBox[{{5.163621605349954, -1.0745105326239368`}, {
     5.334754575517146, -1.036803537480276}}]}, 
   {Hue[0.687413268856698], AbsoluteThickness[0.5], 
    LineBox[{{5.334754575517146, -1.036803537480276}, {
     5.6439890461897475`, -0.9749340211278993}}]}, 
   {Hue[0.6071186793518888], AbsoluteThickness[0.5], 
    LineBox[{{4.419077733814899, -2.79762915124042}, {
     4.608174023497259, -2.8416987101365607`}}]}, 
   {Hue[0.6079939463789176], AbsoluteThickness[0.5], 
    LineBox[{{4.608174023497259, -2.8416987101365607`}, {
     4.874299447647827, -2.880185512543312}}]}, 
   {Hue[0.2841564976470553], AbsoluteThickness[0.5], 
    LineBox[{{3.77483995949091, -3.4372416890708823`}, {
     3.7614060242050145`, -3.5496627263545375`}}]}, 
   {Hue[0.28466449210300954`], AbsoluteThickness[0.5], 
    LineBox[{{3.7614060242050145`, -3.5496627263545375`}, {
     3.7340818051155993`, -3.892451883446549}}]}, 
   {Hue[0.6153481031862548], AbsoluteThickness[0.5], 
    LineBox[{{3.3341557215325435`, -2.9159524939842534`}, {
     3.1691055856447305`, -2.9445154990396825`}}]}, 
   {Hue[0.6157924782735875], AbsoluteThickness[0.5], 
    LineBox[{{3.1691055856447305`, -2.9445154990396825`}, {
     2.831757936060197, -3.009546507076422}}]}, 
   {Hue[0.6166435102616057], AbsoluteThickness[0.5], 
    LineBox[{{6.3712516550442695`, -0.6942983855546734}, {
     6.460614255887537, -0.686011103970822}}]}, 
   {Hue[0.6189687999389701], AbsoluteThickness[0.5], 
    LineBox[{{6.460614255887537, -0.686011103970822}, {
     6.691576219227442, -0.62898818782639}}]}, 
   {Hue[0.6163841794951274], AbsoluteThickness[0.5], 
    LineBox[{{4.834596255186881, -2.5199955510787393`}, {
     4.862811276473758, -2.669440300901749}}]}, 
   {Hue[0.6190334420084614], AbsoluteThickness[0.5], 
    LineBox[{{4.862811276473758, -2.669440300901749}, {
     4.868998794212574, -2.8863539994322394`}}]}, 
   {Hue[0.5476712892603472], AbsoluteThickness[0.5], 
    LineBox[{{4.950187313867133, -2.612343339894973}, {
     5.077157127595388, -2.6555931468446827`}}]}, 
   {Hue[0.5481005304105492], AbsoluteThickness[0.5], 
    LineBox[{{5.077157127595388, -2.6555931468446827`}, {
     5.404145983712174, -2.77001624174616}}]}, 
   {Hue[0.6802486658087473], AbsoluteThickness[0.5], 
    LineBox[{{5.087484378227502, -2.5572169118944763`}, {
     5.266937741832242, -2.3973992753070474`}}]}, 
   {Hue[0.6860872158949407], AbsoluteThickness[0.5], 
    LineBox[{{5.266937741832242, -2.3973992753070474`}, {
     5.388691363793476, -2.230898271360738}}]}, 
   {Hue[0.45352125126644577`], AbsoluteThickness[0.5], 
    LineBox[{{2.7741997609281652`, -3.4296035592425302`}, {
     2.7536757530021174`, -3.5726411509897034`}}]}, 
   {Hue[0.4539533677343733], AbsoluteThickness[0.5], 
    LineBox[{{2.7536757530021174`, -3.5726411509897034`}, {
     2.712684446931498, -3.883008218202262}}]}, 
   {Hue[0.6971651989086506], AbsoluteThickness[0.5], 
    LineBox[{{3.6364897111645367`, -2.907112954485144}, {
     3.9225077359016587`, -3.1195149551435133`}}]}, 
   {Hue[0.685890012997327], AbsoluteThickness[0.5], 
    LineBox[{{4.0854239787760145`, -3.2901286060772734`}, {
     4.066005323219972, -3.329145254203706}}]}, 
   {Hue[0.6863888532410419], AbsoluteThickness[0.5], 
    LineBox[{{4.066005323219972, -3.329145254203706}, {
     3.954993522981294, -3.5747007628498926`}}]}, 
   {Hue[0.26497055232083766`], AbsoluteThickness[0.5], 
    LineBox[{{4.901432935913149, -3.3587805302606646`}, {
     4.905796192423828, -3.3612836046133534`}}]}, 
   {Hue[0.2655491441876809], AbsoluteThickness[0.5], 
    LineBox[{{4.905796192423828, -3.3612836046133534`}, {
     5.16250121217185, -3.527133031129849}}]}, 
   {Hue[0.6880203569629478], AbsoluteThickness[0.5], 
    LineBox[{{4.739387967081124, -2.624916473155098}, {
     4.825768548632886, -2.4845462535553193`}}]}, 
   {Hue[0.6900616495124023], AbsoluteThickness[0.5], 
    LineBox[{{4.825768548632886, -2.4845462535553193`}, {
     4.961905320756877, -2.320533729563639}}]}, 
   {Hue[0.5925049224355106], AbsoluteThickness[0.5], 
    LineBox[{{5.379193407445641, -2.2906600165561555`}, {
     5.4012412500878275`, -2.3264507389863818`}}]}, 
   {Hue[0.5929359039576626], AbsoluteThickness[0.5], 
    LineBox[{{5.4012412500878275`, -2.3264507389863818`}, {
     5.564213781915145, -2.5971270252759875`}}]}, 
   {Hue[0.5797732806149573], AbsoluteThickness[0.5], 
    LineBox[{{5.671137349615453, -1.4227318946946022`}, {
     5.820363179877082, -1.4025085070703043`}}]}, 
   {Hue[0.5806621292044559], AbsoluteThickness[0.5], 
    LineBox[{{5.820363179877082, -1.4025085070703043`}, {
     6.094168768966386, -1.3892799143389478`}}]}, 
   {Hue[0.6584081680983325], AbsoluteThickness[0.5], 
    LineBox[{{4.782519145789811, -0.08557373594640755}, {4.808997392872581, 
     0.16379283322099764`}}]}, 
   {Hue[0.6595235226561602], AbsoluteThickness[0.5], 
    LineBox[{{4.808997392872581, 0.16379283322099764`}, {4.809859199480522, 
     0.3844838638707961}}]}, 
   {Hue[0.6728024084077646], AbsoluteThickness[0.5], 
    LineBox[{{4.715144946531152, 0.40867876489360544`}, {5.042785774596238, 
     0.83928149622928}}]}, 
   {Hue[0.6747219348861359], AbsoluteThickness[0.5], 
    LineBox[{{5.042785774596238, 0.83928149622928}, {5.162650183906772, 
     1.0519387676171947`}}]}, 
   {Hue[0.6119596943669106], AbsoluteThickness[0.5], 
    LineBox[{{2.208607427758521, -2.861293254471109}, {
     2.2416416476852645`, -3.064260214629114}}]}, 
   {Hue[0.6124013065277033], AbsoluteThickness[0.5], 
    LineBox[{{2.2416416476852645`, -3.064260214629114}, {
     2.295102319024979, -3.359791537669654}}]}, 
   {Hue[0.6661314507617938], AbsoluteThickness[0.5], 
    LineBox[{{3.2945611804798833`, -2.8983584553729904`}, {
     3.380501622532277, -3.181201277533782}}]}, 
   {Hue[0.669675201319151], AbsoluteThickness[0.5], 
    LineBox[{{3.380501622532277, -3.181201277533782}, {
     3.404523776272398, -3.384491011213036}}]}, 
   {Hue[0.5276616197772981], AbsoluteThickness[0.5], 
    LineBox[{{4.170027974209632, -3.0685900421039163`}, {
     4.602235650205558, -3.2654445558774494`}}]}, 
   {Hue[0.5282376115233619], AbsoluteThickness[0.5], 
    LineBox[{{4.602235650205558, -3.2654445558774494`}, {
     4.886888141409564, -3.3775024804030003`}}]}, 
   {Hue[0.5538389192015306], AbsoluteThickness[0.5], 
    LineBox[{{2.7223676682001012`, -2.920004077798222}, {
     2.6178988576503057`, -2.9507370854926767`}}]}, 
   {Hue[0.5542927135172626], AbsoluteThickness[0.5], 
    LineBox[{{2.6178988576503057`, -2.9507370854926767`}, {
     2.329598386327699, -3.0282867575039227`}}]}, 
   {Hue[0.37693082661832167`], AbsoluteThickness[0.5], 
    LineBox[{{3.1397138318901696`, -3.1092943360337797`}, {
     3.139734369023912, -3.221871594960443}}]}, 
   {Hue[0.3812141466941003], AbsoluteThickness[0.5], 
    LineBox[{{3.139734369023912, -3.221871594960443}, {
     3.1772773649630603`, -3.416671138205574}}]}, 
   {Hue[0.5731362862700193], AbsoluteThickness[0.5], 
    LineBox[{{3.6454506149446466`, -2.9738439926653393`}, {
     3.8991467866593696`, -3.021369074539742}}]}, 
   {Hue[0.5735634342718218], AbsoluteThickness[0.5], 
    LineBox[{{3.8991467866593696`, -3.021369074539742}, {
     4.169606941271529, -3.070558895816128}}]}, 
   {Hue[0.6944710553131962], AbsoluteThickness[0.5], 
    LineBox[{{4.782949065983467, -2.397720483839051}, {
     4.824725059922241, -2.467633862086106}}]}, 
   {Hue[0.698116123830986], AbsoluteThickness[0.5], 
    LineBox[{{4.824725059922241, -2.467633862086106}, {
     4.951229467882055, -2.612492914562263}}]}, 
   {Hue[0.4744172269026477], AbsoluteThickness[0.5], 
    LineBox[{{6.702686771898657, -2.5263018619795266`}, {
     7.168438238356105, -2.702767352020559}}]}, 
   {Hue[0.4748991516238043], AbsoluteThickness[0.5], 
    LineBox[{{7.168438238356105, -2.702767352020559}, {
     7.4404234061564605`, -2.816145128516358}}]}, 
   {Hue[0.6750311656620633], AbsoluteThickness[0.5], 
    LineBox[{{5.376679783355897, 1.1569622305002074`}, {5.58265385965219, 
     1.2791166671877212`}}]}, 
   {Hue[0.6762144169236791], AbsoluteThickness[0.5], 
    LineBox[{{5.58265385965219, 1.2791166671877212`}, {5.846117441243009, 
     1.3997887080182134`}}]}, 
   {Hue[0.4704384097075179], AbsoluteThickness[0.5], 
    LineBox[{{3.393132125598578, 2.8884812846905206`}, {3.3933585462741584`, 
     2.8970143155309227`}}]}, 
   {Hue[0.4715021153874568], AbsoluteThickness[0.5], 
    LineBox[{{3.3933585462741584`, 2.8970143155309227`}, {3.4273092232311617`,
      3.1666748602701187`}}]}, 
   {Hue[0.5785132159906301], AbsoluteThickness[0.5], 
    LineBox[{{5.185498344552433, 2.5592406364249785`}, {5.229111079280584, 
     2.5905940661041877`}}]}, 
   {Hue[0.5798700517168641], AbsoluteThickness[0.5], 
    LineBox[{{5.229111079280584, 2.5905940661041877`}, {5.389510181787468, 
     2.736482272957798}}]}, 
   {Hue[0.6386499882597001], AbsoluteThickness[0.5], 
    LineBox[{{4.545082436945182, 0.3383877295897794}, {4.596124657158336, 
     0.2717386228467946}}]}, 
   {Hue[0.6410160075981177], AbsoluteThickness[0.5], 
    LineBox[{{4.596124657158336, 0.2717386228467946}, {4.733698803005555, 
     0.1392605200746395}}]}, 
   {Hue[0.6937750139874214], AbsoluteThickness[0.5], 
    LineBox[{{3.3287267644932, -0.4264155101671486}, {
     3.2473233586892882`, -0.6291871696351062}}]}, 
   {Hue[0.6942242718267669], AbsoluteThickness[0.5], 
    LineBox[{{3.2473233586892882`, -0.6291871696351062}, {
     3.1357890810513624`, -0.9251811594554628}}]}, 
   {Hue[0.4489513500662992], AbsoluteThickness[0.5], 
    LineBox[{{7.153508861361645, 0.0472788978023332}, {7.4377623995966164`, 
     0.07311825058042039}}]}, 
   {Hue[0.4531287164625505], AbsoluteThickness[0.5], 
    LineBox[{{7.4377623995966164`, 0.07311825058042037}, {7.6235461539594604`,
      0.054882391682013504`}}]}, 
   {Hue[0.5218390182888273], AbsoluteThickness[0.5], 
    LineBox[{{4.1384242233903406`, -3.5688021548918365`}, {
     4.050037275529105, -3.850420092593126}}]}, 
   {Hue[0.5223194855871954], AbsoluteThickness[0.5], 
    LineBox[{{4.050037275529105, -3.850420092593126}, {
     3.980674758852672, -4.099345388436077}}]}, 
   {Hue[0.5661382536969072], AbsoluteThickness[0.5], 
    LineBox[{{3.388278171736167, -3.8958529084869706`}, {
     3.3578389501621033`, -4.092357464188081}}]}, 
   {Hue[0.5666068391849798], AbsoluteThickness[0.5], 
    LineBox[{{3.3578389501621033`, -4.092357464188081}, {
     3.300971287665975, -4.400648676087593}}]}, 
   {Hue[0.5659233484370411], AbsoluteThickness[0.5], 
    LineBox[{{2.853115957234686, -1.5232593587173808`}, {
     2.7837282175698865`, -1.5804839830037551`}}]}, 
   {Hue[0.566567954042439], AbsoluteThickness[0.5], 
    LineBox[{{2.7837282175698865`, -1.5804839830037551`}, {
     2.5617894537175356`, -1.7880084268686764`}}]}, 
   {Hue[0.5660804784714203], AbsoluteThickness[0.5], 
    LineBox[{{2.5928210776853198`, 1.2764604228296812`}, {2.4979235008543847`,
      1.3159067424933713`}}]}, 
   {Hue[0.5705904879061383], AbsoluteThickness[0.5], 
    LineBox[{{2.4979235008543847`, 1.3159067424933713`}, {2.3171635468824845`,
      1.4363333455402565`}}]}, 
   {Hue[0.48411217416405], AbsoluteThickness[0.5], 
    LineBox[{{5.042157102366224, 2.0941287884800523`}, {4.79924741788296, 
     2.6224974039314453`}}]}, 
   {Hue[0.48454938218558224`], AbsoluteThickness[0.5], 
    LineBox[{{4.79924741788296, 2.6224974039314453`}, {4.67227050634152, 
     2.909975702746802}}]}, 
   {Hue[0.5195144972317064], AbsoluteThickness[0.5], 
    LineBox[{{4.905125729378626, -1.5123648390582447`}, {
     4.862971936284975, -1.5999458854868276`}}]}, 
   {Hue[0.5200474101296396], AbsoluteThickness[0.5], 
    LineBox[{{4.862971936284975, -1.5999458854868276`}, {
     4.726948681134282, -1.8529708661052982`}}]}, 
   {Hue[0.5751687592375858], AbsoluteThickness[0.5], 
    LineBox[{{5.63754680200265, -0.2561349097010347}, {
     5.150130313576224, -0.47206470987163685`}}]}, 
   {Hue[0.5756067159299743], AbsoluteThickness[0.5], 
    LineBox[{{5.150130313576224, -0.47206470987163685`}, {
     4.871753092144263, -0.5902696800849899}}]}, 
   {Hue[0.5637212021812487], AbsoluteThickness[0.5], 
    LineBox[{{6.089936220661324, 0.3684093933369444}, {5.614586705713153, 
     0.3801643989705882}}]}, 
   {Hue[0.5650678736595567], AbsoluteThickness[0.5], 
    LineBox[{{5.614586705713153, 0.3801643989705882}, {5.339163016758249, 
     0.41869394101402313`}}]}, 
   {Hue[0.5662728455963969], AbsoluteThickness[0.5], 
    LineBox[{{7.108184989612472, 0.272764367993269}, {6.906582630409519, 
     0.2659079065229686}}]}, 
   {Hue[0.5667132998225289], AbsoluteThickness[0.5], 
    LineBox[{{6.906582630409519, 0.2659079065229686}, {6.588220805058812, 
     0.2496678390217722}}]}, 
   {Hue[0.5662455929309643], AbsoluteThickness[0.5], 
    LineBox[{{8.064620880166169, 0.21870149092733096`}, {7.921614121404449, 
     0.21936389300228304`}}]}, 
   {Hue[0.5666735083252785], AbsoluteThickness[0.5], 
    LineBox[{{7.921614121404449, 0.21936389300228304`}, {7.582004075588618, 
     0.21871119209612877`}}]}, 
   {Hue[0.5670971028144713], AbsoluteThickness[0.5], 
    LineBox[{{8.064672211011958, 0.22148949620949657`}, {7.921269338518016, 
     0.2246723055762196}}]}, 
   {Hue[0.5675308270124603], AbsoluteThickness[0.5], 
    LineBox[{{7.921269338518016, 0.2246723055762196}, {7.582675634343785, 
     0.22794480672015785`}}]}, 
   {Hue[0.5671120605704969], AbsoluteThickness[0.5], 
    LineBox[{{7.10609724167968, 0.14320927168507647`}, {7.096931887208189, 
     0.14377542456844633`}}]}, 
   {Hue[0.5719251374675752], AbsoluteThickness[0.5], 
    LineBox[{{7.096931887208189, 0.14377542456844633`}, {6.952480692885278, 
     0.12392596508174225`}}]}, 
   {Hue[0.5772382671806848], AbsoluteThickness[0.5], 
    LineBox[{{6.543616646454833, -0.23831446840583614`}, {
     6.2625689294727716`, -0.616427962716892}}]}, 
   {Hue[0.5778735955131745], AbsoluteThickness[0.5], 
    LineBox[{{6.2625689294727716`, -0.616427962716892}, {
     6.109586251192059, -0.8508577805183248}}]}, 
   {Hue[0.5675102998093537], AbsoluteThickness[0.5], 
    LineBox[{{5.3202913979563125`, 0.5501724962177167}, {5.17364562957327, 
     0.5772390835395301}}]}, 
   {Hue[0.5680864127768516], AbsoluteThickness[0.5], 
    LineBox[{{5.17364562957327, 0.5772390835395301}, {4.8917459419969775`, 
     0.6141351536645686}}]}, 
   {Hue[0.5214518352747655], AbsoluteThickness[0.5], 
    LineBox[{{5.074791017464291, 2.675062659666707}, {4.977932472078936, 
     2.8314805014039357`}}]}, 
   {Hue[0.522314354353302], AbsoluteThickness[0.5], 
    LineBox[{{4.977932472078936, 2.8314805014039357`}, {4.851986833946945, 
     3.0793408223041268`}}]}, 
   {Hue[0.5882884587199816], AbsoluteThickness[0.5], 
    LineBox[{{5.252347783747108, -1.8852261730103013`}, {
     5.207232740114192, -2.065213277047733}}]}, 
   {Hue[0.5887963497423938], AbsoluteThickness[0.5], 
    LineBox[{{5.207232740114192, -2.065213277047733}, {
     5.140331737530475, -2.384999047225103}}]}, 
   {Hue[0.5912467868767614], AbsoluteThickness[0.5], 
    LineBox[{{3.5435802907958855`, -0.2005660885692982}, {
     3.4725635562820854`, -0.17932087019023552`}}]}, 
   {Hue[0.5976003157278852], AbsoluteThickness[0.5], 
    LineBox[{{3.4725635562820854`, -0.17932087019023552`}, {
     3.303144324751041, -0.08487842060263466}}]}, 
   {Hue[0.6762154787980573], AbsoluteThickness[0.5], 
    LineBox[{{4.445671154172447, 1.1757887914132055`}, {4.4045538861910165`, 
     1.2217235025889184`}}]}, 
   {Hue[0.6769280740800679], AbsoluteThickness[0.5], 
    LineBox[{{4.4045538861910165`, 1.2217235025889184`}, {4.201133822930824, 
     1.4191486079786046`}}]}, 
   {Hue[0.5857154300640525], AbsoluteThickness[0.5], 
    LineBox[{{2.725208535629809, -0.901041010762715}, {
     2.6417845804177125`, -0.9405836152318328}}]}, 
   {Hue[0.5861478641177457], AbsoluteThickness[0.5], 
    LineBox[{{2.6417845804177125`, -0.9405836152318329}, {
     2.3209343888125185`, -1.0971989640266366`}}]}, 
   {Hue[0.5693722565870147], AbsoluteThickness[0.5], 
    LineBox[{{3.413989583946645, 2.648475393853868}, {3.411426555057629, 
     2.656210141943271}}]}, 
   {Hue[0.5700452069179961], AbsoluteThickness[0.5], 
    LineBox[{{3.411426555057629, 2.656210141943271}, {3.303477354934688, 
     2.9220624557246255`}}]}, 
   {Hue[0.6076850278628662], AbsoluteThickness[0.5], 
    LineBox[{{4.875287251962306, 1.105796215809494}, {4.7827733229260625`, 
     1.1651146699520694`}}]}, 
   {Hue[0.6085844560448519], AbsoluteThickness[0.5], 
    LineBox[{{4.7827733229260625`, 1.1651146699520696`}, {4.60492055611214, 
     1.3024091942588543`}}]}, 
   {Hue[0.3269660903282754], AbsoluteThickness[0.5], 
    LineBox[{{7.164988653108599, 1.0346971075157592`}, {7.222575617617811, 
     1.1053829949994176`}}]}, 
   {Hue[0.32839443439491156`], AbsoluteThickness[0.5], 
    LineBox[{{7.222575617617811, 1.1053829949994176`}, {7.363164825942386, 
     1.3268885201699543`}}]}, 
   {Hue[0.6156190272839148], AbsoluteThickness[0.5], 
    LineBox[{{7.70057827198202, -0.9845491140092091}, {
     7.777433936919948, -1.0757899518351146`}}]}, 
   {Hue[0.616548322045189], AbsoluteThickness[0.5], 
    LineBox[{{7.777433936919948, -1.0757899518351146`}, {
     7.9406327998716755`, -1.3090401938365324`}}]}, 
   {Hue[0.5700734710803481], AbsoluteThickness[0.5], 
    LineBox[{{4.134279919881224, -0.7053021782523812}, {
     3.696967448357079, -1.0209163157266419`}}]}, 
   {Hue[0.5737173091226275], AbsoluteThickness[0.5], 
    LineBox[{{3.696967448357079, -1.0209163157266419`}, {
     3.5026100944680296`, -1.1138252596026281`}}]}, 
   {Hue[0.49084034315091424`], AbsoluteThickness[0.5], 
    LineBox[{{6.373795229262254, 1.1746088336009244`}, {6.358515729385509, 
     1.2265119193364142`}}]}, 
   {Hue[0.49390175466648073`], AbsoluteThickness[0.5], 
    LineBox[{{6.358515729385509, 1.2265119193364142`}, {6.265748982234742, 
     1.4166553309204464`}}]}, 
   {Hue[0.5533955336657921], AbsoluteThickness[0.5], 
    LineBox[{{6.816792275529389, -1.0673424449995488`}, {
     6.76903775954833, -1.1510301547042785`}}]}, 
   {Hue[0.5541909939191181], AbsoluteThickness[0.5], 
    LineBox[{{6.76903775954833, -1.1510301547042785`}, {
     6.662034097408441, -1.3782900929749218`}}]}, 
   {Hue[0.5767584438365769], AbsoluteThickness[0.5], 
    LineBox[{{7.3884426023262675`, -1.0121691934008297`}, {
     7.300330333150186, -1.1349538303890956`}}]}, 
   {Hue[0.577313551710003], AbsoluteThickness[0.5], 
    LineBox[{{7.300330333150186, -1.1349538303890956`}, {
     7.139716481228284, -1.3835426716014068`}}]}, 
   {Hue[0.12867877565025762`], AbsoluteThickness[0.5], 
    LineBox[{{7.619354980106846, -1.1178463161520402`}, {
     7.66056541850083, -1.1316260522265051`}}]}, 
   {Hue[0.1292516165882124], AbsoluteThickness[0.5], 
    LineBox[{{7.66056541850083, -1.1316260522265051`}, {
     7.953856866841899, -1.2469134421646144`}}]}, 
   {Hue[0.6540250400284957], AbsoluteThickness[0.5], 
    LineBox[{{7.953856866841899, -1.2469134421646144`}, {
     7.656275223975168, -1.3506256486664572`}}]}, 
   {Hue[0.5791507870939043], AbsoluteThickness[0.5], 
    LineBox[{{7.652132399103487, -0.8660253057315965}, {
     7.6524913106860515`, -0.8503713724892374}}]}, 
   {Hue[0.5804149227257718], AbsoluteThickness[0.5], 
    LineBox[{{7.6524913106860515`, -0.8503713724892374}, {
     7.683359843580768, -0.6197559872668554}}]}, 
   {Hue[0.5550120851239216], AbsoluteThickness[0.5], 
    LineBox[{{7.531818170287938, -0.3375845677858367}, {
     7.589716437081267, -0.1753342215441897}}]}, 
   {Hue[0.5566732681822144], AbsoluteThickness[0.5], 
    LineBox[{{7.589716437081267, -0.1753342215441897}, {7.636637858459357, 
     0.03962449780703818}}]}, 
   {Hue[0.6664527845831334], AbsoluteThickness[0.5], 
    LineBox[{{6.6198885477207385`, -0.7901631905955421}, {
     6.54021426007762, -0.8310642794072147}}]}, 
   {Hue[0.6686984084542243], AbsoluteThickness[0.5], 
    LineBox[{{6.54021426007762, -0.8310642794072147}, {
     6.358182795568251, -0.9614555715225186}}]}, 
   {Hue[0.6586718422219832], AbsoluteThickness[0.5], 
    LineBox[{{8.114315363349343, -0.31333269510986894`}, {
     8.010716067417759, -0.39604987534054764`}}]}, 
   {Hue[0.6593146815148831], AbsoluteThickness[0.5], 
    LineBox[{{8.010716067417759, -0.39604987534054764`}, {
     7.81246427005846, -0.575542573607976}}]}, 
   {Hue[0.659588883041124], AbsoluteThickness[0.5], 
    LineBox[{{8.101141691585351, -0.19382120629324912`}, {
     7.879472702395853, -0.18392486014011655`}}]}, 
   {Hue[0.6601583557864255], AbsoluteThickness[0.5], 
    LineBox[{{7.879472702395853, -0.18392486014011655`}, {
     7.605734156260967, -0.18575041835159195`}}]}, 
   {Hue[0.6689785276615842], AbsoluteThickness[0.5], 
    LineBox[{{6.839485511703017, -0.5667677846538254}, {
     6.714639698051683, -0.5602084015024124}}]}, 
   {Hue[0.6694063968400673], AbsoluteThickness[0.5], 
    LineBox[{{6.714639698051683, -0.5602084015024124}, {
     6.379833071714092, -0.5404400328761949}}]}, 
   {Hue[0.21597645032604315`], AbsoluteThickness[0.5], 
    LineBox[{{7.547538327762724, 0.6247962430662375}, {7.669831140960174, 
     0.9421694288128266}}]}, 
   {Hue[0.23840427942724632`], AbsoluteThickness[0.5], 
    LineBox[{{7.669831140960174, 0.9421694288128266}, {7.679229166761721, 
     1.123561446022567}}]}, 
   {Hue[0.40224579776806785`], AbsoluteThickness[0.5], 
    LineBox[{{7.679229166761721, 1.123561446022567}, {7.522937409450165, 
     1.216104805551228}}]}, 
   {Hue[0.5660873161088906], AbsoluteThickness[0.5], 
    LineBox[{{7.522937409450165, 1.216104805551228}, {7.368407882906106, 
     1.1206479450201265`}}]}, 
   {Hue[0.5385297920515402], AbsoluteThickness[0.5], 
    LineBox[{{6.372021675903593, 0.13238409920163033`}, {6.27515823098612, 
     0.13446297242085395`}}]}, 
   {Hue[0.5574812095497165], AbsoluteThickness[0.5], 
    LineBox[{{6.27515823098612, 0.13446297242085395`}, {6.110853683994083, 
     0.18956174558611813`}}]}, 
   {Hue[0.34320537580053273`], AbsoluteThickness[0.5], 
    LineBox[{{6.486355752910804, 0.660196213855839}, {6.416184980660797, 
     0.8658899081420139}}]}, 
   {Hue[0.3440783952361107], AbsoluteThickness[0.5], 
    LineBox[{{6.416184980660797, 0.8658899081420139}, {6.345163492353907, 
     1.151649926217305}}]}, 
   {Hue[0.5651331971236335], AbsoluteThickness[0.5], 
    LineBox[{{7.054642597348614, 0.6053018194401824}, {7.191912523452839, 
     0.6555199608376021}}]}, 
   {Hue[0.5665007135023511], AbsoluteThickness[0.5], 
    LineBox[{{7.191912523452839, 0.6555199608376021}, {7.410478753189179, 
     0.7654400697544645}}]}, 
   {Hue[0.42376783651330663`], AbsoluteThickness[0.5], 
    LineBox[{{6.060392843487193, -0.3371234386571548}, {
     5.899700132575954, -0.3234840056498283}}]}, 
   {Hue[0.42421510887689345`], AbsoluteThickness[0.5], 
    LineBox[{{5.899700132575954, -0.3234840056498283}, {
     5.633419388837108, -0.2953770629804829}}]}, 
   {Hue[0.5321824768200917], AbsoluteThickness[0.5], 
    LineBox[{{6.5922612783590395`, -1.1214510933541992`}, {
     6.438862680768334, -1.4241696796337349`}}]}, 
   {Hue[0.543628940231007], AbsoluteThickness[0.5], 
    LineBox[{{6.438862680768334, -1.4241696796337349`}, {
     6.406681885941332, -1.57725143207938}}]}, 
   {Hue[0.6444812555333198], AbsoluteThickness[0.5], 
    LineBox[{{7.644668080063981, -1.1003916668096594`}, {
     7.684425262126303, -1.1096363420219097`}}]}, 
   {Hue[0.6455256097506284], AbsoluteThickness[0.5], 
    LineBox[{{7.684425262126303, -1.1096363420219097`}, {
     7.947757888756799, -1.198644108184762}}]}, 
   {Hue[0.4969787352376928], AbsoluteThickness[0.5], 
    LineBox[{{5.136569387834561, -1.3481263393754064`}, {
     5.130743580304792, -1.3491707090382068`}}]}, 
   {Hue[0.49793927823231626`], AbsoluteThickness[0.5], 
    LineBox[{{5.130743580304792, -1.3491707090382068`}, {
     4.899641186143113, -1.4129267727557808`}}]}, 
   {Hue[0.5630065604146526], AbsoluteThickness[0.5], 
    LineBox[{{5.09764295044793, 0.8069563336040951}, {5.061177277218737, 
     0.8447872413802227}}]}, 
   {Hue[0.5635895227177676], AbsoluteThickness[0.5], 
    LineBox[{{5.061177277218737, 0.8447872413802227}, {4.857874148719598, 
     1.0796206085829978`}}]}, 
   {Hue[0.6451947104607467], AbsoluteThickness[0.5], 
    LineBox[{{5.649877445151607, -1.8841143747183111`}, {
     6.114383608933324, -2.2175302469263167`}}]}, 
   {Hue[0.6459697795527056], AbsoluteThickness[0.5], 
    LineBox[{{6.114383608933324, -2.2175302469263167`}, {
     6.3637099719336145`, -2.3690177406499378`}}]}, 
   {Hue[0.33893480124199626`], AbsoluteThickness[0.5], 
    LineBox[{{5.603119379416055, -2.093129075304882}, {
     5.5061927447348875`, -2.3129242846517104`}}]}, 
   {Hue[0.33939270374750863`], AbsoluteThickness[0.5], 
    LineBox[{{5.5061927447348875`, -2.3129242846517104`}, {
     5.387545112426055, -2.601264161207059}}]}, 
   {Hue[0.6544126083382179], AbsoluteThickness[0.5], 
    LineBox[{{5.388956161530407, -2.0903762808177735`}, {
     5.103515446445684, -2.030102814859543}}]}, 
   {Hue[0.6548384030352133], AbsoluteThickness[0.5], 
    LineBox[{{5.103515446445684, -2.030102814859543}, {
     4.7989626556395155`, -1.9654518233506095`}}]}, 
   {Hue[0.632572217048382], AbsoluteThickness[0.5], 
    LineBox[{{3.855931511382925, -0.9574232958730357}, {
     3.371912672263886, -1.285063135738712}}]}, 
   {Hue[0.6343413039445891], AbsoluteThickness[0.5], 
    LineBox[{{3.371912672263886, -1.285063135738712}, {
     3.1503037844177033`, -1.395731682203307}}]}, 
   {Hue[0.6572056384870566], AbsoluteThickness[0.5], 
    LineBox[{{3.0856647969255224`, 2.6790102014619053`}, {3.240043766274813, 
     3.116418512050707}}]}, 
   {Hue[0.6576721948769637], AbsoluteThickness[0.5], 
    LineBox[{{3.240043766274813, 3.116418512050707}, {3.334784312144549, 
     3.4109264504557344`}}]}, 
   {Hue[0.5103313090050658], AbsoluteThickness[0.5], 
    LineBox[{{3.334437716689853, -2.877104597143399}, {
     3.0297187810142456`, -3.3861991949071846`}}]}, 
   {Hue[0.5109118804307716], AbsoluteThickness[0.5], 
    LineBox[{{3.0297187810142456`, -3.3861991949071846`}, {
     2.889147012922871, -3.6521316696794446`}}]}, 
   {Hue[0.5744007421757187], AbsoluteThickness[0.5], 
    LineBox[{{2.9366521158743493`, -2.65574954324112}, {
     2.912342887162619, -2.694235581145141}}]}, 
   {Hue[0.575426108780895], AbsoluteThickness[0.5], 
    LineBox[{{2.912342887162619, -2.694235581145141}, {
     2.736110075624667, -2.921495762594847}}]}, 
   {Hue[0.5577399049435576], AbsoluteThickness[0.5], 
    LineBox[{{3.3835902858217612`, 0.9956791318545444}, {3.184512128466646, 
     1.0568910330992527`}}]}, 
   {Hue[0.5587703430718082], AbsoluteThickness[0.5], 
    LineBox[{{3.184512128466646, 1.0568910330992527`}, {2.8995300116576708`, 
     1.1151718029145221`}}]}, 
   {Hue[0.5435632805796788], AbsoluteThickness[0.5], 
    LineBox[{{5.630120900243981, 1.6299670195362055`}, {5.604261015752525, 
     1.7778972255933132`}}]}, 
   {Hue[0.5545423481000293], AbsoluteThickness[0.5], 
    LineBox[{{5.648999733444483, 0.8660752230173452}, {5.639527697329449, 
     0.8794038969457664}}]}, 
   {Hue[0.5550295001141138], AbsoluteThickness[0.5], 
    LineBox[{{5.639527697329449, 0.8794038969457664}, {5.442452080701284, 
     1.1375385393623547`}}]}, 
   {Hue[0.5411657668641998], AbsoluteThickness[0.5], 
    LineBox[{{6.086873768027755, -0.7942341793969764}, {
     6.06010894496874, -0.8382968331384053}}]}, 
   {Hue[0.5416749810268755], AbsoluteThickness[0.5], 
    LineBox[{{6.06010894496874, -0.8382968331384053}, {
     5.9177842868027, -1.0950277126809584`}}]}, 
   {Hue[0.5679988547638463], AbsoluteThickness[0.5], 
    LineBox[{{6.93710557949533, 0.10363846861624737`}, {6.858171196777798, 
     0.12110415135527111`}}]}, 
   {Hue[0.5688234760300144], AbsoluteThickness[0.5], 
    LineBox[{{6.858171196777798, 0.12110415135527111`}, {6.591700642546763, 
     0.2032006815101277}}]}, 
   {Hue[0.5471944927136876], AbsoluteThickness[0.5], 
    LineBox[{{7.853392189340278, -0.05773122956403057}, {
     7.7966513596894265`, -0.09950215652777031}}]}, 
   {Hue[0.5479471435527525], AbsoluteThickness[0.5], 
    LineBox[{{7.7966513596894265`, -0.09950215652777031}, {
     7.600810455284947, -0.26748957210191393`}}]}, 
   {Hue[0.016800724969517043`], AbsoluteThickness[0.5], 
    LineBox[{{8.155250926625996, -0.06940656844503204}, {
     8.230601316622751, -0.06890549009885918}}]}, 
   {Hue[0.04305746124090619], AbsoluteThickness[0.5], 
    LineBox[{{8.230601316622751, -0.06890549009885918}, {
     8.396347004765932, -0.12430699846526025`}}]}, 
   {Hue[0.19276393189197183`], AbsoluteThickness[0.5], 
    LineBox[{{8.396347004765932, -0.12430699846526025`}, {
     8.426889428458164, -0.29637710226697583`}}]}, 
   {Hue[0.3424704025430364], AbsoluteThickness[0.5], 
    LineBox[{{8.426889428458164, -0.29637710226697583`}, {
     8.29033557568274, -0.40543674447946837`}}]}, 
   {Hue[0.49217687319410297`], AbsoluteThickness[0.5], 
    LineBox[{{8.29033557568274, -0.40543674447946837`}, {
     8.129277721086217, -0.33760365712459295`}}]}, 
   {Hue[0.6418833438451693], AbsoluteThickness[0.5], 
    LineBox[{{8.129277721086217, -0.33760365712459295`}, {
     8.11189570998121, -0.16371051189662678`}}]}, 
   {Hue[0.5482667614270132], AbsoluteThickness[0.5], 
    LineBox[{{7.917834223081918, 0.11737758423387704`}, {7.900978274014054, 
     0.12944409519115413`}}]}, 
   {Hue[0.5487036148103454], AbsoluteThickness[0.5], 
    LineBox[{{7.900978274014054, 0.12944409519115413`}, {7.623202944288723, 
     0.32215408596913514`}}]}, 
   {Hue[0.5689686521481371], AbsoluteThickness[0.5], 
    LineBox[{{6.545723155960326, -0.20850682246037056`}, {
     6.379463957114927, -0.24733650175405883`}}]}, 
   {Hue[0.5693955459576587], AbsoluteThickness[0.5], 
    LineBox[{{6.379463957114927, -0.24733650175405883`}, {
     6.0553756683444595`, -0.3213958252609278}}]}, 
   {Hue[0.541484604965923], AbsoluteThickness[0.5], 
    LineBox[{{6.36304839370805, 0.6062653595749425}, {6.3554413276193085`, 
     0.6107307336804346}}]}, 
   {Hue[0.542303792778076], AbsoluteThickness[0.5], 
    LineBox[{{6.3554413276193085`, 0.6107307336804346}, {6.166709610015191, 
     0.7430419003002823}}]}, 
   {Hue[0.5741288339126892], AbsoluteThickness[0.5], 
    LineBox[{{5.680424676690819, -0.8466646712201136}, {
     5.639853911409281, -0.9643428776580459}}]}, 
   {Hue[0.5757180692812698], AbsoluteThickness[0.5], 
    LineBox[{{5.639853911409281, -0.9643428776580459}, {
     5.532917756247213, -1.1818216611133805`}}]}, 
   {Hue[0.5023944406339438], AbsoluteThickness[0.5], 
    LineBox[{{5.6038834307540535`, -1.6537191819558945`}, {
     5.574828055576979, -1.8083732617536543`}}]}, 
   {Hue[0.5028863474774236], AbsoluteThickness[0.5], 
    LineBox[{{5.574828055576979, -1.8083732617536543`}, {
     5.502576680982024, -2.1296838422899396`}}]}, 
   {Hue[0.5555019893929808], AbsoluteThickness[0.5], 
    LineBox[{{4.205381702818821, -1.368260993376091}, {
     4.11279359409122, -1.4704724372435602`}}]}, 
   {Hue[0.5568989999803557], AbsoluteThickness[0.5], 
    LineBox[{{4.11279359409122, -1.4704724372435602`}, {
     3.957077172731855, -1.6065259421256657`}}]}, 
   {Hue[0.5883436652008881], AbsoluteThickness[0.5], 
    LineBox[{{2.8832770731809365`, -0.0766094288435}, {
     2.8071031737953436`, -0.0986294837643556}}]}, 
   {Hue[0.5920929906056179], AbsoluteThickness[0.5], 
    LineBox[{{2.8071031737953436`, -0.0986294837643556}, {
     2.6242844862481394`, -0.18979051844913064`}}]}, 
   {Hue[0.5299858020230473], AbsoluteThickness[0.5], 
    LineBox[{{2.3535659318525837`, 3.098971023063012}, {2.3521122056164145`, 
     3.0995242907932106`}}]}, 
   {Hue[0.5309226115372117], AbsoluteThickness[0.5], 
    LineBox[{{2.3521122056164145`, 3.0995242907932106`}, {2.1108399193335665`,
      3.217186508121462}}]}, 
   {Hue[0.638920053613531], AbsoluteThickness[0.5], 
    LineBox[{{3.275170746944, -2.35107506194573}, {
     3.229553897702393, -2.5771391736672444`}}]}, 
   {Hue[0.6393937717478668], AbsoluteThickness[0.5], 
    LineBox[{{3.229553897702393, -2.5771391736672444`}, {
     3.175139801046358, -2.896515628323856}}]}, 
   {Hue[0.6199898335454292], AbsoluteThickness[0.5], 
    LineBox[{{2.3096873381154195`, 1.4804703639468886`}, {2.1851496357615776`,
      1.5640133541841428`}}]}, 
   {Hue[0.6211737939204356], AbsoluteThickness[0.5], 
    LineBox[{{2.1851496357615776`, 1.5640133541841428`}, {1.9209227970468312`,
      1.703270531361045}}]}, 
   {Hue[0.6955540727161862], AbsoluteThickness[0.5], 
    LineBox[{{4.097753882116313, 2.6627006355976346`}, {3.9619169556399014`, 
     2.8338164841124884`}}]}, 
   {Hue[0.6964048241697136], AbsoluteThickness[0.5], 
    LineBox[{{3.9619169556399014`, 2.8338164841124884`}, {3.835810972125268, 
     3.0231262631609703`}}]}, 
   {Hue[0.23246424177604175`], AbsoluteThickness[0.5], 
    LineBox[{{6.854859612651246, -1.4158809044572065`}, {
     6.855528652761384, -1.4167311931099675`}}]}, 
   {Hue[0.23289344616898136`], AbsoluteThickness[0.5], 
    LineBox[{{6.855528652761384, -1.4167311931099675`}, {
     7.034639736310979, -1.6405337456483051`}}]}, 
   {Hue[0.5833990305499305], AbsoluteThickness[0.5], 
    LineBox[{{3.8428988406362716`, 0.6044286511249765}, {3.5690408780172658`, 
     0.6110940349290104}}]}, 
   {Hue[0.585284969978181], AbsoluteThickness[0.5], 
    LineBox[{{3.5690408780172658`, 0.6110940349290104}, {3.345640729751031, 
     0.5860364469883248}}]}, 
   {Hue[0.5924209395297453], AbsoluteThickness[0.5], 
    LineBox[{{4.881230150565236, 0.8893525885189948}, {4.690225257493295, 
     0.9980189646672557}}]}, 
   {Hue[0.59302939923397], AbsoluteThickness[0.5], 
    LineBox[{{4.690225257493295, 0.9980189646672557}, {4.39485461746657, 
     1.144340699922345}}]}, 
   {Hue[0.3628569383659616], AbsoluteThickness[0.5], 
    LineBox[{{7.160383146799558, 0.4483052129234696}, {7.597846896418203, 
     0.13896450703030783`}}]}, 
   {Hue[0.3668091585293765], AbsoluteThickness[0.5], 
    LineBox[{{7.597846896418203, 0.13896450703030783`}, {7.797441511417062, 
     0.047240845976946666`}}]}, 
   {Hue[0.6975388606696787], AbsoluteThickness[0.5], 
    LineBox[{{7.797441511417062, 0.047240845976946694`}, {7.920870218738016, 
     0.2289455364575529}}]}, 
   {Hue[0.4693189893260975], AbsoluteThickness[0.5], 
    LineBox[{{7.08910715380312, 0.8558616229079116}, {7.108852609273228, 
     0.8443172975563392}}]}, 
   {Hue[0.4697834495225153], AbsoluteThickness[0.5], 
    LineBox[{{7.108852609273228, 0.8443172975563392}, {7.377404445653592, 
     0.6970063767355839}}]}, 
   {Hue[0.5887294654415682], AbsoluteThickness[0.5], 
    LineBox[{{6.923585226531508, 1.384430231900378}, {6.922325068188449, 
     1.1189257392858996`}}]}, 
   {Hue[0.5896292257396447], AbsoluteThickness[0.5], 
    LineBox[{{6.922325068188449, 1.1189257392858996`}, {6.94426956604189, 
     0.853640143488327}}]}, 
   {Hue[0.04563608225105654], AbsoluteThickness[0.5], 
    LineBox[{{7.043024463711233, 1.623098242003608}, {7.075759764616064, 
     1.6937784355481678`}}]}, 
   {Hue[0.0486481299642654], AbsoluteThickness[0.5], 
    LineBox[{{7.075759764616064, 1.6937784355481678`}, {7.201239231614649, 
     1.8770880989415415`}}]}, 
   {Hue[0.40643970668673257`], AbsoluteThickness[0.5], 
    LineBox[{{7.201239231614649, 1.8770880989415415`}, {7.394498555319542, 
     1.7675510589378582`}}]}, 
   {Hue[0.5896763160492441], AbsoluteThickness[0.5], 
    LineBox[{{6.835134065659889, 1.4557371568530757`}, {6.793214250512888, 
     1.4198458134706307`}}]}, 
   {Hue[0.5902855998060511], AbsoluteThickness[0.5], 
    LineBox[{{6.793214250512888, 1.4198458134706307`}, {6.575802867549453, 
     1.2109187723914039`}}]}, 
   {Hue[0.47182239386691377`], AbsoluteThickness[0.5], 
    LineBox[{{6.342768709801086, 1.5297899636793373`}, {6.251378784994297, 
     1.5648424581695308`}}]}, 
   {Hue[0.4896898138195466], AbsoluteThickness[0.5], 
    LineBox[{{6.251378784994297, 1.5648424581695308`}, {6.118666346054708, 
     1.6685929695552773`}}]}, 
   {Hue[0.6743632029137944], AbsoluteThickness[0.5], 
    LineBox[{{6.118666346054708, 1.6685929695552773`}, {6.153161963291812, 
     1.8334772091099696`}}]}, 
   {Hue[0.3722243514542165], AbsoluteThickness[0.5], 
    LineBox[{{5.952148635015081, 2.15513423952321}, {5.738256494528711, 
     2.639174991325452}}]}, 
   {Hue[0.3726743216777931], AbsoluteThickness[0.5], 
    LineBox[{{5.738256494528711, 2.639174991325452}, {5.617949763047362, 
     2.928253222618959}}]}, 
   {Hue[0.6970375876499272], AbsoluteThickness[0.5], 
    LineBox[{{5.619785094200908, 0.7318271963025047}, {5.539400080641547, 
     0.6781677391965731}}]}, 
   {Hue[0.6981314125259318], AbsoluteThickness[0.5], 
    LineBox[{{5.539400080641547, 0.6781677391965731}, {5.315671422371666, 
     0.4938236825129747}}]}, 
   {Hue[0.5715064784484019], AbsoluteThickness[0.5], 
    LineBox[{{5.865621530831638, -0.5866494900579388}, {
     5.862777387781934, -0.6053032824220119}}]}, 
   {Hue[0.5722409987877353], AbsoluteThickness[0.5], 
    LineBox[{{5.862777387781934, -0.6053032824220119}, {
     5.802966384687996, -0.8680005796727559}}]}, 
   {Hue[0.5821008809438967], AbsoluteThickness[0.5], 
    LineBox[{{4.859288194084859, -0.5615708727200162}, {
     4.842618573424153, -0.5768753529786199}}]}, 
   {Hue[0.5826239416981649], AbsoluteThickness[0.5], 
    LineBox[{{4.842618573424153, -0.5768753529786199}, {
     4.636864913626556, -0.782633719276651}}]}, 
   {Hue[0.616135507284765], AbsoluteThickness[0.5], 
    LineBox[{{4.432049029638953, 1.5409692291594008`}, {4.27644466065269, 
     1.584620048838438}}]}, 
   {Hue[0.6406877877606661], AbsoluteThickness[0.5], 
    LineBox[{{4.27644466065269, 1.584620048838438}, {4.135049106765918, 
     1.6807506071738325`}}]}, 
   {Hue[0.39010362733625104`], AbsoluteThickness[0.5], 
    LineBox[{{4.816965700845403, 1.8224660042968313`}, {4.721018910447627, 
     2.1026500878980743`}}]}, 
   {Hue[0.39066687265862243`], AbsoluteThickness[0.5], 
    LineBox[{{4.721018910447627, 2.1026500878980743`}, {4.638915541281222, 
     2.3885057755428236`}}]}, 
   {Hue[0.6338842733974698], AbsoluteThickness[0.5], 
    LineBox[{{5.332743116346129, 1.7837260496438638`}, {5.846157745625035, 
     1.9957140100773856`}}]}, 
   {Hue[0.6344503161819219], AbsoluteThickness[0.5], 
    LineBox[{{5.846157745625035, 1.9957140100773856`}, {6.155817370778267, 
     2.105553926090553}}]}, 
   {Hue[0.6487868007080788], AbsoluteThickness[0.5], 
    LineBox[{{5.705553518259504, 1.8420885461279697`}, {5.63114546457714, 
     1.9608473845276535`}}]}, 
   {Hue[0.6492907270645193], AbsoluteThickness[0.5], 
    LineBox[{{5.63114546457714, 1.9608473845276535`}, {5.502952295165385, 
     2.1489707318438014`}}]}, 
   {Hue[0.34902964679818954`], AbsoluteThickness[0.5], 
    LineBox[{{6.316102591298726, 1.8753983615424614`}, {6.385508791284644, 
     1.9009031230912705`}}]}, 
   {Hue[0.34950013078416486`], AbsoluteThickness[0.5], 
    LineBox[{{6.385508791284644, 1.9009031230912705`}, {6.678804040378377, 
     2.0185581527679615`}}]}, 
   {Hue[0.6623263192771748], AbsoluteThickness[0.5], 
    LineBox[{{6.760855510741436, 1.1114263012140602`}, {6.875375954426916, 
     1.0636471035078066`}}]}, 
   {Hue[0.6627562251995252], AbsoluteThickness[0.5], 
    LineBox[{{6.875375954426916, 1.0636471035078066`}, {7.16177634057598, 
     0.9410994488237364}}]}, 
   {Hue[0.44931018706985], AbsoluteThickness[0.5], 
    LineBox[{{7.413626211545165, 0.8026183772118229}, {7.624598534356329, 
     0.7968239871940531}}]}, 
   {Hue[0.44976876664839627`], AbsoluteThickness[0.5], 
    LineBox[{{7.624598534356329, 0.7968239871940531}, {7.9561635944141775`, 
     0.7793411433215943}}]}, 
   {Hue[0.5662132419443803], AbsoluteThickness[0.5], 
    LineBox[{{6.863820121383281, -0.905305332431093}, {
     6.864016944748285, -0.9054102769559628}}]}, 
   {Hue[0.5667905890976068], AbsoluteThickness[0.5], 
    LineBox[{{6.864016944748285, -0.9054102769559628}, {
     7.097385165108374, -1.0460666800168128`}}]}, 
   {Hue[0.675968240642521], AbsoluteThickness[0.5], 
    LineBox[{{5.023689501919517, -1.149297355242544}, {
     4.934840722394658, -1.3546330630897394`}}]}, 
   {Hue[0.6843926673186735], AbsoluteThickness[0.5], 
    LineBox[{{4.934840722394658, -1.3546330630897394`}, {
     4.9070602388804705`, -1.5166000893071179`}}]}, 
   {Hue[0.6068785946139992], AbsoluteThickness[0.5], 
    LineBox[{{4.161363715889605, 1.5272745324007335`}, {4.151349182761073, 
     1.6530010024815838`}}]}, 
   {Hue[0.610297921143849], AbsoluteThickness[0.5], 
    LineBox[{{4.151349182761073, 1.6530010024815835`}, {4.17235496781594, 
     1.8723375781448788`}}]}, 
   {Hue[0.5838214469848688], AbsoluteThickness[0.5], 
    LineBox[{{4.061493392925861, 1.6355256124272228`}, {3.9161083715389244`, 
     1.7067139165362317`}}]}, 
   {Hue[0.584247247416865], AbsoluteThickness[0.5], 
    LineBox[{{3.9161083715389244`, 1.7067139165362317`}, {3.6240212083165213`,
      1.8501433189327867`}}]}, 
   {Hue[0.6921391222497324], AbsoluteThickness[0.5], 
    LineBox[{{3.9174558718880723`, 1.6047754861010994`}, {3.42332088461127, 
     1.280582931512312}}]}, 
   {Hue[0.6928826425888236], AbsoluteThickness[0.5], 
    LineBox[{{3.42332088461127, 1.280582931512312}, {3.2059138765548028`, 
     1.1597846435132622`}}]}, 
   {Hue[0.5462951445426771], AbsoluteThickness[0.5], 
    LineBox[{{3.49572223780299, -1.6688055850099464`}, {
     3.4141702919279804`, -1.7437390304982883`}}]}, 
   {Hue[0.5478271024263196], AbsoluteThickness[0.5], 
    LineBox[{{3.4141702919279804`, -1.7437390304982883`}, {
     3.2115271252125748`, -1.888562723825694}}]}, 
   {Hue[0.660518968444714], AbsoluteThickness[0.5], 
    LineBox[{{5.397977320594125, 1.2162146887117604`}, {5.43572825732183, 
     1.1344309376485298`}}]}, 
   {Hue[0.660945088678882], AbsoluteThickness[0.5], 
    LineBox[{{5.43572825732183, 1.1344309376485298`}, {5.576704930961346, 
     0.8312148705104332}}]}, 
   {Hue[0.6017182139427977], AbsoluteThickness[0.5], 
    LineBox[{{6.104549679442639, 0.562226095591961}, {6.206705885744549, 
     0.4570138705910269}}]}, 
   {Hue[0.6025096699656122], AbsoluteThickness[0.5], 
    LineBox[{{6.206705885744549, 0.4570138705910269}, {6.391101180552501, 
     0.23474775295352285`}}]}, 
   {Hue[0.6167141445044884], AbsoluteThickness[0.5], 
    LineBox[{{5.847842256073196, 1.9702383832908335`}, {5.726410200955237, 
     2.0902626205732773`}}]}, 
   {Hue[0.6175677668811124], AbsoluteThickness[0.5], 
    LineBox[{{5.726410200955237, 2.0902626205732773`}, {5.594074402493003, 
     2.2449577470382738`}}]}, 
   {Hue[0.23174530370085158`], AbsoluteThickness[0.5], 
    LineBox[{{6.00103433816739, 2.1680960143317805`}, {6.307038303657766, 
     2.4624857745911073`}}]}, 
   {Hue[0.23236604152690407`], AbsoluteThickness[0.5], 
    LineBox[{{6.307038303657766, 2.4624857745911073`}, {6.542071635246261, 
     2.6632886200827173`}}]}, 
   {Hue[0.6211080578261454], AbsoluteThickness[0.5], 
    LineBox[{{6.194973486697652, 2.009972446054161}, {6.3188988848985845`, 
     1.8744921607854375`}}]}, 
   {Hue[0.6252653207336029], AbsoluteThickness[0.5], 
    LineBox[{{6.3188988848985845`, 1.8744921607854375`}, {6.426133767939059, 
     1.700649388615563}}]}, 
   {Hue[0.6042474339676903], AbsoluteThickness[0.5], 
    LineBox[{{4.376677541611813, 1.955825988121902}, {4.230322346958617, 
     2.0843100971852295`}}]}, 
   {Hue[0.6063159516939999], AbsoluteThickness[0.5], 
    LineBox[{{4.230322346958617, 2.0843100971852295`}, {4.074699745006795, 
     2.2659777006437296`}}]}, 
   {Hue[0.5165264451186455], AbsoluteThickness[0.5], 
    LineBox[{{4.16190678633962, -3.094605185222496}, {
     4.16240669298084, -3.1214171930574337`}}]}, 
   {Hue[0.5170810175274022], AbsoluteThickness[0.5], 
    LineBox[{{4.16240669298084, -3.1214171930574337`}, {
     4.179892578476828, -3.3805784690400054`}}]}, 
   {Hue[0.6858232185171206], AbsoluteThickness[0.5], 
    LineBox[{{2.311117948387541, 1.5098506513105614`}, {2.27601565430161, 
     1.6361914244958593`}}]}, 
   {Hue[0.6863631206240269], AbsoluteThickness[0.5], 
    LineBox[{{2.27601565430161, 1.6361914244958593`}, {2.2185498204725094`, 
     1.8873047963633585`}}]}, 
   {Hue[0.6385066514167699], AbsoluteThickness[0.5], 
    LineBox[{{3.6031581148806473`, -2.6419793554143336`}, {
     3.4773338650462526`, -2.8022842749626458`}}]}, 
   {Hue[0.6396440893797887], AbsoluteThickness[0.5], 
    LineBox[{{3.4773338650462526`, -2.8022842749626458`}, {
     3.339359024414511, -3.0212436224175665`}}]}, 
   {Hue[0.6609273021201265], AbsoluteThickness[0.5], 
    LineBox[{{2.574441327653942, 0.3159516341114863}, {2.162516410229113, 
     0.4696741234203193}}]}, 
   {Hue[0.6615475757560858], AbsoluteThickness[0.5], 
    LineBox[{{2.162516410229113, 0.4696741234203193}, {1.950387133287635, 
     0.5348757458942459}}]}, 
   {Hue[0.6648008570976564], AbsoluteThickness[0.5], 
    LineBox[{{3.8407227659974126`, -0.42811834502949636`}, {
     3.742955010591339, -0.40931964783930574`}}]}, 
   {Hue[0.672559476023749], AbsoluteThickness[0.5], 
    LineBox[{{3.742955010591339, -0.40931964783930574`}, {
     3.5614763065915445`, -0.3277610391835444}}]}, 
   {Hue[0.4906562608625788], AbsoluteThickness[0.5], 
    LineBox[{{5.843853134092717, -1.8680757517200894`}, {
     5.911959915612832, -2.4632375549532384`}}]}, 
   {Hue[0.4924361861499844], AbsoluteThickness[0.5], 
    LineBox[{{5.911959915612832, -2.4632375549532384`}, {
     5.959242826528645, -2.6513606504658322`}}]}, 
   {Hue[0.6677007713831454], AbsoluteThickness[0.5], 
    LineBox[{{5.337331765095499, -1.0574923060641015`}, {
     4.864421590481492, -1.237056309366503}}]}, 
   {Hue[0.6684005023580276], AbsoluteThickness[0.5], 
    LineBox[{{4.864421590481492, -1.237056309366503}, {
     4.5948984394024555`, -1.3186793737321671`}}]}, 
   {Hue[0.5618287536876327], AbsoluteThickness[0.5], 
    LineBox[{{6.644688666771838, -0.71667040456841}, {
     6.637360894413845, -0.6844156182745768}}]}, 
   {Hue[0.5623519889450429], AbsoluteThickness[0.5], 
    LineBox[{{6.637360894413845, -0.6844156182745768}, {
     6.5529375527412945`, -0.3746892483342946}}]}, 
   {Hue[0.11689873960809236`], AbsoluteThickness[0.5], 
    LineBox[{{6.877243573350921, -0.7053760519435339}, {
     7.053078735040938, -0.7159368955916358}}]}, 
   {Hue[0.11735346833735538`], AbsoluteThickness[0.5], 
    LineBox[{{7.053078735040938, -0.7159368955916358}, {
     7.4197563391422, -0.7467037590125342}}]}, 
   {Hue[0.665467592209029], AbsoluteThickness[0.5], 
    LineBox[{{7.4197563391422, -0.7467037590125342}, {
     7.0636834550149725`, -0.8395001297579493}}]}, 
   {Hue[0.5642952648455523], AbsoluteThickness[0.5], 
    LineBox[{{6.823064262317305, -0.9318135692217979}, {
     6.743226384051207, -1.1551154709053468`}}]}, 
   {Hue[0.5651034572790099], AbsoluteThickness[0.5], 
    LineBox[{{6.743226384051207, -1.1551154709053468`}, {
     6.677963098456788, -1.3968205165392522`}}]}, 
   {Hue[0.6685744210463546], AbsoluteThickness[0.5], 
    LineBox[{{5.615337731456239, -0.7418814461021419}, {
     5.353953662625147, -0.7280896572466938}}]}, 
   {Hue[0.6690666360266186], AbsoluteThickness[0.5], 
    LineBox[{{5.353953662625147, -0.7280896572466938}, {
     5.066806623227411, -0.7231620274018349}}]}, 
   {Hue[0.5012697249003959], AbsoluteThickness[0.5], 
    LineBox[{{5.86108654714832, -0.1909277427625363}, {5.789995359386993, 
     0.14306021653805553`}}]}, 
   {Hue[0.5022049534898241], AbsoluteThickness[0.5], 
    LineBox[{{5.789995359386993, 0.14306021653805556`}, {5.731187060914117, 
     0.3333815480998783}}]}, 
   {Hue[0.6655653449338786], AbsoluteThickness[0.5], 
    LineBox[{{3.635416973861742, -0.7161856778330311}, {
     3.3637440867976527`, -0.7283254016543321}}]}, 
   {Hue[0.6660778036136983], AbsoluteThickness[0.5], 
    LineBox[{{3.3637440867976527`, -0.7283254016543321}, {
     3.057464631718489, -0.7544384215840135}}]}, 
   {Hue[0.6776468692567357], AbsoluteThickness[0.5], 
    LineBox[{{3.072047963040112, -0.8589125605820825}, {
     3.0273410713852793`, -0.8604461406011925}}]}, 
   {Hue[0.6838086057213705], AbsoluteThickness[0.5], 
    LineBox[{{3.0273410713852793`, -0.8604461406011925}, {
     2.8581735166072266`, -0.9036328473965733}}]}, 
   {Hue[0.5821154529637743], AbsoluteThickness[0.5], 
    LineBox[{{4.84097892522051, 1.367685994691264}, {4.76981112768787, 
     1.5598402520021224`}}]}, 
   {Hue[0.5825412050181494], AbsoluteThickness[0.5], 
    LineBox[{{4.76981112768787, 1.5598402520021224`}, {4.662706778391557, 
     1.849520887106504}}]}, 
   {Hue[0.5005529737377333], AbsoluteThickness[0.5], 
    LineBox[{{4.811182674721449, 2.9193828574586274`}, {4.813604362619355, 
     3.0825573861476725`}}]}, 
   {Hue[0.5010212736758066], AbsoluteThickness[0.5], 
    LineBox[{{4.813604362619355, 3.0825573861476725`}, {4.809207644859281, 
     3.401259488339621}}]}, 
   {Hue[0.6878583017163458], AbsoluteThickness[0.5], 
    LineBox[{{5.6439890461897475`, -0.9749340211278993}, {
     5.883168157835923, -0.9318899915316409}}]}, 
   {Hue[0.6885925711520707], AbsoluteThickness[0.5], 
    LineBox[{{5.883168157835923, -0.9318899915316409}, {
     6.1531529038070225`, -0.9032933044444245}}]}, 
   {Hue[0.6088692134059464], AbsoluteThickness[0.5], 
    LineBox[{{4.874299447647827, -2.880185512543312}, {
     5.129693679547204, -2.8950867630537624`}}]}, 
   {Hue[0.28517248655896377`], AbsoluteThickness[0.5], 
    LineBox[{{3.7340818051155993`, -3.892451883446549}, {
     3.723987387828884, -4.143710301620085}}]}, 
   {Hue[0.28576846230695957`], AbsoluteThickness[0.5], 
    LineBox[{{3.723987387828884, -4.143710301620085}, {
     3.728555703654014, -4.441966765269619}}]}, 
   {Hue[0.6162368533609202], AbsoluteThickness[0.5], 
    LineBox[{{2.831757936060197, -3.009546507076422}, {
     2.583344438401864, -3.0623671625304496`}}]}, 
   {Hue[0.6183272925813639], AbsoluteThickness[0.5], 
    LineBox[{{2.583344438401864, -3.0623671625304496`}, {
     2.365082753080663, -3.076975848557064}}]}, 
   {Hue[0.6212940896163347], AbsoluteThickness[0.5], 
    LineBox[{{6.691576219227442, -0.62898818782639}, {
     6.840278391736478, -0.5675796227514385}}]}, 
   {Hue[0.6218494975693841], AbsoluteThickness[0.5], 
    LineBox[{{6.840278391736478, -0.5675796227514385}, {
     7.122128915508533, -0.43471571433655104`}}]}, 
   {Hue[0.6216827045217955], AbsoluteThickness[0.5], 
    LineBox[{{4.868998794212574, -2.8863539994322394`}, {
     4.868862126752212, -2.8874028875359694`}}]}, 
   {Hue[0.6262664697070589], AbsoluteThickness[0.5], 
    LineBox[{{4.868862126752212, -2.8874028875359694`}, {
     4.881768144179713, -3.0847534395047354`}}]}, 
   {Hue[0.5485297715607511], AbsoluteThickness[0.5], 
    LineBox[{{5.404145983712174, -2.77001624174616}, {
     5.576665894120437, -2.8319996953538022`}}]}, 
   {Hue[0.5498182133196219], AbsoluteThickness[0.5], 
    LineBox[{{5.576665894120437, -2.8319996953538022`}, {
     5.79525520382468, -2.883997172009637}}]}, 
   {Hue[0.6919257659811339], AbsoluteThickness[0.5], 
    LineBox[{{5.388691363793476, -2.230898271360738}, {
     5.43855345781811, -2.119115219250337}}]}, 
   {Hue[0.692354572229956], AbsoluteThickness[0.5], 
    LineBox[{{5.43855345781811, -2.119115219250337}, {
     5.57437605666209, -1.808144012538015}}]}, 
   {Hue[0.4543854842023008], AbsoluteThickness[0.5], 
    LineBox[{{2.712684446931498, -3.883008218202262}, {
     2.6965969764392623`, -4.0162994132173475`}}]}, 
   {Hue[0.46816807312134234`], AbsoluteThickness[0.5], 
    LineBox[{{2.6965969764392623`, -4.0162994132173475`}, {
     2.6281678280366756`, -4.179741500618176}}]}, 
   {Hue[0.6771568271979886], AbsoluteThickness[0.5], 
    LineBox[{{2.6281678280366756`, -4.179741500618176}, {
     2.4510412404602167`, -4.184435779962514}}]}, 
   {Hue[0.6868876934847569], AbsoluteThickness[0.5], 
    LineBox[{{3.954993522981294, -3.5747007628498926`}, {
     3.9380470334984405`, -3.616238576820617}}]}, 
   {Hue[0.687596474888991], AbsoluteThickness[0.5], 
    LineBox[{{3.9380470334984405`, -3.616238576820617}, {
     3.79667795197282, -3.9036030887960997`}}]}, 
   {Hue[0.26612773605452406`], AbsoluteThickness[0.5], 
    LineBox[{{5.16250121217185, -3.527133031129849}, {
     5.308974024132155, -3.633118559771017}}]}, 
   {Hue[0.2701399409099175], AbsoluteThickness[0.5], 
    LineBox[{{5.308974024132155, -3.633118559771017}, {
     5.447389811850078, -3.77913882401281}}]}, 
   {Hue[0.5993729367196027], AbsoluteThickness[0.5], 
    LineBox[{{5.447389811850078, -3.77913882401281}, {
     5.326909527749279, -3.9402764949709286`}}]}, 
   {Hue[0.6921029420618567], AbsoluteThickness[0.5], 
    LineBox[{{4.961905320756877, -2.320533729563639}, {
     5.049351393829758, -2.2411890750993306`}}]}, 
   {Hue[0.6931571249116726], AbsoluteThickness[0.5], 
    LineBox[{{5.049351393829758, -2.2411890750993306`}, {
     5.274360506324998, -2.0740955253790783`}}]}, 
   {Hue[0.5933668854798145], AbsoluteThickness[0.5], 
    LineBox[{{5.564213781915145, -2.5971270252759875`}, {
     5.608033511963776, -2.6716078265851815`}}]}, 
   {Hue[0.593834858554977], AbsoluteThickness[0.5], 
    LineBox[{{5.608033511963776, -2.6716078265851815`}, {
     5.7555484919781685`, -2.906727499148084}}]}, 
   {Hue[0.5815509777939547], AbsoluteThickness[0.5], 
    LineBox[{{6.094168768966386, -1.3892799143389478`}, {
     6.237018522460699, -1.3947321100750263`}}]}, 
   {Hue[0.5988433055718275], AbsoluteThickness[0.5], 
    LineBox[{{6.237018522460699, -1.3947321100750263`}, {
     6.4093724135189465`, -1.3495337226023023`}}]}, 
   {Hue[0.660638877213988], AbsoluteThickness[0.5], 
    LineBox[{{4.809859199480522, 0.3844838638707961}, {4.791782568471858, 
     0.5683944583944295}}]}, 
   {Hue[0.6610967482866089], AbsoluteThickness[0.5], 
    LineBox[{{4.791782568471858, 0.5683944583944295}, {4.753859348096594, 
     0.8753378499601965}}]}, 
   {Hue[0.676641461364507], AbsoluteThickness[0.5], 
    LineBox[{{5.162650183906772, 1.0519387676171947`}, {5.1760498612617205`, 
     1.0858715375365247`}}]}, 
   {Hue[0.6770675583168703], AbsoluteThickness[0.5], 
    LineBox[{{5.1760498612617205`, 1.0858715375365247`}, {5.29732709000602, 
     1.395403612384024}}]}, 
   {Hue[0.612842918688496], AbsoluteThickness[0.5], 
    LineBox[{{2.295102319024979, -3.359791537669654}, {
     2.3464423196527298`, -3.617583306856734}}]}, 
   {Hue[0.620304587984927], AbsoluteThickness[0.5], 
    LineBox[{{2.3464423196527298`, -3.617583306856734}, {
     2.3402962626843005`, -3.804031083238653}}]}, 
   {Hue[0.6732189518765083], AbsoluteThickness[0.5], 
    LineBox[{{3.404523776272398, -3.384491011213036}, {
     3.403814860391266, -3.396344071788164}}]}, 
   {Hue[0.6818156934272276], AbsoluteThickness[0.5], 
    LineBox[{{3.403814860391266, -3.396344071788164}, {
     3.4350021303011027`, -3.567457477832827}}]}, 
   {Hue[0.5288136032694258], AbsoluteThickness[0.5], 
    LineBox[{{4.886888141409564, -3.3775024804030003`}, {
     4.886989810035905, -3.377536475003889}}]}, 
   {Hue[0.5294363158860947], AbsoluteThickness[0.5], 
    LineBox[{{4.886989810035905, -3.377536475003889}, {
     5.166163594599994, -3.4896865903732195`}}]}, 
   {Hue[0.5547465078329946], AbsoluteThickness[0.5], 
    LineBox[{{2.329598386327699, -3.0282867575039227`}, {
     2.186932269880955, -3.0631128429386814`}}]}, 
   {Hue[0.5559401555557589], AbsoluteThickness[0.5], 
    LineBox[{{2.186932269880955, -3.0631128429386814`}, {
     1.919755288166379, -3.0988735426958574`}}]}, 
   {Hue[0.699672203215898], AbsoluteThickness[0.5], 
    LineBox[{{3.139734369023912, -3.221871594960443}, {
     2.685535836770305, -3.51206261084592}}]}, 
   {Hue[0.3854974667698789], AbsoluteThickness[0.5], 
    LineBox[{{3.1772773649630603`, -3.416671138205574}, {
     3.244839111387874, -3.5855289460867845`}}]}, 
   {Hue[0.3859356378135214], AbsoluteThickness[0.5], 
    LineBox[{{3.244839111387874, -3.5855289460867845`}, {
     3.3680949585117226`, -3.9080924358547477`}}]}, 
   {Hue[0.5739905822736241], AbsoluteThickness[0.5], 
    LineBox[{{4.169606941271529, -3.070558895816128}, {
     4.428075445995461, -3.116160203986285}}]}, 
   {Hue[0.47538107634496085`], AbsoluteThickness[0.5], 
    LineBox[{{7.4404234061564605`, -2.816145128516358}, {
     7.499801573012694, -2.8432141255062255`}}]}, 
   {Hue[0.47699244547057806`], AbsoluteThickness[0.5], 
    LineBox[{{7.499801573012694, -2.8432141255062255`}, {
     7.66565221275906, -2.9457246026476906`}}]}, 
   {Hue[0.6773976681852949], AbsoluteThickness[0.5], 
    LineBox[{{5.846117441243009, 1.3997887080182134`}, {5.901823831429745, 
     1.4184788964429176`}}]}, 
   {Hue[0.6779603114059658], AbsoluteThickness[0.5], 
    LineBox[{{5.901823831429745, 1.4184788964429176`}, {6.176616987296926, 
     1.5262776116214887`}}]}, 
   {Hue[0.47256582106739564`], AbsoluteThickness[0.5], 
    LineBox[{{3.4273092232311617`, 3.1666748602701187`}, {3.4622193936861523`,
      3.319939063173434}}]}, 
   {Hue[0.4730024432855651], AbsoluteThickness[0.5], 
    LineBox[{{3.4622193936861523`, 3.319939063173434}, {3.5395247777225953`, 
     3.6378075200691664`}}]}, 
   {Hue[0.5812268874430979], AbsoluteThickness[0.5], 
    LineBox[{{5.389510181787468, 2.736482272957798}, {5.473804320336405, 
     2.8329829555432333`}}]}, 
   {Hue[0.5829486963642881], AbsoluteThickness[0.5], 
    LineBox[{{5.473804320336405, 2.8329829555432333`}, {5.605519914791828, 
     3.0306331251291048`}}]}, 
   {Hue[0.6433820269365353], AbsoluteThickness[0.5], 
    LineBox[{{4.733698803005555, 0.1392605200746395}, {4.830623180066086, 
     0.07067485177245282}}]}, 
   {Hue[0.6438974804161799], AbsoluteThickness[0.5], 
    LineBox[{{4.830623180066086, 0.07067485177245283}, {
     5.087094000429387, -0.09544402860329891}}]}, 
   {Hue[0.6946735296661124], AbsoluteThickness[0.5], 
    LineBox[{{3.1357890810513624`, -0.9251811594554628}, {
     3.1157025742405646`, -0.9821534906480516}}]}, 
   {Hue[0.45730608285880187`], AbsoluteThickness[0.5], 
    LineBox[{{7.6235461539594604`, 0.05488239168201348}, {
     7.847450634003893, -0.01104188293574004}}]}, 
   {Hue[0.45778794049514887`], AbsoluteThickness[0.5], 
    LineBox[{{7.847450634003893, -0.01104188293574004}, {
     8.146708279763079, -0.08859696561023264}}]}, 
   {Hue[0.5227999528855637], AbsoluteThickness[0.5], 
    LineBox[{{3.980674758852672, -4.099345388436077}, {
     3.942036427344396, -4.257652973929241}}]}, 
   {Hue[0.5282301361247133], AbsoluteThickness[0.5], 
    LineBox[{{3.942036427344396, -4.257652973929241}, {
     3.8570140473338053`, -4.435439782454702}}]}, 
   {Hue[0.5672125596478369], AbsoluteThickness[0.5], 
    LineBox[{{2.5617894537175356`, -1.7880084268686764`}, {
     2.538703952028999, -1.8124571035585149`}}]}, 
   {Hue[0.5677493878463017], AbsoluteThickness[0.5], 
    LineBox[{{2.538703952028999, -1.8124571035585149`}, {
     2.338850561999893, -2.044368622707695}}]}, 
   {Hue[0.5751004973408562], AbsoluteThickness[0.5], 
    LineBox[{{2.3171635468824845`, 1.4363333455402565`}, {2.1845242049335933`,
      1.5679289773503942`}}]}, 
   {Hue[0.5775990272640883], AbsoluteThickness[0.5], 
    LineBox[{{2.1845242049335933`, 1.5679289773503942`}, {1.9747949438819588`,
      1.7199453840791081`}}]}, 
   {Hue[0.48498659020711454`], AbsoluteThickness[0.5], 
    LineBox[{{4.67227050634152, 2.909975702746802}, {4.667041138209176, 
     2.9223124194859817`}}]}, 
   {Hue[0.4860022143250604], AbsoluteThickness[0.5], 
    LineBox[{{4.667041138209176, 2.9223124194859817`}, {4.541787749137131, 
     3.153492818071428}}]}, 
   {Hue[0.5205803230275728], AbsoluteThickness[0.5], 
    LineBox[{{4.726948681134282, -1.8529708661052982`}, {
     4.6575233889510965`, -1.969331996812263}}]}, 
   {Hue[0.5217634925082674], AbsoluteThickness[0.5], 
    LineBox[{{4.6575233889510965`, -1.969331996812263}, {
     4.497033277805737, -2.1832157732571895`}}]}, 
   {Hue[0.5760446726223628], AbsoluteThickness[0.5], 
    LineBox[{{4.871753092144263, -0.5902696800849899}, {
     4.866335125385009, -0.5924719448313004}}]}, 
   {Hue[0.5767264170335619], AbsoluteThickness[0.5], 
    LineBox[{{4.866335125385009, -0.5924719448313004}, {
     4.619088312838318, -0.7127744078632142}}]}, 
   {Hue[0.5664145451378648], AbsoluteThickness[0.5], 
    LineBox[{{5.339163016758249, 0.41869394101402313`}, {5.156608529401882, 
     0.4659413736969554}}]}, 
   {Hue[0.5669032070561391], AbsoluteThickness[0.5], 
    LineBox[{{5.156608529401882, 0.4659413736969554}, {4.874148555238022, 
     0.5495798146877937}}]}, 
   {Hue[0.567153754048661], AbsoluteThickness[0.5], 
    LineBox[{{6.588220805058812, 0.2496678390217722}, {6.391700371472155, 
     0.23629612826685367`}}]}, 
   {Hue[0.5677493573731685], AbsoluteThickness[0.5], 
    LineBox[{{6.391700371472155, 0.23629612826685367`}, {6.085047625956404, 
     0.23245533627235457`}}]}, 
   {Hue[0.5671014237195927], AbsoluteThickness[0.5], 
    LineBox[{{7.582004075588618, 0.21871119209612877`}, {7.319985528625674, 
     0.21649033489341804`}}]}, 
   {Hue[0.5675317502409829], AbsoluteThickness[0.5], 
    LineBox[{{7.319985528625674, 0.21649033489341804`}, {7.087599030761333, 
     0.21231134088577247`}}]}, 
   {Hue[0.5679645512104493], AbsoluteThickness[0.5], 
    LineBox[{{7.582675634343785, 0.22794480672015785`}, {7.318555837587778, 
     0.2271889258712625}}]}, 
   {Hue[0.5684143264428801], AbsoluteThickness[0.5], 
    LineBox[{{7.318555837587778, 0.2271889258712625}, {7.088436374630313, 
     0.22155154518104944`}}]}, 
   {Hue[0.5767382143646536], AbsoluteThickness[0.5], 
    LineBox[{{6.952480692885278, 0.12392596508174225`}, {6.659792410742075, 
     0.022098005753345064`}}]}, 
   {Hue[0.5773186642306339], AbsoluteThickness[0.5], 
    LineBox[{{6.659792410742075, 0.022098005753345064`}, {
     6.371344807352816, -0.06138961679348243}}]}, 
   {Hue[0.5785089238456641], AbsoluteThickness[0.5], 
    LineBox[{{6.109586251192059, -0.8508577805183248}, {
     6.105951649269297, -0.8572475838648381}}]}, 
   {Hue[0.5789357479324806], AbsoluteThickness[0.5], 
    LineBox[{{6.105951649269297, -0.8572475838648381}, {
     5.9539039686522335`, -1.1216968074721831`}}]}, 
   {Hue[0.5686625257443494], AbsoluteThickness[0.5], 
    LineBox[{{4.8917459419969775`, 0.6141351536645686}, {4.864561925219788, 
     0.6162535455636922}}]}, 
   {Hue[0.5695480272452397], AbsoluteThickness[0.5], 
    LineBox[{{4.864561925219788, 0.6162535455636922}, {4.599339530151859, 
     0.6601254754603463}}]}, 
   {Hue[0.5231768734318386], AbsoluteThickness[0.5], 
    LineBox[{{4.851986833946945, 3.0793408223041268`}, {4.846241909768509, 
     3.0934845427041497`}}]}, 
   {Hue[0.5236040114305799], AbsoluteThickness[0.5], 
    LineBox[{{4.846241909768509, 3.0934845427041497`}, {4.722278708358541, 
     3.394132464294925}}]}, 
   {Hue[0.589304240764806], AbsoluteThickness[0.5], 
    LineBox[{{5.140331737530475, -2.384999047225103}, {
     5.1017270557006515`, -2.614199708358186}}]}, 
   {Hue[0.593448059380627], AbsoluteThickness[0.5], 
    LineBox[{{5.1017270557006515`, -2.614199708358186}, {
     5.106416827515296, -2.8366400937863143`}}]}, 
   {Hue[0.603953844579009], AbsoluteThickness[0.5], 
    LineBox[{{3.303144324751041, -0.08487842060263466}, {3.1933384671866434`, 
     0.012679787113690964`}}]}, 
   {Hue[0.6087563255004812], AbsoluteThickness[0.5], 
    LineBox[{{3.1933384671866434`, 0.012679787113690964`}, {
     3.0182261927779166`, 0.1148829423819008}}]}, 
   {Hue[0.6776406693620783], AbsoluteThickness[0.5], 
    LineBox[{{4.201133822930824, 1.4191486079786046`}, {4.1597681737985335`, 
     1.4540049367088292`}}]}, 
   {Hue[0.6782337901556177], AbsoluteThickness[0.5], 
    LineBox[{{4.1597681737985335`, 1.4540049367088292`}, {3.9385650572563193`,
      1.6204838125783445`}}]}, 
   {Hue[0.5865802981714389], AbsoluteThickness[0.5], 
    LineBox[{{2.3209343888125185`, -1.0971989640266366`}, {
     2.254570872112523, -1.1305410277209254`}}]}, 
   {Hue[0.5895883926176787], AbsoluteThickness[0.5], 
    LineBox[{{2.254570872112523, -1.1305410277209254`}, {
     2.0816163913942787`, -1.257180772816139}}]}, 
   {Hue[0.5707181572489775], AbsoluteThickness[0.5], 
    LineBox[{{3.303477354934688, 2.9220624557246255`}, {3.20540853684583, 
     3.1243347776699513`}}]}, 
   {Hue[0.5721008483481925], AbsoluteThickness[0.5], 
    LineBox[{{3.20540853684583, 3.1243347776699513`}, {3.124158228085083, 
     3.357385728390915}}]}, 
   {Hue[0.6094838842268376], AbsoluteThickness[0.5], 
    LineBox[{{4.60492055611214, 1.3024091942588543`}, {4.5736787318433665`, 
     1.3312037943116977`}}]}, 
   {Hue[0.61017122659285], AbsoluteThickness[0.5], 
    LineBox[{{4.5736787318433665`, 1.3312037943116977`}, {4.410173620933537, 
     1.5036742370074287`}}]}, 
   {Hue[0.3298227784615479], AbsoluteThickness[0.5], 
    LineBox[{{7.363164825942386, 1.3268885201699543`}, {7.389047743293438, 
     1.3808205361647177`}}]}, 
   {Hue[0.3302903695045256], AbsoluteThickness[0.5], 
    LineBox[{{7.389047743293438, 1.3808205361647177`}, {7.536409726370974, 
     1.6667647584837573`}}]}, 
   {Hue[0.6174776168064631], AbsoluteThickness[0.5], 
    LineBox[{{7.9406327998716755`, -1.3090401938365324`}, {
     7.990873820826045, -1.3965881723788172`}}]}, 
   {Hue[0.6181391510537261], AbsoluteThickness[0.5], 
    LineBox[{{7.990873820826045, -1.3965881723788172`}, {
     8.110500134686815, -1.6400959741484387`}}]}, 
   {Hue[0.5773611471649068], AbsoluteThickness[0.5], 
    LineBox[{{3.5026100944680296`, -1.1138252596026281`}, {
     3.353316711892201, -1.154611476677613}}]}, 
   {Hue[0.5778518420601436], AbsoluteThickness[0.5], 
    LineBox[{{3.353316711892201, -1.154611476677613}, {
     3.0457773263807466`, -1.2503680657476617`}}]}, 
   {Hue[0.49696316618204717`], AbsoluteThickness[0.5], 
    LineBox[{{6.265748982234742, 1.4166553309204464`}, {6.175216927536117, 
     1.5430635172639229`}}]}, 
   {Hue[0.5016184103053121], AbsoluteThickness[0.5], 
    LineBox[{{6.175216927536117, 1.5430635172639229`}, {6.03130202265139, 
     1.6780369926897356`}}]}, 
   {Hue[0.5549864541724442], AbsoluteThickness[0.5], 
    LineBox[{{6.662034097408441, -1.3782900929749218`}, {
     6.642320288744821, -1.4304175965812564`}}]}, 
   {Hue[0.5556268855092498], AbsoluteThickness[0.5], 
    LineBox[{{6.642320288744821, -1.4304175965812564`}, {
     6.536264334896482, -1.6658547240111423`}}]}, 
   {Hue[0.5778686595834291], AbsoluteThickness[0.5], 
    LineBox[{{7.139716481228284, -1.3835426716014068`}, {
     7.086897184064586, -1.4747731548289644`}}]}, 
   {Hue[0.5789330599561114], AbsoluteThickness[0.5], 
    LineBox[{{7.086897184064586, -1.4747731548289644`}, {
     6.948744385238747, -1.6668365944968957`}}]}, 
   {Hue[0.6534521990905376], AbsoluteThickness[0.5], 
    LineBox[{{7.66056541850083, -1.1316260522265051`}, {
     7.645671684299585, -1.0995369469039207`}}]}, 
   {Hue[0.6539391517317887], AbsoluteThickness[0.5], 
    LineBox[{{7.645671684299585, -1.0995369469039207`}, {
     7.507240720458449, -0.8261477207982871}}]}, 
   {Hue[0.12982445752616698`], AbsoluteThickness[0.5], 
    LineBox[{{7.953856866841899, -1.2469134421646144`}, {
     8.166524044565504, -1.3435137470518559`}}]}, 
   {Hue[0.14971935023520389`], AbsoluteThickness[0.5], 
    LineBox[{{8.166524044565504, -1.3435137470518559`}, {
     8.320246576497244, -1.3620915307848682`}}]}, 
   {Hue[0.3244827667713562], AbsoluteThickness[0.5], 
    LineBox[{{8.320246576497244, -1.3620915307848682`}, {
     8.406412456425837, -1.233440094694684}}]}, 
   {Hue[0.49924618330750836`], AbsoluteThickness[0.5], 
    LineBox[{{8.406412456425837, -1.233440094694684}, {
     8.33071713568877, -1.0983624529827856`}}]}, 
   {Hue[0.6740095998436606], AbsoluteThickness[0.5], 
    LineBox[{{8.33071713568877, -1.0983624529827856`}, {
     8.176005622819455, -1.1046948030697035`}}]}, 
   {Hue[0.6545978809664503], AbsoluteThickness[0.5], 
    LineBox[{{7.656275223975168, -1.3506256486664572`}, {
     7.561292820935176, -1.3782998541560465`}}]}, 
   {Hue[0.6558235045001546], AbsoluteThickness[0.5], 
    LineBox[{{7.561292820935176, -1.3782998541560465`}, {
     7.329220829562278, -1.4741346270515876`}}]}, 
   {Hue[0.5816790583576392], AbsoluteThickness[0.5], 
    LineBox[{{7.683359843580768, -0.6197559872668554}, {
     7.742642690744189, -0.3808192662346024}}]}, 
   {Hue[0.5821510136618459], AbsoluteThickness[0.5], 
    LineBox[{{7.742642690744189, -0.3808192662346024}, {
     7.803016429585375, -0.10220107904508957`}}]}, 
   {Hue[0.5583344512405071], AbsoluteThickness[0.5], 
    LineBox[{{7.636637858459357, 0.039624497807038195`}, {7.640390828201578, 
     0.0826232278476218}}]}, 
   {Hue[0.5592142596602829], AbsoluteThickness[0.5], 
    LineBox[{{7.640390828201578, 0.0826232278476218}, {7.690458986265605, 
     0.3695343782454692}}]}, 
   {Hue[0.6709440323253153], AbsoluteThickness[0.5], 
    LineBox[{{6.358182795568251, -0.9614555715225186}, {
     6.244112495297388, -1.071824109506736}}]}, 
   {Hue[0.6750359816462904], AbsoluteThickness[0.5], 
    LineBox[{{6.244112495297388, -1.071824109506736}, {
     6.119572882381925, -1.2482026719749497`}}]}, 
   {Hue[0.659957520807783], AbsoluteThickness[0.5], 
    LineBox[{{7.81246427005846, -0.575542573607976}, {
     7.785056955383748, -0.6036366333652226}}]}, 
   {Hue[0.6607287077766677], AbsoluteThickness[0.5], 
    LineBox[{{7.785056955383748, -0.6036366333652226}, {
     7.619886143074046, -0.8010074378144955}}]}, 
   {Hue[0.660727828531727], AbsoluteThickness[0.5], 
    LineBox[{{7.605734156260967, -0.18575041835159195`}, {
     7.556082844947299, -0.18863107895247655`}}]}, 
   {Hue[0.6897476301551763], AbsoluteThickness[0.5], 
    LineBox[{{7.556082844947299, -0.18863107895247655`}, {
     7.413965410687054, -0.14780747487543572`}}]}, 
   {Hue[0.6698342660185503], AbsoluteThickness[0.5], 
    LineBox[{{6.379833071714092, -0.5404400328761949}, {
     6.086103640385724, -0.5211850742486187}}]}, 
   {Hue[0.670291605474271], AbsoluteThickness[0.5], 
    LineBox[{{6.086103640385724, -0.5211850742486187}, {
     5.820724544607654, -0.49718041075457214`}}]}, 
   {Hue[0.37981796866686146`], AbsoluteThickness[0.5], 
    LineBox[{{7.669831140960174, 0.9421694288128266}, {8.162308292387332, 
     1.398304744333045}}]}, 
   {Hue[0.4460090131550262], AbsoluteThickness[0.5], 
    LineBox[{{8.162308292387332, 1.398304744333045}, {8.325030888654787, 
     1.455907844898162}}]}, 
   {Hue[0.5204712878704164], AbsoluteThickness[0.5], 
    LineBox[{{8.325030888654787, 1.455907844898162}, {8.45980468068989, 
     1.3480524532331402`}}]}, 
   {Hue[0.5949335625858072], AbsoluteThickness[0.5], 
    LineBox[{{8.45980468068989, 1.3480524532331402`}, {8.439269748494217, 
     1.1766608633272888`}}]}, 
   {Hue[0.6693958373011959], AbsoluteThickness[0.5], 
    LineBox[{{8.439269748494217, 1.1766608633272888`}, {8.282831402863897, 
     1.1036964572981516`}}]}, 
   {Hue[0.2608321085284487], AbsoluteThickness[0.5], 
    LineBox[{{7.679229166761721, 1.123561446022567}, {7.606762866617798, 
     1.3913653539190698`}}]}, 
   {Hue[0.26151450449575747`], AbsoluteThickness[0.5], 
    LineBox[{{7.606762866617798, 1.3913653539190698`}, {7.510336669031569, 
     1.6718640383964265`}}]}, 
   {Hue[0.42467362686926985`], AbsoluteThickness[0.5], 
    LineBox[{{7.522937409450165, 1.216104805551228}, {7.370381111290329, 
     1.2499910709930002`}}]}, 
   {Hue[0.42510435629042337`], AbsoluteThickness[0.5], 
    LineBox[{{7.370381111290329, 1.2499910709930002`}, {7.040900872638703, 
     1.3197565339429709`}}]}, 
   {Hue[0.5885151452100927], AbsoluteThickness[0.5], 
    LineBox[{{7.368407882906106, 1.1206479450201265`}, {7.223828807769234, 
     0.9494896653865545}}]}, 
   {Hue[0.5907207589021354], AbsoluteThickness[0.5], 
    LineBox[{{7.223828807769234, 0.9494896653865545}, {7.106088075246317, 
     0.7596988837535565}}]}, 
   {Hue[0.5764326270478921], AbsoluteThickness[0.5], 
    LineBox[{{6.110853683994083, 0.18956174558611816`}, {5.668922423780154, 
     0.5088533524094048}}]}, 
   {Hue[0.577321508238077], AbsoluteThickness[0.5], 
    LineBox[{{5.668922423780154, 0.5088533524094048}, {5.409400801227912, 
     0.6641483264572462}}]}, 
   {Hue[0.34495141467168855`], AbsoluteThickness[0.5], 
    LineBox[{{6.345163492353907, 1.151649926217305}, {6.339735267612788, 
     1.1856237168541885`}}]}, 
   {Hue[0.3465793105892407], AbsoluteThickness[0.5], 
    LineBox[{{6.339735267612788, 1.1856237168541885`}, {6.272948231956461, 
     1.413600155176027}}]}, 
   {Hue[0.5678682298810686], AbsoluteThickness[0.5], 
    LineBox[{{7.410478753189179, 0.7654400697544645}, {7.572356392979166, 
     0.8717846338567836}}]}, 
   {Hue[0.5809433787767027], AbsoluteThickness[0.5], 
    LineBox[{{7.572356392979166, 0.8717846338567836}, {7.698353212626806, 
     1.016216588551541}}]}, 
   {Hue[0.42466238124048034`], AbsoluteThickness[0.5], 
    LineBox[{{5.633419388837108, -0.2953770629804829}, {
     5.444532690010198, -0.2715172276721892}}]}, 
   {Hue[0.42515273095627015`], AbsoluteThickness[0.5], 
    LineBox[{{5.444532690010198, -0.2715172276721892}, {
     5.100258828555836, -0.21570262285716993`}}]}, 
   {Hue[0.5550754036419222], AbsoluteThickness[0.5], 
    LineBox[{{6.406681885941332, -1.57725143207938}, {
     6.419675845163592, -1.8149243169820446`}}]}, 
   {Hue[0.5556007104533306], AbsoluteThickness[0.5], 
    LineBox[{{6.419675845163592, -1.8149243169820446`}, {
     6.4495131212597725`, -2.1191507762765758`}}]}, 
   {Hue[0.646569963967937], AbsoluteThickness[0.5], 
    LineBox[{{7.947757888756799, -1.198644108184762}, {
     8.118524233631307, -1.2756072852721194`}}]}, 
   {Hue[0.647809798678661], AbsoluteThickness[0.5], 
    LineBox[{{8.118524233631307, -1.2756072852721194`}, {
     8.34344479452597, -1.3487889805869697`}}]}, 
   {Hue[0.4988998212269397], AbsoluteThickness[0.5], 
    LineBox[{{4.899641186143113, -1.4129267727557808`}, {
     4.691664617568466, -1.4914431474624605`}}]}, 
   {Hue[0.4994360033993738], AbsoluteThickness[0.5], 
    LineBox[{{4.691664617568466, -1.4914431474624605`}, {
     4.418948562849473, -1.580508050698262}}]}, 
   {Hue[0.5641724850208826], AbsoluteThickness[0.5], 
    LineBox[{{4.857874148719598, 1.0796206085829978`}, {4.789391705716007, 
     1.167842779473889}}]}, 
   {Hue[0.5646447510100662], AbsoluteThickness[0.5], 
    LineBox[{{4.789391705716007, 1.167842779473889}, {4.637601806914382, 
     1.375946308869912}}]}, 
   {Hue[0.6467448486446643], AbsoluteThickness[0.5], 
    LineBox[{{6.3637099719336145`, -2.3690177406499378`}, {
     6.388739399038149, -2.381712824440955}}]}, 
   {Hue[0.6471716553782813], AbsoluteThickness[0.5], 
    LineBox[{{6.388739399038149, -2.381712824440955}, {
     6.697543246409562, -2.5365602268206597`}}]}, 
   {Hue[0.33985060625302105`], AbsoluteThickness[0.5], 
    LineBox[{{5.387545112426055, -2.601264161207059}, {
     5.379256728977982, -2.6229283443934186`}}]}, 
   {Hue[0.340662412380697], AbsoluteThickness[0.5], 
    LineBox[{{5.379256728977982, -2.6229283443934186`}, {
     5.249028000565526, -2.895737306005449}}]}, 
   {Hue[0.655264197732209], AbsoluteThickness[0.5], 
    LineBox[{{4.7989626556395155`, -1.9654518233506095`}, {
     4.64075176959746, -1.9316888853939973`}}]}, 
   {Hue[0.6565041355011934], AbsoluteThickness[0.5], 
    LineBox[{{4.64075176959746, -1.9316888853939973`}, {
     4.377201202344631, -1.9048784719246465`}}]}, 
   {Hue[0.6361103908407961], AbsoluteThickness[0.5], 
    LineBox[{{3.1503037844177033`, -1.395731682203307}, {
     3.1359591383984062`, -1.4006651136670547`}}]}, 
   {Hue[0.6366772386680994], AbsoluteThickness[0.5], 
    LineBox[{{3.1359591383984062`, -1.4006651136670547`}, {
     2.852590123666429, -1.5145350941360707`}}]}, 
   {Hue[0.6581387512668708], AbsoluteThickness[0.5], 
    LineBox[{{3.334784312144549, 3.4109264504557344`}, {3.3531580792159916`, 
     3.474066341606073}}]}, 
   {Hue[0.6728616470377868], AbsoluteThickness[0.5], 
    LineBox[{{3.3531580792159916`, 3.474066341606073}, {3.4480654296593887`, 
     3.6238357671843278`}}]}, 
   {Hue[0.5114924518564773], AbsoluteThickness[0.5], 
    LineBox[{{2.889147012922871, -3.6521316696794446`}, {
     2.8860155199422644`, -3.6589028957254897`}}]}, 
   {Hue[0.5124747076047678], AbsoluteThickness[0.5], 
    LineBox[{{2.8860155199422644`, -3.6589028957254897`}, {
     2.7538368999740435`, -3.886314270252309}}]}, 
   {Hue[0.5764514753860712], AbsoluteThickness[0.5], 
    LineBox[{{2.736110075624667, -2.921495762594847}, {
     2.4350447553076124`, -3.2409030031683868`}}]}, 
   {Hue[0.5799911828475872], AbsoluteThickness[0.5], 
    LineBox[{{2.4350447553076124`, -3.2409030031683868`}, {
     2.274966621675135, -3.359509014003251}}]}, 
   {Hue[0.5598007812000587], AbsoluteThickness[0.5], 
    LineBox[{{2.8995300116576708`, 1.1151718029145221`}, {2.898514796785383, 
     1.1152789463130868`}}]}, 
   {Hue[0.5605422779328557], AbsoluteThickness[0.5], 
    LineBox[{{2.898514796785383, 1.1152789463130868`}, {2.5921075592485754`, 
     1.1705369604128828`}}]}, 
   {Hue[0.545658013707024], AbsoluteThickness[0.5], 
    LineBox[{{5.604261015752525, 1.7778972255933132`}, {5.557719093316768, 
     1.9203068198366993`}}]}, 
   {Hue[0.5461146106403452], AbsoluteThickness[0.5], 
    LineBox[{{5.557719093316768, 1.9203068198366993`}, {5.480440541972943, 
     2.138536697444207}}]}, 
   {Hue[0.5555166521281983], AbsoluteThickness[0.5], 
    LineBox[{{5.442452080701284, 1.1375385393623547`}, {5.393791859850965, 
     1.1969451321349025`}}]}, 
   {Hue[0.5563625394302164], AbsoluteThickness[0.5], 
    LineBox[{{5.393791859850965, 1.1969451321349025`}, {5.194052355935229, 
     1.4032598958736007`}}]}, 
   {Hue[0.5421841951895514], AbsoluteThickness[0.5], 
    LineBox[{{5.9177842868027, -1.0950277126809582`}, {
     5.90079885858513, -1.1287554743188928`}}]}, 
   {Hue[0.5430525569280705], AbsoluteThickness[0.5], 
    LineBox[{{5.90079885858513, -1.1287554743188928`}, {
     5.757526553142145, -1.3617524174530566`}}]}, 
   {Hue[0.5696480972961825], AbsoluteThickness[0.5], 
    LineBox[{{6.591700642546763, 0.2032006815101277}, {6.401741250193409, 
     0.2790644980025457}}]}, 
   {Hue[0.5701389033587485], AbsoluteThickness[0.5], 
    LineBox[{{6.401741250193409, 0.2790644980025457}, {6.100824399415988, 
     0.38712795898507624`}}]}, 
   {Hue[0.5486997943918175], AbsoluteThickness[0.5], 
    LineBox[{{7.600810455284947, -0.26748957210191393`}, {
     7.530817667584, -0.3372017675376045}}]}, 
   {Hue[0.5492892135443199], AbsoluteThickness[0.5], 
    LineBox[{{7.530817667584, -0.3372017675376045}, {
     7.341158763311035, -0.5478834826480993}}]}, 
   {Hue[0.21902066816336122`], AbsoluteThickness[0.5], 
    LineBox[{{8.426889428458164, -0.29637710226697583`}, {
     8.377323077836747, -0.6166166361287498}}]}, 
   {Hue[0.21962269928677253`], AbsoluteThickness[0.5], 
    LineBox[{{8.377323077836747, -0.6166166361287498}, {
     8.308965817275022, -0.9374383623867352}}]}, 
   {Hue[0.36872713881442526`], AbsoluteThickness[0.5], 
    LineBox[{{8.29033557568274, -0.40543674447946837`}, {
     8.087997598697171, -0.47808077432529034`}}]}, 
   {Hue[0.3691530462399667], AbsoluteThickness[0.5], 
    LineBox[{{8.087997598697171, -0.4780807743252903}, {
     7.813078109565036, -0.577354086535449}}]}, 
   {Hue[0.5184336094654919], AbsoluteThickness[0.5], 
    LineBox[{{8.129277721086217, -0.33760365712459295`}, {7.692304433378345, 
     0.05176640540795718}}]}, 
   {Hue[0.5271642473764745], AbsoluteThickness[0.5], 
    LineBox[{{7.692304433378345, 0.05176640540795718}, {7.581836918836688, 
     0.21262605063297377`}}]}, 
   {Hue[0.6681400801165581], AbsoluteThickness[0.5], 
    LineBox[{{8.11189570998121, -0.1637105118966268}, {
     8.12113978137567, -0.12415950329186548`}}]}, 
   {Hue[0.6718304969708101], AbsoluteThickness[0.5], 
    LineBox[{{8.12113978137567, -0.12415950329186548`}, {8.131412885772525, 
     0.08313908030315903}}]}, 
   {Hue[0.5491404681936776], AbsoluteThickness[0.5], 
    LineBox[{{7.623202944288723, 0.32215408596913514`}, {7.598170596353506, 
     0.33897861858318973`}}]}, 
   {Hue[0.5495840197797168], AbsoluteThickness[0.5], 
    LineBox[{{7.598170596353506, 0.33897861858318973`}, {7.301772394581715, 
     0.5463209944965997}}]}, 
   {Hue[0.5698224397671803], AbsoluteThickness[0.5], 
    LineBox[{{6.0553756683444595`, -0.3213958252609278}, {
     5.884575317852464, -0.35956862750260166`}}]}, 
   {Hue[0.5710923566553934], AbsoluteThickness[0.5], 
    LineBox[{{5.884575317852464, -0.35956862750260166`}, {
     5.670621316452382, -0.3830784591755282}}]}, 
   {Hue[0.5431229805902292], AbsoluteThickness[0.5], 
    LineBox[{{6.166709610015191, 0.7430419003002823}, {6.097602274574318, 
     0.8003181746455778}}]}, 
   {Hue[0.5438560267341096], AbsoluteThickness[0.5], 
    LineBox[{{6.097602274574318, 0.8003181746455778}, {5.882671680179077, 
     1.0064335206823334`}}]}, 
   {Hue[0.5773073046498504], AbsoluteThickness[0.5], 
    LineBox[{{5.532917756247213, -1.1818216611133805`}, {
     5.291755984509298, -1.5483233743480922`}}]}, 
   {Hue[0.5778765909205225], AbsoluteThickness[0.5], 
    LineBox[{{5.291755984509298, -1.5483233743480922`}, {
     5.130231533150663, -1.8235389794736816`}}]}, 
   {Hue[0.5033782543209034], AbsoluteThickness[0.5], 
    LineBox[{{5.502576680982024, -2.1296838422899396`}, {
     5.455160586753236, -2.310350256145658}}]}, 
   {Hue[0.5039207829205561], AbsoluteThickness[0.5], 
    LineBox[{{5.455160586753236, -2.310350256145658}, {
     5.392469756690759, -2.6042841980883122`}}]}, 
   {Hue[0.5582960105677308], AbsoluteThickness[0.5], 
    LineBox[{{3.957077172731855, -1.6065259421256657`}, {
     3.8081971413180935`, -1.708698983812281}}]}, 
   {Hue[0.5587234663553334], AbsoluteThickness[0.5], 
    LineBox[{{3.8081971413180935`, -1.708698983812281}, {
     3.5870701282812703`, -1.8623550741277144`}}]}, 
   {Hue[0.5958423160103479], AbsoluteThickness[0.5], 
    LineBox[{{2.6242844862481394`, -0.18979051844913064`}, {
     2.4114858214609085`, -0.3494609388724264}}]}, 
   {Hue[0.6007736180187796], AbsoluteThickness[0.5], 
    LineBox[{{2.4114858214609085`, -0.3494609388724264}, {
     2.2326337526402518`, -0.43448804352089077`}}]}, 
   {Hue[0.6398674898822025], AbsoluteThickness[0.5], 
    LineBox[{{3.175139801046358, -2.896515628323856}, {
     3.1686418026285543`, -2.9431670842186506`}}]}, 
   {Hue[0.6447854555962269], AbsoluteThickness[0.5], 
    LineBox[{{3.1686418026285543`, -2.9431670842186506`}, {
     3.0968822287330457`, -3.147230657597475}}]}, 
   {Hue[0.697255575623241], AbsoluteThickness[0.5], 
    LineBox[{{3.835810972125268, 3.0231262631609703`}, {3.797611695191113, 
     3.0923401602174487`}}]}, 
   {Hue[0.6978316115034638], AbsoluteThickness[0.5], 
    LineBox[{{3.797611695191113, 3.0923401602174487`}, {3.6587363810070537`, 
     3.3784145441020645`}}]}, 
   {Hue[0.23332265056192106`], AbsoluteThickness[0.5], 
    LineBox[{{7.034639736310979, -1.6405337456483051`}, {
     7.109439849551316, -1.7324305682211276`}}]}, 
   {Hue[0.23392429848039467`], AbsoluteThickness[0.5], 
    LineBox[{{7.109439849551316, -1.7324305682211276`}, {
     7.292222293829205, -1.9328090461082534`}}]}, 
   {Hue[0.5871709094064315], AbsoluteThickness[0.5], 
    LineBox[{{3.345640729751031, 0.5860364469883248}, {3.185058368274591, 
     0.5454211860329584}}]}, 
   {Hue[0.5876283275395511], AbsoluteThickness[0.5], 
    LineBox[{{3.185058368274591, 0.5454211860329584}, {2.896744195807954, 
     0.4800548107756964}}]}, 
   {Hue[0.5936378589381949], AbsoluteThickness[0.5], 
    LineBox[{{4.39485461746657, 1.144340699922345}, {4.3649132612522195`, 
     1.1570930756868538`}}]}, 
   {Hue[0.5941963369410531], AbsoluteThickness[0.5], 
    LineBox[{{4.3649132612522195`, 1.1570930756868538`}, {4.096342521451647, 
     1.2875090619583176`}}]}, 
   {Hue[0.6935866405062628], AbsoluteThickness[0.5], 
    LineBox[{{7.597846896418203, 0.13896450703030783`}, {7.592997798034806, 
     0.07857508652741634}}]}, 
   {Hue[0.6941962963002144], AbsoluteThickness[0.5], 
    LineBox[{{7.592997798034806, 0.07857508652741634}, {
     7.555992663212056, -0.18865427982325889`}}]}, 
   {Hue[0.3707613786927913], AbsoluteThickness[0.5], 
    LineBox[{{7.797441511417062, 0.047240845976946694`}, {7.854660514319341, 
     0.03287133453159807}}]}, 
   {Hue[0.3711895806183808], AbsoluteThickness[0.5], 
    LineBox[{{7.854660514319341, 0.03287133453159807}, {
     8.161770611381012, -0.04653363109292151}}]}, 
   {Hue[0.4702479097189331], AbsoluteThickness[0.5], 
    LineBox[{{7.377404445653592, 0.6970063767355839}, {7.479892105917085, 
     0.6443803371560817}}]}, 
   {Hue[0.478165447216247], AbsoluteThickness[0.5], 
    LineBox[{{7.479892105917085, 0.6443803371560817}, {7.64109911063895, 
     0.5062998498842269}}]}, 
   {Hue[0.5905289860377212], AbsoluteThickness[0.5], 
    LineBox[{{6.94426956604189, 0.853640143488327}, {6.985319453345622, 
     0.6142294972336985}}]}, 
   {Hue[0.5909593605868558], AbsoluteThickness[0.5], 
    LineBox[{{6.985319453345622, 0.6142294972336985}, {7.036429634414309, 
     0.2980366119365171}}]}, 
   {Hue[0.4034276589735234], AbsoluteThickness[0.5], 
    LineBox[{{7.075759764616064, 1.6937784355481678`}, {6.501484185844988, 
     2.3493612048435404`}}]}, 
   {Hue[0.4041113614545185], AbsoluteThickness[0.5], 
    LineBox[{{6.501484185844988, 2.3493612048435404`}, {6.31762450123799, 
     2.590022773728822}}]}, 
   {Hue[0.05166017767747411], AbsoluteThickness[0.5], 
    LineBox[{{7.201239231614649, 1.8770880989415415`}, {7.322720763102491, 
     2.003176579454123}}]}, 
   {Hue[0.05245321676205974], AbsoluteThickness[0.5], 
    LineBox[{{7.322720763102491, 2.003176579454123}, {7.551129759968373, 
     2.2058365971629588`}}]}, 
   {Hue[0.5443749005058237], AbsoluteThickness[0.5], 
    LineBox[{{7.551129759968373, 2.2058365971629588`}, {7.601113440024909, 
     1.9046001711533702`}}]}, 
   {Hue[0.40945175439994125`], AbsoluteThickness[0.5], 
    LineBox[{{7.394498555319542, 1.7675510589378582`}, {7.512642446035188, 
     1.6715878579128096`}}]}, 
   {Hue[0.41275655771231595`], AbsoluteThickness[0.5], 
    LineBox[{{7.512642446035188, 1.6715878579128096`}, {7.656122465802491, 
     1.50665042274029}}]}, 
   {Hue[0.5908948835628582], AbsoluteThickness[0.5], 
    LineBox[{{6.575802867549453, 1.2109187723914039`}, {6.5479542875563705`, 
     1.1808975808108315`}}]}, 
   {Hue[0.5913710684086297], AbsoluteThickness[0.5], 
    LineBox[{{6.5479542875563705`, 1.1808975808108315`}, {6.327944502512593, 
     0.9284076859007319}}]}, 
   {Hue[0.6564957829611608], AbsoluteThickness[0.5], 
    LineBox[{{6.251378784994297, 1.5648424581695308`}, {6.173548035059409, 
     1.552864378177353}}]}, 
   {Hue[0.6569232261955285], AbsoluteThickness[0.5], 
    LineBox[{{6.173548035059409, 1.552864378177353}, {5.864158033057047, 
     1.5034104926593594`}}]}, 
   {Hue[0.5075572337721794], AbsoluteThickness[0.5], 
    LineBox[{{6.118666346054708, 1.6685929695552773`}, {6.012914501535698, 
     1.8199039823830152`}}]}, 
   {Hue[0.5085002879073791], AbsoluteThickness[0.5], 
    LineBox[{{6.012914501535698, 1.8199039823830152`}, {5.866399564355644, 
     2.0761229014313405`}}]}, 
   {Hue[0.6922306228664268], AbsoluteThickness[0.5], 
    LineBox[{{6.153161963291812, 1.8334772091099696`}, {6.27614725411729, 
     2.0567301647720524`}}]}, 
   {Hue[0.6928134902440113], AbsoluteThickness[0.5], 
    LineBox[{{6.27614725411729, 2.0567301647720524`}, {6.407407272639543, 
     2.328413722614079}}]}, 
   {Hue[0.3731242919013696], AbsoluteThickness[0.5], 
    LineBox[{{5.617949763047362, 2.928253222618959}, {5.607122202303005, 
     2.955950913335799}}]}, 
   {Hue[0.37597492150826467`], AbsoluteThickness[0.5], 
    LineBox[{{5.607122202303005, 2.955950913335799}, {5.4966386240414105`, 
     3.142139853216612}}]}, 
   {Hue[0.6992252374019364], AbsoluteThickness[0.5], 
    LineBox[{{5.315671422371666, 0.4938236825129747}, {5.229119518898549, 
     0.4065126313853116}}]}, 
   {Hue[0.5729755191270686], AbsoluteThickness[0.5], 
    LineBox[{{5.802966384687996, -0.8680005796727559}, {
     5.749312815234773, -1.0436709044075823`}}]}, 
   {Hue[0.5735134199301422], AbsoluteThickness[0.5], 
    LineBox[{{5.749312815234773, -1.0436709044075823`}, {
     5.674207869805691, -1.3368591895259816`}}]}, 
   {Hue[0.583147002452433], AbsoluteThickness[0.5], 
    LineBox[{{4.636864913626556, -0.782633719276651}, {
     4.5894884216257426`, -0.8342385042215057}}]}, 
   {Hue[0.5836119836799561], AbsoluteThickness[0.5], 
    LineBox[{{4.5894884216257426`, -0.8342385042215057}, {
     4.390908773101687, -1.0628628581431236`}}]}, 
   {Hue[0.6652400682365672], AbsoluteThickness[0.5], 
    LineBox[{{4.135049106765918, 1.6807506071738325`}, {4.037908256454439, 
     1.8085023693967115`}}]}, 
   {Hue[0.6661954859982753], AbsoluteThickness[0.5], 
    LineBox[{{4.037908256454439, 1.8085023693967115`}, {3.889561485034637, 
     2.0458131144785923`}}]}, 
   {Hue[0.39123011798099383`], AbsoluteThickness[0.5], 
    LineBox[{{4.638915541281222, 2.3885057755428236`}, {4.635546525854652, 
     2.402929813729685}}]}, 
   {Hue[0.3936465821427996], AbsoluteThickness[0.5], 
    LineBox[{{4.635546525854652, 2.402929813729685}, {4.552750356711879, 
     2.6093036226808963`}}]}, 
   {Hue[0.6350163589663741], AbsoluteThickness[0.5], 
    LineBox[{{6.155817370778267, 2.105553926090553}, {6.169758110549239, 
     2.1097163990583967`}}]}, 
   {Hue[0.6356212037446534], AbsoluteThickness[0.5], 
    LineBox[{{6.169758110549239, 2.1097163990583967`}, {6.451273495997101, 
     2.2115017920807754`}}]}, 
   {Hue[0.6497946534209598], AbsoluteThickness[0.5], 
    LineBox[{{5.502952295165385, 2.1489707318438014`}, {5.400124177647383, 
     2.288064892142645}}]}, 
   {Hue[0.6648189540647886], AbsoluteThickness[0.5], 
    LineBox[{{5.400124177647383, 2.288064892142645}, {5.256105137457783, 
     2.397760983609794}}]}, 
   {Hue[0.3499706147701402], AbsoluteThickness[0.5], 
    LineBox[{{6.678804040378377, 2.0185581527679615`}, {6.8530715019399775`, 
     2.094474132900494}}]}, 
   {Hue[0.35135148622158036`], AbsoluteThickness[0.5], 
    LineBox[{{6.8530715019399775`, 2.094474132900494}, {7.0422421505485, 
     2.151944818135586}}]}, 
   {Hue[0.6631861311218755], AbsoluteThickness[0.5], 
    LineBox[{{7.16177634057598, 0.9410994488237364}, {7.1805807959888055`, 
     0.9328508631640436}}]}, 
   {Hue[0.6640952292350227], AbsoluteThickness[0.5], 
    LineBox[{{7.1805807959888055`, 0.9328508631640436}, {7.4135144155510355`, 
     0.8051827220874821}}]}, 
   {Hue[0.45022734622694266`], AbsoluteThickness[0.5], 
    LineBox[{{7.9561635944141775`, 0.7793411433215943}, {8.057283903410038, 
     0.771447831429547}}]}, 
   {Hue[0.4506613646835301], AbsoluteThickness[0.5], 
    LineBox[{{8.057283903410038, 0.771447831429547}, {8.384033950643115, 
     0.7501310270772685}}]}, 
   {Hue[0.5673679362508334], AbsoluteThickness[0.5], 
    LineBox[{{7.097385165108374, -1.0460666800168128`}, {
     7.2281655889272125`, -1.1345801346318682`}}]}, 
   {Hue[0.5685882289565475], AbsoluteThickness[0.5], 
    LineBox[{{7.2281655889272125`, -1.1345801346318682`}, {
     7.419913494471442, -1.2970121431167412`}}]}, 
   {Hue[0.6928170939948257], AbsoluteThickness[0.5], 
    LineBox[{{4.9070602388804705`, -1.5166000893071179`}, {
     4.929464870888627, -1.8424874921707728`}}]}, 
   {Hue[0.693246880430318], AbsoluteThickness[0.5], 
    LineBox[{{4.929464870888627, -1.8424874921707728`}, {
     4.953542473603414, -2.1522566838690143`}}]}, 
   {Hue[0.6137172476736986], AbsoluteThickness[0.5], 
    LineBox[{{4.17235496781594, 1.8723375781448788`}, {4.173361514471299, 
     1.875968247024732}}]}, 
   {Hue[0.6226979391278334], AbsoluteThickness[0.5], 
    LineBox[{{4.173361514471299, 1.875968247024732}, {4.178519219760383, 
     2.065907330556893}}]}, 
   {Hue[0.5846730478488611], AbsoluteThickness[0.5], 
    LineBox[{{3.6240212083165213`, 1.8501433189327867`}, {3.564377623251462, 
     1.8795146781216754`}}]}, 
   {Hue[0.5869321684739406], AbsoluteThickness[0.5], 
    LineBox[{{3.564377623251462, 1.8795146781216754`}, {3.409997432556123, 
     1.9863357648402198`}}]}, 
   {Hue[0.6936261629279147], AbsoluteThickness[0.5], 
    LineBox[{{3.2059138765548028`, 1.1597846435132622`}, {3.133075694766166, 
     1.1260549354926295`}}]}, 
   {Hue[0.6942434550577498], AbsoluteThickness[0.5], 
    LineBox[{{3.133075694766166, 1.1260549354926295`}, {2.847837552246246, 
     0.9730929997149885}}]}, 
   {Hue[0.5493590603099621], AbsoluteThickness[0.5], 
    LineBox[{{3.2115271252125748`, -1.888562723825694}, {
     3.157708526677824, -1.917816241210988}}]}, 
   {Hue[0.5498289659713743], AbsoluteThickness[0.5], 
    LineBox[{{3.157708526677824, -1.917816241210988}, {
     2.903933305517268, -2.0655004347039867`}}]}, 
   {Hue[0.6613712089130501], AbsoluteThickness[0.5], 
    LineBox[{{5.576704930961346, 0.8312148705104332}, {5.616877965125623, 
     0.7454282113503471}}]}, 
   {Hue[0.6775991137817552], AbsoluteThickness[0.5], 
    LineBox[{{5.616877965125623, 0.7454282113503471}, {5.724339415876592, 
     0.6247243540171241}}]}, 
   {Hue[0.6033011259884267], AbsoluteThickness[0.5], 
    LineBox[{{6.391101180552501, 0.23474775295352285`}, {6.429956927547626, 
     0.1796734265924112}}]}, 
   {Hue[0.6037477947836531], AbsoluteThickness[0.5], 
    LineBox[{{6.429956927547626, 0.1796734265924112}, {
     6.60788061537168, -0.08365298490173734}}]}, 
   {Hue[0.6184213892577365], AbsoluteThickness[0.5], 
    LineBox[{{5.594074402493003, 2.2449577470382738`}, {5.5259064601653405`, 
     2.339623206880429}}]}, 
   {Hue[0.6191734854979756], AbsoluteThickness[0.5], 
    LineBox[{{5.5259064601653405`, 2.339623206880429}, {5.36889740982916, 
     2.5958607035538153`}}]}, 
   {Hue[0.2329867793529564], AbsoluteThickness[0.5], 
    LineBox[{{6.542071635246261, 2.6632886200827173`}, {6.5634403129154535`, 
     2.679465252999057}}]}, 
   {Hue[0.2334823780139835], AbsoluteThickness[0.5], 
    LineBox[{{6.5634403129154535`, 2.679465252999057}, {6.823274588344199, 
     2.861674068874864}}]}, 
   {Hue[0.6294225836410602], AbsoluteThickness[0.5], 
    LineBox[{{6.426133767939059, 1.700649388615563}, {6.444066234230498, 
     1.653657369627826}}]}, 
   {Hue[0.6298483394093731], AbsoluteThickness[0.5], 
    LineBox[{{6.444066234230498, 1.653657369627826}, {6.557534532410283, 
     1.3557584169243782`}}]}, 
   {Hue[0.6083844694203093], AbsoluteThickness[0.5], 
    LineBox[{{4.074699745006795, 2.2659777006437296`}, {4.026928173347063, 
     2.3411127038450763`}}]}, 
   {Hue[0.6091139753678995], AbsoluteThickness[0.5], 
    LineBox[{{4.026928173347063, 2.3411127038450763`}, {3.883695840037536, 
     2.6068893378982416`}}]}, 
   {Hue[0.517635589936159], AbsoluteThickness[0.5], 
    LineBox[{{4.179892578476828, -3.3805784690400054`}, {
     4.210949843552842, -3.6468910477963288`}}]}, 
   {Hue[0.5180672268438853], AbsoluteThickness[0.5], 
    LineBox[{{4.210949843552842, -3.6468910477963288`}, {
     4.238758311999491, -3.909945917628075}}]}, 
   {Hue[0.6869030227309332], AbsoluteThickness[0.5], 
    LineBox[{{2.2185498204725094`, 1.8873047963633585`}, {2.18072686787777, 
     2.0964188726371167`}}]}, 
   {Hue[0.6876401095220027], AbsoluteThickness[0.5], 
    LineBox[{{2.18072686787777, 2.0964188726371167`}, {2.153989211283725, 
     2.347444225042594}}]}, 
   {Hue[0.6407815273428075], AbsoluteThickness[0.5], 
    LineBox[{{3.339359024414511, -3.0212436224175665`}, {
     3.2801190534471694`, -3.1410818885449956`}}]}, 
   {Hue[0.6413786586651933], AbsoluteThickness[0.5], 
    LineBox[{{3.2801190534471694`, -3.1410818885449956`}, {
     3.1665987878374544`, -3.4070128673919564`}}]}, 
   {Hue[0.680318094949842], AbsoluteThickness[0.5], 
    LineBox[{{3.5614763065915445`, -0.3277610391835444}, {
     3.4011820913373616`, -0.2046942942043417}}]}, 
   {Hue[0.6874420329414651], AbsoluteThickness[0.5], 
    LineBox[{{3.4011820913373616`, -0.2046942942043417}, {
     3.2309947927534743`, -0.12692623379782494`}}]}, 
   {Hue[0.49421611143738986`], AbsoluteThickness[0.5], 
    LineBox[{{5.959242826528645, -2.6513606504658322`}, {
     6.026718266798768, -2.8210154731174417`}}]}, 
   {Hue[0.49489920150165834`], AbsoluteThickness[0.5], 
    LineBox[{{6.026718266798768, -2.8210154731174417`}, {
     6.124609311267963, -3.124922046863884}}]}, 
   {Hue[0.6691002333329098], AbsoluteThickness[0.5], 
    LineBox[{{4.5948984394024555`, -1.3186793737321671`}, {
     4.1049720020576155`, -1.4309353390250992`}}]}, 
   {Hue[0.6695374361100556], AbsoluteThickness[0.5], 
    LineBox[{{4.1049720020576155`, -1.4309353390250992`}, {
     3.8491053960572787`, -1.4936134599775535`}}]}, 
   {Hue[0.5628752242024532], AbsoluteThickness[0.5], 
    LineBox[{{6.5529375527412945`, -0.3746892483342946}, {
     6.4727161228654335`, -0.12323820547340007`}}]}, 
   {Hue[0.5635184103029129], AbsoluteThickness[0.5], 
    LineBox[{{6.4727161228654335`, -0.12323820547340007`}, {6.400947668504853,
      0.1616431659666841}}]}, 
   {Hue[0.6650128634797675], AbsoluteThickness[0.5], 
    LineBox[{{7.053078735040938, -0.7159368955916358}, {
     6.715159286798319, -0.5543321717469242}}]}, 
   {Hue[0.6655606922163475], AbsoluteThickness[0.5], 
    LineBox[{{6.715159286798319, -0.5543321717469242}, {
     6.422211858761835, -0.43096859656081427`}}]}, 
   {Hue[0.11780819706661826`], AbsoluteThickness[0.5], 
    LineBox[{{7.4197563391422, -0.7467037590125342}, {
     7.6109103897276285`, -0.7673194060086646}}]}, 
   {Hue[0.11828308758043204`], AbsoluteThickness[0.5], 
    LineBox[{{7.6109103897276285`, -0.7673194060086646}, {
     7.895500239498922, -0.7891950491012565}}]}, 
   {Hue[0.6620109048299003], AbsoluteThickness[0.5], 
    LineBox[{{7.895500239498922, -0.7891950491012565}, {
     7.646648554229892, -0.6493996089312503}}]}, 
   {Hue[0.665922320938292], AbsoluteThickness[0.5], 
    LineBox[{{7.0636834550149725`, -0.8395001297579493}, {
     6.8844605164061665`, -0.881694291670257}}]}, 
   {Hue[0.6675720850250532], AbsoluteThickness[0.5], 
    LineBox[{{6.8844605164061665`, -0.881694291670257}, {
     6.665704507844567, -0.9044859243191652}}]}, 
   {Hue[0.5659116497124674], AbsoluteThickness[0.5], 
    LineBox[{{6.677963098456788, -1.3968205165392522`}, {
     6.665271514422033, -1.4649875379866313`}}]}, 
   {Hue[0.568387119991576], AbsoluteThickness[0.5], 
    LineBox[{{6.665271514422033, -1.4649875379866313`}, {
     6.599808318449947, -1.6513953757555468`}}]}, 
   {Hue[0.6695588510068827], AbsoluteThickness[0.5], 
    LineBox[{{5.066806623227411, -0.7231620274018349}, {
     4.922695565718708, -0.7258136301652558}}]}, 
   {Hue[0.6699945003607927], AbsoluteThickness[0.5], 
    LineBox[{{4.922695565718708, -0.7258136301652558}, {
     4.619914941590726, -0.7271612514344342}}]}, 
   {Hue[0.5031401820792522], AbsoluteThickness[0.5], 
    LineBox[{{5.731187060914117, 0.3333815480998783}, {5.667794642701532, 
     0.4877535500613709}}]}, 
   {Hue[0.5073901020135855], AbsoluteThickness[0.5], 
    LineBox[{{5.667794642701532, 0.48775355006137083`}, {5.544132138120535, 
     0.6767810933628681}}]}, 
   {Hue[0.666590262293518], AbsoluteThickness[0.5], 
    LineBox[{{3.057464631718489, -0.7544384215840135}, {
     2.932250804241932, -0.7702295309056181}}]}, 
   {Hue[0.6670279761219075], AbsoluteThickness[0.5], 
    LineBox[{{2.932250804241932, -0.7702295309056181}, {
     2.64606287838615, -0.8018753139606621}}]}, 
   {Hue[0.6899703421860055], AbsoluteThickness[0.5], 
    LineBox[{{2.8581735166072266`, -0.9036328473965733}, {
     2.66425210689158, -1.0010702171062744`}}]}, 
   {Hue[0.6904652527193389], AbsoluteThickness[0.5], 
    LineBox[{{2.66425210689158, -1.0010702171062744`}, {
     2.3490324783105665`, -1.1453953453675132`}}]}, 
   {Hue[0.5829669570725244], AbsoluteThickness[0.5], 
    LineBox[{{4.662706778391557, 1.849520887106504}, {4.656990086398705, 
     1.8650091958191002`}}]}, 
   {Hue[0.5836145293877484], AbsoluteThickness[0.5], 
    LineBox[{{4.656990086398705, 1.8650091958191002`}, {4.537704783443696, 
     2.134881290517207}}]}, 
   {Hue[0.50148957361388], AbsoluteThickness[0.5], 
    LineBox[{{4.809207644859281, 3.401259488339621}, {4.801782304731057, 
     3.57615804471848}}]}, 
   {Hue[0.5019245603131028], AbsoluteThickness[0.5], 
    LineBox[{{4.801782304731057, 3.57615804471848}, {4.785103490071498, 
     3.874189915830109}}]}, 
   {Hue[0.6893268405877957], AbsoluteThickness[0.5], 
    LineBox[{{6.1531529038070225`, -0.9032933044444245}, {
     6.167650691156127, -0.9028148100075911}}]}, 
   {Hue[0.6935354531608217], AbsoluteThickness[0.5], 
    LineBox[{{6.167650691156127, -0.9028148100075911}, {
     6.358034586127154, -0.8598416516368165}}]}, 
   {Hue[0.6097256828722812], AbsoluteThickness[0.5], 
    LineBox[{{5.129693679547204, -2.8950867630537624`}, {
     5.2051950220119725`, -2.8931589049996567`}}]}, 
   {Hue[0.6204177318018077], AbsoluteThickness[0.5], 
    LineBox[{{2.365082753080663, -3.076975848557064}, {
     2.361359390235984, -3.076692899556602}}]}, 
   {Hue[0.6264049205191877], AbsoluteThickness[0.5], 
    LineBox[{{2.361359390235984, -3.076692899556602}, {
     2.1798533646973453`, -3.1018567484978803`}}]}, 
   {Hue[0.6224049055224335], AbsoluteThickness[0.5], 
    LineBox[{{7.122128915508533, -0.43471571433655104`}, {
     7.161593056943479, -0.41369743514118046`}}]}, 
   {Hue[0.6230967800272929], AbsoluteThickness[0.5], 
    LineBox[{{7.161593056943479, -0.41369743514118046`}, {
     7.394111608702756, -0.26878784133737543`}}]}, 
   {Hue[0.6308502348923224], AbsoluteThickness[0.5], 
    LineBox[{{4.881768144179713, -3.0847534395047354`}, {
     4.910674744229145, -3.19333985878281}}]}, 
   {Hue[0.6553636949328184], AbsoluteThickness[0.5], 
    LineBox[{{4.910674744229145, -3.19333985878281}, {
     4.9000624923538, -3.3608039472912195`}}]}, 
   {Hue[0.5511066550784927], AbsoluteThickness[0.5], 
    LineBox[{{5.79525520382468, -2.883997172009637}, {
     5.860665477773413, -2.8920272527347026`}}]}, 
   {Hue[0.5517867764224149], AbsoluteThickness[0.5], 
    LineBox[{{5.860665477773413, -2.8920272527347026`}, {
     6.17456817794093, -2.95198472610044}}]}, 
   {Hue[0.6927833784787781], AbsoluteThickness[0.5], 
    LineBox[{{5.57437605666209, -1.808144012538015}, {
     5.60589661225861, -1.734418567293951}}]}, 
   {Hue[0.6993038101777989], AbsoluteThickness[0.5], 
    LineBox[{{5.60589661225861, -1.734418567293951}, {
     5.716244297818687, -1.581068254450813}}]}, 
   {Hue[0.6633742382789461], AbsoluteThickness[0.5], 
    LineBox[{{2.6965969764392623`, -4.0162994132173475`}, {
     2.7398726273261893`, -4.100467488884404}}]}, 
   {Hue[0.6638323474206395], AbsoluteThickness[0.5], 
    LineBox[{{2.7398726273261893`, -4.100467488884404}, {
     2.8795367517094568`, -4.389693011475721}}]}, 
   {Hue[0.4819506620403838], AbsoluteThickness[0.5], 
    LineBox[{{2.6281678280366756`, -4.179741500618176}, {
     2.5013736150146335`, -4.338837237405239}}]}, 
   {Hue[0.4844479181397609], AbsoluteThickness[0.5], 
    LineBox[{{2.5013736150146335`, -4.338837237405239}, {
     2.3836308943699063`, -4.545116830382357}}]}, 
   {Hue[0.6909394161170299], AbsoluteThickness[0.5], 
    LineBox[{{2.4510412404602167`, -4.184435779962514}, {
     2.3059649467317818`, -4.147408421114508}}]}, 
   {Hue[0.6970804431068965], AbsoluteThickness[0.5], 
    LineBox[{{2.3059649467317818`, -4.147408421114508}, {
     2.1070928615763784`, -4.140550270721309}}]}, 
   {Hue[0.688305256293225], AbsoluteThickness[0.5], 
    LineBox[{{3.79667795197282, -3.9036030887960997`}, {
     3.709415926974043, -4.05356168151172}}]}, 
   {Hue[0.6934941577778967], AbsoluteThickness[0.5], 
    LineBox[{{3.709415926974043, -4.05356168151172}, {
     3.5772886664684926`, -4.201053969143193}}]}, 
   {Hue[0.5953607318642109], AbsoluteThickness[0.5], 
    LineBox[{{5.308974024132155, -3.633118559771017}, {
     5.349548174513025, -3.615829371884761}}]}, 
   {Hue[0.5958244816912358], AbsoluteThickness[0.5], 
    LineBox[{{5.349548174513025, -3.615829371884761}, {
     5.644316091753737, -3.4806753396259476`}}]}, 
   {Hue[0.27415214576531116`], AbsoluteThickness[0.5], 
    LineBox[{{5.447389811850078, -3.77913882401281}, {
     5.492470774785129, -3.8490210486831544`}}]}, 
   {Hue[0.2747257219899773], AbsoluteThickness[0.5], 
    LineBox[{{5.492470774785129, -3.8490210486831544`}, {
     5.638125493917369, -4.1028458788106015`}}]}, 
   {Hue[0.6033851415749961], AbsoluteThickness[0.5], 
    LineBox[{{5.326909527749279, -3.9402764949709286`}, {
     5.179857088016156, -4.075368190195351}}]}, 
   {Hue[0.6136401900017054], AbsoluteThickness[0.5], 
    LineBox[{{5.179857088016156, -4.075368190195351}, {
     5.090151487246294, -4.2139722767478345`}}]}, 
   {Hue[0.6942113077614882], AbsoluteThickness[0.5], 
    LineBox[{{5.274360506324998, -2.0740955253790783`}, {
     5.3440205369186895`, -2.0322783505629602`}}]}, 
   {Hue[0.6946446330065471], AbsoluteThickness[0.5], 
    LineBox[{{5.3440205369186895`, -2.0322783505629602`}, {
     5.636401316191984, -1.8615828957642224`}}]}, 
   {Hue[0.5943028316301396], AbsoluteThickness[0.5], 
    LineBox[{{5.7555484919781685`, -2.906727499148084}, {
     5.827646511555985, -3.0146754587349007`}}]}, 
   {Hue[0.5989634705576021], AbsoluteThickness[0.5], 
    LineBox[{{5.827646511555985, -3.0146754587349007`}, {
     5.9848120446204005`, -3.1720060350837165`}}]}, 
   {Hue[0.6161356333497009], AbsoluteThickness[0.5], 
    LineBox[{{6.4093724135189465`, -1.3495337226023023`}, {
     6.828125682352501, -1.0921699340331208`}}]}, 
   {Hue[0.6165619981995624], AbsoluteThickness[0.5], 
    LineBox[{{6.828125682352501, -1.0921699340331208`}, {
     7.076569717171966, -0.9406802164157528}}]}, 
   {Hue[0.6615546193592298], AbsoluteThickness[0.5], 
    LineBox[{{4.753859348096594, 0.8753378499601965}, {4.711640790007929, 
     1.158744127166797}}]}, 
   {Hue[0.6620734297761234], AbsoluteThickness[0.5], 
    LineBox[{{4.711640790007929, 1.158744127166797}, {4.684913813812924, 
     1.4097076354724425`}}]}, 
   {Hue[0.6774936552692337], AbsoluteThickness[0.5], 
    LineBox[{{5.29732709000602, 1.395403612384024}, {5.5033258467320545`, 
     1.9253257704799542`}}]}, 
   {Hue[0.6779209351265082], AbsoluteThickness[0.5], 
    LineBox[{{5.5033258467320545`, 1.9253257704799545`}, {5.587611353298005, 
     2.1457394954163154`}}]}, 
   {Hue[0.6277662572813584], AbsoluteThickness[0.5], 
    LineBox[{{2.3402962626843005`, -3.8040310832386535`}, {
     2.2555452280231494`, -4.119460982989594}}]}, 
   {Hue[0.628195481462684], AbsoluteThickness[0.5], 
    LineBox[{{2.2555452280231494`, -4.119460982989594}, {
     2.1674348972510074`, -4.436871634253457}}]}, 
   {Hue[0.6904124349779471], AbsoluteThickness[0.5], 
    LineBox[{{3.4350021303011027`, -3.567457477832827}, {
     3.577243484849489, -3.885717717822387}}]}, 
   {Hue[0.6912241458226983], AbsoluteThickness[0.5], 
    LineBox[{{3.577243484849489, -3.885717717822387}, {
     3.670326143665631, -4.1485748502879005`}}]}, 
   {Hue[0.5300590285027637], AbsoluteThickness[0.5], 
    LineBox[{{5.166163594599994, -3.4896865903732195`}, {
     5.324837813900008, -3.5646392471520936`}}]}, 
   {Hue[0.5311748701476271], AbsoluteThickness[0.5], 
    LineBox[{{5.324837813900008, -3.5646392471520936`}, {
     5.579082727013409, -3.654400353206119}}]}, 
   {Hue[0.386373808857164], AbsoluteThickness[0.5], 
    LineBox[{{3.3680949585117226`, -3.9080924358547477`}, {
     3.398366021297309, -3.991179363269009}}]}, 
   {Hue[0.3883341635521361], AbsoluteThickness[0.5], 
    LineBox[{{3.398366021297309, -3.991179363269009}, {
     3.5081075538511746`, -4.197962070238288}}]}, 
   {Hue[0.6067971869859564], AbsoluteThickness[0.5], 
    LineBox[{{4.428075445995461, -3.116160203986285}, {
     4.633896927687128, -3.1715385818021806`}}]}, 
   {Hue[0.6073414244388797], AbsoluteThickness[0.5], 
    LineBox[{{4.633896927687128, -3.171538581802181}, {
     4.928831207720194, -3.265911486361361}}]}, 
   {Hue[0.4786038145961952], AbsoluteThickness[0.5], 
    LineBox[{{7.66565221275906, -2.9457246026476906`}, {
     7.830666371983981, -3.079028782845262}}]}, 
   {Hue[0.4813026944886381], AbsoluteThickness[0.5], 
    LineBox[{{7.830666371983981, -3.079028782845262}, {
     8.037695893186287, -3.1976207350873174`}}]}, 
   {Hue[0.6785229546266366], AbsoluteThickness[0.5], 
    LineBox[{{6.176616987296926, 1.5262776116214887`}, {6.260481772885489, 
     1.5641298395475156`}}]}, 
   {Hue[0.683449247941104], AbsoluteThickness[0.5], 
    LineBox[{{6.260481772885489, 1.5641298395475156`}, {6.421824814544766, 
     1.680252306280024}}]}, 
   {Hue[0.5846705052854784], AbsoluteThickness[0.5], 
    LineBox[{{5.605519914791828, 3.0306331251291048`}, {5.69140956408578, 
     3.205014054690824}}]}, 
   {Hue[0.5853457432817629], AbsoluteThickness[0.5], 
    LineBox[{{5.69140956408578, 3.205014054690824}, {5.81102299602497, 
     3.412158309172562}}]}, 
   {Hue[0.6444129338958245], AbsoluteThickness[0.5], 
    LineBox[{{5.087094000429387, -0.09544402860329892}, {
     5.120849011677595, -0.1153900829588642}}]}, 
   {Hue[0.6448400300297505], AbsoluteThickness[0.5], 
    LineBox[{{5.120849011677595, -0.1153900829588642}, {
     5.4312365081996505`, -0.29663804968911817`}}]}, 
   {Hue[0.4582697981314959], AbsoluteThickness[0.5], 
    LineBox[{{8.146708279763079, -0.08859696561023264}, {
     8.17140392926514, -0.09414065000610275}}]}, 
   {Hue[0.45952388317633763`], AbsoluteThickness[0.5], 
    LineBox[{{8.17140392926514, -0.09414065000610275}, {
     8.429330468139579, -0.1826122958678177}}]}, 
   {Hue[0.5682862160447664], AbsoluteThickness[0.5], 
    LineBox[{{2.338850561999893, -2.044368622707695}, {
     2.317375524660978, -2.071707647925551}}]}, 
   {Hue[0.5688849905743563], AbsoluteThickness[0.5], 
    LineBox[{{2.317375524660978, -2.071707647925551}, {
     2.136596856862243, -2.3303876148091587`}}]}, 
   {Hue[0.48701783844300633`], AbsoluteThickness[0.5], 
    LineBox[{{4.541787749137131, 3.153492818071428}, {4.434185771647393, 
     3.3134635239149226`}}]}, 
   {Hue[0.4929413316945932], AbsoluteThickness[0.5], 
    LineBox[{{4.434185771647393, 3.3134635239149226`}, {4.274342891238699, 
     3.4671690983309635`}}]}, 
   {Hue[0.5229466619889619], AbsoluteThickness[0.5], 
    LineBox[{{4.497033277805737, -2.1832157732571895`}, {
     4.370188957245376, -2.319504349030078}}]}, 
   {Hue[0.5791772662638558], AbsoluteThickness[0.5], 
    LineBox[{{4.370188957245376, -2.319504349030078}, {
     4.22567405841697, -2.3853861198720026`}}]}, 
   {Hue[0.66568428330342], AbsoluteThickness[0.5], 
    LineBox[{{4.22567405841697, -2.3853861198720026`}, {
     4.094046860383692, -2.296508426098139}}]}, 
   {Hue[0.577408161444761], AbsoluteThickness[0.5], 
    LineBox[{{4.619088312838318, -0.7127744078632142}, {
     4.416747533766539, -0.8285233307422127}}]}, 
   {Hue[0.57924572577338], AbsoluteThickness[0.5], 
    LineBox[{{4.416747533766539, -0.8285233307422127}, {
     4.204978188829775, -0.9144005499123509}}]}, 
   {Hue[0.5673918689744133], AbsoluteThickness[0.5], 
    LineBox[{{4.874148555238022, 0.5495798146877937}, {4.804374239302736, 
     0.5728966248557905}}]}, 
   {Hue[0.5691675704029021], AbsoluteThickness[0.5], 
    LineBox[{{4.804374239302736, 0.5728966248557905}, {4.594036529338442, 
     0.6757118203911825}}]}, 
   {Hue[0.5683449606976759], AbsoluteThickness[0.5], 
    LineBox[{{6.085047625956404, 0.2324553362723546}, {5.815798561855616, 
     0.24401028738321032`}}]}, 
   {Hue[0.568821008005491], AbsoluteThickness[0.5], 
    LineBox[{{5.815798561855616, 0.24401028738321032`}, {5.586004614336115, 
     0.24672723876850278`}}]}, 
   {Hue[0.567962076762373], AbsoluteThickness[0.5], 
    LineBox[{{7.087599030761333, 0.21231134088577247`}, {6.905956729913358, 
     0.2073174145984553}}]}, 
   {Hue[0.5684264921550448], AbsoluteThickness[0.5], 
    LineBox[{{6.905956729913358, 0.2073174145984553}, {6.590844928898939, 
     0.20726694231820708`}}]}, 
   {Hue[0.568864101675311], AbsoluteThickness[0.5], 
    LineBox[{{7.088436374630313, 0.22155154518104944`}, {6.906996525133617, 
     0.21317695080140173`}}]}, 
   {Hue[0.5693220966949141], AbsoluteThickness[0.5], 
    LineBox[{{6.906996525133617, 0.21317695080140173`}, {6.590997754928661, 
     0.20650087492591718`}}]}, 
   {Hue[0.5778991140966144], AbsoluteThickness[0.5], 
    LineBox[{{6.371344807352816, -0.06138961679348243}, {
     6.131792383147582, -0.11714311655115747`}}]}, 
   {Hue[0.583961540871012], AbsoluteThickness[0.5], 
    LineBox[{{6.131792383147582, -0.11714311655115747`}, {
     5.921677910940088, -0.12012063392163658`}}]}, 
   {Hue[0.579362572019297], AbsoluteThickness[0.5], 
    LineBox[{{5.9539039686522335`, -1.1216968074721831`}, {
     5.917822546740886, -1.1837841548810641`}}]}, 
   {Hue[0.5816260421221311], AbsoluteThickness[0.5], 
    LineBox[{{5.917822546740886, -1.1837841548810641`}, {
     5.776263785060849, -1.360904970108695}}]}, 
   {Hue[0.57043352874613], AbsoluteThickness[0.5], 
    LineBox[{{4.599339530151859, 0.6601254754603463}, {4.421680439672227, 
     0.7055066506182737}}]}, 
   {Hue[0.5708593497100216], AbsoluteThickness[0.5], 
    LineBox[{{4.421680439672227, 0.7055066506182737}, {4.101218836295858, 
     0.7869239311739157}}]}, 
   {Hue[0.5240311494293212], AbsoluteThickness[0.5], 
    LineBox[{{4.722278708358541, 3.394132464294925}, {4.685356536983857, 
     3.482360639613924}}]}, 
   {Hue[0.5254982578175521], AbsoluteThickness[0.5], 
    LineBox[{{4.685356536983857, 3.482360639613924}, {4.570945105927604, 
     3.6839737841831632`}}]}, 
   {Hue[0.5975918779964479], AbsoluteThickness[0.5], 
    LineBox[{{5.106416827515296, -2.8366400937863143`}, {
     5.114476371930564, -2.874634531004468}}]}, 
   {Hue[0.6016541414190767], AbsoluteThickness[0.5], 
    LineBox[{{5.114476371930564, -2.874634531004468}, {
     5.11900056276031, -3.076256904103008}}]}, 
   {Hue[0.6135588064219533], AbsoluteThickness[0.5], 
    LineBox[{{3.0182261927779166`, 0.1148829423819008}, {2.892189321758836, 
     0.15808308404351495`}}]}, 
   {Hue[0.614003102927425], AbsoluteThickness[0.5], 
    LineBox[{{2.892189321758836, 0.15808308404351495`}, {2.561802565991818, 
     0.2784010440633579}}]}, 
   {Hue[0.678826910949157], AbsoluteThickness[0.5], 
    LineBox[{{3.9385650572563193`, 1.6204838125783445`}, {3.880361978785863, 
     1.6594648756588208`}}]}, 
   {Hue[0.6792986511634864], AbsoluteThickness[0.5], 
    LineBox[{{3.880361978785863, 1.6594648756588208`}, {3.621359343349023, 
     1.8443185283862658`}}]}, 
   {Hue[0.5925964870639187], AbsoluteThickness[0.5], 
    LineBox[{{2.0816163913942787`, -1.257180772816139}, {
     2.009979339163972, -1.3307146131780128`}}]}, 
   {Hue[0.5935369721251037], AbsoluteThickness[0.5], 
    LineBox[{{2.009979339163972, -1.3307146131780128`}, {
     1.8412696457617708`, -1.5384986605398612`}}]}, 
   {Hue[0.5734835394474078], AbsoluteThickness[0.5], 
    LineBox[{{3.124158228085083, 3.357385728390915}, {3.1091307620015383`, 
     3.424751774469307}}]}, 
   {Hue[0.574201537134306], AbsoluteThickness[0.5], 
    LineBox[{{3.1091307620015383`, 3.424751774469307}, {3.030147612625989, 
     3.6891408223000477`}}]}, 
   {Hue[0.6108585689588623], AbsoluteThickness[0.5], 
    LineBox[{{4.410173620933537, 1.5036742370074287`}, {4.336842612556883, 
     1.5922888218686706`}}]}, 
   {Hue[0.6114106372477038], AbsoluteThickness[0.5], 
    LineBox[{{4.336842612556883, 1.5922888218686706`}, {4.148201117867823, 
     1.8440617646666544`}}]}, 
   {Hue[0.3307579605475032], AbsoluteThickness[0.5], 
    LineBox[{{7.536409726370974, 1.6667647584837573`}, {7.593202605871944, 
     1.7696802621184873`}}]}, 
   {Hue[0.3423548189754571], AbsoluteThickness[0.5], 
    LineBox[{{7.593202605871944, 1.7696802621184873`}, {7.728045955913257, 
     1.9095544111967866`}}]}, 
   {Hue[0.5677717703976249], AbsoluteThickness[0.5], 
    LineBox[{{7.728045955913257, 1.9095544111967866`}, {7.9091766341686744`, 
     1.8392750826180742`}}]}, 
   {Hue[0.618800685300989], AbsoluteThickness[0.5], 
    LineBox[{{8.110500134686815, -1.6400959741484387`}, {
     8.110773267342951, -1.6407561508187878`}}]}, 
   {Hue[0.6193383242579171], AbsoluteThickness[0.5], 
    LineBox[{{8.110773267342951, -1.6407561508187878`}, {
     8.23102766911496, -1.8976020281344783`}}]}, 
   {Hue[0.5783425369553804], AbsoluteThickness[0.5], 
    LineBox[{{3.0457773263807466`, -1.2503680657476617`}, {
     2.9343617893219722`, -1.2894055741023782`}}]}, 
   {Hue[0.5794491538615483], AbsoluteThickness[0.5], 
    LineBox[{{2.9343617893219722`, -1.2894055741023782`}, {
     2.6978716276280292`, -1.3461904880284352`}}]}, 
   {Hue[0.5062736544285769], AbsoluteThickness[0.5], 
    LineBox[{{6.03130202265139, 1.6780369926897356`}, {5.609494869723037, 
     1.940968279459119}}]}, 
   {Hue[0.5068370283596361], AbsoluteThickness[0.5], 
    LineBox[{{5.609494869723037, 1.940968279459119}, {5.427040300609053, 
     2.067856124985877}}]}, 
   {Hue[0.5562673168460553], AbsoluteThickness[0.5], 
    LineBox[{{6.536264334896482, -1.6658547240111423`}, {
     6.463778131372021, -1.8034309369887263`}}]}, 
   {Hue[0.5570855951979244], AbsoluteThickness[0.5], 
    LineBox[{{6.463778131372021, -1.8034309369887263`}, {
     6.354297778610573, -2.059249900305226}}]}, 
   {Hue[0.579997460328794], AbsoluteThickness[0.5], 
    LineBox[{{6.948744385238747, -1.6668365944968957`}, {
     6.852653046284278, -1.7758838110315511`}}]}, 
   {Hue[0.5844614127949573], AbsoluteThickness[0.5], 
    LineBox[{{6.852653046284278, -1.7758838110315511`}, {
     6.711032226184094, -1.884762065022832}}]}, 
   {Hue[0.6544261043730398], AbsoluteThickness[0.5], 
    LineBox[{{7.507240720458449, -0.826147720798287}, {
     7.381768660220691, -0.5980385303375619}}]}, 
   {Hue[0.6621271511211995], AbsoluteThickness[0.5], 
    LineBox[{{7.381768660220691, -0.5980385303375619}, {
     7.334229061698916, -0.42695045245047847`}}]}, 
   {Hue[0.5191410760165442], AbsoluteThickness[0.5], 
    LineBox[{{8.33071713568877, -1.0983624529827856`}, {
     8.163083998770357, -0.940964916813286}}]}, 
   {Hue[0.5456288995620008], AbsoluteThickness[0.5], 
    LineBox[{{8.163083998770357, -0.940964916813286}, {
     8.025320886732034, -0.8787900241205219}}]}, 
   {Hue[0.6945579255602541], AbsoluteThickness[0.5], 
    LineBox[{{8.025320886732034, -0.8787900241205219}, {
     7.9047963099149126`, -0.9699942932250648}}]}, 
   {Hue[0.6939044925526963], AbsoluteThickness[0.5], 
    LineBox[{{8.176005622819455, -1.1046948030697035`}, {
     8.164380285283483, -1.1088989777592322`}}]}, 
   {Hue[0.6963221390369461], AbsoluteThickness[0.5], 
    LineBox[{{8.164380285283483, -1.1088989777592322`}, {
     7.96006334809905, -1.1492309740932498`}}]}, 
   {Hue[0.6570491280338587], AbsoluteThickness[0.5], 
    LineBox[{{7.329220829562278, -1.4741346270515876`}, {
     7.053361892710719, -1.6247411273354508`}}]}, 
   {Hue[0.6718952176259715], AbsoluteThickness[0.5], 
    LineBox[{{7.053361892710719, -1.6247411273354508`}, {
     6.902356419194153, -1.6581004445235688`}}]}, 
   {Hue[0.5826229689660523], AbsoluteThickness[0.5], 
    LineBox[{{7.803016429585375, -0.1022010790450896}, {7.833486321960865, 
     0.06190485011657376}}]}, 
   {Hue[0.5836401654445322], AbsoluteThickness[0.5], 
    LineBox[{{7.833486321960865, 0.06190485011657379}, {7.858298387098312, 
     0.3435221777820815}}]}, 
   {Hue[0.5600940680800589], AbsoluteThickness[0.5], 
    LineBox[{{7.690458986265605, 0.36953437824546914`}, {7.749753527018152, 
     0.5938039627775216}}]}, 
   {Hue[0.5605202727087012], AbsoluteThickness[0.5], 
    LineBox[{{7.749753527018152, 0.5938039627775216}, {7.8349985987335655`, 
     0.9202387976421}}]}, 
   {Hue[0.6791279309672654], AbsoluteThickness[0.5], 
    LineBox[{{6.119572882381925, -1.2482026719749497`}, {
     6.068647697170132, -1.3599149605943956`}}]}, 
   {Hue[0.6796308253235319], AbsoluteThickness[0.5], 
    LineBox[{{6.068647697170132, -1.3599149605943956`}, {
     5.929719700892593, -1.6362025143293077`}}]}, 
   {Hue[0.6614998947455524], AbsoluteThickness[0.5], 
    LineBox[{{7.619886143074046, -0.8010074378144955}, {
     7.5977794364553874`, -0.8319338257462009}}]}, 
   {Hue[0.6619821979267071], AbsoluteThickness[0.5], 
    LineBox[{{7.5977794364553874`, -0.8319338257462009}, {
     7.427516535745411, -1.0874871012417577`}}]}, 
   {Hue[0.6707489449299917], AbsoluteThickness[0.5], 
    LineBox[{{5.820724544607654, -0.49718041075457214`}, {
     5.646455301951351, -0.47705809036886604`}}]}, 
   {Hue[0.6714328454277406], AbsoluteThickness[0.5], 
    LineBox[{{5.646455301951351, -0.47705809036886604`}, {
     5.354120582941557, -0.4630335399352374}}]}, 
   {Hue[0.6611246070739695], AbsoluteThickness[0.5], 
    LineBox[{{8.439269748494217, 1.1766608633272888`}, {8.292621747385144, 
     0.9241320856617431}}]}, 
   {Hue[0.6615551364410596], AbsoluteThickness[0.5], 
    LineBox[{{8.292621747385144, 0.9241320856617431}, {8.130656709383604, 
     0.6388832522562267}}]}, 
   {Hue[0.2621969004630662], AbsoluteThickness[0.5], 
    LineBox[{{7.510336669031569, 1.6718640383964265`}, {7.421974880164028, 
     1.8820557478341216`}}]}, 
   {Hue[0.26371178478971213`], AbsoluteThickness[0.5], 
    LineBox[{{7.421974880164028, 1.8820557478341216`}, {7.348934085334367, 
     2.1398846131055422`}}]}, 
   {Hue[0.6904054007446278], AbsoluteThickness[0.5], 
    LineBox[{{7.348934085334367, 2.1398846131055422`}, {7.615701757275222, 
     2.165295057488778}}]}, 
   {Hue[0.42553508571157694`], AbsoluteThickness[0.5], 
    LineBox[{{7.040900872638703, 1.3197565339429709`}, {6.866931241548715, 
     1.3547954888246068`}}]}, 
   {Hue[0.4267241709426297], AbsoluteThickness[0.5], 
    LineBox[{{6.866931241548715, 1.3547954888246068`}, {6.605518293673161, 
     1.3790799174676178`}}]}, 
   {Hue[0.5929263725941781], AbsoluteThickness[0.5], 
    LineBox[{{7.106088075246317, 0.7596988837535565}, {7.040994918127893, 
     0.6095682654268679}}]}, 
   {Hue[0.5933695143259622], AbsoluteThickness[0.5], 
    LineBox[{{7.040994918127893, 0.6095682654268679}, {6.91980015645421, 
     0.31529250183649343`}}]}, 
   {Hue[0.578210389428262], AbsoluteThickness[0.5], 
    LineBox[{{5.409400801227912, 0.6641483264572462}, {5.372880531147393, 
     0.6819162183506846}}]}, 
   {Hue[0.578639299526547], AbsoluteThickness[0.5], 
    LineBox[{{5.372880531147393, 0.6819162183506846}, {5.101400640576203, 
     0.8166620319653274}}]}, 
   {Hue[0.34820720650679277`], AbsoluteThickness[0.5], 
    LineBox[{{6.272948231956461, 1.413600155176027}, {6.2007697602529515`, 
     1.5789776843301842`}}]}, 
   {Hue[0.34990311275160074`], AbsoluteThickness[0.5], 
    LineBox[{{6.2007697602529515`, 1.5789776843301842`}, {6.134016072747441, 
     1.8090899378427323`}}]}, 
   {Hue[0.5940185276723359], AbsoluteThickness[0.5], 
    LineBox[{{7.698353212626806, 1.016216588551541}, {7.759286172609318, 
     1.143947778102499}}]}, 
   {Hue[0.5945061725724122], AbsoluteThickness[0.5], 
    LineBox[{{7.759286172609318, 1.143947778102499}, {7.865425709899865, 
     1.3876485083300707`}}]}, 
   {Hue[0.42564308067206014`], AbsoluteThickness[0.5], 
    LineBox[{{5.100258828555836, -0.21570262285716993`}, {
     4.870101857093866, -0.17005402570289369`}}]}, 
   {Hue[0.42649193277961095`], AbsoluteThickness[0.5], 
    LineBox[{{4.870101857093866, -0.17005402570289369`}, {
     4.593231204258052, -0.13873974349099893`}}]}, 
   {Hue[0.5561260172647392], AbsoluteThickness[0.5], 
    LineBox[{{6.4495131212597725`, -2.1191507762765758`}, {
     6.47466567980867, -2.2964696932332656`}}]}, 
   {Hue[0.5566167101622179], AbsoluteThickness[0.5], 
    LineBox[{{6.47466567980867, -2.2964696932332656`}, {
     6.533363215786913, -2.6263926686410266`}}]}, 
   {Hue[0.49997218557180784`], AbsoluteThickness[0.5], 
    LineBox[{{4.418948562849473, -1.580508050698262}, {
     4.359971760385006, -1.596852366038446}}]}, 
   {Hue[0.50073587669954], AbsoluteThickness[0.5], 
    LineBox[{{4.359971760385006, -1.596852366038446}, {
     4.058730362783512, -1.7053938181796608`}}]}, 
   {Hue[0.56511701699925], AbsoluteThickness[0.5], 
    LineBox[{{4.637601806914382, 1.375946308869912}, {4.637503307978245, 
     1.3760901988449212`}}]}, 
   {Hue[0.5656240277338629], AbsoluteThickness[0.5], 
    LineBox[{{4.637503307978245, 1.3760901988449212`}, {4.486143626927396, 
     1.5796198589160806`}}]}, 
   {Hue[0.6475984621118982], AbsoluteThickness[0.5], 
    LineBox[{{6.697543246409562, -2.5365602268206597`}, {
     7.143530437194431, -2.7576384685235564`}}]}, 
   {Hue[0.6480677406581198], AbsoluteThickness[0.5], 
    LineBox[{{7.143530437194431, -2.7576384685235564`}, {
     7.412773963335607, -2.8815273202644174`}}]}, 
   {Hue[0.341474218508373], AbsoluteThickness[0.5], 
    LineBox[{{5.249028000565526, -2.895737306005449}, {
     4.997651340758125, -3.329384392833915}}]}, 
   {Hue[0.342224397348183], AbsoluteThickness[0.5], 
    LineBox[{{4.997651340758125, -3.329384392833915}, {
     4.8715294376352425`, -3.589683807187125}}]}, 
   {Hue[0.6577440732701779], AbsoluteThickness[0.5], 
    LineBox[{{4.377201202344631, -1.9048784719246465`}, {
     4.289768181625381, -1.9055335966364573`}}]}, 
   {Hue[0.6732486549333815], AbsoluteThickness[0.5], 
    LineBox[{{4.289768181625381, -1.9055335966364573`}, {
     4.102690140001282, -1.8520831592761535`}}]}, 
   {Hue[0.6372440864954028], AbsoluteThickness[0.5], 
    LineBox[{{2.852590123666429, -1.5145350941360707`}, {
     2.736497892605995, -1.5681910462811581`}}]}, 
   {Hue[0.640797168745741], AbsoluteThickness[0.5], 
    LineBox[{{2.736497892605995, -1.5681910462811581`}, {
     2.5574233999406477`, -1.6934763461167557`}}]}, 
   {Hue[0.687584542808703], AbsoluteThickness[0.5], 
    LineBox[{{3.4480654296593887`, 3.6238357671843278`}, {3.636700321480725, 
     3.7907317641275173`}}]}, 
   {Hue[0.6888790289795105], AbsoluteThickness[0.5], 
    LineBox[{{3.636700321480725, 3.7907317641275173`}, {3.839720893251104, 
     3.9334259681391184`}}]}, 
   {Hue[0.5134569633530583], AbsoluteThickness[0.5], 
    LineBox[{{2.7538368999740435`, -3.886314270252309}, {
     2.6861254573246036`, -3.9811937254661376`}}]}, 
   {Hue[0.514193604485969], AbsoluteThickness[0.5], 
    LineBox[{{2.6861254573246036`, -3.9811937254661376`}, {
     2.5008728600170835`, -4.204460560737765}}]}, 
   {Hue[0.5835308903091032], AbsoluteThickness[0.5], 
    LineBox[{{2.274966621675135, -3.359509014003251}, {
     2.1346341878818, -3.4291039756719437`}}]}, 
   {Hue[0.5839639823267657], AbsoluteThickness[0.5], 
    LineBox[{{2.1346341878818, -3.4291039756719437`}, {
     1.849000832544112, -3.566504332745907}}]}, 
   {Hue[0.5612837746656526], AbsoluteThickness[0.5], 
    LineBox[{{2.5921075592485754`, 1.1705369604128828`}, {2.4124564887571576`,
      1.2167347642044588`}}]}, 
   {Hue[0.561747001287752], AbsoluteThickness[0.5], 
    LineBox[{{2.4124564887571576`, 1.2167347642044588`}, {2.094920728946099, 
     1.2893399418312028`}}]}, 
   {Hue[0.5465712075736664], AbsoluteThickness[0.5], 
    LineBox[{{5.480440541972943, 2.138536697444207}, {5.376637774960482, 
     2.4103495719272336`}}]}, 
   {Hue[0.5572084267322346], AbsoluteThickness[0.5], 
    LineBox[{{5.194052355935229, 1.4032598958736007`}, {5.15860409041749, 
     1.434266826085851}}]}, 
   {Hue[0.5577313363111741], AbsoluteThickness[0.5], 
    LineBox[{{5.15860409041749, 1.434266826085851}, {4.906592675413393, 
     1.636403556319194}}]}, 
   {Hue[0.5439209186665899], AbsoluteThickness[0.5], 
    LineBox[{{5.757526553142145, -1.3617524174530566`}, {
     5.687825694562729, -1.4561349852109609`}}]}, 
   {Hue[0.5447260356691482], AbsoluteThickness[0.5], 
    LineBox[{{5.687825694562729, -1.4561349852109609`}, {
     5.506915179230448, -1.6642986975228595`}}]}, 
   {Hue[0.5706297094213144], AbsoluteThickness[0.5], 
    LineBox[{{6.100824399415988, 0.38712795898507624`}, {6.038474418119913, 
     0.4070715106930426}}]}, 
   {Hue[0.5716437112519939], AbsoluteThickness[0.5], 
    LineBox[{{6.038474418119913, 0.4070715106930426}, {5.806843527139206, 
     0.5063907779491743}}]}, 
   {Hue[0.5498786326968224], AbsoluteThickness[0.5], 
    LineBox[{{7.341158763311035, -0.5478834826480993}, {
     7.30657254290372, -0.5907880440285339}}]}, 
   {Hue[0.5503669391797903], AbsoluteThickness[0.5], 
    LineBox[{{7.30657254290372, -0.5907880440285339}, {
     7.089064848785108, -0.8805392112836646}}]}, 
   {Hue[0.22022473041018398`], AbsoluteThickness[0.5], 
    LineBox[{{8.308965817275022, -0.9374383623867352}, {
     8.27007496899289, -1.080011431696735}}]}, 
   {Hue[0.22067795550230776`], AbsoluteThickness[0.5], 
    LineBox[{{8.27007496899289, -1.080011431696735}, {
     8.199762254056463, -1.3634143532644176`}}]}, 
   {Hue[0.36957895366550814`], AbsoluteThickness[0.5], 
    LineBox[{{7.813078109565036, -0.577354086535449}, {
     7.7484730755022095`, -0.6008172594656177}}]}, 
   {Hue[0.38318785032021246`], AbsoluteThickness[0.5], 
    LineBox[{{7.7484730755022095`, -0.6008172594656177}, {
     7.619472750724593, -0.6936439482100208}}]}, 
   {Hue[0.5933769234087715], AbsoluteThickness[0.5], 
    LineBox[{{7.619472750724593, -0.6936439482100208}, {
     7.651447575254202, -0.8493214627465835}}]}, 
   {Hue[0.5358948852874573], AbsoluteThickness[0.5], 
    LineBox[{{7.581836918836688, 0.21262605063297377`}, {7.548547879546372, 
     0.3009079344597628}}]}, 
   {Hue[0.5363318713728671], AbsoluteThickness[0.5], 
    LineBox[{{7.548547879546372, 0.3009079344597628}, {7.415477219416373, 
     0.6385334147184625}}]}, 
   {Hue[0.6755209138250622], AbsoluteThickness[0.5], 
    LineBox[{{8.131412885772525, 0.08313908030315903}, {8.130746875173731, 
     0.0882108314599109}}]}, 
   {Hue[0.6767595812010017], AbsoluteThickness[0.5], 
    LineBox[{{8.130746875173731, 0.0882108314599109}, {8.12522248279647, 
     0.34197862684131836`}}]}, 
   {Hue[0.5500275713657559], AbsoluteThickness[0.5], 
    LineBox[{{7.301772394581715, 0.5463209944965997}, {6.927039911241529, 
     0.8190114254719124}}]}, 
   {Hue[0.5545716540688049], AbsoluteThickness[0.5], 
    LineBox[{{6.927039911241529, 0.8190114254719124}, {6.726188483215471, 
     0.9122956764785157}}]}, 
   {Hue[0.5723622735436066], AbsoluteThickness[0.5], 
    LineBox[{{5.670621316452382, -0.3830784591755282}, {
     5.538426621055585, -0.38294717460978067`}}]}, 
   {Hue[0.590440037649432], AbsoluteThickness[0.5], 
    LineBox[{{5.538426621055585, -0.38294717460978067`}, {
     5.3748429010454695`, -0.4330559216525751}}]}, 
   {Hue[0.5445890728779899], AbsoluteThickness[0.5], 
    LineBox[{{5.882671680179077, 1.0064335206823334`}, {5.821263270489169, 
     1.0745129924317638`}}]}, 
   {Hue[0.5451385957396098], AbsoluteThickness[0.5], 
    LineBox[{{5.821263270489169, 1.0745129924317638`}, {5.605909087231291, 
     1.337522307678692}}]}, 
   {Hue[0.5784458771911947], AbsoluteThickness[0.5], 
    LineBox[{{5.130231533150663, -1.8235389794736816`}, {
     5.083309505364348, -1.9137823932405618`}}]}, 
   {Hue[0.5791558033826081], AbsoluteThickness[0.5], 
    LineBox[{{5.083309505364348, -1.9137823932405618`}, {
     4.937656294966853, -2.151654359134207}}]}, 
   {Hue[0.5044633115202086], AbsoluteThickness[0.5], 
    LineBox[{{5.392469756690759, -2.6042841980883122`}, {
     5.3873120537390795`, -2.6355278569901066`}}]}, 
   {Hue[0.5063679795678934], AbsoluteThickness[0.5], 
    LineBox[{{5.3873120537390795`, -2.6355278569901066`}, {
     5.311838667570306, -2.8792764846880274`}}]}, 
   {Hue[0.5591509221429359], AbsoluteThickness[0.5], 
    LineBox[{{3.5870701282812703`, -1.8623550741277144`}, {
     3.5791253003265644`, -1.867944628679391}}]}, 
   {Hue[0.5598017521493635], AbsoluteThickness[0.5], 
    LineBox[{{3.5791253003265644`, -1.867944628679391}, {
     3.387305352562622, -2.021834095195231}}]}, 
   {Hue[0.6057049200272114], AbsoluteThickness[0.5], 
    LineBox[{{2.2326337526402518`, -0.43448804352089077`}, {
     2.1599175024837463`, -0.45257923420293295`}}]}, 
   {Hue[0.6061824789313109], AbsoluteThickness[0.5], 
    LineBox[{{2.1599175024837463`, -0.45257923420293295`}, {
     1.8571130682154622`, -0.5178558836611052}}]}, 
   {Hue[0.6497034213102516], AbsoluteThickness[0.5], 
    LineBox[{{3.0968822287330457`, -3.147230657597475}, {
     2.9475588978016596`, -3.397532648714622}}]}, 
   {Hue[0.6520548244378315], AbsoluteThickness[0.5], 
    LineBox[{{2.9475588978016596`, -3.397532648714622}, {
     2.8615781542418333`, -3.6081451992747553`}}]}, 
   {Hue[0.6984076473836868], AbsoluteThickness[0.5], 
    LineBox[{{3.6587363810070537`, 3.3784145441020645`}, {3.655746978780111, 
     3.3854934195540536`}}]}, 
   {Hue[0.6992264916019207], AbsoluteThickness[0.5], 
    LineBox[{{3.655746978780111, 3.3854934195540536`}, {3.5236279153002164`, 
     3.639161950739819}}]}, 
   {Hue[0.23452594639886837`], AbsoluteThickness[0.5], 
    LineBox[{{7.292222293829205, -1.9328090461082534`}, {
     7.335513983141616, -1.9752076344400105`}}]}, 
   {Hue[0.2362909023750326], AbsoluteThickness[0.5], 
    LineBox[{{7.335513983141616, -1.9752076344400105`}, {
     7.509977518663065, -2.1059784864761806`}}]}, 
   {Hue[0.6476260896787946], AbsoluteThickness[0.5], 
    LineBox[{{7.509977518663065, -2.1059784864761806`}, {
     7.620240934938551, -1.9178813838930502`}}]}, 
   {Hue[0.5880857456726707], AbsoluteThickness[0.5], 
    LineBox[{{2.896744195807954, 0.4800548107756964}, {2.590704837167731, 
     0.4186000946987386}}]}, 
   {Hue[0.5912284619854041], AbsoluteThickness[0.5], 
    LineBox[{{2.590704837167731, 0.4186000946987386}, {2.37457278013143, 
     0.41236772940879196`}}]}, 
   {Hue[0.5947548149439115], AbsoluteThickness[0.5], 
    LineBox[{{4.096342521451647, 1.2875090619583176`}, {3.985412669873419, 
     1.3483219705577132`}}]}, 
   {Hue[0.6091272574366934], AbsoluteThickness[0.5], 
    LineBox[{{3.985412669873419, 1.3483219705577132`}, {3.8712640103931544`, 
     1.461513623156924}}]}, 
   {Hue[0.6948059520941662], AbsoluteThickness[0.5], 
    LineBox[{{7.555992663212056, -0.18865427982325889`}, {
     7.5269205146900795`, -0.3357868271064226}}]}, 
   {Hue[0.695246572360837], AbsoluteThickness[0.5], 
    LineBox[{{7.5269205146900795`, -0.3357868271064226}, {
     7.463355290549831, -0.6309110554032935}}]}, 
   {Hue[0.37161778254397043`], AbsoluteThickness[0.5], 
    LineBox[{{8.161770611381012, -0.046533631092921524`}, {
     8.239522749438663, -0.06721614685269262}}]}, 
   {Hue[0.3781509164341421], AbsoluteThickness[0.5], 
    LineBox[{{8.239522749438663, -0.06721614685269264}, {
     8.420825885483094, -0.16157032324309478`}}]}, 
   {Hue[0.6592264252750921], AbsoluteThickness[0.5], 
    LineBox[{{8.420825885483094, -0.16157032324309478`}, {
     8.382237238207516, -0.3622801985439811}}]}, 
   {Hue[0.4860829847135609], AbsoluteThickness[0.5], 
    LineBox[{{7.64109911063895, 0.5062998498842268}, {7.732957557228306, 
     0.37994658026048134`}}]}, 
   {Hue[0.4867750268696161], AbsoluteThickness[0.5], 
    LineBox[{{7.732957557228306, 0.37994658026048134`}, {7.895791654618303, 
     0.12060283839371863`}}]}, 
   {Hue[0.5913897351359905], AbsoluteThickness[0.5], 
    LineBox[{{7.036429634414309, 0.2980366119365171}, {7.0576178337498, 
     0.1585054999175927}}]}, 
   {Hue[0.5919054266752104], AbsoluteThickness[0.5], 
    LineBox[{{7.0576178337498, 0.1585054999175927}, {
     7.082057043420267, -0.06360337386427108}}]}, 
   {Hue[0.40479506393551357`], AbsoluteThickness[0.5], 
    LineBox[{{6.31762450123799, 2.590022773728822}, {6.290539015472427, 
     2.630882002483658}}]}, 
   {Hue[0.4052294239875311], AbsoluteThickness[0.5], 
    LineBox[{{6.290539015472427, 2.630882002483658}, {6.110310903769714, 
     2.9105980726534373`}}]}, 
   {Hue[0.5435818614212378], AbsoluteThickness[0.5], 
    LineBox[{{7.322720763102491, 2.003176579454123}, {7.08910239523788, 
     2.0916510931197934`}}]}, 
   {Hue[0.5446903762532818], AbsoluteThickness[0.5], 
    LineBox[{{7.08910239523788, 2.0916510931197934`}, {6.889523970784141, 
     2.1448611096221875`}}]}, 
   {Hue[0.05324625584664536], AbsoluteThickness[0.5], 
    LineBox[{{7.551129759968373, 2.2058365971629588`}, {7.5907937172647495`, 
     2.2358311309519157`}}]}, 
   {Hue[0.05377169705086837], AbsoluteThickness[0.5], 
    LineBox[{{7.5907937172647495`, 2.2358311309519157`}, {7.842869718411299, 
     2.40987936138732}}]}, 
   {Hue[0.5872740015187784], AbsoluteThickness[0.5], 
    LineBox[{{7.842869718411299, 2.40987936138732}, {7.733250214138802, 
     2.1238397467274224`}}]}, 
   {Hue[0.5451679395904093], AbsoluteThickness[0.5], 
    LineBox[{{7.601113440024909, 1.9046001711533702`}, {7.60873234377885, 
     1.816393563103377}}]}, 
   {Hue[0.5485960310028681], AbsoluteThickness[0.5], 
    LineBox[{{7.60873234377885, 1.816393563103377}, {7.668699245897137, 
     1.5921435030471}}]}, 
   {Hue[0.41606136102469055`], AbsoluteThickness[0.5], 
    LineBox[{{7.656122465802491, 1.50665042274029}, {7.720016315763232, 
     1.4008403825569462`}}]}, 
   {Hue[0.4164909240036779], AbsoluteThickness[0.5], 
    LineBox[{{7.720016315763232, 1.4008403825569462`}, {7.859236113709474, 
     1.1656995049785202`}}]}, 
   {Hue[0.5918472532544012], AbsoluteThickness[0.5], 
    LineBox[{{6.327944502512593, 0.9284076859007319}, {6.272335163420305, 
     0.8604307360127814}}]}, 
   {Hue[0.593782248597109], AbsoluteThickness[0.5], 
    LineBox[{{6.272335163420305, 0.8604307360127814}, {6.171091340426499, 
     0.6945427586502549}}]}, 
   {Hue[0.6573506694298962], AbsoluteThickness[0.5], 
    LineBox[{{5.864158033057047, 1.5034104926593594`}, {5.646621213246176, 
     1.4673432470730503`}}]}, 
   {Hue[0.6587781084798977], AbsoluteThickness[0.5], 
    LineBox[{{5.646621213246176, 1.4673432470730503`}, {5.4575270292587605`, 
     1.4585905239819008`}}]}, 
   {Hue[0.5094433420425789], AbsoluteThickness[0.5], 
    LineBox[{{5.866399564355644, 2.0761229014313405`}, {5.820134945130379, 
     2.177290120317691}}]}, 
   {Hue[0.5114229882043816], AbsoluteThickness[0.5], 
    LineBox[{{5.820134945130379, 2.177290120317691}, {5.727390254801979, 
     2.322599385388017}}]}, 
   {Hue[0.6933963576215957], AbsoluteThickness[0.5], 
    LineBox[{{6.407407272639543, 2.328413722614079}, {6.417736408221136, 
     2.3530769787542085`}}]}, 
   {Hue[0.6938296097379475], AbsoluteThickness[0.5], 
    LineBox[{{6.417736408221136, 2.3530769787542085`}, {6.543046556765034, 
     2.6627949900028285`}}]}, 
   {Hue[0.5740513207332157], AbsoluteThickness[0.5], 
    LineBox[{{5.674207869805691, -1.3368591895259816`}, {
     5.659558210693202, -1.4072733036443155`}}]}, 
   {Hue[0.5750087282582519], AbsoluteThickness[0.5], 
    LineBox[{{5.659558210693202, -1.4072733036443155`}, {
     5.581761193546521, -1.6617413904821767`}}]}, 
   {Hue[0.5840769649074793], AbsoluteThickness[0.5], 
    LineBox[{{4.390908773101687, -1.0628628581431236`}, {
     4.36351686402291, -1.0962100153696042`}}]}, 
   {Hue[0.5845046668182323], AbsoluteThickness[0.5], 
    LineBox[{{4.36351686402291, -1.0962100153696042`}, {
     4.1578609559231055`, -1.343423681350016}}]}, 
   {Hue[0.6671509037599833], AbsoluteThickness[0.5], 
    LineBox[{{3.889561485034637, 2.0458131144785923`}, {3.825496248402175, 
     2.1727980373814515`}}]}, 
   {Hue[0.6684133092222131], AbsoluteThickness[0.5], 
    LineBox[{{3.825496248402175, 2.1727980373814515`}, {3.710973166087805, 
     2.3486320899573454`}}]}, 
   {Hue[0.39606304630460526`], AbsoluteThickness[0.5], 
    LineBox[{{4.552750356711879, 2.6093036226808963`}, {4.431106332846696, 
     2.8152057995588318`}}]}, 
   {Hue[0.4022028390925353], AbsoluteThickness[0.5], 
    LineBox[{{4.431106332846696, 2.8152057995588318`}, {4.297858637767286, 
     2.958517964124089}}]}, 
   {Hue[0.6893763997220232], AbsoluteThickness[0.5], 
    LineBox[{{4.297858637767286, 2.958517964124089}, {4.1236371191860215`, 
     2.869410235954234}}]}, 
   {Hue[0.6362260485229325], AbsoluteThickness[0.5], 
    LineBox[{{6.451273495997101, 2.2115017920807754`}, {6.70762700808031, 
     2.321012056936536}}]}, 
   {Hue[0.6463006393161017], AbsoluteThickness[0.5], 
    LineBox[{{6.70762700808031, 2.321012056936536}, {6.8484066121077065`, 
     2.3425365709348624`}}]}, 
   {Hue[0.6798432547086177], AbsoluteThickness[0.5], 
    LineBox[{{5.256105137457783, 2.397760983609794}, {5.145199541016746, 
     2.4404799225640774`}}]}, 
   {Hue[0.6804375070043506], AbsoluteThickness[0.5], 
    LineBox[{{5.145199541016746, 2.4404799225640774`}, {4.910839694496389, 
     2.54594857149001}}]}, 
   {Hue[0.35273235767302064`], AbsoluteThickness[0.5], 
    LineBox[{{7.0422421505485, 2.151944818135586}, {7.090596269983999, 
     2.160696141509252}}]}, 
   {Hue[0.35350473304560437`], AbsoluteThickness[0.5], 
    LineBox[{{7.090596269983999, 2.160696141509252}, {7.354844770525024, 
     2.229684053172597}}]}, 
   {Hue[0.6650043273481699], AbsoluteThickness[0.5], 
    LineBox[{{7.4135144155510355`, 0.8051827220874821}, {7.852233401567906, 
     0.5118344910233393}}]}, 
   {Hue[0.6658012474095955], AbsoluteThickness[0.5], 
    LineBox[{{7.852233401567906, 0.5118344910233393}, {8.10655150150298, 
     0.3693298005733229}}]}, 
   {Hue[0.5698085216622614], AbsoluteThickness[0.5], 
    LineBox[{{7.419913494471442, -1.2970121431167412`}, {
     7.476281727189944, -1.3563002091140022`}}]}, 
   {Hue[0.5709614952316422], AbsoluteThickness[0.5], 
    LineBox[{{7.476281727189944, -1.3563002091140022`}, {
     7.631328414187725, -1.557702275150708}}]}, 
   {Hue[0.6936766668658102], AbsoluteThickness[0.5], 
    LineBox[{{4.953542473603414, -2.1522566838690143`}, {
     4.96811104003193, -2.3202560642215424`}}]}, 
   {Hue[0.6941053838968154], AbsoluteThickness[0.5], 
    LineBox[{{4.96811104003193, -2.3202560642215424`}, {
     4.991206006908431, -2.612589870224008}}]}, 
   {Hue[0.631678630581968], AbsoluteThickness[0.5], 
    LineBox[{{4.178519219760383, 2.065907330556893}, {4.17134156419762, 
     2.0985959023902354`}}]}, 
   {Hue[0.6325817514958654], AbsoluteThickness[0.5], 
    LineBox[{{4.17134156419762, 2.0985959023902354`}, {4.135235673754737, 
     2.377790205066963}}]}, 
   {Hue[0.5891912890990201], AbsoluteThickness[0.5], 
    LineBox[{{3.409997432556123, 1.9863357648402198`}, {3.3200830994882886`, 
     2.070604544794815}}]}, 
   {Hue[0.5901485269300291], AbsoluteThickness[0.5], 
    LineBox[{{3.3200830994882886`, 2.070604544794815}, {3.139126996476194, 
     2.274347432322024}}]}, 
   {Hue[0.6948607471875846], AbsoluteThickness[0.5], 
    LineBox[{{2.847837552246246, 0.9730929997149884}, {2.1348507958747893`, 
     0.5351804800541071}}]}, 
   {Hue[0.6953034191176424], AbsoluteThickness[0.5], 
    LineBox[{{2.1348507958747893`, 0.5351804800541071}, {1.9337668468916682`, 
     0.4065800783784195}}]}, 
   {Hue[0.5502988716327867], AbsoluteThickness[0.5], 
    LineBox[{{2.903933305517268, -2.0655004347039867`}, {
     2.8330900525608267`, -2.1095412480270586`}}]}, 
   {Hue[0.5507402111345884], AbsoluteThickness[0.5], 
    LineBox[{{2.8330900525608267`, -2.1095412480270586`}, {
     2.5639091577048396`, -2.283473602966811}}]}, 
   {Hue[0.6938270186504606], AbsoluteThickness[0.5], 
    LineBox[{{5.724339415876592, 0.6247243540171241}, {5.809233254303767, 
     0.5722180916291555}}]}, 
   {Hue[0.6943257899203603], AbsoluteThickness[0.5], 
    LineBox[{{5.809233254303767, 0.5722180916291555}, {6.0636562489049926`, 
     0.42765724960114687`}}]}, 
   {Hue[0.6041944635788796], AbsoluteThickness[0.5], 
    LineBox[{{6.60788061537168, -0.08365298490173734}, {
     6.616959258651195, -0.09769262274844862}}]}, 
   {Hue[0.6046203744613112], AbsoluteThickness[0.5], 
    LineBox[{{6.616959258651195, -0.09769262274844862}, {
     6.796835466404744, -0.37473224979044134`}}]}, 
   {Hue[0.6199255817382147], AbsoluteThickness[0.5], 
    LineBox[{{5.36889740982916, 2.5958607035538153`}, {5.350935027247329, 
     2.6307544546570227`}}]}, 
   {Hue[0.620440025484588], AbsoluteThickness[0.5], 
    LineBox[{{5.350935027247329, 2.6307544546570227`}, {5.22008251226371, 
     2.8613027319903215`}}]}, 
   {Hue[0.2339779766750106], AbsoluteThickness[0.5], 
    LineBox[{{6.823274588344199, 2.861674068874864}, {6.9079302599434875`, 
     2.9165524309119584`}}]}, 
   {Hue[0.23443272110703123`], AbsoluteThickness[0.5], 
    LineBox[{{6.9079302599434875`, 2.9165524309119584`}, {7.1383892426434965`,
      3.05829815803376}}]}, 
   {Hue[0.630274095177686], AbsoluteThickness[0.5], 
    LineBox[{{6.557534532410283, 1.3557584169243782`}, {6.57158932924559, 
     1.318790030818873}}]}, 
   {Hue[0.6323878424364172], AbsoluteThickness[0.5], 
    LineBox[{{6.57158932924559, 1.318790030818873}, {6.685613320647193, 
     1.1133562302976907`}}]}, 
   {Hue[0.6098434813154897], AbsoluteThickness[0.5], 
    LineBox[{{3.883695840037536, 2.6068893378982416`}, {3.859743035070066, 
     2.6602026055348347`}}]}, 
   {Hue[0.6103048239983618], AbsoluteThickness[0.5], 
    LineBox[{{3.859743035070066, 2.6602026055348347`}, {3.7473901064006174`, 
     2.89368500304916}}]}, 
   {Hue[0.5184988637516118], AbsoluteThickness[0.5], 
    LineBox[{{4.238758311999491, -3.909945917628075}, {
     4.251995793853607, -4.04953416732922}}]}, 
   {Hue[0.5189266008199137], AbsoluteThickness[0.5], 
    LineBox[{{4.251995793853607, -4.04953416732922}, {
     4.2838136894081, -4.364024216847826}}]}, 
   {Hue[0.6883771963130723], AbsoluteThickness[0.5], 
    LineBox[{{2.153989211283725, 2.347444225042594}, {2.1434758001048335`, 
     2.663144305795893}}]}, 
   {Hue[0.6890404955763424], AbsoluteThickness[0.5], 
    LineBox[{{2.1434758001048335`, 2.663144305795893}, {2.1508851683884687`, 
     2.8999633502122433`}}]}, 
   {Hue[0.641975789987579], AbsoluteThickness[0.5], 
    LineBox[{{3.1665987878374544`, -3.4070128673919564`}, {
     3.1468498408564383`, -3.4614840176499833`}}]}, 
   {Hue[0.6429568440735777], AbsoluteThickness[0.5], 
    LineBox[{{3.1468498408564383`, -3.4614840176499833`}, {
     3.031801653807409, -3.705188711035731}}]}, 
   {Hue[0.6945659709330885], AbsoluteThickness[0.5], 
    LineBox[{{3.2309947927534743`, -0.12692623379782494`}, {
     3.1868723245510786`, -0.1178682617578587}}]}, 
   {Hue[0.695047053502265], AbsoluteThickness[0.5], 
    LineBox[{{3.1868723245510786`, -0.1178682617578587}, {
     2.880216504554785, -0.04444175777973724}}]}, 
   {Hue[0.49558229156592687`], AbsoluteThickness[0.5], 
    LineBox[{{6.124609311267963, -3.124922046863884}, {
     6.13393897836381, -3.162286744329215}}]}, 
   {Hue[0.49655358567769003`], AbsoluteThickness[0.5], 
    LineBox[{{6.13393897836381, -3.162286744329215}, {
     6.21885540305325, -3.404457330070654}}]}, 
   {Hue[0.6699746388872013], AbsoluteThickness[0.5], 
    LineBox[{{3.8491053960572787`, -1.4936134599775535`}, {
     3.688184543733616, -1.5356003916659369`}}]}, 
   {Hue[0.6706023342776017], AbsoluteThickness[0.5], 
    LineBox[{{3.688184543733616, -1.5356003916659369`}, {
     3.380636448174245, -1.5964200764941456`}}]}, 
   {Hue[0.5641615964033727], AbsoluteThickness[0.5], 
    LineBox[{{6.400947668504853, 0.1616431659666841}, {6.388466604876646, 
     0.2284289514711261}}]}, 
   {Hue[0.5668758900132581], AbsoluteThickness[0.5], 
    LineBox[{{6.388466604876646, 0.2284289514711261}, {6.311731109791709, 
     0.4423414635259728}}]}, 
   {Hue[0.6661085209529276], AbsoluteThickness[0.5], 
    LineBox[{{6.422211858761835, -0.43096859656081427`}, {
     6.33212946071477, -0.39797758940635464`}}]}, 
   {Hue[0.666719626548338], AbsoluteThickness[0.5], 
    LineBox[{{6.33212946071477, -0.39797758940635464`}, {
     6.049850131622351, -0.27571108474386474`}}]}, 
   {Hue[0.6615360143160884], AbsoluteThickness[0.5], 
    LineBox[{{7.6109103897276285`, -0.7673194060086646}, {
     7.395675702454272, -0.8555694927910606}}]}, 
   {Hue[0.6636601921095595], AbsoluteThickness[0.5], 
    LineBox[{{7.395675702454272, -0.8555694927910606}, {
     7.134797655288283, -0.9209051371933594}}]}, 
   {Hue[0.11875797809424592`], AbsoluteThickness[0.5], 
    LineBox[{{7.895500239498922, -0.7891950491012565}, {
     8.105446178707219, -0.7988593201712213}}]}, 
   {Hue[0.11923302849571385`], AbsoluteThickness[0.5], 
    LineBox[{{8.105446178707219, -0.7988593201712213}, {
     8.450617184266829, -0.8041182156868756}}]}, 
   {Hue[0.6629268124963005], AbsoluteThickness[0.5], 
    LineBox[{{8.450617184266829, -0.8041182156868756}, {
     8.139924490823192, -0.6536498492379236}}]}, 
   {Hue[0.6624857953437141], AbsoluteThickness[0.5], 
    LineBox[{{7.646648554229892, -0.6493996089312503}, {
     7.562267940863301, -0.605350810648031}}]}, 
   {Hue[0.6631482768472488], AbsoluteThickness[0.5], 
    LineBox[{{7.562267940863301, -0.605350810648031}, {
     7.325903510265283, -0.46186865000579325`}}]}, 
   {Hue[0.6692218491118144], AbsoluteThickness[0.5], 
    LineBox[{{6.665704507844567, -0.9044859243191652}, {
     6.647377821063877, -0.9040534801312947}}]}, 
   {Hue[0.6699939606952524], AbsoluteThickness[0.5], 
    LineBox[{{6.647377821063877, -0.9040534801312947}, {
     6.3713677431193, -0.9186151178417657}}]}, 
   {Hue[0.5708625902706848], AbsoluteThickness[0.5], 
    LineBox[{{6.599808318449947, -1.6513953757555468`}, {
     6.516881228602825, -1.806352334500181}}]}, 
   {Hue[0.5713468735342957], AbsoluteThickness[0.5], 
    LineBox[{{6.516881228602825, -1.806352334500181}, {
     6.379335896513874, -2.085412588603809}}]}, 
   {Hue[0.6704301497147027], AbsoluteThickness[0.5], 
    LineBox[{{4.619914941590726, -0.7271612514344342}, {
     4.417881756974629, -0.7252426733866172}}]}, 
   {Hue[0.6709531463487723], AbsoluteThickness[0.5], 
    LineBox[{{4.417881756974629, -0.7252426733866172}, {
     4.12284435269526, -0.7350330323557107}}]}, 
   {Hue[0.511640021947919], AbsoluteThickness[0.5], 
    LineBox[{{5.544132138120535, 0.6767810933628681}, {5.145887079524409, 
     1.0883075737967323`}}]}, 
   {Hue[0.5360959327394893], AbsoluteThickness[0.5], 
    LineBox[{{5.145887079524409, 1.0883075737967323`}, {4.994230525119114, 
     1.1669794558625997`}}]}, 
   {Hue[0.6921396456240176], AbsoluteThickness[0.5], 
    LineBox[{{4.994230525119114, 1.1669794558625997`}, {4.853294229931647, 
     1.070408568838077}}]}, 
   {Hue[0.6674656899502969], AbsoluteThickness[0.5], 
    LineBox[{{2.64606287838615, -0.8018753139606621}, {
     2.3170936485595788`, -0.833158077133503}}]}, 
   {Hue[0.6709913773901742], AbsoluteThickness[0.5], 
    LineBox[{{2.3170936485595788`, -0.8331580771335031}, {
     2.0999369210436822`, -0.8152657336802517}}]}, 
   {Hue[0.6909601632526723], AbsoluteThickness[0.5], 
    LineBox[{{2.3490324783105665`, -1.1453953453675132`}, {
     2.3241579555782543`, -1.1557110665551997`}}]}, 
   {Hue[0.69177450206121], AbsoluteThickness[0.5], 
    LineBox[{{2.3241579555782543`, -1.1557110665551997`}, {
     2.0787350858778306`, -1.2814039577305978`}}]}, 
   {Hue[0.5842621017029723], AbsoluteThickness[0.5], 
    LineBox[{{4.537704783443696, 2.134881290517207}, {4.445408035993258, 
     2.312692488071889}}]}, 
   {Hue[0.58554220711486], AbsoluteThickness[0.5], 
    LineBox[{{4.445408035993258, 2.312692488071889}, {4.355178594317804, 
     2.5468311143626847`}}]}, 
   {Hue[0.6977440657338478], AbsoluteThickness[0.5], 
    LineBox[{{6.358034586127154, -0.8598416516368165}, {
     6.631561869447946, -0.7406316263074831}}]}, 
   {Hue[0.6992662694509623], AbsoluteThickness[0.5], 
    LineBox[{{6.631561869447946, -0.7406316263074831}, {
     6.845695544525758, -0.6770125388893067}}]}, 
   {Hue[0.6097256828722813], AbsoluteThickness[0.5], 
    LineBox[{{5.2051950220119725`, -2.8931589049996567`}, {
     5.399848500305891, -2.9747139744484437`}}]}, 
   {Hue[0.6101913886908047], AbsoluteThickness[0.5], 
    LineBox[{{5.399848500305891, -2.9747139744484437`}, {
     5.651538893852952, -3.088480866580487}}]}, 
   {Hue[0.6323921092365677], AbsoluteThickness[0.5], 
    LineBox[{{2.1798533646973453`, -3.1018567484978803`}, {
     2.1412889264789725`, -3.1159937342609734`}}]}, 
   {Hue[0.6462055388113008], AbsoluteThickness[0.5], 
    LineBox[{{2.1412889264789725`, -3.1159937342609734`}, {
     1.9600685655216916`, -3.1295750351174574`}}]}, 
   {Hue[0.623788654532152], AbsoluteThickness[0.5], 
    LineBox[{{7.394111608702756, -0.2687878413373754}, {
     7.500524394862455, -0.19197174350592738`}}]}, 
   {Hue[0.6252872813114669], AbsoluteThickness[0.5], 
    LineBox[{{7.500524394862455, -0.19197174350592738`}, {
     7.665287425646017, -0.03956702474220075}}]}, 
   {Hue[0.6798771549733146], AbsoluteThickness[0.5], 
    LineBox[{{4.9000624923538, -3.3608039472912195`}, {
     4.897036351930555, -3.368234510543171}}]}, 
   {Hue[0.6846644409482563], AbsoluteThickness[0.5], 
    LineBox[{{4.897036351930555, -3.368234510543171}, {
     4.858622588968935, -3.56919944704185}}]}, 
   {Hue[0.5524668977663371], AbsoluteThickness[0.5], 
    LineBox[{{6.17456817794093, -2.95198472610044}, {
     6.32658982965677, -2.991663739369146}}]}, 
   {Hue[0.552892634332052], AbsoluteThickness[0.5], 
    LineBox[{{6.32658982965677, -2.991663739369146}, {
     6.634131531000934, -3.0719619480994393`}}]}, 
   {Hue[0.6642904565623328], AbsoluteThickness[0.5], 
    LineBox[{{2.8795367517094568`, -4.389693011475721}, {
     2.8817507045147397`, -4.394587131977253}}]}, 
   {Hue[0.6648108118869385], AbsoluteThickness[0.5], 
    LineBox[{{2.8817507045147397`, -4.394587131977253}, {
     3.026231222541645, -4.68118878265017}}]}, 
   {Hue[0.6986830592625685], AbsoluteThickness[0.5], 
    LineBox[{{3.5772886664684926`, -4.201053969143193}, {
     3.447239417791438, -4.2972358228152485`}}]}, 
   {Hue[0.5962882315182607], AbsoluteThickness[0.5], 
    LineBox[{{5.644316091753737, -3.4806753396259476`}, {
     5.7534319470788615`, -3.4270206873733966`}}]}, 
   {Hue[0.626706892760835], AbsoluteThickness[0.5], 
    LineBox[{{5.7534319470788615`, -3.4270206873733966`}, {
     5.866329565438444, -3.3110875034097034`}}]}, 
   {Hue[0.27529929821464344`], AbsoluteThickness[0.5], 
    LineBox[{{5.638125493917369, -4.1028458788106015`}, {
     5.645884946560857, -4.118159279056841}}]}, 
   {Hue[0.2757630915912154], AbsoluteThickness[0.5], 
    LineBox[{{5.645884946560857, -4.118159279056841}, {
     5.805708072520338, -4.413436912493349}}]}, 
   {Hue[0.623895238428415], AbsoluteThickness[0.5], 
    LineBox[{{5.090151487246294, -4.2139722767478345`}, {
     5.0432240103240815`, -4.355082224616573}}]}, 
   {Hue[0.6243308085058572], AbsoluteThickness[0.5], 
    LineBox[{{5.0432240103240815`, -4.355082224616573}, {
     4.93590655339797, -4.663412666117347}}]}, 
   {Hue[0.6950779582516061], AbsoluteThickness[0.5], 
    LineBox[{{5.636401316191984, -1.8615828957642224`}, {
     5.658190951998235, -1.849216098678765}}]}, 
   {Hue[0.6955899025561164], AbsoluteThickness[0.5], 
    LineBox[{{5.658190951998235, -1.849216098678765}, {
     5.916011929233098, -1.6888284034040753`}}]}, 
   {Hue[0.6036241094850646], AbsoluteThickness[0.5], 
    LineBox[{{5.9848120446204005`, -3.1720060350837165`}, {
     6.10203398467738, -3.250476150908984}}]}, 
   {Hue[0.6043699419354926], AbsoluteThickness[0.5], 
    LineBox[{{6.10203398467738, -3.250476150908984}, {
     6.337779794013787, -3.384264369261639}}]}, 
   {Hue[0.6169883630494238], AbsoluteThickness[0.5], 
    LineBox[{{7.076569717171966, -0.9406802164157528}, {
     7.122785088713447, -0.9127230019332337}}]}, 
   {Hue[0.6175472891470805], AbsoluteThickness[0.5], 
    LineBox[{{7.122785088713447, -0.9127230019332337}, {
     7.414490709319449, -0.7159150517247848}}]}, 
   {Hue[0.662592240193017], AbsoluteThickness[0.5], 
    LineBox[{{4.684913813812924, 1.4097076354724425`}, {4.675484803513788, 
     1.5561137582376623`}}]}, 
   {Hue[0.6631125568129215], AbsoluteThickness[0.5], 
    LineBox[{{4.675484803513788, 1.5561137582376623`}, {4.668918718869527, 
     1.8516964213326221`}}]}, 
   {Hue[0.6783482149837827], AbsoluteThickness[0.5], 
    LineBox[{{5.587611353298005, 2.1457394954163154`}, {5.595019980700425, 
     2.1654387691979124`}}]}, 
   {Hue[0.6800823256586748], AbsoluteThickness[0.5], 
    LineBox[{{5.595019980700425, 2.1654387691979124`}, {5.67825740711686, 
     2.321364133162266}}]}, 
   {Hue[0.6286247056440096], AbsoluteThickness[0.5], 
    LineBox[{{2.1674348972510074`, -4.436871634253457}, {
     2.151589618921411, -4.492170525374189}}]}, 
   {Hue[0.6328364046993462], AbsoluteThickness[0.5], 
    LineBox[{{2.1515896189214114`, -4.492170525374189}, {
     2.056385288825266, -4.680470306999031}}]}, 
   {Hue[0.6920358566674495], AbsoluteThickness[0.5], 
    LineBox[{{3.670326143665631, -4.1485748502879005`}, {
     3.6769992092339363`, -4.173621474163667}}]}, 
   {Hue[0.6926825858837905], AbsoluteThickness[0.5], 
    LineBox[{{3.6769992092339363`, -4.173621474163667}, {
     3.770010163461477, -4.451615706743826}}]}, 
   {Hue[0.5322907117924907], AbsoluteThickness[0.5], 
    LineBox[{{5.579082727013409, -3.654400353206119}, {
     5.630413558991187, -3.6668248217368986`}}]}, 
   {Hue[0.5328856224479367], AbsoluteThickness[0.5], 
    LineBox[{{5.630413558991187, -3.6668248217368986`}, {
     5.908461374811387, -3.750642945817226}}]}, 
   {Hue[0.6078856618918029], AbsoluteThickness[0.5], 
    LineBox[{{4.928831207720194, -3.265911486361361}, {
     5.096057070746652, -3.3281946972906895`}}]}, 
   {Hue[0.6091984005144999], AbsoluteThickness[0.5], 
    LineBox[{{5.096057070746652, -3.3281946972906895`}, {
     5.357972964306915, -3.3933818763277874`}}]}, 
   {Hue[0.48400157438108093`], AbsoluteThickness[0.5], 
    LineBox[{{8.037695893186287, -3.1976207350873174`}, {
     8.1520109230307, -3.2407665099208858`}}]}, 
   {Hue[0.48442761739979323`], AbsoluteThickness[0.5], 
    LineBox[{{8.1520109230307, -3.2407665099208858`}, {
     8.441441115664464, -3.3508201067963177`}}]}, 
   {Hue[0.6883755412555712], AbsoluteThickness[0.5], 
    LineBox[{{6.421824814544766, 1.680252306280024}, {6.566082204504703, 
     1.8360087977386677`}}]}, 
   {Hue[0.6920571939465385], AbsoluteThickness[0.5], 
    LineBox[{{6.566082204504703, 1.8360087977386677`}, {6.679520616593402, 
     2.014099144513647}}]}, 
   {Hue[0.5860209812780474], AbsoluteThickness[0.5], 
    LineBox[{{5.81102299602497, 3.412158309172562}, {5.847606256435702, 
     3.4668354000623545`}}]}, 
   {Hue[0.588276603088835], AbsoluteThickness[0.5], 
    LineBox[{{5.847606256435702, 3.4668354000623545`}, {5.974153831466134, 
     3.60618887209148}}]}, 
   {Hue[0.6452671261636763], AbsoluteThickness[0.5], 
    LineBox[{{5.4312365081996505`, -0.29663804968911817`}, {
     5.825919540225528, -0.5243770336296584}}]}, 
   {Hue[0.6467709649784619], AbsoluteThickness[0.5], 
    LineBox[{{5.825919540225528, -0.5243770336296584}, {
     6.017535277147618, -0.6058258364405791}}]}, 
   {Hue[0.569483765103946], AbsoluteThickness[0.5], 
    LineBox[{{2.136596856862243, -2.3303876148091587`}, {
     2.120721197755244, -2.3560467330724904`}}]}, 
   {Hue[0.5699295431156196], AbsoluteThickness[0.5], 
    LineBox[{{2.120721197755244, -2.3560467330724904`}, {
     1.9395587416653202`, -2.636310910594125}}]}, 
   {Hue[0.4988648249461799], AbsoluteThickness[0.5], 
    LineBox[{{4.274342891238699, 3.4671690983309635`}, {4.142545804275946, 
     3.548516159167919}}]}, 
   {Hue[0.4996543133079628], AbsoluteThickness[0.5], 
    LineBox[{{4.142545804275946, 3.548516159167919}, {3.912632299582414, 
     3.666766216145601}}]}, 
   {Hue[0.609453679028529], AbsoluteThickness[0.5], 
    LineBox[{{4.370188957245376, -2.319504349030078}, {
     4.203238754068385, -2.6145249066653347`}}]}, 
   {Hue[0.614718156035287], AbsoluteThickness[0.5], 
    LineBox[{{4.203238754068385, -2.6145249066653347`}, {
     4.147834099542077, -2.7872163612839236`}}]}, 
   {Hue[0.6354078705387517], AbsoluteThickness[0.5], 
    LineBox[{{4.22567405841697, -2.3853861198720026`}, {
     4.1114350148976, -2.3892940745239715`}}]}, 
   {Hue[0.6361999758155341], AbsoluteThickness[0.5], 
    LineBox[{{4.1114350148976, -2.3892940745239715`}, {
     3.8269803148109927`, -2.421395638487014}}]}, 
   {Hue[0.581083290101999], AbsoluteThickness[0.5], 
    LineBox[{{4.204978188829775, -0.9144005499123509}, {
     4.148749520324281, -0.9288121243286277}}]}, 
   {Hue[0.5815651889409477], AbsoluteThickness[0.5], 
    LineBox[{{4.148749520324281, -0.9288121243286277}, {
     3.847961158782051, -1.0165026893195102`}}]}, 
   {Hue[0.5709432718313909], AbsoluteThickness[0.5], 
    LineBox[{{4.594036529338442, 0.6757118203911825}, {4.419577269964835, 
     0.7917161330050018}}]}, 
   {Hue[0.5728032683657414], AbsoluteThickness[0.5], 
    LineBox[{{4.419577269964835, 0.7917161330050018}, {4.199864864931973, 
     0.8983009627323136}}]}, 
   {Hue[0.5692970553133059], AbsoluteThickness[0.5], 
    LineBox[{{5.586004614336115, 0.24672723876850278`}, {5.370120250051456, 
     0.24257237473578994`}}]}, 
   {Hue[0.5697250694833638], AbsoluteThickness[0.5], 
    LineBox[{{5.370120250051456, 0.24257237473578994`}, {5.051959192898659, 
     0.2385815110206089}}]}, 
   {Hue[0.5688909075477168], AbsoluteThickness[0.5], 
    LineBox[{{6.590844928898939, 0.20726694231820708`}, {6.3806511103963, 
     0.2129784560141949}}]}, 
   {Hue[0.5695526487500769], AbsoluteThickness[0.5], 
    LineBox[{{6.3806511103963, 0.2129784560141949}, {6.08202873426027, 
     0.2403913781533282}}]}, 
   {Hue[0.5697800917145173], AbsoluteThickness[0.5], 
    LineBox[{{6.590997754928661, 0.20650087492591718`}, {6.377258603123303, 
     0.20732934330070063`}}]}, 
   {Hue[0.5705296422743047], AbsoluteThickness[0.5], 
    LineBox[{{6.377258603123303, 0.20732934330070063`}, {6.086043597166242, 
     0.23008017286883264`}}]}, 
   {Hue[0.5900239676454098], AbsoluteThickness[0.5], 
    LineBox[{{5.921677910940088, -0.12012063392163659`}, {
     5.60255776390126, -0.055322308966082784`}}]}, 
   {Hue[0.5916086711798562], AbsoluteThickness[0.5], 
    LineBox[{{5.60255776390126, -0.055322308966082784`}, {5.432638829135789, 
     0.001957656128148362}}]}, 
   {Hue[0.5838895122249652], AbsoluteThickness[0.5], 
    LineBox[{{5.776263785060849, -1.360904970108695}, {
     5.684043465287026, -1.4465934980452808`}}]}, 
   {Hue[0.5844119714584189], AbsoluteThickness[0.5], 
    LineBox[{{5.684043465287026, -1.4465934980452808`}, {
     5.454028017084742, -1.6427617749203458`}}]}, 
   {Hue[0.5712851706739132], AbsoluteThickness[0.5], 
    LineBox[{{4.101218836295858, 0.7869239311739157}, {3.9054033257398477`, 
     0.8364038253789561}}]}, 
   {Hue[0.5720439361692983], AbsoluteThickness[0.5], 
    LineBox[{{3.9054033257398477`, 0.8364038253789561}, {3.63183006274481, 
     0.8840691581865909}}]}, 
   {Hue[0.6057164048417054], AbsoluteThickness[0.5], 
    LineBox[{{5.11900056276031, -3.076256904103008}, {
     5.102212776673569, -3.177604173976496}}]}, 
   {Hue[0.6166370019210079], AbsoluteThickness[0.5], 
    LineBox[{{5.102212776673569, -3.177604173976496}, {
     5.1201059873986505`, -3.3673397614158103`}}]}, 
   {Hue[0.6144473994328967], AbsoluteThickness[0.5], 
    LineBox[{{2.561802565991818, 0.2784010440633579}, {2.1606018757314835`, 
     0.43321925870341277`}}]}, 
   {Hue[0.6148937347924199], AbsoluteThickness[0.5], 
    LineBox[{{2.1606018757314835`, 0.43321925870341277`}, {
     1.9366430112464637`, 0.5145237818790009}}]}, 
   {Hue[0.6797703913778158], AbsoluteThickness[0.5], 
    LineBox[{{3.621359343349023, 1.8443185283862658`}, {3.572607182996253, 
     1.8813502951484329`}}]}, 
   {Hue[0.6807481096967624], AbsoluteThickness[0.5], 
    LineBox[{{3.572607182996253, 1.8813502951484329`}, {3.40984555308592, 
     2.0307515259013695`}}]}, 
   {Hue[0.6119627055365453], AbsoluteThickness[0.5], 
    LineBox[{{4.148201117867823, 1.8440617646666544`}, {4.1461545369325545`, 
     1.8470872517433718`}}]}, 
   {Hue[0.612396134291094], AbsoluteThickness[0.5], 
    LineBox[{{4.1461545369325545`, 1.8470872517433718`}, {3.9573464658850694`,
      2.118942426898756}}]}, 
   {Hue[0.5561749119696684], AbsoluteThickness[0.5], 
    LineBox[{{7.593202605871944, 1.7696802621184873`}, {7.576046578912234, 
     1.888069559414004}}]}, 
   {Hue[0.5567066581494624], AbsoluteThickness[0.5], 
    LineBox[{{7.576046578912234, 1.888069559414004}, {7.513807308768862, 
     2.2145836392609417`}}]}, 
   {Hue[0.35395167740341055`], AbsoluteThickness[0.5], 
    LineBox[{{7.728045955913257, 1.9095544111967866`}, {7.914695998633557, 
     2.021660310721557}}]}, 
   {Hue[0.3570797045011979], AbsoluteThickness[0.5], 
    LineBox[{{7.914695998633557, 2.021660310721557}, {8.092304264001527, 
     2.0909250013635523`}}]}, 
   {Hue[0.5793686288255783], AbsoluteThickness[0.5], 
    LineBox[{{7.9091766341686744`, 1.8392750826180742`}, {8.102290567177018, 
     1.6975970150704869`}}]}, 
   {Hue[0.5826293429716608], AbsoluteThickness[0.5], 
    LineBox[{{8.102290567177018, 1.6975970150704869`}, {8.271794343534138, 
     1.6133713067154432`}}]}, 
   {Hue[0.6198759632148453], AbsoluteThickness[0.5], 
    LineBox[{{8.23102766911496, -1.8976020281344783`}, {
     8.333860052689962, -2.093456405931154}}]}, 
   {Hue[0.6242812831265666], AbsoluteThickness[0.5], 
    LineBox[{{8.333860052689962, -2.093456405931154}, {
     8.395524124599893, -2.2990859831031694`}}]}, 
   {Hue[0.5805557707677161], AbsoluteThickness[0.5], 
    LineBox[{{2.6978716276280292`, -1.3461904880284352`}, {
     2.5426387430519166`, -1.367164023722701}}]}, 
   {Hue[0.5836572080634089], AbsoluteThickness[0.5], 
    LineBox[{{2.5426387430519166`, -1.367164023722701}, {
     2.351561375345233, -1.4268501082215128`}}]}, 
   {Hue[0.5074004022906954], AbsoluteThickness[0.5], 
    LineBox[{{5.427040300609053, 2.067856124985877}, {5.365422708877116, 
     2.1154730011061}}]}, 
   {Hue[0.5078323803678866], AbsoluteThickness[0.5], 
    LineBox[{{5.365422708877116, 2.1154730011061}, {5.1022244808439545`, 
     2.323565140824154}}]}, 
   {Hue[0.5579038735497935], AbsoluteThickness[0.5], 
    LineBox[{{6.354297778610573, -2.059249900305226}, {
     6.349015290802563, -2.074988157747587}}]}, 
   {Hue[0.5583379839512479], AbsoluteThickness[0.5], 
    LineBox[{{6.349015290802563, -2.074988157747587}, {
     6.239906709783326, -2.3867466416051784`}}]}, 
   {Hue[0.5889253652611207], AbsoluteThickness[0.5], 
    LineBox[{{6.711032226184094, -1.884762065022832}, {
     6.636449355384614, -1.9219354215482805`}}]}, 
   {Hue[0.5893844735391607], AbsoluteThickness[0.5], 
    LineBox[{{6.636449355384614, -1.9219354215482805`}, {
     6.3512713762803905`, -2.0551342989204158`}}]}, 
   {Hue[0.6698281978693592], AbsoluteThickness[0.5], 
    LineBox[{{7.334229061698916, -0.42695045245047847`}, {
     7.333461584520993, -0.4073691337614379}}]}, 
   {Hue[0.6706495319472784], AbsoluteThickness[0.5], 
    LineBox[{{7.333461584520993, -0.4073691337614379}, {
     7.301824442867045, -0.14496588377955782`}}]}, 
   {Hue[0.668070102014791], AbsoluteThickness[0.5], 
    LineBox[{{8.163083998770357, -0.940964916813286}, {
     8.122312383642083, -0.8458789992676344}}]}, 
   {Hue[0.5721167231074555], AbsoluteThickness[0.5], 
    LineBox[{{8.025320886732034, -0.8787900241205219}, {
     7.845753435107716, -0.8618643195466151}}]}, 
   {Hue[0.5736093566894851], AbsoluteThickness[0.5], 
    LineBox[{{7.845753435107716, -0.8618643195466152}, {
     7.625742330799511, -0.8138373947869403}}]}, 
   {Hue[0.6987397855211958], AbsoluteThickness[0.5], 
    LineBox[{{7.96006334809905, -1.1492309740932498`}, {
     7.925856963433618, -1.15069526229957}}]}, 
   {Hue[0.6994682569884587], AbsoluteThickness[0.5], 
    LineBox[{{7.925856963433618, -1.15069526229957}, {
     7.628371102878871, -1.1849707382353623`}}]}, 
   {Hue[0.6867413072180836], AbsoluteThickness[0.5], 
    LineBox[{{6.902356419194153, -1.6581004445235688`}, {
     6.8231729285617755`, -1.6529552354858856`}}]}, 
   {Hue[0.6880238002855332], AbsoluteThickness[0.5], 
    LineBox[{{6.8231729285617755`, -1.6529552354858856`}, {
     6.599575636028021, -1.6632914445452884`}}]}, 
   {Hue[0.5846573619230121], AbsoluteThickness[0.5], 
    LineBox[{{7.858298387098312, 0.3435221777820815}, {7.857306247584444, 
     0.4703239431119499}}]}, 
   {Hue[0.6052574092049215], AbsoluteThickness[0.5], 
    LineBox[{{7.857306247584444, 0.4703239431119499}, {7.908870569285332, 
     0.6363405921956174}}]}, 
   {Hue[0.5609464773373434], AbsoluteThickness[0.5], 
    LineBox[{{7.8349985987335655`, 0.9202387976421}, {7.8665993152653675`, 
     1.0427721408829564`}}]}, 
   {Hue[0.578945612477818], AbsoluteThickness[0.5], 
    LineBox[{{7.8665993152653675`, 1.0427721408829564`}, {7.957399573447786, 
     1.1907794871119046`}}]}, 
   {Hue[0.6801337196797984], AbsoluteThickness[0.5], 
    LineBox[{{5.929719700892593, -1.6362025143293077`}, {
     5.910115564981473, -1.6717392951820378`}}]}, 
   {Hue[0.681130884069549], AbsoluteThickness[0.5], 
    LineBox[{{5.910115564981473, -1.6717392951820378`}, {
     5.7614451381756, -1.8897657093966496`}}]}, 
   {Hue[0.6624645011078619], AbsoluteThickness[0.5], 
    LineBox[{{7.427516535745411, -1.0874871012417577`}, {
     7.373103178520216, -1.1752830896059447`}}]}, 
   {Hue[0.662928251010395], AbsoluteThickness[0.5], 
    LineBox[{{7.373103178520216, -1.175283089605945}, {
     7.203976935424871, -1.432343928083896}}]}, 
   {Hue[0.6721167459254895], AbsoluteThickness[0.5], 
    LineBox[{{5.354120582941557, -0.4630335399352374}, {
     5.148505872676409, -0.4669576974966616}}]}, 
   {Hue[0.6726199225118045], AbsoluteThickness[0.5], 
    LineBox[{{5.148505872676409, -0.4669576974966616}, {
     4.8555560121133405`, -0.4837764862605864}}]}, 
   {Hue[0.6619856658081497], AbsoluteThickness[0.5], 
    LineBox[{{8.130656709383604, 0.6388832522562267}, {8.129160864155706, 
     0.6361881762410667}}]}, 
   {Hue[0.6624479786447828], AbsoluteThickness[0.5], 
    LineBox[{{8.129160864155706, 0.6361881762410667}, {7.962700276203219, 
     0.35421291790887827`}}]}, 
   {Hue[0.68889051641798], AbsoluteThickness[0.5], 
    LineBox[{{7.421974880164028, 1.8820557478341216`}, {7.333154680150007, 
     1.851110419410723}}]}, 
   {Hue[0.6897523968296337], AbsoluteThickness[0.5], 
    LineBox[{{7.333154680150007, 1.851110419410723}, {7.075181166291394, 
     1.7360589289094108`}}]}, 
   {Hue[0.2652266691163579], AbsoluteThickness[0.5], 
    LineBox[{{7.348934085334367, 2.1398846131055422`}, {7.340701567611936, 
     2.1928631620768386`}}]}, 
   {Hue[0.2674563202016598], AbsoluteThickness[0.5], 
    LineBox[{{7.340701567611936, 2.1928631620768386`}, {7.2750128182084195`, 
     2.404456802605155}}]}, 
   {Hue[0.6553383896578476], AbsoluteThickness[0.5], 
    LineBox[{{7.2750128182084195`, 2.404456802605155}, {7.064748356344884, 
     2.334630327773166}}]}, 
   {Hue[0.6919202850712737], AbsoluteThickness[0.5], 
    LineBox[{{7.615701757275222, 2.165295057488778}, {7.6364245465329, 
     2.164736826426478}}]}, 
   {Hue[0.6937075731903917], AbsoluteThickness[0.5], 
    LineBox[{{7.6364245465329, 2.164736826426478}, {7.873716585856401, 
     2.1898970367554913`}}]}, 
   {Hue[0.4279132561736824], AbsoluteThickness[0.5], 
    LineBox[{{6.605518293673161, 1.3790799174676178`}, {6.598431440155935, 
     1.378984327278222}}]}, 
   {Hue[0.43011894988758714`], AbsoluteThickness[0.5], 
    LineBox[{{6.598431440155935, 1.378984327278222}, {6.372371296183886, 
     1.4091519663780299`}}]}, 
   {Hue[0.5938126560577461], AbsoluteThickness[0.5], 
    LineBox[{{6.91980015645421, 0.31529250183649343`}, {6.904475339467136, 
     0.2760416222435866}}]}, 
   {Hue[0.596425925360649], AbsoluteThickness[0.5], 
    LineBox[{{6.904475339467136, 0.2760416222435866}, {6.791952908495986, 
     0.08374147770756987}}]}, 
   {Hue[0.579068209624832], AbsoluteThickness[0.5], 
    LineBox[{{5.101400640576203, 0.8166620319653274}, {5.051900372443935, 
     0.8417206611625272}}]}, 
   {Hue[0.5805607532181747], AbsoluteThickness[0.5], 
    LineBox[{{5.051900372443935, 0.8417206611625272}, {4.838990514160342, 
     0.9841394659698103}}]}, 
   {Hue[0.3515990189964087], AbsoluteThickness[0.5], 
    LineBox[{{6.134016072747441, 1.8090899378427323`}, {6.126852245084889, 
     1.8554976456070484`}}]}, 
   {Hue[0.3522662925678431], AbsoluteThickness[0.5], 
    LineBox[{{6.126852245084889, 1.8554976456070484`}, {6.058177141974077, 
     2.1652092660638718`}}]}, 
   {Hue[0.5949938174724887], AbsoluteThickness[0.5], 
    LineBox[{{7.865425709899865, 1.3876485083300707`}, {7.867345995680858, 
     1.3925069373016739`}}]}, 
   {Hue[0.5959164900151628], AbsoluteThickness[0.5], 
    LineBox[{{7.867345995680858, 1.3925069373016739`}, {7.971585357905859, 
     1.6000593918475816`}}]}, 
   {Hue[0.42734078488716176`], AbsoluteThickness[0.5], 
    LineBox[{{4.593231204258052, -0.13873974349099893`}, {
     4.408448493684566, -0.13329658941986544`}}]}, 
   {Hue[0.42831850763659074`], AbsoluteThickness[0.5], 
    LineBox[{{4.408448493684566, -0.13329658941986544`}, {
     4.110086273807027, -0.15228745046046818`}}]}, 
   {Hue[0.5571074030596969], AbsoluteThickness[0.5], 
    LineBox[{{6.533363215786913, -2.6263926686410266`}, {
     6.597228730009583, -2.9242302758706975`}}]}, 
   {Hue[0.5607795308524414], AbsoluteThickness[0.5], 
    LineBox[{{6.597228730009583, -2.9242302758706975`}, {
     6.6037717327071785`, -3.1320105407043783`}}]}, 
   {Hue[0.5014995678272722], AbsoluteThickness[0.5], 
    LineBox[{{4.058730362783512, -1.7053938181796608`}, {
     3.8347113048614405`, -1.8057895391221135`}}]}, 
   {Hue[0.5022196088968351], AbsoluteThickness[0.5], 
    LineBox[{{3.8347113048614405`, -1.8057895391221135`}, {
     3.6086057982016286`, -1.8883965789319122`}}]}, 
   {Hue[0.5661310384684759], AbsoluteThickness[0.5], 
    LineBox[{{4.486143626927396, 1.5796198589160806`}, {4.42363092430859, 
     1.6571450208865424`}}]}, 
   {Hue[0.5666278446097738], AbsoluteThickness[0.5], 
    LineBox[{{4.42363092430859, 1.6571450208865424`}, {4.212541434448424, 
     1.900104389151962}}]}, 
   {Hue[0.6485370192043414], AbsoluteThickness[0.5], 
    LineBox[{{7.412773963335607, -2.8815273202644174`}, {
     7.434403668167529, -2.890730841270008}}]}, 
   {Hue[0.6490008418970908], AbsoluteThickness[0.5], 
    LineBox[{{7.434403668167529, -2.890730841270008}, {
     7.6636234440920665`, -2.9956943239432876`}}]}, 
   {Hue[0.3429745761879929], AbsoluteThickness[0.5], 
    LineBox[{{4.8715294376352425`, -3.589683807187125}, {
     4.831127894125554, -3.691711938684029}}]}, 
   {Hue[0.3438545939166023], AbsoluteThickness[0.5], 
    LineBox[{{4.831127894125554, -3.691711938684029}, {
     4.716456323147216, -3.921562584586871}}]}, 
   {Hue[0.6887532365965845], AbsoluteThickness[0.5], 
    LineBox[{{4.102690140001282, -1.8520831592761535`}, {
     3.672228356374676, -1.5797477437396485`}}]}, 
   {Hue[0.6891836967157589], AbsoluteThickness[0.5], 
    LineBox[{{3.672228356374676, -1.5797477437396485`}, {
     3.3830611252289007`, -1.4006842239532256`}}]}, 
   {Hue[0.6443502509960791], AbsoluteThickness[0.5], 
    LineBox[{{2.5574233999406477`, -1.6934763461167557`}, {
     2.4491496056123974`, -1.8023174517324805`}}]}, 
   {Hue[0.6468823009763736], AbsoluteThickness[0.5], 
    LineBox[{{2.4491496056123974`, -1.8023174517324805`}, {
     2.3172326875036067`, -1.9841376138510303`}}]}, 
   {Hue[0.5149302456188797], AbsoluteThickness[0.5], 
    LineBox[{{2.5008728600170835`, -4.204460560737765}, {
     2.150947948282805, -4.5686760778861695`}}]}, 
   {Hue[0.5187828692826685], AbsoluteThickness[0.5], 
    LineBox[{{2.150947948282805, -4.5686760778861695`}, {
     1.976988881641963, -4.693501923196791}}]}, 
   {Hue[0.5465712075736664], AbsoluteThickness[0.5], 
    LineBox[{{5.376637774960482, 2.4103495719272336`}, {5.183091883339127, 
     2.571740312053556}}]}, 
   {Hue[0.5531644395180212], AbsoluteThickness[0.5], 
    LineBox[{{5.183091883339127, 2.571740312053556}, {5.11462032946465, 
     2.6608412636211796`}}]}, 
   {Hue[0.5582542458901136], AbsoluteThickness[0.5], 
    LineBox[{{4.906592675413393, 1.636403556319194}, {4.866288779793597, 
     1.6659980774718992`}}]}, 
   {Hue[0.5588045343740845], AbsoluteThickness[0.5], 
    LineBox[{{4.866288779793597, 1.6659980774718992`}, {4.6228213858257385`, 
     1.8273987966706309`}}]}, 
   {Hue[0.5455311526717067], AbsoluteThickness[0.5], 
    LineBox[{{5.506915179230448, -1.6642986975228595`}, {
     5.429566813406183, -1.740200603631091}}]}, 
   {Hue[0.5477536793094478], AbsoluteThickness[0.5], 
    LineBox[{{5.429566813406183, -1.740200603631091}, {
     5.233267415918655, -1.8831191840448234`}}]}, 
   {Hue[0.5726577130826731], AbsoluteThickness[0.5], 
    LineBox[{{5.806843527139206, 0.5063907779491743}, {5.64636367887999, 
     0.5941780502819028}}]}, 
   {Hue[0.5759065082495556], AbsoluteThickness[0.5], 
    LineBox[{{5.64636367887999, 0.5941780502819028}, {5.422780052690844, 
     0.6705138136616465}}]}, 
   {Hue[0.5508552456627583], AbsoluteThickness[0.5], 
    LineBox[{{7.089064848785108, -0.8805392112836646}, {
     7.061045303871558, -0.9206804163066099}}]}, 
   {Hue[0.5513169993227656], AbsoluteThickness[0.5], 
    LineBox[{{7.061045303871558, -0.92068041630661}, {
     6.891238424153179, -1.1507659059479496`}}]}, 
   {Hue[0.2211311805944316], AbsoluteThickness[0.5], 
    LineBox[{{8.199762254056463, -1.3634143532644176`}, {
     8.142854697491176, -1.617799589989076}}]}, 
   {Hue[0.22221733681579306`], AbsoluteThickness[0.5], 
    LineBox[{{8.142854697491176, -1.617799589989076}, {
     8.113554811276916, -1.8608526690485188`}}]}, 
   {Hue[0.6824116645202348], AbsoluteThickness[0.5], 
    LineBox[{{8.113554811276916, -1.8608526690485188`}, {
     8.351701318053932, -1.8041118206027202`}}]}, 
   {Hue[0.5797680267540692], AbsoluteThickness[0.5], 
    LineBox[{{7.7484730755022095`, -0.6008172594656177}, {
     7.6035541293106155`, -0.5637379813775357}}]}, 
   {Hue[0.5802893486799191], AbsoluteThickness[0.5], 
    LineBox[{{7.6035541293106155`, -0.5637379813775357}, {
     7.324885772347973, -0.4797278943551833}}]}, 
   {Hue[0.39679674697491696`], AbsoluteThickness[0.5], 
    LineBox[{{7.619472750724593, -0.6936439482100208}, {
     7.51547112243193, -0.8244692246658031}}]}, 
   {Hue[0.3984732629486001], AbsoluteThickness[0.5], 
    LineBox[{{7.51547112243193, -0.8244692246658031}, {
     7.39260725914644, -1.0279478410501555`}}]}, 
   {Hue[0.6069858200634759], AbsoluteThickness[0.5], 
    LineBox[{{7.651447575254202, -0.8493214627465835}, {
     7.672381137866586, -0.8897324205580233}}]}, 
   {Hue[0.6569313119121994], AbsoluteThickness[0.5], 
    LineBox[{{7.672381137866586, -0.8897324205580233}, {
     7.686979250267073, -1.04408508654914}}]}, 
   {Hue[0.5367688574582768], AbsoluteThickness[0.5], 
    LineBox[{{7.415477219416373, 0.6385334147184625}, {7.386485803124027, 
     0.7090038916997364}}]}, 
   {Hue[0.5375580109991056], AbsoluteThickness[0.5], 
    LineBox[{{7.386485803124027, 0.7090038916997364}, {7.26304483131566, 
     0.9530999671969401}}]}, 
   {Hue[0.6779982485769411], AbsoluteThickness[0.5], 
    LineBox[{{8.12522248279647, 0.3419786268413184}, {8.12906442965944, 
     0.3860078863509011}}]}, 
   {Hue[0.6794733518225317], AbsoluteThickness[0.5], 
    LineBox[{{8.12906442965944, 0.3860078863509011}, {8.120535347461905, 
     0.6432924311144571}}]}, 
   {Hue[0.5591157367718541], AbsoluteThickness[0.5], 
    LineBox[{{6.726188483215471, 0.9122956764785157}, {6.612411491614063, 
     0.9402026587013051}}]}, 
   {Hue[0.5596211041551141], AbsoluteThickness[0.5], 
    LineBox[{{6.612411491614063, 0.9402026587013051}, {6.294622030554857, 
     1.031347403082313}}]}, 
   {Hue[0.6085178017552572], AbsoluteThickness[0.5], 
    LineBox[{{5.3748429010454695`, -0.4330559216525751}, {
     5.132943331937122, -0.596948237167294}}]}, 
   {Hue[0.615392849866627], AbsoluteThickness[0.5], 
    LineBox[{{5.132943331937122, -0.596948237167294}, {
     4.9647742985089325`, -0.6625471398767516}}]}, 
   {Hue[0.5456881186012296], AbsoluteThickness[0.5], 
    LineBox[{{5.605909087231291, 1.337522307678692}, {5.546380362341173, 
     1.4177626217951311`}}]}, 
   {Hue[0.5466316234817514], AbsoluteThickness[0.5], 
    LineBox[{{5.546380362341173, 1.4177626217951311`}, {5.439271234356284, 
     1.593361647286202}}]}, 
   {Hue[0.5798657295740214], AbsoluteThickness[0.5], 
    LineBox[{{4.937656294966853, -2.151654359134207}, {
     4.907542275083172, -2.1938920126324697`}}]}, 
   {Hue[0.5806046664526869], AbsoluteThickness[0.5], 
    LineBox[{{4.907542275083172, -2.1938920126324697`}, {
     4.7409900953044115`, -2.3947119652886575`}}]}, 
   {Hue[0.508272647615578], AbsoluteThickness[0.5], 
    LineBox[{{5.311838667570306, -2.8792764846880274`}, {
     5.211935721355855, -3.093177971882633}}]}, 
   {Hue[0.5092654291516003], AbsoluteThickness[0.5], 
    LineBox[{{5.211935721355855, -3.093177971882633}, {
     5.1159503545473815`, -3.362052234712795}}]}, 
   {Hue[0.560452582155791], AbsoluteThickness[0.5], 
    LineBox[{{3.387305352562622, -2.021834095195231}, {
     3.342120388038122, -2.0630202186669195`}}]}, 
   {Hue[0.5610500231554532], AbsoluteThickness[0.5], 
    LineBox[{{3.342120388038122, -2.0630202186669195`}, {
     3.1468483407673093`, -2.2620077304853217`}}]}, 
   {Hue[0.6544062275654114], AbsoluteThickness[0.5], 
    LineBox[{{2.8615781542418333`, -3.6081451992747553`}, {
     2.8586320000039698`, -3.6203273508232714`}}]}, 
   {Hue[0.6551687395365776], AbsoluteThickness[0.5], 
    LineBox[{{2.8586320000039698`, -3.6203273508232714`}, {
     2.7733741188578915`, -3.8840710673423815`}}]}, 
   {Hue[0.6458611337026312], AbsoluteThickness[0.5], 
    LineBox[{{7.335513983141616, -1.9752076344400105`}, {
     7.253389816895786, -2.0891620942383704`}}]}, 
   {Hue[0.6464872082427562], AbsoluteThickness[0.5], 
    LineBox[{{7.253389816895786, -2.0891620942383704`}, {
     7.098587525588251, -2.333516866223829}}]}, 
   {Hue[0.23805585835119686`], AbsoluteThickness[0.5], 
    LineBox[{{7.509977518663065, -2.1059784864761806`}, {
     7.6304985958591285`, -2.173624606655471}}]}, 
   {Hue[0.23848261489749975`], AbsoluteThickness[0.5], 
    LineBox[{{7.6304985958591285`, -2.173624606655471}, {
     7.8952226831071, -2.323774706703366}}]}, 
   {Hue[0.649391045654959], AbsoluteThickness[0.5], 
    LineBox[{{7.620240934938551, -1.9178813838930502`}, {
     7.658234225144166, -1.8276309032983318`}}]}, 
   {Hue[0.6514012266553576], AbsoluteThickness[0.5], 
    LineBox[{{7.658234225144166, -1.8276309032983318`}, {
     7.766397690894249, -1.6466154826866868`}}]}, 
   {Hue[0.5943711782981376], AbsoluteThickness[0.5], 
    LineBox[{{2.37457278013143, 0.41236772940879196`}, {2.1621421917119985`, 
     0.4424154642384513}}]}, 
   {Hue[0.5947970471811542], AbsoluteThickness[0.5], 
    LineBox[{{2.1621421917119985`, 0.4424154642384513}, {1.9237407298776115`, 
     0.47574334319812034`}}]}, 
   {Hue[0.6234996999294753], AbsoluteThickness[0.5], 
    LineBox[{{3.8712640103931544`, 1.461513623156924}, {3.7840556413635973`, 
     1.6174626119481104`}}]}, 
   {Hue[0.6240908594077841], AbsoluteThickness[0.5], 
    LineBox[{{3.7840556413635973`, 1.6174626119481104`}, {3.650823583248038, 
     1.8896869555814462`}}]}, 
   {Hue[0.6956871926275078], AbsoluteThickness[0.5], 
    LineBox[{{7.463355290549831, -0.6309110554032935}, {
     7.39439659799154, -0.9264791188403765}}]}, 
   {Hue[0.6657595591652639], AbsoluteThickness[0.5], 
    LineBox[{{8.382237238207516, -0.3622801985439811}, {
     8.284791417937647, -0.5866005959199371}}]}, 
   {Hue[0.6663069372952151], AbsoluteThickness[0.5], 
    LineBox[{{8.284791417937647, -0.5866005959199371}, {
     8.1661092924191, -0.8996444132025083}}]}, 
   {Hue[0.48746706902567155`], AbsoluteThickness[0.5], 
    LineBox[{{7.895791654618303, 0.12060283839371863`}, {7.903386493057323, 
     0.10645625651259091`}}]}, 
   {Hue[0.4879279133026215], AbsoluteThickness[0.5], 
    LineBox[{{7.903386493057323, 0.10645625651259091`}, {
     8.058156822588801, -0.1646318897637109}}]}, 
   {Hue[0.5924211182144303], AbsoluteThickness[0.5], 
    LineBox[{{7.082057043420267, -0.06360337386427109}, {
     7.09486619345914, -0.2503553020517263}}]}, 
   {Hue[0.6060238224006301], AbsoluteThickness[0.5], 
    LineBox[{{7.09486619345914, -0.2503553020517263}, {
     7.1506144750573775`, -0.40605477948388796`}}]}, 
   {Hue[0.40566378403954867`], AbsoluteThickness[0.5], 
    LineBox[{{6.110310903769714, 2.9105980726534373`}, {6.08413656302188, 
     2.9524060017724962`}}]}, 
   {Hue[0.40620292761960936`], AbsoluteThickness[0.5], 
    LineBox[{{6.08413656302188, 2.9524060017724962`}, {5.9259672961039005`, 
     3.181016450081046}}]}, 
   {Hue[0.5457988910853259], AbsoluteThickness[0.5], 
    LineBox[{{6.889523970784141, 2.1448611096221875`}, {6.8886200971469185`, 
     2.1450061233170747`}}]}, 
   {Hue[0.5465585316064795], AbsoluteThickness[0.5], 
    LineBox[{{6.8886200971469185`, 2.1450061233170747`}, {6.671468816587459, 
     2.1968069220503086`}}]}, 
   {Hue[0.5867485603145534], AbsoluteThickness[0.5], 
    LineBox[{{7.5907937172647495`, 2.2358311309519157`}, {7.357777181458283, 
     2.2450199299140285`}}]}, 
   {Hue[0.5871817412283635], AbsoluteThickness[0.5], 
    LineBox[{{7.357777181458283, 2.2450199299140285`}, {7.04906452011257, 
     2.2609353860613313`}}]}, 
   {Hue[0.054297138255091304`], AbsoluteThickness[0.5], 
    LineBox[{{7.842869718411299, 2.40987936138732}, {7.861558252159787, 
     2.421625320156505}}]}, 
   {Hue[0.054768250147419525`], AbsoluteThickness[0.5], 
    LineBox[{{7.861558252159787, 2.421625320156505}, {8.116899897840076, 
     2.5717759680030534`}}]}, 
   {Hue[0.5993037351723542], AbsoluteThickness[0.5], 
    LineBox[{{8.116899897840076, 2.5717759680030534`}, {7.944754840062339, 
     2.3307144568691602`}}]}, 
   {Hue[0.5877994427230013], AbsoluteThickness[0.5], 
    LineBox[{{7.733250214138802, 2.1238397467274224`}, {7.535202463674254, 
     1.667099300762628}}]}, 
   {Hue[0.5882407387134757], AbsoluteThickness[0.5], 
    LineBox[{{7.535202463674254, 1.667099300762628}, {7.410837286737428, 
     1.3660020845780763`}}]}, 
   {Hue[0.5520241224153271], AbsoluteThickness[0.5], 
    LineBox[{{7.668699245897137, 1.5921435030471}, {7.752476772758128, 
     1.4125289068857918`}}]}, 
   {Hue[0.5524869093812698], AbsoluteThickness[0.5], 
    LineBox[{{7.752476772758128, 1.4125289068857918`}, {7.8595641716778175`, 
     1.1659232740399668`}}]}, 
   {Hue[0.4169204869826653], AbsoluteThickness[0.5], 
    LineBox[{{7.859236113709474, 1.1656995049785202`}, {7.885539238352638, 
     1.1203809877223332`}}]}, 
   {Hue[0.4176751612900898], AbsoluteThickness[0.5], 
    LineBox[{{7.885539238352638, 1.1203809877223332`}, {8.049867358543636, 
     0.8804343923135989}}]}, 
   {Hue[0.5957172439398168], AbsoluteThickness[0.5], 
    LineBox[{{6.171091340426499, 0.6945427586502549}, {6.106693578753236, 
     0.5464900047341151}}]}, 
   {Hue[0.600173851741628], AbsoluteThickness[0.5], 
    LineBox[{{6.106693578753236, 0.5464900047341151}, {5.997825718946675, 
     0.388450251213067}}]}, 
   {Hue[0.6602055475298992], AbsoluteThickness[0.5], 
    LineBox[{{5.4575270292587605`, 1.4585905239819008`}, {5.169691551106872, 
     1.4792910968179878`}}]}, 
   {Hue[0.6606320505651284], AbsoluteThickness[0.5], 
    LineBox[{{5.169691551106872, 1.4792910968179878`}, {4.832950453391747, 
     1.5048257151003592`}}]}, 
   {Hue[0.5134026343661842], AbsoluteThickness[0.5], 
    LineBox[{{5.727390254801979, 2.322599385388017}, {5.6526835741710615`, 
     2.4100026722227392`}}]}, 
   {Hue[0.5138744279308255], AbsoluteThickness[0.5], 
    LineBox[{{5.6526835741710615`, 2.4100026722227392`}, {5.429549069096307, 
     2.655855316396245}}]}, 
   {Hue[0.6942628618542993], AbsoluteThickness[0.5], 
    LineBox[{{6.543046556765034, 2.6627949900028285`}, {6.557407021806119, 
     2.699567563486493}}]}, 
   {Hue[0.6969849986642359], AbsoluteThickness[0.5], 
    LineBox[{{6.557407021806119, 2.699567563486493}, {6.67204511918515, 
     2.894252753090364}}]}, 
   {Hue[0.575966135783288], AbsoluteThickness[0.5], 
    LineBox[{{5.581761193546521, -1.6617413904821767`}, {
     5.52821979395628, -1.7926363319079395`}}]}, 
   {Hue[0.5764257011521987], AbsoluteThickness[0.5], 
    LineBox[{{5.52821979395628, -1.7926363319079395`}, {
     5.409635563907917, -2.105133789784374}}]}, 
   {Hue[0.5849323687289855], AbsoluteThickness[0.5], 
    LineBox[{{4.1578609559231055`, -1.343423681350016}, {
     4.097816046570846, -1.4146950204102509`}}]}, 
   {Hue[0.5854903109454168], AbsoluteThickness[0.5], 
    LineBox[{{4.097816046570846, -1.4146950204102509`}, {
     3.9276037515993067`, -1.5976130755287712`}}]}, 
   {Hue[0.6696757146844429], AbsoluteThickness[0.5], 
    LineBox[{{3.710973166087805, 2.3486320899573454`}, {3.623682877914745, 
     2.454968928101182}}]}, 
   {Hue[0.6704757140556127], AbsoluteThickness[0.5], 
    LineBox[{{3.623682877914745, 2.454968928101182}, {3.4318112971230987`, 
     2.6543317522816245`}}]}, 
   {Hue[0.6832366069340938], AbsoluteThickness[0.5], 
    LineBox[{{4.431106332846696, 2.8152057995588318`}, {4.446534777062093, 
     2.8602313797402847`}}]}, 
   {Hue[0.6836955383273569], AbsoluteThickness[0.5], 
    LineBox[{{4.446534777062093, 2.8602313797402847`}, {4.5547602128643625`, 
     3.151752171178532}}]}, 
   {Hue[0.4083426318804653], AbsoluteThickness[0.5], 
    LineBox[{{4.297858637767286, 2.958517964124089}, {3.9419706953933185`, 
     3.2053355147578366`}}]}, 
   {Hue[0.40882718833089693`], AbsoluteThickness[0.5], 
    LineBox[{{3.9419706953933185`, 3.2053355147578366`}, {3.664574384812285, 
     3.3842567423908356`}}]}, 
   {Hue[0.6955161925099534], AbsoluteThickness[0.5], 
    LineBox[{{4.1236371191860215`, 2.869410235954234}, {3.6249528496208794`, 
     2.459350602990368}}]}, 
   {Hue[0.6980707775346091], AbsoluteThickness[0.5], 
    LineBox[{{3.6249528496208794`, 2.459350602990368}, {3.434893373211385, 
     2.3473583861005296`}}]}, 
   {Hue[0.6563752301092707], AbsoluteThickness[0.5], 
    LineBox[{{6.8484066121077065`, 2.3425365709348624`}, {6.928605291979971, 
     2.3344672414616907`}}]}, 
   {Hue[0.677460360756458], AbsoluteThickness[0.5], 
    LineBox[{{6.928605291979971, 2.3344672414616907`}, {7.086497881146298, 
     2.368223580085873}}]}, 
   {Hue[0.6810317593000834], AbsoluteThickness[0.5], 
    LineBox[{{4.910839694496389, 2.54594857149001}, {4.7742503962869485`, 
     2.616726726484692}}]}, 
   {Hue[0.6834947785773332], AbsoluteThickness[0.5], 
    LineBox[{{4.7742503962869485`, 2.616726726484692}, {4.59533862718291, 
     2.7475609048138905`}}]}, 
   {Hue[0.35427710841818827`], AbsoluteThickness[0.5], 
    LineBox[{{7.354844770525024, 2.229684053172597}, {7.585445650891827, 
     2.3091083708250935`}}]}, 
   {Hue[0.35493444271861757`], AbsoluteThickness[0.5], 
    LineBox[{{7.585445650891827, 2.3091083708250935`}, {7.867021207653984, 
     2.386390507060466}}]}, 
   {Hue[0.6665981674710211], AbsoluteThickness[0.5], 
    LineBox[{{8.10655150150298, 0.3693298005733229}, {8.141494128746501, 
     0.35321453514969386`}}]}, 
   {Hue[0.6674158781650067], AbsoluteThickness[0.5], 
    LineBox[{{8.141494128746501, 0.35321453514969386`}, {8.382223459857004, 
     0.21773225895026987`}}]}, 
   {Hue[0.5721144688010229], AbsoluteThickness[0.5], 
    LineBox[{{7.631328414187725, -1.557702275150708}, {
     7.704732306080127, -1.676892906022156}}]}, 
   {Hue[0.5725560307624546], AbsoluteThickness[0.5], 
    LineBox[{{7.704732306080127, -1.676892906022156}, {
     7.859729841413681, -1.9189308576094473`}}]}, 
   {Hue[0.6945341009278206], AbsoluteThickness[0.5], 
    LineBox[{{4.991206006908431, -2.612589870224008}, {
     5.006110314984789, -2.821639821952649}}]}, 
   {Hue[0.6949729447159643], AbsoluteThickness[0.5], 
    LineBox[{{5.006110314984789, -2.821639821952649}, {
     5.02328086657909, -3.1326528503414046`}}]}, 
   {Hue[0.6334848724097627], AbsoluteThickness[0.5], 
    LineBox[{{4.135235673754737, 2.377790205066963}, {4.135011040980463, 
     2.3832567476329665`}}]}, 
   {Hue[0.6344895669065469], AbsoluteThickness[0.5], 
    LineBox[{{4.135011040980463, 2.3832567476329665`}, {4.096720621916753, 
     2.6632031158539267`}}]}, 
   {Hue[0.5911057647610379], AbsoluteThickness[0.5], 
    LineBox[{{3.139126996476194, 2.274347432322024}, {3.1002646052526672`, 
     2.327128595960277}}]}, 
   {Hue[0.591576846337463], AbsoluteThickness[0.5], 
    LineBox[{{3.1002646052526672`, 2.327128595960277}, {2.8913256812643104`, 
     2.629192028469021}}]}, 
   {Hue[0.5511815506363902], AbsoluteThickness[0.5], 
    LineBox[{{2.5639091577048396`, -2.283473602966811}, {
     2.5110731794900274`, -2.3189372132252233`}}]}, 
   {Hue[0.5555938643215224], AbsoluteThickness[0.5], 
    LineBox[{{2.5110731794900274`, -2.3189372132252233`}, {
     2.365834136276386, -2.4635915128095047`}}]}, 
   {Hue[0.6948245611902599], AbsoluteThickness[0.5], 
    LineBox[{{6.0636562489049926`, 0.42765724960114687`}, {
     6.1123844621691745`, 0.40231992807795297`}}]}, 
   {Hue[0.6952916803126689], AbsoluteThickness[0.5], 
    LineBox[{{6.1123844621691745`, 0.4023199280779529}, {6.394800979578804, 
     0.24518414514209183`}}]}, 
   {Hue[0.6050462853437429], AbsoluteThickness[0.5], 
    LineBox[{{6.796835466404744, -0.37473224979044134`}, {
     6.805650960450831, -0.38825456218392657`}}]}, 
   {Hue[0.605865701267724], AbsoluteThickness[0.5], 
    LineBox[{{6.805650960450831, -0.38825456218392657`}, {
     6.981236024915728, -0.6152563224123637}}]}, 
   {Hue[0.6209544692309614], AbsoluteThickness[0.5], 
    LineBox[{{5.22008251226371, 2.8613027319903215`}, {5.14910691507626, 
     2.9752510543120265`}}]}, 
   {Hue[0.6230388680197775], AbsoluteThickness[0.5], 
    LineBox[{{5.14910691507626, 2.9752510543120265`}, {4.998648154316641, 
     3.1540407703996065`}}]}, 
   {Hue[0.23488746553905193`], AbsoluteThickness[0.5], 
    LineBox[{{7.1383892426434965`, 3.05829815803376}, {7.19137102085663, 
     3.0891768975092737`}}]}, 
   {Hue[0.2370557565861193], AbsoluteThickness[0.5], 
    LineBox[{{7.19137102085663, 3.0891768975092737`}, {7.382424735668911, 
     3.241392485962096}}]}, 
   {Hue[0.6277351796176234], AbsoluteThickness[0.5], 
    LineBox[{{7.382424735668911, 3.241392485962096}, {7.224519005658315, 
     3.4277708316501934`}}]}, 
   {Hue[0.6345015896951486], AbsoluteThickness[0.5], 
    LineBox[{{6.685613320647193, 1.1133562302976907`}, {6.848893853691764, 
     0.8986162335543887}}]}, 
   {Hue[0.6400753807594979], AbsoluteThickness[0.5], 
    LineBox[{{6.848893853691764, 0.8986162335543887}, {6.940571025145557, 
     0.7046737564505943}}]}, 
   {Hue[0.6107661666812341], AbsoluteThickness[0.5], 
    LineBox[{{3.7473901064006174`, 2.89368500304916}, {3.664067268395014, 
     3.0558097400694413`}}]}, 
   {Hue[0.628956066486007], AbsoluteThickness[0.5], 
    LineBox[{{3.664067268395014, 3.0558097400694413`}, {3.5425081440602795`, 
     3.1803010714985946`}}]}, 
   {Hue[0.5193543378882155], AbsoluteThickness[0.5], 
    LineBox[{{4.2838136894081, -4.364024216847826}, {
     4.295422159323054, -4.471988217433412}}]}, 
   {Hue[0.5248544516259793], AbsoluteThickness[0.5], 
    LineBox[{{4.295422159323054, -4.471988217433412}, {
     4.363868337063371, -4.682257612531309}}]}, 
   {Hue[0.6897037948396125], AbsoluteThickness[0.5], 
    LineBox[{{2.1508851683884687`, 2.8999633502122433`}, {2.1553413880554078`,
      2.946315754821659}}]}, 
   {Hue[0.6439378981595762], AbsoluteThickness[0.5], 
    LineBox[{{3.031801653807409, -3.705188711035731}, {
     2.9803684542907045`, -3.7921102919007548`}}]}, 
   {Hue[0.6445975453636644], AbsoluteThickness[0.5], 
    LineBox[{{2.9803684542907045`, -3.7921102919007548`}, {
     2.849404546774056, -4.049808571429186}}]}, 
   {Hue[0.6955281360714416], AbsoluteThickness[0.5], 
    LineBox[{{2.880216504554785, -0.04444175777973723}, {2.6563771550459627`, 
     0.016919408309178242`}}]}, 
   {Hue[0.6961275904959277], AbsoluteThickness[0.5], 
    LineBox[{{2.6563771550459627`, 0.01691940830917824}, {2.343122411559728, 
     0.08420119139047562}}]}, 
   {Hue[0.4975248797894532], AbsoluteThickness[0.5], 
    LineBox[{{6.21885540305325, -3.404457330070654}, {
     6.327483659443012, -3.64143228558282}}]}, 
   {Hue[0.5081847137703139], AbsoluteThickness[0.5], 
    LineBox[{{6.327483659443012, -3.64143228558282}, {
     6.356803741723045, -3.8087345295407613`}}]}, 
   {Hue[0.671230029668002], AbsoluteThickness[0.5], 
    LineBox[{{3.380636448174245, -1.5964200764941456`}, {
     3.3489453260427835`, -1.6007325857318222`}}]}, 
   {Hue[0.6726516021556304], AbsoluteThickness[0.5], 
    LineBox[{{3.3489453260427835`, -1.6007325857318222`}, {
     3.104261163899703, -1.6640012419778976`}}]}, 
   {Hue[0.5695901836231435], AbsoluteThickness[0.5], 
    LineBox[{{6.311731109791709, 0.4423414635259728}, {6.203871782435634, 
     0.6378671433690848}}]}, 
   {Hue[0.5862143323137741], AbsoluteThickness[0.5], 
    LineBox[{{6.203871782435634, 0.6378671433690848}, {6.1740874865001505`, 
     0.7757901289830695}}]}, 
   {Hue[0.6673307321437486], AbsoluteThickness[0.5], 
    LineBox[{{6.049850131622351, -0.2757110847438647}, {
     5.606807739817493, -0.05264727949754067}}]}, 
   {Hue[0.6680279949024742], AbsoluteThickness[0.5], 
    LineBox[{{5.606807739817493, -0.05264727949754067}, {5.424634568440845, 
     0.05531210072010476}}]}, 
   {Hue[0.6657843699030308], AbsoluteThickness[0.5], 
    LineBox[{{7.134797655288283, -0.9209051371933594}, {
     7.067224116167232, -0.927799968327345}}]}, 
   {Hue[0.6665733595203559], AbsoluteThickness[0.5], 
    LineBox[{{7.067224116167232, -0.927799968327345}, {
     6.816270396384949, -0.9733560419524511}}]}, 
   {Hue[0.6624517620948351], AbsoluteThickness[0.5], 
    LineBox[{{8.105446178707219, -0.7988593201712213}, {
     7.699877511098632, -0.9954245064575279}}]}, 
   {Hue[0.6631908493699807], AbsoluteThickness[0.5], 
    LineBox[{{7.699877511098632, -0.9954245064575279}, {
     7.439389381488089, -1.0989463022747046`}}]}, 
   {Hue[0.6634018628977684], AbsoluteThickness[0.5], 
    LineBox[{{8.139924490823192, -0.6536498492379236}, {
     8.065641276051501, -0.6204553196595781}}]}, 
   {Hue[0.6638779369380134], AbsoluteThickness[0.5], 
    LineBox[{{8.065641276051501, -0.6204553196595781}, {
     7.808930037178675, -0.496032197679244}}]}, 
   {Hue[0.6638107583507837], AbsoluteThickness[0.5], 
    LineBox[{{7.325903510265283, -0.46186865000579325`}, {
     7.2830051655695405`, -0.43188333683969476`}}]}, 
   {Hue[0.66485392219455], AbsoluteThickness[0.5], 
    LineBox[{{7.2830051655695405`, -0.43188333683969476`}, {
     7.091759896169797, -0.26834910502029935`}}]}, 
   {Hue[0.6707660722786903], AbsoluteThickness[0.5], 
    LineBox[{{6.3713677431193, -0.9186151178417657}, {
     6.172085951611804, -0.9444679624203562}}]}, 
   {Hue[0.6712097554844741], AbsoluteThickness[0.5], 
    LineBox[{{6.172085951611804, -0.9444679624203562}, {
     5.872911295726647, -0.9889900087951579}}]}, 
   {Hue[0.5718311567979069], AbsoluteThickness[0.5], 
    LineBox[{{6.379335896513874, -2.085412588603809}, {
     6.376767909777325, -2.091094170536472}}]}, 
   {Hue[0.5722875229845756], AbsoluteThickness[0.5], 
    LineBox[{{6.376767909777325, -2.091094170536472}, {
     6.234990762054958, -2.385440525508746}}]}, 
   {Hue[0.6714761429828422], AbsoluteThickness[0.5], 
    LineBox[{{4.12284435269526, -0.7350330323557107}, {
     3.939418938539776, -0.7489704936818035}}]}, 
   {Hue[0.6719296570557162], AbsoluteThickness[0.5], 
    LineBox[{{3.939418938539776, -0.7489704936818035}, {
     3.638263304515852, -0.7648291929539344}}]}, 
   {Hue[0.6676837348324408], AbsoluteThickness[0.5], 
    LineBox[{{5.145887079524409, 1.0883075737967323`}, {5.140308271944989, 
     1.104268310810226}}]}, 
   {Hue[0.6700076421319124], AbsoluteThickness[0.5], 
    LineBox[{{5.140308271944989, 1.104268310810226}, {5.096569236141754, 
     1.3357910803015578`}}]}, 
   {Hue[0.5605518435310579], AbsoluteThickness[0.5], 
    LineBox[{{4.994230525119114, 1.1669794558625997`}, {4.827075526699468, 
     1.1931445637446738`}}]}, 
   {Hue[0.5614838481819929], AbsoluteThickness[0.5], 
    LineBox[{{4.827075526699468, 1.1931445637446738`}, {4.610694076187342, 
     1.2472439704707483`}}]}, 
   {Hue[0.6925888408697477], AbsoluteThickness[0.5], 
    LineBox[{{2.0787350858778306`, -1.2814039577305978`}, {
     2.0003036934224303`, -1.329870768090729}}]}, 
   {Hue[0.6951982692899026], AbsoluteThickness[0.5], 
    LineBox[{{2.0003036934224303`, -1.329870768090729}, {
     1.8336924275214526`, -1.4732542376714384`}}]}, 
   {Hue[0.5868223125267475], AbsoluteThickness[0.5], 
    LineBox[{{4.355178594317804, 2.5468311143626847`}, {4.328713447015243, 
     2.647584529328547}}]}, 
   {Hue[0.5872581713702566], AbsoluteThickness[0.5], 
    LineBox[{{4.328713447015243, 2.647584529328547}, {4.242300135990645, 
     2.958653860880806}}]}, 
   {Hue[0.6106570945093279], AbsoluteThickness[0.5], 
    LineBox[{{5.651538893852952, -3.088480866580487}, {
     5.701732013854048, -3.112869047086785}}]}, 
   {Hue[0.6698158816238721], AbsoluteThickness[0.5], 
    LineBox[{{5.701732013854048, -3.112869047086785}, {
     5.7374642304186585`, -3.1148207538741954`}}]}, 
   {Hue[0.6267859080907816], AbsoluteThickness[0.5], 
    LineBox[{{7.665287425646017, -0.03956702474220078}, {7.734350491527184, 
     0.04190650299569837}}]}, 
   {Hue[0.62761025054101], AbsoluteThickness[0.5], 
    LineBox[{{7.734350491527184, 0.04190650299569837}, {7.906370197256607, 
     0.28181153269222736`}}]}, 
   {Hue[0.6894517269231979], AbsoluteThickness[0.5], 
    LineBox[{{4.858622588968935, -3.56919944704185}, {
     4.8642560884911115`, -4.194500033049438}}]}, 
   {Hue[0.692342983401862], AbsoluteThickness[0.5], 
    LineBox[{{4.8642560884911115`, -4.194500033049438}, {
     4.829779486093567, -4.4154089103162}}]}, 
   {Hue[0.5533183708977673], AbsoluteThickness[0.5], 
    LineBox[{{6.634131531000934, -3.0719619480994393`}, {
     6.671074467239444, -3.081610888855282}}]}, 
   {Hue[0.5550423720849497], AbsoluteThickness[0.5], 
    LineBox[{{6.671074467239444, -3.081610888855282}, {
     6.899930564895412, -3.174540551814754}}]}, 
   {Hue[0.6571255540034103], AbsoluteThickness[0.5], 
    LineBox[{{5.866329565438444, -3.3110875034097034`}, {
     5.935901562833797, -3.1595787055072435`}}]}, 
   {Hue[0.657552397891499], AbsoluteThickness[0.5], 
    LineBox[{{5.935901562833797, -3.1595787055072435`}, {
     6.081837289859851, -2.837813264929599}}]}, 
   {Hue[0.2762268849677873], AbsoluteThickness[0.5], 
    LineBox[{{5.805708072520338, -4.413436912493349}, {
     5.831896688689484, -4.458836479185337}}]}, 
   {Hue[0.2770046359953243], AbsoluteThickness[0.5], 
    LineBox[{{5.8318966886894845`, -4.458836479185337}, {
     6.003619497252942, -4.709810653383114}}]}, 
   {Hue[0.6961018468606266], AbsoluteThickness[0.5], 
    LineBox[{{5.916011929233098, -1.6888284034040753`}, {
     5.993735709127912, -1.6360205531850112`}}]}, 
   {Hue[0.6051157743859207], AbsoluteThickness[0.5], 
    LineBox[{{6.337779794013787, -3.384264369261639}, {
     6.347487543260412, -3.3888639409188626`}}]}, 
   {Hue[0.6055423792892874], AbsoluteThickness[0.5], 
    LineBox[{{6.347487543260412, -3.3888639409188626`}, {
     6.623107770800839, -3.5208537525908548`}}]}, 
   {Hue[0.6181062152447372], AbsoluteThickness[0.5], 
    LineBox[{{7.414490709319449, -0.7159150517247848}, {
     7.560361629291671, -0.6066213381401222}}]}, 
   {Hue[0.6636328734328258], AbsoluteThickness[0.5], 
    LineBox[{{4.668918718869527, 1.8516964213326221`}, {4.669495481752964, 
     1.8806850947986917`}}]}, 
   {Hue[0.6664563244264717], AbsoluteThickness[0.5], 
    LineBox[{{4.669495481752964, 1.8806850947986917`}, {4.638132754593107, 
     2.09948350520848}}]}, 
   {Hue[0.6818164363335668], AbsoluteThickness[0.5], 
    LineBox[{{5.67825740711686, 2.321364133162266}, {6.216651124428579, 
     3.0739793423113557`}}]}, 
   {Hue[0.682291312179582], AbsoluteThickness[0.5], 
    LineBox[{{6.216651124428579, 3.0739793423113557`}, {6.397471300632101, 
     3.343892858939146}}]}, 
   {Hue[0.5334805331033825], AbsoluteThickness[0.5], 
    LineBox[{{5.908461374811387, -3.750642945817226}, {
     6.0819014994316, -3.813579875850225}}]}, 
   {Hue[0.5349306953026814], AbsoluteThickness[0.5], 
    LineBox[{{6.0819014994316, -3.813579875850225}, {
     6.310953746921912, -3.866975427737977}}]}, 
   {Hue[0.6105111391371968], AbsoluteThickness[0.5], 
    LineBox[{{5.357972964306915, -3.3933818763277874`}, {
     5.374509444450504, -3.395566131471415}}]}, 
   {Hue[0.6116233987768974], AbsoluteThickness[0.5], 
    LineBox[{{5.374509444450504, -3.395566131471415}, {
     5.637017124102652, -3.457868109930103}}]}, 
   {Hue[0.6957388466375061], AbsoluteThickness[0.5], 
    LineBox[{{6.679520616593402, 2.014099144513647}, {6.724011532014876, 
     2.1231920362958028`}}]}, 
   {Hue[0.6961950590400668], AbsoluteThickness[0.5], 
    LineBox[{{6.724011532014876, 2.1231920362958028`}, {6.823607798834304, 
     2.3513775983994054`}}]}, 
   {Hue[0.5905322248996225], AbsoluteThickness[0.5], 
    LineBox[{{5.974153831466134, 3.60618887209148}, {6.082521253155166, 
     3.6948870161218927`}}]}, 
   {Hue[0.5913934582801386], AbsoluteThickness[0.5], 
    LineBox[{{6.082521253155166, 3.6948870161218927`}, {6.297222573089578, 
     3.8423133011994732`}}]}, 
   {Hue[0.6482748037932475], AbsoluteThickness[0.5], 
    LineBox[{{6.017535277147618, -0.6058258364405791}, {
     6.147511136098517, -0.6432712291768892}}]}, 
   {Hue[0.649237100902062], AbsoluteThickness[0.5], 
    LineBox[{{6.147511136098517, -0.6432712291768892}, {
     6.386597138215577, -0.7366714308399953}}]}, 
   {Hue[0.5004438016697457], AbsoluteThickness[0.5], 
    LineBox[{{3.912632299582414, 3.666766216145601}, {3.901978296573076, 
     3.6712342956786443`}}]}, 
   {Hue[0.5010156769813158], AbsoluteThickness[0.5], 
    LineBox[{{3.901978296573076, 3.6712342956786443`}, {3.63725413540805, 
     3.798713404170469}}]}, 
   {Hue[0.6199826330420452], AbsoluteThickness[0.5], 
    LineBox[{{4.147834099542077, -2.7872163612839236`}, {
     4.1313384266402755`, -2.9423287531854507`}}]}, 
   {Hue[0.6209529460249968], AbsoluteThickness[0.5], 
    LineBox[{{4.1313384266402755`, -2.9423287531854507`}, {
     4.085806426856718, -3.1687567459407036`}}]}, 
   {Hue[0.6369920810923165], AbsoluteThickness[0.5], 
    LineBox[{{3.8269803148109927`, -2.421395638487014}, {
     3.6434532869272855`, -2.4567980802734084`}}]}, 
   {Hue[0.6374710243502535], AbsoluteThickness[0.5], 
    LineBox[{{3.6434532869272855`, -2.4567980802734084`}, {
     3.3505624246198233`, -2.5230581114666615`}}]}, 
   {Hue[0.5820470877798963], AbsoluteThickness[0.5], 
    LineBox[{{3.847961158782051, -1.0165026893195102`}, {
     3.652903815078904, -1.0803739311382328`}}]}, 
   {Hue[0.5898317747640444], AbsoluteThickness[0.5], 
    LineBox[{{3.652903815078904, -1.0803739311382328`}, {
     3.4618257100042524`, -1.096422679302357}}]}, 
   {Hue[0.5746632649000918], AbsoluteThickness[0.5], 
    LineBox[{{4.199864864931973, 0.8983009627323136}, {4.134850055008293, 
     0.9195958696696139}}]}, 
   {Hue[0.5754240519254276], AbsoluteThickness[0.5], 
    LineBox[{{4.134850055008293, 0.9195958696696139}, {3.8764273565314835`, 
     1.0263447626949131`}}]}, 
   {Hue[0.5701530836534218], AbsoluteThickness[0.5], 
    LineBox[{{5.051959192898659, 0.2385815110206089}, {4.861351664778296, 
     0.23746790414088365`}}]}, 
   {Hue[0.5706438324426345], AbsoluteThickness[0.5], 
    LineBox[{{4.861351664778296, 0.23746790414088365`}, {4.599307598199741, 
     0.24515681016851465`}}]}, 
   {Hue[0.5702143899524373], AbsoluteThickness[0.5], 
    LineBox[{{6.08202873426027, 0.2403913781533282}, {5.7985976099463095`, 
     0.28494468681776813`}}]}, 
   {Hue[0.571415499301082], AbsoluteThickness[0.5], 
    LineBox[{{5.7985976099463095`, 0.28494468681776813`}, {5.609474006244555, 
     0.2942448717076789}}]}, 
   {Hue[0.5712791928340919], AbsoluteThickness[0.5], 
    LineBox[{{6.086043597166242, 0.23008017286883264`}, {5.8055434121719784`, 
     0.27306337220785204`}}]}, 
   {Hue[0.5721480494940853], AbsoluteThickness[0.5], 
    LineBox[{{5.8055434121719784`, 0.27306337220785204`}, {5.603755512959419, 
     0.2866500430212181}}]}, 
   {Hue[0.5931933747143027], AbsoluteThickness[0.5], 
    LineBox[{{5.432638829135789, 0.0019576561281483273`}, {5.244867243872589, 
     0.09264940869100588}}]}, 
   {Hue[0.5952857511428802], AbsoluteThickness[0.5], 
    LineBox[{{5.244867243872589, 0.09264940869100588}, {5.053981524896907, 
     0.22120202258361985`}}]}, 
   {Hue[0.5849344306918729], AbsoluteThickness[0.5], 
    LineBox[{{5.454028017084742, -1.6427617749203458`}, {
     5.424049127068846, -1.6662014829955887`}}]}, 
   {Hue[0.5854775380148411], AbsoluteThickness[0.5], 
    LineBox[{{5.424049127068846, -1.6662014829955887`}, {
     5.161117810432792, -1.8527035427157652`}}]}, 
   {Hue[0.5728027016646832], AbsoluteThickness[0.5], 
    LineBox[{{3.63183006274481, 0.8840691581865909}, {3.626346666240446, 
     0.8846054692985521}}]}, 
   {Hue[0.5747532287230447], AbsoluteThickness[0.5], 
    LineBox[{{3.626346666240446, 0.8846054692985521}, {3.402624636551746, 
     0.9383355876035095}}]}, 
   {Hue[0.6275575990003105], AbsoluteThickness[0.5], 
    LineBox[{{5.1201059873986505`, -3.3673397614158103`}, {
     5.127248558501592, -3.386773390172028}}]}, 
   {Hue[0.6372478532061118], AbsoluteThickness[0.5], 
    LineBox[{{5.127248558501592, -3.386773390172028}, {
     5.1462960020449104`, -3.5707356088282745`}}]}, 
   {Hue[0.6817258280157088], AbsoluteThickness[0.5], 
    LineBox[{{3.40984555308592, 2.0307515259013695`}, {3.3622976066741503`, 
     2.08333422098049}}]}, 
   {Hue[0.6822285311833568], AbsoluteThickness[0.5], 
    LineBox[{{3.3622976066741503`, 2.08333422098049}, {3.161912059449901, 
     2.3226916198902874`}}]}, 
   {Hue[0.6128295630456427], AbsoluteThickness[0.5], 
    LineBox[{{3.9573464658850694`, 2.118942426898756}, {3.413672644218905, 
     2.8815666423975697`}}]}, 
   {Hue[0.6211256973188136], AbsoluteThickness[0.5], 
    LineBox[{{3.413672644218905, 2.8815666423975697`}, {3.3426242328939093`, 
     3.0584389714349762`}}]}, 
   {Hue[0.5572384043292565], AbsoluteThickness[0.5], 
    LineBox[{{7.513807308768862, 2.2145836392609417`}, {7.487100124227508, 
     2.327222530149139}}]}, 
   {Hue[0.5576649887850207], AbsoluteThickness[0.5], 
    LineBox[{{7.487100124227508, 2.327222530149139}, {7.410816810891881, 
     2.654916663834237}}]}, 
   {Hue[0.3602077315989853], AbsoluteThickness[0.5], 
    LineBox[{{8.092304264001527, 2.0909250013635523`}, {8.163318110417054, 
     2.105528202222812}}]}, 
   {Hue[0.3638759111927692], AbsoluteThickness[0.5], 
    LineBox[{{8.163318110417054, 2.105528202222812}, {8.347104600707908, 
     2.179466320375446}}]}, 
   {Hue[0.6286866030382878], AbsoluteThickness[0.5], 
    LineBox[{{8.395524124599893, -2.2990859831031694`}, {
     8.433349884127763, -2.6791042297401746`}}]}, 
   {Hue[0.6324934709472301], AbsoluteThickness[0.5], 
    LineBox[{{8.433349884127763, -2.6791042297401746`}, {
     8.413214814154534, -2.9212123474724474`}}]}, 
   {Hue[0.5867586453591016], AbsoluteThickness[0.5], 
    LineBox[{{2.351561375345233, -1.4268501082215128`}, {
     2.143246696123521, -1.5329890869889569`}}]}, 
   {Hue[0.5880184283889174], AbsoluteThickness[0.5], 
    LineBox[{{2.143246696123521, -1.5329890869889569`}, {
     1.907234740423717, -1.6221795647070467`}}]}, 
   {Hue[0.5082643584450778], AbsoluteThickness[0.5], 
    LineBox[{{5.1022244808439545`, 2.323565140824154}, {4.989713941366013, 
     2.4145628566418673`}}]}, 
   {Hue[0.5290991928634519], AbsoluteThickness[0.5], 
    LineBox[{{4.989713941366013, 2.4145628566418673`}, {4.910759430903985, 
     2.534861876819981}}]}, 
   {Hue[0.6996387471232474], AbsoluteThickness[0.5], 
    LineBox[{{4.910759430903985, 2.534861876819981}, {4.981631650194683, 
     2.6600928534628387`}}]}, 
   {Hue[0.5587720943527021], AbsoluteThickness[0.5], 
    LineBox[{{6.239906709783326, -2.3867466416051784`}, {
     6.165935676817577, -2.5897191114053446`}}]}, 
   {Hue[0.5598826877234472], AbsoluteThickness[0.5], 
    LineBox[{{6.165935676817577, -2.5897191114053446`}, {
     6.113733579063284, -2.7959792267364305`}}]}, 
   {Hue[0.5898435818172006], AbsoluteThickness[0.5], 
    LineBox[{{6.3512713762803905`, -2.0551342989204158`}, {
     6.325592669639345, -2.0663421427446105`}}]}, 
   {Hue[0.5917448998693438], AbsoluteThickness[0.5], 
    LineBox[{{6.325592669639345, -2.0663421427446105`}, {
     6.117362588661209, -2.1934643961026183`}}]}, 
   {Hue[0.6714708660251976], AbsoluteThickness[0.5], 
    LineBox[{{7.301824442867045, -0.14496588377955782`}, {7.25190649337151, 
     0.10027785884098857`}}]}, 
   {Hue[0.671936019998308], AbsoluteThickness[0.5], 
    LineBox[{{7.25190649337151, 0.10027785884098857`}, {7.200172233847885, 
     0.32285155166020685`}}]}, 
   {Hue[0.5751019902715147], AbsoluteThickness[0.5], 
    LineBox[{{7.625742330799511, -0.8138373947869403}, {
     7.419265532892371, -0.7417586453535625}}]}, 
   {Hue[0.5757131906076494], AbsoluteThickness[0.5], 
    LineBox[{{7.419265532892371, -0.7417586453535625}, {
     7.087319688415603, -0.6469652106360281}}]}, 
   {Hue[0.6893062933529831], AbsoluteThickness[0.5], 
    LineBox[{{6.599575636028021, -1.6632914445452884`}, {
     6.2939057217237675`, -1.711766055010192}}]}, 
   {Hue[0.6901443267607957], AbsoluteThickness[0.5], 
    LineBox[{{6.2939057217237675`, -1.711766055010192}, {
     6.091216357937925, -1.7612673360048654`}}]}, 
   {Hue[0.6258574564868291], AbsoluteThickness[0.5], 
    LineBox[{{7.908870569285332, 0.6363405921956174}, {7.918174982432908, 
     0.6496496235341948}}]}, 
   {Hue[0.5969447476182916], AbsoluteThickness[0.5], 
    LineBox[{{7.957399573447786, 1.1907794871119046`}, {8.128689798690683, 
     1.3418145168176208`}}]}, 
   {Hue[0.6013075122920131], AbsoluteThickness[0.5], 
    LineBox[{{8.128689798690683, 1.3418145168176208`}, {8.323360768520535, 
     1.4561817774912749`}}]}, 
   {Hue[0.6821280484592998], AbsoluteThickness[0.5], 
    LineBox[{{5.7614451381756, -1.8897657093966496`}, {
     5.659123499473315, -2.013030867778954}}]}, 
   {Hue[0.6906448014128643], AbsoluteThickness[0.5], 
    LineBox[{{5.659123499473315, -2.013030867778954}, {
     5.501983216141877, -2.129699724911777}}]}, 
   {Hue[0.6633920009129283], AbsoluteThickness[0.5], 
    LineBox[{{7.203976935424871, -1.432343928083896}, {
     6.760297199622442, -2.0684795741898383`}}]}, 
   {Hue[0.6650364516436159], AbsoluteThickness[0.5], 
    LineBox[{{6.760297199622442, -2.0684795741898383`}, {
     6.655334519762255, -2.269199865264574}}]}, 
   {Hue[0.6731230990981195], AbsoluteThickness[0.5], 
    LineBox[{{4.8555560121133405`, -0.4837764862605864}, {
     4.656532245140392, -0.5028643622352128}}]}, 
   {Hue[0.6735651207983427], AbsoluteThickness[0.5], 
    LineBox[{{4.656532245140392, -0.5028643622352128}, {
     4.342426496753941, -0.5386559841940423}}]}, 
   {Hue[0.6629102914814159], AbsoluteThickness[0.5], 
    LineBox[{{7.962700276203219, 0.35421291790887827`}, {7.910753701734286, 
     0.2713334505586714}}]}, 
   {Hue[0.6638353013283502], AbsoluteThickness[0.5], 
    LineBox[{{7.910753701734286, 0.2713334505586714}, {7.736517336313909, 
     0.041696597688378106`}}]}, 
   {Hue[0.6906142772412874], AbsoluteThickness[0.5], 
    LineBox[{{7.075181166291394, 1.7360589289094108`}, {6.9093263636212985`, 
     1.6446401433046534`}}]}, 
   {Hue[0.6531087385725439], AbsoluteThickness[0.5], 
    LineBox[{{7.340701567611936, 2.1928631620768386`}, {7.584748955312181, 
     2.3042723820850526`}}]}, 
   {Hue[0.6538569890406485], AbsoluteThickness[0.5], 
    LineBox[{{7.584748955312181, 2.3042723820850526`}, {7.851221229629994, 
     2.4028406753332177`}}]}, 
   {Hue[0.2696859712869616], AbsoluteThickness[0.5], 
    LineBox[{{7.2750128182084195`, 2.404456802605155}, {7.158776787694478, 
     2.6463995820760804`}}]}, 
   {Hue[0.27204141343306215`], AbsoluteThickness[0.5], 
    LineBox[{{7.158776787694478, 2.6463995820760804`}, {7.101909736487721, 
     2.8319088152941503`}}]}, 
   {Hue[0.6544243608951488], AbsoluteThickness[0.5], 
    LineBox[{{7.101909736487721, 2.8319088152941503`}, {7.287382059810395, 
     2.8888961332113623`}}]}, 
   {Hue[0.6575680407431495], AbsoluteThickness[0.5], 
    LineBox[{{7.064748356344884, 2.334630327773166}, {6.916287728124953, 
     2.25968677020543}}]}, 
   {Hue[0.6580313644073128], AbsoluteThickness[0.5], 
    LineBox[{{6.916287728124953, 2.25968677020543}, {6.691843155935229, 
     2.1538751372386757`}}]}, 
   {Hue[0.6954948613095098], AbsoluteThickness[0.5], 
    LineBox[{{7.873716585856401, 2.1898970367554913`}, {8.061623158308258, 
     2.2355232355417956`}}]}, 
   {Hue[0.6959380163972634], AbsoluteThickness[0.5], 
    LineBox[{{8.061623158308258, 2.2355232355417956`}, {8.354599139732844, 
     2.3009631612452894`}}]}, 
   {Hue[0.43232464360149186`], AbsoluteThickness[0.5], 
    LineBox[{{6.372371296183886, 1.4091519663780299`}, {6.167179613513065, 
     1.4678934700777249`}}]}, 
   {Hue[0.432754195119278], AbsoluteThickness[0.5], 
    LineBox[{{6.167179613513065, 1.4678934700777249`}, {5.867044451974879, 
     1.5566368054896491`}}]}, 
   {Hue[0.5990391946635518], AbsoluteThickness[0.5], 
    LineBox[{{6.791952908495986, 0.08374147770756984}, {
     6.660054476466439, -0.07717815293864871}}]}, 
   {Hue[0.6019430134933327], AbsoluteThickness[0.5], 
    LineBox[{{6.660054476466439, -0.07717815293864871}, {
     6.547802470072989, -0.2720996382726648}}]}, 
   {Hue[0.5820532968115175], AbsoluteThickness[0.5], 
    LineBox[{{4.838990514160342, 0.9841394659698102}, {3.448760086155289, 
     2.180280600223608}}]}, 
   {Hue[0.5826164827904191], AbsoluteThickness[0.5], 
    LineBox[{{3.448760086155289, 2.180280600223608}, {3.2081730367418957`, 
     2.3671057489221643`}}]}, 
   {Hue[0.3529335661392774], AbsoluteThickness[0.5], 
    LineBox[{{6.058177141974077, 2.1652092660638718`}, {6.011572763817216, 
     2.3253148043592535`}}]}, 
   {Hue[0.3536178909760126], AbsoluteThickness[0.5], 
    LineBox[{{6.011572763817216, 2.3253148043592535`}, {5.94684732761072, 
     2.620028925960009}}]}, 
   {Hue[0.596839162557837], AbsoluteThickness[0.5], 
    LineBox[{{7.971585357905859, 1.6000593918475816`}, {8.120565466229836, 
     1.8406381674606482`}}]}, 
   {Hue[0.6031722656273139], AbsoluteThickness[0.5], 
    LineBox[{{8.120565466229836, 1.8406381674606482`}, {8.176833414021146, 
     2.001323404552496}}]}, 
   {Hue[0.4292962303860196], AbsoluteThickness[0.5], 
    LineBox[{{4.110086273807027, -0.15228745046046818`}, {
     3.8714255420977093`, -0.18996482186958547`}}]}, 
   {Hue[0.429740240015581], AbsoluteThickness[0.5], 
    LineBox[{{3.8714255420977093`, -0.18996482186958547`}, {
     3.538572026826272, -0.248976831906159}}]}, 
   {Hue[0.5644516586451859], AbsoluteThickness[0.5], 
    LineBox[{{6.6037717327071785`, -3.1320105407043783`}, {
     6.601520079231877, -3.147084985411699}}]}, 
   {Hue[0.573017027616051], AbsoluteThickness[0.5], 
    LineBox[{{6.601520079231877, -3.147084985411699}, {
     6.618847852367887, -3.3359856355758333`}}]}, 
   {Hue[0.502939649966398], AbsoluteThickness[0.5], 
    LineBox[{{3.6086057982016286`, -1.8883965789319122`}, {
     3.387919698706914, -1.9516748291211938`}}]}, 
   {Hue[0.5671246507510717], AbsoluteThickness[0.5], 
    LineBox[{{4.212541434448424, 1.900104389151962}, {4.19585927829969, 
     1.917938289425763}}]}, 
   {Hue[0.5677595118267043], AbsoluteThickness[0.5], 
    LineBox[{{4.19585927829969, 1.917938289425763}, {3.97446169355675, 
     2.127443232744459}}]}, 
   {Hue[0.6494646645898404], AbsoluteThickness[0.5], 
    LineBox[{{7.6636234440920665`, -2.9956943239432876`}, {
     7.830224368177267, -3.077519418774147}}]}, 
   {Hue[0.6506427395962807], AbsoluteThickness[0.5], 
    LineBox[{{7.830224368177267, -3.077519418774147}, {
     8.092413729545955, -3.173533051402061}}]}, 
   {Hue[0.34473461164521163`], AbsoluteThickness[0.5], 
    LineBox[{{4.716456323147216, -3.921562584586871}, {
     4.673826242455347, -3.991330489262004}}]}, 
   {Hue[0.34663040435621567`], AbsoluteThickness[0.5], 
    LineBox[{{4.673826242455347, -3.991330489262004}, {
     4.534238698711695, -4.1622418413519835`}}]}, 
   {Hue[0.689614156834933], AbsoluteThickness[0.5], 
    LineBox[{{3.3830611252289007`, -1.4006842239532256`}, {
     3.3232246055399983`, -1.3644246203918862`}}]}, 
   {Hue[0.6901082814694993], AbsoluteThickness[0.5], 
    LineBox[{{3.3232246055399983`, -1.3644246203918862`}, {
     3.054354681655003, -1.187943136511272}}]}, 
   {Hue[0.649414350956668], AbsoluteThickness[0.5], 
    LineBox[{{2.3172326875036067`, -1.9841376138510303`}, {
     2.2747427356163157`, -2.0672628258120835`}}]}, 
   {Hue[0.6500778882201695], AbsoluteThickness[0.5], 
    LineBox[{{2.2747427356163157`, -2.0672628258120835`}, {
     2.1522504194559615`, -2.350691308028444}}]}, 
   {Hue[0.559757671462376], AbsoluteThickness[0.5], 
    LineBox[{{5.11462032946465, 2.6608412636211796`}, {5.032683423025726, 
     2.837310943600785}}]}, 
   {Hue[0.5602083285784567], AbsoluteThickness[0.5], 
    LineBox[{{5.032683423025726, 2.837310943600785}, {4.892430575263001, 
     3.122750265386465}}]}, 
   {Hue[0.5593548228580553], AbsoluteThickness[0.5], 
    LineBox[{{4.6228213858257385`, 1.8273987966706309`}, {4.6152086000944825`,
      1.8319357682912891`}}]}, 
   {Hue[0.5600634655131946], AbsoluteThickness[0.5], 
    LineBox[{{4.615208600094482, 1.8319357682912891`}, {4.3774770971887245`, 
     1.9971218660906978`}}]}, 
   {Hue[0.549976205947189], AbsoluteThickness[0.5], 
    LineBox[{{5.233267415918655, -1.8831191840448234`}, {
     5.10079835537349, -1.952533812323374}}]}, 
   {Hue[0.5504317696042623], AbsoluteThickness[0.5], 
    LineBox[{{5.10079835537349, -1.952533812323374}, {
     4.825724737661423, -2.088343552397559}}]}, 
   {Hue[0.5791553034164382], AbsoluteThickness[0.5], 
    LineBox[{{5.422780052690844, 0.6705138136616465}, {5.3710156768436494`, 
     0.6787326874045062}}]}, 
   {Hue[0.5797100906069158], AbsoluteThickness[0.5], 
    LineBox[{{5.3710156768436494`, 0.6787326874045062}, {5.090473139923394, 
     0.7374218268061139}}]}, 
   {Hue[0.5517787529827728], AbsoluteThickness[0.5], 
    LineBox[{{6.891238424153179, -1.1507659059479496`}, {
     6.867293897721306, -1.181479868441188}}]}, 
   {Hue[0.5522045057552496], AbsoluteThickness[0.5], 
    LineBox[{{6.867293897721306, -1.181479868441188}, {
     6.690610036272507, -1.4078476767354253`}}]}, 
   {Hue[0.6813255082988755], AbsoluteThickness[0.5], 
    LineBox[{{8.142854697491176, -1.617799589989076}, {
     8.128527311893006, -1.6121809884811054`}}]}, 
   {Hue[0.6817571033425055], AbsoluteThickness[0.5], 
    LineBox[{{8.128527311893006, -1.6121809884811054`}, {
     7.852774090257703, -1.5006121927318183`}}]}, 
   {Hue[0.2233034930371547], AbsoluteThickness[0.5], 
    LineBox[{{8.113554811276916, -1.8608526690485188`}, {
     8.113010999242983, -1.8882338328657222`}}]}, 
   {Hue[0.2247124299575202], AbsoluteThickness[0.5], 
    LineBox[{{8.113010999242983, -1.8882338328657222`}, {
     8.082170567618235, -2.11183533372746}}]}, 
   {Hue[0.6587005868874302], AbsoluteThickness[0.5], 
    LineBox[{{8.082170567618235, -2.11183533372746}, {
     7.870347099697598, -2.033863660355023}}]}, 
   {Hue[0.5808106706057689], AbsoluteThickness[0.5], 
    LineBox[{{7.324885772347973, -0.4797278943551833}, {
     7.116893037380274, -0.40729301904863136`}}]}, 
   {Hue[0.5816509657492837], AbsoluteThickness[0.5], 
    LineBox[{{7.116893037380274, -0.40729301904863136`}, {
     6.840469680316674, -0.3359238797185977}}]}, 
   {Hue[0.40014977892228326`], AbsoluteThickness[0.5], 
    LineBox[{{7.39260725914644, -1.0279478410501555`}, {
     7.338905716848308, -1.149906726845968}}]}, 
   {Hue[0.4005812793751412], AbsoluteThickness[0.5], 
    LineBox[{{7.338905716848308, -1.149906726845968}, {
     7.20989690304216, -1.4346329557336868`}}]}, 
   {Hue[0.5383471645399345], AbsoluteThickness[0.5], 
    LineBox[{{7.26304483131566, 0.9530999671969401}, {7.16906126706836, 
     1.1077373543298221`}}]}, 
   {Hue[0.5395699570121398], AbsoluteThickness[0.5], 
    LineBox[{{7.16906126706836, 1.1077373543298221`}, {7.054282042140435, 
     1.352716413629225}}]}, 
   {Hue[0.6809484550681221], AbsoluteThickness[0.5], 
    LineBox[{{8.120535347461905, 0.6432924311144571}, {8.120028455242764, 
     0.6465727000460388}}]}, 
   {Hue[0.6824776230919231], AbsoluteThickness[0.5], 
    LineBox[{{8.120028455242764, 0.6465727000460388}, {8.112261487492178, 
     0.8985828620418925}}]}, 
   {Hue[0.560126471538374], AbsoluteThickness[0.5], 
    LineBox[{{6.294622030554857, 1.031347403082313}, {6.163555052004519, 
     1.0745043521545632`}}]}, 
   {Hue[0.5647354366834226], AbsoluteThickness[0.5], 
    LineBox[{{6.163555052004519, 1.0745043521545632`}, {5.9542502168143585`, 
     1.1003461488955129`}}]}, 
   {Hue[0.622267897977997], AbsoluteThickness[0.5], 
    LineBox[{{4.9647742985089325`, -0.6625471398767516}, {
     4.917583061937287, -0.6696005355564463}}]}, 
   {Hue[0.6227062942185445], AbsoluteThickness[0.5], 
    LineBox[{{4.917583061937287, -0.6696005355564463}, {
     4.619278244988409, -0.719000973751349}}]}, 
   {Hue[0.5475751283622733], AbsoluteThickness[0.5], 
    LineBox[{{5.439271234356284, 1.593361647286202}, {5.207055003585291, 
     2.065445464526139}}]}, 
   {Hue[0.5485463784640771], AbsoluteThickness[0.5], 
    LineBox[{{5.207055003585291, 2.065445464526139}, {5.106313691046077, 
     2.3294110350738806`}}]}, 
   {Hue[0.5813436033313527], AbsoluteThickness[0.5], 
    LineBox[{{4.7409900953044115`, -2.3947119652886575`}, {
     4.64217141873233, -2.497563574502396}}]}, 
   {Hue[0.5822545920677491], AbsoluteThickness[0.5], 
    LineBox[{{4.64217141873233, -2.497563574502396}, {
     4.450353755805007, -2.6648697355702615`}}]}, 
   {Hue[0.5102582106876226], AbsoluteThickness[0.5], 
    LineBox[{{5.1159503545473815`, -3.362052234712795}, {
     5.113339183384897, -3.372328401723442}}]}, 
   {Hue[0.5109203812608075], AbsoluteThickness[0.5], 
    LineBox[{{5.113339183384897, -3.372328401723442}, {
     5.021828387008208, -3.6548322427269113`}}]}, 
   {Hue[0.5616474641551154], AbsoluteThickness[0.5], 
    LineBox[{{3.1468483407673093`, -2.2620077304853217`}, {
     3.0740708533235224`, -2.3449381126978786`}}]}, 
   {Hue[0.5620821630864091], AbsoluteThickness[0.5], 
    LineBox[{{3.0740708533235224`, -2.3449381126978786`}, {
     2.8500711487036394`, -2.6071219764809106`}}]}, 
   {Hue[0.655931251507744], AbsoluteThickness[0.5], 
    LineBox[{{2.7733741188578915`, -3.8840710673423815`}, {
     2.6971670913110195`, -4.070508788573988}}]}, 
   {Hue[0.6777523718955936], AbsoluteThickness[0.5], 
    LineBox[{{2.6971670913110195`, -4.070508788573988}, {
     2.587864227679066, -4.19981037741914}}]}, 
   {Hue[0.6471132827828809], AbsoluteThickness[0.5], 
    LineBox[{{7.098587525588251, -2.333516866223829}, {
     7.08946647383629, -2.350018962729753}}]}, 
   {Hue[0.6476230083227383], AbsoluteThickness[0.5], 
    LineBox[{{7.08946647383629, -2.350018962729753}, {
     6.939401135504566, -2.5977107157373154`}}]}, 
   {Hue[0.23890937144380253`], AbsoluteThickness[0.5], 
    LineBox[{{7.8952226831071, -2.323774706703366}, {
     7.9080988330994835`, -2.3311545325711105`}}]}, 
   {Hue[0.2396954697943234], AbsoluteThickness[0.5], 
    LineBox[{{7.9080988330994835`, -2.3311545325711105`}, {
     8.128771201372222, -2.48149666384228}}]}, 
   {Hue[0.6534114076557562], AbsoluteThickness[0.5], 
    LineBox[{{7.766397690894249, -1.6466154826866868`}, {
     7.8458136146584145`, -1.5481585915605582`}}]}, 
   {Hue[0.6552754802182265], AbsoluteThickness[0.5], 
    LineBox[{{7.8458136146584145`, -1.5481585915605582`}, {
     8.005954775621067, -1.3969365314326265`}}]}, 
   {Hue[0.624682018886093], AbsoluteThickness[0.5], 
    LineBox[{{3.650823583248038, 1.8896869555814462`}, {3.63768269075704, 
     1.9207327314916287`}}]}, 
   {Hue[0.6252818574015244], AbsoluteThickness[0.5], 
    LineBox[{{3.63768269075704, 1.9207327314916287`}, {3.529822058405508, 
     2.1403900997047196`}}]}, 
   {Hue[0.6668543154251663], AbsoluteThickness[0.5], 
    LineBox[{{8.1661092924191, -0.8996444132025083}, {
     8.155770412418903, -0.9313786408255527}}]}, 
   {Hue[0.6676141952151722], AbsoluteThickness[0.5], 
    LineBox[{{8.155770412418903, -0.9313786408255527}, {
     8.056362983429345, -1.1731684351515157`}}]}, 
   {Hue[0.48838875757957145`], AbsoluteThickness[0.5], 
    LineBox[{{8.058156822588801, -0.1646318897637109}, {
     8.096077868278284, -0.2272071949761921}}]}, 
   {Hue[0.49115071317751363`], AbsoluteThickness[0.5], 
    LineBox[{{8.096077868278284, -0.2272071949761921}, {
     8.24845679086599, -0.406060293006069}}]}, 
   {Hue[0.6196265265868297], AbsoluteThickness[0.5], 
    LineBox[{{7.1506144750573775`, -0.40605477948388796`}, {
     7.275023876159413, -0.5806240122737596}}]}, 
   {Hue[0.6212780366337071], AbsoluteThickness[0.5], 
    LineBox[{{7.275023876159413, -0.5806240122737596}, {
     7.408168799288016, -0.8292249785419747}}]}, 
   {Hue[0.40674207119967], AbsoluteThickness[0.5], 
    LineBox[{{5.9259672961039005`, 3.181016450081046}, {5.907935287104784, 
     3.2046804361511456`}}]}, 
   {Hue[0.40724607018297737`], AbsoluteThickness[0.5], 
    LineBox[{{5.907935287104784, 3.2046804361511456`}, {5.745913387735054, 
     3.401151074217439}}]}, 
   {Hue[0.5473181721276332], AbsoluteThickness[0.5], 
    LineBox[{{6.671468816587459, 2.1968069220503086`}, {6.442698990110666, 
     2.269901894298836}}]}, 
   {Hue[0.5482220272528608], AbsoluteThickness[0.5], 
    LineBox[{{6.442698990110666, 2.269901894298836}, {6.1742847683642905`, 
     2.3303941980732543`}}]}, 
   {Hue[0.5876149221421737], AbsoluteThickness[0.5], 
    LineBox[{{7.04906452011257, 2.2609353860613313`}, {6.913338823279581, 
     2.269579695973019}}]}, 
   {Hue[0.5881772839064451], AbsoluteThickness[0.5], 
    LineBox[{{6.913338823279581, 2.269579695973019}, {6.675409231196168, 
     2.272796650093518}}]}, 
   {Hue[0.5988326232800256], AbsoluteThickness[0.5], 
    LineBox[{{7.861558252159787, 2.421625320156505}, {7.830010629167544, 
     2.419002395368275}}]}, 
   {Hue[0.6010406747387107], AbsoluteThickness[0.5], 
    LineBox[{{7.830010629167544, 2.419002395368275}, {7.60663463756123, 
     2.3668950816325114`}}]}, 
   {Hue[0.05523936203974775], AbsoluteThickness[0.5], 
    LineBox[{{8.116899897840076, 2.5717759680030534`}, {8.149674483573722, 
     2.589767496202743}}]}, 
   {Hue[0.05599284251832031], AbsoluteThickness[0.5], 
    LineBox[{{8.149674483573722, 2.589767496202743}, {8.419264243665063, 
     2.765055051254562}}]}, 
   {Hue[0.55308018733537], AbsoluteThickness[0.5], 
    LineBox[{{8.419264243665063, 2.765055051254562}, {8.122252615323708, 
     2.8882965147811217`}}]}, 
   {Hue[0.5997748470646825], AbsoluteThickness[0.5], 
    LineBox[{{7.944754840062339, 2.3307144568691602`}, {7.90396893592733, 
     2.277027311430666}}]}, 
   {Hue[0.6024130831237677], AbsoluteThickness[0.5], 
    LineBox[{{7.90396893592733, 2.277027311430666}, {7.743497739669455, 
     2.123494058446904}}]}, 
   {Hue[0.58868203470395], AbsoluteThickness[0.5], 
    LineBox[{{7.410837286737428, 1.3660020845780763`}, {7.371848571968646, 
     1.266734318101678}}]}, 
   {Hue[0.5993956716174527], AbsoluteThickness[0.5], 
    LineBox[{{7.371848571968646, 1.266734318101678}, {7.260477484587177, 
     1.1142943773174796`}}]}, 
   {Hue[0.5529496963472125], AbsoluteThickness[0.5], 
    LineBox[{{7.8595641716778175`, 1.1659232740399668`}, {7.881350338756192, 
     1.1118366227327279`}}]}, 
   {Hue[0.5542163198472958], AbsoluteThickness[0.5], 
    LineBox[{{7.881350338756192, 1.1118366227327279`}, {8.005214679975802, 
     0.8813857955213649}}]}, 
   {Hue[0.4184298355975145], AbsoluteThickness[0.5], 
    LineBox[{{8.049867358543636, 0.8804343923135989}, {8.074646035368229, 
     0.8494830694768176}}]}, 
   {Hue[0.41902456272162847`], AbsoluteThickness[0.5], 
    LineBox[{{8.074646035368229, 0.8494830694768176}, {8.27870320829224, 
     0.6216346026934134}}]}, 
   {Hue[0.604630459543439], AbsoluteThickness[0.5], 
    LineBox[{{5.997825718946675, 0.388450251213067}, {5.818124065550799, 
     0.21257010005642177`}}]}, 
   {Hue[0.6062431512864859], AbsoluteThickness[0.5], 
    LineBox[{{5.818124065550799, 0.21257010005642177`}, {5.675717351249698, 
     0.1046008753151962}}]}, 
   {Hue[0.6610585536003575], AbsoluteThickness[0.5], 
    LineBox[{{4.832950453391747, 1.5048257151003592`}, {4.6489457821256135`, 
     1.5194985249893178`}}]}, 
   {Hue[0.6618420938549107], AbsoluteThickness[0.5], 
    LineBox[{{4.6489457821256135`, 1.5194985249893178`}, {4.41774203418334, 
     1.5200044649987976`}}]}, 
   {Hue[0.5143462214954667], AbsoluteThickness[0.5], 
    LineBox[{{5.429549069096307, 2.655855316396245}, {5.387178228210689, 
     2.699836344370948}}]}, 
   {Hue[0.5151840124923963], AbsoluteThickness[0.5], 
    LineBox[{{5.387178228210689, 2.699836344370948}, {5.207743513392063, 
     2.8577867218133304`}}]}, 
   {Hue[0.6997071354741725], AbsoluteThickness[0.5], 
    LineBox[{{6.67204511918515, 2.894252753090364}, {7.2285551396024585`, 
     3.5657466334810497`}}]}, 
   {Hue[0.5768852665211092], AbsoluteThickness[0.5], 
    LineBox[{{5.409635563907917, -2.105133789784374}, {
     5.381478680920222, -2.1854734331046792`}}]}, 
   {Hue[0.5792812757225927], AbsoluteThickness[0.5], 
    LineBox[{{5.381478680920222, -2.1854734331046792`}, {
     5.2691734055796395`, -2.396724050244714}}]}, 
   {Hue[0.5860482531618483], AbsoluteThickness[0.5], 
    LineBox[{{3.9276037515993067`, -1.5976130755287712`}, {
     3.8104177644695025`, -1.7117102152514592`}}]}, 
   {Hue[0.5864913551074395], AbsoluteThickness[0.5], 
    LineBox[{{3.8104177644695025`, -1.7117102152514592`}, {
     3.6155994324587826`, -1.894525461251382}}]}, 
   {Hue[0.6712757134267823], AbsoluteThickness[0.5], 
    LineBox[{{3.4318112971230987`, 2.6543317522816245`}, {3.4193275490217574`,
      2.6654059747540098`}}]}, 
   {Hue[0.6717036514852266], AbsoluteThickness[0.5], 
    LineBox[{{3.4193275490217574`, 2.6654059747540098`}, {3.1813073741642923`,
      2.8737658495676683`}}]}, 
   {Hue[0.6841544697206198], AbsoluteThickness[0.5], 
    LineBox[{{4.5547602128643625`, 3.151752171178532}, {4.727609203038033, 
     3.5834726911049155`}}]}, 
   {Hue[0.6845809445408905], AbsoluteThickness[0.5], 
    LineBox[{{4.727609203038033, 3.5834726911049155`}, {4.837975572840485, 
     3.862210742265206}}]}, 
   {Hue[0.4093117447813285], AbsoluteThickness[0.5], 
    LineBox[{{3.664574384812285, 3.3842567423908356`}, {3.657602011505822, 
     3.3884299348133933`}}]}, 
   {Hue[0.40973761787567237`], AbsoluteThickness[0.5], 
    LineBox[{{3.657602011505822, 3.3884299348133933`}, {3.3756474746787504`, 
     3.5578189227949846`}}]}, 
   {Hue[0.6985454914036449], AbsoluteThickness[0.5], 
    LineBox[{{7.086497881146298, 2.368223580085873}, {7.087522147022943, 
     2.3688121098177386`}}]}, 
   {Hue[0.6859577978545831], AbsoluteThickness[0.5], 
    LineBox[{{4.59533862718291, 2.7475609048138905`}, {4.502819805406495, 
     2.839956924889803}}]}, 
   {Hue[0.6883641605324153], AbsoluteThickness[0.5], 
    LineBox[{{4.502819805406495, 2.839956924889803}, {4.370922781610552, 
     3.0192497553137096`}}]}, 
   {Hue[0.35559177701904693`], AbsoluteThickness[0.5], 
    LineBox[{{7.867021207653984, 2.386390507060466}, {7.877283121249253, 
     2.388513855659674}}]}, 
   {Hue[0.3561288873558473], AbsoluteThickness[0.5], 
    LineBox[{{7.877283121249253, 2.388513855659674}, {8.15628943865821, 
     2.4596173053357795`}}]}, 
   {Hue[0.5729975927238864], AbsoluteThickness[0.5], 
    LineBox[{{7.859729841413681, -1.9189308576094473`}, {
     7.87185064703846, -1.9371445754785717`}}]}, 
   {Hue[0.5738771055875462], AbsoluteThickness[0.5], 
    LineBox[{{7.87185064703846, -1.9371445754785717`}, {
     8.026535331140416, -2.1312468752421223`}}]}, 
   {Hue[0.695411788504108], AbsoluteThickness[0.5], 
    LineBox[{{5.02328086657909, -3.1326528503414046`}, {
     5.031075684371769, -3.3317545710898138`}}]}, 
   {Hue[0.695873002183694], AbsoluteThickness[0.5], 
    LineBox[{{5.031075684371769, -3.3317545710898138`}, {
     5.035227669071989, -3.6526989879522036`}}]}, 
   {Hue[0.6354942614033312], AbsoluteThickness[0.5], 
    LineBox[{{4.096720621916753, 2.6632031158539267`}, {4.047605030894261, 
     2.872217611858553}}]}, 
   {Hue[0.6362401596155208], AbsoluteThickness[0.5], 
    LineBox[{{4.047605030894261, 2.872217611858553}, {3.977505836413961, 
     3.095252481737712}}]}, 
   {Hue[0.5920479279138882], AbsoluteThickness[0.5], 
    LineBox[{{2.8913256812643104`, 2.629192028469021}, {2.8632367858787005`, 
     2.6724787132513232`}}]}, 
   {Hue[0.5926756195058043], AbsoluteThickness[0.5], 
    LineBox[{{2.8632367858787005`, 2.6724787132513232`}, {2.6935174959428623`,
      2.9025393038137066`}}]}, 
   {Hue[0.5600061780066545], AbsoluteThickness[0.5], 
    LineBox[{{2.365834136276386, -2.4635915128095047`}, {
     2.3092543394119756`, -2.5471572290842133`}}]}, 
   {Hue[0.5605135682542648], AbsoluteThickness[0.5], 
    LineBox[{{2.3092543394119756`, -2.5471572290842133`}, {
     2.1416337583908494`, -2.816956223302733}}]}, 
   {Hue[0.6957587994350777], AbsoluteThickness[0.5], 
    LineBox[{{6.394800979578804, 0.24518414514209186`}, {6.480232680291019, 
     0.19443893846246152`}}]}, 
   {Hue[0.6979074333481915], AbsoluteThickness[0.5], 
    LineBox[{{6.480232680291019, 0.19443893846246152`}, {6.659692182695705, 
     0.04918593335212337}}]}, 
   {Hue[0.6066851171917048], AbsoluteThickness[0.5], 
    LineBox[{{6.981236024915728, -0.6152563224123637}, {
     7.05810755580538, -0.6996114423601658}}]}, 
   {Hue[0.6073390906066083], AbsoluteThickness[0.5], 
    LineBox[{{7.05810755580538, -0.6996114423601658}, {
     7.302785761556029, -0.936095584107759}}]}, 
   {Hue[0.6251232668085935], AbsoluteThickness[0.5], 
    LineBox[{{4.998648154316641, 3.1540407703996065`}, {4.937858221216312, 
     3.20830516137135}}]}, 
   {Hue[0.6258236912091891], AbsoluteThickness[0.5], 
    LineBox[{{4.937858221216312, 3.20830516137135}, {4.70685809455572, 
     3.387527058565831}}]}, 
   {Hue[0.6255668885705579], AbsoluteThickness[0.5], 
    LineBox[{{7.19137102085663, 3.0891768975092737`}, {7.367801984065969, 
     2.9135321663649467`}}]}, 
   {Hue[0.630356696557105], AbsoluteThickness[0.5], 
    LineBox[{{7.367801984065969, 2.9135321663649467`}, {7.517236611483914, 
     2.814501905121874}}]}, 
   {Hue[0.2392240476331867], AbsoluteThickness[0.5], 
    LineBox[{{7.382424735668911, 3.241392485962096}, {7.471034799899652, 
     3.3359356226244485`}}]}, 
   {Hue[0.2398199176358752], AbsoluteThickness[0.5], 
    LineBox[{{7.471034799899652, 3.3359356226244485`}, {7.654994426077595, 
     3.5554240113134896`}}]}, 
   {Hue[0.6299034706646909], AbsoluteThickness[0.5], 
    LineBox[{{7.224519005658315, 3.4277708316501934`}, {6.891507309641701, 
     3.7215374670450734`}}]}, 
   {Hue[0.6306440788058323], AbsoluteThickness[0.5], 
    LineBox[{{6.891507309641701, 3.7215374670450734`}, {6.648964727819394, 
     3.9057973396696273`}}]}, 
   {Hue[0.6456491718238473], AbsoluteThickness[0.5], 
    LineBox[{{6.940571025145557, 0.7046737564505943}, {6.962908832908473, 
     0.6105629133543862}}]}, 
   {Hue[0.6460749080505458], AbsoluteThickness[0.5], 
    LineBox[{{6.962908832908473, 0.6105629133543862}, {7.037050949080651, 
     0.29818282138163965`}}]}, 
   {Hue[0.6471459662907801], AbsoluteThickness[0.5], 
    LineBox[{{3.5425081440602795`, 3.1803010714985946`}, {3.413809918368542, 
     3.2503708853760167`}}]}, 
   {Hue[0.6476778631108455], AbsoluteThickness[0.5], 
    LineBox[{{3.413809918368542, 3.2503708853760167`}, {3.1435775763814275`, 
     3.382275553748318}}]}, 
   {Hue[0.6452571925677524], AbsoluteThickness[0.5], 
    LineBox[{{2.849404546774056, -4.049808571429186}, {
     2.827593351421164, -4.10053570418653}}]}, 
   {Hue[0.645696457467343], AbsoluteThickness[0.5], 
    LineBox[{{2.827593351421164, -4.10053570418653}, {
     2.704419435254165, -4.400361396971252}}]}, 
   {Hue[0.6967270449204139], AbsoluteThickness[0.5], 
    LineBox[{{2.343122411559728, 0.0842011913904756}, {2.0845708989373666`, 
     0.1247543261178052}}]}, 
   {Hue[0.5188445477511746], AbsoluteThickness[0.5], 
    LineBox[{{6.356803741723045, -3.8087345295407613`}, {
     6.345652513236842, -3.943049532401065}}]}, 
   {Hue[0.529421548935232], AbsoluteThickness[0.5], 
    LineBox[{{6.345652513236842, -3.943049532401065}, {
     6.377501697143815, -4.125425650701477}}]}, 
   {Hue[0.6740731746432587], AbsoluteThickness[0.5], 
    LineBox[{{3.104261163899703, -1.6640012419778976`}, {
     2.884078647983296, -1.7496078720965442`}}]}, 
   {Hue[0.674705897499108], AbsoluteThickness[0.5], 
    LineBox[{{2.884078647983296, -1.7496078720965442`}, {
     2.593581503910271, -1.842709679913864}}]}, 
   {Hue[0.6028384810044055], AbsoluteThickness[0.5], 
    LineBox[{{6.1740874865001505`, 0.7757901289830695}, {6.181042068771924, 
     0.8639375972613617}}]}, 
   {Hue[0.6067153442841998], AbsoluteThickness[0.5], 
    LineBox[{{6.181042068771924, 0.8639375972613617}, {6.158377046542862, 
     1.079655511838091}}]}, 
   {Hue[0.6687252576611998], AbsoluteThickness[0.5], 
    LineBox[{{5.424634568440845, 0.05531210072010476}, {5.317042819751427, 
     0.1294770319424728}}]}, 
   {Hue[0.6691960453161085], AbsoluteThickness[0.5], 
    LineBox[{{5.317042819751427, 0.1294770319424728}, {5.065776237865189, 
     0.3138209934879861}}]}, 
   {Hue[0.667362349137681], AbsoluteThickness[0.5], 
    LineBox[{{6.816270396384949, -0.9733560419524511}, {
     6.668027420846843, -1.0123905238353117`}}]}, 
   {Hue[0.6679540737134997], AbsoluteThickness[0.5], 
    LineBox[{{6.668027420846843, -1.0123905238353117`}, {
     6.381609940183878, -1.0712390887599839`}}]}, 
   {Hue[0.6639299366451265], AbsoluteThickness[0.5], 
    LineBox[{{7.439389381488089, -1.0989463022747046`}, {
     7.313278174973295, -1.1386831746169745`}}]}, 
   {Hue[0.6663434000742287], AbsoluteThickness[0.5], 
    LineBox[{{7.313278174973295, -1.1386831746169745`}, {
     7.115306982609331, -1.2360895645433216`}}]}, 
   {Hue[0.6643540109782585], AbsoluteThickness[0.5], 
    LineBox[{{7.808930037178675, -0.496032197679244}, {
     7.595675104232797, -0.38436019970434043`}}]}, 
   {Hue[0.6711657970821017], AbsoluteThickness[0.5], 
    LineBox[{{7.595675104232797, -0.38436019970434043`}, {
     7.421059005638186, -0.338001022670505}}]}, 
   {Hue[0.6658970860383161], AbsoluteThickness[0.5], 
    LineBox[{{7.091759896169797, -0.26834910502029935`}, {6.7585881145226745`,
      0.07804495166215328}}]}, 
   {Hue[0.6669647969175823], AbsoluteThickness[0.5], 
    LineBox[{{6.7585881145226745`, 0.07804495166215328}, {6.595006748083417, 
     0.28580785448505197`}}]}, 
   {Hue[0.6716534386902578], AbsoluteThickness[0.5], 
    LineBox[{{5.872911295726647, -0.9889900087951579}, {
     5.652912048359456, -1.025951873257104}}]}, 
   {Hue[0.6720980292730756], AbsoluteThickness[0.5], 
    LineBox[{{5.652912048359456, -1.025951873257104}, {
     5.340894985895122, -1.0722375888756497`}}]}, 
   {Hue[0.5727438891712444], AbsoluteThickness[0.5], 
    LineBox[{{6.234990762054958, -2.385440525508746}, {
     6.14897432499868, -2.5534228836988784`}}]}, 
   {Hue[0.5832388076607273], AbsoluteThickness[0.5], 
    LineBox[{{6.14897432499868, -2.5534228836988784`}, {
     6.051783412638282, -2.6623824470807356`}}]}, 
   {Hue[0.6723831711285901], AbsoluteThickness[0.5], 
    LineBox[{{3.638263304515852, -0.7648291929539344}, {
     3.3738726411137208`, -0.7726000600586983}}]}, 
   {Hue[0.6728110284310437], AbsoluteThickness[0.5], 
    LineBox[{{3.3738726411137208`, -0.7726000600586983}, {
     3.054373136532107, -0.7840587567859695}}]}, 
   {Hue[0.672331549431384], AbsoluteThickness[0.5], 
    LineBox[{{5.096569236141754, 1.3357910803015578`}, {5.095798332428355, 
     1.356517128024159}}]}, 
   {Hue[0.6730762174368858], AbsoluteThickness[0.5], 
    LineBox[{{5.095798332428355, 1.356517128024159}, {5.0626744504079495`, 
     1.6543114717460656`}}]}, 
   {Hue[0.562415852832928], AbsoluteThickness[0.5], 
    LineBox[{{4.610694076187342, 1.2472439704707483`}, {4.404155782485892, 
     1.3190795915946154`}}]}, 
   {Hue[0.5633483340531631], AbsoluteThickness[0.5], 
    LineBox[{{4.404155782485892, 1.3190795915946154`}, {4.144111651976884, 
     1.3840857233728665`}}]}, 
   {Hue[0.5876940302137657], AbsoluteThickness[0.5], 
    LineBox[{{4.242300135990645, 2.958653860880806}, {4.197562210974278, 
     3.111324700701478}}]}, 
   {Hue[0.5885097612665245], AbsoluteThickness[0.5], 
    LineBox[{{4.197562210974278, 3.111324700701478}, {4.13284966389924, 
     3.422974821525778}}]}, 
   {Hue[0.6933456938110437], AbsoluteThickness[0.5], 
    LineBox[{{5.701732013854048, -3.112869047086785}, {
     5.830148566037293, -3.031069035778284}}]}, 
   {Hue[0.6939327257953964], AbsoluteThickness[0.5], 
    LineBox[{{5.830148566037293, -3.031069035778284}, {
     6.092280012794133, -2.843424693458682}}]}, 
   {Hue[0.6284345929912385], AbsoluteThickness[0.5], 
    LineBox[{{7.906370197256607, 0.28181153269222736`}, {7.952336119517301, 
     0.3583225668815183}}]}, 
   {Hue[0.628873217386506], AbsoluteThickness[0.5], 
    LineBox[{{7.952336119517301, 0.3583225668815183}, {8.118379058300926, 
     0.6449226663315251}}]}, 
   {Hue[0.5567663732721321], AbsoluteThickness[0.5], 
    LineBox[{{6.899930564895412, -3.174540551814754}, {
     7.053680776379236, -3.2617500086503033`}}]}, 
   {Hue[0.5575643327760507], AbsoluteThickness[0.5], 
    LineBox[{{7.053680776379236, -3.2617500086503033`}, {
     7.309970576340112, -3.381544453280943}}]}, 
   {Hue[0.6579792417795874], AbsoluteThickness[0.5], 
    LineBox[{{6.081837289859851, -2.837813264929599}, {
     6.10541816723868, -2.785168366081709}}]}, 
   {Hue[0.6587125522829878], AbsoluteThickness[0.5], 
    LineBox[{{6.10541816723868, -2.785168366081709}, {
     6.2152155951258345`, -2.5810723405099556`}}]}, 
   {Hue[0.6059689841926544], AbsoluteThickness[0.5], 
    LineBox[{{6.623107770800839, -3.5208537525908548`}, {
     6.757930115248017, -3.5861053179592504`}}]}, 
   {Hue[0.6187208615398058], AbsoluteThickness[0.5], 
    LineBox[{{6.757930115248017, -3.5861053179592504`}, {
     6.900543530396513, -3.711440073745309}}]}, 
   {Hue[0.664662511009505], AbsoluteThickness[0.5], 
    LineBox[{{7.560361629291671, -0.6066213381401222}, {
     7.824902078697203, -0.4559732130025493}}]}, 
   {Hue[0.6684671086922066], AbsoluteThickness[0.5], 
    LineBox[{{7.824902078697203, -0.4559732130025493}, {
     8.004361075079022, -0.3933941032834033}}]}, 
   {Hue[0.6692797754201175], AbsoluteThickness[0.5], 
    LineBox[{{4.638132754593107, 2.09948350520848}, {4.624031937876376, 
     2.1443302124415378`}}]}, 
   {Hue[0.6731943585732206], AbsoluteThickness[0.5], 
    LineBox[{{4.624031937876376, 2.1443302124415378`}, {4.599435908218015, 
     2.3473535365259495`}}]}, 
   {Hue[0.6827661880255974], AbsoluteThickness[0.5], 
    LineBox[{{6.397471300632101, 3.343892858939146}, {6.417517197957304, 
     3.375899366953035}}]}, 
   {Hue[0.6832223784424243], AbsoluteThickness[0.5], 
    LineBox[{{6.417517197957304, 3.375899366953035}, {6.5695900465028005`, 
     3.6323580995431572`}}]}, 
   {Hue[0.5363808575019804], AbsoluteThickness[0.5], 
    LineBox[{{6.310953746921912, -3.866975427737977}, {
     6.399586639312654, -3.8767602930653924`}}]}, 
   {Hue[0.5379902519106682], AbsoluteThickness[0.5], 
    LineBox[{{6.399586639312654, -3.8767602930653924`}, {
     6.643629357222951, -3.9353858072439656`}}]}, 
   {Hue[0.6127356584165979], AbsoluteThickness[0.5], 
    LineBox[{{5.637017124102652, -3.457868109930103}, {
     5.87039208931529, -3.5390371728041723`}}]}, 
   {Hue[0.6133861242045936], AbsoluteThickness[0.5], 
    LineBox[{{5.87039208931529, -3.5390371728041723`}, {
     6.137275091159029, -3.6134020134562284`}}]}, 
   {Hue[0.6966512714426276], AbsoluteThickness[0.5], 
    LineBox[{{6.823607798834304, 2.3513775983994054`}, {6.846781820812852, 
     2.4011361350807556`}}]}, 
   {Hue[0.6974657635005019], AbsoluteThickness[0.5], 
    LineBox[{{6.846781820812852, 2.4011361350807556`}, {6.980064814907501, 
     2.6360577075587694`}}]}, 
   {Hue[0.6501993980108765], AbsoluteThickness[0.5], 
    LineBox[{{6.386597138215577, -0.7366714308399953}, {
     6.63358193070513, -0.8603807804354889}}]}, 
   {Hue[0.6522840622677354], AbsoluteThickness[0.5], 
    LineBox[{{6.63358193070513, -0.8603807804354889}, {
     6.833207782240434, -0.9269446988361995}}]}, 
   {Hue[0.6219232590079485], AbsoluteThickness[0.5], 
    LineBox[{{4.085806426856718, -3.1687567459407036`}, {
     4.038309454043637, -3.3273806559264156`}}]}, 
   {Hue[0.6224383216357203], AbsoluteThickness[0.5], 
    LineBox[{{4.038309454043637, -3.3273806559264156`}, {
     3.9721082559078655`, -3.5866860519826593`}}]}, 
   {Hue[0.6379499676081906], AbsoluteThickness[0.5], 
    LineBox[{{3.3505624246198233`, -2.5230581114666615`}, {
     3.118328203232917, -2.5834483089094658`}}]}, 
   {Hue[0.6396292489256957], AbsoluteThickness[0.5], 
    LineBox[{{3.118328203232917, -2.5834483089094658`}, {
     2.859527213339528, -2.6161932857223684`}}]}, 
   {Hue[0.5976164617481924], AbsoluteThickness[0.5], 
    LineBox[{{3.4618257100042524`, -1.096422679302357}, {
     3.1075544412984932`, -1.0432938398466487`}}]}, 
   {Hue[0.5980728200431797], AbsoluteThickness[0.5], 
    LineBox[{{3.1075544412984932`, -1.0432938398466487`}, {
     2.826503644727011, -0.9941157286018478}}]}, 
   {Hue[0.5761848389507632], AbsoluteThickness[0.5], 
    LineBox[{{3.8764273565314835`, 1.0263447626949131`}, {3.4217658085794107`,
      1.2555457993474688`}}]}, 
   {Hue[0.5766929991159196], AbsoluteThickness[0.5], 
    LineBox[{{3.4217658085794107`, 1.2555457993474688`}, {3.1763028621250227`,
      1.367380054709261}}]}, 
   {Hue[0.5711345812318472], AbsoluteThickness[0.5], 
    LineBox[{{4.599307598199741, 0.24515681016851465`}, {4.461322446096763, 
     0.2540705422266259}}]}, 
   {Hue[0.5715603220287462], AbsoluteThickness[0.5], 
    LineBox[{{4.461322446096763, 0.2540705422266259}, {4.136204013050589, 
     0.2749748351498943}}]}, 
   {Hue[0.5726166086497267], AbsoluteThickness[0.5], 
    LineBox[{{5.609474006244555, 0.2942448717076789}, {5.366979532778847, 
     0.2802506066935628}}]}, 
   {Hue[0.5730583203373415], AbsoluteThickness[0.5], 
    LineBox[{{5.366979532778847, 0.2802506066935628}, {5.051875130029453, 
     0.2564720054982866}}]}, 
   {Hue[0.5730169061540785], AbsoluteThickness[0.5], 
    LineBox[{{5.603755512959419, 0.2866500430212181}, {5.366507063188319, 
     0.2824752416856857}}]}, 
   {Hue[0.5734734635737796], AbsoluteThickness[0.5], 
    LineBox[{{5.366507063188319, 0.2824752416856857}, {5.053056531371361, 
     0.2692896488285821}}]}, 
   {Hue[0.5973781275714578], AbsoluteThickness[0.5], 
    LineBox[{{5.053981524896907, 0.22120202258361998`}, {4.18798172128448, 
     1.004703344448355}}]}, 
   {Hue[0.5980473134673089], AbsoluteThickness[0.5], 
    LineBox[{{4.18798172128448, 1.004703344448355}, {3.9628467720727776`, 
     1.1831204805494644`}}]}, 
   {Hue[0.5860206453378095], AbsoluteThickness[0.5], 
    LineBox[{{5.161117810432792, -1.8527035427157652`}, {
     5.078067790884993, -1.9059729252487134`}}]}, 
   {Hue[0.5864483385382386], AbsoluteThickness[0.5], 
    LineBox[{{5.078067790884993, -1.9059729252487134`}, {
     4.817307280071607, -2.0755232938811505`}}]}, 
   {Hue[0.5767037557814062], AbsoluteThickness[0.5], 
    LineBox[{{3.402624636551746, 0.9383355876035095}, {3.1952282855067415`, 
     1.0197101303044396`}}]}, 
   {Hue[0.5774334158970206], AbsoluteThickness[0.5], 
    LineBox[{{3.1952282855067415`, 1.0197101303044396`}, {2.8969485225635543`,
      1.1125840558185158`}}]}, 
   {Hue[0.646938107411913], AbsoluteThickness[0.5], 
    LineBox[{{5.1462960020449104`, -3.5707356088282745`}, {
     5.099318717113653, -3.890504266620194}}]}, 
   {Hue[0.6475327356332383], AbsoluteThickness[0.5], 
    LineBox[{{5.099318717113653, -3.890504266620194}, {
     5.044742242163473, -4.158180197656881}}]}, 
   {Hue[0.6827312343510048], AbsoluteThickness[0.5], 
    LineBox[{{3.161912059449901, 2.3226916198902874`}, {3.1406038194229264`, 
     2.3502121957329027`}}]}, 
   {Hue[0.683157139280489], AbsoluteThickness[0.5], 
    LineBox[{{3.1406038194229264`, 2.3502121957329027`}, {2.911285923811317, 
     2.647505866953311}}]}, 
   {Hue[0.629421831591985], AbsoluteThickness[0.5], 
    LineBox[{{3.3426242328939093`, 3.0584389714349762`}, {3.3316437880300867`,
      3.1338457191650715`}}]}, 
   {Hue[0.6299471867421621], AbsoluteThickness[0.5], 
    LineBox[{{3.3316437880300867`, 3.1338457191650715`}, {3.275365450434138, 
     3.4300573945397765`}}]}, 
   {Hue[0.5580915732407848], AbsoluteThickness[0.5], 
    LineBox[{{7.410816810891881, 2.654916663834237}, {7.305653489633981, 
     3.1151901917234417`}}]}, 
   {Hue[0.5586218471207086], AbsoluteThickness[0.5], 
    LineBox[{{7.305653489633981, 3.1151901917234417`}, {7.219482146837619, 
     3.4280361110756083`}}]}, 
   {Hue[0.6363003388561722], AbsoluteThickness[0.5], 
    LineBox[{{8.413214814154534, -2.9212123474724474`}, {
     8.350165272617577, -3.153393239617193}}]}, 
   {Hue[0.636732745946403], AbsoluteThickness[0.5], 
    LineBox[{{8.350165272617577, -3.153393239617193}, {
     8.265875601492539, -3.4503042976858587`}}]}, 
   {Hue[0.6788039127048674], AbsoluteThickness[0.5], 
    LineBox[{{4.989713941366013, 2.4145628566418673`}, {4.646512210777132, 
     2.4856020010661504`}}]}, 
   {Hue[0.6793266641640509], AbsoluteThickness[0.5], 
    LineBox[{{4.646512210777132, 2.4856020010661504`}, {4.348214114881094, 
     2.534197616189217}}]}, 
   {Hue[0.5499340272818246], AbsoluteThickness[0.5], 
    LineBox[{{4.910759430903985, 2.534861876819981}, {4.872704564368732, 
     2.671888517857498}}]}, 
   {Hue[0.550767362825514], AbsoluteThickness[0.5], 
    LineBox[{{4.872704564368732, 2.671888517857498}, {4.778096133812215, 
     2.9288748090765435`}}]}, 
   {Hue[0.5609932810941921], AbsoluteThickness[0.5], 
    LineBox[{{6.113733579063284, -2.7959792267364305`}, {
     6.105492276978176, -2.851913103397198}}]}, 
   {Hue[0.5616267272667292], AbsoluteThickness[0.5], 
    LineBox[{{6.105492276978176, -2.851913103397198}, {
     6.038797820971663, -3.1694175103509883`}}]}, 
   {Hue[0.5936462179214868], AbsoluteThickness[0.5], 
    LineBox[{{6.117362588661209, -2.1934643961026183`}, {
     5.40178712478938, -2.777649452616401}}]}, 
   {Hue[0.5968403489856341], AbsoluteThickness[0.5], 
    LineBox[{{5.40178712478938, -2.777649452616401}, {
     5.199419394356257, -2.8919724588578934`}}]}, 
   {Hue[0.6724011739714182], AbsoluteThickness[0.5], 
    LineBox[{{7.200172233847885, 0.32285155166020685`}, {7.156856547450469, 
     0.4883670008515649}}]}, 
   {Hue[0.5763243909437841], AbsoluteThickness[0.5], 
    LineBox[{{7.087319688415603, -0.6469652106360281}, {
     6.95283318831776, -0.61682536000801}}]}, 
   {Hue[0.6064664945112775], AbsoluteThickness[0.5], 
    LineBox[{{6.95283318831776, -0.61682536000801}, {
     6.811497785080155, -0.5279484339322117}}]}, 
   {Hue[0.6909823601686085], AbsoluteThickness[0.5], 
    LineBox[{{6.091216357937925, -1.7612673360048654`}, {
     5.888636949171332, -1.8288031391207946`}}]}, 
   {Hue[0.6938506467626476], AbsoluteThickness[0.5], 
    LineBox[{{5.888636949171332, -1.8288031391207946`}, {
     5.675654318604676, -1.8628443487521356`}}]}, 
   {Hue[0.6901950398956954], AbsoluteThickness[0.5], 
    LineBox[{{7.918174982432908, 0.6496496235341948}, {8.057814677682316, 
     0.7897354868812646}}]}, 
   {Hue[0.6920321391498065], AbsoluteThickness[0.5], 
    LineBox[{{8.057814677682316, 0.7897354868812646}, {8.251205735770823, 
     0.9375635866250075}}]}, 
   {Hue[0.6991615543664287], AbsoluteThickness[0.5], 
    LineBox[{{5.501983216141877, -2.129699724911777}, {
     5.380103881235772, -2.1811333394228862`}}]}, 
   {Hue[0.6995920155839522], AbsoluteThickness[0.5], 
    LineBox[{{5.380103881235772, -2.1811333394228862`}, {
     5.066807029246527, -2.3098010355170953`}}]}, 
   {Hue[0.6666809023743036], AbsoluteThickness[0.5], 
    LineBox[{{6.655334519762255, -2.269199865264574}, {
     6.640427495197418, -2.309458667172783}}]}, 
   {Hue[0.6671467161347937], AbsoluteThickness[0.5], 
    LineBox[{{6.640427495197418, -2.309458667172783}, {
     6.513951945054676, -2.623891189997678}}]}, 
   {Hue[0.674007142498566], AbsoluteThickness[0.5], 
    LineBox[{{4.342426496753941, -0.5386559841940423}, {
     4.111780040174579, -0.5691154688202988}}]}, 
   {Hue[0.6749367363094105], AbsoluteThickness[0.5], 
    LineBox[{{4.111780040174579, -0.5691154688202988}, {
     3.8530268536614947`, -0.5799263551656945}}]}, 
   {Hue[0.6647603111752846], AbsoluteThickness[0.5], 
    LineBox[{{7.736517336313909, 0.041696597688378106`}, {
     7.6651095564055005`, -0.03677877897311943}}]}, 
   {Hue[0.6660200849914322], AbsoluteThickness[0.5], 
    LineBox[{{7.6651095564055005`, -0.03677877897311943}, {
     7.490911951299366, -0.1903667540336224}}]}, 
   {Hue[0.6546052395087532], AbsoluteThickness[0.5], 
    LineBox[{{7.851221229629994, 2.4028406753332177`}, {7.867109650527928, 
     2.4074152001256595`}}]}, 
   {Hue[0.6550465054643658], AbsoluteThickness[0.5], 
    LineBox[{{7.867109650527928, 2.4074152001256595`}, {8.154363259274254, 
     2.495569178994785}}]}, 
   {Hue[0.6520689187490476], AbsoluteThickness[0.5], 
    LineBox[{{7.158776787694478, 2.6463995820760804`}, {7.030645348987742, 
     2.627507759754618}}]}, 
   {Hue[0.6568349050654654], AbsoluteThickness[0.5], 
    LineBox[{{7.030645348987742, 2.627507759754618}, {6.847530923384571, 
     2.561917581596624}}]}, 
   {Hue[0.27439685557916266`], AbsoluteThickness[0.5], 
    LineBox[{{7.101909736487721, 2.8319088152941503`}, {7.099740452639225, 
     2.8465558966770454`}}]}, 
   {Hue[0.2749212907932833], AbsoluteThickness[0.5], 
    LineBox[{{7.099740452639225, 2.8465558966770454`}, {7.050199592235489, 
     3.104150986860193}}]}, 
   {Hue[0.6567798030412493], AbsoluteThickness[0.5], 
    LineBox[{{7.287382059810395, 2.8888961332113623`}, {7.3722339578901765`, 
     2.901519222918631}}]}, 
   {Hue[0.6572556405061064], AbsoluteThickness[0.5], 
    LineBox[{{7.3722339578901765`, 2.901519222918631}, {7.64713429871928, 
     2.951169678595261}}]}, 
   {Hue[0.6584946880714764], AbsoluteThickness[0.5], 
    LineBox[{{6.691843155935229, 2.1538751372386757`}, {6.615815865536914, 
     2.1205061181136555`}}]}, 
   {Hue[0.6591901780770248], AbsoluteThickness[0.5], 
    LineBox[{{6.615815865536914, 2.1205061181136555`}, {6.358310786409703, 
     1.9858111698644374`}}]}, 
   {Hue[0.4331837466370641], AbsoluteThickness[0.5], 
    LineBox[{{5.867044451974879, 1.5566368054896491`}, {5.726413752273847, 
     1.5995471529450405`}}]}, 
   {Hue[0.4398249001409664], AbsoluteThickness[0.5], 
    LineBox[{{5.726413752273847, 1.5995471529450405`}, {5.600193810950904, 
     1.6713481522794116`}}]}, 
   {Hue[0.6048468323231135], AbsoluteThickness[0.5], 
    LineBox[{{6.547802470072989, -0.2720996382726648}, {
     6.507585707054884, -0.3794703554341191}}]}, 
   {Hue[0.6056702164352835], AbsoluteThickness[0.5], 
    LineBox[{{6.507585707054884, -0.3794703554341191}, {
     6.427732098816598, -0.6599216620373501}}]}, 
   {Hue[0.5831796687693206], AbsoluteThickness[0.5], 
    LineBox[{{3.2081730367418957`, 2.3671057489221643`}, {3.1782991451553047`,
      2.387987212940285}}]}, 
   {Hue[0.5836061585115446], AbsoluteThickness[0.5], 
    LineBox[{{3.1782991451553047`, 2.387987212940285}, {2.87148781689881, 
     2.604209988660282}}]}, 
   {Hue[0.3543022158127477], AbsoluteThickness[0.5], 
    LineBox[{{5.94684732761072, 2.620028925960009}, {5.903409937433414, 
     2.9091592388681833`}}]}, 
   {Hue[0.35513056483343186`], AbsoluteThickness[0.5], 
    LineBox[{{5.903409937433414, 2.9091592388681833`}, {5.8862403000199155`, 
     3.1624074667428963`}}]}, 
   {Hue[0.6095053686967902], AbsoluteThickness[0.5], 
    LineBox[{{8.176833414021146, 2.001323404552496}, {8.188559639871327, 
     2.099229376633677}}]}, 
   {Hue[0.6099322662968212], AbsoluteThickness[0.5], 
    LineBox[{{8.188559639871327, 2.099229376633677}, {8.225989972898832, 
     2.399566584878138}}]}, 
   {Hue[0.43018424964514224`], AbsoluteThickness[0.5], 
    LineBox[{{3.538572026826272, -0.248976831906159}, {
     3.421101834702676, -0.2721000165818174}}]}, 
   {Hue[0.4306229819525142], AbsoluteThickness[0.5], 
    LineBox[{{3.421101834702676, -0.2721000165818174}, {
     3.111134626534969, -0.3279934650924246}}]}, 
   {Hue[0.5815823965869156], AbsoluteThickness[0.5], 
    LineBox[{{6.618847852367887, -3.3359856355758333`}, {
     6.70507328887334, -3.586722329454685}}]}, 
   {Hue[0.5820294843328778], AbsoluteThickness[0.5], 
    LineBox[{{6.70507328887334, -3.586722329454685}, {
     6.809966807521882, -3.913259320639062}}]}, 
   {Hue[0.503680536141798], AbsoluteThickness[0.5], 
    LineBox[{{3.387919698706914, -1.9516748291211938`}, {
     3.194042177694233, -1.9921941865471766`}}]}, 
   {Hue[0.5041072168087902], AbsoluteThickness[0.5], 
    LineBox[{{3.194042177694233, -1.9921941865471766`}, {
     2.900821168908437, -2.0547978620815046`}}]}, 
   {Hue[0.5683943729023367], AbsoluteThickness[0.5], 
    LineBox[{{3.97446169355675, 2.127443232744459}, {3.829327983946738, 
     2.2489100595024336`}}]}, 
   {Hue[0.5707859823185192], AbsoluteThickness[0.5], 
    LineBox[{{3.829327983946738, 2.2489100595024336`}, {3.6704956400698032`, 
     2.345299403652872}}]}, 
   {Hue[0.651820814602721], AbsoluteThickness[0.5], 
    LineBox[{{8.092413729545955, -3.173533051402061}, {
     8.180016984815781, -3.195485004066221}}]}, 
   {Hue[0.6524677227081251], AbsoluteThickness[0.5], 
    LineBox[{{8.180016984815781, -3.195485004066221}, {
     8.449650508536998, -3.2812750062343294`}}]}, 
   {Hue[0.3485261970672197], AbsoluteThickness[0.5], 
    LineBox[{{4.534238698711695, -4.1622418413519835`}, {
     4.42061524560626, -4.268002310840936}}]}, 
   {Hue[0.3551194858387934], AbsoluteThickness[0.5], 
    LineBox[{{4.42061524560626, -4.268002310840936}, {
     4.257603503519386, -4.363304573652053}}]}, 
   {Hue[0.6352959291814091], AbsoluteThickness[0.5], 
    LineBox[{{4.257603503519386, -4.363304573652053}, {
     4.11942388907462, -4.23461213600705}}]}, 
   {Hue[0.6906024061040655], AbsoluteThickness[0.5], 
    LineBox[{{3.054354681655003, -1.187943136511272}, {
     2.9843415078996, -1.138287626112131}}]}, 
   {Hue[0.6923892640619542], AbsoluteThickness[0.5], 
    LineBox[{{2.9843415078996, -1.138287626112131}, {
     2.8265269054589583`, -0.991431239231634}}]}, 
   {Hue[0.6507414254836712], AbsoluteThickness[0.5], 
    LineBox[{{2.1522504194559615`, -2.350691308028444}, {
     2.142272369191707, -2.3786018664463047`}}]}, 
   {Hue[0.6514918780297514], AbsoluteThickness[0.5], 
    LineBox[{{2.142272369191707, -2.3786018664463047`}, {
     2.0212385610678707`, -2.651444689244636}}]}, 
   {Hue[0.5606589856945373], AbsoluteThickness[0.5], 
    LineBox[{{4.892430575263001, 3.122750265386465}, {4.8915763505502055`, 
     3.1243961835088494`}}]}, 
   {Hue[0.5611762695308693], AbsoluteThickness[0.5], 
    LineBox[{{4.8915763505502055`, 3.1243961835088494`}, {4.761226025805638, 
     3.4032479925117745`}}]}, 
   {Hue[0.5607721081683339], AbsoluteThickness[0.5], 
    LineBox[{{4.3774770971887245`, 1.9971218660906978`}, {4.266452344190504, 
     2.0863654629417723`}}]}, 
   {Hue[0.5619172878224833], AbsoluteThickness[0.5], 
    LineBox[{{4.266452344190504, 2.0863654629417723`}, {4.075890544682921, 
     2.2751437449874863`}}]}, 
   {Hue[0.5508873332613357], AbsoluteThickness[0.5], 
    LineBox[{{4.825724737661423, -2.088343552397559}, {
     4.78905972178139, -2.1053615308275067`}}]}, 
   {Hue[0.5543058757189324], AbsoluteThickness[0.5], 
    LineBox[{{4.78905972178139, -2.1053615308275067`}, {
     4.629650704966972, -2.216658134139652}}]}, 
   {Hue[0.5802648777973933], AbsoluteThickness[0.5], 
    LineBox[{{5.090473139923394, 0.7374218268061139}, {4.884544882819118, 
     0.7910996957101797}}]}, 
   {Hue[0.581438664467327], AbsoluteThickness[0.5], 
    LineBox[{{4.884544882819118, 0.7910996957101797}, {4.6335404542532554`, 
     0.8289646191719509}}]}, 
   {Hue[0.5526302585277265], AbsoluteThickness[0.5], 
    LineBox[{{6.690610036272507, -1.4078476767354253`}, {
     6.657355374547379, -1.4504034661268257`}}]}, 
   {Hue[0.5531609225724665], AbsoluteThickness[0.5], 
    LineBox[{{6.657355374547379, -1.4504034661268257`}, {
     6.482621590976752, -1.6547036927676912`}}]}, 
   {Hue[0.6821886983861355], AbsoluteThickness[0.5], 
    LineBox[{{7.852774090257703, -1.5006121927318183`}, {
     7.564959788695516, -1.3805523591873274`}}]}, 
   {Hue[0.6572916499670656], AbsoluteThickness[0.5], 
    LineBox[{{8.113010999242983, -1.8882338328657222`}, {
     8.163107482279257, -1.890169507142647}}]}, 
   {Hue[0.670721810094077], AbsoluteThickness[0.5], 
    LineBox[{{8.163107482279257, -1.890169507142647}, {
     8.321066090134172, -1.8522307229926285`}}]}, 
   {Hue[0.22612136687788578`], AbsoluteThickness[0.5], 
    LineBox[{{8.082170567618235, -2.11183533372746}, {
     8.027286574712432, -2.3230178318651085`}}]}, 
   {Hue[0.22655202040953087`], AbsoluteThickness[0.5], 
    LineBox[{{8.027286574712432, -2.3230178318651085`}, {
     7.947998734759508, -2.6162229324364703`}}]}, 
   {Hue[0.6601095238077959], AbsoluteThickness[0.5], 
    LineBox[{{7.870347099697598, -2.033863660355023}, {
     7.615073899121223, -1.9042230213782758`}}]}, 
   {Hue[0.6620149025970231], AbsoluteThickness[0.5], 
    LineBox[{{7.615073899121223, -1.9042230213782758`}, {
     7.411996550938982, -1.8339336670243103`}}]}, 
   {Hue[0.5824912608927985], AbsoluteThickness[0.5], 
    LineBox[{{6.840469680316674, -0.3359238797185977}, {
     6.839623076063976, -0.3357783636661541}}]}, 
   {Hue[0.5831437960512444], AbsoluteThickness[0.5], 
    LineBox[{{6.839623076063976, -0.3357783636661541}, {
     6.546533951632397, -0.26608623200507564`}}]}, 
   {Hue[0.40101277982799904`], AbsoluteThickness[0.5], 
    LineBox[{{7.20989690304216, -1.4346329557336868`}, {
     7.010494828486968, -1.8625395614803313`}}]}, 
   {Hue[0.4016495399834114], AbsoluteThickness[0.5], 
    LineBox[{{7.010494828486968, -1.8625395614803313`}, {
     6.909934196985228, -2.1181048832976273`}}]}, 
   {Hue[0.5407927494843452], AbsoluteThickness[0.5], 
    LineBox[{{7.054282042140435, 1.352716413629225}, {7.036250028218527, 
     1.4053272295887205`}}]}, 
   {Hue[0.5412851283399747], AbsoluteThickness[0.5], 
    LineBox[{{7.036250028218527, 1.4053272295887205`}, {6.94159779007513, 
     1.6524398150218027`}}]}, 
   {Hue[0.684006791115724], AbsoluteThickness[0.5], 
    LineBox[{{8.112261487492178, 0.8985828620418925}, {8.112479417181389, 
     0.9009528935726415}}]}, 
   {Hue[0.6848503451120753], AbsoluteThickness[0.5], 
    LineBox[{{8.112479417181389, 0.9009528935726415}, {8.1150273317068, 
     1.185091355684414}}]}, 
   {Hue[0.5693444018284715], AbsoluteThickness[0.5], 
    LineBox[{{5.9542502168143585`, 1.1003461488955129`}, {5.858227520386525, 
     1.0933813247219857`}}]}, 
   {Hue[0.5733424269258717], AbsoluteThickness[0.5], 
    LineBox[{{5.858227520386525, 1.0933813247219857`}, {5.628008791365957, 
     1.1195306515478172`}}]}, 
   {Hue[0.6231446904590922], AbsoluteThickness[0.5], 
    LineBox[{{4.619278244988409, -0.719000973751349}, {
     4.424794420233457, -0.7543635970470365}}]}, 
   {Hue[0.6235718739986283], AbsoluteThickness[0.5], 
    LineBox[{{4.424794420233457, -0.7543635970470365}, {
     4.120994459372017, -0.8079279384398885}}]}, 
   {Hue[0.5495176285658809], AbsoluteThickness[0.5], 
    LineBox[{{5.106313691046077, 2.3294110350738806`}, {5.084925096908708, 
     2.4060893324825785`}}]}, 
   {Hue[0.5499434064805777], AbsoluteThickness[0.5], 
    LineBox[{{5.084925096908708, 2.4060893324825785`}, {5.010945845477219, 
     2.672238208985169}}]}, 
   {Hue[0.5831655808041457], AbsoluteThickness[0.5], 
    LineBox[{{4.450353755805007, -2.6648697355702615`}, {
     4.423199271690903, -2.684631367227786}}]}, 
   {Hue[0.5836503979617941], AbsoluteThickness[0.5], 
    LineBox[{{4.423199271690903, -2.684631367227786}, {
     4.186730649351903, -2.844858290445353}}]}, 
   {Hue[0.5115825518339923], AbsoluteThickness[0.5], 
    LineBox[{{5.021828387008208, -3.6548322427269113`}, {
     4.923774507469937, -3.901983398003938}}]}, 
   {Hue[0.5162146671806878], AbsoluteThickness[0.5], 
    LineBox[{{4.923774507469937, -3.901983398003938}, {
     4.890286668989602, -4.0838502241117896`}}]}, 
   {Hue[0.5625168620177029], AbsoluteThickness[0.5], 
    LineBox[{{2.8500711487036394`, -2.6071219764809106`}, {
     2.849194938883284, -2.608175532086864}}]}, 
   {Hue[0.5629462062178349], AbsoluteThickness[0.5], 
    LineBox[{{2.849194938883284, -2.608175532086864}, {
     2.6303424241088087`, -2.875882312110963}}]}, 
   {Hue[0.6995734922834443], AbsoluteThickness[0.5], 
    LineBox[{{2.587864227679066, -4.19981037741914}, {
     2.350756140075879, -4.346907219780113}}]}, 
   {Hue[0.6481327338625958], AbsoluteThickness[0.5], 
    LineBox[{{6.939401135504566, -2.5977107157373154`}, {
     6.878441386051601, -2.6898484103502054`}}]}, 
   {Hue[0.6488025018946525], AbsoluteThickness[0.5], 
    LineBox[{{6.878441386051601, -2.6898484103502054`}, {
     6.701380426182704, -2.9228339198541726`}}]}, 
   {Hue[0.24048156814484437`], AbsoluteThickness[0.5], 
    LineBox[{{8.128771201372222, -2.48149666384228}, {
     8.27857172176629, -2.6015687816946746`}}]}, 
   {Hue[0.24236107264452375`], AbsoluteThickness[0.5], 
    LineBox[{{8.27857172176629, -2.6015687816946746`}, {
     8.468193424002491, -2.8013549820143013`}}]}, 
   {Hue[0.6473809694865102], AbsoluteThickness[0.5], 
    LineBox[{{8.468193424002491, -2.8013549820143013`}, {
     8.252741644672328, -2.972969219712039}}]}, 
   {Hue[0.6571395527806968], AbsoluteThickness[0.5], 
    LineBox[{{8.005954775621067, -1.3969365314326265`}, {
     8.132980526863353, -1.3059673830050569`}}]}, 
   {Hue[0.6575682988254221], AbsoluteThickness[0.5], 
    LineBox[{{8.132980526863353, -1.3059673830050569`}, {
     8.374594675143245, -1.1357354187474387`}}]}, 
   {Hue[0.625881695916956], AbsoluteThickness[0.5], 
    LineBox[{{3.529822058405508, 2.1403900997047196`}, {3.444765697346773, 
     2.291562280105297}}]}, 
   {Hue[0.6779657828422466], AbsoluteThickness[0.5], 
    LineBox[{{3.444765697346773, 2.291562280105297}, {3.3204529290578106`, 
     2.3902777693330934`}}]}, 
   {Hue[0.6683740750051782], AbsoluteThickness[0.5], 
    LineBox[{{8.056362983429345, -1.1731684351515157`}, {
     7.938727215765984, -1.4075415987071034`}}]}, 
   {Hue[0.6700838531121304], AbsoluteThickness[0.5], 
    LineBox[{{7.938727215765984, -1.4075415987071034`}, {
     7.865015635528626, -1.6189623212629007`}}]}, 
   {Hue[0.6229295466805843], AbsoluteThickness[0.5], 
    LineBox[{{7.408168799288016, -0.8292249785419747}, {
     7.42542649439175, -0.874492372778701}}]}, 
   {Hue[0.6235698701488476], AbsoluteThickness[0.5], 
    LineBox[{{7.42542649439175, -0.874492372778701}, {
     7.544793856834848, -1.1376117829390586`}}]}, 
   {Hue[0.40775006916628465`], AbsoluteThickness[0.5], 
    LineBox[{{5.745913387735054, 3.401151074217439}, {5.663601535493142, 
     3.4934880239016524`}}]}, 
   {Hue[0.4086819263035567], AbsoluteThickness[0.5], 
    LineBox[{{5.663601535493142, 3.4934880239016524`}, {5.447640698324035, 
     3.6958994310932796`}}]}, 
   {Hue[0.5491258823780885], AbsoluteThickness[0.5], 
    LineBox[{{6.1742847683642905`, 2.3303941980732543`}, {6.121791216509047, 
     2.337474503801307}}]}, 
   {Hue[0.5520648006898308], AbsoluteThickness[0.5], 
    LineBox[{{6.121791216509047, 2.337474503801307}, {5.904773752012882, 
     2.40436246201966}}]}, 
   {Hue[0.5887396456707166], AbsoluteThickness[0.5], 
    LineBox[{{6.675409231196168, 2.272796650093518}, {6.44448681554109, 
     2.2643494212171933`}}]}, 
   {Hue[0.5892182375209902], AbsoluteThickness[0.5], 
    LineBox[{{6.44448681554109, 2.2643494212171933`}, {6.130380974655817, 
     2.242835944917377}}]}, 
   {Hue[0.6032487261973957], AbsoluteThickness[0.5], 
    LineBox[{{7.60663463756123, 2.3668950816325114`}, {7.359236867177295, 
     2.269399540691426}}]}, 
   {Hue[0.6037828675222887], AbsoluteThickness[0.5], 
    LineBox[{{7.359236867177295, 2.269399540691426}, {7.0798532049662235`, 
     2.173555070450576}}]}, 
   {Hue[0.5523267068567963], AbsoluteThickness[0.5], 
    LineBox[{{8.149674483573722, 2.589767496202743}, {8.154403263725087, 
     2.495338784595102}}]}, 
   {Hue[0.6065506370649126], AbsoluteThickness[0.5], 
    LineBox[{{8.154403263725087, 2.495338784595102}, {8.104887900407892, 
     2.355578124357415}}]}, 
   {Hue[0.6958275151900791], AbsoluteThickness[0.5], 
    LineBox[{{8.104887900407892, 2.355578124357415}, {7.959781492385336, 
     2.3250995465477575`}}]}, 
   {Hue[0.5538336678139426], AbsoluteThickness[0.5], 
    LineBox[{{8.122252615323708, 2.8882965147811217`}, {8.072452714594746, 
     2.904735347946129}}]}, 
   {Hue[0.5549790173125374], AbsoluteThickness[0.5], 
    LineBox[{{8.072452714594746, 2.904735347946129}, {7.844195077655641, 
     3.00734810157187}}]}, 
   {Hue[0.6050513191828529], AbsoluteThickness[0.5], 
    LineBox[{{7.743497739669455, 2.123494058446904}, {7.665105008422096, 
     2.0692279554090476`}}]}, 
   {Hue[0.6056597441944204], AbsoluteThickness[0.5], 
    LineBox[{{7.665105008422096, 2.0692279554090476`}, {7.389501592758315, 
     1.9009378317368384`}}]}, 
   {Hue[0.610109308530955], AbsoluteThickness[0.5], 
    LineBox[{{7.260477484587177, 1.1142943773174796`}, {7.1645555717487, 
     1.0362292431250322`}}]}, 
   {Hue[0.6106785735744431], AbsoluteThickness[0.5], 
    LineBox[{{7.1645555717487, 1.0362292431250322`}, {6.928032609155934, 
     0.8630970452538537}}]}, 
   {Hue[0.5554829433473792], AbsoluteThickness[0.5], 
    LineBox[{{8.005214679975802, 0.8813857955213649}, {8.05943813465084, 
     0.8027118129471802}}]}, 
   {Hue[0.5569306681849526], AbsoluteThickness[0.5], 
    LineBox[{{8.05943813465084, 0.8027118129471802}, {8.227932108697644, 
     0.6115350012692857}}]}, 
   {Hue[0.6078558430295325], AbsoluteThickness[0.5], 
    LineBox[{{5.675717351249698, 0.10460087531519621`}, {5.650915911821739, 
     0.09030902031070787}}]}, 
   {Hue[0.6082952028719911], AbsoluteThickness[0.5], 
    LineBox[{{5.650915911821739, 0.09030902031070785}, {
     5.446407101204477, -0.02313121211159941}}]}, 
   {Hue[0.662625634109464], AbsoluteThickness[0.5], 
    LineBox[{{4.41774203418334, 1.5200044649987976`}, {4.165011066208282, 
     1.5009640623873128`}}]}, 
   {Hue[0.6630519115165976], AbsoluteThickness[0.5], 
    LineBox[{{4.165011066208282, 1.5009640623873128`}, {3.868400325203023, 
     1.479592295625569}}]}, 
   {Hue[0.5160218034893259], AbsoluteThickness[0.5], 
    LineBox[{{5.207743513392063, 2.8577867218133304`}, {5.130329365861044, 
     2.9153728962608296`}}]}, 
   {Hue[0.5164625839234877], AbsoluteThickness[0.5], 
    LineBox[{{5.130329365861044, 2.9153728962608296`}, {4.869705720764164, 
     3.10238488154577}}]}, 
   {Hue[0.5816772849240762], AbsoluteThickness[0.5], 
    LineBox[{{5.2691734055796395`, -2.396724050244714}, {
     5.125095748813396, -2.5901746390439246`}}]}, 
   {Hue[0.6040761996826423], AbsoluteThickness[0.5], 
    LineBox[{{5.125095748813396, -2.5901746390439246`}, {
     5.067868118194362, -2.760450478811867}}]}, 
   {Hue[0.5869344570530307], AbsoluteThickness[0.5], 
    LineBox[{{3.6155994324587826`, -1.894525461251382}, {
     3.615214993392053, -1.8948731222848716`}}]}, 
   {Hue[0.5873607276402157], AbsoluteThickness[0.5], 
    LineBox[{{3.615214993392053, -1.8948731222848716`}, {
     3.4159639877479133`, -2.0762419631981595`}}]}, 
   {Hue[0.6721315895436709], AbsoluteThickness[0.5], 
    LineBox[{{3.1813073741642923`, 2.8737658495676683`}, {3.1359520954765516`,
      2.912944554414682}}]}, 
   {Hue[0.6726011144956507], AbsoluteThickness[0.5], 
    LineBox[{{3.1359520954765516`, 2.912944554414682}, {2.9081181198589725`, 
     3.1216031644612454`}}]}, 
   {Hue[0.4101634909700163], AbsoluteThickness[0.5], 
    LineBox[{{3.3756474746787504`, 3.5578189227949846`}, {3.269069739777134, 
     3.6220859265871312`}}]}, 
   {Hue[0.41108082210034297`], AbsoluteThickness[0.5], 
    LineBox[{{3.269069739777134, 3.6220859265871312`}, {3.0573858926927096`, 
     3.776833976489408}}]}, 
   {Hue[0.6907705232102473], AbsoluteThickness[0.5], 
    LineBox[{{4.370922781610552, 3.0192497553137096`}, {4.320592808397393, 
     3.1153497680574076`}}]}, 
   {Hue[0.691204860066159], AbsoluteThickness[0.5], 
    LineBox[{{4.320592808397393, 3.1153497680574076`}, {4.155834208809857, 
     3.4401408381186647`}}]}, 
   {Hue[0.5747566184512063], AbsoluteThickness[0.5], 
    LineBox[{{8.026535331140416, -2.1312468752421223`}, {
     8.077589081472947, -2.185118776997969}}]}, 
   {Hue[0.5754524453763126], AbsoluteThickness[0.5], 
    LineBox[{{8.077589081472947, -2.185118776997969}, {
     8.301484984920078, -2.391148681626046}}]}, 
   {Hue[0.6963342158632799], AbsoluteThickness[0.5], 
    LineBox[{{5.035227669071989, -3.6526989879522036`}, {
     5.032382026991558, -3.8673248057644463`}}]}, 
   {Hue[0.6967643642663897], AbsoluteThickness[0.5], 
    LineBox[{{5.032382026991558, -3.8673248057644463`}, {
     5.025766994392219, -4.160269302588668}}]}, 
   {Hue[0.6369860578277105], AbsoluteThickness[0.5], 
    LineBox[{{3.977505836413961, 3.095252481737712}, {3.9379194527332, 
     3.1948716882992114`}}]}, 
   {Hue[0.6383738998773995], AbsoluteThickness[0.5], 
    LineBox[{{3.9379194527332, 3.1948716882992114`}, {3.812007353556518, 
     3.4284144011240247`}}]}, 
   {Hue[0.5933033110977204], AbsoluteThickness[0.5], 
    LineBox[{{2.6935174959428623`, 2.9025393038137066`}, {2.61848240714257, 
     2.99242727026059}}]}, 
   {Hue[0.5957451356089605], AbsoluteThickness[0.5], 
    LineBox[{{2.61848240714257, 2.99242727026059}, {2.4512462266413277`, 
     3.1398327406820012`}}]}, 
   {Hue[0.5610209585018751], AbsoluteThickness[0.5], 
    LineBox[{{2.1416337583908494`, -2.816956223302733}, {
     2.1283754756219753`, -2.840292231353996}}]}, 
   {Hue[0.5614477937769188], AbsoluteThickness[0.5], 
    LineBox[{{2.1283754756219753`, -2.8402922313539967`}, {
     1.9617230760765, -3.130464610862816}}]}, 
   {Hue[0.6079930640215117], AbsoluteThickness[0.5], 
    LineBox[{{7.302785761556029, -0.936095584107759}, {
     7.387688852823115, -1.0083311916479896`}}]}, 
   {Hue[0.6099338996412954], AbsoluteThickness[0.5], 
    LineBox[{{7.387688852823115, -1.0083311916479896`}, {
     7.582688526243872, -1.1325168684922842`}}]}, 
   {Hue[0.6265241156097846], AbsoluteThickness[0.5], 
    LineBox[{{4.70685809455572, 3.387527058565831}, {4.64810496393761, 
     3.426945790720795}}]}, 
   {Hue[0.6269899316515557], AbsoluteThickness[0.5], 
    LineBox[{{4.64810496393761, 3.426945790720795}, {4.408554572928095, 
     3.5975106450604746`}}]}, 
   {Hue[0.6351465045436524], AbsoluteThickness[0.5], 
    LineBox[{{7.517236611483914, 2.814501905121874}, {7.592611809052062, 
     2.7837529267727246`}}]}, 
   {Hue[0.6357325658537685], AbsoluteThickness[0.5], 
    LineBox[{{7.592611809052062, 2.7837529267727246`}, {7.844973517905891, 
     2.6963573478968876`}}]}, 
   {Hue[0.24041578763856386`], AbsoluteThickness[0.5], 
    LineBox[{{7.654994426077595, 3.5554240113134896`}, {7.690238137868821, 
     3.6025522200568836`}}]}, 
   {Hue[0.24084818034033237`], AbsoluteThickness[0.5], 
    LineBox[{{7.690238137868821, 3.6025522200568836`}, {7.881844528438306, 
     3.8649764211033224`}}]}, 
   {Hue[0.6465006442772443], AbsoluteThickness[0.5], 
    LineBox[{{7.037050949080651, 0.29818282138163965`}, {7.070963861340593, 
     0.15529253265819598`}}]}, 
   {Hue[0.6472075211996788], AbsoluteThickness[0.5], 
    LineBox[{{7.070963861340593, 0.15529253265819598`}, {
     7.104948006276149, -0.05082166296360853}}]}, 
   {Hue[0.6482097599309109], AbsoluteThickness[0.5], 
    LineBox[{{3.1435775763814275`, 3.382275553748318}, {3.086460399662175, 
     3.407074500056825}}]}, 
   {Hue[0.649019190944965], AbsoluteThickness[0.5], 
    LineBox[{{3.086460399662175, 3.407074500056825}, {2.8489492290488845`, 
     3.533569775408288}}]}, 
   {Hue[0.6461357223669338], AbsoluteThickness[0.5], 
    LineBox[{{2.704419435254165, -4.400361396971252}, {
     2.6966304926893745`, -4.420235189543883}}]}, 
   {Hue[0.6471788137970603], AbsoluteThickness[0.5], 
    LineBox[{{2.6966304926893745`, -4.420235189543883}, {
     2.5691688328505355`, -4.670589441838488}}]}, 
   {Hue[0.5399985501192892], AbsoluteThickness[0.5], 
    LineBox[{{6.377501697143815, -4.125425650701477}, {
     6.488540366080848, -4.368427354870165}}]}, 
   {Hue[0.5404658453305577], AbsoluteThickness[0.5], 
    LineBox[{{6.488540366080848, -4.368427354870165}, {
     6.611200085437479, -4.658292226312249}}]}, 
   {Hue[0.6753386203549576], AbsoluteThickness[0.5], 
    LineBox[{{2.593581503910271, -1.842709679913864}, {
     2.587449810032835, -1.8442719907538494`}}]}, 
   {Hue[0.6760950971826406], AbsoluteThickness[0.5], 
    LineBox[{{2.587449810032835, -1.8442719907538494`}, {
     2.317668506302129, -1.9349528906515239`}}]}, 
   {Hue[0.6105922075639945], AbsoluteThickness[0.5], 
    LineBox[{{6.158377046542862, 1.079655511838091}, {6.14414437108626, 
     1.1276826515682743`}}]}, 
   {Hue[0.6116776698206041], AbsoluteThickness[0.5], 
    LineBox[{{6.14414437108626, 1.1276826515682743`}, {6.0960400150533145`, 
     1.3804910351795916`}}]}, 
   {Hue[0.6696668329710174], AbsoluteThickness[0.5], 
    LineBox[{{5.065776237865189, 0.3138209934879861}, {4.748387677789791, 
     0.5613707498111629}}]}, 
   {Hue[0.6716208360730863], AbsoluteThickness[0.5], 
    LineBox[{{4.748387677789791, 0.5613707498111629}, {4.5883124840740335`, 
     0.7264277874548725}}]}, 
   {Hue[0.6685457982893184], AbsoluteThickness[0.5], 
    LineBox[{{6.381609940183878, -1.0712390887599839`}, {
     6.345263754650192, -1.0766511980307603`}}]}, 
   {Hue[0.6728221133612629], AbsoluteThickness[0.5], 
    LineBox[{{6.345263754650192, -1.0766511980307603`}, {
     6.143015728985267, -1.1477198518691811`}}]}, 
   {Hue[0.6687568635033309], AbsoluteThickness[0.5], 
    LineBox[{{7.115306982609331, -1.2360895645433216`}, {
     6.888298191582205, -1.3944953678094458`}}]}, 
   {Hue[0.6779775831859447], AbsoluteThickness[0.5], 
    LineBox[{{7.421059005638186, -0.3380010226705051}, {
     7.38599830689422, -0.336716567854607}}]}, 
   {Hue[0.6784822206493685], AbsoluteThickness[0.5], 
    LineBox[{{7.38599830689422, -0.336716567854607}, {
     7.0937162565677365`, -0.3146867318148557}}]}, 
   {Hue[0.6680325077968484], AbsoluteThickness[0.5], 
    LineBox[{{6.595006748083417, 0.28580785448505197`}, {6.5188300102899275`, 
     0.4051759688395875}}]}, 
   {Hue[0.6684877032883626], AbsoluteThickness[0.5], 
    LineBox[{{6.5188300102899275`, 0.4051759688395875}, {6.383586783581768, 
     0.6287112059635681}}]}, 
   {Hue[0.6725426198558935], AbsoluteThickness[0.5], 
    LineBox[{{5.340894985895122, -1.0722375888756497`}, {
     5.147901740684832, -1.0970931235489243`}}]}, 
   {Hue[0.6741226021836], AbsoluteThickness[0.5], 
    LineBox[{{5.147901740684832, -1.0970931235489243`}, {
     4.922056451717865, -1.0978764544743551`}}]}, 
   {Hue[0.5937337261502105], AbsoluteThickness[0.5], 
    LineBox[{{6.051783412638282, -2.6623824470807356`}, {
     5.845238695539821, -2.799868714732223}}]}, 
   {Hue[0.5950392251857696], AbsoluteThickness[0.5], 
    LineBox[{{5.845238695539821, -2.799868714732223}, {
     5.645950130047048, -2.90237123912204}}]}, 
   {Hue[0.6732388857334971], AbsoluteThickness[0.5], 
    LineBox[{{3.054373136532107, -0.7840587567859695}, {
     2.9309925678202466`, -0.7892827438236146}}]}, 
   {Hue[0.6736880712020434], AbsoluteThickness[0.5], 
    LineBox[{{2.9309925678202466`, -0.7892827438236146}, {
     2.6447463609147697`, -0.7952798311964091}}]}, 
   {Hue[0.6738208854423878], AbsoluteThickness[0.5], 
    LineBox[{{5.0626744504079495`, 1.6543114717460656`}, {5.028967556023222, 
     1.8350542771973388`}}]}, 
   {Hue[0.6742892629668616], AbsoluteThickness[0.5], 
    LineBox[{{5.028967556023222, 1.8350542771973388`}, {4.989567072597458, 
     2.0860391559845612`}}]}, 
   {Hue[0.5642808152733981], AbsoluteThickness[0.5], 
    LineBox[{{4.144111651976884, 1.3840857233728665`}, {4.120747365339233, 
     1.3877412908696827`}}]}, 
   {Hue[0.5651839025555531], AbsoluteThickness[0.5], 
    LineBox[{{4.120747365339233, 1.3877412908696827`}, {3.87473073868987, 
     1.448659958107534}}]}, 
   {Hue[0.5893254923192836], AbsoluteThickness[0.5], 
    LineBox[{{4.13284966389924, 3.422974821525778}, {4.126137078189405, 
     3.4766488668031004`}}]}, 
   {Hue[0.5920302064136581], AbsoluteThickness[0.5], 
    LineBox[{{4.126137078189405, 3.4766488668031004`}, {4.069152240593838, 
     3.6719786092446527`}}]}, 
   {Hue[0.6945197577797492], AbsoluteThickness[0.5], 
    LineBox[{{6.092280012794133, -2.843424693458682}, {
     6.130799331144638, -2.812568719069882}}]}, 
   {Hue[0.6949937423080255], AbsoluteThickness[0.5], 
    LineBox[{{6.130799331144638, -2.812568719069882}, {
     6.332676434423579, -2.6607058165568227`}}]}, 
   {Hue[0.6293118417817734], AbsoluteThickness[0.5], 
    LineBox[{{8.118379058300926, 0.6449226663315251}, {8.119523039865333, 
     0.6469716231309538}}]}, 
   {Hue[0.6297574960784267], AbsoluteThickness[0.5], 
    LineBox[{{8.119523039865333, 0.6469716231309538}, {8.283800130237383, 
     0.928040468853838}}]}, 
   {Hue[0.5583622922799693], AbsoluteThickness[0.5], 
    LineBox[{{7.309970576340112, -3.381544453280943}, {
     7.395298722188936, -3.413518468903136}}]}, 
   {Hue[0.5591064181828234], AbsoluteThickness[0.5], 
    LineBox[{{7.395298722188936, -3.413518468903136}, {
     7.639694343258777, -3.526215243966392}}]}, 
   {Hue[0.6594458627863881], AbsoluteThickness[0.5], 
    LineBox[{{6.2152155951258345`, -2.5810723405099556`}, {
     6.34359077419019, -2.379012092694996}}]}, 
   {Hue[0.6620368805728879], AbsoluteThickness[0.5], 
    LineBox[{{6.34359077419019, -2.379012092694996}, {
     6.435326701516632, -2.167577987088304}}]}, 
   {Hue[0.6314727388869564], AbsoluteThickness[0.5], 
    LineBox[{{6.900543530396513, -3.711440073745309}, {
     6.990645719835519, -3.849102502806385}}]}, 
   {Hue[0.6322237957794573], AbsoluteThickness[0.5], 
    LineBox[{{6.990645719835519, -3.849102502806385}, {
     7.124178761335555, -4.090481948885803}}]}, 
   {Hue[0.6722717063749083], AbsoluteThickness[0.5], 
    LineBox[{{8.004361075079022, -0.3933941032834033}, {
     8.159771947371866, -0.36936836962560776`}}]}, 
   {Hue[0.6734632144623384], AbsoluteThickness[0.5], 
    LineBox[{{8.159771947371866, -0.36936836962560776`}, {
     8.426015205107939, -0.2986464339759695}}]}, 
   {Hue[0.6771089417263239], AbsoluteThickness[0.5], 
    LineBox[{{4.599435908218015, 2.3473535365259495`}, {4.599640939238517, 
     2.35057737266454}}]}, 
   {Hue[0.6786984449615286], AbsoluteThickness[0.5], 
    LineBox[{{4.599640939238517, 2.35057737266454}, {4.584860866866911, 
     2.5906355797733256`}}]}, 
   {Hue[0.6836785688592513], AbsoluteThickness[0.5], 
    LineBox[{{6.5695900465028005`, 3.6323580995431572`}, {6.581369274045664, 
     3.653370506680564}}]}, 
   {Hue[0.6842973184191464], AbsoluteThickness[0.5], 
    LineBox[{{6.581369274045664, 3.653370506680564}, {6.752029282274451, 
     3.919803111211337}}]}, 
   {Hue[0.539599646319356], AbsoluteThickness[0.5], 
    LineBox[{{6.643629357222951, -3.9353858072439656`}, {
     6.838281934661396, -4.009001751232687}}]}, 
   {Hue[0.5401572172339469], AbsoluteThickness[0.5], 
    LineBox[{{6.838281934661396, -4.009001751232687}, {
     7.1179331010595845`, -4.099294926275692}}]}, 
   {Hue[0.6140365899925891], AbsoluteThickness[0.5], 
    LineBox[{{6.137275091159029, -3.6134020134562284`}, {
     6.1434344732077335`, -3.6147069842501045`}}]}, 
   {Hue[0.6157169293657141], AbsoluteThickness[0.5], 
    LineBox[{{6.1434344732077335`, -3.6147069842501045`}, {
     6.35913336615644, -3.6903697292568918`}}]}, 
   {Hue[0.6982802555583763], AbsoluteThickness[0.5], 
    LineBox[{{6.980064814907501, 2.6360577075587694`}, {7.0890061923480605`, 
     2.796576213733028}}]}, 
   {Hue[0.6543687265245942], AbsoluteThickness[0.5], 
    LineBox[{{6.833207782240434, -0.9269446988361995}, {
     6.840889513987098, -0.9283373749152}}]}, 
   {Hue[0.655036134807311], AbsoluteThickness[0.5], 
    LineBox[{{6.840889513987098, -0.9283373749152}, {
     7.097228434674572, -0.9922687171851868}}]}, 
   {Hue[0.6229533842634921], AbsoluteThickness[0.5], 
    LineBox[{{3.9721082559078655`, -3.5866860519826593`}, {
     3.958602728586494, -3.650365267340968}}]}, 
   {Hue[0.625264073123362], AbsoluteThickness[0.5], 
    LineBox[{{3.958602728586494, -3.650365267340968}, {
     3.8697384423712133`, -3.8877774626920565`}}]}, 
   {Hue[0.641308530243201], AbsoluteThickness[0.5], 
    LineBox[{{2.859527213339528, -2.6161932857223684`}, {
     2.8594789717441813`, -2.6161931558708007`}}]}, 
   {Hue[0.6431589806235248], AbsoluteThickness[0.5], 
    LineBox[{{2.8594789717441813`, -2.6161931558708007`}, {
     2.6056204162088434`, -2.6499281619610047`}}]}, 
   {Hue[0.5985291783381672], AbsoluteThickness[0.5], 
    LineBox[{{2.826503644727011, -0.9941157286018478}, {
     2.6513675971080937`, -0.9590523362681111}}]}, 
   {Hue[0.5993888060017665], AbsoluteThickness[0.5], 
    LineBox[{{2.6513675971080937`, -0.9590523362681111}, {
     2.344982164585665, -0.9241198354907832}}]}, 
   {Hue[0.5772011592810762], AbsoluteThickness[0.5], 
    LineBox[{{3.1763028621250227`, 1.367380054709261}, {3.1177421855365615`, 
     1.391320257707196}}]}, 
   {Hue[0.5777172119394351], AbsoluteThickness[0.5], 
    LineBox[{{3.1177421855365615`, 1.391320257707196}, {2.81715101341015, 
     1.5289110027312063`}}]}, 
   {Hue[0.5719860628256451], AbsoluteThickness[0.5], 
    LineBox[{{4.136204013050589, 0.2749748351498943}, {3.910476361715091, 
     0.28942044353344487`}}]}, 
   {Hue[0.5726900186712878], AbsoluteThickness[0.5], 
    LineBox[{{3.910476361715091, 0.28942044353344487`}, {3.6192866942430797`, 
     0.28785285798352067`}}]}, 
   {Hue[0.5735000320249564], AbsoluteThickness[0.5], 
    LineBox[{{5.051875130029453, 0.2564720054982866}, {4.8617056037392565`, 
     0.23873622063259348`}}]}, 
   {Hue[0.574036854588792], AbsoluteThickness[0.5], 
    LineBox[{{4.8617056037392565`, 0.23873622063259348`}, {4.604877999663432, 
     0.22651434155274883`}}]}, 
   {Hue[0.5739300209934808], AbsoluteThickness[0.5], 
    LineBox[{{5.053056531371361, 0.2692896488285821}, {4.865348616907787, 
     0.25679101798061926`}}]}, 
   {Hue[0.5743861310174059], AbsoluteThickness[0.5], 
    LineBox[{{4.865348616907787, 0.25679101798061926`}, {4.599221093119048, 
     0.245549446364753}}]}, 
   {Hue[0.59871649936316], AbsoluteThickness[0.5], 
    LineBox[{{3.9628467720727776`, 1.1831204805494644`}, {3.9222965514212844`,
      1.211152888091279}}]}, 
   {Hue[0.5991428219107313], AbsoluteThickness[0.5], 
    LineBox[{{3.9222965514212844`, 1.211152888091279}, {3.6771100514131083`, 
     1.3794210096170156`}}]}, 
   {Hue[0.5868760317386678], AbsoluteThickness[0.5], 
    LineBox[{{4.817307280071607, -2.0755232938811505`}, {
     4.773473714822621, -2.1044134676725874`}}]}, 
   {Hue[0.5897123842581499], AbsoluteThickness[0.5], 
    LineBox[{{4.773473714822621, -2.1044134676725874`}, {
     4.625903985120743, -2.240599543018196}}]}, 
   {Hue[0.5781630760126348], AbsoluteThickness[0.5], 
    LineBox[{{2.8969485225635543`, 1.1125840558185158`}, {2.896481833481804, 
     1.1126932277039512`}}]}, 
   {Hue[0.5787720324614065], AbsoluteThickness[0.5], 
    LineBox[{{2.896481833481804, 1.1126932277039512`}, {2.5851711374459643`, 
     1.2046345641657668`}}]}, 
   {Hue[0.6481273638545637], AbsoluteThickness[0.5], 
    LineBox[{{5.044742242163473, -4.158180197656881}, {
     4.996713308560307, -4.341377799109789}}]}, 
   {Hue[0.6485637142066779], AbsoluteThickness[0.5], 
    LineBox[{{4.996713308560307, -4.341377799109789}, {
     4.918515517193298, -4.658215871261835}}]}, 
   {Hue[0.6835830442099732], AbsoluteThickness[0.5], 
    LineBox[{{2.911285923811317, 2.647505866953311}, {2.8743540606027613`, 
     2.695566366901865}}]}, 
   {Hue[0.6843208357536672], AbsoluteThickness[0.5], 
    LineBox[{{2.8743540606027613`, 2.695566366901865}, {2.6905007746802174`, 
     2.901795773814807}}]}, 
   {Hue[0.6304725418923391], AbsoluteThickness[0.5], 
    LineBox[{{3.275365450434138, 3.4300573945397765`}, {3.232509937396155, 
     3.6123396024631287`}}]}, 
   {Hue[0.6309048508298567], AbsoluteThickness[0.5], 
    LineBox[{{3.232509937396155, 3.6123396024631287`}, {3.1654947037103853`, 
     3.9126665373461273`}}]}, 
   {Hue[0.5591521210006324], AbsoluteThickness[0.5], 
    LineBox[{{7.219482146837619, 3.4280361110756083`}, {7.149653028436006, 
     3.6438485657309787`}}]}, 
   {Hue[0.6115981910723827], AbsoluteThickness[0.5], 
    LineBox[{{7.149653028436006, 3.6438485657309787`}, {7.1614249883340175`, 
     3.8009018388327367`}}]}, 
   {Hue[0.6371651530366338], AbsoluteThickness[0.5], 
    LineBox[{{8.265875601492539, -3.4503042976858587`}, {
     8.213310066124329, -3.627708259714595}}]}, 
   {Hue[0.6383873706449474], AbsoluteThickness[0.5], 
    LineBox[{{8.213310066124329, -3.627708259714595}, {
     8.16835009193181, -3.874592140068242}}]}, 
   {Hue[0.6798494156232341], AbsoluteThickness[0.5], 
    LineBox[{{4.348214114881094, 2.534197616189217}, {4.187075779637602, 
     2.5534436366897717`}}]}, 
   {Hue[0.6803967424098191], AbsoluteThickness[0.5], 
    LineBox[{{4.187075779637602, 2.5534436366897717`}, {3.866946863658657, 
     2.5763575351349295`}}]}, 
   {Hue[0.5516006983692032], AbsoluteThickness[0.5], 
    LineBox[{{4.778096133812215, 2.9288748090765435`}, {4.698846418971221, 
     3.0995960881003244`}}]}, 
   {Hue[0.5540580387001506], AbsoluteThickness[0.5], 
    LineBox[{{4.698846418971221, 3.0995960881003244`}, {4.635445318385971, 
     3.3188978160179565`}}]}, 
   {Hue[0.5622601734392664], AbsoluteThickness[0.5], 
    LineBox[{{6.038797820971663, -3.1694175103509883`}, {
     5.98400913961934, -3.3690844661930757`}}]}, 
   {Hue[0.5629431503296595], AbsoluteThickness[0.5], 
    LineBox[{{5.98400913961934, -3.3690844661930757`}, {
     5.9292929107256125`, -3.637771857766554}}]}, 
   {Hue[0.6000344800497813], AbsoluteThickness[0.5], 
    LineBox[{{5.199419394356257, -2.8919724588578934`}, {
     5.139517020824986, -2.9134192888657098`}}]}, 
   {Hue[0.6004652547169944], AbsoluteThickness[0.5], 
    LineBox[{{5.139517020824986, -2.9134192888657098`}, {
     4.846130400327585, -3.0217680788510046`}}]}, 
   {Hue[0.6366085980787691], AbsoluteThickness[0.5], 
    LineBox[{{6.811497785080155, -0.5279484339322117}, {
     6.71056288114093, -0.40016777299458656`}}]}, 
   {Hue[0.6375561497604425], AbsoluteThickness[0.5], 
    LineBox[{{6.71056288114093, -0.40016777299458656`}, {
     6.558370178128817, -0.16669830842571093`}}]}, 
   {Hue[0.6967189333566866], AbsoluteThickness[0.5], 
    LineBox[{{5.675654318604676, -1.8628443487521356`}, {
     5.637157490854342, -1.8626591304288487`}}]}, 
   {Hue[0.6975690560127686], AbsoluteThickness[0.5], 
    LineBox[{{5.637157490854342, -1.8626591304288487`}, {
     5.344838161654844, -1.885644287677807}}]}, 
   {Hue[0.6676125298952837], AbsoluteThickness[0.5], 
    LineBox[{{6.513951945054676, -2.623891189997678}, {
     6.394738887616425, -2.897999786939515}}]}, 
   {Hue[0.6704307334679405], AbsoluteThickness[0.5], 
    LineBox[{{6.394738887616425, -2.897999786939515}, {
     6.341312844873362, -3.108909405966274}}]}, 
   {Hue[0.675866330120255], AbsoluteThickness[0.5], 
    LineBox[{{3.8530268536614947`, -0.5799263551656945}, {
     3.6859733777498174`, -0.5719369933761519}}]}, 
   {Hue[0.6763249052469832], AbsoluteThickness[0.5], 
    LineBox[{{3.6859733777498174`, -0.5719369933761519}, {
     3.362750366602453, -0.5482970199050196}}]}, 
   {Hue[0.6672798588075798], AbsoluteThickness[0.5], 
    LineBox[{{7.490911951299366, -0.1903667540336224}, {
     7.392786905028037, -0.2593423731702266}}]}, 
   {Hue[0.667884970461828], AbsoluteThickness[0.5], 
    LineBox[{{7.392786905028037, -0.2593423731702266}, {
     7.153341832467244, -0.4080893934259795}}]}, 
   {Hue[0.6616008913818833], AbsoluteThickness[0.5], 
    LineBox[{{6.847530923384571, 2.561917581596624}, {6.6020247463158155`, 
     2.4142453721332653`}}]}, 
   {Hue[0.6690890102071204], AbsoluteThickness[0.5], 
    LineBox[{{6.6020247463158155`, 2.4142453721332653`}, {6.414939325543486, 
     2.353959752925625}}]}, 
   {Hue[0.27544572600740397`], AbsoluteThickness[0.5], 
    LineBox[{{7.050199592235489, 3.104150986860193}, {6.9908622039948325`, 
     3.3542293734681152`}}]}, 
   {Hue[0.27587494015179803`], AbsoluteThickness[0.5], 
    LineBox[{{6.9908622039948325`, 3.3542293734681152`}, {6.926381430156632, 
     3.6163090736854038`}}]}, 
   {Hue[0.6577314779709635], AbsoluteThickness[0.5], 
    LineBox[{{7.64713429871928, 2.951169678595261}, {7.847593604921558, 
     2.9938309795105}}]}, 
   {Hue[0.6581622695787162], AbsoluteThickness[0.5], 
    LineBox[{{7.847593604921558, 2.9938309795105}, {8.147689191245997, 
     3.0608320707099805`}}]}, 
   {Hue[0.6598856680825731], AbsoluteThickness[0.5], 
    LineBox[{{6.358310786409703, 1.9858111698644374`}, {5.811067985970641, 
     1.6500795702649191`}}]}, 
   {Hue[0.6670329278117177], AbsoluteThickness[0.5], 
    LineBox[{{5.811067985970641, 1.6500795702649191`}, {5.674843955248316, 
     1.6043458059306115`}}]}, 
   {Hue[0.44646605364486863`], AbsoluteThickness[0.5], 
    LineBox[{{5.600193810950904, 1.6713481522794116`}, {4.870379569205521, 
     2.3354023260983987`}}]}, 
   {Hue[0.45712243782012224`], AbsoluteThickness[0.5], 
    LineBox[{{4.870379569205521, 2.3354023260983987`}, {4.713698731334323, 
     2.417362111296979}}]}, 
   {Hue[0.6906484418936393], AbsoluteThickness[0.5], 
    LineBox[{{4.713698731334323, 2.417362111296979}, {4.579098741219622, 
     2.3026924378565243`}}]}, 
   {Hue[0.6064936005474536], AbsoluteThickness[0.5], 
    LineBox[{{6.427732098816598, -0.6599216620373501}, {
     6.379129350851876, -0.9042013428614218}}]}, 
   {Hue[0.6163725245779447], AbsoluteThickness[0.5], 
    LineBox[{{6.379129350851876, -0.9042013428614218}, {
     6.388721068733993, -1.0813044266053828`}}]}, 
   {Hue[0.5840326482537684], AbsoluteThickness[0.5], 
    LineBox[{{2.87148781689881, 2.604209988660282}, {2.8305137871420305`, 
     2.633323181530109}}]}, 
   {Hue[0.5845054556881089], AbsoluteThickness[0.5], 
    LineBox[{{2.8305137871420305`, 2.633323181530109}, {2.5882082491968275`, 
     2.8166976089816007`}}]}, 
   {Hue[0.355958913854116], AbsoluteThickness[0.5], 
    LineBox[{{5.8862403000199155`, 3.1624074667428963`}, {5.8864939324342425`,
      3.180877439805875}}]}, 
   {Hue[0.3571126314195055], AbsoluteThickness[0.5], 
    LineBox[{{5.8864939324342425`, 3.180877439805875}, {5.867161567005154, 
     3.3941647574617706`}}]}, 
   {Hue[0.6103591638968523], AbsoluteThickness[0.5], 
    LineBox[{{8.225989972898832, 2.399566584878138}, {8.247663190620434, 
     2.566939100819839}}]}, 
   {Hue[0.6108100872452406], AbsoluteThickness[0.5], 
    LineBox[{{8.247663190620434, 2.566939100819839}, {8.285866812309248, 
     2.9238281108744575`}}]}, 
   {Hue[0.431061714259886], AbsoluteThickness[0.5], 
    LineBox[{{3.111134626534969, -0.3279934650924246}, {
     3.089434746624759, -0.33154992025401453`}}]}, 
   {Hue[0.43253930792314516`], AbsoluteThickness[0.5], 
    LineBox[{{3.089434746624759, -0.33154992025401453`}, {
     2.85710114453368, -0.3990468533382532}}]}, 
   {Hue[0.5824765720788403], AbsoluteThickness[0.5], 
    LineBox[{{6.809966807521882, -3.913259320639062}, {
     6.838256870670999, -4.007917035024732}}]}, 
   {Hue[0.598988830876769], AbsoluteThickness[0.5], 
    LineBox[{{6.838256870670999, -4.007917035024732}, {
     6.9293809215545785`, -4.146612234815339}}]}, 
   {Hue[0.5045338974757825], AbsoluteThickness[0.5], 
    LineBox[{{2.900821168908437, -2.0547978620815046`}, {
     2.796642905916285, -2.0775108547327807`}}]}, 
   {Hue[0.5068920272618558], AbsoluteThickness[0.5], 
    LineBox[{{2.796642905916285, -2.0775108547327807`}, {
     2.6055910368859605`, -2.089787655441193}}]}, 
   {Hue[0.5731775917347014], AbsoluteThickness[0.5], 
    LineBox[{{3.6704956400698032`, 2.345299403652872}, {3.578286771747183, 
     2.3836387745797154`}}]}, 
   {Hue[0.5737836837383389], AbsoluteThickness[0.5], 
    LineBox[{{3.578286771747183, 2.3836387745797154`}, {3.314234994465451, 
     2.5115178616594105`}}]}, 
   {Hue[0.6287026404098328], AbsoluteThickness[0.5], 
    LineBox[{{4.42061524560626, -4.268002310840936}, {
     4.422109882791029, -4.357876612544315}}]}, 
   {Hue[0.6291680131880055], AbsoluteThickness[0.5], 
    LineBox[{{4.422109882791029, -4.357876612544315}, {
     4.437770221668245, -4.711282191217022}}]}, 
   {Hue[0.36171277461036677`], AbsoluteThickness[0.5], 
    LineBox[{{4.257603503519386, -4.363304573652053}, {
     4.15443126141947, -4.396184845586194}}]}, 
   {Hue[0.3622661732390148], AbsoluteThickness[0.5], 
    LineBox[{{4.15443126141947, -4.396184845586194}, {
     3.870473323532715, -4.502107084479699}}]}, 
   {Hue[0.6418892179529826], AbsoluteThickness[0.5], 
    LineBox[{{4.11942388907462, -4.23461213600705}, {
     4.037834962385692, -4.115457523420974}}]}, 
   {Hue[0.6428172448903179], AbsoluteThickness[0.5], 
    LineBox[{{4.037834962385692, -4.115457523420974}, {
     3.9279029709237454`, -3.919375029109192}}]}, 
   {Hue[0.694176122019843], AbsoluteThickness[0.5], 
    LineBox[{{2.8265269054589583`, -0.991431239231634}, {
     2.7617807991763574`, -0.9127907412952326}}]}, 
   {Hue[0.6959798945500184], AbsoluteThickness[0.5], 
    LineBox[{{2.7617807991763574`, -0.9127907412952326}, {
     2.6482715407445836`, -0.7299739379928217}}]}, 
   {Hue[0.5616935533672013], AbsoluteThickness[0.5], 
    LineBox[{{4.761226025805638, 3.4032479925117745`}, {4.691450885566592, 
     3.5702251489438948`}}]}, 
   {Hue[0.5630624674766327], AbsoluteThickness[0.5], 
    LineBox[{{4.075890544682921, 2.2751437449874863`}, {4.021865883251751, 
     2.341074572985361}}]}, 
   {Hue[0.5641053391714584], AbsoluteThickness[0.5], 
    LineBox[{{4.021865883251751, 2.341074572985361}, {3.866066447875262, 
     2.5742279739834126`}}]}, 
   {Hue[0.5577244181765293], AbsoluteThickness[0.5], 
    LineBox[{{4.629650704966972, -2.216658134139652}, {
     4.472042925750941, -2.373968523351091}}]}, 
   {Hue[0.5600899138755295], AbsoluteThickness[0.5], 
    LineBox[{{4.472042925750941, -2.373968523351091}, {
     4.346544683921633, -2.544065780281749}}]}, 
   {Hue[0.5826124511372607], AbsoluteThickness[0.5], 
    LineBox[{{4.6335404542532554`, 0.8289646191719509}, {4.529776831593772, 
     0.8335810328943158}}]}, 
   {Hue[0.6278641764826942], AbsoluteThickness[0.5], 
    LineBox[{{4.529776831593772, 0.8335810328943158}, {4.369257599604803, 
     0.9052290655568795}}]}, 
   {Hue[0.5536915866172064], AbsoluteThickness[0.5], 
    LineBox[{{6.482621590976752, -1.6547036927676912`}, {
     6.3238443262742825`, -1.8245311738485857`}}]}, 
   {Hue[0.5578707276283659], AbsoluteThickness[0.5], 
    LineBox[{{6.3238443262742825`, -1.8245311738485857`}, {
     6.199155877671204, -1.9155365655164078`}}]}, 
   {Hue[0.22698267394117597`], AbsoluteThickness[0.5], 
    LineBox[{{7.947998734759508, -2.6162229324364703`}, {
     7.8626080260593865`, -2.9201016700632216`}}]}, 
   {Hue[0.23382963236603918`], AbsoluteThickness[0.5], 
    LineBox[{{7.8626080260593865`, -2.9201016700632216`}, {
     7.852208431272864, -3.125135169400311}}]}, 
   {Hue[0.5103057633986456], AbsoluteThickness[0.5], 
    LineBox[{{7.852208431272864, -3.125135169400311}, {
     8.045015079767252, -3.1956510095959563`}}]}, 
   {Hue[0.6639202813862505], AbsoluteThickness[0.5], 
    LineBox[{{7.411996550938982, -1.8339336670243103`}, {
     7.3836138271711995`, -1.8282829096845268`}}]}, 
   {Hue[0.6643465630794436], AbsoluteThickness[0.5], 
    LineBox[{{7.3836138271711995`, -1.8282829096845268`}, {
     7.097204366780842, -1.7702837773598346`}}]}, 
   {Hue[0.5837963312096904], AbsoluteThickness[0.5], 
    LineBox[{{6.546533951632397, -0.26608623200507564`}, {
     6.368291958948914, -0.21159725619187914`}}]}, 
   {Hue[0.584894415579394], AbsoluteThickness[0.5], 
    LineBox[{{6.368291958948914, -0.21159725619187914`}, {
     6.101158777415393, -0.15860301589132159`}}]}, 
   {Hue[0.4022863001388238], AbsoluteThickness[0.5], 
    LineBox[{{6.909934196985228, -2.1181048832976273`}, {
     6.909824696948593, -2.118442444112495}}]}, 
   {Hue[0.40304550988435944`], AbsoluteThickness[0.5], 
    LineBox[{{6.909824696948593, -2.118442444112495}, {
     6.809528011819617, -2.363328325603887}}]}, 
   {Hue[0.5417775071956039], AbsoluteThickness[0.5], 
    LineBox[{{6.94159779007513, 1.6524398150218027`}, {6.746879151504067, 
     2.1112094549341665`}}]}, 
   {Hue[0.5431287432462759], AbsoluteThickness[0.5], 
    LineBox[{{6.746879151504067, 2.1112094549341665`}, {6.690690906036114, 
     2.3016471809204977`}}]}, 
   {Hue[0.6856938991084266], AbsoluteThickness[0.5], 
    LineBox[{{8.1150273317068, 1.185091355684414}, {8.099854926246167, 
     1.3904162998685694`}}]}, 
   {Hue[0.6880081209105695], AbsoluteThickness[0.5], 
    LineBox[{{8.099854926246167, 1.3904162998685694`}, {8.056907924911837, 
     1.5797745390945321`}}]}, 
   {Hue[0.5773404520232719], AbsoluteThickness[0.5], 
    LineBox[{{5.628008791365957, 1.1195306515478172`}, {5.587514487411758, 
     1.1319951956116883`}}]}, 
   {Hue[0.6076765554026591], AbsoluteThickness[0.5], 
    LineBox[{{5.587514487411758, 1.1319951956116883`}, {5.418592908749717, 
     1.1247570083385896`}}]}, 
   {Hue[0.6239990575381645], AbsoluteThickness[0.5], 
    LineBox[{{4.120994459372017, -0.8079279384398885}, {
     3.88682684700114, -0.8479264135215137}}]}, 
   {Hue[0.6275905252612678], AbsoluteThickness[0.5], 
    LineBox[{{3.88682684700114, -0.8479264135215137}, {
     3.686106284137202, -0.8461040061521784}}]}, 
   {Hue[0.5503691843952745], AbsoluteThickness[0.5], 
    LineBox[{{5.010945845477219, 2.672238208985169}, {4.966519046889373, 
     2.8326324623662584`}}]}, 
   {Hue[0.5509416151128387], AbsoluteThickness[0.5], 
    LineBox[{{4.966519046889373, 2.8326324623662584`}, {4.900830592772577, 
     3.1285533780371346`}}]}, 
   {Hue[0.5841352151194424], AbsoluteThickness[0.5], 
    LineBox[{{4.186730649351903, -2.844858290445353}, {
     4.0813656096103745`, -2.9112013109932473`}}]}, 
   {Hue[0.5851071746830426], AbsoluteThickness[0.5], 
    LineBox[{{4.0813656096103745`, -2.9112013109932473`}, {
     3.898202302843766, -3.0517609693935466`}}]}, 
   {Hue[0.5208467825273834], AbsoluteThickness[0.5], 
    LineBox[{{4.890286668989602, -4.0838502241117896`}, {
     4.894024640042707, -4.360688539975778}}]}, 
   {Hue[0.5215119616584616], AbsoluteThickness[0.5], 
    LineBox[{{4.894024640042707, -4.360688539975778}, {
     4.917334173681919, -4.657785243917121}}]}, 
   {Hue[0.5633755504179669], AbsoluteThickness[0.5], 
    LineBox[{{2.6303424241088087`, -2.875882312110963}, {
     2.6063856514779515`, -2.905696307289349}}]}, 
   {Hue[0.5640322352527182], AbsoluteThickness[0.5], 
    LineBox[{{2.6063856514779515`, -2.905696307289349}, {
     2.420338479167671, -3.109187551476117}}]}, 
   {Hue[0.6494722699267093], AbsoluteThickness[0.5], 
    LineBox[{{6.701380426182704, -2.9228339198541726`}, {
     6.6357012254020455`, -2.998448038423049}}]}, 
   {Hue[0.6503866532111705], AbsoluteThickness[0.5], 
    LineBox[{{6.6357012254020455`, -2.998448038423049}, {
     6.441247720715189, -3.18594811307588}}]}, 
   {Hue[0.6492604739861897], AbsoluteThickness[0.5], 
    LineBox[{{8.252741644672328, -2.972969219712039}, {
     8.16922858389145, -3.022668140834675}}]}, 
   {Hue[0.6499254553321716], AbsoluteThickness[0.5], 
    LineBox[{{8.16922858389145, -3.022668140834675}, {
     7.889401824116802, -3.1655293703782172`}}]}, 
   {Hue[0.6717936312190824], AbsoluteThickness[0.5], 
    LineBox[{{7.865015635528626, -1.6189623212629007`}, {
     7.857268156270659, -1.6560821594834216`}}]}, 
   {Hue[0.6722570364437311], AbsoluteThickness[0.5], 
    LineBox[{{7.857268156270659, -1.6560821594834216`}, {
     7.791673742885342, -1.9328155172634356`}}]}, 
   {Hue[0.6242101936171107], AbsoluteThickness[0.5], 
    LineBox[{{7.544793856834848, -1.1376117829390588`}, {
     7.62300449785886, -1.2851066998715919`}}]}, 
   {Hue[0.6450257340777137], AbsoluteThickness[0.5], 
    LineBox[{{7.62300449785886, -1.2851066998715919`}, {
     7.748281112518247, -1.407412426677133}}]}, 
   {Hue[0.4096137834408287], AbsoluteThickness[0.5], 
    LineBox[{{5.447640698324035, 3.6958994310932796`}, {5.4046315797002435`, 
     3.729507725351194}}]}, 
   {Hue[0.4102591029986101], AbsoluteThickness[0.5], 
    LineBox[{{5.4046315797002435`, 3.729507725351194}, {5.141022204835036, 
     3.910238840310721}}]}, 
   {Hue[0.5550037190015732], AbsoluteThickness[0.5], 
    LineBox[{{5.904773752012882, 2.40436246201966}, {5.684466373695906, 
     2.5145805992210715`}}]}, 
   {Hue[0.5556690185268953], AbsoluteThickness[0.5], 
    LineBox[{{5.684466373695906, 2.5145805992210715`}, {5.400314800517776, 
     2.634406970291726}}]}, 
   {Hue[0.5896968293712639], AbsoluteThickness[0.5], 
    LineBox[{{6.130380974655817, 2.242835944917377}, {5.823682721542342, 
     2.212000071207684}}]}, 
   {Hue[0.5901247397351407], AbsoluteThickness[0.5], 
    LineBox[{{5.823682721542342, 2.212000071207684}, {5.588813482890147, 
     2.1899380505810755`}}]}, 
   {Hue[0.6043170088471818], AbsoluteThickness[0.5], 
    LineBox[{{7.0798532049662235`, 2.173555070450576}, {7.0305691516921724`, 
     2.159086291592156}}]}, 
   {Hue[0.605705975405167], AbsoluteThickness[0.5], 
    LineBox[{{7.0305691516921724`, 2.159086291592156}, {6.8488183324584675`, 
     2.0818504549234156`}}]}, 
   {Hue[0.6416035849819623], AbsoluteThickness[0.5], 
    LineBox[{{8.154403263725087, 2.495338784595102}, {8.183857257086869, 
     2.3974448679053655`}}]}, 
   {Hue[0.6420372296183564], AbsoluteThickness[0.5], 
    LineBox[{{8.183857257086869, 2.3974448679053655`}, {8.267153541184173, 
     2.1075513548491003`}}]}, 
   {Hue[0.6607745672730286], AbsoluteThickness[0.5], 
    LineBox[{{8.104887900407892, 2.355578124357415}, {8.100869524001356, 
     2.3510970512833125`}}]}, 
   {Hue[0.5561243668111324], AbsoluteThickness[0.5], 
    LineBox[{{7.844195077655641, 3.00734810157187}, {7.382322851649286, 
     3.2755651962498034`}}]}, 
   {Hue[0.5570081792071278], AbsoluteThickness[0.5], 
    LineBox[{{7.382322851649286, 3.2755651962498034`}, {7.118783665925361, 
     3.3996644783457275`}}]}, 
   {Hue[0.6062681692059877], AbsoluteThickness[0.5], 
    LineBox[{{7.389501592758315, 1.9009378317368384`}, {7.316087349068392, 
     1.8616951129278694`}}]}, 
   {Hue[0.6070664682802619], AbsoluteThickness[0.5], 
    LineBox[{{7.316087349068392, 1.8616951129278694`}, {7.074407802002502, 
     1.7069067412362675`}}]}, 
   {Hue[0.6112478386179312], AbsoluteThickness[0.5], 
    LineBox[{{6.928032609155934, 0.8630970452538537}, {6.907861509472061, 
     0.8498635620373594}}]}, 
   {Hue[0.6116783218052065], AbsoluteThickness[0.5], 
    LineBox[{{6.907861509472061, 0.8498635620373594}, {6.6172753919074285`, 
     0.6551777919117211}}]}, 
   {Hue[0.6087345627144498], AbsoluteThickness[0.5], 
    LineBox[{{5.446407101204477, -0.02313121211159941}, {
     5.386012577036358, -0.05535339291948693}}]}, 
   {Hue[0.609344009872787], AbsoluteThickness[0.5], 
    LineBox[{{5.386012577036358, -0.05535339291948693}, {
     5.101848676588302, -0.2286215604516462}}]}, 
   {Hue[0.6634781889237311], AbsoluteThickness[0.5], 
    LineBox[{{3.868400325203023, 1.479592295625569}, {3.600190776371424, 
     1.4611476810033754`}}]}, 
   {Hue[0.6639710429648674], AbsoluteThickness[0.5], 
    LineBox[{{3.600190776371424, 1.4611476810033754`}, {3.328806002872901, 
     1.4522049659072374`}}]}, 
   {Hue[0.5169033643576494], AbsoluteThickness[0.5], 
    LineBox[{{4.869705720764164, 3.10238488154577}, {4.866537937185489, 
     3.1045766078487897`}}]}, 
   {Hue[0.51746580238701], AbsoluteThickness[0.5], 
    LineBox[{{4.866537937185489, 3.1045766078487897`}, {4.623650941674435, 
     3.291280121189655}}]}, 
   {Hue[0.6264751144412085], AbsoluteThickness[0.5], 
    LineBox[{{5.067868118194362, -2.760450478811867}, {
     5.067223199653058, -2.8381060403914407`}}]}, 
   {Hue[0.6270966458537589], AbsoluteThickness[0.5], 
    LineBox[{{5.067223199653058, -2.8381060403914407`}, {
     5.047749079484228, -3.1263818769018625`}}]}, 
   {Hue[0.5877869982274007], AbsoluteThickness[0.5], 
    LineBox[{{3.4159639877479133`, -2.0762419631981595`}, {
     3.392519691707921, -2.097721814611869}}]}, 
   {Hue[0.588213056117158], AbsoluteThickness[0.5], 
    LineBox[{{3.392519691707921, -2.097721814611869}, {
     3.171857218701396, -2.3009195014084822`}}]}, 
   {Hue[0.6730706394476306], AbsoluteThickness[0.5], 
    LineBox[{{2.9081181198589725`, 3.1216031644612454`}, {2.906336261490413, 
     3.1233328095278705`}}]}, 
   {Hue[0.6735540429879168], AbsoluteThickness[0.5], 
    LineBox[{{2.906336261490413, 3.1233328095278705`}, {2.6756761067420034`, 
     3.3328220750058217`}}]}, 
   {Hue[0.6916391969220705], AbsoluteThickness[0.5], 
    LineBox[{{4.155834208809857, 3.4401408381186647`}, {4.1318271060581715`, 
     3.4890309764139475`}}]}, 
   {Hue[0.692793105819806], AbsoluteThickness[0.5], 
    LineBox[{{4.1318271060581715`, 3.4890309764139475`}, {4.004646344868565, 
     3.691621434697718}}]}, 
   {Hue[0.6971945126694995], AbsoluteThickness[0.5], 
    LineBox[{{5.025766994392219, -4.160269302588668}, {
     5.019830773865461, -4.346313009413646}}]}, 
   {Hue[0.6976703613881892], AbsoluteThickness[0.5], 
    LineBox[{{5.019830773865461, -4.346313009413646}, {
     4.999700178590435, -4.6659146505953055`}}]}, 
   {Hue[0.5981869601202006], AbsoluteThickness[0.5], 
    LineBox[{{2.4512462266413277`, 3.1398327406820012`}, {2.4114575856402376`,
      3.165318883011262}}]}, 
   {Hue[0.5986234001163602], AbsoluteThickness[0.5], 
    LineBox[{{2.4114575856402376`, 3.165318883011262}, {2.1431650454299063`, 
     3.3317383017636777`}}]}, 
   {Hue[0.6118747352610793], AbsoluteThickness[0.5], 
    LineBox[{{7.582688526243872, -1.1325168684922842`}, {
     7.6406424868324345`, -1.1590391815487735`}}]}, 
   {Hue[0.6123077788738713], AbsoluteThickness[0.5], 
    LineBox[{{7.6406424868324345`, -1.1590391815487735`}, {
     7.9434173961103625`, -1.3020150499462226`}}]}, 
   {Hue[0.6274557476933268], AbsoluteThickness[0.5], 
    LineBox[{{4.408554572928095, 3.5975106450604746`}, {4.3527769629400455`, 
     3.6396105169887343`}}]}, 
   {Hue[0.6278835285477423], AbsoluteThickness[0.5], 
    LineBox[{{4.3527769629400455`, 3.6396105169887343`}, {4.1163644726217425`,
      3.815705422576748}}]}, 
   {Hue[0.6363186271638845], AbsoluteThickness[0.5], 
    LineBox[{{7.844973517905891, 2.6963573478968876`}, {8.109164983015683, 
     2.620550485097312}}]}, 
   {Hue[0.6404051840910024], AbsoluteThickness[0.5], 
    LineBox[{{8.109164983015683, 2.620550485097312}, {8.341711659980321, 
     2.5989936553164505`}}]}, 
   {Hue[0.6479143981221134], AbsoluteThickness[0.5], 
    LineBox[{{7.104948006276149, -0.050821662963608516`}, {
     7.118734200754745, -0.19737095465892324`}}]}, 
   {Hue[0.6496848887877211], AbsoluteThickness[0.5], 
    LineBox[{{7.118734200754745, -0.19737095465892324`}, {
     7.16949024947014, -0.4183667883837526}}]}, 
   {Hue[0.6498286219590191], AbsoluteThickness[0.5], 
    LineBox[{{2.8489492290488845`, 3.533569775408288}, {2.7579130090589894`, 
     3.5918099617887544`}}]}, 
   {Hue[0.6511914115515313], AbsoluteThickness[0.5], 
    LineBox[{{2.7579130090589894`, 3.5918099617887544`}, {2.542712226420876, 
     3.767325132042177}}]}, 
   {Hue[0.6768515740103237], AbsoluteThickness[0.5], 
    LineBox[{{2.317668506302129, -1.9349528906515239`}, {
     2.1919671417331204`, -1.9879566782392613`}}]}, 
   {Hue[0.6777232796984209], AbsoluteThickness[0.5], 
    LineBox[{{2.1919671417331204`, -1.9879566782392613`}, {
     1.9141226635352826`, -2.078180612399867}}]}, 
   {Hue[0.6127631320772138], AbsoluteThickness[0.5], 
    LineBox[{{6.0960400150533145`, 1.3804910351795916`}, {6.0956949816867185`,
      1.3844034156245275`}}]}, 
   {Hue[0.6133445525543638], AbsoluteThickness[0.5], 
    LineBox[{{6.0956949816867185`, 1.3844034156245275`}, {6.054449334116864, 
     1.6745966638859084`}}]}, 
   {Hue[0.6735748391751555], AbsoluteThickness[0.5], 
    LineBox[{{4.5883124840740335`, 0.7264277874548725}, {4.510492722088808, 
     0.8327665266739996}}]}, 
   {Hue[0.6744898568789435], AbsoluteThickness[0.5], 
    LineBox[{{4.510492722088808, 0.8327665266739996}, {4.354060626691401, 
     1.0917879266675314`}}]}, 
   {Hue[0.6770984284332073], AbsoluteThickness[0.5], 
    LineBox[{{6.143015728985267, -1.1477198518691811`}, {
     5.888502728785751, -1.2961648664883287`}}]}, 
   {Hue[0.6838664672710241], AbsoluteThickness[0.5], 
    LineBox[{{5.888502728785751, -1.2961648664883287`}, {
     5.707960488084197, -1.3531215603239766`}}]}, 
   {Hue[0.6789868581127921], AbsoluteThickness[0.5], 
    LineBox[{{7.0937162565677365`, -0.3146867318148557}, {
     7.0398303157368955`, -0.30852569692057286`}}]}, 
   {Hue[0.6861108749101329], AbsoluteThickness[0.5], 
    LineBox[{{7.0398303157368955`, -0.30852569692057286`}, {
     6.846232734149933, -0.3303595863593283}}]}, 
   {Hue[0.6689428987798768], AbsoluteThickness[0.5], 
    LineBox[{{6.383586783581768, 0.6287112059635681}, {6.253818836855383, 
     0.855254129202131}}]}, 
   {Hue[0.6757025845113066], AbsoluteThickness[0.5], 
    LineBox[{{4.922056451717865, -1.0978764544743551`}, {
     4.798321198002303, -1.0828124384287998`}}]}, 
   {Hue[0.680473401720891], AbsoluteThickness[0.5], 
    LineBox[{{4.798321198002303, -1.0828124384287998`}, {
     4.602480380999232, -1.0978217022176406`}}]}, 
   {Hue[0.5963447242213287], AbsoluteThickness[0.5], 
    LineBox[{{5.645950130047048, -2.90237123912204}, {
     5.640657659326004, -2.9043803565561137`}}]}, 
   {Hue[0.5969159831986569], AbsoluteThickness[0.5], 
    LineBox[{{5.640657659326004, -2.9043803565561137`}, {
     5.39730538962839, -3.011422304384213}}]}, 
   {Hue[0.6741372566705898], AbsoluteThickness[0.5], 
    LineBox[{{2.6447463609147697`, -0.7952798311964091}, {
     2.354164240167561, -0.7951578773040511}}]}, 
   {Hue[0.6749834744889897], AbsoluteThickness[0.5], 
    LineBox[{{2.354164240167561, -0.7951578773040511}, {
     2.069419752768739, -0.7713630141231064}}]}, 
   {Hue[0.6747576404913357], AbsoluteThickness[0.5], 
    LineBox[{{4.989567072597458, 2.0860391559845612`}, {4.94299426369777, 
     2.4506284899955237`}}]}, 
   {Hue[0.67784457219857], AbsoluteThickness[0.5], 
    LineBox[{{4.94299426369777, 2.4506284899955237`}, {4.9506413959460325`, 
     2.6365725409437655`}}]}, 
   {Hue[0.566086989837708], AbsoluteThickness[0.5], 
    LineBox[{{3.87473073868987, 1.448659958107534}, {3.592781475520635, 
     1.545320820711325}}]}, 
   {Hue[0.5672225883327414], AbsoluteThickness[0.5], 
    LineBox[{{3.592781475520635, 1.545320820711325}, {3.370669597879347, 
     1.5966708469483937`}}]}, 
   {Hue[0.6954677268363018], AbsoluteThickness[0.5], 
    LineBox[{{6.332676434423579, -2.6607058165568227`}, {
     6.436164658371095, -2.587680187349714}}]}, 
   {Hue[0.695971882478594], AbsoluteThickness[0.5], 
    LineBox[{{6.436164658371095, -2.587680187349714}, {
     6.712373735724104, -2.408289745128004}}]}, 
   {Hue[0.63020315037508], AbsoluteThickness[0.5], 
    LineBox[{{8.283800130237383, 0.928040468853838}, {8.425569088148817, 
     1.1599804150190463`}}]}, 
   {Hue[0.6579698848109506], AbsoluteThickness[0.5], 
    LineBox[{{8.425569088148817, 1.1599804150190463`}, {8.46406358679981, 
     1.3365175692132867`}}]}, 
   {Hue[0.5598505440856775], AbsoluteThickness[0.5], 
    LineBox[{{7.639694343258777, -3.526215243966392}, {
     7.698276443557571, -3.5586467620171276`}}]}, 
   {Hue[0.5612694989826342], AbsoluteThickness[0.5], 
    LineBox[{{7.698276443557571, -3.5586467620171276`}, {
     7.8899432712459285`, -3.6964282896020006`}}]}, 
   {Hue[0.6646278983593878], AbsoluteThickness[0.5], 
    LineBox[{{6.435326701516632, -2.167577987088304}, {
     6.447919875277595, -2.118815493506755}}]}, 
   {Hue[0.6650548496235459], AbsoluteThickness[0.5], 
    LineBox[{{6.447919875277595, -2.118815493506755}, {
     6.526366235678133, -1.808800098791853}}]}, 
   {Hue[0.632974852671958], AbsoluteThickness[0.5], 
    LineBox[{{7.124178761335555, -4.090481948885803}, {
     7.126304540643609, -4.095104134313245}}]}, 
   {Hue[0.6334348519096058], AbsoluteThickness[0.5], 
    LineBox[{{7.126304540643609, -4.095104134313245}, {
     7.261437885400475, -4.370052800262218}}]}, 
   {Hue[0.6802879481967335], AbsoluteThickness[0.5], 
    LineBox[{{4.584860866866911, 2.5906355797733256`}, {4.538105937913072, 
     2.8384255689781885`}}]}, 
   {Hue[0.6807242476958467], AbsoluteThickness[0.5], 
    LineBox[{{4.538105937913072, 2.8384255689781885`}, {4.484261555427588, 
     3.1481958381996322`}}]}, 
   {Hue[0.5407147881485379], AbsoluteThickness[0.5], 
    LineBox[{{7.1179331010595845`, -4.099294926275692}, {
     7.120188106981396, -4.09990219361551}}]}, 
   {Hue[0.5415733539680991], AbsoluteThickness[0.5], 
    LineBox[{{7.120188106981396, -4.09990219361551}, {
     7.372464814451507, -4.191144720026113}}]}, 
   {Hue[0.6173972687388392], AbsoluteThickness[0.5], 
    LineBox[{{6.35913336615644, -3.6903697292568918`}, {
     6.563870362660927, -3.7933302691616144`}}]}, 
   {Hue[0.6183833036125664], AbsoluteThickness[0.5], 
    LineBox[{{6.563870362660927, -3.7933302691616144`}, {
     6.834080188492347, -3.8988714446203776`}}]}, 
   {Hue[0.655703543090028], AbsoluteThickness[0.5], 
    LineBox[{{7.097228434674572, -0.9922687171851868}, {
     7.444730462551885, -1.1033846206457267`}}]}, 
   {Hue[0.6648791978230955], AbsoluteThickness[0.5], 
    LineBox[{{7.444730462551885, -1.1033846206457267`}, {
     7.624287694495394, -1.1149948560706253`}}]}, 
   {Hue[0.6275747619832319], AbsoluteThickness[0.5], 
    LineBox[{{3.8697384423712133`, -3.8877774626920565`}, {
     3.7284617299680156`, -4.1419368051400856`}}]}, 
   {Hue[0.6293986354054212], AbsoluteThickness[0.5], 
    LineBox[{{3.7284617299680156`, -4.1419368051400856`}, {
     3.6416953989751586`, -4.36336709322511}}]}, 
   {Hue[0.6450094310038487], AbsoluteThickness[0.5], 
    LineBox[{{2.6056204162088434`, -2.6499281619610047`}, {
     2.4283050733183043`, -2.6984144538388657`}}]}, 
   {Hue[0.6454743046893642], AbsoluteThickness[0.5], 
    LineBox[{{2.4283050733183043`, -2.6984144538388657`}, {
     2.1138178255006665`, -2.7751872693517066`}}]}, 
   {Hue[0.6002484336653657], AbsoluteThickness[0.5], 
    LineBox[{{2.344982164585665, -0.9241198354907832}, {
     2.129319046021984, -0.9177656136879655}}]}, 
   {Hue[0.6010223244635837], AbsoluteThickness[0.5], 
    LineBox[{{2.129319046021984, -0.9177656136879655}, {
     1.7917771748607272`, -0.9336471814074092}}]}, 
   {Hue[0.5782332645977941], AbsoluteThickness[0.5], 
    LineBox[{{2.81715101341015, 1.5289110027312063`}, {2.4184268249061547`, 
     1.731677683014958}}]}, 
   {Hue[0.5786825472528324], AbsoluteThickness[0.5], 
    LineBox[{{2.4184268249061547`, 1.731677683014958}, {2.1769245681499423`, 
     1.8480519959757062`}}]}, 
   {Hue[0.5733939745169303], AbsoluteThickness[0.5], 
    LineBox[{{3.6192866942430797`, 0.28785285798352067`}, {
     3.4005419968776955`, 0.2714876111954489}}]}, 
   {Hue[0.5738203031313054], AbsoluteThickness[0.5], 
    LineBox[{{3.4005419968776955`, 0.2714876111954489}, {3.073008612662402, 
     0.24810912040500221`}}]}, 
   {Hue[0.5745736771526275], AbsoluteThickness[0.5], 
    LineBox[{{4.604877999663432, 0.22651434155274883`}, {4.4571493789872525`, 
     0.22620263801044213`}}]}, 
   {Hue[0.5750440958618708], AbsoluteThickness[0.5], 
    LineBox[{{4.4571493789872525`, 0.22620263801044213`}, {4.138500953100903, 
     0.23487580234613556`}}]}, 
   {Hue[0.5748422410413311], AbsoluteThickness[0.5], 
    LineBox[{{4.599221093119048, 0.245549446364753}, {4.460261614224388, 
     0.24305554896174336`}}]}, 
   {Hue[0.5752847402017457], AbsoluteThickness[0.5], 
    LineBox[{{4.460261614224388, 0.24305554896174336`}, {4.13721292182909, 
     0.24310576236783532`}}]}, 
   {Hue[0.5995691444583028], AbsoluteThickness[0.5], 
    LineBox[{{3.677110051413108, 1.3794210096170156`}, {3.592509272621638, 
     1.4370590846877944`}}]}, 
   {Hue[0.6000257798949401], AbsoluteThickness[0.5], 
    LineBox[{{3.592509272621638, 1.4370590846877944`}, {3.360614879070025, 
     1.586871675816136}}]}, 
   {Hue[0.5925487367776319], AbsoluteThickness[0.5], 
    LineBox[{{4.625903985120743, -2.240599543018196}, {
     4.521221050154713, -2.3746691298622054`}}]}, 
   {Hue[0.5931984783480465], AbsoluteThickness[0.5], 
    LineBox[{{4.521221050154713, -2.3746691298622054`}, {
     4.366964248422053, -2.6001202531007293`}}]}, 
   {Hue[0.5793809889101782], AbsoluteThickness[0.5], 
    LineBox[{{2.5851711374459643`, 1.2046345641657668`}, {2.405831106039961, 
     1.2689931353259194`}}]}, 
   {Hue[0.5802657134926221], AbsoluteThickness[0.5], 
    LineBox[{{2.405831106039961, 1.2689931353259194`}, {2.1313622455690426`, 
     1.3415524409376163`}}]}, 
   {Hue[0.685058627297361], AbsoluteThickness[0.5], 
    LineBox[{{2.6905007746802174`, 2.901795773814807}, {2.618563076349603, 
     2.9715237620215134`}}]}, 
   {Hue[0.6861423106870432], AbsoluteThickness[0.5], 
    LineBox[{{2.618563076349603, 2.9715237620215134`}, {2.4142848338071903`, 
     3.133311342994274}}]}, 
   {Hue[0.6396095882532609], AbsoluteThickness[0.5], 
    LineBox[{{8.16835009193181, -3.874592140068242}, {
     8.168262304836764, -3.8758057650453637`}}]}, 
   {Hue[0.641612671176966], AbsoluteThickness[0.5], 
    LineBox[{{8.168262304836764, -3.8758057650453637`}, {
     8.120240370898566, -4.098779934781666}}]}, 
   {Hue[0.6809440691964042], AbsoluteThickness[0.5], 
    LineBox[{{3.866946863658657, 2.5763575351349295`}, {3.6081016070405347`, 
     2.58258026682565}}]}, 
   {Hue[0.681704215024903], AbsoluteThickness[0.5], 
    LineBox[{{3.6081016070405347`, 2.58258026682565}, {3.3288014129480503`, 
     2.568294347251686}}]}, 
   {Hue[0.5565153790310977], AbsoluteThickness[0.5], 
    LineBox[{{4.635445318385971, 3.3188978160179565`}, {4.62389722333971, 
     3.4084414079096237`}}]}, 
   {Hue[0.5571021609212505], AbsoluteThickness[0.5], 
    LineBox[{{4.62389722333971, 3.4084414079096237`}, {4.573171297086786, 
     3.683571698151923}}]}, 
   {Hue[0.5636261272200526], AbsoluteThickness[0.5], 
    LineBox[{{5.9292929107256125`, -3.637771857766554}, {
     5.901098181534076, -3.846946628793178}}]}, 
   {Hue[0.5644615520552745], AbsoluteThickness[0.5], 
    LineBox[{{5.901098181534076, -3.846946628793178}, {
     5.887060601616193, -4.116930277842006}}]}, 
   {Hue[0.6008960293842076], AbsoluteThickness[0.5], 
    LineBox[{{4.846130400327585, -3.0217680788510046`}, {
     4.348854980184475, -3.2110614759182896`}}]}, 
   {Hue[0.6013281946679855], AbsoluteThickness[0.5], 
    LineBox[{{4.348854980184475, -3.2110614759182896`}, {
     4.09151793901149, -3.305721155366677}}]}, 
   {Hue[0.6385037014421157], AbsoluteThickness[0.5], 
    LineBox[{{6.558370178128817, -0.16669830842571093`}, {
     6.534555855293202, -0.12170779014750822`}}]}, 
   {Hue[0.6389874343687486], AbsoluteThickness[0.5], 
    LineBox[{{6.534555855293202, -0.12170779014750822`}, {6.397707818292967, 
     0.15904679120468923`}}]}, 
   {Hue[0.6984191786688507], AbsoluteThickness[0.5], 
    LineBox[{{5.344838161654844, -1.885644287677807}, {
     5.090790237109794, -1.9270984165232437`}}]}, 
   {Hue[0.69891935985336], AbsoluteThickness[0.5], 
    LineBox[{{5.090790237109794, -1.9270984165232437`}, {
     4.796135985353077, -1.986612176572475}}]}, 
   {Hue[0.673248937040597], AbsoluteThickness[0.5], 
    LineBox[{{6.341312844873362, -3.108909405966274}, {
     6.33960813577383, -3.1286938618186504`}}]}, 
   {Hue[0.6739211433899297], AbsoluteThickness[0.5], 
    LineBox[{{6.33960813577383, -3.1286938618186504`}, {
     6.297766935201437, -3.4025827257331995`}}]}, 
   {Hue[0.6767834803737113], AbsoluteThickness[0.5], 
    LineBox[{{3.362750366602453, -0.5482970199050196}, {
     3.1433509490368667`, -0.5266763157916133}}]}, 
   {Hue[0.6773030934171862], AbsoluteThickness[0.5], 
    LineBox[{{3.1433509490368667`, -0.5266763157916133}, {
     2.8461561655048797`, -0.4847398102769068}}]}, 
   {Hue[0.6684900821160763], AbsoluteThickness[0.5], 
    LineBox[{{7.153341832467244, -0.4080893934259795}, {
     7.120943885457081, -0.42574865625016045`}}]}, 
   {Hue[0.6690134605642624], AbsoluteThickness[0.5], 
    LineBox[{{7.120943885457081, -0.42574865625016045`}, {
     6.837624706793859, -0.5648177273477154}}]}, 
   {Hue[0.6765771290323573], AbsoluteThickness[0.5], 
    LineBox[{{6.414939325543486, 2.353959752925625}, {6.3807482400486695`, 
     2.3511519501244837`}}]}, 
   {Hue[0.6785539618122758], AbsoluteThickness[0.5], 
    LineBox[{{6.3807482400486695`, 2.3511519501244837`}, {6.150664217077219, 
     2.2994575666377393`}}]}, 
   {Hue[0.27630415429619215`], AbsoluteThickness[0.5], 
    LineBox[{{6.926381430156632, 3.6163090736854038`}, {6.893885522823127, 
     3.7438287409999873`}}]}, 
   {Hue[0.2907545920083297], AbsoluteThickness[0.5], 
    LineBox[{{6.893885522823127, 3.7438287409999873`}, {6.800272548374458, 
     3.903720781093537}}]}, 
   {Hue[0.49527433978637103`], AbsoluteThickness[0.5], 
    LineBox[{{6.800272548374458, 3.903720781093537}, {6.615917689755518, 
     3.8852237658209394`}}]}, 
   {Hue[0.6997940875644117], AbsoluteThickness[0.5], 
    LineBox[{{6.615917689755518, 3.8852237658209394`}, {6.55593606862351, 
     3.709921003159364}}]}, 
   {Hue[0.6585930611864689], AbsoluteThickness[0.5], 
    LineBox[{{8.147689191245997, 3.0608320707099805`}, {8.245652453873213, 
     3.083732016092113}}]}, 
   {Hue[0.674180187540862], AbsoluteThickness[0.5], 
    LineBox[{{5.674843955248316, 1.6043458059306115`}, {5.652967303906132, 
     1.6022056509942348`}}]}, 
   {Hue[0.6747862200917301], AbsoluteThickness[0.5], 
    LineBox[{{5.652967303906132, 1.6022056509942348`}, {5.429982970796115, 
     1.5674841771304788`}}]}, 
   {Hue[0.6799920577183826], AbsoluteThickness[0.5], 
    LineBox[{{4.870379569205521, 2.3354023260983987`}, {4.823199295691741, 
     2.6323470533727638`}}]}, 
   {Hue[0.6804998138853654], AbsoluteThickness[0.5], 
    LineBox[{{4.823199295691741, 2.6323470533727638`}, {4.763686315919806, 
     2.9306754685411667`}}]}, 
   {Hue[0.4677788219953755], AbsoluteThickness[0.5], 
    LineBox[{{4.713698731334323, 2.417362111296979}, {4.644854846446582, 
     2.4331664687621286`}}]}, 
   {Hue[0.46820511679866467`], AbsoluteThickness[0.5], 
    LineBox[{{4.644854846446582, 2.4331664687621286`}, {4.336686791613659, 
     2.5028358850875247`}}]}, 
   {Hue[0.6262514486084355], AbsoluteThickness[0.5], 
    LineBox[{{6.388721068733993, -1.0813044266053828`}, {
     6.396813805154897, -1.1070450373074778`}}]}, 
   {Hue[0.629578049082579], AbsoluteThickness[0.5], 
    LineBox[{{6.396813805154897, -1.1070450373074778`}, {
     6.426119818901029, -1.3286461120366424`}}]}, 
   {Hue[0.5849782631224492], AbsoluteThickness[0.5], 
    LineBox[{{2.5882082491968275`, 2.8166976089816007`}, {2.5479307021555266`,
      2.849129407639726}}]}, 
   {Hue[0.5854816433118079], AbsoluteThickness[0.5], 
    LineBox[{{2.5479307021555266`, 2.849129407639726}, {2.3170728868507218`, 
     3.0500697221548667`}}]}, 
   {Hue[0.358266348984895], AbsoluteThickness[0.5], 
    LineBox[{{5.867161567005154, 3.3941647574617706`}, {5.8640374491792695`, 
     3.4100225532253354`}}]}, 
   {Hue[0.3707364811240572], AbsoluteThickness[0.5], 
    LineBox[{{5.8640374491792695`, 3.4100225532253354`}, {5.87475992724196, 
     3.5546948758297714`}}]}, 
   {Hue[0.5892240609613073], AbsoluteThickness[0.5], 
    LineBox[{{5.87475992724196, 3.5546948758297714`}, {6.011800178418934, 
     3.6022871233173466`}}]}, 
   {Hue[0.6112610105936287], AbsoluteThickness[0.5], 
    LineBox[{{8.285866812309248, 2.9238281108744575`}, {8.300778776993004, 
     3.0998684060503843`}}]}, 
   {Hue[0.6120101899473301], AbsoluteThickness[0.5], 
    LineBox[{{8.300778776993004, 3.0998684060503843`}, {8.303633302464954, 
     3.372920771027824}}]}, 
   {Hue[0.434016901586404], AbsoluteThickness[0.5], 
    LineBox[{{2.85710114453368, -0.3990468533382532}, {
     2.7036509993648874`, -0.46447157323103744`}}]}, 
   {Hue[0.43444263813702433`], AbsoluteThickness[0.5], 
    LineBox[{{2.7036509993648874`, -0.46447157323103744`}, {
     2.3920500018863944`, -0.5972955279904086}}]}, 
   {Hue[0.615501089674697], AbsoluteThickness[0.5], 
    LineBox[{{6.9293809215545785`, -4.146612234815339}, {
     7.070166739580383, -4.264867407508395}}]}, 
   {Hue[0.6184635513611201], AbsoluteThickness[0.5], 
    LineBox[{{7.070166739580383, -4.264867407508395}, {
     7.2522394955700165`, -4.372332769030049}}]}, 
   {Hue[0.5092501570479289], AbsoluteThickness[0.5], 
    LineBox[{{2.6055910368859605`, -2.089787655441193}, {
     2.5763571364919344`, -2.0872579036243453`}}]}, 
   {Hue[0.5120481282299865], AbsoluteThickness[0.5], 
    LineBox[{{2.5763571364919344`, -2.0872579036243453`}, {
     2.3968142799779795`, -2.100811837788073}}]}, 
   {Hue[0.5743897757419762], AbsoluteThickness[0.5], 
    LineBox[{{3.314234994465451, 2.5115178616594105`}, {3.200173035611733, 
     2.5750154722166894`}}]}, 
   {Hue[0.5765707481997245], AbsoluteThickness[0.5], 
    LineBox[{{3.200173035611733, 2.5750154722166894`}, {2.94847555012497, 
     2.670487125900177}}]}, 
   {Hue[0.36281957186766267`], AbsoluteThickness[0.5], 
    LineBox[{{3.870473323532715, -4.502107084479699}, {
     3.6136245327688594`, -4.6123858964317765`}}]}, 
   {Hue[0.3642795525778809], AbsoluteThickness[0.5], 
    LineBox[{{3.6136245327688594`, -4.6123858964317765`}, {
     3.3587480505349756`, -4.68734704091687}}]}, 
   {Hue[0.6437452718276531], AbsoluteThickness[0.5], 
    LineBox[{{3.9279029709237454`, -3.919375029109192}, {
     3.904456542107963, -3.8670895136412975`}}]}, 
   {Hue[0.6442125026156214], AbsoluteThickness[0.5], 
    LineBox[{{3.904456542107963, -3.8670895136412975`}, {
     3.7521950130531545`, -3.5517467668931584`}}]}, 
   {Hue[0.6977836670801939], AbsoluteThickness[0.5], 
    LineBox[{{2.6482715407445836`, -0.7299739379928217}, {
     2.6262174920962145`, -0.6809158757452819}}]}, 
   {Hue[0.6982120061484203], AbsoluteThickness[0.5], 
    LineBox[{{2.6262174920962145`, -0.6809158757452819}, {
     2.4853099309644704`, -0.3733830222983079}}]}, 
   {Hue[0.5616935533672013], AbsoluteThickness[0.5], 
    LineBox[{{4.691450885566592, 3.5702251489438948`}, {4.6893526466579925`, 
     3.6041206011627627`}}]}, 
   {Hue[0.5632575046311886], AbsoluteThickness[0.5], 
    LineBox[{{4.6893526466579925`, 3.6041206011627627`}, {4.651809971392609, 
     3.8038694445228023`}}]}, 
   {Hue[0.5651482108662841], AbsoluteThickness[0.5], 
    LineBox[{{3.866066447875262, 2.5742279739834126`}, {3.8290474867365702`, 
     2.643348657741215}}]}, 
   {Hue[0.5655854125710403], AbsoluteThickness[0.5], 
    LineBox[{{3.8290474867365702`, 2.643348657741215}, {3.708751187587927, 
     2.8762871666547016`}}]}, 
   {Hue[0.5624554095745299], AbsoluteThickness[0.5], 
    LineBox[{{4.346544683921633, -2.544065780281749}, {
     4.3205147368254035`, -2.5934653943560892`}}]}, 
   {Hue[0.5629289878175224], AbsoluteThickness[0.5], 
    LineBox[{{4.3205147368254035`, -2.5934653943560892`}, {
     4.194437839885494, -2.851401092403826}}]}, 
   {Hue[0.686098931618395], AbsoluteThickness[0.5], 
    LineBox[{{4.529776831593772, 0.8335810328943158}, {4.414720926851723, 
     0.8057491321190823}}]}, 
   {Hue[0.6865398116891827], AbsoluteThickness[0.5], 
    LineBox[{{4.414720926851723, 0.8057491321190823}, {4.097157870779512, 
     0.7231204329469665}}]}, 
   {Hue[0.673115901828129], AbsoluteThickness[0.5], 
    LineBox[{{4.369257599604803, 0.9052290655568795}, {4.183084959724205, 
     1.0950767311582545`}}]}, 
   {Hue[0.6792628784407524], AbsoluteThickness[0.5], 
    LineBox[{{4.183084959724205, 1.0950767311582545`}, {4.023347680863359, 
     1.1996588997195219`}}]}, 
   {Hue[0.5620498686395254], AbsoluteThickness[0.5], 
    LineBox[{{6.199155877671204, -1.9155365655164078`}, {
     6.154033551337778, -1.9368875625602615`}}]}, 
   {Hue[0.5625048779914513], AbsoluteThickness[0.5], 
    LineBox[{{6.154033551337778, -1.9368875625602615`}, {
     5.9368618334716405`, -2.0333832456383}}]}, 
   {Hue[0.5034588049737848], AbsoluteThickness[0.5], 
    LineBox[{{7.8626080260593865`, -2.9201016700632216`}, {
     7.650823581703243, -3.0283548259743744`}}]}, 
   {Hue[0.5063264267884185], AbsoluteThickness[0.5], 
    LineBox[{{7.650823581703243, -3.0283548259743744`}, {
     7.483845134758273, -3.08170266570363}}]}, 
   {Hue[0.2406765907909024], AbsoluteThickness[0.5], 
    LineBox[{{7.852208431272864, -3.125135169400311}, {
     7.853209871159699, -3.130880130488442}}]}, 
   {Hue[0.24341613299370515`], AbsoluteThickness[0.5], 
    LineBox[{{7.853209871159699, -3.130880130488442}, {
     7.856113592464554, -3.366939489287598}}]}, 
   {Hue[0.6106819354666141], AbsoluteThickness[0.5], 
    LineBox[{{7.856113592464554, -3.366939489287598}, {
     7.620547199964535, -3.3824613190319184`}}]}, 
   {Hue[0.5171527218235089], AbsoluteThickness[0.5], 
    LineBox[{{8.045015079767252, -3.1956510095959563`}, {
     8.167656767295115, -3.2113558821909582`}}]}, 
   {Hue[0.5177862864443029], AbsoluteThickness[0.5], 
    LineBox[{{8.167656767295115, -3.2113558821909582`}, {
     8.446850603323314, -3.2645115230631143`}}]}, 
   {Hue[0.6647728447726368], AbsoluteThickness[0.5], 
    LineBox[{{7.097204366780842, -1.7702837773598346`}, {
     6.854369743393549, -1.720278884837801}}]}, 
   {Hue[0.6653172068913593], AbsoluteThickness[0.5], 
    LineBox[{{6.854369743393549, -1.720278884837801}, {
     6.590266062173317, -1.678684078778548}}]}, 
   {Hue[0.5859924999490977], AbsoluteThickness[0.5], 
    LineBox[{{6.101158777415393, -0.15860301589132159`}, {
     6.042762707882233, -0.15303879297946477`}}]}, 
   {Hue[0.6140154152479852], AbsoluteThickness[0.5], 
    LineBox[{{6.042762707882233, -0.15303879297946477`}, {
     5.881999752137925, -0.07936456098215756}}]}, 
   {Hue[0.403804719629895], AbsoluteThickness[0.5], 
    LineBox[{{6.809528011819617, -2.363328325603887}, {
     6.68512410890188, -2.6120581588945844`}}]}, 
   {Hue[0.4051627258975601], AbsoluteThickness[0.5], 
    LineBox[{{6.68512410890188, -2.6120581588945844`}, {
     6.598547395749276, -2.8500027101051555`}}]}, 
   {Hue[0.5444799792969479], AbsoluteThickness[0.5], 
    LineBox[{{6.690690906036114, 2.3016471809204977`}, {6.640167009904462, 
     2.591763270028201}}]}, 
   {Hue[0.5454365952756891], AbsoluteThickness[0.5], 
    LineBox[{{6.640167009904462, 2.591763270028201}, {6.617845028413572, 
     2.8670745017424095`}}]}, 
   {Hue[0.6903223427127123], AbsoluteThickness[0.5], 
    LineBox[{{8.056907924911837, 1.5797745390945321`}, {7.951903438520577, 
     1.8486648423660137`}}]}, 
   {Hue[0.6943606181505033], AbsoluteThickness[0.5], 
    LineBox[{{7.951903438520577, 1.8486648423660137`}, {7.918115797962569, 
     2.028109040302557}}]}, 
   {Hue[0.6380126587820457], AbsoluteThickness[0.5], 
    LineBox[{{5.418592908749717, 1.1247570083385896`}, {5.1690604359622725`, 
     1.023857994890458}}]}, 
   {Hue[0.6384868284994979], AbsoluteThickness[0.5], 
    LineBox[{{5.1690604359622725`, 1.023857994890458}, {4.864397022989695, 
     0.9113485724587121}}]}, 
   {Hue[0.631181992984371], AbsoluteThickness[0.5], 
    LineBox[{{3.686106284137202, -0.8461040061521784}, {
     3.6657036770175204`, -0.8422364990160351}}]}, 
   {Hue[0.6336204008642872], AbsoluteThickness[0.5], 
    LineBox[{{3.6657036770175204`, -0.8422364990160351}, {
     3.4347702262503246`, -0.8342273561908617}}]}, 
   {Hue[0.5515140458304028], AbsoluteThickness[0.5], 
    LineBox[{{4.900830592772577, 3.1285533780371346`}, {4.900046718381665, 
     3.1332130402735507`}}]}, 
   {Hue[0.5525089460722423], AbsoluteThickness[0.5], 
    LineBox[{{4.900046718381665, 3.1332130402735507`}, {4.82993723400549, 
     3.3958468197789093`}}]}, 
   {Hue[0.5860791342466428], AbsoluteThickness[0.5], 
    LineBox[{{3.898202302843766, -3.0517609693935466`}, {
     3.8066987667571843`, -3.13652022180718}}]}, 
   {Hue[0.587161457646629], AbsoluteThickness[0.5], 
    LineBox[{{3.8066987667571843`, -3.13652022180718}, {
     3.6422565258155317`, -3.322592771888509}}]}, 
   {Hue[0.5646889200874693], AbsoluteThickness[0.5], 
    LineBox[{{2.420338479167671, -3.109187551476117}, {
     2.409554418250852, -3.1195694382374994`}}]}, 
   {Hue[0.565129072003939], AbsoluteThickness[0.5], 
    LineBox[{{2.409554418250852, -3.1195694382374994`}, {
     2.189567347060777, -3.324345434809075}}]}, 
   {Hue[0.6513010364956318], AbsoluteThickness[0.5], 
    LineBox[{{6.441247720715189, -3.18594811307588}, {
     6.402661883966015, -3.2170740840478893`}}]}, 
   {Hue[0.651887377345706], AbsoluteThickness[0.5], 
    LineBox[{{6.402661883966015, -3.2170740840478893`}, {
     6.171303787281273, -3.383924119348245}}]}, 
   {Hue[0.6505904366781535], AbsoluteThickness[0.5], 
    LineBox[{{7.889401824116802, -3.1655293703782172`}, {
     7.88120113666646, -3.1690670397399514`}}]}, 
   {Hue[0.6510218693808867], AbsoluteThickness[0.5], 
    LineBox[{{7.88120113666646, -3.1690670397399514`}, {
     7.568473772665055, -3.307918069888385}}]}, 
   {Hue[0.67272044166838], AbsoluteThickness[0.5], 
    LineBox[{{7.791673742885342, -1.9328155172634356`}, {
     7.746894929263097, -2.1013397720517966`}}]}, 
   {Hue[0.6732493650562343], AbsoluteThickness[0.5], 
    LineBox[{{7.746894929263097, -2.1013397720517966`}, {
     7.684690597105262, -2.385063745987754}}]}, 
   {Hue[0.6658412745383155], AbsoluteThickness[0.5], 
    LineBox[{{7.748281112518247, -1.407412426677133}, {
     7.8680674885992845`, -1.4672930107848128`}}]}, 
   {Hue[0.6662731216950659], AbsoluteThickness[0.5], 
    LineBox[{{7.8680674885992845`, -1.4672930107848128`}, {
     8.132634607216966, -1.6031939018677062`}}]}, 
   {Hue[0.5563343180522174], AbsoluteThickness[0.5], 
    LineBox[{{5.400314800517776, 2.634406970291726}, {5.36435077664577, 
     2.6468970042467452`}}]}, 
   {Hue[0.5568251865434949], AbsoluteThickness[0.5], 
    LineBox[{{5.36435077664577, 2.6468970042467452`}, {5.114620657043498, 
     2.7436052852853194`}}]}, 
   {Hue[0.5905526500990174], AbsoluteThickness[0.5], 
    LineBox[{{5.588813482890147, 2.1899380505810755`}, {5.400661067903458, 
     2.1735061116252306`}}]}, 
   {Hue[0.5911459764151236], AbsoluteThickness[0.5], 
    LineBox[{{5.400661067903458, 2.1735061116252306`}, {5.0875746845745, 
     2.163470550492381}}]}, 
   {Hue[0.6070949419631522], AbsoluteThickness[0.5], 
    LineBox[{{6.8488183324584675`, 2.0818504549234156`}, {6.6811629443936535`,
      1.9862780295055391`}}]}, 
   {Hue[0.6078269564981916], AbsoluteThickness[0.5], 
    LineBox[{{6.6811629443936535`, 1.9862780295055391`}, {6.421771840824382, 
     1.8623160124020834`}}]}, 
   {Hue[0.6424708742547504], AbsoluteThickness[0.5], 
    LineBox[{{8.267153541184173, 2.1075513548491003`}, {8.338921390874619, 
     1.8455179438358436`}}]}, 
   {Hue[0.6474590112819629], AbsoluteThickness[0.5], 
    LineBox[{{8.338921390874619, 1.8455179438358436`}, {8.350668307526071, 
     1.669389064590502}}]}, 
   {Hue[0.6691004997036958], AbsoluteThickness[0.5], 
    LineBox[{{8.100869524001356, 2.3510970512833125`}, {7.647963142481853, 
     1.868207587183164}}]}, 
   {Hue[0.5578919916031232], AbsoluteThickness[0.5], 
    LineBox[{{7.118783665925361, 3.3996644783457275`}, {7.069146110553881, 
     3.4180127267697564`}}]}, 
   {Hue[0.5583350435728862], AbsoluteThickness[0.5], 
    LineBox[{{7.069146110553881, 3.4180127267697564`}, {6.819495285927612, 
     3.5155505086764145`}}]}, 
   {Hue[0.6078647673545359], AbsoluteThickness[0.5], 
    LineBox[{{7.074407802002502, 1.7069067412362675`}, {6.99623941307157, 
     1.647680212902404}}]}, 
   {Hue[0.6087565038795725], AbsoluteThickness[0.5], 
    LineBox[{{6.99623941307157, 1.647680212902404}, {6.8231517475505505`, 
     1.49119980864954}}]}, 
   {Hue[0.612108804992482], AbsoluteThickness[0.5], 
    LineBox[{{6.6172753919074285`, 0.6551777919117211}, {6.566224921479508, 
     0.6202555871735563}}]}, 
   {Hue[0.6125551392205435], AbsoluteThickness[0.5], 
    LineBox[{{6.566224921479508, 0.6202555871735563}, {6.3526733309609495`, 
     0.46779968640209313`}}]}, 
   {Hue[0.6099534570311242], AbsoluteThickness[0.5], 
    LineBox[{{5.101848676588302, -0.22862156045164617`}, {
     4.660979872761006, -0.5334850466164723}}]}, 
   {Hue[0.6107046977395221], AbsoluteThickness[0.5], 
    LineBox[{{4.660979872761006, -0.5334850466164723}, {
     4.417623262550861, -0.6763151735752865}}]}, 
   {Hue[0.6644638970060038], AbsoluteThickness[0.5], 
    LineBox[{{3.328806002872901, 1.4522049659072374`}, {3.1521610358748, 
     1.452696186755529}}]}, 
   {Hue[0.6649650078081119], AbsoluteThickness[0.5], 
    LineBox[{{3.1521610358748, 1.452696186755529}, {2.8197410466331765`, 
     1.466184370069291}}]}, 
   {Hue[0.5180282404163706], AbsoluteThickness[0.5], 
    LineBox[{{4.623650941674435, 3.291280121189655}, {4.505911463736482, 
     3.3915525796492467`}}]}, 
   {Hue[0.5239373355171976], AbsoluteThickness[0.5], 
    LineBox[{{4.505911463736482, 3.3915525796492467`}, {4.395453041234828, 
     3.5360497858040247`}}]}, 
   {Hue[0.6277181772663093], AbsoluteThickness[0.5], 
    LineBox[{{5.047749079484228, -3.1263818769018625`}, {
     5.021782020843202, -3.3303993386110697`}}]}, 
   {Hue[0.628143996962748], AbsoluteThickness[0.5], 
    LineBox[{{5.021782020843202, -3.3303993386110697`}, {
     4.98095872750068, -3.6544592365431594`}}]}, 
   {Hue[0.5886391140069154], AbsoluteThickness[0.5], 
    LineBox[{{3.171857218701396, -2.3009195014084822`}, {
     3.1000903850854837`, -2.367341104495103}}]}, 
   {Hue[0.5890649957414202], AbsoluteThickness[0.5], 
    LineBox[{{3.1000903850854837`, -2.367341104495103}, {
     2.8462682236337233`, -2.6030582719901867`}}]}, 
   {Hue[0.674037446528203], AbsoluteThickness[0.5], 
    LineBox[{{2.675676106742003, 3.3328220750058217`}, {2.6539144328685853`, 
     3.35130629433194}}]}, 
   {Hue[0.6744641692317626], AbsoluteThickness[0.5], 
    LineBox[{{2.6539144328685853`, 3.35130629433194}, {2.390110756597884, 
     3.5773901200574127`}}]}, 
   {Hue[0.6939470147175414], AbsoluteThickness[0.5], 
    LineBox[{{4.004646344868565, 3.691621434697718}, {3.9484359518140826`, 
     3.763345312661575}}]}, 
   {Hue[0.6952679526027267], AbsoluteThickness[0.5], 
    LineBox[{{3.9484359518140826`, 3.763345312661575}, {3.7750118905819083`, 
     3.939447915006459}}]}, 
   {Hue[0.5990598401125198], AbsoluteThickness[0.5], 
    LineBox[{{2.1431650454299063`, 3.3317383017636777`}, {2.076876082654065, 
     3.3715384840611935`}}]}, 
   {Hue[0.5997881084509858], AbsoluteThickness[0.5], 
    LineBox[{{2.076876082654065, 3.3715384840611935`}, {1.8559634213328087`, 
     3.526803432819854}}]}, 
   {Hue[0.6514553794533288], AbsoluteThickness[0.5], 
    LineBox[{{7.16949024947014, -0.4183667883837525}, {
     7.228445709409051, -0.5760884034787112}}]}, 
   {Hue[0.6519717425668199], AbsoluteThickness[0.5], 
    LineBox[{{7.228445709409051, -0.5760884034787112}, {
     7.339839600342299, -0.9162615734347286}}]}, 
   {Hue[0.613925973031514], AbsoluteThickness[0.5], 
    LineBox[{{6.054449334116864, 1.6745966638859084`}, {6.025861048735463, 
     1.8197913007914321`}}]}, 
   {Hue[0.6143729540798877], AbsoluteThickness[0.5], 
    LineBox[{{6.025861048735463, 1.8197913007914321`}, {5.965974247185192, 
     2.1603711096767886`}}]}, 
   {Hue[0.6754048745827315], AbsoluteThickness[0.5], 
    LineBox[{{4.354060626691401, 1.0917879266675314`}, {4.333802062812203, 
     1.13321131369546}}]}, 
   {Hue[0.6758349256016201], AbsoluteThickness[0.5], 
    LineBox[{{4.333802062812203, 1.13321131369546}, {4.192371647825257, 
     1.4157705018606768`}}]}, 
   {Hue[0.690634506108841], AbsoluteThickness[0.5], 
    LineBox[{{5.707960488084197, -1.3531215603239766`}, {
     5.5966829961482985`, -1.3623983474084276`}}]}, 
   {Hue[0.6960248001896514], AbsoluteThickness[0.5], 
    LineBox[{{5.5966829961482985`, -1.3623983474084276`}, {
     5.410391657168372, -1.4178564859341527`}}]}, 
   {Hue[0.6932348917074735], AbsoluteThickness[0.5], 
    LineBox[{{6.846232734149933, -0.3303595863593283}, {
     6.842746289633953, -0.3315867967847713}}]}, 
   {Hue[0.695866853270961], AbsoluteThickness[0.5], 
    LineBox[{{6.842746289633953, -0.3315867967847713}, {
     6.617593867399691, -0.3727425678912868}}]}, 
   {Hue[0.6693923006886361], AbsoluteThickness[0.5], 
    LineBox[{{6.253818836855383, 0.855254129202131}, {6.208997030532959, 
     0.9375483880217163}}]}, 
   {Hue[0.6770333079149241], AbsoluteThickness[0.5], 
    LineBox[{{6.208997030532959, 0.9375483880217163}, {6.1751371751919475`, 
     1.0611176723813127`}}]}, 
   {Hue[0.6852442189304757], AbsoluteThickness[0.5], 
    LineBox[{{4.602480380999232, -1.0978217022176406`}, {
     4.5919477313241375`, -1.1007835721160866`}}]}, 
   {Hue[0.5974872421759851], AbsoluteThickness[0.5], 
    LineBox[{{5.39730538962839, -3.011422304384213}, {
     5.243957047781139, -3.0885427291219902`}}]}, 
   {Hue[0.6041492679397752], AbsoluteThickness[0.5], 
    LineBox[{{5.243957047781139, -3.0885427291219902`}, {
     5.0865961719534125`, -3.2176924635626323`}}]}, 
   {Hue[0.6809315039058044], AbsoluteThickness[0.5], 
    LineBox[{{4.9506413959460325`, 2.6365725409437655`}, {4.991968869997949, 
     2.8311766808073577`}}]}, 
   {Hue[0.6813994608008441], AbsoluteThickness[0.5], 
    LineBox[{{4.991968869997949, 2.8311766808073577`}, {5.048882069523557, 
     3.142637055734707}}]}, 
   {Hue[0.568358186827775], AbsoluteThickness[0.5], 
    LineBox[{{3.370669597879347, 1.5966708469483937`}, {3.3111673995753597`, 
     1.6040945877479031`}}]}, 
   {Hue[0.5775094769488247], AbsoluteThickness[0.5], 
    LineBox[{{3.3111673995753597`, 1.6040945877479031`}, {3.1324212431353136`,
      1.6731838923132727`}}]}, 
   {Hue[0.6964760381208861], AbsoluteThickness[0.5], 
    LineBox[{{6.712373735724104, -2.408289745128004}, {
     6.786910590225022, -2.3638623200532627`}}]}, 
   {Hue[0.6857366192468215], AbsoluteThickness[0.5], 
    LineBox[{{8.46406358679981, 1.3365175692132867`}, {8.3592259561301, 
     2.2114760927490584`}}]}, 
   {Hue[0.6945810919811601], AbsoluteThickness[0.5], 
    LineBox[{{8.3592259561301, 2.2114760927490584`}, {8.297872756380093, 
     2.3737860578723873`}}]}, 
   {Hue[0.5626884538795909], AbsoluteThickness[0.5], 
    LineBox[{{7.8899432712459285`, -3.6964282896020006`}, {
     8.014250634588532, -3.810145143265588}}]}, 
   {Hue[0.5636638286897474], AbsoluteThickness[0.5], 
    LineBox[{{8.014250634588532, -3.810145143265588}, {
     8.19076808997436, -4.00462739335131}}]}, 
   {Hue[0.6654818008877038], AbsoluteThickness[0.5], 
    LineBox[{{6.526366235678133, -1.808800098791853}, {
     6.562333974672027, -1.6636740901439364`}}]}, 
   {Hue[0.6660655744068639], AbsoluteThickness[0.5], 
    LineBox[{{6.562333974672027, -1.6636740901439364`}, {
     6.611906221527652, -1.4050053872434454`}}]}, 
   {Hue[0.6811605471949598], AbsoluteThickness[0.5], 
    LineBox[{{4.484261555427588, 3.1481958381996322`}, {4.439427242136003, 
     3.4301243680940106`}}]}, 
   {Hue[0.6835787007190914], AbsoluteThickness[0.5], 
    LineBox[{{4.439427242136003, 3.4301243680940106`}, {4.438249771434392, 
     3.64110877179139}}]}, 
   {Hue[0.5424319197876604], AbsoluteThickness[0.5], 
    LineBox[{{7.372464814451507, -4.191144720026113}, {
     7.575585245491044, -4.284551086436265}}]}, 
   {Hue[0.5430553407670471], AbsoluteThickness[0.5], 
    LineBox[{{7.575585245491044, -4.284551086436265}, {
     7.828682041900999, -4.383188322485962}}]}, 
   {Hue[0.6193693384862937], AbsoluteThickness[0.5], 
    LineBox[{{6.834080188492347, -3.8988714446203776`}, {
     6.870892235585228, -3.909408194710161}}]}, 
   {Hue[0.6199211039457093], AbsoluteThickness[0.5], 
    LineBox[{{6.870892235585228, -3.909408194710161}, {
     7.1498137431994335`, -4.004012566675287}}]}, 
   {Hue[0.674054852556163], AbsoluteThickness[0.5], 
    LineBox[{{7.624287694495394, -1.1149948560706253`}, {
     7.695327133758601, -1.1020428317297424`}}]}, 
   {Hue[0.6818914700712735], AbsoluteThickness[0.5], 
    LineBox[{{7.695327133758601, -1.1020428317297424`}, {
     7.890784388550819, -1.1123727827250542`}}]}, 
   {Hue[0.6312225088276104], AbsoluteThickness[0.5], 
    LineBox[{{3.6416953989751586`, -4.36336709322511}, {
     3.613570390792544, -4.478504051611564}}]}, 
   {Hue[0.6335231091103073], AbsoluteThickness[0.5], 
    LineBox[{{3.613570390792544, -4.478504051611564}, {
     3.5212355919665574`, -4.704114879370452}}]}, 
   {Hue[0.5791318299078709], AbsoluteThickness[0.5], 
    LineBox[{{2.1769245681499423`, 1.8480519959757062`}, {2.0534679024658895`,
      1.9043185262399205`}}]}, 
   {Hue[0.5811167341006492], AbsoluteThickness[0.5], 
    LineBox[{{2.0534679024658895`, 1.9043185262399205`}, {1.878673661752114, 
     2.0156091967941157`}}]}, 
   {Hue[0.5742466317456806], AbsoluteThickness[0.5], 
    LineBox[{{3.073008612662402, 0.24810912040500221`}, {2.9126727102305527`, 
     0.23721555220846555`}}]}, 
   {Hue[0.5746783149315805], AbsoluteThickness[0.5], 
    LineBox[{{2.9126727102305527`, 0.23721555220846555`}, {2.559412835962438, 
     0.2170497183414858}}]}, 
   {Hue[0.5755145145711139], AbsoluteThickness[0.5], 
    LineBox[{{4.138500953100903, 0.23487580234613556`}, {3.924721588546218, 
     0.24697444044257236`}}]}, 
   {Hue[0.5759867658464121], AbsoluteThickness[0.5], 
    LineBox[{{3.924721588546218, 0.24697444044257236`}, {3.6076299679478945`, 
     0.25542109380509953`}}]}, 
   {Hue[0.5757272393621604], AbsoluteThickness[0.5], 
    LineBox[{{4.13721292182909, 0.24310576236783532`}, {3.9247195239249333`, 
     0.2469854484962036}}]}, 
   {Hue[0.5761853914945233], AbsoluteThickness[0.5], 
    LineBox[{{3.9247195239249333`, 0.2469854484962036}, {3.6054217900086174`, 
     0.24481302916809133`}}]}, 
   {Hue[0.6004824153315774], AbsoluteThickness[0.5], 
    LineBox[{{3.360614879070025, 1.586871675816136}, {3.325606331418112, 
     1.608292672169582}}]}, 
   {Hue[0.6015255620113623], AbsoluteThickness[0.5], 
    LineBox[{{3.325606331418112, 1.608292672169582}, {3.1037675652491004`, 
     1.7757174866097332`}}]}, 
   {Hue[0.5938482199184612], AbsoluteThickness[0.5], 
    LineBox[{{4.366964248422053, -2.6001202531007293`}, {
     4.361026502246985, -2.6100896694698883`}}]}, 
   {Hue[0.5942739585808576], AbsoluteThickness[0.5], 
    LineBox[{{4.361026502246985, -2.6100896694698883`}, {
     4.210603133632322, -2.8625229634085043`}}]}, 
   {Hue[0.5811504380750661], AbsoluteThickness[0.5], 
    LineBox[{{2.1313622455690426`, 1.3415524409376163`}, {2.0448631658031053`,
      1.3566100470972153`}}]}, 
   {Hue[0.5882375151939616], AbsoluteThickness[0.5], 
    LineBox[{{2.0448631658031053`, 1.3566100470972153`}, {1.8432228443194083`,
      1.4414151804773183`}}]}, 
   {Hue[0.6872259940767254], AbsoluteThickness[0.5], 
    LineBox[{{2.4142848338071903`, 3.133311342994274}, {2.398567726669713, 
     3.1433828878472285`}}]}, 
   {Hue[0.6876530305859962], AbsoluteThickness[0.5], 
    LineBox[{{2.398567726669713, 3.1433828878472285`}, {2.132345818222263, 
     3.315886158083719}}]}, 
   {Hue[0.6436157541006708], AbsoluteThickness[0.5], 
    LineBox[{{8.120240370898566, -4.098779934781666}, {
     8.032467100769594, -4.3377136343847145`}}]}, 
   {Hue[0.6440451767921594], AbsoluteThickness[0.5], 
    LineBox[{{8.032467100769594, -4.3377136343847145`}, {
     7.917038938468622, -4.660396701675549}}]}, 
   {Hue[0.6824643608534018], AbsoluteThickness[0.5], 
    LineBox[{{3.3288014129480503`, 2.568294347251686}, {3.208128578567729, 
     2.5529785998353596`}}]}, 
   {Hue[0.6829092217680118], AbsoluteThickness[0.5], 
    LineBox[{{3.208128578567729, 2.5529785998353596`}, {2.840162141814522, 
     2.499033968941653}}]}, 
   {Hue[0.5652969768904964], AbsoluteThickness[0.5], 
    LineBox[{{5.887060601616193, -4.116930277842006}, {
     5.88784249684077, -4.142909419469527}}]}, 
   {Hue[0.567530667149601], AbsoluteThickness[0.5], 
    LineBox[{{5.88784249684077, -4.142909419469527}, {
     5.859367128493709, -4.3854219181685625`}}]}, 
   {Hue[0.6017603599517635], AbsoluteThickness[0.5], 
    LineBox[{{4.09151793901149, -3.305721155366677}, {
     4.028579094548515, -3.328072683982372}}]}, 
   {Hue[0.6230135701959734], AbsoluteThickness[0.5], 
    LineBox[{{4.028579094548515, -3.328072683982372}, {
     3.9133547706534397`, -3.416176545246503}}]}, 
   {Hue[0.6394711672953816], AbsoluteThickness[0.5], 
    LineBox[{{6.397707818292967, 0.15904679120468926`}, {6.376597735610737, 
     0.20628580433114418`}}]}, 
   {Hue[0.6402628729829775], AbsoluteThickness[0.5], 
    LineBox[{{6.376597735610737, 0.20628580433114418`}, {6.238555697933659, 
     0.4599337312827515}}]}, 
   {Hue[0.6994195410378691], AbsoluteThickness[0.5], 
    LineBox[{{4.796135985353077, -1.986612176572475}, {
     4.664658979921041, -2.018347500694896}}]}, 
   {Hue[0.6998919311760241], AbsoluteThickness[0.5], 
    LineBox[{{4.664658979921041, -2.018347500694896}, {
     4.34746820416744, -2.084926875056824}}]}, 
   {Hue[0.6745933497392623], AbsoluteThickness[0.5], 
    LineBox[{{6.297766935201437, -3.4025827257331995`}, {
     6.25433273400026, -3.5993656561487435`}}]}, 
   {Hue[0.6750194820191613], AbsoluteThickness[0.5], 
    LineBox[{{6.25433273400026, -3.5993656561487435`}, {
     6.1880840589026995`, -3.895575044399531}}]}, 
   {Hue[0.6778227064606613], AbsoluteThickness[0.5], 
    LineBox[{{2.8461561655048797`, -0.4847398102769068}, {
     2.7007124885467526`, -0.4579522949895184}}]}, 
   {Hue[0.6787002259514605], AbsoluteThickness[0.5], 
    LineBox[{{2.7007124885467526`, -0.4579522949895184}, {
     2.411743906875508, -0.4299471154705458}}]}, 
   {Hue[0.6695368390124483], AbsoluteThickness[0.5], 
    LineBox[{{6.837624706793859, -0.5648177273477154}, {
     6.691636799084561, -0.628887346702727}}]}, 
   {Hue[0.672073324743381], AbsoluteThickness[0.5], 
    LineBox[{{6.691636799084561, -0.628887346702727}, {
     6.4652262451567, -0.6887099889069456}}]}, 
   {Hue[0.6805307945921941], AbsoluteThickness[0.5], 
    LineBox[{{6.150664217077219, 2.2994575666377393`}, {5.8194592841770865`, 
     2.174762635998432}}]}, 
   {Hue[0.681420434540911], AbsoluteThickness[0.5], 
    LineBox[{{5.8194592841770865`, 2.174762635998432}, {5.625122080682023, 
     2.1202268423312303`}}]}, 
   {Hue[0.5097247774985085], AbsoluteThickness[0.5], 
    LineBox[{{6.615917689755518, 3.8852237658209394`}, {6.362627215476967, 
     3.784011990407738}}]}, 
   {Hue[0.5101725240658426], AbsoluteThickness[0.5], 
    LineBox[{{6.362627215476967, 3.784011990407738}, {6.086985422600325, 
     3.6671927000743785`}}]}, 
   {Hue[0.6753922526425983], AbsoluteThickness[0.5], 
    LineBox[{{5.429982970796115, 1.5674841771304788`}, {5.169943184118535, 
     1.5116708043856044`}}]}, 
   {Hue[0.6758295387124622], AbsoluteThickness[0.5], 
    LineBox[{{5.169943184118535, 1.5116708043856044`}, {4.840531784797741, 
     1.446136660014117}}]}, 
   {Hue[0.6810075700523481], AbsoluteThickness[0.5], 
    LineBox[{{4.763686315919806, 2.9306754685411667`}, {4.725938666419233, 
     3.0874783490873154`}}]}, 
   {Hue[0.6817709021267195], AbsoluteThickness[0.5], 
    LineBox[{{4.725938666419233, 3.0874783490873154`}, {4.679969954369674, 
     3.3709099722718983`}}]}, 
   {Hue[0.4686314116019538], AbsoluteThickness[0.5], 
    LineBox[{{4.336686791613659, 2.5028358850875247`}, {4.190775304308223, 
     2.535314216632762}}]}, 
   {Hue[0.4691720905918857], AbsoluteThickness[0.5], 
    LineBox[{{4.190775304308223, 2.535314216632762}, {3.8737762684716697`, 
     2.590656059725776}}]}, 
   {Hue[0.6329046495567224], AbsoluteThickness[0.5], 
    LineBox[{{6.426119818901029, -1.3286461120366424`}, {
     6.421265344952086, -1.4451510046113478`}}]}, 
   {Hue[0.6361628618409434], AbsoluteThickness[0.5], 
    LineBox[{{6.421265344952086, -1.4451510046113478`}, {
     6.445685133936152, -1.6317922370582127`}}]}, 
   {Hue[0.5859850235011665], AbsoluteThickness[0.5], 
    LineBox[{{2.3170728868507218`, 3.0500697221548667`}, {2.288402764023846, 
     3.077022722253862}}]}, 
   {Hue[0.5870204351396101], AbsoluteThickness[0.5], 
    LineBox[{{2.288402764023846, 3.077022722253862}, {2.115109582759048, 
     3.274861394297961}}]}, 
   {Hue[0.5767539288221406], AbsoluteThickness[0.5], 
    LineBox[{{5.8640374491792695`, 3.4100225532253354`}, {5.641153420861398, 
     3.6179579251309733`}}]}, 
   {Hue[0.5931838707334418], AbsoluteThickness[0.5], 
    LineBox[{{5.641153420861398, 3.6179579251309733`}, {5.474227932516873, 
     3.7007125858964467`}}]}, 
   {Hue[0.38320661326321886`], AbsoluteThickness[0.5], 
    LineBox[{{5.87475992724196, 3.5546948758297714`}, {5.904211823062667, 
     3.6373025383369106`}}]}, 
   {Hue[0.38877698403313027`], AbsoluteThickness[0.5], 
    LineBox[{{5.904211823062667, 3.6373025383369106`}, {5.932716905950035, 
     3.848763816472477}}]}, 
   {Hue[0.685531760112999], AbsoluteThickness[0.5], 
    LineBox[{{5.932716905950035, 3.848763816472477}, {5.735198261317041, 
     3.9294781084131745`}}]}, 
   {Hue[0.6016941931004689], AbsoluteThickness[0.5], 
    LineBox[{{6.011800178418934, 3.6022871233173466`}, {6.116398745889458, 
     3.6091752333889757`}}]}, 
   {Hue[0.6025577540610063], AbsoluteThickness[0.5], 
    LineBox[{{6.116398745889458, 3.6091752333889757`}, {6.373768735000898, 
     3.648112565212877}}]}, 
   {Hue[0.6127593693010315], AbsoluteThickness[0.5], 
    LineBox[{{8.303633302464954, 3.372920771027824}, {8.291454889937961, 
     3.5641516956947266`}}]}, 
   {Hue[0.613192236505545], AbsoluteThickness[0.5], 
    LineBox[{{8.291454889937961, 3.5641516956947266`}, {8.26895824250015, 
     3.998397728479294}}]}, 
   {Hue[0.4348683746876447], AbsoluteThickness[0.5], 
    LineBox[{{2.3920500018863944`, -0.5972955279904086}, {
     2.3584980906235007`, -0.6115942695504235}}]}, 
   {Hue[0.43531425339479196`], AbsoluteThickness[0.5], 
    LineBox[{{2.3584980906235007`, -0.6115942695504235}, {
     2.0597728629994405`, -0.7459586893713026}}]}, 
   {Hue[0.6214260130475432], AbsoluteThickness[0.5], 
    LineBox[{{7.2522394955700165`, -4.372332769030049}, {
     7.392088521259915, -4.426217323317612}}]}, 
   {Hue[0.621863858763614], AbsoluteThickness[0.5], 
    LineBox[{{7.392088521259915, -4.426217323317612}, {
     7.664004835697806, -4.535827908983871}}]}, 
   {Hue[0.5148460994120442], AbsoluteThickness[0.5], 
    LineBox[{{2.3968142799779795`, -2.100811837788073}, {
     2.3840249460522607`, -2.103901191690007}}]}, 
   {Hue[0.5161809975854799], AbsoluteThickness[0.5], 
    LineBox[{{2.3840249460522607`, -2.103901191690007}, {
     2.143810223478889, -2.1336762109413923`}}]}, 
   {Hue[0.5787517206574727], AbsoluteThickness[0.5], 
    LineBox[{{2.94847555012497, 2.670487125900177}, {2.8710294392811133`, 
     2.6875716764518023`}}]}, 
   {Hue[0.5792102509637679], AbsoluteThickness[0.5], 
    LineBox[{{2.8710294392811133`, 2.6875716764518023`}, {2.5740592462522844`,
      2.760977274157578}}]}, 
   {Hue[0.6446797334035895], AbsoluteThickness[0.5], 
    LineBox[{{3.7521950130531545`, -3.5517467668931584`}, {
     3.6895254999078677`, -3.4308125483771685`}}]}, 
   {Hue[0.6595900624802963], AbsoluteThickness[0.5], 
    LineBox[{{3.6895254999078677`, -3.4308125483771685`}, {
     3.577285498144843, -3.3129022184324715`}}]}, 
   {Hue[0.6986403452166468], AbsoluteThickness[0.5], 
    LineBox[{{2.4853099309644704`, -0.3733830222983079}, {
     2.421734731064172, -0.23721298444671474`}}]}, 
   {Hue[0.5660226142757965], AbsoluteThickness[0.5], 
    LineBox[{{3.708751187587927, 2.8762871666547016`}, {3.6609059278454654`, 
     2.9724424956427957`}}]}, 
   {Hue[0.5675310155539242], AbsoluteThickness[0.5], 
    LineBox[{{3.6609059278454654`, 2.9724424956427957`}, {3.521233148763959, 
     3.1840863573262115`}}]}, 
   {Hue[0.563402566060515], AbsoluteThickness[0.5], 
    LineBox[{{4.194437839885494, -2.851401092403826}, {
     4.145850215985145, -2.958950143831127}}]}, 
   {Hue[0.5640835735137311], AbsoluteThickness[0.5], 
    LineBox[{{4.145850215985145, -2.958950143831127}, {
     4.0286222128460105`, -3.1781966823724757`}}]}, 
   {Hue[0.6869806917599702], AbsoluteThickness[0.5], 
    LineBox[{{4.097157870779512, 0.7231204329469665}, {4.035956580211997, 
     0.7060661975736511}}]}, 
   {Hue[0.6911284799840903], AbsoluteThickness[0.5], 
    LineBox[{{4.035956580211997, 0.7060661975736511}, {3.8460215942879983`, 
     0.6120163516980889}}]}, 
   {Hue[0.6854098550533758], AbsoluteThickness[0.5], 
    LineBox[{{4.023347680863359, 1.1996588997195219`}, {3.934305388799493, 
     1.2336015023728144`}}]}, 
   {Hue[0.6858368736888762], AbsoluteThickness[0.5], 
    LineBox[{{3.934305388799493, 1.2336015023728144`}, {3.657072029210732, 
     1.3408817344744626`}}]}, 
   {Hue[0.5629598873433771], AbsoluteThickness[0.5], 
    LineBox[{{5.9368618334716405`, -2.0333832456383}, {
     5.746920148611249, -2.112414637358781}}]}, 
   {Hue[0.5660356360141189], AbsoluteThickness[0.5], 
    LineBox[{{5.746920148611249, -2.112414637358781}, {
     5.566233670934659, -2.226252455931248}}]}, 
   {Hue[0.5091940486030523], AbsoluteThickness[0.5], 
    LineBox[{{7.483845134758273, -3.08170266570363}, {
     7.294598779946619, -3.1095216187607897`}}]}, 
   {Hue[0.5113277993822659], AbsoluteThickness[0.5], 
    LineBox[{{7.294598779946619, -3.1095216187607897`}, {
     7.071370748696711, -3.1761258239682078`}}]}, 
   {Hue[0.6079423932638136], AbsoluteThickness[0.5], 
    LineBox[{{7.853209871159699, -3.130880130488442}, {
     7.856697436299587, -3.1315924628879985`}}]}, 
   {Hue[0.609536279357572], AbsoluteThickness[0.5], 
    LineBox[{{7.856697436299587, -3.1315924628879985`}, {
     8.119030178520674, -3.1516463896895437`}}]}, 
   {Hue[0.24615567519650797`], AbsoluteThickness[0.5], 
    LineBox[{{7.856113592464554, -3.366939489287598}, {
     7.8243703945442835`, -3.579878917177504}}]}, 
   {Hue[0.24677277788406873`], AbsoluteThickness[0.5], 
    LineBox[{{7.8243703945442835`, -3.579878917177504}, {
     7.766957317913787, -3.8539272748865567`}}]}, 
   {Hue[0.6134214776694171], AbsoluteThickness[0.5], 
    LineBox[{{7.620547199964535, -3.3824613190319184`}, {
     7.338025832877562, -3.3556874185472423`}}]}, 
   {Hue[0.6142717576121144], AbsoluteThickness[0.5], 
    LineBox[{{7.338025832877562, -3.3556874185472423`}, {
     7.063231685825354, -3.3063135995223156`}}]}, 
   {Hue[0.6658615690100819], AbsoluteThickness[0.5], 
    LineBox[{{6.590266062173317, -1.678684078778548}, {
     6.040603779625546, -1.6183437310214828`}}]}, 
   {Hue[0.6682931502190274], AbsoluteThickness[0.5], 
    LineBox[{{6.040603779625546, -1.6183437310214828`}, {
     5.822909492846566, -1.5600065765038356`}}]}, 
   {Hue[0.6420383305468733], AbsoluteThickness[0.5], 
    LineBox[{{5.881999752137925, -0.07936456098215758}, {5.6926482047980675`, 
     0.10221071331559888`}}]}, 
   {Hue[0.6438906998740838], AbsoluteThickness[0.5], 
    LineBox[{{5.6926482047980675`, 0.10221071331559889`}, {5.584365318838603, 
     0.2384711540590646}}]}, 
   {Hue[0.4065207321652252], AbsoluteThickness[0.5], 
    LineBox[{{6.598547395749276, -2.8500027101051555`}, {
     6.58391098150084, -2.9113646525631562`}}]}, 
   {Hue[0.4071614037971665], AbsoluteThickness[0.5], 
    LineBox[{{6.58391098150084, -2.9113646525631562`}, {
     6.499065085615725, -3.1897228751610283`}}]}, 
   {Hue[0.5463932112544301], AbsoluteThickness[0.5], 
    LineBox[{{6.617845028413572, 2.8670745017424095`}, {6.617883141607935, 
     2.870664132495522}}]}, 
   {Hue[0.5485222202131591], AbsoluteThickness[0.5], 
    LineBox[{{6.617883141607935, 2.870664132495522}, {6.586500050581291, 
     3.1047981307866888`}}]}, 
   {Hue[0.6983988935882943], AbsoluteThickness[0.5], 
    LineBox[{{7.918115797962569, 2.028109040302557}, {7.9181399578859635`, 
     2.345655936032902}}]}, 
   {Hue[0.699247046525714], AbsoluteThickness[0.5], 
    LineBox[{{7.9181399578859635`, 2.345655936032902}, {7.939860883391668, 
     2.6061501974052597`}}]}, 
   {Hue[0.6389609982169501], AbsoluteThickness[0.5], 
    LineBox[{{4.864397022989695, 0.9113485724587121}, {4.756422156308151, 
     0.8751758351591655}}]}, 
   {Hue[0.646528231245785], AbsoluteThickness[0.5], 
    LineBox[{{4.756422156308151, 0.8751758351591655}, {4.600018611181995, 
     0.7784591298358078}}]}, 
   {Hue[0.6360588087442033], AbsoluteThickness[0.5], 
    LineBox[{{3.4347702262503246`, -0.8342273561908617}, {
     3.363985846794644, -0.8426189903118521}}]}, 
   {Hue[0.6367056080656827], AbsoluteThickness[0.5], 
    LineBox[{{3.363985846794644, -0.8426189903118521}, {
     3.072010669576292, -0.8588399200997123}}]}, 
   {Hue[0.5535038463140819], AbsoluteThickness[0.5], 
    LineBox[{{4.82993723400549, 3.3958468197789093`}, {4.763431430407299, 
     3.575214874930655}}]}, 
   {Hue[0.5541260212538899], AbsoluteThickness[0.5], 
    LineBox[{{4.763431430407299, 3.575214874930655}, {4.6828838357235965`, 
     3.839502812947185}}]}, 
   {Hue[0.5882437810466152], AbsoluteThickness[0.5], 
    LineBox[{{3.6422565258155317`, -3.322592771888509}, {
     3.631045841447462, -3.3381675290355464`}}]}, 
   {Hue[0.5886696467629233], AbsoluteThickness[0.5], 
    LineBox[{{3.631045841447462, -3.3381675290355464`}, {
     3.453991537035909, -3.583317689141742}}]}, 
   {Hue[0.5655692239204089], AbsoluteThickness[0.5], 
    LineBox[{{2.189567347060777, -3.324345434809075}, {
     2.1145301906715943`, -3.391877641179621}}]}, 
   {Hue[0.5660031958609324], AbsoluteThickness[0.5], 
    LineBox[{{2.1145301906715943`, -3.391877641179621}, {
     1.8763600478094447`, -3.600805945301011}}]}, 
   {Hue[0.6524737181957803], AbsoluteThickness[0.5], 
    LineBox[{{6.171303787281273, -3.383924119348245}, {
     6.129484668233276, -3.4107761549882447`}}]}, 
   {Hue[0.6529303504324733], AbsoluteThickness[0.5], 
    LineBox[{{6.129484668233276, -3.4107761549882447`}, {
     5.881935333724532, -3.578422727377539}}]}, 
   {Hue[0.6514533020836198], AbsoluteThickness[0.5], 
    LineBox[{{7.568473772665055, -3.307918069888385}, {
     7.186154918742031, -3.4825355980468156`}}]}, 
   {Hue[0.6519215787360024], AbsoluteThickness[0.5], 
    LineBox[{{7.186154918742031, -3.4825355980468156`}, {
     6.894188159568165, -3.605912314857369}}]}, 
   {Hue[0.6737782884440887], AbsoluteThickness[0.5], 
    LineBox[{{7.684690597105262, -2.385063745987754}, {
     7.634775902237589, -2.6724920158576406`}}]}, 
   {Hue[0.6752705317857978], AbsoluteThickness[0.5], 
    LineBox[{{7.634775902237589, -2.6724920158576406`}, {
     7.624683535655903, -2.870130004883361}}]}, 
   {Hue[0.6667049688518163], AbsoluteThickness[0.5], 
    LineBox[{{8.132634607216966, -1.6031939018677062`}, {
     8.151919232627076, -1.6133685967291065`}}]}, 
   {Hue[0.6676693800237744], AbsoluteThickness[0.5], 
    LineBox[{{8.151919232627076, -1.6133685967291065`}, {
     8.36204238602026, -1.7503042236506916`}}]}, 
   {Hue[0.5573160550347722], AbsoluteThickness[0.5], 
    LineBox[{{5.114620657043498, 2.7436052852853194`}, {4.895715034917978, 
     2.8373658493481577`}}]}, 
   {Hue[0.5588651612356366], AbsoluteThickness[0.5], 
    LineBox[{{4.895715034917978, 2.8373658493481577`}, {4.6634527369030065`, 
     2.9044893264111664`}}]}, 
   {Hue[0.5917393027312298], AbsoluteThickness[0.5], 
    LineBox[{{5.0875746845745, 2.163470550492381}, {4.860077720462856, 
     2.1687099922349438`}}]}, 
   {Hue[0.5925548513918609], AbsoluteThickness[0.5], 
    LineBox[{{4.860077720462856, 2.1687099922349438`}, {4.5865274152254925`, 
     2.197076969064456}}]}, 
   {Hue[0.6085589710332311], AbsoluteThickness[0.5], 
    LineBox[{{6.421771840824382, 1.8623160124020834`}, {6.373283888576857, 
     1.8433133129010109`}}]}, 
   {Hue[0.6092031667833251], AbsoluteThickness[0.5], 
    LineBox[{{6.373283888576857, 1.8433133129010109`}, {6.109003597854673, 
     1.720288130215295}}]}, 
   {Hue[0.6524471483091752], AbsoluteThickness[0.5], 
    LineBox[{{8.350668307526071, 1.669389064590502}, {8.321926011177291, 
     1.4564040798289852`}}]}, 
   {Hue[0.6528730644229616], AbsoluteThickness[0.5], 
    LineBox[{{8.321926011177291, 1.4564040798289852`}, {8.273771726915419, 
     1.1045760388572392`}}]}, 
   {Hue[0.5587780955426493], AbsoluteThickness[0.5], 
    LineBox[{{6.819495285927612, 3.5155505086764145`}, {6.5911077084578835`, 
     3.6096585119530467`}}]}, 
   {Hue[0.5625986566769114], AbsoluteThickness[0.5], 
    LineBox[{{6.5911077084578835`, 3.6096585119530467`}, {6.398698984133153, 
     3.650352655872802}}]}, 
   {Hue[0.609648240404609], AbsoluteThickness[0.5], 
    LineBox[{{6.8231517475505505`, 1.49119980864954}, {6.765523624187799, 
     1.4292278232863118`}}]}, 
   {Hue[0.6103334734636623], AbsoluteThickness[0.5], 
    LineBox[{{6.765523624187799, 1.4292278232863118`}, {6.58015944779799, 
     1.2009021872400871`}}]}, 
   {Hue[0.6130014734486049], AbsoluteThickness[0.5], 
    LineBox[{{6.3526733309609495`, 0.46779968640209313`}, {
     6.3157058712584035`, 0.440273440819557}}]}, 
   {Hue[0.6136021292351418], AbsoluteThickness[0.5], 
    LineBox[{{6.3157058712584035`, 0.440273440819557}, {6.080823447131878, 
     0.2439525437859313}}]}, 
   {Hue[0.6114559384479198], AbsoluteThickness[0.5], 
    LineBox[{{4.417623262550861, -0.6763151735752865}, {
     4.397807993999246, -0.6860460404935633}}]}, 
   {Hue[0.6119013467435989], AbsoluteThickness[0.5], 
    LineBox[{{4.397807993999246, -0.6860460404935633}, {
     4.126120481966752, -0.8261377423030113}}]}, 
   {Hue[0.6654661186102198], AbsoluteThickness[0.5], 
    LineBox[{{2.8197410466331765`, 1.466184370069291}, {2.652878258755507, 
     1.479280880743839}}]}, 
   {Hue[0.6658927378363958], AbsoluteThickness[0.5], 
    LineBox[{{2.652878258755507, 1.479280880743839}, {2.3105022011863134`, 
     1.5047156151042578`}}]}, 
   {Hue[0.5298464306180244], AbsoluteThickness[0.5], 
    LineBox[{{4.395453041234828, 3.5360497858040247`}, {4.3491269037442315`, 
     3.634452158002576}}]}, 
   {Hue[0.530508053221645], AbsoluteThickness[0.5], 
    LineBox[{{4.3491269037442315`, 3.634452158002576}, {4.219455912824971, 
     3.8693715457280367`}}]}, 
   {Hue[0.6285698166591868], AbsoluteThickness[0.5], 
    LineBox[{{4.98095872750068, -3.6544592365431594`}, {
     4.952495189401937, -3.8827686834504402`}}]}, 
   {Hue[0.6293858299421763], AbsoluteThickness[0.5], 
    LineBox[{{4.952495189401937, -3.8827686834504402`}, {
     4.941335344279472, -4.138058903235302}}]}, 
   {Hue[0.589490877475925], AbsoluteThickness[0.5], 
    LineBox[{{2.8462682236337233`, -2.6030582719901867`}, {
     2.8443739969931903`, -2.6048233721464276`}}]}, 
   {Hue[0.5899584379713159], AbsoluteThickness[0.5], 
    LineBox[{{2.8443739969931903`, -2.6048233721464276`}, {
     2.602735941846418, -2.843158415617484}}]}, 
   {Hue[0.674890891935322], AbsoluteThickness[0.5], 
    LineBox[{{2.390110756597884, 3.5773901200574127`}, {2.339989846305448, 
     3.620729444350386}}]}, 
   {Hue[0.675317089598375], AbsoluteThickness[0.5], 
    LineBox[{{2.339989846305448, 3.620729444350386}, {2.11022671314051, 
     3.818196092846386}}]}, 
   {Hue[0.652488105680311], AbsoluteThickness[0.5], 
    LineBox[{{7.339839600342299, -0.9162615734347287}, {
     7.464324566224961, -1.3571253303227504`}}]}, 
   {Hue[0.6529356172085219], AbsoluteThickness[0.5], 
    LineBox[{{7.464324566224961, -1.3571253303227504`}, {
     7.542428453794627, -1.6572378320787606`}}]}, 
   {Hue[0.6148199351282613], AbsoluteThickness[0.5], 
    LineBox[{{5.965974247185192, 2.1603711096767886`}, {5.933914880637347, 
     2.3672998633718434`}}]}, 
   {Hue[0.616999184019358], AbsoluteThickness[0.5], 
    LineBox[{{5.933914880637347, 2.3672998633718434`}, {5.931917390935369, 
     2.606930288762667}}]}, 
   {Hue[0.6762649766205088], AbsoluteThickness[0.5], 
    LineBox[{{4.192371647825257, 1.4157705018606768`}, {4.163580384391221, 
     1.4719910456931804`}}]}, 
   {Hue[0.6787629652664573], AbsoluteThickness[0.5], 
    LineBox[{{4.163580384391221, 1.4719910456931804`}, {4.041427884988962, 
     1.6403974272232003`}}]}, 
   {Hue[0.6984988148344484], AbsoluteThickness[0.5], 
    LineBox[{{6.617593867399691, -0.3727425678912868}, {
     6.348901772082151, -0.3789608505552845}}]}, 
   {Hue[0.6994762169540264], AbsoluteThickness[0.5], 
    LineBox[{{6.348901772082151, -0.3789608505552845}, {
     6.070724892980512, -0.3594979460836912}}]}, 
   {Hue[0.6846743151412121], AbsoluteThickness[0.5], 
    LineBox[{{6.1751371751919475`, 1.0611176723813127`}, {6.173078575379532, 
     1.1180041790876534`}}]}, 
   {Hue[0.6851732898939924], AbsoluteThickness[0.5], 
    LineBox[{{6.173078575379532, 1.1180041790876534`}, {6.151092519087672, 
     1.4168956805402855`}}]}, 
   {Hue[0.6108112937035651], AbsoluteThickness[0.5], 
    LineBox[{{5.0865961719534125`, -3.2176924635626323`}, {
     4.999543292949205, -3.329334851080475}}]}, 
   {Hue[0.6118230215247041], AbsoluteThickness[0.5], 
    LineBox[{{4.999543292949205, -3.329334851080475}, {
     4.853519881497733, -3.558697811301595}}]}, 
   {Hue[0.6818674176958837], AbsoluteThickness[0.5], 
    LineBox[{{5.048882069523557, 3.142637055734707}, {5.077789134709745, 
     3.3310784632974935`}}]}, 
   {Hue[0.6825845547347684], AbsoluteThickness[0.5], 
    LineBox[{{5.077789134709745, 3.3310784632974935`}, {5.097463948837873, 
     3.571993898512117}}]}, 
   {Hue[0.5866607670698747], AbsoluteThickness[0.5], 
    LineBox[{{3.1324212431353136`, 1.6731838923132727`}, {2.9236719063865997`,
      1.820186815512315}}]}, 
   {Hue[0.5887354727162687], AbsoluteThickness[0.5], 
    LineBox[{{2.9236719063865997`, 1.820186815512315}, {2.7235665665348665`, 
     1.922174480220636}}]}, 
   {Hue[0.5646392034999039], AbsoluteThickness[0.5], 
    LineBox[{{8.19076808997436, -4.00462739335131}, {
     8.253166000772614, -4.08770975447159}}]}, 
   {Hue[0.5652644234463481], AbsoluteThickness[0.5], 
    LineBox[{{8.253166000772614, -4.08770975447159}, {
     8.445809000590584, -4.378871353628191}}]}, 
   {Hue[0.6666493479260238], AbsoluteThickness[0.5], 
    LineBox[{{6.611906221527652, -1.4050053872434454`}, {
     6.662494279192894, -1.034649939393856}}]}, 
   {Hue[0.6988857176974419], AbsoluteThickness[0.5], 
    LineBox[{{6.662494279192894, -1.034649939393856}, {
     6.629411550095126, -0.8800640175205724}}]}, 
   {Hue[0.5436787617464338], AbsoluteThickness[0.5], 
    LineBox[{{7.828682041900999, -4.383188322485962}, {
     7.853938190259228, -4.391340083961319}}]}, 
   {Hue[0.5442401068915119], AbsoluteThickness[0.5], 
    LineBox[{{7.853938190259228, -4.391340083961319}, {
     8.156324702606854, -4.505890657251756}}]}, 
   {Hue[0.6204728694051249], AbsoluteThickness[0.5], 
    LineBox[{{7.1498137431994335`, -4.004012566675287}, {
     7.610154005358531, -4.185335853195037}}]}, 
   {Hue[0.6209862722705436], AbsoluteThickness[0.5], 
    LineBox[{{7.610154005358531, -4.185335853195037}, {
     7.8692191035925365`, -4.299735434153131}}]}, 
   {Hue[0.6897280875863839], AbsoluteThickness[0.5], 
    LineBox[{{7.890784388550819, -1.1123727827250542`}, {
     7.931299634286689, -1.1242842526647208`}}]}, 
   {Hue[0.6930088909775828], AbsoluteThickness[0.5], 
    LineBox[{{7.931299634286689, -1.1242842526647208`}, {
     8.127361731484788, -1.1466810227634192`}}]}, 
   {Hue[0.5751099981174806], AbsoluteThickness[0.5], 
    LineBox[{{2.559412835962438, 0.2170497183414858}, {2.298540636581515, 
     0.20498667492464706`}}]}, 
   {Hue[0.576155581826665], AbsoluteThickness[0.5], 
    LineBox[{{2.298540636581515, 0.2049866749246471}, {2.0997434441958025`, 
     0.215204222004802}}]}, 
   {Hue[0.57645901712171], AbsoluteThickness[0.5], 
    LineBox[{{3.6076299679478945`, 0.25542109380509953`}, {3.400467875023218, 
     0.2547435593479836}}]}, 
   {Hue[0.5768873443636899], AbsoluteThickness[0.5], 
    LineBox[{{3.400467875023218, 0.2547435593479836}, {3.072439951006924, 
     0.25601466258898786`}}]}, 
   {Hue[0.576643543626886], AbsoluteThickness[0.5], 
    LineBox[{{3.6054217900086174`, 0.24481302916809133`}, {3.398709856318664, 
     0.23822430405981282`}}]}, 
   {Hue[0.5770968693439551], AbsoluteThickness[0.5], 
    LineBox[{{3.398709856318664, 0.23822430405981282`}, {3.074734574383372, 
     0.2354014091887244}}]}, 
   {Hue[0.6025687086911471], AbsoluteThickness[0.5], 
    LineBox[{{3.1037675652491004`, 1.7757174866097332`}, {3.034190291403562, 
     1.8397489483846365`}}]}, 
   {Hue[0.6033861330049398], AbsoluteThickness[0.5], 
    LineBox[{{3.034190291403562, 1.8397489483846365`}, {2.8508688650479703`, 
     2.0379516888865696`}}]}, 
   {Hue[0.5946996972432541], AbsoluteThickness[0.5], 
    LineBox[{{4.210603133632322, -2.8625229634085043`}, {
     4.149780228529424, -2.964542125806422}}]}, 
   {Hue[0.5953082171801207], AbsoluteThickness[0.5], 
    LineBox[{{4.149780228529424, -2.964542125806422}, {
     4.007070012663248, -3.1754285363115446`}}]}, 
   {Hue[0.6880800670952673], AbsoluteThickness[0.5], 
    LineBox[{{2.132345818222263, 3.315886158083719}, {2.059422459327112, 
     3.363664207765516}}]}, 
   {Hue[0.6889650223405346], AbsoluteThickness[0.5], 
    LineBox[{{2.059422459327112, 3.363664207765516}, {1.855576098515073, 
     3.5238810585050175`}}]}, 
   {Hue[0.6833540826826218], AbsoluteThickness[0.5], 
    LineBox[{{2.840162141814522, 2.499033968941653}, {2.6392741927654924`, 
     2.465606954313503}}]}, 
   {Hue[0.684296415752348], AbsoluteThickness[0.5], 
    LineBox[{{2.6392741927654924`, 2.465606954313503}, {2.3774027449322745`, 
     2.4460874659795016`}}]}, 
   {Hue[0.5697643574087053], AbsoluteThickness[0.5], 
    LineBox[{{5.859367128493709, -4.3854219181685625`}, {
     5.845569786871961, -4.4364943586178045`}}]}, 
   {Hue[0.5789815158202126], AbsoluteThickness[0.5], 
    LineBox[{{5.845569786871961, -4.4364943586178045`}, {
     5.841901861586191, -4.633647239394128}}]}, 
   {Hue[0.644266780440182], AbsoluteThickness[0.5], 
    LineBox[{{3.9133547706534397`, -3.416176545246503}, {
     3.821857036398906, -3.5480878386448667`}}]}, 
   {Hue[0.6448928947715777], AbsoluteThickness[0.5], 
    LineBox[{{3.821857036398906, -3.5480878386448667`}, {
     3.6509433401480753`, -3.8289534845107482`}}]}, 
   {Hue[0.6410545786705736], AbsoluteThickness[0.5], 
    LineBox[{{6.238555697933659, 0.4599337312827515}, {6.022353097365466, 
     0.792429206364514}}]}, 
   {Hue[0.6421155729958147], AbsoluteThickness[0.5], 
    LineBox[{{6.022353097365466, 0.792429206364514}, {5.895436561364092, 
     1.0374065415936127`}}]}, 
   {Hue[0.6754456142990602], AbsoluteThickness[0.5], 
    LineBox[{{6.1880840589026995`, -3.895575044399531}, {
     6.130017548099069, -4.1518351931692115`}}]}, 
   {Hue[0.6770927423019075], AbsoluteThickness[0.5], 
    LineBox[{{6.130017548099069, -4.1518351931692115`}, {
     6.105072394179704, -4.412171137558303}}]}, 
   {Hue[0.6795777454422598], AbsoluteThickness[0.5], 
    LineBox[{{2.411743906875508, -0.4299471154705458}, {
     2.3233519304224624`, -0.4289669568320894}}]}, 
   {Hue[0.688741452920655], AbsoluteThickness[0.5], 
    LineBox[{{2.3233519304224624`, -0.4289669568320894}, {
     2.1481056205562528`, -0.38311593307172065`}}]}, 
   {Hue[0.6746098104743136], AbsoluteThickness[0.5], 
    LineBox[{{6.4652262451567, -0.6887099889069456}, {
     6.373298770547263, -0.6982193919810753}}]}, 
   {Hue[0.6751489833983099], AbsoluteThickness[0.5], 
    LineBox[{{6.373298770547263, -0.6982193919810753}, {
     6.086569253477244, -0.7412527554813763}}]}, 
   {Hue[0.6823100744896278], AbsoluteThickness[0.5], 
    LineBox[{{5.625122080682023, 2.1202268423312303`}, {5.6250654838732865`, 
     2.120216127731293}}]}, 
   {Hue[0.6831199791314418], AbsoluteThickness[0.5], 
    LineBox[{{5.6250654838732865`, 2.120216127731293}, {5.426541259644721, 
     2.065934742565875}}]}, 
   {Hue[0.5106202706331763], AbsoluteThickness[0.5], 
    LineBox[{{6.086985422600325, 3.6671927000743785`}, {5.659040400618901, 
     3.4752773720040633`}}]}, 
   {Hue[0.5117443785487492], AbsoluteThickness[0.5], 
    LineBox[{{5.659040400618901, 3.4752773720040633`}, {5.388520076657984, 
     3.385878785628368}}]}, 
   {Hue[0.6762668247823261], AbsoluteThickness[0.5], 
    LineBox[{{4.840531784797741, 1.446136660014117}, {4.657374579307555, 
     1.4125555167467436`}}]}, 
   {Hue[0.6769650939399524], AbsoluteThickness[0.5], 
    LineBox[{{4.657374579307555, 1.4125555167467436`}, {4.422011515505318, 
     1.3859235880992415`}}]}, 
   {Hue[0.682534234201091], AbsoluteThickness[0.5], 
    LineBox[{{4.679969954369674, 3.3709099722718983`}, {4.672620745936511, 
     3.4568233368940366`}}]}, 
   {Hue[0.6848096545088278], AbsoluteThickness[0.5], 
    LineBox[{{4.672620745936511, 3.4568233368940366`}, {4.623256254340471, 
     3.6643727566065047`}}]}, 
   {Hue[0.4697127695818176], AbsoluteThickness[0.5], 
    LineBox[{{3.8737762684716697`, 2.590656059725776}, {3.5643179706168526`, 
     2.630062523738041}}]}, 
   {Hue[0.4741554862180636], AbsoluteThickness[0.5], 
    LineBox[{{3.5643179706168526`, 2.630062523738041}, {3.364007264631872, 
     2.616810940022137}}]}, 
   {Hue[0.6394210741251645], AbsoluteThickness[0.5], 
    LineBox[{{6.445685133936152, -1.6317922370582127`}, {
     6.499110603620356, -1.8033822697309134`}}]}, 
   {Hue[0.6399976344396624], AbsoluteThickness[0.5], 
    LineBox[{{6.499110603620356, -1.8033822697309134`}, {
     6.573063563436087, -2.093736882364953}}]}, 
   {Hue[0.5880558467780536], AbsoluteThickness[0.5], 
    LineBox[{{2.115109582759048, 3.274861394297961}, {2.0530025928849254`, 
     3.3614067978051323`}}]}, 
   {Hue[0.588559189971771], AbsoluteThickness[0.5], 
    LineBox[{{2.0530025928849254`, 3.3614067978051323`}, {1.8918709965230673`,
      3.6051333013175766`}}]}, 
   {Hue[0.609613812644742], AbsoluteThickness[0.5], 
    LineBox[{{5.474227932516873, 3.7007125858964467`}, {5.400815879474352, 
     3.7132978487501522`}}]}, 
   {Hue[0.6100485675176975], AbsoluteThickness[0.5], 
    LineBox[{{5.400815879474352, 3.7132978487501522`}, {5.058593017520518, 
     3.776664719922227}}]}, 
   {Hue[0.6799613893430835], AbsoluteThickness[0.5], 
    LineBox[{{5.904211823062667, 3.6373025383369106`}, {6.0823442582206315`, 
     3.698005660489309}}]}, 
   {Hue[0.6804517454379423], AbsoluteThickness[0.5], 
    LineBox[{{6.0823442582206315`, 3.698005660489309}, {6.363313299837524, 
     3.7828795860321582`}}]}, 
   {Hue[0.6034213150215438], AbsoluteThickness[0.5], 
    LineBox[{{6.373768735000898, 3.648112565212877}, {6.41470591844706, 
     3.657894138382205}}]}, 
   {Hue[0.646207863282606], AbsoluteThickness[0.5], 
    LineBox[{{6.41470591844706, 3.657894138382205}, {6.563165695192667, 
     3.637566837745387}}]}, 
   {Hue[0.6223017044796848], AbsoluteThickness[0.5], 
    LineBox[{{7.664004835697806, -4.535827908983871}, {
     7.856613320424013, -4.616940254248864}}]}, 
   {Hue[0.6280701809689069], AbsoluteThickness[0.5], 
    LineBox[{{7.856613320424013, -4.616940254248864}, {
     8.061928960346819, -4.655920873090138}}]}, 
   {Hue[0.5796687812700629], AbsoluteThickness[0.5], 
    LineBox[{{2.5740592462522844`, 2.760977274157578}, {2.3218143919734913`, 
     2.830116968941683}}]}, 
   {Hue[0.5806304903401058], AbsoluteThickness[0.5], 
    LineBox[{{2.3218143919734913`, 2.830116968941683}, {2.1059068156762986`, 
     2.8684345869358117`}}]}, 
   {Hue[0.6745003915570026], AbsoluteThickness[0.5], 
    LineBox[{{3.577285498144843, -3.3129022184324715`}, {
     3.4083040158987825`, -3.2144879144864493`}}]}, 
   {Hue[0.6790889984673859], AbsoluteThickness[0.5], 
    LineBox[{{3.4083040158987825`, -3.2144879144864493`}, {
     3.222844442345745, -3.1504590809045645`}}]}, 
   {Hue[0.5690394168320518], AbsoluteThickness[0.5], 
    LineBox[{{3.521233148763959, 3.1840863573262115`}, {3.4098504117689137`, 
     3.315002871757704}}]}, 
   {Hue[0.575005812693625], AbsoluteThickness[0.5], 
    LineBox[{{3.4098504117689137`, 3.315002871757704}, {3.2579781696389736`, 
     3.4310528545764356`}}]}, 
   {Hue[0.564764580966947], AbsoluteThickness[0.5], 
    LineBox[{{4.0286222128460105`, -3.1781966823724757`}, {
     3.934114750383075, -3.3297139956937305`}}]}, 
   {Hue[0.5814474363071875], AbsoluteThickness[0.5], 
    LineBox[{{3.934114750383075, -3.3297139956937305`}, {
     3.81329675289589, -3.4359794003074002`}}]}, 
   {Hue[0.6952762682082105], AbsoluteThickness[0.5], 
    LineBox[{{3.8460215942879983`, 0.6120163516980889}, {3.606947047737583, 
     0.4311045722355115}}]}, 
   {Hue[0.6999519352492717], AbsoluteThickness[0.5], 
    LineBox[{{3.606947047737583, 0.4311045722355115}, {3.4342960102338087`, 
     0.3473757321617485}}]}, 
   {Hue[0.6862638923243768], AbsoluteThickness[0.5], 
    LineBox[{{3.657072029210732, 1.3408817344744626`}, {3.5513445606155445`, 
     1.3824073182334662`}}]}, 
   {Hue[0.6869565509483225], AbsoluteThickness[0.5], 
    LineBox[{{3.5513445606155445`, 1.3824073182334662`}, {3.3231849474947075`,
      1.4904553901589366`}}]}, 
   {Hue[0.5691113846848608], AbsoluteThickness[0.5], 
    LineBox[{{5.566233670934659, -2.226252455931248}, {
     5.47338382455698, -2.3093659140625196`}}]}, 
   {Hue[0.5707347107812926], AbsoluteThickness[0.5], 
    LineBox[{{5.47338382455698, -2.3093659140625196`}, {
     5.316083123754253, -2.490785981514291}}]}, 
   {Hue[0.5134615501614797], AbsoluteThickness[0.5], 
    LineBox[{{7.071370748696711, -3.1761258239682078`}, {
     6.90768530179531, -3.251982423184165}}]}, 
   {Hue[0.5142364878105647], AbsoluteThickness[0.5], 
    LineBox[{{6.90768530179531, -3.251982423184165}, {
     6.63605602614572, -3.3534171632238485`}}]}, 
   {Hue[0.24738988057162936`], AbsoluteThickness[0.5], 
    LineBox[{{7.766957317913787, -3.8539272748865567`}, {
     7.69026403877258, -4.136479736118938}}]}, 
   {Hue[0.24804595992389114`], AbsoluteThickness[0.5], 
    LineBox[{{7.69026403877258, -4.136479736118938}, {
     7.636519825633674, -4.3997557798636215`}}]}, 
   {Hue[0.6151220375548118], AbsoluteThickness[0.5], 
    LineBox[{{7.063231685825354, -3.3063135995223156`}, {
     6.9055153051053635`, -3.264176557362512}}]}, 
   {Hue[0.6155494601774849], AbsoluteThickness[0.5], 
    LineBox[{{6.9055153051053635`, -3.264176557362512}, {
     6.5868111235174345`, -3.180994345594259}}]}, 
   {Hue[0.6707247314279728], AbsoluteThickness[0.5], 
    LineBox[{{5.822909492846566, -1.5600065765038356`}, {
     5.697057443965277, -1.5046609244727533`}}]}, 
   {Hue[0.6713332068599773], AbsoluteThickness[0.5], 
    LineBox[{{5.697057443965277, -1.5046609244727533`}, {
     5.422932052604315, -1.4024156279624311`}}]}, 
   {Hue[0.6457430692012941], AbsoluteThickness[0.5], 
    LineBox[{{5.584365318838603, 0.2384711540590646}, {5.527313673699266, 
     0.334382958653327}}]}, 
   {Hue[0.6462635958184156], AbsoluteThickness[0.5], 
    LineBox[{{5.527313673699266, 0.334382958653327}, {5.3665998235230825`, 
     0.6324780260583723}}]}, 
   {Hue[0.4078020754291079], AbsoluteThickness[0.5], 
    LineBox[{{6.499065085615725, -3.1897228751610283`}, {
     6.4545570222173465`, -3.3088445423780053`}}]}, 
   {Hue[0.408536132097153], AbsoluteThickness[0.5], 
    LineBox[{{6.4545570222173465`, -3.3088445423780053`}, {
     6.378074229267231, -3.5698395154254845`}}]}, 
   {Hue[0.5506512291718881], AbsoluteThickness[0.5], 
    LineBox[{{6.586500050581291, 3.1047981307866888`}, {6.5106815527448, 
     3.371366204703128}}]}, 
   {Hue[0.5510770821544633], AbsoluteThickness[0.5], 
    LineBox[{{6.5106815527448, 3.371366204703128}, {6.428319308331606, 
     3.66262069100383}}]}, 
   {Hue[0.6540954642746197], AbsoluteThickness[0.5], 
    LineBox[{{4.600018611181995, 0.7784591298358078}, {4.234825158015149, 
     0.4140021192679394}}]}, 
   {Hue[0.6622746691212853], AbsoluteThickness[0.5], 
    LineBox[{{4.234825158015149, 0.4140021192679394}, {4.13621505978222, 
     0.2532000520910042}}]}, 
   {Hue[0.637352407387162], AbsoluteThickness[0.5], 
    LineBox[{{3.072010669576292, -0.8588399200997123}, {
     3.0224314858810075`, -0.8584926768637484}}]}, 
   {Hue[0.6470088682872591], AbsoluteThickness[0.5], 
    LineBox[{{3.0224314858810075`, -0.8584926768637484}, {
     2.8631060906611183`, -0.8977813353275388}}]}, 
   {Hue[0.5890955124792315], AbsoluteThickness[0.5], 
    LineBox[{{3.453991537035909, -3.583317689141742}, {
     3.415923287402103, -3.635850021429178}}]}, 
   {Hue[0.5895517679363071], AbsoluteThickness[0.5], 
    LineBox[{{3.415923287402103, -3.635850021429178}, {
     3.208398444011405, -3.908034963505968}}]}, 
   {Hue[0.6533869826691662], AbsoluteThickness[0.5], 
    LineBox[{{5.881935333724532, -3.578422727377539}, {
     5.81994612254088, -3.6226541733884137`}}]}, 
   {Hue[0.6540654547642202], AbsoluteThickness[0.5], 
    LineBox[{{5.81994612254088, -3.6226541733884137`}, {
     5.601452992647481, -3.801570333409129}}]}, 
   {Hue[0.6523898553883848], AbsoluteThickness[0.5], 
    LineBox[{{6.894188159568165, -3.605912314857369}, {
     6.845049139359148, -3.6250385162833183`}}]}, 
   {Hue[0.6530599943724783], AbsoluteThickness[0.5], 
    LineBox[{{6.845049139359148, -3.6250385162833183`}, {
     6.560170261217219, -3.7579656068956524`}}]}, 
   {Hue[0.6767627751275068], AbsoluteThickness[0.5], 
    LineBox[{{7.624683535655903, -2.870130004883361}, {
     7.641044993149036, -3.103805856633432}}]}, 
   {Hue[0.677403903519538], AbsoluteThickness[0.5], 
    LineBox[{{7.641044993149036, -3.103805856633432}, {
     7.682288333499879, -3.415215211925911}}]}, 
   {Hue[0.5604142674365009], AbsoluteThickness[0.5], 
    LineBox[{{4.6634527369030065`, 2.9044893264111664`}, {4.656809778943767, 
     2.9055476797483144`}}]}, 
   {Hue[0.561029567707931], AbsoluteThickness[0.5], 
    LineBox[{{4.656809778943767, 2.9055476797483144`}, {4.371704939386365, 
     2.968187018488044}}]}, 
   {Hue[0.5933704000524922], AbsoluteThickness[0.5], 
    LineBox[{{4.5865274152254925`, 2.197076969064456}, {4.403264672629728, 
     2.2311135397106723`}}]}, 
   {Hue[0.593800197649989], AbsoluteThickness[0.5], 
    LineBox[{{4.403264672629728, 2.2311135397106723`}, {4.0785566914616975`, 
     2.2884212238763473`}}]}, 
   {Hue[0.6098473625334192], AbsoluteThickness[0.5], 
    LineBox[{{6.109003597854673, 1.720288130215295}, {6.031270035605688, 
     1.678039323910922}}]}, 
   {Hue[0.6129415827211695], AbsoluteThickness[0.5], 
    LineBox[{{6.031270035605688, 1.678039323910922}, {5.865243833866334, 
     1.5475398119748}}]}, 
   {Hue[0.6532989805367477], AbsoluteThickness[0.5], 
    LineBox[{{8.273771726915419, 1.1045760388572392`}, {8.25060730452076, 
     0.9376718386487788}}]}, 
   {Hue[0.6537258702439651], AbsoluteThickness[0.5], 
    LineBox[{{8.25060730452076, 0.9376718386487788}, {8.203877537238544, 
     0.6123768695632916}}]}, 
   {Hue[0.5664192178111738], AbsoluteThickness[0.5], 
    LineBox[{{6.398698984133153, 3.650352655872802}, {6.374895285604471, 
     3.650971679146646}}]}, 
   {Hue[0.5669419104929262], AbsoluteThickness[0.5], 
    LineBox[{{6.374895285604471, 3.650971679146646}, {6.0860977421364435`, 
     3.670815304287449}}]}, 
   {Hue[0.6110187065227157], AbsoluteThickness[0.5], 
    LineBox[{{6.58015944779799, 1.2009021872400871`}, {6.560661669494509, 
     1.1732851474558605`}}]}, 
   {Hue[0.6114452034701878], AbsoluteThickness[0.5], 
    LineBox[{{6.560661669494509, 1.1732851474558605`}, {6.363894699407268, 
     0.8922763450160127}}]}, 
   {Hue[0.6142027850216785], AbsoluteThickness[0.5], 
    LineBox[{{6.080823447131878, 0.2439525437859313}, {6.027277489221601, 
     0.1938313032468836}}]}, 
   {Hue[0.6156548500093013], AbsoluteThickness[0.5], 
    LineBox[{{6.027277489221601, 0.1938313032468836}, {
     5.853882328904092, -0.012338323091579353`}}]}, 
   {Hue[0.6123467550392778], AbsoluteThickness[0.5], 
    LineBox[{{4.126120481966752, -0.8261377423030113}, {
     4.067010275258206, -0.8580982092247889}}]}, 
   {Hue[0.6134201486246684], AbsoluteThickness[0.5], 
    LineBox[{{4.067010275258206, -0.8580982092247889}, {
     3.847750244652887, -1.0064953231888212`}}]}, 
   {Hue[0.6663193570625718], AbsoluteThickness[0.5], 
    LineBox[{{2.3105022011863134`, 1.5047156151042578`}, {2.185693862065037, 
     1.5134638882124358`}}]}, 
   {Hue[0.6667474655589186], AbsoluteThickness[0.5], 
    LineBox[{{2.185693862065037, 1.5134638882124358`}, {1.8168600927779441`, 
     1.5418524044478945`}}]}, 
   {Hue[0.6302018432251657], AbsoluteThickness[0.5], 
    LineBox[{{4.941335344279472, -4.138058903235302}, {
     4.948806531896903, -4.34177626151431}}]}, 
   {Hue[0.6306381967094418], AbsoluteThickness[0.5], 
    LineBox[{{4.948806531896903, -4.34177626151431}, {
     4.965471775693526, -4.667695260196255}}]}, 
   {Hue[0.5904259984667066], AbsoluteThickness[0.5], 
    LineBox[{{2.602735941846418, -2.843158415617484}, {
     2.581198458480413, -2.8656429234102103`}}]}, 
   {Hue[0.5908576671775693], AbsoluteThickness[0.5], 
    LineBox[{{2.581198458480413, -2.8656429234102103`}, {
     2.3700714185912735`, -3.0813403714260597`}}]}, 
   {Hue[0.6533831287367328], AbsoluteThickness[0.5], 
    LineBox[{{7.542428453794627, -1.6572378320787606`}, {
     7.592751865097625, -1.8683549717037968`}}]}, 
   {Hue[0.658457316818377], AbsoluteThickness[0.5], 
    LineBox[{{7.592751865097625, -1.8683549717037968`}, {
     7.598569719547527, -2.0496986080475894`}}]}, 
   {Hue[0.6191784329104547], AbsoluteThickness[0.5], 
    LineBox[{{5.931917390935369, 2.606930288762667}, {5.971566376113098, 
     2.894448652605397}}]}, 
   {Hue[0.6196251479062543], AbsoluteThickness[0.5], 
    LineBox[{{5.971566376113098, 2.894448652605397}, {6.00531478190308, 
     3.1820462490674384`}}]}, 
   {Hue[0.6812609539124059], AbsoluteThickness[0.5], 
    LineBox[{{4.041427884988962, 1.6403974272232003`}, {3.9309398995563667`, 
     1.7516887500092244`}}]}, 
   {Hue[0.6821173370721857], AbsoluteThickness[0.5], 
    LineBox[{{3.9309398995563667`, 1.7516887500092244`}, {3.7174847812183973`,
      1.933392304515839}}]}, 
   {Hue[0.6856722646467727], AbsoluteThickness[0.5], 
    LineBox[{{6.151092519087672, 1.4168956805402855`}, {6.1492903965976184`, 
     1.4331113046470312`}}]}, 
   {Hue[0.6893988042503022], AbsoluteThickness[0.5], 
    LineBox[{{6.1492903965976184`, 1.4331113046470312`}, {6.160389044746029, 
     1.591261023567}}]}, 
   {Hue[0.6128347493458434], AbsoluteThickness[0.5], 
    LineBox[{{4.853519881497733, -3.558697811301595}, {
     4.802561426336377, -3.658621799598411}}]}, 
   {Hue[0.6133065298229431], AbsoluteThickness[0.5], 
    LineBox[{{4.802561426336377, -3.658621799598411}, {
     4.661636490741214, -3.915758867559659}}]}, 
   {Hue[0.6833016917736532], AbsoluteThickness[0.5], 
    LineBox[{{5.097463948837873, 3.571993898512117}, {5.098299640111517, 
     3.649672887893089}}]}, 
   {Hue[0.6851051333314627], AbsoluteThickness[0.5], 
    LineBox[{{5.098299640111517, 3.649672887893089}, {5.135547946887427, 
     3.906722677806359}}]}, 
   {Hue[0.5908101783626627], AbsoluteThickness[0.5], 
    LineBox[{{2.7235665665348665`, 1.922174480220636}, {2.6128644012120845`, 
     1.9599891834703873`}}]}, 
   {Hue[0.5913015304215583], AbsoluteThickness[0.5], 
    LineBox[{{2.6128644012120845`, 1.9599891834703873`}, {2.3612252664292828`,
      2.0361321939973536`}}]}, 
   {Hue[0.6214996751359623], AbsoluteThickness[0.5], 
    LineBox[{{7.8692191035925365`, -4.299735434153131}, {
     7.943135869224623, -4.3360304530677425`}}]}, 
   {Hue[0.6233251798255421], AbsoluteThickness[0.5], 
    LineBox[{{7.943135869224623, -4.3360304530677425`}, {
     8.154538605057787, -4.47769080408213}}]}, 
   {Hue[0.6962896943687816], AbsoluteThickness[0.5], 
    LineBox[{{8.127361731484788, -1.1466810227634192`}, {
     8.13485672061667, -1.146242344452487}}]}, 
   {Hue[0.6971966032483814], AbsoluteThickness[0.5], 
    LineBox[{{8.13485672061667, -1.146242344452487}, {
     8.386744392057254, -1.1536418167854712`}}]}, 
   {Hue[0.5773156716056699], AbsoluteThickness[0.5], 
    LineBox[{{3.072439951006924, 0.25601466258898786`}, {2.911908564515445, 
     0.25778386579400675`}}]}, 
   {Hue[0.5777499530949108], AbsoluteThickness[0.5], 
    LineBox[{{2.911908564515445, 0.25778386579400675`}, {2.558538700417571, 
     0.2571005933905803}}]}, 
   {Hue[0.5775501950610241], AbsoluteThickness[0.5], 
    LineBox[{{3.074734574383372, 0.2354014091887244}, {2.912682912729162, 
     0.23774111052592942`}}]}, 
   {Hue[0.5779759404229533], AbsoluteThickness[0.5], 
    LineBox[{{2.912682912729162, 0.23774111052592942`}, {2.557812057809007, 
     0.2430154891248253}}]}, 
   {Hue[0.6042035573187324], AbsoluteThickness[0.5], 
    LineBox[{{2.8508688650479703`, 2.0379516888865696`}, {2.803814536295265, 
     2.0978421479699905`}}]}, 
   {Hue[0.6046437504472163], AbsoluteThickness[0.5], 
    LineBox[{{2.803814536295265, 2.0978421479699905`}, {2.5897873435991237`, 
     2.3798940547940144`}}]}, 
   {Hue[0.5959167371169873], AbsoluteThickness[0.5], 
    LineBox[{{4.007070012663248, -3.1754285363115446`}, {
     3.938771322127534, -3.2648543569291935`}}]}, 
   {Hue[0.597233412142567], AbsoluteThickness[0.5], 
    LineBox[{{3.938771322127534, -3.2648543569291935`}, {
     3.7734019201127045`, -3.4370980662274806`}}]}, 
   {Hue[0.6852387488220743], AbsoluteThickness[0.5], 
    LineBox[{{2.3774027449322745`, 2.4460874659795016`}, {2.1449739614400167`,
      2.4498261545879374`}}]}, 
   {Hue[0.68567336572643], AbsoluteThickness[0.5], 
    LineBox[{{2.1449739614400167`, 2.4498261545879374`}, {1.7862693127230944`,
      2.460335074068138}}]}, 
   {Hue[0.6455190091029734], AbsoluteThickness[0.5], 
    LineBox[{{3.6509433401480753`, -3.8289534845107482`}, {
     3.6148225092461583`, -3.8971832871165772`}}]}, 
   {Hue[0.6459481977119166], AbsoluteThickness[0.5], 
    LineBox[{{3.6148225092461583`, -3.8971832871165772`}, {
     3.467639999424477, -4.180833096573291}}]}, 
   {Hue[0.6431765673210558], AbsoluteThickness[0.5], 
    LineBox[{{5.895436561364092, 1.0374065415936127`}, {5.86977501560569, 
     1.101755676879179}}]}, 
   {Hue[0.6436697548062374], AbsoluteThickness[0.5], 
    LineBox[{{5.86977501560569, 1.101755676879179}, {5.729394268236789, 
     1.4201468737029062`}}]}, 
   {Hue[0.6787398703047548], AbsoluteThickness[0.5], 
    LineBox[{{6.105072394179704, -4.412171137558303}, {
     6.105077271853577, -4.412324595657479}}]}, 
   {Hue[0.6801356213819935], AbsoluteThickness[0.5], 
    LineBox[{{6.105077271853577, -4.412324595657479}, {
     6.082197316082534, -4.681430041973885}}]}, 
   {Hue[0.6979051603990498], AbsoluteThickness[0.5], 
    LineBox[{{2.1481056205562528`, -0.38311593307172065`}, {
     2.143534463942195, -0.3806144570064577}}]}, 
   {Hue[0.675688156322306], AbsoluteThickness[0.5], 
    LineBox[{{6.086569253477244, -0.7412527554813763}, {
     5.906279334722111, -0.7768365285283341}}]}, 
   {Hue[0.6764596093129805], AbsoluteThickness[0.5], 
    LineBox[{{5.906279334722111, -0.7768365285283341}, {
     5.641489580797917, -0.8083960713989804}}]}, 
   {Hue[0.6839298837732558], AbsoluteThickness[0.5], 
    LineBox[{{5.426541259644721, 2.065934742565875}, {5.164694259880715, 
     1.9713307506853344`}}]}, 
   {Hue[0.6844267870759435], AbsoluteThickness[0.5], 
    LineBox[{{5.164694259880715, 1.9713307506853344`}, {4.9258300772564905`, 
     1.8948270964345033`}}]}, 
   {Hue[0.5128684864643221], AbsoluteThickness[0.5], 
    LineBox[{{5.388520076657984, 3.385878785628368}, {5.283419825369215, 
     3.362732505823574}}]}, 
   {Hue[0.5140386298233255], AbsoluteThickness[0.5], 
    LineBox[{{5.283419825369215, 3.362732505823574}, {5.076077791663603, 
     3.2936003941103706`}}]}, 
   {Hue[0.6776633630975786], AbsoluteThickness[0.5], 
    LineBox[{{4.422011515505318, 1.3859235880992415`}, {4.364003306601121, 
     1.3833687322438328`}}]}, 
   {Hue[0.6789106862762645], AbsoluteThickness[0.5], 
    LineBox[{{4.364003306601121, 1.3833687322438328`}, {4.114235277994201, 
     1.3447827162102863`}}]}, 
   {Hue[0.47859820285430943`], AbsoluteThickness[0.5], 
    LineBox[{{3.364007264631872, 2.616810940022137}, {3.200778476617839, 
     2.573602384876503}}]}, 
   {Hue[0.47903934096537165`], AbsoluteThickness[0.5], 
    LineBox[{{3.200778476617839, 2.573602384876503}, {2.842309823463806, 
     2.4720223003655875`}}]}, 
   {Hue[0.6405741947541603], AbsoluteThickness[0.5], 
    LineBox[{{6.573063563436087, -2.093736882364953}, {
     6.613206470012671, -2.2949169291126905`}}]}, 
   {Hue[0.6413947952121926], AbsoluteThickness[0.5], 
    LineBox[{{6.613206470012671, -2.2949169291126905`}, {
     6.6480343454723725`, -2.5932862798191154`}}]}, 
   {Hue[0.610483322390653], AbsoluteThickness[0.5], 
    LineBox[{{5.058593017520518, 3.776664719922227}, {4.903767985557588, 
     3.8074686783891227`}}]}, 
   {Hue[0.6118434818812583], AbsoluteThickness[0.5], 
    LineBox[{{4.903767985557588, 3.8074686783891227`}, {4.669269810111314, 
     3.826618220068934}}]}, 
   {Hue[0.680942101532801], AbsoluteThickness[0.5], 
    LineBox[{{6.363313299837524, 3.7828795860321582`}, {6.575305357512666, 
     3.838885336068161}}]}, 
   {Hue[0.68236275489282], AbsoluteThickness[0.5], 
    LineBox[{{6.575305357512666, 3.838885336068161}, {6.839505665602181, 
     3.8762642674256416`}}]}, 
   {Hue[0.6889944115436654], AbsoluteThickness[0.5], 
    LineBox[{{6.563165695192667, 3.637566837745387}, {6.816301322354127, 
     3.497070000556156}}]}, 
   {Hue[0.68956572092626], AbsoluteThickness[0.5], 
    LineBox[{{6.816301322354127, 3.497070000556156}, {7.044150709903622, 
     3.38556790760162}}]}, 
   {Hue[0.5815921994101488], AbsoluteThickness[0.5], 
    LineBox[{{2.1059068156762986`, 2.8684345869358117`}, {2.1040979520341043`,
      2.868586452681623}}]}, 
   {Hue[0.583380314628358], AbsoluteThickness[0.5], 
    LineBox[{{2.1040979520341043`, 2.868586452681623}, {1.9146357314859304`, 
     2.910229791554978}}]}, 
   {Hue[0.6836776053777691], AbsoluteThickness[0.5], 
    LineBox[{{3.222844442345745, -3.1504590809045645`}, {
     3.113593937524018, -3.1353430921835903`}}]}, 
   {Hue[0.6849244629815782], AbsoluteThickness[0.5], 
    LineBox[{{3.113593937524018, -3.1353430921835903`}, {
     2.8451879450175266`, -3.067743475450773}}]}, 
   {Hue[0.5809722085551982], AbsoluteThickness[0.5], 
    LineBox[{{3.2579781696389736`, 3.4310528545764356`}, {3.1477861357240484`,
      3.48281103374636}}]}, 
   {Hue[0.5814027244940089], AbsoluteThickness[0.5], 
    LineBox[{{3.1477861357240484`, 3.48281103374636}, {2.8677569423408085`, 
     3.6110429943621583`}}]}, 
   {Hue[0.5981302916474279], AbsoluteThickness[0.5], 
    LineBox[{{3.81329675289589, -3.4359794003074002`}, {
     3.68857676226665, -3.4931330934397504`}}]}, 
   {Hue[0.5990656094744407], AbsoluteThickness[0.5], 
    LineBox[{{3.68857676226665, -3.4931330934397504`}, {
     3.4473776301586665`, -3.578380602195374}}]}, 
   {Hue[0.6876492095722685], AbsoluteThickness[0.5], 
    LineBox[{{3.3231849474947075`, 1.4904553901589366`}, {3.1334652069253366`,
      1.596651848810146}}]}, 
   {Hue[0.6920298707604274], AbsoluteThickness[0.5], 
    LineBox[{{3.1334652069253366`, 1.596651848810146}, {2.925471175618579, 
     1.6652444742117243`}}]}, 
   {Hue[0.5723580368777242], AbsoluteThickness[0.5], 
    LineBox[{{5.316083123754253, -2.490785981514291}, {
     5.274517536903772, -2.553141722064114}}]}, 
   {Hue[0.5729027932832914], AbsoluteThickness[0.5], 
    LineBox[{{5.274517536903772, -2.553141722064114}, {
     5.105106858343368, -2.8351197472964325`}}]}, 
   {Hue[0.5150114254596498], AbsoluteThickness[0.5], 
    LineBox[{{6.63605602614572, -3.3534171632238485`}, {
     6.602403466789067, -3.363124102296879}}]}, 
   {Hue[0.5155760534438071], AbsoluteThickness[0.5], 
    LineBox[{{6.602403466789067, -3.363124102296879}, {
     6.330477014401239, -3.4566588337003403`}}]}, 
   {Hue[0.24870203927615292`], AbsoluteThickness[0.5], 
    LineBox[{{7.636519825633674, -4.3997557798636215`}, {
     7.6361065802849915`, -4.402737955511791}}]}, 
   {Hue[0.24991741944343496`], AbsoluteThickness[0.5], 
    LineBox[{{7.6361065802849915`, -4.402737955511791}, {
     7.578650454369959, -4.632294647310723}}]}, 
   {Hue[0.6987846198327178], AbsoluteThickness[0.5], 
    LineBox[{{7.578650454369959, -4.632294647310723}, {
     7.3752506433840725`, -4.51135665474536}}]}, 
   {Hue[0.615976882800158], AbsoluteThickness[0.5], 
    LineBox[{{6.5868111235174345`, -3.180994345594259}, {
     6.554122213678761, -3.1726635294704755`}}]}, 
   {Hue[0.6176083596512774], AbsoluteThickness[0.5], 
    LineBox[{{6.554122213678761, -3.1726635294704755`}, {
     6.330273201475919, -3.084233645045451}}]}, 
   {Hue[0.6719416822919818], AbsoluteThickness[0.5], 
    LineBox[{{5.422932052604315, -1.4024156279624311`}, {
     5.366647752235769, -1.3850234890951951`}}]}, 
   {Hue[0.6725789480034283], AbsoluteThickness[0.5], 
    LineBox[{{5.366647752235769, -1.3850234890951951`}, {
     5.122296960163164, -1.2927802577618481`}}]}, 
   {Hue[0.6467841224355372], AbsoluteThickness[0.5], 
    LineBox[{{5.3665998235230825`, 0.6324780260583723}, {5.354847468700297, 
     0.656664078980306}}]}, 
   {Hue[0.6473479398011535], AbsoluteThickness[0.5], 
    LineBox[{{5.354847468700297, 0.656664078980306}, {5.217249152472406, 
     0.9069583244641133}}]}, 
   {Hue[0.409270188765198], AbsoluteThickness[0.5], 
    LineBox[{{6.378074229267231, -3.5698395154254845`}, {
     6.354368552127185, -3.679684384408264}}]}, 
   {Hue[0.41131495411397445`], AbsoluteThickness[0.5], 
    LineBox[{{6.354368552127185, -3.679684384408264}, {
     6.27805459079111, -3.8863051120724847`}}]}, 
   {Hue[0.6704538739679508], AbsoluteThickness[0.5], 
    LineBox[{{4.13621505978222, 0.2532000520910042}, {4.1079969825890466`, 
     0.16624360340906075`}}]}, 
   {Hue[0.6709133362912199], AbsoluteThickness[0.5], 
    LineBox[{{4.1079969825890466`, 0.16624360340906075`}, {
     4.001778120530808, -0.13466575758055604`}}]}, 
   {Hue[0.6566653291873564], AbsoluteThickness[0.5], 
    LineBox[{{2.8631060906611183`, -0.8977813353275388}, {
     2.664703095971386, -1.0037458897251024`}}]}, 
   {Hue[0.6571829521581071], AbsoluteThickness[0.5], 
    LineBox[{{2.664703095971386, -1.0037458897251024`}, {
     2.355399111003448, -1.1527815034408753`}}]}, 
   {Hue[0.5900080233933827], AbsoluteThickness[0.5], 
    LineBox[{{3.208398444011405, -3.908034963505968}, {
     3.1130322941040074`, -4.026997863677094}}]}, 
   {Hue[0.6236938789684776], AbsoluteThickness[0.5], 
    LineBox[{{3.1130322941040074`, -4.026997863677094}, {
     2.9766323013265974`, -4.109640788509894}}]}, 
   {Hue[0.6547439268592741], AbsoluteThickness[0.5], 
    LineBox[{{5.601452992647481, -3.801570333409129}, {
     5.549623641379269, -3.850099308309405}}]}, 
   {Hue[0.6555977602092351], AbsoluteThickness[0.5], 
    LineBox[{{5.549623641379269, -3.850099308309405}, {
     5.369236973353895, -4.049777755215899}}]}, 
   {Hue[0.6537301333565717], AbsoluteThickness[0.5], 
    LineBox[{{6.560170261217219, -3.7579656068956524`}, {
     6.1279170276264985`, -3.9952165706961997`}}]}, 
   {Hue[0.6544863141343169], AbsoluteThickness[0.5], 
    LineBox[{{6.1279170276264985`, -3.9952165706961997`}, {
     5.876700005491963, -4.109587573614218}}]}, 
   {Hue[0.6780450319115695], AbsoluteThickness[0.5], 
    LineBox[{{7.682288333499879, -3.415215211925911}, {
     7.709857047106748, -3.5559471645935004`}}]}, 
   {Hue[0.6784707779795246], AbsoluteThickness[0.5], 
    LineBox[{{7.709857047106748, -3.5559471645935004`}, {
     7.768051837438495, -3.853713923402574}}]}, 
   {Hue[0.5616448679793612], AbsoluteThickness[0.5], 
    LineBox[{{4.371704939386365, 2.968187018488044}, {4.046482379368974, 
     3.0597896378850935`}}]}, 
   {Hue[0.5659781630683778], AbsoluteThickness[0.5], 
    LineBox[{{4.046482379368974, 3.0597896378850935`}, {3.8792395325617983`, 
     3.0737943759012385`}}]}, 
   {Hue[0.5942299952474859], AbsoluteThickness[0.5], 
    LineBox[{{4.0785566914616975`, 2.2884212238763473`}, {3.5665918374189487`,
      2.374064447380978}}]}, 
   {Hue[0.5955193118077986], AbsoluteThickness[0.5], 
    LineBox[{{3.5665918374189487`, 2.374064447380978}, {3.325088824650425, 
     2.4427720213817374`}}]}, 
   {Hue[0.6160358029089198], AbsoluteThickness[0.5], 
    LineBox[{{5.865243833866334, 1.5475398119748}, {5.751829729396698, 
     1.4224109843551116`}}]}, 
   {Hue[0.6173549091110127], AbsoluteThickness[0.5], 
    LineBox[{{5.751829729396698, 1.4224109843551116`}, {5.58627051583668, 
     1.1921698692700742`}}]}, 
   {Hue[0.6541527599511825], AbsoluteThickness[0.5], 
    LineBox[{{8.203877537238544, 0.6123768695632916}, {8.167241237647522, 
     0.36570927175585033`}}]}, 
   {Hue[0.6548337715215764], AbsoluteThickness[0.5], 
    LineBox[{{8.167241237647522, 0.36570927175585033`}, {8.144084037570696, 
     0.07960360216599013}}]}, 
   {Hue[0.5674646031746786], AbsoluteThickness[0.5], 
    LineBox[{{6.0860977421364435`, 3.670815304287449}, {5.93953816833839, 
     3.6871813148463577`}}]}, 
   {Hue[0.5679808173309686], AbsoluteThickness[0.5], 
    LineBox[{{5.93953816833839, 3.6871813148463577`}, {5.609018875066696, 
     3.737956520294091}}]}, 
   {Hue[0.6118717004176599], AbsoluteThickness[0.5], 
    LineBox[{{6.363894699407268, 0.8922763450160127}, {6.3392056448044745`, 
     0.8567248382579394}}]}, 
   {Hue[0.6123693267899897], AbsoluteThickness[0.5], 
    LineBox[{{6.3392056448044745`, 0.8567248382579394}, {6.200909313866513, 
     0.6409987041066725}}]}, 
   {Hue[0.617106914996924], AbsoluteThickness[0.5], 
    LineBox[{{5.853882328904092, -0.01233832309157934}, {
     5.760612239048217, -0.15466563463854022`}}]}, 
   {Hue[0.6180121191355853], AbsoluteThickness[0.5], 
    LineBox[{{5.760612239048217, -0.15466563463854022`}, {
     5.651641558995951, -0.3577855591336413}}]}, 
   {Hue[0.6144935422100589], AbsoluteThickness[0.5], 
    LineBox[{{3.847750244652887, -1.0064953231888212`}, {
     3.162634862621722, -1.5769312055176912`}}]}, 
   {Hue[0.6201824936058925], AbsoluteThickness[0.5], 
    LineBox[{{3.162634862621722, -1.5769312055176912`}, {
     2.9872301075461047`, -1.6692179494102835`}}]}, 
   {Hue[0.5912893358884316], AbsoluteThickness[0.5], 
    LineBox[{{2.3700714185912735`, -3.0813403714260597`}, {
     2.369680233618288, -3.081731482734295}}]}, 
   {Hue[0.5917492323361757], AbsoluteThickness[0.5], 
    LineBox[{{2.369680233618288, -3.081731482734295}, {
     2.164649634246244, -3.2975457558168855`}}]}, 
   {Hue[0.6635315049000212], AbsoluteThickness[0.5], 
    LineBox[{{7.598569719547527, -2.0496986080475894`}, {
     7.539963498987111, -2.3914031738795485`}}]}, 
   {Hue[0.6639850440617336], AbsoluteThickness[0.5], 
    LineBox[{{7.539963498987111, -2.3914031738795485`}, {
     7.479925983373871, -2.6984484937166773`}}]}, 
   {Hue[0.620071862902054], AbsoluteThickness[0.5], 
    LineBox[{{6.00531478190308, 3.1820462490674384`}, {6.021485844885822, 
     3.3489501087046514`}}]}, 
   {Hue[0.6206563102973012], AbsoluteThickness[0.5], 
    LineBox[{{6.021485844885822, 3.3489501087046514`}, {6.032061240190912, 
     3.5953896284060005`}}]}, 
   {Hue[0.6829737202319657], AbsoluteThickness[0.5], 
    LineBox[{{3.7174847812183973`, 1.933392304515839}, {3.665819747043344, 
     1.9703871184995492`}}]}, 
   {Hue[0.6834870843002679], AbsoluteThickness[0.5], 
    LineBox[{{3.665819747043344, 1.9703871184995492`}, {3.454275235617676, 
     2.109232147061146}}]}, 
   {Hue[0.6931253438538318], AbsoluteThickness[0.5], 
    LineBox[{{6.160389044746029, 1.591261023567}, {6.1634760379368405`, 
     1.603310084490107}}]}, 
   {Hue[0.6938471586575259], AbsoluteThickness[0.5], 
    LineBox[{{6.1634760379368405`, 1.603310084490107}, {6.212352346572241, 
     1.8725490103011193`}}]}, 
   {Hue[0.6137783103000428], AbsoluteThickness[0.5], 
    LineBox[{{4.661636490741214, -3.915758867559659}, {
     4.6519794433194575`, -3.932199241757489}}]}, 
   {Hue[0.6144170680213242], AbsoluteThickness[0.5], 
    LineBox[{{4.6519794433194575`, -3.932199241757489}, {
     4.498553630528735, -4.160079156436329}}]}, 
   {Hue[0.5917928824804538], AbsoluteThickness[0.5], 
    LineBox[{{2.3612252664292828`, 2.0361321939973536`}, {2.1512440593909727`,
      2.0916537756023974`}}]}, 
   {Hue[0.5926492063519663], AbsoluteThickness[0.5], 
    LineBox[{{2.1512440593909727`, 2.0916537756023974`}, {1.9102958766228246`,
      2.134180923400093}}]}, 
   {Hue[0.5781842345841517], AbsoluteThickness[0.5], 
    LineBox[{{2.558538700417571, 0.2571005933905803}, {2.320538871550796, 
     0.2535570742537989}}]}, 
   {Hue[0.5786469070959548], AbsoluteThickness[0.5], 
    LineBox[{{2.320538871550796, 0.2535570742537989}, {2.0841563397549967`, 
     0.25635327038414235`}}]}, 
   {Hue[0.5784016857848824], AbsoluteThickness[0.5], 
    LineBox[{{2.557812057809007, 0.2430154891248253}, {2.318916002241808, 
     0.24666764402294822`}}]}, 
   {Hue[0.5788754012169058], AbsoluteThickness[0.5], 
    LineBox[{{2.318916002241808, 0.24666764402294822`}, {2.083972713750846, 
     0.2573987179929717}}]}, 
   {Hue[0.6050839435757002], AbsoluteThickness[0.5], 
    LineBox[{{2.5897873435991237`, 2.3798940547940144`}, {2.5742400829430463`,
      2.401114705920703}}]}, 
   {Hue[0.6055269517238427], AbsoluteThickness[0.5], 
    LineBox[{{2.5742400829430463`, 2.401114705920703}, {2.3966809809512295`, 
     2.65304727788272}}]}, 
   {Hue[0.5985500871681468], AbsoluteThickness[0.5], 
    LineBox[{{3.7734019201127045`, -3.4370980662274806`}, {
     3.682899079772362, -3.5122445822944375`}}]}, 
   {Hue[0.6024016965054317], AbsoluteThickness[0.5], 
    LineBox[{{3.682899079772362, -3.5122445822944375`}, {
     3.511643790788773, -3.608033984523073}}]}, 
   {Hue[0.6463773863208597], AbsoluteThickness[0.5], 
    LineBox[{{3.467639999424477, -4.180833096573291}, {
     3.454109492522924, -4.207443534163462}}]}, 
   {Hue[0.6483559930904349], AbsoluteThickness[0.5], 
    LineBox[{{3.454109492522924, -4.207443534163462}, {
     3.3203254589500304`, -4.3990531615889115`}}]}, 
   {Hue[0.6441629422914192], AbsoluteThickness[0.5], 
    LineBox[{{5.729394268236789, 1.4201468737029062`}, {5.670297635504438, 
     1.5421519003902968`}}]}, 
   {Hue[0.6503785516926416], AbsoluteThickness[0.5], 
    LineBox[{{5.670297635504438, 1.5421519003902968`}, {5.5795505048837954`, 
     1.6573188172433897`}}]}, 
   {Hue[0.6772310623036552], AbsoluteThickness[0.5], 
    LineBox[{{5.641489580797917, -0.8083960713989804}, {
     5.3458776026368175`, -0.8209345577486281}}]}, 
   {Hue[0.6778431539677282], AbsoluteThickness[0.5], 
    LineBox[{{5.3458776026368175`, -0.8209345577486281}, {
     5.071879052172968, -0.8167051736636017}}]}, 
   {Hue[0.6849236903786312], AbsoluteThickness[0.5], 
    LineBox[{{4.9258300772564905`, 1.8948270964345033`}, {4.76800341181704, 
     1.8506006622166002`}}]}, 
   {Hue[0.6875216850802432], AbsoluteThickness[0.5], 
    LineBox[{{4.76800341181704, 1.8506006622166002`}, {4.573042266991026, 
     1.7611825664215952`}}]}, 
   {Hue[0.5152087731823286], AbsoluteThickness[0.5], 
    LineBox[{{5.076077791663603, 3.2936003941103706`}, {4.941005148578677, 
     3.2321612598243865`}}]}, 
   {Hue[0.515859033249528], AbsoluteThickness[0.5], 
    LineBox[{{4.941005148578677, 3.2321612598243865`}, {4.663452447921007, 
     3.1264377225063056`}}]}, 
   {Hue[0.6801580094549503], AbsoluteThickness[0.5], 
    LineBox[{{4.114235277994201, 1.3447827162102863`}, {3.9461864886183435`, 
     1.2996213277125597`}}]}, 
   {Hue[0.6806193761953447], AbsoluteThickness[0.5], 
    LineBox[{{3.9461864886183435`, 1.2996213277125597`}, {3.6620246284607134`,
      1.2311992581724005`}}]}, 
   {Hue[0.479480479076434], AbsoluteThickness[0.5], 
    LineBox[{{2.842309823463806, 2.4720223003655875`}, {2.7027087750304672`, 
     2.4298324250371266`}}]}, 
   {Hue[0.5014715449617518], AbsoluteThickness[0.5], 
    LineBox[{{2.7027087750304672`, 2.4298324250371266`}, {2.5509313837721272`,
      2.3242297719080645`}}]}, 
   {Hue[0.6670955981371687], AbsoluteThickness[0.5], 
    LineBox[{{2.5509313837721272`, 2.3242297719080645`}, {2.5743682808585113`,
      2.1408203700224293`}}]}, 
   {Hue[0.642215395670225], AbsoluteThickness[0.5], 
    LineBox[{{6.6480343454723725`, -2.5932862798191154`}, {
     6.64930248288945, -2.6290413023626584`}}]}, 
   {Hue[0.6429253859892063], AbsoluteThickness[0.5], 
    LineBox[{{6.64930248288945, -2.6290413023626584`}, {
     6.679713870388628, -2.9164850240567985`}}]}, 
   {Hue[0.6132036413718635], AbsoluteThickness[0.5], 
    LineBox[{{4.669269810111314, 3.826618220068934}, {4.3446582922094725`, 
     3.815761376023612}}]}, 
   {Hue[0.6141403119336856], AbsoluteThickness[0.5], 
    LineBox[{{4.3446582922094725`, 3.815761376023612}, {4.097007775853238, 
     3.785019503396601}}]}, 
   {Hue[0.6837834082528389], AbsoluteThickness[0.5], 
    LineBox[{{6.839505665602181, 3.8762642674256416`}, {7.723992716432925, 
     3.896439919948688}}]}, 
   {Hue[0.6976345028986869], AbsoluteThickness[0.5], 
    LineBox[{{7.723992716432925, 3.896439919948688}, {7.895229065683388, 
     3.851990334449864}}]}, 
   {Hue[0.6901370303088548], AbsoluteThickness[0.5], 
    LineBox[{{7.044150709903622, 3.38556790760162}, {7.083772268272467, 
     3.3686516625601297`}}]}, 
   {Hue[0.6906391182448868], AbsoluteThickness[0.5], 
    LineBox[{{7.083772268272467, 3.3686516625601297`}, {7.380634759209041, 
     3.22834136662045}}]}, 
   {Hue[0.6861713205853871], AbsoluteThickness[0.5], 
    LineBox[{{2.8451879450175266`, -3.067743475450773}, {
     2.6175416334824604`, -2.983104837084421}}]}, 
   {Hue[0.6866419178743238], AbsoluteThickness[0.5], 
    LineBox[{{2.6175416334824604`, -2.983104837084421}, {
     2.337004740022085, -2.888084010719469}}]}, 
   {Hue[0.5818332404328196], AbsoluteThickness[0.5], 
    LineBox[{{2.8677569423408085`, 3.6110429943621583`}, {2.8313832186417134`,
      3.6272744925694633`}}]}, 
   {Hue[0.5824663281438901], AbsoluteThickness[0.5], 
    LineBox[{{2.8313832186417134`, 3.6272744925694633`}, {2.5431549862340614`,
      3.7774895693576154`}}]}, 
   {Hue[0.6000009273014535], AbsoluteThickness[0.5], 
    LineBox[{{3.4473776301586665`, -3.578380602195374}, {
     3.3670445595655645`, -3.59887244154362}}]}, 
   {Hue[0.6017040898563306], AbsoluteThickness[0.5], 
    LineBox[{{3.3670445595655645`, -3.59887244154362}, {
     3.124618154569795, -3.6954811176491287`}}]}, 
   {Hue[0.6964105319485866], AbsoluteThickness[0.5], 
    LineBox[{{2.925471175618579, 1.6652444742117243`}, {2.8885386905990935`, 
     1.6699527756876047`}}]}, 
   {Hue[0.697280514786844], AbsoluteThickness[0.5], 
    LineBox[{{2.8885386905990935`, 1.6699527756876047`}, {2.627973187196212, 
     1.7259580634615364`}}]}, 
   {Hue[0.5734475496888586], AbsoluteThickness[0.5], 
    LineBox[{{5.105106858343368, -2.8351197472964325`}, {
     5.094207938227012, -2.8553549460849927`}}]}, 
   {Hue[0.5738975162578613], AbsoluteThickness[0.5], 
    LineBox[{{5.094207938227012, -2.8553549460849927`}, {
     4.94141814614186, -3.1248428902306187`}}]}, 
   {Hue[0.5161406814279642], AbsoluteThickness[0.5], 
    LineBox[{{6.330477014401239, -3.4566588337003403`}, {
     6.172241886552621, -3.5201837842864836`}}]}, 
   {Hue[0.5167132840261002], AbsoluteThickness[0.5], 
    LineBox[{{6.172241886552621, -3.5201837842864836`}, {
     5.902908597610116, -3.6124258959823545`}}]}, 
   {Hue[0.697569239665438], AbsoluteThickness[0.5], 
    LineBox[{{7.6361065802849915`, -4.402737955511791}, {
     7.641272733044898, -4.4030567904482645`}}]}, 
   {Hue[0.7], AbsoluteThickness[0.5], 
    LineBox[{{7.3752506433840725`, -4.51135665474536}, {
     7.191359602035851, -4.373299324055335}}]}, 
   {Hue[0.6192398365023968], AbsoluteThickness[0.5], 
    LineBox[{{6.330273201475919, -3.084233645045451}, {
     6.180113705592881, -3.0016325961669272`}}]}, 
   {Hue[0.6198767694162256], AbsoluteThickness[0.5], 
    LineBox[{{6.180113705592881, -3.0016325961669272`}, {
     5.8871579411380655`, -2.8631096387050823`}}]}, 
   {Hue[0.673216213714875], AbsoluteThickness[0.5], 
    LineBox[{{5.122296960163164, -1.2927802577618481`}, {
     4.862206044598459, -1.175934652272195}}]}, 
   {Hue[0.6741571976670918], AbsoluteThickness[0.5], 
    LineBox[{{4.862206044598459, -1.175934652272195}, {
     4.611878719665567, -1.0896754395572406`}}]}, 
   {Hue[0.6479117571667697], AbsoluteThickness[0.5], 
    LineBox[{{5.217249152472406, 0.9069583244641133}, {5.16975010341641, 
     0.983915499111987}}]}, 
   {Hue[0.6500739058430289], AbsoluteThickness[0.5], 
    LineBox[{{5.16975010341641, 0.983915499111987}, {5.016331855624439, 
     1.1668596290369726`}}]}, 
   {Hue[0.4133597194627509], AbsoluteThickness[0.5], 
    LineBox[{{6.27805459079111, -3.8863051120724847`}, {
     6.137368900084763, -4.146883915613849}}]}, 
   {Hue[0.4174900386519021], AbsoluteThickness[0.5], 
    LineBox[{{6.137368900084763, -4.146883915613849}, {
     6.0702279906395455`, -4.358427042550493}}]}, 
   {Hue[0.6713727986144892], AbsoluteThickness[0.5], 
    LineBox[{{4.001778120530808, -0.1346657575805561}, {
     3.918390774960375, -0.35295939313358893`}}]}, 
   {Hue[0.6726857014583062], AbsoluteThickness[0.5], 
    LineBox[{{3.918390774960375, -0.35295939313358893`}, {
     3.8580950228875817`, -0.5868715160116167}}]}, 
   {Hue[0.6577005751288577], AbsoluteThickness[0.5], 
    LineBox[{{2.355399111003448, -1.1527815034408753`}, {
     2.3333889824288274`, -1.1622821161357915`}}]}, 
   {Hue[0.6583814226630962], AbsoluteThickness[0.5], 
    LineBox[{{2.3333889824288274`, -1.1622821161357915`}, {
     2.07868065332371, -1.292998541963801}}]}, 
   {Hue[0.6573797345435736], AbsoluteThickness[0.5], 
    LineBox[{{2.9766323013265974`, -4.109640788509894}, {
     2.882815220218921, -4.128114130816228}}]}, 
   {Hue[0.6585110161813221], AbsoluteThickness[0.5], 
    LineBox[{{2.882815220218921, -4.128114130816228}, {
     2.628858046163994, -4.205905940036988}}]}, 
   {Hue[0.656451593559196], AbsoluteThickness[0.5], 
    LineBox[{{5.369236973353895, -4.049777755215899}, {
     5.331966563871574, -4.098693530461543}}]}, 
   {Hue[0.6568794092401108], AbsoluteThickness[0.5], 
    LineBox[{{5.331966563871574, -4.098693530461543}, {
     5.152678549160744, -4.330902074618845}}]}, 
   {Hue[0.655242494912062], AbsoluteThickness[0.5], 
    LineBox[{{5.876700005491963, -4.109587573614218}, {
     5.860234153057911, -4.115644329843818}}]}, 
   {Hue[0.6559856724550522], AbsoluteThickness[0.5], 
    LineBox[{{5.860234153057911, -4.115644329843818}, {
     5.583819682012412, -4.241052336139848}}]}, 
   {Hue[0.6788965240474797], AbsoluteThickness[0.5], 
    LineBox[{{7.768051837438495, -3.853713923402574}, {
     7.831807546630773, -4.180700020232562}}]}, 
   {Hue[0.6823119930185452], AbsoluteThickness[0.5], 
    LineBox[{{7.831807546630773, -4.180700020232562}, {
     7.835259400430074, -4.375970716090762}}]}, 
   {Hue[0.5703114581573941], AbsoluteThickness[0.5], 
    LineBox[{{3.8792395325617983`, 3.0737943759012385`}, {3.6651145372869385`,
      3.050695405262259}}]}, 
   {Hue[0.5707418640028957], AbsoluteThickness[0.5], 
    LineBox[{{3.6651145372869385`, 3.050695405262259}, {3.3383127846329925`, 
     3.0122684797902095`}}]}, 
   {Hue[0.5968086283681112], AbsoluteThickness[0.5], 
    LineBox[{{3.325088824650425, 2.4427720213817374`}, {3.215225560483648, 
     2.4877527236932475`}}]}, 
   {Hue[0.5973203260016339], AbsoluteThickness[0.5], 
    LineBox[{{3.215225560483648, 2.4877527236932475`}, {2.8761440580221316`, 
     2.610903625647883}}]}, 
   {Hue[0.6186740153131055], AbsoluteThickness[0.5], 
    LineBox[{{5.58627051583668, 1.1921698692700742`}, {5.559190592265948, 
     1.143813164858145}}]}, 
   {Hue[0.6191333090253494], AbsoluteThickness[0.5], 
    LineBox[{{5.559190592265948, 1.143813164858145}, {5.405829701994144, 
     0.852797712718042}}]}, 
   {Hue[0.6555147830919702], AbsoluteThickness[0.5], 
    LineBox[{{8.144084037570696, 0.07960360216599013}, {8.143873103761997, 
     0.0646229278583765}}]}, 
   {Hue[0.6591364701501651], AbsoluteThickness[0.5], 
    LineBox[{{8.143873103761997, 0.0646229278583765}, {
     8.103958189965098, -0.13972375703737988`}}]}, 
   {Hue[0.5684970314872586], AbsoluteThickness[0.5], 
    LineBox[{{5.609018875066696, 3.737956520294091}, {5.406815934120762, 
     3.7776109709940773`}}]}, 
   {Hue[0.5689895791052532], AbsoluteThickness[0.5], 
    LineBox[{{5.406815934120762, 3.7776109709940773`}, {5.072332416479123, 
     3.8309077317622267`}}]}, 
   {Hue[0.6128669531623193], AbsoluteThickness[0.5], 
    LineBox[{{6.200909313866513, 0.6409987041066725}, {5.913032402155182, 
     0.15320270616340195`}}]}, 
   {Hue[0.6233656003289479], AbsoluteThickness[0.5], 
    LineBox[{{5.913032402155182, 0.15320270616340195`}, {
     5.85952773502239, -0.03427764055797869}}]}, 
   {Hue[0.6189173232742464], AbsoluteThickness[0.5], 
    LineBox[{{5.651641558995951, -0.3577855591336413}, {
     5.619286675242151, -0.4333186230332791}}]}, 
   {Hue[0.6195311911997513], AbsoluteThickness[0.5], 
    LineBox[{{5.619286675242151, -0.4333186230332791}, {
     5.4855941784570845`, -0.7012816483605044}}]}, 
   {Hue[0.6258714450017256], AbsoluteThickness[0.5], 
    LineBox[{{2.9872301075461047`, -1.6692179494102835`}, {
     2.8812810774368716`, -1.6990382684092682`}}]}, 
   {Hue[0.626300469471306], AbsoluteThickness[0.5], 
    LineBox[{{2.8812810774368716`, -1.6990382684092682`}, {
     2.56122147691468, -1.7863482638640393`}}]}, 
   {Hue[0.5922091287839198], AbsoluteThickness[0.5], 
    LineBox[{{2.164649634246244, -3.2975457558168855`}, {
     2.097441186182001, -3.3720339870463474`}}]}, 
   {Hue[0.5926362776152918], AbsoluteThickness[0.5], 
    LineBox[{{2.097441186182001, -3.3720339870463474`}, {
     1.883223223119023, -3.6069504926856597`}}]}, 
   {Hue[0.6644385832234461], AbsoluteThickness[0.5], 
    LineBox[{{7.479925983373871, -2.6984484937166773`}, {
     7.438987787970335, -2.8847224613941167`}}]}, 
   {Hue[0.6695894521412571], AbsoluteThickness[0.5], 
    LineBox[{{7.438987787970335, -2.8847224613941167`}, {
     7.436863219229152, -3.0437816184361615`}}]}, 
   {Hue[0.6840004483685702], AbsoluteThickness[0.5], 
    LineBox[{{3.454275235617676, 2.109232147061146}, {3.4210869847055423`, 
     2.1291361066887697`}}]}, 
   {Hue[0.684440386832504], AbsoluteThickness[0.5], 
    LineBox[{{3.4210869847055423`, 2.1291361066887697`}, {3.148286399563912, 
     2.298989925148061}}]}, 
   {Hue[0.6945689734612199], AbsoluteThickness[0.5], 
    LineBox[{{6.212352346572241, 1.8725490103011193`}, {6.233432099552451, 
     2.066336540955686}}]}, 
   {Hue[0.6950603873095871], AbsoluteThickness[0.5], 
    LineBox[{{6.233432099552451, 2.066336540955686}, {6.256045126880962, 
     2.375543237820618}}]}, 
   {Hue[0.6150558257426056], AbsoluteThickness[0.5], 
    LineBox[{{4.498553630528735, -4.160079156436329}, {
     4.4252584845782055`, -4.255692929372476}}]}, 
   {Hue[0.6258856928579835], AbsoluteThickness[0.5], 
    LineBox[{{4.4252584845782055`, -4.255692929372476}, {
     4.285593852353766, -4.363915230161777}}]}, 
   {Hue[0.6059699598719852], AbsoluteThickness[0.5], 
    LineBox[{{2.3966809809512295`, 2.65304727788272}, {2.329063342915174, 
     2.752831145511126}}]}, 
   {Hue[0.6072579128897938], AbsoluteThickness[0.5], 
    LineBox[{{2.329063342915174, 2.752831145511126}, {2.194783614726052, 
     2.910032724822234}}]}, 
   {Hue[0.6062533058427166], AbsoluteThickness[0.5], 
    LineBox[{{3.511643790788773, -3.608033984523073}, {
     3.419126371310883, -3.6394145484467293`}}]}, 
   {Hue[0.6068133294527888], AbsoluteThickness[0.5], 
    LineBox[{{3.419126371310883, -3.6394145484467293`}, {
     3.114662662000749, -3.759854016747528}}]}, 
   {Hue[0.6503345998600102], AbsoluteThickness[0.5], 
    LineBox[{{3.3203254589500304`, -4.3990531615889115`}, {
     3.152294307597612, -4.579910546560488}}]}, 
   {Hue[0.6597305760820218], AbsoluteThickness[0.5], 
    LineBox[{{3.152294307597612, -4.579910546560488}, {
     2.992391446336379, -4.683635291843589}}]}, 
   {Hue[0.6565941610938636], AbsoluteThickness[0.5], 
    LineBox[{{5.5795505048837954`, 1.6573188172433897`}, {5.159319128322754, 
     2.0021451788823303`}}]}, 
   {Hue[0.6594333137950852], AbsoluteThickness[0.5], 
    LineBox[{{5.159319128322754, 2.0021451788823303`}, {5.005823334483316, 
     2.0909556501450908`}}]}, 
   {Hue[0.6784552456318015], AbsoluteThickness[0.5], 
    LineBox[{{5.071879052172968, -0.8167051736636017}, {
     4.892224181240236, -0.8035202285650993}}]}, 
   {Hue[0.6792400556029414], AbsoluteThickness[0.5], 
    LineBox[{{4.892224181240236, -0.8035202285650993}, {
     4.628306730757011, -0.7634270326783655}}]}, 
   {Hue[0.6901196797818554], AbsoluteThickness[0.5], 
    LineBox[{{4.573042266991026, 1.7611825664215952`}, {4.42883236923765, 
     1.6652873922492355`}}]}, 
   {Hue[0.6958532720927347], AbsoluteThickness[0.5], 
    LineBox[{{4.42883236923765, 1.6652873922492355`}, {4.240236615204624, 
     1.5907685055712155`}}]}, 
   {Hue[0.5165092933167272], AbsoluteThickness[0.5], 
    LineBox[{{4.663452447921007, 3.1264377225063056`}, {4.630146534350739, 
     3.116098429872871}}]}, 
   {Hue[0.5172654178207498], AbsoluteThickness[0.5], 
    LineBox[{{4.630146534350739, 3.116098429872871}, {4.370184362598746, 
     3.013546462551577}}]}, 
   {Hue[0.6810807429357391], AbsoluteThickness[0.5], 
    LineBox[{{3.6620246284607134`, 1.2311992581724005`}, {3.3737901675549193`,
      1.1697526918361003`}}]}, 
   {Hue[0.6855507626113941], AbsoluteThickness[0.5], 
    LineBox[{{3.3737901675549193`, 1.1697526918361003`}, {3.196285666420612, 
     1.1667526710789817`}}]}, 
   {Hue[0.6451045322518492], AbsoluteThickness[0.5], 
    LineBox[{{2.7027087750304672`, 2.4298324250371266`}, {2.624591507391078, 
     2.4430594071854035`}}]}, 
   {Hue[0.6457692801982421], AbsoluteThickness[0.5], 
    LineBox[{{2.624591507391078, 2.4430594071854035`}, {2.3497619955451237`, 
     2.5081266920586667`}}]}, 
   {Hue[0.5234626108470694], AbsoluteThickness[0.5], 
    LineBox[{{2.5509313837721272`, 2.3242297719080645`}, {2.220812709559426, 
     1.8886424271863747`}}]}, 
   {Hue[0.5308775730390421], AbsoluteThickness[0.5], 
    LineBox[{{2.220812709559426, 1.8886424271863747`}, {2.155982166552086, 
     1.743252767387788}}]}, 
   {Hue[0.689086664022486], AbsoluteThickness[0.5], 
    LineBox[{{2.5743682808585113`, 2.1408203700224293`}, {2.686609437636592, 
     1.9033239220612217`}}]}, 
   {Hue[0.6895331681455336], AbsoluteThickness[0.5], 
    LineBox[{{2.686609437636592, 1.9033239220612217`}, {2.8234263113386255`, 
     1.62829297925702}}]}, 
   {Hue[0.6436353763081878], AbsoluteThickness[0.5], 
    LineBox[{{6.679713870388628, -2.9164850240567985`}, {
     6.706695241011244, -3.068765498350697}}]}, 
   {Hue[0.6440634384144088], AbsoluteThickness[0.5], 
    LineBox[{{6.706695241011244, -3.068765498350697}, {
     6.766335571264554, -3.3925920362655293`}}]}, 
   {Hue[0.6150769824955077], AbsoluteThickness[0.5], 
    LineBox[{{4.097007775853238, 3.785019503396601}, {3.9465907089069914`, 
     3.7523971996192795`}}]}, 
   {Hue[0.6156578252059681], AbsoluteThickness[0.5], 
    LineBox[{{3.9465907089069914`, 3.7523971996192795`}, {3.657510666430413, 
     3.705615186713733}}]}, 
   {Hue[0.6911412061809189], AbsoluteThickness[0.5], 
    LineBox[{{7.380634759209041, 3.22834136662045}, {7.851005702397375, 
     2.983741251592138}}]}, 
   {Hue[0.6927826584293001], AbsoluteThickness[0.5], 
    LineBox[{{7.851005702397375, 2.983741251592138}, {8.069834730998416, 
     2.903253753155572}}]}, 
   {Hue[0.6871125151632603], AbsoluteThickness[0.5], 
    LineBox[{{2.337004740022085, -2.888084010719469}, {
     2.278063243711737, -2.870031726967242}}]}, 
   {Hue[0.6950737225365772], AbsoluteThickness[0.5], 
    LineBox[{{2.278063243711737, -2.870031726967242}, {
     2.1127472606405044`, -2.772834413098602}}]}, 
   {Hue[0.6034072524112077], AbsoluteThickness[0.5], 
    LineBox[{{3.124618154569795, -3.6954811176491287`}, {
     2.947789111272303, -3.7940852995471093`}}]}, 
   {Hue[0.6135640898879766], AbsoluteThickness[0.5], 
    LineBox[{{2.947789111272303, -3.7940852995471093`}, {
     2.8183345497840113`, -3.9174458131592194`}}]}, 
   {Hue[0.6981504976251014], AbsoluteThickness[0.5], 
    LineBox[{{2.627973187196212, 1.7259580634615364`}, {2.423210210071237, 
     1.7885439881159926`}}]}, 
   {Hue[0.6987391596057382], AbsoluteThickness[0.5], 
    LineBox[{{2.423210210071237, 1.7885439881159926`}, {2.177729415183039, 
     1.849209950953191}}]}, 
   {Hue[0.5743474828268639], AbsoluteThickness[0.5], 
    LineBox[{{4.94141814614186, -3.1248428902306187`}, {
     4.905811902637747, -3.184582733620197}}]}, 
   {Hue[0.5750117439954565], AbsoluteThickness[0.5], 
    LineBox[{{4.905811902637747, -3.184582733620197}, {
     4.737718276326208, -3.4291424024345223`}}]}, 
   {Hue[0.5172858866242362], AbsoluteThickness[0.5], 
    LineBox[{{5.902908597610116, -3.6124258959823545`}, {
     5.836056732582679, -3.631516448133172}}]}, 
   {Hue[0.5184432227861353], AbsoluteThickness[0.5], 
    LineBox[{{5.836056732582679, -3.631516448133172}, {
     5.6013965128924, -3.7259217716295816`}}]}, 
   {Hue[0.6205137023300547], AbsoluteThickness[0.5], 
    LineBox[{{5.8871579411380655`, -2.8631096387050823`}, {
     5.830976136303717, -2.840639454788858}}]}, 
   {Hue[0.6209484625075985], AbsoluteThickness[0.5], 
    LineBox[{{5.830976136303717, -2.840639454788858}, {
     5.570502934850762, -2.73241867240367}}]}, 
   {Hue[0.6750981816193087], AbsoluteThickness[0.5], 
    LineBox[{{4.611878719665567, -1.0896754395572406`}, {
     4.609019639436786, -1.0889713574610296`}}]}, 
   {Hue[0.6760436956866456], AbsoluteThickness[0.5], 
    LineBox[{{4.609019639436786, -1.0889713574610296`}, {
     4.362699336232393, -1.0040017256639195`}}]}, 
   {Hue[0.6522360545192882], AbsoluteThickness[0.5], 
    LineBox[{{5.016331855624439, 1.1668596290369726`}, {4.8671195896357045`, 
     1.299880453872274}}]}, 
   {Hue[0.6537503097418045], AbsoluteThickness[0.5], 
    LineBox[{{4.8671195896357045`, 1.299880453872274}, {4.7007791540461294`, 
     1.4152056476893038`}}]}, 
   {Hue[0.42162035784105345`], AbsoluteThickness[0.5], 
    LineBox[{{6.0702279906395455`, -4.358427042550493}, {
     6.067042966261702, -4.384928976925519}}]}, 
   {Hue[0.42216321754351704`], AbsoluteThickness[0.5], 
    LineBox[{{6.067042966261702, -4.384928976925519}, {
     6.012744551646769, -4.708623849938242}}]}, 
   {Hue[0.6739986043021232], AbsoluteThickness[0.5], 
    LineBox[{{3.8580950228875817`, -0.5868715160116167}, {
     3.8568886823986728`, -0.5954524895929534}}]}, 
   {Hue[0.6745163453189392], AbsoluteThickness[0.5], 
    LineBox[{{3.8568886823986728`, -0.5954524895929534}, {
     3.8040769309948566`, -0.8836759892358351}}]}, 
   {Hue[0.6590622701973347], AbsoluteThickness[0.5], 
    LineBox[{{2.07868065332371, -1.292998541963801}, {
     2.014802423155818, -1.3313599977243764`}}]}, 
   {Hue[0.6609679527858207], AbsoluteThickness[0.5], 
    LineBox[{{2.014802423155818, -1.3313599977243764`}, {
     1.8333635891759976`, -1.4773399295486607`}}]}, 
   {Hue[0.6596422978190709], AbsoluteThickness[0.5], 
    LineBox[{{2.628858046163994, -4.205905940036988}, {
     2.361131640507422, -4.319119774809319}}]}, 
   {Hue[0.660614144423142], AbsoluteThickness[0.5], 
    LineBox[{{2.361131640507422, -4.319119774809319}, {
     2.09715227973593, -4.402942365763785}}]}, 
   {Hue[0.6573072249210256], AbsoluteThickness[0.5], 
    LineBox[{{5.152678549160744, -4.330902074618845}, {
     5.099821864889055, -4.3984618606201105`}}]}, 
   {Hue[0.6577672104833211], AbsoluteThickness[0.5], 
    LineBox[{{5.099821864889055, -4.3984618606201105`}, {
     4.894558997420646, -4.647345039868695}}]}, 
   {Hue[0.6567288499980425], AbsoluteThickness[0.5], 
    LineBox[{{5.583819682012412, -4.241052336139848}, {
     5.454164653513313, -4.311777067449056}}]}, 
   {Hue[0.6730982405800405], AbsoluteThickness[0.5], 
    LineBox[{{5.454164653513313, -4.311777067449056}, {
     5.323141578390029, -4.443889024797092}}]}, 
   {Hue[0.6857274619896107], AbsoluteThickness[0.5], 
    LineBox[{{7.835259400430074, -4.375970716090762}, {
     7.82530017021974, -4.438796580482471}}]}, 
   {Hue[0.5711722698483972], AbsoluteThickness[0.5], 
    LineBox[{{3.3383127846329925`, 3.0122684797902095`}, {3.194450521626693, 
     2.99395259111638}}]}, 
   {Hue[0.5717657970010758], AbsoluteThickness[0.5], 
    LineBox[{{3.194450521626693, 2.99395259111638}, {2.9014937284106432`, 
     2.972960316153997}}]}, 
   {Hue[0.5978320236351565], AbsoluteThickness[0.5], 
    LineBox[{{2.8761440580221316`, 2.610903625647883}, {2.8235155400785286`, 
     2.627654609953043}}]}, 
   {Hue[0.5986769571928734], AbsoluteThickness[0.5], 
    LineBox[{{2.8235155400785286`, 2.627654609953043}, {2.575209826279311, 
     2.7300100936667957`}}]}, 
   {Hue[0.6195926027375932], AbsoluteThickness[0.5], 
    LineBox[{{5.405829701994144, 0.852797712718042}, {5.383836993860866, 
     0.8083538778455381}}]}, 
   {Hue[0.6208805184581085], AbsoluteThickness[0.5], 
    LineBox[{{5.383836993860866, 0.8083538778455381}, {5.253750846516375, 
     0.6057895787427856}}]}, 
   {Hue[0.66275815720836], AbsoluteThickness[0.5], 
    LineBox[{{8.103958189965098, -0.13972375703737983`}, {
     8.00497235087721, -0.39363438392764216`}}]}, 
   {Hue[0.6631839125619925], AbsoluteThickness[0.5], 
    LineBox[{{8.00497235087721, -0.39363438392764216`}, {
     7.8986295729737686`, -0.6659219199745012}}]}, 
   {Hue[0.5694821267232478], AbsoluteThickness[0.5], 
    LineBox[{{5.072332416479123, 3.8309077317622267`}, {4.845325654548789, 
     3.8588259974866994`}}]}, 
   {Hue[0.5802265981574342], AbsoluteThickness[0.5], 
    LineBox[{{4.845325654548789, 3.8588259974866994`}, {4.679212555270891, 
     3.836337656642519}}]}, 
   {Hue[0.6338642474955763], AbsoluteThickness[0.5], 
    LineBox[{{5.85952773502239, -0.03427764055797866}, {
     5.856050880580548, -0.18644712140656813`}}]}, 
   {Hue[0.6348671952695317], AbsoluteThickness[0.5], 
    LineBox[{{5.856050880580548, -0.18644712140656813`}, {
     5.829570253584054, -0.4105998318282503}}]}, 
   {Hue[0.6201450591252564], AbsoluteThickness[0.5], 
    LineBox[{{5.4855941784570845`, -0.7012816483605044}, {
     5.229606407345793, -1.1474824384836448`}}]}, 
   {Hue[0.6214431936991096], AbsoluteThickness[0.5], 
    LineBox[{{5.229606407345793, -1.1474824384836448`}, {
     5.139881216779003, -1.3544952087281594`}}]}, 
   {Hue[0.6267294939408864], AbsoluteThickness[0.5], 
    LineBox[{{2.56122147691468, -1.7863482638640393`}, {
     2.501990675895027, -1.8019949519473097`}}]}, 
   {Hue[0.6333927584392878], AbsoluteThickness[0.5], 
    LineBox[{{2.501990675895027, -1.8019949519473097`}, {
     2.3317863595211987`, -1.8905090406046374`}}]}, 
   {Hue[0.6747403210590683], AbsoluteThickness[0.5], 
    LineBox[{{7.436863219229152, -3.0437816184361615`}, {
     7.501851426066027, -3.382388630636445}}]}, 
   {Hue[0.6752296368033254], AbsoluteThickness[0.5], 
    LineBox[{{7.501851426066027, -3.382388630636445}, {
     7.547238644384257, -3.673198281822919}}]}, 
   {Hue[0.6848803252964379], AbsoluteThickness[0.5], 
    LineBox[{{3.148286399563912, 2.298989925148061}, {3.102952674426591, 
     2.328276025568259}}]}, 
   {Hue[0.6856786539996974], AbsoluteThickness[0.5], 
    LineBox[{{3.102952674426591, 2.328276025568259}, {2.842129590970372, 
     2.5275114169878106`}}]}, 
   {Hue[0.6955518011579541], AbsoluteThickness[0.5], 
    LineBox[{{6.256045126880962, 2.375543237820618}, {6.265265223955792, 
     2.620296145762882}}]}, 
   {Hue[0.6961219692540669], AbsoluteThickness[0.5], 
    LineBox[{{6.265265223955792, 2.620296145762882}, {6.29260024058567, 
     2.9264377333669502`}}]}, 
   {Hue[0.6367155599733613], AbsoluteThickness[0.5], 
    LineBox[{{4.285593852353766, -4.363915230161777}, {
     4.1673234447795044`, -4.414154896953917}}]}, 
   {Hue[0.6371589317010158], AbsoluteThickness[0.5], 
    LineBox[{{4.1673234447795044`, -4.414154896953917}, {
     3.877000673008314, -4.543892382096527}}]}, 
   {Hue[0.6085458659076024], AbsoluteThickness[0.5], 
    LineBox[{{2.194783614726052, 2.910032724822234}, {2.155458978696683, 
     2.946852742709985}}]}, 
   {Hue[0.6092682406450552], AbsoluteThickness[0.5], 
    LineBox[{{2.155458978696683, 2.946852742709985}, {1.9746944120451517`, 
     3.0933981261057175`}}]}, 
   {Hue[0.6073733530628611], AbsoluteThickness[0.5], 
    LineBox[{{3.114662662000749, -3.759854016747528}, {
     3.0251032422339525`, -3.800535091992928}}]}, 
   {Hue[0.6088768522877608], AbsoluteThickness[0.5], 
    LineBox[{{3.0251032422339525`, -3.800535091992928}, {
     2.81646350964426, -3.927817048425796}}]}, 
   {Hue[0.6622724664963068], AbsoluteThickness[0.5], 
    LineBox[{{5.005823334483316, 2.0909556501450908`}, {4.845897753502258, 
     2.151498419925102}}]}, 
   {Hue[0.6628378395344154], AbsoluteThickness[0.5], 
    LineBox[{{4.845897753502258, 2.151498419925102}, {4.57365095573567, 
     2.2706328214567733`}}]}, 
   {Hue[0.6800248655740815], AbsoluteThickness[0.5], 
    LineBox[{{4.628306730757011, -0.7634270326783655}, {
     4.413304438100673, -0.7134785866420572}}]}, 
   {Hue[0.6809318760548666], AbsoluteThickness[0.5], 
    LineBox[{{4.413304438100673, -0.7134785866420572}, {
     4.153091612947505, -0.6766951774244456}}]}, 
   {Hue[0.518021542324772], AbsoluteThickness[0.5], 
    LineBox[{{4.370184362598746, 3.013546462551577}, {4.261025180561499, 
     2.960750629307671}}]}, 
   {Hue[0.5254805607842505], AbsoluteThickness[0.5], 
    LineBox[{{4.261025180561499, 2.960750629307671}, {4.113062125721776, 
     2.8410994544730372`}}]}, 
   {Hue[0.6900207822870491], AbsoluteThickness[0.5], 
    LineBox[{{3.196285666420612, 1.1667526710789817`}, {2.93477854736326, 
     1.213323705151558}}]}, 
   {Hue[0.6904583390839243], AbsoluteThickness[0.5], 
    LineBox[{{2.93477854736326, 1.213323705151558}, {2.5906446920067316`, 
     1.2692194079206218`}}]}, 
   {Hue[0.646434028144635], AbsoluteThickness[0.5], 
    LineBox[{{2.3497619955451237`, 2.5081266920586667`}, {2.1091828631712266`,
      2.581813788512502}}]}, 
   {Hue[0.6489386013159463], AbsoluteThickness[0.5], 
    LineBox[{{2.1091828631712266`, 2.581813788512502}, {1.8597472715506411`, 
     2.6176782062606168`}}]}, 
   {Hue[0.538292535231015], AbsoluteThickness[0.5], 
    LineBox[{{2.155982166552086, 1.743252767387788}, {2.139986294249428, 
     1.6602469179786605`}}]}, 
   {Hue[0.5392231593826425], AbsoluteThickness[0.5], 
    LineBox[{{2.139986294249428, 1.6602469179786605`}, {2.053315063481586, 
     1.35883399904892}}]}, 
   {Hue[0.6899796722685813], AbsoluteThickness[0.5], 
    LineBox[{{2.8234263113386255`, 1.62829297925702}, {2.8409394852054657`, 
     1.5947955392058368`}}]}, 
   {Hue[0.6907004268914275], AbsoluteThickness[0.5], 
    LineBox[{{2.8409394852054657`, 1.5947955392058368`}, {3.0025908777993844`,
      1.3328154212022882`}}]}, 
   {Hue[0.64449150052063], AbsoluteThickness[0.5], 
    LineBox[{{6.766335571264554, -3.3925920362655293`}, {
     6.806042945714155, -3.6002853011547113`}}]}, 
   {Hue[0.6453564544605941], AbsoluteThickness[0.5], 
    LineBox[{{6.806042945714155, -3.6002853011547113`}, {
     6.837097588520956, -3.89667219203488}}]}, 
   {Hue[0.6162386679164286], AbsoluteThickness[0.5], 
    LineBox[{{3.657510666430413, 3.705615186713733}, {3.3333502112551594`, 
     3.6706960510111015`}}]}, 
   {Hue[0.6175271172417599], AbsoluteThickness[0.5], 
    LineBox[{{3.3333502112551594`, 3.6706960510111015`}, {3.088532055457694, 
     3.6716939140993996`}}]}, 
   {Hue[0.6944241106776814], AbsoluteThickness[0.5], 
    LineBox[{{8.069834730998416, 2.903253753155572}, {8.125073154968366, 
     2.890589348745979}}]}, 
   {Hue[0.695409897963139], AbsoluteThickness[0.5], 
    LineBox[{{8.125073154968366, 2.890589348745979}, {8.413902000532918, 
     2.795212123577022}}]}, 
   {Hue[0.6237209273647458], AbsoluteThickness[0.5], 
    LineBox[{{2.8183345497840113`, -3.9174458131592194`}, {
     2.689504808801506, -4.124364946064878}}]}, 
   {Hue[0.6310874609445127], AbsoluteThickness[0.5], 
    LineBox[{{2.689504808801506, -4.124364946064878}, {
     2.6276937961685234`, -4.305836056254799}}]}, 
   {Hue[0.575676005164049], AbsoluteThickness[0.5], 
    LineBox[{{4.737718276326208, -3.4291424024345223`}, {
     4.2490068373104215`, -4.050003381217375}}]}, 
   {Hue[0.5772722440513788], AbsoluteThickness[0.5], 
    LineBox[{{4.2490068373104215`, -4.050003381217375}, {
     4.124975212739056, -4.2561799973583465`}}]}, 
   {Hue[0.5196005589480345], AbsoluteThickness[0.5], 
    LineBox[{{5.6013965128924, -3.7259217716295816`}, {
     5.446404079627086, -3.807961785869586}}]}, 
   {Hue[0.5204508919765048], AbsoluteThickness[0.5], 
    LineBox[{{5.446404079627086, -3.807961785869586}, {
     5.198713755372594, -3.9137148666865302`}}]}, 
   {Hue[0.6213832226851423], AbsoluteThickness[0.5], 
    LineBox[{{5.570502934850762, -2.73241867240367}, {
     5.398343799840194, -2.6581882952912936`}}]}, 
   {Hue[0.6227593195618183], AbsoluteThickness[0.5], 
    LineBox[{{5.398343799840194, -2.6581882952912936`}, {
     5.138154162253719, -2.580142940067291}}]}, 
   {Hue[0.6769892097539826], AbsoluteThickness[0.5], 
    LineBox[{{4.362699336232393, -1.0040017256639195`}, {
     4.125280173437909, -0.8971525226930763}}]}, 
   {Hue[0.684883283598883], AbsoluteThickness[0.5], 
    LineBox[{{4.125280173437909, -0.8971525226930763}, {
     3.9413433415860735`, -0.8619285824689742}}]}, 
   {Hue[0.6552645649643206], AbsoluteThickness[0.5], 
    LineBox[{{4.7007791540461294`, 1.4152056476893038`}, {4.663166651197154, 
     1.43499553308856}}]}, 
   {Hue[0.6557753603616946], AbsoluteThickness[0.5], 
    LineBox[{{4.663166651197154, 1.43499553308856}, {4.434521530160174, 
     1.5438474417884844`}}]}, 
   {Hue[0.6750340863357553], AbsoluteThickness[0.5], 
    LineBox[{{3.8040769309948566`, -0.8836759892358351}, {
     3.7405296500131717`, -1.1641939357913857`}}]}, 
   {Hue[0.6760346462875257], AbsoluteThickness[0.5], 
    LineBox[{{3.7405296500131717`, -1.1641939357913857`}, {
     3.7122684356855578`, -1.3834478328394595`}}]}, 
   {Hue[0.6615859910272133], AbsoluteThickness[0.5], 
    LineBox[{{2.09715227973593, -4.402942365763785}, {
     1.8415148544618527`, -4.458730731076645}}]}, 
   {Hue[0.5723593241537542], AbsoluteThickness[0.5], 
    LineBox[{{2.9014937284106432`, 2.972960316153997}, {2.618330361114143, 
     2.9683062744779756`}}]}, 
   {Hue[0.5727924476996331], AbsoluteThickness[0.5], 
    LineBox[{{2.618330361114143, 2.9683062744779756`}, {2.302090429786014, 
     2.9669192639071915`}}]}, 
   {Hue[0.5995218907505903], AbsoluteThickness[0.5], 
    LineBox[{{2.575209826279311, 2.7300100936667957`}, {2.2883100617667496`, 
     2.8771328027190157`}}]}, 
   {Hue[0.6180245251430952], AbsoluteThickness[0.5], 
    LineBox[{{2.2883100617667496`, 2.8771328027190157`}, {2.153072683336735, 
     2.9008626175403442`}}]}, 
   {Hue[0.6221684341786239], AbsoluteThickness[0.5], 
    LineBox[{{5.253750846516375, 0.6057895787427856}, {5.173164022019684, 
     0.5065876285209723}}]}, 
   {Hue[0.6280269381518114], AbsoluteThickness[0.5], 
    LineBox[{{5.173164022019684, 0.5065876285209723}, {5.029421185709824, 
     0.3911760424463208}}]}, 
   {Hue[0.663609667915625], AbsoluteThickness[0.5], 
    LineBox[{{7.8986295729737686`, -0.6659219199745012}, {
     7.889727314646164, -0.6886746207862178}}]}, 
   {Hue[0.6649918660882471], AbsoluteThickness[0.5], 
    LineBox[{{7.889727314646164, -0.6886746207862178}, {
     7.782360783186844, -0.8904958288263762}}]}, 
   {Hue[0.5909710695916208], AbsoluteThickness[0.5], 
    LineBox[{{4.679212555270891, 3.836337656642519}, {4.377719346748182, 
     3.7118808732586457`}}]}, 
   {Hue[0.5915964359760861], AbsoluteThickness[0.5], 
    LineBox[{{4.377719346748182, 3.7118808732586457`}, {4.120969055438524, 
     3.6234149412160286`}}]}, 
   {Hue[0.6358701430434872], AbsoluteThickness[0.5], 
    LineBox[{{5.829570253584054, -0.41059983182825033`}, {
     5.794626746422052, -0.5726842219973607}}]}, 
   {Hue[0.6362961229182225], AbsoluteThickness[0.5], 
    LineBox[{{5.794626746422052, -0.5726842219973607}, {
     5.73144817577346, -0.8688872702311752}}]}, 
   {Hue[0.6227413282729628], AbsoluteThickness[0.5], 
    LineBox[{{5.139881216779003, -1.3544952087281594`}, {
     5.139042131826513, -1.3572357244189366`}}]}, 
   {Hue[0.6234296823709715], AbsoluteThickness[0.5], 
    LineBox[{{5.139042131826513, -1.3572357244189366`}, {
     5.047409115720155, -1.5972887981085437`}}]}, 
   {Hue[0.6400560229376889], AbsoluteThickness[0.5], 
    LineBox[{{2.3317863595211987`, -1.8905090406046374`}, {
     2.1828695146258026`, -2.0161554946129217`}}]}, 
   {Hue[0.6450525029304841], AbsoluteThickness[0.5], 
    LineBox[{{2.1828695146258026`, -2.0161554946129217`}, {
     1.9970164508298114`, -2.1176859496806686`}}]}, 
   {Hue[0.6757189525475824], AbsoluteThickness[0.5], 
    LineBox[{{7.547238644384257, -3.673198281822919}, {
     7.570943621574519, -3.869751682040838}}]}, 
   {Hue[0.6782514462010725], AbsoluteThickness[0.5], 
    LineBox[{{7.570943621574519, -3.869751682040838}, {
     7.565037997689859, -4.037865826435556}}]}, 
   {Hue[0.6864769827029568], AbsoluteThickness[0.5], 
    LineBox[{{2.842129590970372, 2.5275114169878106`}, {2.7620866827350263`, 
     2.5992981904978256`}}]}, 
   {Hue[0.6873542896392733], AbsoluteThickness[0.5], 
    LineBox[{{2.7620866827350263`, 2.5992981904978256`}, {2.5796147934313263`,
      2.793520369248785}}]}, 
   {Hue[0.6966921373501797], AbsoluteThickness[0.5], 
    LineBox[{{6.29260024058567, 2.9264377333669502`}, {6.312375930716081, 
     3.0663109522505594`}}]}, 
   {Hue[0.6972633620800761], AbsoluteThickness[0.5], 
    LineBox[{{6.312375930716081, 3.0663109522505594`}, {6.370741930476482, 
     3.36651378631305}}]}, 
   {Hue[0.6103803515126606], AbsoluteThickness[0.5], 
    LineBox[{{2.81646350964426, -3.927817048425796}, {
     2.6975020660027473`, -4.021908251090913}}]}, 
   {Hue[0.6110849693608073], AbsoluteThickness[0.5], 
    LineBox[{{2.6975020660027473`, -4.021908251090913}, {
     2.4557812924100024`, -4.18721664840607}}]}, 
   {Hue[0.6634032125725241], AbsoluteThickness[0.5], 
    LineBox[{{4.57365095573567, 2.2706328214567733`}, {4.501404066281681, 
     2.3067057775309916`}}]}, 
   {Hue[0.6670309392112448], AbsoluteThickness[0.5], 
    LineBox[{{4.501404066281681, 2.3067057775309916`}, {4.335525959192381, 
     2.43073132001656}}]}, 
   {Hue[0.6818388865356517], AbsoluteThickness[0.5], 
    LineBox[{{4.153091612947505, -0.6766951774244456}, {
     3.9249328368733427`, -0.6646851820281604}}]}, 
   {Hue[0.6825163490327856], AbsoluteThickness[0.5], 
    LineBox[{{3.9249328368733427`, -0.6646851820281604}, {
     3.648313195575461, -0.6684687323130577}}]}, 
   {Hue[0.5329395792437288], AbsoluteThickness[0.5], 
    LineBox[{{4.113062125721776, 2.8410994544730372`}, {3.9841851400728503`, 
     2.6754857923457904`}}]}, 
   {Hue[0.5349294753554265], AbsoluteThickness[0.5], 
    LineBox[{{3.9841851400728503`, 2.6754857923457904`}, {3.8609861131327574`,
      2.461208837307021}}]}, 
   {Hue[0.6908958958807994], AbsoluteThickness[0.5], 
    LineBox[{{2.5906446920067316`, 1.2692194079206218`}, {2.394219506984771, 
     1.298062249057746}}]}, 
   {Hue[0.6917600207124539], AbsoluteThickness[0.5], 
    LineBox[{{2.394219506984771, 1.298062249057746}, {2.1094726590127975`, 
     1.3155556839715625`}}]}, 
   {Hue[0.5401537835342701], AbsoluteThickness[0.5], 
    LineBox[{{2.053315063481586, 1.35883399904892}, {1.9798891975459203`, 
     1.1693103836665824`}}]}, 
   {Hue[0.5407559870746943], AbsoluteThickness[0.5], 
    LineBox[{{1.9798891975459203`, 1.1693103836665824`}, {1.8833428754513182`,
      0.8712216935182996}}]}, 
   {Hue[0.6914211815142738], AbsoluteThickness[0.5], 
    LineBox[{{3.0025908777993844`, 1.3328154212022882`}, {3.3461913553283225`,
      0.8555366631590129}}]}, 
   {Hue[0.6984566319516059], AbsoluteThickness[0.5], 
    LineBox[{{3.3461913553283225`, 0.8555366631590129}, {3.4151249407016033`, 
     0.6919159772886454}}]}, 
   {Hue[0.6462214084005582], AbsoluteThickness[0.5], 
    LineBox[{{6.837097588520956, -3.89667219203488}, {
     6.8389512070893534`, -3.989854965893774}}]}, 
   {Hue[0.6188155665670912], AbsoluteThickness[0.5], 
    LineBox[{{3.088532055457694, 3.6716939140993996`}, {3.0763558784626386`, 
     3.673106053700125}}]}, 
   {Hue[0.6271669678410373], AbsoluteThickness[0.5], 
    LineBox[{{3.0763558784626386`, 3.673106053700125}, {2.8994296066340493`, 
     3.651341539172758}}]}, 
   {Hue[0.6384539945242799], AbsoluteThickness[0.5], 
    LineBox[{{2.6276937961685234`, -4.305836056254799}, {
     2.6232771483079245`, -4.349991425194697}}]}, 
   {Hue[0.6389908636020804], AbsoluteThickness[0.5], 
    LineBox[{{2.6232771483079245`, -4.349991425194697}, {
     2.5765755981535894`, -4.6694875814119605`}}]}, 
   {Hue[0.5788684829387086], AbsoluteThickness[0.5], 
    LineBox[{{4.124975212739056, -4.2561799973583465`}, {
     4.084668598037623, -4.347341379505318}}]}, 
   {Hue[0.5792983622870927], AbsoluteThickness[0.5], 
    LineBox[{{4.084668598037623, -4.347341379505318}, {
     3.9578556332833443`, -4.641304200136824}}]}, 
   {Hue[0.5213012250049753], AbsoluteThickness[0.5], 
    LineBox[{{5.198713755372594, -3.9137148666865302`}, {
     5.141725221034689, -3.932614764995947}}]}, 
   {Hue[0.5217828840432578], AbsoluteThickness[0.5], 
    LineBox[{{5.141725221034689, -3.932614764995947}, {
     4.873467705799851, -4.031428934427787}}]}, 
   {Hue[0.6241354164384942], AbsoluteThickness[0.5], 
    LineBox[{{5.138154162253719, -2.580142940067291}, {
     5.076997328998445, -2.5692829171642573`}}]}, 
   {Hue[0.6249486383036809], AbsoluteThickness[0.5], 
    LineBox[{{5.076997328998445, -2.5692829171642573`}, {
     4.82959468392758, -2.504568980858765}}]}, 
   {Hue[0.6927773574437834], AbsoluteThickness[0.5], 
    LineBox[{{3.9413433415860735`, -0.8619285824689742}, {
     3.861498849545159, -0.865481771659957}}]}, 
   {Hue[0.6980414229752294], AbsoluteThickness[0.5], 
    LineBox[{{3.861498849545159, -0.865481771659957}, {
     3.6751918755879536`, -0.83540990396734}}]}, 
   {Hue[0.6562861557590687], AbsoluteThickness[0.5], 
    LineBox[{{4.434521530160174, 1.5438474417884844`}, {4.327568068576069, 
     1.5896095368075756`}}]}, 
   {Hue[0.6584451667731117], AbsoluteThickness[0.5], 
    LineBox[{{4.327568068576069, 1.5896095368075756`}, {4.123628078350912, 
     1.7143843200315325`}}]}, 
   {Hue[0.6770352062392961], AbsoluteThickness[0.5], 
    LineBox[{{3.7122684356855578`, -1.3834478328394595`}, {
     3.703124625833182, -1.6554399320421065`}}]}, 
   {Hue[0.6774611547802655], AbsoluteThickness[0.5], 
    LineBox[{{3.703124625833182, -1.6554399320421065`}, {
     3.6946216758012684`, -1.9247861187852957`}}]}, 
   {Hue[0.5732255712455119], AbsoluteThickness[0.5], 
    LineBox[{{2.302090429786014, 2.9669192639071915`}, {2.1582582874124108`, 
     2.968021410470173}}]}, 
   {Hue[0.5736526203989805], AbsoluteThickness[0.5], 
    LineBox[{{2.1582582874124108`, 2.968021410470173}, {1.897745588716595, 
     2.9713433834200074`}}]}, 
   {Hue[0.6365271595355999], AbsoluteThickness[0.5], 
    LineBox[{{2.153072683336735, 2.9008626175403442`}, {2.133943275543023, 
     2.8984309752053674`}}]}, 
   {Hue[0.6377493781323528], AbsoluteThickness[0.5], 
    LineBox[{{2.133943275543023, 2.8984309752053674`}, {1.925069544990799, 
     2.894564211763571}}]}, 
   {Hue[0.6338854421249989], AbsoluteThickness[0.5], 
    LineBox[{{5.029421185709824, 0.3911760424463208}, {4.86240269599251, 
     0.3074996338329848}}]}, 
   {Hue[0.6343483396849805], AbsoluteThickness[0.5], 
    LineBox[{{4.86240269599251, 0.3074996338329848}, {4.621918591572351, 
     0.19497339178338496`}}]}, 
   {Hue[0.6663740642608691], AbsoluteThickness[0.5], 
    LineBox[{{7.782360783186844, -0.8904958288263762}, {
     7.696872713598476, -1.0141571615525666`}}]}, 
   {Hue[0.674341857781786], AbsoluteThickness[0.5], 
    LineBox[{{7.696872713598476, -1.0141571615525666`}, {
     7.560432770807403, -1.1366432079208593`}}]}, 
   {Hue[0.5922218023605514], AbsoluteThickness[0.5], 
    LineBox[{{4.120969055438524, 3.6234149412160286`}, {4.119850961169349, 
     3.6231029124489322`}}]}, 
   {Hue[0.5927164741489547], AbsoluteThickness[0.5], 
    LineBox[{{4.119850961169349, 3.6231029124489322`}, {3.8477199795851145`, 
     3.5364320535421103`}}]}, 
   {Hue[0.6367221027929578], AbsoluteThickness[0.5], 
    LineBox[{{5.73144817577346, -0.8688872702311752}, {
     5.691389471964459, -1.0587358937261007`}}]}, 
   {Hue[0.6376549901561888], AbsoluteThickness[0.5], 
    LineBox[{{5.691389471964459, -1.0587358937261007`}, {
     5.659617149440272, -1.326368006638475}}]}, 
   {Hue[0.6241180364689801], AbsoluteThickness[0.5], 
    LineBox[{{5.047409115720155, -1.5972887981085437`}, {
     4.934606031394798, -1.8418398412210573`}}]}, 
   {Hue[0.6248430670406172], AbsoluteThickness[0.5], 
    LineBox[{{4.934606031394798, -1.8418398412210573`}, {
     4.83662343956195, -2.101668268175593}}]}, 
   {Hue[0.6807839398545624], AbsoluteThickness[0.5], 
    LineBox[{{7.565037997689859, -4.037865826435556}, {
     7.504999694985042, -4.349621665139881}}]}, 
   {Hue[0.6812865479793886], AbsoluteThickness[0.5], 
    LineBox[{{7.504999694985042, -4.349621665139881}, {
     7.461887260631291, -4.630841244592836}}]}, 
   {Hue[0.6882315965755897], AbsoluteThickness[0.5], 
    LineBox[{{2.5796147934313263`, 2.793520369248785}, {2.5397081893929077`, 
     2.8440252625433833`}}]}, 
   {Hue[0.6886731225730253], AbsoluteThickness[0.5], 
    LineBox[{{2.5397081893929077`, 2.8440252625433833`}, {2.3488402843029594`,
      3.0945086811412597`}}]}, 
   {Hue[0.6978345868099725], AbsoluteThickness[0.5], 
    LineBox[{{6.370741930476482, 3.36651378631305}, {6.37850017599803, 
     3.397729543481489}}]}, 
   {Hue[0.6984762881408121], AbsoluteThickness[0.5], 
    LineBox[{{6.37850017599803, 3.397729543481489}, {6.427116626096466, 
     3.662260879914916}}]}, 
   {Hue[0.6117895872089538], AbsoluteThickness[0.5], 
    LineBox[{{2.4557812924100024`, -4.18721664840607}, {
     2.3634226932042632`, -4.2413883409245585`}}]}, 
   {Hue[0.6123016935977258], AbsoluteThickness[0.5], 
    LineBox[{{2.3634226932042632`, -4.2413883409245585`}, {
     2.083750236513452, -4.390613265176297}}]}, 
   {Hue[0.6706586658499654], AbsoluteThickness[0.5], 
    LineBox[{{4.335525959192381, 2.43073132001656}, {3.9602131973284678`, 
     2.8337299157538816`}}]}, 
   {Hue[0.6717356618213554], AbsoluteThickness[0.5], 
    LineBox[{{3.9602131973284678`, 2.8337299157538816`}, {3.8289933008600086`,
      3.0062354060671397`}}]}, 
   {Hue[0.6831938115299195], AbsoluteThickness[0.5], 
    LineBox[{{3.648313195575461, -0.6684687323130577}, {
     3.612272507005883, -0.6713561277549156}}]}, 
   {Hue[0.6882668037495538], AbsoluteThickness[0.5], 
    LineBox[{{3.612272507005883, -0.6713561277549156}, {
     3.4093261156597907`, -0.6464794687618997}}]}, 
   {Hue[0.5369193714671241], AbsoluteThickness[0.5], 
    LineBox[{{3.8609861131327574`, 2.461208837307021}, {3.7986422479718414`, 
     2.3061580861753264`}}]}, 
   {Hue[0.5375299067352527], AbsoluteThickness[0.5], 
    LineBox[{{3.7986422479718414`, 2.3061580861753264`}, {3.694823613783175, 
     2.0855801900563278`}}]}, 
   {Hue[0.6355183691149829], AbsoluteThickness[0.5], 
    LineBox[{{2.8994296066340493`, 3.651341539172758}, {2.827593408170621, 
     3.6242809351390264`}}]}, 
   {Hue[0.649565218432362], AbsoluteThickness[0.5], 
    LineBox[{{2.827593408170621, 3.6242809351390264`}, {2.6363933295803497`, 
     3.608497443270168}}]}, 
   {Hue[0.5222645430815405], AbsoluteThickness[0.5], 
    LineBox[{{4.873467705799851, -4.031428934427787}, {
     4.6010458626957345`, -4.142022128062738}}]}, 
   {Hue[0.5666126235608324], AbsoluteThickness[0.5], 
    LineBox[{{4.6010458626957345`, -4.142022128062738}, {
     4.452881975076909, -4.143797962280964}}]}, 
   {Hue[0.6717245949310375], AbsoluteThickness[0.5], 
    LineBox[{{4.452881975076909, -4.143797962280964}, {
     4.375543802140372, -4.017407700835182}}]}, 
   {Hue[0.6257618601688675], AbsoluteThickness[0.5], 
    LineBox[{{4.82959468392758, -2.504568980858765}, {
     4.611312991987927, -2.428350925088355}}]}, 
   {Hue[0.6290134824906148], AbsoluteThickness[0.5], 
    LineBox[{{4.611312991987927, -2.428350925088355}, {
     4.414193336120299, -2.3956634771939345`}}]}, 
   {Hue[0.660604177787155], AbsoluteThickness[0.5], 
    LineBox[{{4.123628078350912, 1.7143843200315325`}, {4.006452686439459, 
     1.8118510558692065`}}]}, 
   {Hue[0.6650786086083813], AbsoluteThickness[0.5], 
    LineBox[{{4.006452686439459, 1.8118510558692065`}, {3.873544082268539, 
     1.9749507369537496`}}]}, 
   {Hue[0.6778871033212349], AbsoluteThickness[0.5], 
    LineBox[{{3.6946216758012684`, -1.9247861187852957`}, {
     3.6886389427681086`, -2.127452916334363}}]}, 
   {Hue[0.6796823895640738], AbsoluteThickness[0.5], 
    LineBox[{{3.6886389427681086`, -2.127452916334363}, {
     3.709252432867395, -2.326207544410299}}]}, 
   {Hue[0.6348112372449622], AbsoluteThickness[0.5], 
    LineBox[{{4.621918591572351, 0.19497339178338496`}, {4.586861305355816, 
     0.1797006945884271}}]}, 
   {Hue[0.6366395810849523], AbsoluteThickness[0.5], 
    LineBox[{{4.586861305355816, 0.1797006945884271}, {4.392936275623713, 
     0.062163983934530834`}}]}, 
   {Hue[0.6823096513027029], AbsoluteThickness[0.5], 
    LineBox[{{7.560432770807403, -1.1366432079208593`}, {
     7.405393113799459, -1.2207769065839444`}}]}, 
   {Hue[0.6827379911949967], AbsoluteThickness[0.5], 
    LineBox[{{7.405393113799459, -1.2207769065839444`}, {
     7.129144563105245, -1.3681341637309854`}}]}, 
   {Hue[0.5932111459373578], AbsoluteThickness[0.5], 
    LineBox[{{3.8477199795851145`, 3.5364320535421103`}, {3.68208887727915, 
     3.476999218293325}}]}, 
   {Hue[0.5937287658382807], AbsoluteThickness[0.5], 
    LineBox[{{3.68208887727915, 3.476999218293325}, {3.3811998923545006`, 
     3.382937141572555}}]}, 
   {Hue[0.6385878775194197], AbsoluteThickness[0.5], 
    LineBox[{{5.659617149440272, -1.326368006638475}, {
     5.657391835853586, -1.4047756711819437`}}]}, 
   {Hue[0.640106426686321], AbsoluteThickness[0.5], 
    LineBox[{{5.657391835853586, -1.4047756711819437`}, {
     5.6210234693403, -1.6447152563846366`}}]}, 
   {Hue[0.6255680976122543], AbsoluteThickness[0.5], 
    LineBox[{{4.83662343956195, -2.101668268175593}, {
     4.83203981609132, -2.117081896512566}}]}, 
   {Hue[0.6260066041989212], AbsoluteThickness[0.5], 
    LineBox[{{4.83203981609132, -2.117081896512566}, {
     4.744452596821478, -2.395425641223746}}]}, 
   {Hue[0.6891146485704608], AbsoluteThickness[0.5], 
    LineBox[{{2.3488402843029594`, 3.0945086811412597`}, {2.347270013265707, 
     3.0966463048562654`}}]}, 
   {Hue[0.689550436970743], AbsoluteThickness[0.5], 
    LineBox[{{2.347270013265707, 3.0966463048562654`}, {2.163891611647784, 
     3.353772454168395}}]}, 
   {Hue[0.6128137999864977], AbsoluteThickness[0.5], 
    LineBox[{{2.083750236513452, -4.390613265176297}, {
     2.0818837286868623`, -4.3915144828197015`}}]}, 
   {Hue[0.6135316887964962], AbsoluteThickness[0.5], 
    LineBox[{{2.0818837286868623`, -4.3915144828197015`}, {
     1.8260215575053518`, -4.5382259898298045`}}]}, 
   {Hue[0.6728126577927452], AbsoluteThickness[0.5], 
    LineBox[{{3.8289933008600086`, 3.0062354060671397`}, {3.7765228278271357`,
      3.091673131449505}}]}, 
   {Hue[0.6736027116481537], AbsoluteThickness[0.5], 
    LineBox[{{3.7765228278271357`, 3.091673131449505}, {3.641086781956351, 
     3.3564866281740193`}}]}, 
   {Hue[0.6933397959691883], AbsoluteThickness[0.5], 
    LineBox[{{3.4093261156597907`, -0.6464794687618997}, {
     3.1284986717101173`, -0.5522047003398768}}]}, 
   {Hue[0.6938380394921261], AbsoluteThickness[0.5], 
    LineBox[{{3.1284986717101173`, -0.5522047003398768}, {
     2.8451373127380495`, -0.44523689442215236`}}]}, 
   {Hue[0.5381404420033813], AbsoluteThickness[0.5], 
    LineBox[{{3.694823613783175, 2.0855801900563278`}, {3.6685460235298497`, 
     2.0371933279624574`}}]}, 
   {Hue[0.5398860562050014], AbsoluteThickness[0.5], 
    LineBox[{{3.6685460235298497`, 2.0371933279624574`}, {3.5527098568663935`,
      1.8778380147074196`}}]}, 
   {Hue[0.66361206774974], AbsoluteThickness[0.5], 
    LineBox[{{2.6363933295803497`, 3.608497443270168}, {2.6257509333240536`, 
     3.610605319625497}}]}, 
   {Hue[0.6702215355206235], AbsoluteThickness[0.5], 
    LineBox[{{2.6257509333240536`, 3.610605319625497}, {2.4184547503477853`, 
     3.6053863073266728`}}]}, 
   {Hue[0.62737651445175], AbsoluteThickness[0.5], 
    LineBox[{{4.6010458626957345`, -4.142022128062738}, {
     4.402163645312273, -4.300233152687785}}]}, 
   {Hue[0.6450259961869865], AbsoluteThickness[0.5], 
    LineBox[{{4.402163645312273, -4.300233152687785}, {
     4.2464330700440565`, -4.361660864604002}}]}, 
   {Hue[0.6109607040401267], AbsoluteThickness[0.5], 
    LineBox[{{4.452881975076909, -4.143797962280964}, {
     4.413063333559854, -4.128734316583912}}]}, 
   {Hue[0.6128020801129639], AbsoluteThickness[0.5], 
    LineBox[{{4.413063333559854, -4.128734316583912}, {
     4.184947904965205, -4.076001518252941}}]}, 
   {Hue[0.6322651048123624], AbsoluteThickness[0.5], 
    LineBox[{{4.414193336120299, -2.3956634771939345`}, {
     4.117090369021671, -2.397825746587586}}]}, 
   {Hue[0.6329989879153143], AbsoluteThickness[0.5], 
    LineBox[{{4.117090369021671, -2.397825746587586}, {
     3.827142598012918, -2.421004426369227}}]}, 
   {Hue[0.6695530394296076], AbsoluteThickness[0.5], 
    LineBox[{{3.873544082268539, 1.9749507369537496`}, {3.7941640592723096`, 
     2.1235764928139402`}}]}, 
   {Hue[0.6700474842206282], AbsoluteThickness[0.5], 
    LineBox[{{3.7941640592723096`, 2.1235764928139402`}, {3.665932076940217, 
     2.344110986775512}}]}, 
   {Hue[0.6814776758069124], AbsoluteThickness[0.5], 
    LineBox[{{3.709252432867395, -2.326207544410299}, {
     3.7752680928265736`, -2.6004821604179362`}}]}, 
   {Hue[0.6823115633664594], AbsoluteThickness[0.5], 
    LineBox[{{3.7752680928265736`, -2.6004821604179362`}, {
     3.8162838967296064`, -2.864195445094472}}]}, 
   {Hue[0.6384679249249424], AbsoluteThickness[0.5], 
    LineBox[{{4.392936275623713, 0.06216398393453079}, {
     4.236794957210889, -0.06382271625000727}}]}, 
   {Hue[0.642423018450641], AbsoluteThickness[0.5], 
    LineBox[{{4.236794957210889, -0.06382271625000727}, {
     4.08712016576028, -0.23898228545639694`}}]}, 
   {Hue[0.6831663310872902], AbsoluteThickness[0.5], 
    LineBox[{{7.129144563105245, -1.3681341637309854`}, {
     7.043644879961682, -1.4129579341140979`}}]}, 
   {Hue[0.6837281743091128], AbsoluteThickness[0.5], 
    LineBox[{{7.043644879961682, -1.4129579341140979`}, {
     6.810747932054696, -1.5503121430458562`}}]}, 
   {Hue[0.5942463857392035], AbsoluteThickness[0.5], 
    LineBox[{{3.3811998923545006`, 3.382937141572555}, {3.373158746905366, 
     3.3807854402543787`}}]}, 
   {Hue[0.5949016802135558], AbsoluteThickness[0.5], 
    LineBox[{{3.373158746905366, 3.3807854402543787`}, {3.1006380734644776`, 
     3.2889487840879896`}}]}, 
   {Hue[0.6416249758532222], AbsoluteThickness[0.5], 
    LineBox[{{5.6210234693403, -1.6447152563846366`}, {
     5.575234162350826, -1.8085806834308942`}}]}, 
   {Hue[0.6420822666324035], AbsoluteThickness[0.5], 
    LineBox[{{5.575234162350826, -1.8085806834308942`}, {
     5.47724376369272, -2.128513075342996}}]}, 
   {Hue[0.6264451107855881], AbsoluteThickness[0.5], 
    LineBox[{{4.744452596821478, -2.395425641223746}, {
     4.657766998816081, -2.656413610148865}}]}, 
   {Hue[0.6291765277795361], AbsoluteThickness[0.5], 
    LineBox[{{4.657766998816081, -2.656413610148865}, {
     4.623255721698119, -2.869462256514562}}]}, 
   {Hue[0.6899862253710253], AbsoluteThickness[0.5], 
    LineBox[{{2.163891611647784, 3.353772454168395}, {2.1243581397723355`, 
     3.410884711515821}}]}, 
   {Hue[0.6904813255862605], AbsoluteThickness[0.5], 
    LineBox[{{2.1243581397723355`, 3.410884711515821}, {1.9488316238772307`, 
     3.645766748680555}}]}, 
   {Hue[0.6743927655035621], AbsoluteThickness[0.5], 
    LineBox[{{3.641086781956351, 3.3564866281740193`}, {3.638339570855294, 
     3.363080424940536}}]}, 
   {Hue[0.6749857057823331], AbsoluteThickness[0.5], 
    LineBox[{{3.638339570855294, 3.363080424940536}, {3.505226697262981, 
     3.6388030010311345`}}]}, 
   {Hue[0.6943362830150638], AbsoluteThickness[0.5], 
    LineBox[{{2.8451373127380495`, -0.4452368944221523}, {
     2.753043308599178, -0.406513610287334}}]}, 
   {Hue[0.5416316704066213], AbsoluteThickness[0.5], 
    LineBox[{{3.5527098568663935`, 1.8778380147074196`}, {3.439277231187681, 
     1.7583968298255475`}}]}, 
   {Hue[0.5434207317484983], AbsoluteThickness[0.5], 
    LineBox[{{3.439277231187681, 1.7583968298255475`}, {3.2446984846619165`, 
     1.6015104655246515`}}]}, 
   {Hue[0.6768310032915067], AbsoluteThickness[0.5], 
    LineBox[{{2.4184547503477853`, 3.6053863073266728`}, {2.1537266774471826`,
      3.5389518469074015`}}]}, 
   {Hue[0.6772571302188646], AbsoluteThickness[0.5], 
    LineBox[{{2.1537266774471826`, 3.5389518469074015`}, {1.8596649861434087`,
      3.4660232999235747`}}]}, 
   {Hue[0.6626754779222243], AbsoluteThickness[0.5], 
    LineBox[{{4.2464330700440565`, -4.361660864604002}, {
     4.128330848778191, -4.371061674792759}}]}, 
   {Hue[0.6643055976549113], AbsoluteThickness[0.5], 
    LineBox[{{4.128330848778191, -4.371061674792759}, {
     3.890494852415679, -4.420776708081429}}]}, 
   {Hue[0.6146434561858011], AbsoluteThickness[0.5], 
    LineBox[{{4.184947904965205, -4.076001518252941}, {
     4.1426089655285026`, -4.072065971698228}}]}, 
   {Hue[0.6155585998155614], AbsoluteThickness[0.5], 
    LineBox[{{4.1426089655285026`, -4.072065971698228}, {
     3.920854268136044, -4.031450711744683}}]}, 
   {Hue[0.6337328710182663], AbsoluteThickness[0.5], 
    LineBox[{{3.827142598012918, -2.421004426369227}, {
     3.639836395271582, -2.449747033592487}}]}, 
   {Hue[0.6342609297927003], AbsoluteThickness[0.5], 
    LineBox[{{3.639836395271582, -2.449747033592487}, {
     3.351454825817878, -2.5069967355319647`}}]}, 
   {Hue[0.6705419290116489], AbsoluteThickness[0.5], 
    LineBox[{{3.665932076940217, 2.344110986775512}, {3.612806722307977, 
     2.4283219601143866`}}]}, 
   {Hue[0.6712505482828829], AbsoluteThickness[0.5], 
    LineBox[{{3.612806722307977, 2.4283219601143866`}, {3.4449983215464726`, 
     2.657219520389318}}]}, 
   {Hue[0.6831454509260061], AbsoluteThickness[0.5], 
    LineBox[{{3.8162838967296064`, -2.864195445094472}, {
     3.83651025143193, -3.1431070438958137`}}]}, 
   {Hue[0.6837052603375374], AbsoluteThickness[0.5], 
    LineBox[{{3.83651025143193, -3.1431070438958137`}, {
     3.8429923149636425`, -3.428008699033567}}]}, 
   {Hue[0.6463781119763398], AbsoluteThickness[0.5], 
    LineBox[{{4.08712016576028, -0.23898228545639694`}, {
     4.0246999389355675`, -0.34741451807312623`}}]}, 
   {Hue[0.6468415100302752], AbsoluteThickness[0.5], 
    LineBox[{{4.0246999389355675`, -0.34741451807312623`}, {
     3.8820202527180165`, -0.6114934836913243}}]}, 
   {Hue[0.6842900175309353], AbsoluteThickness[0.5], 
    LineBox[{{6.810747932054696, -1.5503121430458562`}, {
     6.729971092814539, -1.6035646764735767`}}]}, 
   {Hue[0.6862126245473197], AbsoluteThickness[0.5], 
    LineBox[{{6.729971092814539, -1.6035646764735767`}, {
     6.574372998701359, -1.7400699723923658`}}]}, 
   {Hue[0.5955569746879082], AbsoluteThickness[0.5], 
    LineBox[{{3.1006380734644776`, 3.2889487840879896`}, {2.9253094300200564`,
      3.2171629003998325`}}]}, 
   {Hue[0.5960486317933267], AbsoluteThickness[0.5], 
    LineBox[{{2.9253094300200564`, 3.2171629003998325`}, {2.6340240938309822`,
      3.1097772054305697`}}]}, 
   {Hue[0.6425395574115849], AbsoluteThickness[0.5], 
    LineBox[{{5.47724376369272, -2.128513075342996}, {
     5.413013004898445, -2.321081913226852}}]}, 
   {Hue[0.6436269672487462], AbsoluteThickness[0.5], 
    LineBox[{{5.413013004898445, -2.321081913226852}, {
     5.355854184434383, -2.574601242987744}}]}, 
   {Hue[0.6319079447734841], AbsoluteThickness[0.5], 
    LineBox[{{4.623255721698119, -2.869462256514562}, {
     4.623094439638264, -3.188305348808696}}]}, 
   {Hue[0.6359960463621067], AbsoluteThickness[0.5], 
    LineBox[{{4.623094439638264, -3.188305348808696}, {
     4.6620110012585165`, -3.3945292663542186`}}]}, 
   {Hue[0.5452097930903753], AbsoluteThickness[0.5], 
    LineBox[{{3.2446984846619165`, 1.6015104655246515`}, {3.1548498041266955`,
      1.5469254721900207`}}]}, 
   {Hue[0.545708069015503], AbsoluteThickness[0.5], 
    LineBox[{{3.1548498041266955`, 1.5469254721900207`}, {2.8639491440197515`,
      1.384647110110922}}]}, 
   {Hue[0.6659357173875983], AbsoluteThickness[0.5], 
    LineBox[{{3.890494852415679, -4.420776708081429}, {
     3.871147022080953, -4.427462155032698}}]}, 
   {Hue[0.6877359662095516], AbsoluteThickness[0.5], 
    LineBox[{{3.871147022080953, -4.427462155032698}, {
     3.704726185631472, -4.430628972276227}}]}, 
   {Hue[0.6164737434453218], AbsoluteThickness[0.5], 
    LineBox[{{3.920854268136044, -4.031450711744683}, {
     3.690810267342986, -3.9678818521900654`}}]}, 
   {Hue[0.6177398364535568], AbsoluteThickness[0.5], 
    LineBox[{{3.690810267342986, -3.9678818521900654`}, {
     3.4393105491574754`, -3.927458510301149}}]}, 
   {Hue[0.6347889885671344], AbsoluteThickness[0.5], 
    LineBox[{{3.351454825817878, -2.5069967355319647`}, {
     3.131194700140927, -2.560823527315624}}]}, 
   {Hue[0.6357977508559443], AbsoluteThickness[0.5], 
    LineBox[{{3.131194700140927, -2.560823527315624}, {
     2.8456612204732767`, -2.6023848556947518`}}]}, 
   {Hue[0.671959167554117], AbsoluteThickness[0.5], 
    LineBox[{{3.4449983215464726`, 2.657219520389318}, {3.427951203854675, 
     2.6773597673576788`}}]}, 
   {Hue[0.6724535278796314], AbsoluteThickness[0.5], 
    LineBox[{{3.427951203854675, 2.6773597673576788`}, {3.2215905572968855`, 
     2.9040363091897365`}}]}, 
   {Hue[0.6842650697490686], AbsoluteThickness[0.5], 
    LineBox[{{3.8429923149636425`, -3.428008699033567}, {
     3.8396673322588772`, -3.551601982237704}}]}, 
   {Hue[0.6847284268547565], AbsoluteThickness[0.5], 
    LineBox[{{3.8396673322588772`, -3.551601982237704}, {
     3.8207838631849835`, -3.901906916615115}}]}, 
   {Hue[0.6473049080842107], AbsoluteThickness[0.5], 
    LineBox[{{3.8820202527180165`, -0.6114934836913242}, {
     3.7466688579831975`, -0.8790188148008027}}]}, 
   {Hue[0.688135231563704], AbsoluteThickness[0.5], 
    LineBox[{{6.574372998701359, -1.7400699723923658`}, {
     6.516988133806748, -1.8063764967528104`}}]}, 
   {Hue[0.6887934720908727], AbsoluteThickness[0.5], 
    LineBox[{{6.516988133806748, -1.8063764967528104`}, {
     6.340837841752885, -2.0383551190524773`}}]}, 
   {Hue[0.5965402888987451], AbsoluteThickness[0.5], 
    LineBox[{{2.6340240938309822`, 3.1097772054305697`}, {2.575399325474753, 
     3.090493276734284}}]}, 
   {Hue[0.5971437777633434], AbsoluteThickness[0.5], 
    LineBox[{{2.575399325474753, 3.090493276734284}, {2.301438719529132, 
     2.982853364961344}}]}, 
   {Hue[0.6447143770859077], AbsoluteThickness[0.5], 
    LineBox[{{5.355854184434383, -2.574601242987744}, {
     5.35350687829742, -2.5938152113493516`}}]}, 
   {Hue[0.6455633340003988], AbsoluteThickness[0.5], 
    LineBox[{{5.35350687829742, -2.5938152113493516`}, {
     5.292612501840239, -2.8870608060169802`}}]}, 
   {Hue[0.6400841479507291], AbsoluteThickness[0.5], 
    LineBox[{{4.6620110012585165`, -3.3945292663542186`}, {
     4.754598746387944, -3.6307582226524877`}}]}, 
   {Hue[0.6411863360822597], AbsoluteThickness[0.5], 
    LineBox[{{4.754598746387944, -3.6307582226524877`}, {
     4.820613924945904, -3.867035516860141}}]}, 
   {Hue[0.5462063449406306], AbsoluteThickness[0.5], 
    LineBox[{{2.8639491440197515`, 1.384647110110922}, {2.845549763977824, 
     1.375259946820331}}]}, 
   {Hue[0.5470066273317176], AbsoluteThickness[0.5], 
    LineBox[{{2.845549763977824, 1.375259946820331}, {2.584430383230937, 
     1.214915504907811}}]}, 
   {Hue[0.6190059294617918], AbsoluteThickness[0.5], 
    LineBox[{{3.4393105491574754`, -3.927458510301149}, {
     3.3311223350073575`, -3.922139290356043}}]}, 
   {Hue[0.6327309072021211], AbsoluteThickness[0.5], 
    LineBox[{{3.3311223350073575`, -3.922139290356043}, {
     3.152268458090119, -3.8618384808763357`}}]}, 
   {Hue[0.636806513144754], AbsoluteThickness[0.5], 
    LineBox[{{2.8456612204732767`, -2.6023848556947518`}, {
     2.8409965961040933`, -2.602615488252624}}]}, 
   {Hue[0.63934170693582], AbsoluteThickness[0.5], 
    LineBox[{{2.8409965961040933`, -2.602615488252624}, {
     2.604398085137293, -2.6517129944932107`}}]}, 
   {Hue[0.672947888205146], AbsoluteThickness[0.5], 
    LineBox[{{3.2215905572968855`, 2.9040363091897365`}, {3.174328044727795, 
     2.9523284807021364`}}]}, 
   {Hue[0.6734044585801715], AbsoluteThickness[0.5], 
    LineBox[{{3.174328044727795, 2.9523284807021364`}, {2.951550238374458, 
     3.1690946676903415`}}]}, 
   {Hue[0.6851917839604446], AbsoluteThickness[0.5], 
    LineBox[{{3.8207838631849835`, -3.901906916615115}, {
     3.80211675505363, -4.132400313527467}}]}, 
   {Hue[0.6856179536589435], AbsoluteThickness[0.5], 
    LineBox[{{3.80211675505363, -4.132400313527467}, {
     3.7752892297349536`, -4.452034285794259}}]}, 
   {Hue[0.6477611846334617], AbsoluteThickness[0.5], 
    LineBox[{{3.7466688579831975`, -0.8790188148008027}, {
     3.7106548025435013`, -0.9547201839582524}}]}, 
   {Hue[0.6894517126180412], AbsoluteThickness[0.5], 
    LineBox[{{6.340837841752885, -2.0383551190524773`}, {
     6.322793281111659, -2.0655688349334396`}}]}, 
   {Hue[0.6899654356945536], AbsoluteThickness[0.5], 
    LineBox[{{6.322793281111659, -2.0655688349334396`}, {
     6.157765919609406, -2.337885127728337}}]}, 
   {Hue[0.5977472666279418], AbsoluteThickness[0.5], 
    LineBox[{{2.301438719529132, 2.982853364961344}, {2.1407753746918172`, 
     2.9089836590360125`}}]}, 
   {Hue[0.6003168404527637], AbsoluteThickness[0.5], 
    LineBox[{{2.1407753746918172`, 2.9089836590360125`}, {1.9661711872713532`,
      2.859743926811792}}]}, 
   {Hue[0.6464122909148897], AbsoluteThickness[0.5], 
    LineBox[{{5.292612501840239, -2.8870608060169802`}, {
     5.232666786912124, -3.0894714612195604`}}]}, 
   {Hue[0.6469820784108019], AbsoluteThickness[0.5], 
    LineBox[{{5.232666786912124, -3.0894714612195604`}, {
     5.157493496845287, -3.4012534341989715`}}]}, 
   {Hue[0.6422885242137903], AbsoluteThickness[0.5], 
    LineBox[{{4.820613924945904, -3.867035516860141}, {
     4.884434501623828, -4.2358196280616305`}}]}, 
   {Hue[0.6869760649738093], AbsoluteThickness[0.5], 
    LineBox[{{4.884434501623828, -4.2358196280616305`}, {
     4.851770889094809, -4.394559078043891}}]}, 
   {Hue[0.6464558849424513], AbsoluteThickness[0.5], 
    LineBox[{{3.152268458090119, -3.8618384808763357`}, {
     2.896800822256992, -3.686598718661227}}]}, 
   {Hue[0.6483350370430025], AbsoluteThickness[0.5], 
    LineBox[{{2.896800822256992, -3.686598718661227}, {
     2.689915330548442, -3.582692171093338}}]}, 
   {Hue[0.6418769007268861], AbsoluteThickness[0.5], 
    LineBox[{{2.604398085137293, -2.6517129944932107`}, {
     2.4279987126972924`, -2.718073444163577}}]}, 
   {Hue[0.6424752413278285], AbsoluteThickness[0.5], 
    LineBox[{{2.4279987126972924`, -2.718073444163577}, {
     2.135494152245416, -2.809837402303213}}]}, 
   {Hue[0.6738610289551971], AbsoluteThickness[0.5], 
    LineBox[{{2.951550238374458, 3.1690946676903415`}, {2.925985752623619, 
     3.1927804595461824`}}]}, 
   {Hue[0.6749180509534812], AbsoluteThickness[0.5], 
    LineBox[{{2.925985752623619, 3.1927804595461824`}, {2.7154128201226433`, 
     3.352520142293125}}]}, 
   {Hue[0.6477611846334616], AbsoluteThickness[0.5], 
    LineBox[{{3.7106548025435013`, -0.9547201839582524}, {
     3.805435592691757, -1.1508378336127705`}}]}, 
   {Hue[0.6485444129337901], AbsoluteThickness[0.5], 
    LineBox[{{3.805435592691757, -1.1508378336127705`}, {
     3.917201782849012, -1.3426715035870278`}}]}, 
   {Hue[0.6904791587710661], AbsoluteThickness[0.5], 
    LineBox[{{6.157765919609406, -2.337885127728337}, {
     6.10349589108347, -2.436252920013397}}]}, 
   {Hue[0.6909338261303923], AbsoluteThickness[0.5], 
    LineBox[{{6.10349589108347, -2.436252920013397}, {
     5.974176706187293, -2.6580579140834435`}}]}, 
   {Hue[0.647551865906714], AbsoluteThickness[0.5], 
    LineBox[{{5.157493496845287, -3.4012534341989715`}, {
     5.152596256026369, -3.427385230444824}}]}, 
   {Hue[0.6503176023804906], AbsoluteThickness[0.5], 
    LineBox[{{5.152596256026369, -3.427385230444824}, {
     5.076483895452665, -3.6384059088421354`}}]}, 
   {Hue[0.6502141891435538], AbsoluteThickness[0.5], 
    LineBox[{{2.689915330548442, -3.582692171093338}, {
     2.667760760867163, -3.5751125844766563`}}]}, 
   {Hue[0.650658543995258], AbsoluteThickness[0.5], 
    LineBox[{{2.667760760867163, -3.5751125844766563`}, {
     2.375961162436695, -3.4690250630170003`}}]}, 
   {Hue[0.6430735819287711], AbsoluteThickness[0.5], 
    LineBox[{{2.135494152245416, -2.809837402303213}, {
     2.087497796841246, -2.821999415786414}}]}, 
   {Hue[0.6467174347554817], AbsoluteThickness[0.5], 
    LineBox[{{2.087497796841246, -2.821999415786414}, {
     1.8879609830033095`, -2.9128846728754083`}}]}, 
   {Hue[0.6759750729517654], AbsoluteThickness[0.5], 
    LineBox[{{2.7154128201226433`, 3.352520142293125}, {2.6739516423749676`, 
     3.3779794919917756`}}]}, 
   {Hue[0.676400813986572], AbsoluteThickness[0.5], 
    LineBox[{{2.6739516423749676`, 3.3779794919917756`}, {2.377680258490498, 
     3.5597800268627084`}}]}, 
   {Hue[0.6493276412341187], AbsoluteThickness[0.5], 
    LineBox[{{3.917201782849012, -1.3426715035870278`}, {
     3.9259634851723977`, -1.3553448036550402`}}]}, 
   {Hue[0.6497867855270132], AbsoluteThickness[0.5], 
    LineBox[{{3.9259634851723977`, -1.3553448036550402`}, {
     4.078816336512063, -1.5648408274851688`}}]}, 
   {Hue[0.6913884934897183], AbsoluteThickness[0.5], 
    LineBox[{{5.974176706187293, -2.6580579140834435`}, {
     5.693969784486845, -3.1135051739888593`}}]}, 
   {Hue[0.6923361287615641], AbsoluteThickness[0.5], 
    LineBox[{{5.693969784486845, -3.1135051739888593`}, {
     5.573895207701303, -3.355449636607189}}]}, 
   {Hue[0.6530833388542673], AbsoluteThickness[0.5], 
    LineBox[{{5.076483895452665, -3.6384059088421354`}, {
     4.934825432642295, -3.8934081475577895`}}]}, 
   {Hue[0.6586091906772715], AbsoluteThickness[0.5], 
    LineBox[{{4.934825432642295, -3.8934081475577895`}, {
     4.88180257200989, -4.065333048993831}}]}, 
   {Hue[0.6511028988469622], AbsoluteThickness[0.5], 
    LineBox[{{2.375961162436695, -3.4690250630170003`}, {
     2.0728785880833134`, -3.352246653974377}}]}, 
   {Hue[0.6765634747801543], AbsoluteThickness[0.5], 
    LineBox[{{2.0728785880833134`, -3.352246653974377}, {
     1.9100683646879397`, -3.3455463629775624`}}]}, 
   {Hue[0.6768265550213786], AbsoluteThickness[0.5], 
    LineBox[{{2.377680258490498, 3.5597800268627084`}, {2.316161909293825, 
     3.597503338215494}}]}, 
   {Hue[0.6773618989742897], AbsoluteThickness[0.5], 
    LineBox[{{2.316161909293825, 3.597503338215494}, {2.077436029657013, 
     3.7591572116466687`}}]}, 
   {Hue[0.6502459298199078], AbsoluteThickness[0.5], 
    LineBox[{{4.078816336512063, -1.5648408274851688`}, {
     4.109049427111603, -1.6041382814135003`}}]}, 
   {Hue[0.6506903880601095], AbsoluteThickness[0.5], 
    LineBox[{{4.109049427111603, -1.6041382814135003`}, {
     4.3221966647047365`, -1.8924309513511197`}}]}, 
   {Hue[0.6932837640334099], AbsoluteThickness[0.5], 
    LineBox[{{5.573895207701303, -3.355449636607189}, {
     5.565869195314576, -3.3761545716081787`}}]}, 
   {Hue[0.6937268608507786], AbsoluteThickness[0.5], 
    LineBox[{{5.565869195314576, -3.3761545716081787`}, {
     5.4418907560246055`, -3.679297409092211}}]}, 
   {Hue[0.6641350425002757], AbsoluteThickness[0.5], 
    LineBox[{{4.88180257200989, -4.065333048993831}, {
     4.8692648807404355`, -4.2023759738954976`}}]}, 
   {Hue[0.6665430928043258], AbsoluteThickness[0.5], 
    LineBox[{{4.8692648807404355`, -4.2023759738954976`}, {
     4.813662243085376, -4.426588572104751}}]}, 
   {Hue[0.6511348463003112], AbsoluteThickness[0.5], 
    LineBox[{{4.3221966647047365`, -1.8924309513511197`}, {
     4.353903741702262, -1.9370772935999467`}}]}, 
   {Hue[0.6518231600711152], AbsoluteThickness[0.5], 
    LineBox[{{4.353903741702262, -1.9370772935999467`}, {
     4.504754570241644, -2.1831223202070253`}}]}, 
   {Hue[0.6941699576681473], AbsoluteThickness[0.5], 
    LineBox[{{5.4418907560246055`, -3.679297409092211}, {
     5.427791745679672, -3.7120370590147096`}}]}, 
   {Hue[0.6951092183621905], AbsoluteThickness[0.5], 
    LineBox[{{5.427791745679672, -3.7120370590147096`}, {
     5.302012747404657, -3.9439812156104734`}}]}, 
   {Hue[0.6525114738419191], AbsoluteThickness[0.5], 
    LineBox[{{4.504754570241644, -2.1831223202070253`}, {
     4.736300116588875, -2.625211999747876}}]}, 
   {Hue[0.6531075597784154], AbsoluteThickness[0.5], 
    LineBox[{{4.736300116588875, -2.625211999747876}, {
     4.882159215301705, -2.8696744131799945`}}]}, 
   {Hue[0.6960484790562338], AbsoluteThickness[0.5], 
    LineBox[{{5.302012747404657, -3.9439812156104734`}, {
     5.2217458518937185`, -4.064602285930417}}]}, 
   {Hue[0.6970829987568065], AbsoluteThickness[0.5], 
    LineBox[{{5.2217458518937185`, -4.064602285930417}, {
     5.107144882219492, -4.279294589896808}}]}, 
   {Hue[0.6537036457149118], AbsoluteThickness[0.5], 
    LineBox[{{4.882159215301705, -2.8696744131799945`}, {
     4.882720520217146, -2.870506530918751}}]}, 
   {Hue[0.6541800529209055], AbsoluteThickness[0.5], 
    LineBox[{{4.882720520217146, -2.870506530918751}, {
     5.044608360709222, -3.1274260863780086`}}]}, 
   {Hue[0.6981175184573793], AbsoluteThickness[0.5], 
    LineBox[{{5.107144882219492, -4.279294589896808}, {
     5.069366494585016, -4.3703010073947315`}}]}, 
   {Hue[0.6985835655727247], AbsoluteThickness[0.5], 
    LineBox[{{5.069366494585016, -4.3703010073947315`}, {
     4.937796761354977, -4.663853473219575}}]}, 
   {Hue[0.6546564601268993], AbsoluteThickness[0.5], 
    LineBox[{{5.044608360709222, -3.1274260863780086`}, {
     5.090254269051603, -3.2051364743806148`}}]}, 
   {Hue[0.6563340546128272], AbsoluteThickness[0.5], 
    LineBox[{{5.090254269051603, -3.2051364743806148`}, {
     5.178962684017296, -3.413435228091362}}]}, 
   {Hue[0.6580116490987552], AbsoluteThickness[0.5], 
    LineBox[{{5.178962684017296, -3.413435228091362}, {
     5.242672919711746, -3.639997926491611}}]}, 
   {Hue[0.6584393088438658], AbsoluteThickness[0.5], 
    LineBox[{{5.242672919711746, -3.639997926491611}, {
     5.325225269442167, -3.9406582643907297`}}]}, 
   {Hue[0.6588669685889764], AbsoluteThickness[0.5], 
    LineBox[{{5.325225269442167, -3.9406582643907297`}, {
     5.426994946503423, -4.320453809681032}}]}, 
   {Hue[0.6593092785643562], AbsoluteThickness[0.5], 
    LineBox[{{5.426994946503423, -4.320453809681032}, {
     5.510345275135512, -4.65551934872902}}]}, 
   {Hue[0.4957391597598198], AbsoluteThickness[0.5], 
    LineBox[{{1.7955815896174605`, -0.125}, {
     0.7499999999999998, -2.3491033229111213`}}]}, 
   {Hue[0.4972663792327792], AbsoluteThickness[0.5], 
    LineBox[{{1.9248237126640428`, 0.16856772185166144`}, {0.75, 
     1.4516803255383852`}}]}, 
   {Hue[0.5525512595937232], AbsoluteThickness[0.5], 
    LineBox[{{1.7667114977152143`, 0.}, {0.7500000000000002, 
     0.2310098625111181}}]}, 
   {Hue[0.5534216714975404], AbsoluteThickness[0.5], 
    LineBox[{{1.7730587304746952`, -0.07498664120871036}, {
     0.75, -0.24942978179698783`}}]}, 
   {Hue[0.5530988747229177], AbsoluteThickness[0.5], 
    LineBox[{{1.7718595590752455`, -0.07063522489757537}, {0.75, 
     0.7535259572771359}}]}, 
   {Hue[0.5504026949617526], AbsoluteThickness[0.5], 
    LineBox[{{1.8423013513061834`, -0.45101505306758705`}, {
     0.75, -0.889343180182121}}]}, 
   {Hue[0.5551690036312306], AbsoluteThickness[0.5], 
    LineBox[{{2.0837373856700006`, 0.2965721905668172}, {0.7500000000000002, 
     0.4096865270363005}}]}, 
   {Hue[0.5580997671569982], AbsoluteThickness[0.5], 
    LineBox[{{2.106427525397316, 0.2053377669254522}, {0.75, 
     0.4273556524690574}}]}, 
   {Hue[0.5522992446022054], AbsoluteThickness[0.5], 
    LineBox[{{1.801637750962374, 0.09092864325017339}, {0.75, 
     0.04978644992781012}}]}, 
   {Hue[0.55647038949886], AbsoluteThickness[0.5], 
    LineBox[{{1.7657163286955608`, -0.012558466677348954`}, {
     0.75, -0.027735645971421197`}}]}, 
   {Hue[0.5573746436949905], AbsoluteThickness[0.5], 
    LineBox[{{1.7691195403203088`, 0.01564522490284401}, {0.75, 
     0.016027855588639117`}}]}, 
   {Hue[0.5617300248405065], AbsoluteThickness[0.5], 
    LineBox[{{1.8314453717792814`, 0.12377842271242047`}, {0.75, 
     0.12473198593804036`}}]}, 
   {Hue[0.5629513106275251], AbsoluteThickness[0.5], 
    LineBox[{{1.8346844121442663`, 0.12654975919679765`}, {0.7500000000000002,
      0.12070395191691197`}}]}, 
   {Hue[0.6600534765745482], AbsoluteThickness[0.5], 
    LineBox[{{1.8119977437452552`, -0.9006206950138466}, {
     0.7500000000000002, -1.5730147447316236`}}]}, 
   {Hue[0.5537739135509361], AbsoluteThickness[0.5], 
    LineBox[{{1.8496955326228355`, -0.4029893226713026}, {
     0.75, -0.4812568677730144}}]}, 
   {Hue[0.5602141656975695], AbsoluteThickness[0.5], 
    LineBox[{{1.8773585995962323`, 0.15362823761233957`}, {0.7499999999999998,
      0.4756309133558575}}]}, 
   {Hue[0.5741945267273225], AbsoluteThickness[0.5], 
    LineBox[{{1.9267200549402579`, -0.5911945978857394}, {
     0.75, -2.731918398948355}}]}, 
   {Hue[0.5594846564141269], AbsoluteThickness[0.5], 
    LineBox[{{2.0861034215346206`, 0.3079172392465792}, {0.75, 
     0.0154157950192228}}]}, 
   {Hue[0.5584005035715468], AbsoluteThickness[0.5], 
    LineBox[{{2.118770664382901, -0.22760592327198906`}, {
     0.75, -0.25838801264058553`}}]}, 
   {Hue[0.5591853919421487], AbsoluteThickness[0.5], 
    LineBox[{{2.1106335737452513`, -0.2649692001902707}, {
     0.75, -0.21203788542241242`}}]}, 
   {Hue[0.5597159402003009], AbsoluteThickness[0.5], 
    LineBox[{{1.8139587979114136`, 0.10638609312081994`}, {
     0.75, -0.07501855218023412}}]}, 
   {Hue[0.30398781072889186`], AbsoluteThickness[0.5], 
    LineBox[{{1.875067271831618, -0.5474952523845649}, {
     0.75, -0.6549637264980807}}]}, 
   {Hue[0.5846987195345453], AbsoluteThickness[0.5], 
    LineBox[{{2.0556988280270816`, -0.6720451299826989}, {
     0.75, -1.4662121775876074`}}]}, 
   {Hue[0.5621459584740839], AbsoluteThickness[0.5], 
    LineBox[{{1.825433283496981, -0.16133456345766564`}, {
     0.7500000000000002, -0.5605090150688239}}]}, 
   {Hue[0.5541315483583653], AbsoluteThickness[0.5], 
    LineBox[{{1.932082784350391, 0.5050359174822743}, {0.75, 
     0.8438476141638663}}]}, 
   {Hue[0.5818893167754982], AbsoluteThickness[0.5], 
    LineBox[{{1.870059276253556, -0.5405844397897467}, {
     0.75, -0.8169159854796321}}]}, 
   {Hue[0.594852245312662], AbsoluteThickness[0.5], 
    LineBox[{{1.8255432740145598`, 2.5849777346123637`}, {0.75, 
     4.410846067521395}}]}, 
   {Hue[0.5686843624569419], AbsoluteThickness[0.5], 
    LineBox[{{2.344349507463681, 0.6226168878589597}, {0.75, 
     1.3856630703951751`}}]}, 
   {Hue[0.35155228184534676`], AbsoluteThickness[0.5], 
    LineBox[{{2.0297050967594505`, 0.5773459705747525}, {0.7500000000000002, 
     1.6248226709384088`}}]}, 
   {Hue[0.6348580812337191], AbsoluteThickness[0.5], 
    LineBox[{{2.0118250519628877`, 0.5740150132060365}, {0.7499999999999998, 
     2.844300040119425}}]}, 
   {Hue[0.5605917270523009], AbsoluteThickness[0.5], 
    LineBox[{{2.359727162854879, 0.6425911505519412}, {0.7499999999999998, 
     1.0060815776516199`}}]}, 
   {Hue[0.6982526919515243], AbsoluteThickness[0.5], 
    LineBox[{{1.8455432951950819`, 0.9160594491701124}, {0.75, 
     0.6660417244130369}}]}, 
   {Hue[0.5624191193469887], AbsoluteThickness[0.5], 
    LineBox[{{1.966398076144971, -1.2089410540504004`}, {
     0.75, -1.8511867494564624`}}]}, 
   {Hue[0.4389000266537935], AbsoluteThickness[0.5], 
    LineBox[{{1.8893781927186855`, -0.5637406615155127}, {
     0.75, -0.65371924491222}}]}, 
   {Hue[0.6622634856340701], AbsoluteThickness[0.5], 
    LineBox[{{1.93646642329049, 1.1604636241787327`}, {0.7500000000000002, 
     3.458773717420485}}]}, 
   {Hue[0.5572446528652487], AbsoluteThickness[0.5], 
    LineBox[{{2.0674070199659016`, -0.6332743526596728}, {
     0.75, -1.1872995268566238`}}]}, 
   {Hue[0.6457774206232993], AbsoluteThickness[0.5], 
    LineBox[{{2.3216116719021582`, 0.5675537950524521}, {0.7499999999999998, 
     1.2300332313732114`}}]}, 
   {Hue[0.661332911351248], AbsoluteThickness[0.5], 
    LineBox[{{1.828934746370603, -0.16458716458333686`}, {
     0.75, -0.15182617766574127`}}]}, 
   {Hue[0.4907960771740356], AbsoluteThickness[0.5], 
    LineBox[{{1.8540552920855577`, 1.6481790350858472`}, {0.7500000000000002, 
     2.442616446394226}}]}, 
   {Hue[0.4655501002854232], AbsoluteThickness[0.5], 
    LineBox[{{2.0188747524139967`, -2.120032197837451}, {
     0.75, -3.6002362764368097`}}]}, 
   {Hue[0.5561958556435133], AbsoluteThickness[0.5], 
    LineBox[{{1.8423154086426972`, -0.45300126496994053`}, {
     0.75, -0.8045545535511653}}]}, 
   {Hue[0.5096827575343666], AbsoluteThickness[0.5], 
    LineBox[{{2.6300443294614073`, 3.9173555973417025`}, {2.5768276262355214`,
      4.6}}]}, 
   {Hue[0.656771416667659], AbsoluteThickness[0.5], 
    LineBox[{{2.0851231123706127`, 3.779878566618073}, {0.75, 
     4.143814615161638}}]}, 
   {Hue[0.4282075142862915], AbsoluteThickness[0.5], 
    LineBox[{{2.057236045360976, -0.6642455881227427}, {
     0.75, -0.8240239888610535}}]}, 
   {Hue[0.6585471481238415], AbsoluteThickness[0.5], 
    LineBox[{{2.1170653404762017`, -0.23278758243140396`}, {
     0.75, -0.16069559687493656`}}]}, 
   {Hue[0.5578067048021073], AbsoluteThickness[0.5], 
    LineBox[{{1.842863952109734, -0.4375276940997859}, {
     0.7499999999999998, -0.5465088103570599}}]}, 
   {Hue[0.6284906867879797], AbsoluteThickness[0.5], 
    LineBox[{{2.095806171912908, 1.1532179287161608`}, {0.75, 
     2.6291346848202424`}}]}, 
   {Hue[0.6043901628979826], AbsoluteThickness[0.5], 
    LineBox[{{3.345213415297582, 3.842096546976099}, {4.5798696211415315`, 
     4.6}}]}, 
   {Hue[0.6063110866569436], AbsoluteThickness[0.5], 
    LineBox[{{2.0669455851804406`, -0.634328785358245}, {
     0.75, -0.7619004469947318}}]}, 
   {Hue[0.6701890969256621], AbsoluteThickness[0.5], 
    LineBox[{{1.8383271638022058`, -1.5287182147375722`}, {
     0.75, -3.301446798434237}}]}, 
   {Hue[0.565176090932801], AbsoluteThickness[0.5], 
    LineBox[{{1.9352542784906013`, 1.7095132569930545`}, {0.7500000000000002, 
     2.1490669755413165`}}]}, 
   {Hue[0.5813548824392004], AbsoluteThickness[0.5], 
    LineBox[{{2.01432323401041, 0.5746505030769323}, {0.75, 
     0.976909276959501}}]}, 
   {Hue[0.578305209516146], AbsoluteThickness[0.5], 
    LineBox[{{2.058438474557272, -0.6592073737932721}, {
     0.7499999999999998, -0.9348415329407874}}]}, 
   {Hue[0.5209177068142883], AbsoluteThickness[0.5], 
    LineBox[{{1.9172721961292385`, -1.627974229620578}, {
     0.75, -2.9013065322344205`}}]}, 
   {Hue[0.5618547799944438], AbsoluteThickness[0.5], 
    LineBox[{{1.8567806597384564`, -0.5171364579243246}, {
     0.75, -0.8172969222163444}}]}, 
   {Hue[0.6067338938847242], AbsoluteThickness[0.5], 
    LineBox[{{1.8404418216938554`, -1.5359674409462236`}, {
     0.75, -3.071296931781909}}]}, 
   {Hue[0.5790494055486624], AbsoluteThickness[0.5], 
    LineBox[{{2.3521208504642495`, 0.43589151963717293`}, {0.75, 
     1.25205801970188}}]}, 
   {Hue[0.6865804055609054], AbsoluteThickness[0.5], 
    LineBox[{{1.9123453334589247`, -1.8233963906524737`}, {
     0.75, -2.0759609748518075`}}]}, 
   {Hue[0.6234109898493562], AbsoluteThickness[0.5], 
    LineBox[{{2.083725719993325, -2.6349061399545337`}, {
     0.75, -3.5020827830639027`}}]}, 
   {Hue[0.45741707728414077`], AbsoluteThickness[0.5], 
    LineBox[{{2.6254031923217167`, -4.653204148378009}, {
     2.5955316754113418`, -5.4}}]}, 
   {Hue[0.5674491392948133], AbsoluteThickness[0.5], 
    LineBox[{{1.8703696917116817`, -0.3607321474066407}, {
     0.75, -0.7013950641324389}}]}, 
   {Hue[0.6114629686743456], AbsoluteThickness[0.5], 
    LineBox[{{1.8304753136753826`, -0.16596815799168402`}, {0.75, 
     0.4193320808339166}}]}, 
   {Hue[0.6726779975138514], AbsoluteThickness[0.5], 
    LineBox[{{2.0985167850331248`, -2.7099219934700547`}, {
     0.75, -3.4692513689339672`}}]}, 
   {Hue[0.5511337175512968], AbsoluteThickness[0.5], 
    LineBox[{{2.132068257041967, -2.8054809508304213`}, {
     0.75, -2.911906000697434}}]}, 
   {Hue[0.012325639840203672`], AbsoluteThickness[0.5], 
    LineBox[{{8.382197538319517, 0.21424896194859802`}, {9.75, 
     0.19590346601470354`}}]}, 
   {Hue[0.5653543162820983], AbsoluteThickness[0.5], 
    LineBox[{{2.109959880802911, -0.2825813678668214}, {
     0.75, -0.1979840373684736}}]}, 
   {Hue[0.11231435322135136`], AbsoluteThickness[0.5], 
    LineBox[{{8.436859022371637, -0.21729711559681503`}, {9.75, 
     0.209986508766555}}]}, 
   {Hue[0.5665395267133803], AbsoluteThickness[0.5], 
    LineBox[{{2.1146467287569317`, -0.24144351625385335`}, {
     0.7500000000000002, -0.36771200286290195`}}]}, 
   {Hue[0.5577744185999717], AbsoluteThickness[0.5], 
    LineBox[{{1.9180050689671857`, 2.1425003823834583`}, {0.75, 
     3.04511614413112}}]}, 
   {Hue[0.5281999808348445], AbsoluteThickness[0.5], 
    LineBox[{{1.919184824223381, -2.082431313001163}, {
     0.7499999999999998, -4.205744685785135}}]}, 
   {Hue[0.5303244042944293], AbsoluteThickness[0.5], 
    LineBox[{{1.9817586770943016`, 2.1791415740487627`}, {0.75, 
     3.1566355096556142`}}]}, 
   {Hue[0.5670754246730524], AbsoluteThickness[0.5], 
    LineBox[{{3.300971287665975, -4.400648676087593}, {
     3.086776964025714, -5.4}}]}, 
   {Hue[0.1665071956205827], AbsoluteThickness[0.5], 
    LineBox[{{8.230601316622751, -0.06890549009885918}, {9.75, 
     0.6109538862222953}}]}, 
   {Hue[0.06931419751229526], AbsoluteThickness[0.5], 
    LineBox[{{8.396347004765932, -0.12430699846526025`}, {
     9.75, -1.1572346027848937`}}]}, 
   {Hue[0.531859421051376], AbsoluteThickness[0.5], 
    LineBox[{{2.1108399193335665`, 3.217186508121462}, {0.75, 
     4.039992395894325}}]}, 
   {Hue[0.6223577542954419], AbsoluteThickness[0.5], 
    LineBox[{{1.920922797046831, 1.703270531361045}, {0.75, 
     2.1698774995448553`}}]}, 
   {Hue[0.662167849392045], AbsoluteThickness[0.5], 
    LineBox[{{1.950387133287635, 0.5348757458942459}, {0.7500000000000002, 
     0.8276502151766855}}]}, 
   {Hue[0.2863644380549555], AbsoluteThickness[0.5], 
    LineBox[{{3.728555703654014, -4.441966765269619}, {
     3.796483501797247, -5.4}}]}, 
   {Hue[0.5571338032785232], AbsoluteThickness[0.5], 
    LineBox[{{1.919755288166379, -3.0988735426958574`}, {
     0.75, -3.1300956431984774`}}]}, 
   {Hue[0.4734390655037346], AbsoluteThickness[0.5], 
    LineBox[{{3.5395247777225953`, 3.6378075200691664`}, {3.788473670202962, 
     4.6}}]}, 
   {Hue[0.5336603193638628], AbsoluteThickness[0.5], 
    LineBox[{{3.8570140473338053`, -4.435439782454702}, {
     3.119534905634081, -5.4}}]}, 
   {Hue[0.5800975571873203], AbsoluteThickness[0.5], 
    LineBox[{{1.9747949438819588`, 1.7199453840791081`}, {0.7499999999999998, 
     2.346628414549215}}]}, 
   {Hue[0.3045878740623143], AbsoluteThickness[0.5], 
    LineBox[{{8.166524044565504, -1.3435137470518559`}, {
     9.75, -3.4020041246891792`}}]}, 
   {Hue[0.16961424294423968`], AbsoluteThickness[0.5], 
    LineBox[{{8.320246576497244, -1.3620915307848682`}, {
     9.75, -1.093300644274752}}]}, 
   {Hue[0.3443776594803921], AbsoluteThickness[0.5], 
    LineBox[{{8.406412456425837, -1.233440094694684}, {9.75, 
     3.3688641657970226`}}]}, 
   {Hue[0.45428024338224743`], AbsoluteThickness[0.5], 
    LineBox[{{8.162308292387332, 1.398304744333045}, {9.75, 
     3.6114305021425186`}}]}, 
   {Hue[0.5122000576431874], AbsoluteThickness[0.5], 
    LineBox[{{8.325030888654787, 1.455907844898162}, {9.75, 
     1.3607980380566072`}}]}, 
   {Hue[0.5866623323585769], AbsoluteThickness[0.5], 
    LineBox[{{8.45980468068989, 1.3480524532331402`}, {
     9.75, -1.0765660535171206`}}]}, 
   {Hue[0.6490496333893848], AbsoluteThickness[0.5], 
    LineBox[{{8.34344479452597, -1.3487889805869697`}, {
     9.75, -1.642264513261415}}]}, 
   {Hue[0.37882555111515964`], AbsoluteThickness[0.5], 
    LineBox[{{5.4966386240414105`, 3.142139853216612}, {4.2725734784201235`, 
     4.6}}]}, 
   {Hue[0.4510953831401175], AbsoluteThickness[0.5], 
    LineBox[{{8.384033950643115, 0.7501310270772685}, {9.75, 
     0.6784991678000553}}]}, 
   {Hue[0.5023595470123255], AbsoluteThickness[0.5], 
    LineBox[{{4.785103490071498, 3.874189915830109}, {4.734665751542629, 
     4.6}}]}, 
   {Hue[0.4869451742391381], AbsoluteThickness[0.5], 
    LineBox[{{2.3836308943699063`, -4.545116830382357}, {
     2.057507126163617, -5.4}}]}, 
   {Hue[0.3902945182471083], AbsoluteThickness[0.5], 
    LineBox[{{3.5081075538511746`, -4.197962070238288}, {
     4.3779957759034325`, -5.4}}]}, 
   {Hue[0.4607779682211794], AbsoluteThickness[0.5], 
    LineBox[{{8.429330468139579, -0.1826122958678177}, {
     9.75, -0.8044391875272284}}]}, 
   {Hue[0.526965366205783], AbsoluteThickness[0.5], 
    LineBox[{{4.570945105927604, 3.6839737841831632`}, {3.8946168538154025`, 
     4.6}}]}, 
   {Hue[0.5944774571862889], AbsoluteThickness[0.5], 
    LineBox[{{1.8412696457617708`, -1.5384986605398612`}, {
     0.75, -3.162593417328839}}]}, 
   {Hue[0.5749195348212042], AbsoluteThickness[0.5], 
    LineBox[{{3.030147612625989, 3.6891408223000477`}, {2.686133023120541, 
     4.6}}]}, 
   {Hue[0.690173515150318], AbsoluteThickness[0.5], 
    LineBox[{{3.839720893251104, 3.9334259681391184`}, {5.057123652955088, 
     4.6}}]}, 
   {Hue[0.584397074344428], AbsoluteThickness[0.5], 
    LineBox[{{1.849000832544112, -3.566504332745907}, {
     0.75, -4.078987116101209}}]}, 
   {Hue[0.5622102279098514], AbsoluteThickness[0.5], 
    LineBox[{{2.094920728946099, 1.2893399418312028`}, {0.7499999999999998, 
     1.5589961224195128`}}]}, 
   {Hue[0.6066600378354106], AbsoluteThickness[0.5], 
    LineBox[{{1.8571130682154622`, -0.5178558836611052}, {
     0.7499999999999998, -0.7202407445451553}}]}, 
   {Hue[0.6526932913849186], AbsoluteThickness[0.5], 
    LineBox[{{8.239522749438663, -0.06721614685269264}, {9.75, 
     0.9249286096191133}}]}, 
   {Hue[0.3846840503243137], AbsoluteThickness[0.5], 
    LineBox[{{8.420825885483094, -0.16157032324309478`}, {
     9.75, -1.2804773796795539`}}]}, 
   {Hue[0.6957460910477], AbsoluteThickness[0.5], 
    LineBox[{{1.9337668468916682`, 0.4065800783784195}, {
     0.7500000000000002, -0.3811859829795602}}]}, 
   {Hue[0.11970807889718178`], AbsoluteThickness[0.5], 
    LineBox[{{8.450617184266829, -0.8041182156868756}, {
     9.75, -0.783936103806467}}]}, 
   {Hue[0.6745170648300517], AbsoluteThickness[0.5], 
    LineBox[{{2.0999369210436822`, -0.8152657336802517}, {
     0.7499999999999998, -0.45727462721551454`}}]}, 
   {Hue[0.6600189683860339], AbsoluteThickness[0.5], 
    LineBox[{{1.9600685655216916`, -3.1295750351174574`}, {
     0.7500000000000002, -2.8820618143037917`}}]}, 
   {Hue[0.665331167211544], AbsoluteThickness[0.5], 
    LineBox[{{3.026231222541645, -4.68118878265017}, {
     3.427405854297935, -5.4}}]}, 
   {Hue[0.6247663785832993], AbsoluteThickness[0.5], 
    LineBox[{{4.93590655339797, -4.663412666117347}, {
     4.668001841216446, -5.4}}]}, 
   {Hue[0.6370481037546829], AbsoluteThickness[0.5], 
    LineBox[{{2.056385288825266, -4.680470306999031}, {
     1.501206952636006, -5.4}}]}, 
   {Hue[0.6933293151001315], AbsoluteThickness[0.5], 
    LineBox[{{3.770010163461477, -4.451615706743826}, {
     4.1547188842060185`, -5.4}}]}, 
   {Hue[0.4848536604185056], AbsoluteThickness[0.5], 
    LineBox[{{8.441441115664464, -3.3508201067963177`}, {
     9.75, -3.8520781360312424`}}]}, 
   {Hue[0.5703753211272932], AbsoluteThickness[0.5], 
    LineBox[{{1.9395587416653202`, -2.636310910594125}, {
     0.75, -4.399140853870264}}]}, 
   {Hue[0.615340070151943], AbsoluteThickness[0.5], 
    LineBox[{{1.9366430112464637`, 0.5145237818790009}, {0.75, 
     0.9185871115891379}}]}, 
   {Hue[0.5858900571177432], AbsoluteThickness[0.5], 
    LineBox[{{8.271794343534138, 1.6133713067154432`}, {9.75, 
     1.1732739611466032`}}]}, 
   {Hue[0.5226354929464575], AbsoluteThickness[0.5], 
    LineBox[{{1.976988881641963, -4.693501923196791}, {
     0.75, -5.270275817105592}}]}, 
   {Hue[0.6834978207415965], AbsoluteThickness[0.5], 
    LineBox[{{8.351701318053932, -1.8041118206027202`}, {
     9.75, -1.3188836087474836`}}]}, 
   {Hue[0.5952229160641709], AbsoluteThickness[0.5], 
    LineBox[{{1.9237407298776115`, 0.47574334319812034`}, {0.7499999999999998,
      0.6378933057528647}}]}, 
   {Hue[0.6682335888589923], AbsoluteThickness[0.5], 
    LineBox[{{8.382223459857004, 0.21773225895026987`}, {
     9.75, -0.7042462815938743}}]}, 
   {Hue[0.530354565363743], AbsoluteThickness[0.5], 
    LineBox[{{4.363868337063371, -4.682257612531309}, {
     4.777003617358147, -5.4}}]}, 
   {Hue[0.6978076977100574], AbsoluteThickness[0.5], 
    LineBox[{{1.8336924275214526`, -1.4732542376714384`}, {
     0.75, -2.751808218694989}}]}, 
   {Hue[0.695234239880526], AbsoluteThickness[0.5], 
    LineBox[{{4.829779486093567, -4.4154089103162}, {
     4.504975999696271, -5.4}}]}, 
   {Hue[0.27778238702286145`], AbsoluteThickness[0.5], 
    LineBox[{{6.003619497252942, -4.709810653383114}, {
     6.55821761485146, -5.4}}]}, 
   {Hue[0.5922546916606546], AbsoluteThickness[0.5], 
    LineBox[{{6.297222573089578, 3.8423133011994732`}, {7.62821459462911, 
     4.6}}]}, 
   {Hue[0.501587552292886], AbsoluteThickness[0.5], 
    LineBox[{{3.63725413540805, 3.798713404170469}, {2.172125336314336, 
     4.6}}]}, 
   {Hue[0.6983543070875408], AbsoluteThickness[0.5], 
    LineBox[{{8.163318110417054, 2.105528202222812}, {9.75, 
     0.24779668996665583`}}]}, 
   {Hue[0.36754409078655303`], AbsoluteThickness[0.5], 
    LineBox[{{8.347104600707908, 2.179466320375446}, {9.75, 
     3.0632599611784057`}}]}, 
   {Hue[0.589278211418733], AbsoluteThickness[0.5], 
    LineBox[{{1.907234740423717, -1.6221795647070467`}, {
     0.75, -1.9194016548622193`}}]}, 
   {Hue[0.6056702769657343], AbsoluteThickness[0.5], 
    LineBox[{{8.323360768520535, 1.4561817774912749`}, {9.75, 
     1.960356213170121}}]}, 
   {Hue[0.696381171485017], AbsoluteThickness[0.5], 
    LineBox[{{8.354599139732844, 2.3009631612452894`}, {9.75, 
     2.5857253659112494`}}]}, 
   {Hue[0.4939126687754557], AbsoluteThickness[0.5], 
    LineBox[{{8.24845679086599, -0.40606029300606894`}, {
     9.75, -1.681968561486069}}]}, 
   {Hue[0.056746322996893035`], AbsoluteThickness[0.5], 
    LineBox[{{8.419264243665063, 2.765055051254562}, {9.75, 
     3.7787840699566844`}}]}, 
   {Hue[0.41961928984574237`], AbsoluteThickness[0.5], 
    LineBox[{{8.27870320829224, 0.6216346026934134}, {
     9.75, -0.8489193519297763}}]}, 
   {Hue[0.6850074193611612], AbsoluteThickness[0.5], 
    LineBox[{{4.837975572840485, 3.862210742265206}, {5.126850465223861, 
     4.6}}]}, 
   {Hue[0.35666599769264756`], AbsoluteThickness[0.5], 
    LineBox[{{8.15628943865821, 2.4596173053357795`}, {9.75, 
     2.94394665855145}}]}, 
   {Hue[0.6313846869469737], AbsoluteThickness[0.5], 
    LineBox[{{6.648964727819394, 3.9057973396696273`}, {5.5812430885986, 
     4.6}}]}, 
   {Hue[0.6938692384039176], AbsoluteThickness[0.5], 
    LineBox[{{8.251205735770823, 0.9375635866250075}, {9.75, 
     1.7923634985890784`}}]}, 
   {Hue[0.6554877714199785], AbsoluteThickness[0.5], 
    LineBox[{{8.154363259274254, 2.495569178994785}, {9.75, 
     3.015841657679229}}]}, 
   {Hue[0.6531146308135293], AbsoluteThickness[0.5], 
    LineBox[{{8.449650508536998, -3.2812750062343294`}, {
     9.75, -3.786471848040794}}]}, 
   {Hue[0.6522423305758316], AbsoluteThickness[0.5], 
    LineBox[{{2.0212385610678707`, -2.651444689244636}, {
     0.75, -5.025040549140214}}]}, 
   {Hue[0.6841519702210888], AbsoluteThickness[0.5], 
    LineBox[{{8.321066090134172, -1.8522307229926285`}, {
     9.75, -1.052843763113267}}]}, 
   {Hue[0.6455014649868321], AbsoluteThickness[0.5], 
    LineBox[{{8.27857172176629, -2.6015687816946746`}, {
     9.75, -1.336400937542062}}]}, 
   {Hue[0.24424057714420314`], AbsoluteThickness[0.5], 
    LineBox[{{8.468193424002491, -2.8013549820143013`}, {
     9.75, -4.583643465571077}}]}, 
   {Hue[0.6579970448701475], AbsoluteThickness[0.5], 
    LineBox[{{8.374594675143245, -1.1357354187474387`}, {
     9.75, -0.18244167425016178`}}]}, 
   {Hue[0.558378393022526], AbsoluteThickness[0.5], 
    LineBox[{{8.227932108697644, 0.6115350012692857}, {
     9.75, -0.7489921922055115}}]}, 
   {Hue[0.4119981532306696], AbsoluteThickness[0.5], 
    LineBox[{{3.0573858926927096`, 3.776833976489408}, {2.11860967901547, 
     4.6}}]}, 
   {Hue[0.5761482723014189], AbsoluteThickness[0.5], 
    LineBox[{{8.301484984920078, -2.391148681626046}, {
     9.75, -3.55172180584983}}]}, 
   {Hue[0.6397617419270886], AbsoluteThickness[0.5], 
    LineBox[{{3.812007353556518, 3.4284144011240247`}, {2.991959463064379, 
     4.6}}]}, 
   {Hue[0.5618746290519624], AbsoluteThickness[0.5], 
    LineBox[{{1.9617230760765, -3.130464610862816}, {
     0.75, -5.217734109336741}}]}, 
   {Hue[0.2412805730421009], AbsoluteThickness[0.5], 
    LineBox[{{7.881844528438306, 3.8649764211033224`}, {8.405730113408904, 
     4.6}}]}, 
   {Hue[0.6482219052271868], AbsoluteThickness[0.5], 
    LineBox[{{2.5691688328505355`, -4.670589441838488}, {
     2.1033661664440224`, -5.4}}]}, 
   {Hue[0.5409331405418263], AbsoluteThickness[0.5], 
    LineBox[{{6.611200085437479, -4.658292226312249}, {
     6.900597605822186, -5.4}}]}, 
   {Hue[0.5947349205080326], AbsoluteThickness[0.5], 
    LineBox[{{4.069152240593838, 3.6719786092446527`}, {3.628509580812656, 
     4.6}}]}, 
   {Hue[0.6746547225497684], AbsoluteThickness[0.5], 
    LineBox[{{8.426015205107939, -0.2986464339759695}, {9.75, 
     0.2086222366050664}}]}, 
   {Hue[0.6849160679790416], AbsoluteThickness[0.5], 
    LineBox[{{6.752029282274451, 3.919803111211337}, {7.24636348380743, 
     4.6}}]}, 
   {Hue[0.6490000645587922], AbsoluteThickness[0.5], 
    LineBox[{{4.918515517193298, -4.658215871261835}, {
     4.746753515990255, -5.4}}]}, 
   {Hue[0.6313371597673744], AbsoluteThickness[0.5], 
    LineBox[{{3.1654947037103853`, 3.9126665373461273`}, {3.020304362262965, 
     4.6}}]}, 
   {Hue[0.6509959904860833], AbsoluteThickness[0.5], 
    LineBox[{{7.149653028436006, 3.6438485657309787`}, {6.547158940674604, 
     4.6}}]}, 
   {Hue[0.6640442611441303], AbsoluteThickness[0.5], 
    LineBox[{{7.1614249883340175`, 3.8009018388327367`}, {7.5598913140054815`,
      4.6}}]}, 
   {Hue[0.629633385966178], AbsoluteThickness[0.5], 
    LineBox[{{4.437770221668245, -4.711282191217022}, {
     4.487401257311898, -5.4}}]}, 
   {Hue[0.5221771407895397], AbsoluteThickness[0.5], 
    LineBox[{{4.917334173681919, -4.657785243917121}, {
     5.0242708755511485`, -5.4}}]}, 
   {Hue[0.4109044225563916], AbsoluteThickness[0.5], 
    LineBox[{{5.141022204835036, 3.910238840310721}, {3.9868865025744027`, 
     4.6}}]}, 
   {Hue[0.6981462101068789], AbsoluteThickness[0.5], 
    LineBox[{{4.999700178590435, -4.6659146505953055`}, {
     4.930558848952948, -5.4}}]}, 
   {Hue[0.6127408224866635], AbsoluteThickness[0.5], 
    LineBox[{{7.9434173961103625`, -1.3020150499462226`}, {
     9.75, -2.181745008181144}}]}, 
   {Hue[0.628311309402158], AbsoluteThickness[0.5], 
    LineBox[{{4.1163644726217425`, 3.815705422576748}, {3.0493527862991847`, 
     4.6}}]}, 
   {Hue[0.6444917410181203], AbsoluteThickness[0.5], 
    LineBox[{{8.341711659980321, 2.5989936553164505`}, {9.75, 
     2.7325627553727125`}}]}, 
   {Hue[0.6525542011440433], AbsoluteThickness[0.5], 
    LineBox[{{2.542712226420876, 3.767325132042177}, {1.7327328061997633`, 
     4.6}}]}, 
   {Hue[0.6785949853865182], AbsoluteThickness[0.5], 
    LineBox[{{1.9141226635352826`, -2.078180612399867}, {
     0.75, -2.349438777430201}}]}, 
   {Hue[0.6758296923073895], AbsoluteThickness[0.5], 
    LineBox[{{2.069419752768739, -0.7713630141231064}, {
     0.75, -0.5498652761080112}}]}, 
   {Hue[0.6338948511472535], AbsoluteThickness[0.5], 
    LineBox[{{7.261437885400475, -4.370052800262218}, {
     7.800999760712571, -5.4}}]}, 
   {Hue[0.6459391783748798], AbsoluteThickness[0.5], 
    LineBox[{{2.1138178255006665`, -2.7751872693517066`}, {
     0.75, -3.068661111720931}}]}, 
   {Hue[0.6017962152618016], AbsoluteThickness[0.5], 
    LineBox[{{1.7917771748607272`, -0.9336471814074092}, {
     0.7500000000000002, -1.0629511441535417`}}]}, 
   {Hue[0.5576889428114032], AbsoluteThickness[0.5], 
    LineBox[{{4.573171297086786, 3.683571698151923}, {4.352411323837587, 
     4.6}}]}, 
   {Hue[0.4808239020742329], AbsoluteThickness[0.5], 
    LineBox[{{6.893885522823127, 3.7438287409999873`}, {7.18838971302459, 
     4.6}}]}, 
   {Hue[0.30520502972046715`], AbsoluteThickness[0.5], 
    LineBox[{{6.800272548374458, 3.903720781093537}, {6.069120772123067, 
     4.6}}]}, 
   {Hue[0.36573953328809916`], AbsoluteThickness[0.5], 
    LineBox[{{3.3587480505349756`, -4.68734704091687}, {
     0.7499999999999996, -5.125850098632721}}]}, 
   {Hue[0.5648214558951759], AbsoluteThickness[0.5], 
    LineBox[{{4.651809971392609, 3.8038694445228023`}, {4.39701590260303, 
     4.6}}]}, 
   {Hue[0.518419851065097], AbsoluteThickness[0.5], 
    LineBox[{{8.446850603323314, -3.2645115230631143`}, {
     9.75, -3.595753630408184}}]}, 
   {Hue[0.696588890487912], AbsoluteThickness[0.5], 
    LineBox[{{3.7750118905819083`, 3.939447915006459}, {2.958252982055162, 
     4.6}}]}, 
   {Hue[0.6005163767894517], AbsoluteThickness[0.5], 
    LineBox[{{1.8559634213328087`, 3.526803432819854}, {0.75, 
     4.429477897931195}}]}, 
   {Hue[0.6859968542432232], AbsoluteThickness[0.5], 
    LineBox[{{4.438249771434392, 3.64110877179139}, {4.5797851779407885`, 
     4.6}}]}, 
   {Hue[0.6358237093930043], AbsoluteThickness[0.5], 
    LineBox[{{3.5212355919665574`, -4.704114879370452}, {
     3.1065999724268507`, -5.4}}]}, 
   {Hue[0.5831016382934274], AbsoluteThickness[0.5], 
    LineBox[{{1.878673661752114, 2.0156091967941157`}, {0.75, 
     2.9784931640198207`}}]}, 
   {Hue[0.5953245923128571], AbsoluteThickness[0.5], 
    LineBox[{{1.8432228443194083`, 1.4414151804773183`}, {0.75, 
     2.2283054123819723`}}]}, 
   {Hue[0.6444745994836482], AbsoluteThickness[0.5], 
    LineBox[{{7.917038938468622, -4.660396701675549}, {
     7.65955939470029, -5.4}}]}, 
   {Hue[0.39434735480304156`], AbsoluteThickness[0.5], 
    LineBox[{{5.932716905950035, 3.848763816472477}, {5.876651740954071, 
     4.6}}]}, 
   {Hue[0.6911021308829102], AbsoluteThickness[0.5], 
    LineBox[{{5.735198261317041, 3.9294781084131745`}, {2.0388194432424114`, 
     4.6}}]}, 
   {Hue[0.6136251037100584], AbsoluteThickness[0.5], 
    LineBox[{{8.26895824250015, 3.998397728479294}, {8.244928632715055, 
     4.6}}]}, 
   {Hue[0.4357601321019392], AbsoluteThickness[0.5], 
    LineBox[{{2.0597728629994405`, -0.7459586893713026}, {
     0.75, -1.366585069281561}}]}, 
   {Hue[0.5175158957589158], AbsoluteThickness[0.5], 
    LineBox[{{2.143810223478889, -2.1336762109413923`}, {
     0.7500000000000002, -2.1470971068010765`}}]}, 
   {Hue[0.6111301654513305], AbsoluteThickness[0.5], 
    LineBox[{{8.119030178520674, -3.1516463896895437`}, {
     9.75, -3.0718520237272275`}}]}, 
   {Hue[0.5547481961936981], AbsoluteThickness[0.5], 
    LineBox[{{4.6828838357235965`, 3.839502812947185}, {4.499520732268831, 
     4.6}}]}, 
   {Hue[0.5664371678014559], AbsoluteThickness[0.5], 
    LineBox[{{1.8763600478094447`, -3.600805945301011}, {
     0.7500000000000002, -4.563803862147914}}]}, 
   {Hue[0.6686337911957324], AbsoluteThickness[0.5], 
    LineBox[{{8.36204238602026, -1.7503042236506916`}, {
     9.75, -2.8491056395421173`}}]}, 
   {Hue[0.5311696758252655], AbsoluteThickness[0.5], 
    LineBox[{{4.219455912824971, 3.8693715457280367`}, {3.7524606840096792`, 
     4.6}}]}, 
   {Hue[0.675743287261428], AbsoluteThickness[0.5], 
    LineBox[{{2.11022671314051, 3.818196092846386}, {1.194983252647856, 
     4.6}}]}, 
   {Hue[0.5658896433927924], AbsoluteThickness[0.5], 
    LineBox[{{8.445809000590584, -4.378871353628191}, {
     9.037075188073572, -5.4}}]}, 
   {Hue[0.5448014520365899], AbsoluteThickness[0.5], 
    LineBox[{{8.156324702606854, -4.505890657251756}, {
     9.75, -5.202394325854792}}]}, 
   {Hue[0.5772011655358495], AbsoluteThickness[0.5], 
    LineBox[{{2.0997434441958025`, 0.215204222004802}, {0.75, 
     0.4176956048416367}}]}, 
   {Hue[0.689849977585802], AbsoluteThickness[0.5], 
    LineBox[{{1.855576098515073, 3.5238810585050175`}, {0.75, 
     4.558475011755909}}]}, 
   {Hue[0.58819867423172], AbsoluteThickness[0.5], 
    LineBox[{{5.841901861586191, -4.633647239394128}, {
     6.0186317188418545`, -5.4}}]}, 
   {Hue[0.6870850748165642], AbsoluteThickness[0.5], 
    LineBox[{{4.623256254340471, 3.6643727566065047`}, {4.247733765524959, 
     4.6}}]}, 
   {Hue[0.5890625331654884], AbsoluteThickness[0.5], 
    LineBox[{{1.8918709965230673`, 3.6051333013175766`}, {1.287586660916232, 
     4.6}}]}, 
   {Hue[0.6338386574581287], AbsoluteThickness[0.5], 
    LineBox[{{8.061928960346819, -4.655920873090138}, {
     9.75, -4.616520180865657}}]}, 
   {Hue[0.5515029351370383], AbsoluteThickness[0.5], 
    LineBox[{{6.428319308331606, 3.66262069100383}, {6.164779038983545, 
     4.6}}]}, 
   {Hue[0.6671755740552652], AbsoluteThickness[0.5], 
    LineBox[{{1.8168600927779441`, 1.5418524044478945`}, {0.75, 
     1.6313088632221708`}}]}, 
   {Hue[0.6310745501937177], AbsoluteThickness[0.5], 
    LineBox[{{4.965471775693526, -4.667695260196255}, {
     5.013520665207753, -5.4}}]}, 
   {Hue[0.6869085748892723], AbsoluteThickness[0.5], 
    LineBox[{{5.135547946887427, 3.906722677806359}, {5.332692504354648, 
     4.6}}]}, 
   {Hue[0.6251506845151219], AbsoluteThickness[0.5], 
    LineBox[{{8.154538605057787, -4.47769080408213}, {
     9.197033101974348, -5.4}}]}, 
   {Hue[0.6981035121279812], AbsoluteThickness[0.5], 
    LineBox[{{8.386744392057254, -1.1536418167854712`}, {
     9.75, -1.3141483534035145`}}]}, 
   {Hue[0.6861079826307859], AbsoluteThickness[0.5], 
    LineBox[{{1.7862693127230944`, 2.460335074068138}, {0.75, 
     2.504395831795081}}]}, 
   {Hue[0.6815313724592321], AbsoluteThickness[0.5], 
    LineBox[{{6.082197316082534, -4.681430041973885}, {
     5.9354801635597285`, -5.4}}]}, 
   {Hue[0.5851684298465674], AbsoluteThickness[0.5], 
    LineBox[{{1.9146357314859304`, 2.910229791554978}, {0.7500000000000002, 
     3.3339756097168594`}}]}, 
   {Hue[0.25113279961071716`], AbsoluteThickness[0.5], 
    LineBox[{{7.578650454369959, -4.632294647310723}, {
     7.295967682643557, -5.4}}]}, 
   {Hue[0.6212407576925484], AbsoluteThickness[0.5], 
    LineBox[{{6.032061240190912, 3.5953896284060005`}, {6.021196806907669, 
     4.6}}]}, 
   {Hue[0.5935055302234786], AbsoluteThickness[0.5], 
    LineBox[{{1.9102958766228246`, 2.134180923400093}, {0.75, 
     2.239947269989799}}]}, 
   {Hue[0.5791095796077579], AbsoluteThickness[0.5], 
    LineBox[{{2.0841563397549967`, 0.25635327038414235`}, {0.7500000000000002,
      0.30780350601989837`}}]}, 
   {Hue[0.5793491166489294], AbsoluteThickness[0.5], 
    LineBox[{{2.083972713750846, 0.2573987179929717}, {0.75, 
     0.35897689025224555`}}]}, 
   {Hue[0.5830994158549607], AbsoluteThickness[0.5], 
    LineBox[{{2.5431549862340614`, 3.7774895693576154`}, {1.1745725500529787`,
      4.6}}]}, 
   {Hue[0.5930634264466639], AbsoluteThickness[0.5], 
    LineBox[{{1.883223223119023, -3.6069504926856597`}, {
     0.75, -4.836572007813797}}]}, 
   {Hue[0.6691265523040327], AbsoluteThickness[0.5], 
    LineBox[{{2.992391446336379, -4.683635291843589}, {
     0.8923363546536702, -5.4}}]}, 
   {Hue[0.699327821586375], AbsoluteThickness[0.5], 
    LineBox[{{2.177729415183039, 1.849209950953191}, {0.7500000000000002, 
     2.1207136343421356`}}]}, 
   {Hue[0.4227060772459806], AbsoluteThickness[0.5], 
    LineBox[{{6.012744551646769, -4.708623849938242}, {
     5.86336553894649, -5.4}}]}, 
   {Hue[0.6628736353743067], AbsoluteThickness[0.5], 
    LineBox[{{1.8333635891759976`, -1.4773399295486607`}, {
     0.75, -2.6250330350031983`}}]}, 
   {Hue[0.6582271960456166], AbsoluteThickness[0.5], 
    LineBox[{{4.894558997420646, -4.647345039868695}, {
     4.240546119807778, -5.4}}]}, 
   {Hue[0.6894676311620385], AbsoluteThickness[0.5], 
    LineBox[{{5.323141578390029, -4.443889024797092}, {
     4.811819978497938, -5.4}}]}, 
   {Hue[0.6376023034286703], AbsoluteThickness[0.5], 
    LineBox[{{3.877000673008314, -4.543892382096527}, {
     2.05289314930585, -5.4}}]}, 
   {Hue[0.6099906153825081], AbsoluteThickness[0.5], 
    LineBox[{{1.9746944120451517`, 3.0933981261057175`}, {0.75, 
     3.949255510262567}}]}, 
   {Hue[0.6514431744872575], AbsoluteThickness[0.5], 
    LineBox[{{1.8597472715506411`, 2.6176782062606168`}, {0.75, 
     2.6047926920980875`}}]}, 
   {Hue[0.6963956852485964], AbsoluteThickness[0.5], 
    LineBox[{{8.413902000532918, 2.795212123577022}, {9.75, 
     2.2104951146378564`}}]}, 
   {Hue[0.6625279882053953], AbsoluteThickness[0.5], 
    LineBox[{{1.8415148544618527`, -4.458730731076645}, {
     0.75, -4.595223821482342}}]}, 
   {Hue[0.6500489829232793], AbsoluteThickness[0.5], 
    LineBox[{{1.9970164508298114`, -2.1176859496806686`}, {
     0.75, -2.5022602780510868`}}]}, 
   {Hue[0.6926241455441084], AbsoluteThickness[0.5], 
    LineBox[{{2.109472659012798, 1.3155556839715625`}, {0.75, 
     1.2841720623119444`}}]}, 
   {Hue[0.5413581906151186], AbsoluteThickness[0.5], 
    LineBox[{{1.8833428754513182`, 0.8712216935182996}, {
     0.75, -3.4441762054854768`}}]}, 
   {Hue[0.6395277326798808], AbsoluteThickness[0.5], 
    LineBox[{{2.5765755981535894`, -4.6694875814119605`}, {
     2.435632332828715, -5.4}}]}, 
   {Hue[0.5797282416354769], AbsoluteThickness[0.5], 
    LineBox[{{3.9578556332833443`, -4.641304200136824}, {
     3.6386570606560826`, -5.4}}]}, 
   {Hue[0.5740796695524492], AbsoluteThickness[0.5], 
    LineBox[{{1.897745588716595, 2.9713433834200074`}, {0.75, 
     2.9918206340238385`}}]}, 
   {Hue[0.6389715967291059], AbsoluteThickness[0.5], 
    LineBox[{{1.925069544990799, 2.894564211763571}, {0.7500000000000002, 
     2.9999159110082387`}}]}, 
   {Hue[0.6817891561042149], AbsoluteThickness[0.5], 
    LineBox[{{7.461887260631291, -4.630841244592836}, {
     7.3738293119294855`, -5.4}}]}, 
   {Hue[0.6991179894716517], AbsoluteThickness[0.5], 
    LineBox[{{6.427116626096466, 3.662260879914916}, {6.540102695880913, 
     4.6}}]}, 
   {Hue[0.6142495776064949], AbsoluteThickness[0.5], 
    LineBox[{{1.8260215575053518`, -4.5382259898298045`}, {
     0.75, -5.260928969402239}}]}, 
   {Hue[0.6909764258014958], AbsoluteThickness[0.5], 
    LineBox[{{1.9488316238772307`, 3.645766748680555}, {1.1802354822446972`, 
     4.6}}]}, 
   {Hue[0.6755786460611041], AbsoluteThickness[0.5], 
    LineBox[{{3.505226697262981, 3.6388030010311345`}, {2.9741329507657315`, 
     4.6}}]}, 
   {Hue[0.6776832571462226], AbsoluteThickness[0.5], 
    LineBox[{{1.8596649861434087`, 3.4660232999235747`}, {0.7499999999999998, 
     3.1940899598688723`}}]}, 
   {Hue[0.5478069097228044], AbsoluteThickness[0.5], 
    LineBox[{{2.584430383230937, 1.214915504907811}, {
     0.7500000000000002, -0.12155502480912783`}}]}, 
   {Hue[0.6860441233574426], AbsoluteThickness[0.5], 
    LineBox[{{3.7752892297349536`, -4.452034285794259}, {
     3.6929319749879213`, -5.4}}]}, 
   {Hue[0.6028864142775858], AbsoluteThickness[0.5], 
    LineBox[{{1.9661711872713532`, 2.859743926811792}, {0.75, 
     2.714601038902809}}]}, 
   {Hue[0.6503612875821926], AbsoluteThickness[0.5], 
    LineBox[{{1.8879609830033097`, -2.9128846728754083`}, {
     0.75, -3.7025396990278328`}}]}, 
   {Hue[0.6778972429272008], AbsoluteThickness[0.5], 
    LineBox[{{2.077436029657013, 3.7591572116466687`}, {0.9489970908376328, 
     4.6}}]}, 
   {Hue[0.6689511431083759], AbsoluteThickness[0.5], 
    LineBox[{{4.813662243085376, -4.426588572104751}, {
     4.407904100625754, -5.4}}]}, 
   {Hue[0.69904961268807], AbsoluteThickness[0.5], 
    LineBox[{{4.937796761354977, -4.663853473219575}, {
     4.582888440710651, -5.4}}]}, 
   {Hue[0.6597515885397359], AbsoluteThickness[0.5], 
    LineBox[{{5.510345275135512, -4.65551934872902}, {
     5.681373808746858, -5.4}}], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJw0unVU0+///78N2GjG6DYRQV8qIgqo10NRQpE2QMEAFRFBAVExEKREJFUk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      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5661014912586393`*^9, 3.614727899334916*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->
  "During evaluation of \
In[280]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData["14.51469799999999921169546723831444978714`7.182407917395096"], \
"Output",
 CellChangeTimes->{3.566101535402987*^9, 3.61472789933687*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"Out[280]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[TurboPlot[
\t{Move[LineOfRays[.5, IntrinsicMedium->1.3, NumberOfRays->7],{0,-4}, 55],
\trodlens,
\tMove[ClearBoundary[9,10],{.75,-.4}]},
\tPlotType->TopView, ThresholdIntensity->.1, ReportedSurfaces->All, \
ColorView->Log[Intensity],
\tCreateClones -> randomclonedata, ShowClones->False, \
RunningCommentary->TurboTrace]][[1]]\
\>", "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"In[281]:="],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147278999050913`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727899907785*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727899909604*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727899910887*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.1`"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "False"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "0.1`"}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"ColorView", "\[Rule]", 
        RowBox[{"Log", "[", "Intensity", "]"}]}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9907689222339402`", ",", 
              RowBox[{"-", "4.529077150335811`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0233663468946883`", ",", 
              RowBox[{"-", "3.99105399895926`"}]}], "}"}], ",", "1", ",", 
            "0.33590735268637717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9858554053727502`", ",", 
              RowBox[{"-", "3.485409892311437`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0401710867365628`", ",", 
              RowBox[{"-", "2.9825767694748495`"}]}], "}"}], ",", "1", ",", 
            "0.33481280744268754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0101577616097117`", ",", 
              RowBox[{"-", "2.4832623444953508`"}]}], "}"}], ",", "1", ",", 
            "0.3370939643600844`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0260706177641596`", ",", 
              RowBox[{"-", "1.950001373046383`"}]}], "}"}], ",", "1", ",", 
            "0.3403660491721731`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9913871279479374`", ",", 
              RowBox[{"-", "1.488002430284238`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9648388984333083`", ",", 
              RowBox[{"-", "1.016901462993699`"}]}], "}"}], ",", "1", ",", 
            "0.38409184093579324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.001113922823207`", ",", 
              RowBox[{"-", "0.45088421904366716`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.958570210111544`", ",", 
              RowBox[{"-", "0.02152209955274949`"}]}], "}"}], ",", "1", ",", 
            "0.3861241577085539`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0427467330474878`", ",", "0.4576864744029721`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.991600406298163`", ",", "1.0008380278066993`"}], 
             "}"}], ",", "1", ",", "0.33775782507244856`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0019778108135475`", ",", "1.5367636247387837`"}], 
             "}"}], ",", "1", ",", "0.3703752972844546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.018234059403475`", ",", "2.0418920267659595`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.9661224054407973`", ",", "2.4721735170502206`"}], 
             "}"}], ",", "1", ",", "0.36048458326182337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.028062972666912`", ",", "2.9744687962408087`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.0059646438310854`", ",", "3.505435861545571`"}], 
             "}"}], ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2019923549027527`", ",", 
              RowBox[{"-", "4.2755298307128085`"}]}], "}"}], ",", "1", ",", 
            "0.3300023966525176`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2145775158831484`", ",", 
              RowBox[{"-", "3.7065617081701907`"}]}], "}"}], ",", "1", ",", 
            "0.318153939931529`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2871534564694445`", ",", 
              RowBox[{"-", "3.2086283677191094`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.263463593059942`", ",", 
              RowBox[{"-", "2.7056774891265234`"}]}], "}"}], ",", "1", ",", 
            "0.3300028199598174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2785832463579005`", ",", 
              RowBox[{"-", "2.2371062681663596`"}]}], "}"}], ",", "1", ",", 
            "0.33977371548432994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.270716860012454`", ",", 
              RowBox[{"-", "1.7133639635294955`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2369828400597376`", ",", 
              RowBox[{"-", "1.2879442959730592`"}]}], "}"}], ",", "1", ",", 
            "0.31676570349672006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2187390491989065`", ",", 
              RowBox[{"-", "0.7001275882682791`"}]}], "}"}], ",", "1", ",", 
            "0.3308820828217743`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2687487806562627`", ",", 
              RowBox[{"-", "0.27983632273901843`"}]}], "}"}], ",", "1", ",", 
            "0.31762525081858006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.202616643758109`", ",", "0.27769889468150044`"}], 
             "}"}], ",", "1", ",", "0.24073619836787136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2906858079893504`", ",", "0.7956948810201728`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2466519999270234`", ",", "1.222263033135929`"}], 
             "}"}], ",", "1", ",", "0.3317932505256897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2886934530865974`", ",", "1.7712247117329811`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.232074484043875`", ",", "2.2288247413061195`"}], 
             "}"}], ",", "1", ",", "0.2840274053251544`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.201539996617153`", ",", "2.7798530794520904`"}], 
             "}"}], ",", "1", ",", "0.2607097141646608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2686108909839335`", ",", "3.234502230432643`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.2229567502592524`", ",", "3.71695934761845`"}], "}"}],
             ",", "1", ",", "0.30303095454516915`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5478940309714795`", ",", 
              RowBox[{"-", "4.502133806037861`"}]}], "}"}], ",", "1", ",", 
            "0.3395875052353165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.535973910199515`", ",", 
              RowBox[{"-", "4.04509635640849`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.529154981772573`", ",", 
              RowBox[{"-", "3.502006217769582`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4672251295432526`", ",", 
              RowBox[{"-", "2.9652600336694723`"}]}], "}"}], ",", "1", ",", 
            "0.3027440395147296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5265383380144644`", ",", 
              RowBox[{"-", "2.4797051124510827`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4765393215539024`", ",", 
              RowBox[{"-", "1.9609549146896452`"}]}], "}"}], ",", "1", ",", 
            "0.32196919848235284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4798863380874407`", ",", 
              RowBox[{"-", "1.5019681455870117`"}]}], "}"}], ",", "1", ",", 
            "0.2973887395341897`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.487845868467305`", ",", 
              RowBox[{"-", "1.0321796264226264`"}]}], "}"}], ",", "1", ",", 
            "0.3582566471289234`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.547811854043566`", ",", 
              RowBox[{"-", "0.5307928868931314`"}]}], "}"}], ",", "1", ",", 
            "0.3387291298978924`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.486305871850152`", ",", 
              RowBox[{"-", "0.012032705874716706`"}]}], "}"}], ",", "1", ",", 
            "0.34503603454472387`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.479200963059632`", ",", "0.5347048826742254`"}], 
             "}"}], ",", "1", ",", "0.32195301354046985`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.463349121590899`", ",", "0.9710079465068331`"}], 
             "}"}], ",", "1", ",", "0.24606359095607133`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.481306932088153`", ",", "1.4868386887120868`"}], 
             "}"}], ",", "1", ",", "0.34347541743583815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.477375211391384`", ",", "1.9661043029153238`"}], 
             "}"}], ",", "1", ",", "0.2712542367897372`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5021519503155796`", ",", "2.538844906481669`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.4601500818481314`", ",", "2.981364336584796`"}], 
             "}"}], ",", "1", ",", "0.317436694379581`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.5256136123011155`", ",", "3.468550018932752`"}], 
             "}"}], ",", "1", ",", "0.3476043240039293`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.783610760294229`", ",", 
              RowBox[{"-", "4.257680748725559`"}]}], "}"}], ",", "1", ",", 
            "0.3263680949199062`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457272742136745`", ",", 
              RowBox[{"-", "3.729481835480237`"}]}], "}"}], ",", "1", ",", 
            "0.31408392907953414`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7457648918269237`", ",", 
              RowBox[{"-", "3.2755011223029324`"}]}], "}"}], ",", "1", ",", 
            "0.3134077398631213`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.747915420170109`", ",", 
              RowBox[{"-", "2.7486889485871053`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.709459019976772`", ",", 
              RowBox[{"-", "2.2134684164282157`"}]}], "}"}], ",", "1", ",", 
            "0.32302005231676906`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7187144571104764`", ",", 
              RowBox[{"-", "1.7333938312613306`"}]}], "}"}], ",", "1", ",", 
            "0.33231437370795947`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7961098983858728`", ",", 
              RowBox[{"-", "1.2344763629350488`"}]}], "}"}], ",", "1", ",", 
            "0.29752851014228643`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.787407525022324`", ",", 
              RowBox[{"-", "0.7702325199734176`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7687346869944887`", ",", 
              RowBox[{"-", "0.25058066585037264`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7352555747067444`", ",", "0.24092257354491342`"}], 
             "}"}], ",", "1", ",", "0.3549117185141242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7585846051463574`", ",", "0.7180549975648313`"}], 
             "}"}], ",", "1", ",", "0.32968191365164135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7596419624056288`", ",", "1.2223725546121618`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7749738448521284`", ",", "1.77573574629039`"}], "}"}],
             ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7139146881919545`", ",", "2.2518543900923986`"}], 
             "}"}], ",", "1", ",", "0.3566609225164404`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7292089530252044`", ",", "2.7512368685933226`"}], 
             "}"}], ",", "1", ",", "0.31091032155449055`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7659992680218455`", ",", "3.2005433386795037`"}], 
             "}"}], ",", "1", ",", "0.32034941890174845`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.7197499330484325`", ",", "3.764705285021538`"}], 
             "}"}], ",", "1", ",", "0.35411418026594893`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.997284810911369`", ",", 
              RowBox[{"-", "4.516062830059166`"}]}], "}"}], ",", "1", ",", 
            "0.3352877866272839`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9736400346625596`", ",", 
              RowBox[{"-", "3.950818352043413`"}]}], "}"}], ",", "1", ",", 
            "0.3177012432140486`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.009877285889045`", ",", 
              RowBox[{"-", "3.5458303100857482`"}]}], "}"}], ",", "1", ",", 
            "0.32171899453998787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.004905347668071`", ",", 
              RowBox[{"-", "3.0002376861930404`"}]}], "}"}], ",", "1", ",", 
            "0.3467949266799934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9746217111823006`", ",", 
              RowBox[{"-", "2.4867528836306616`"}]}], "}"}], ",", "1", ",", 
            "0.34641917456943816`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0463207425217136`", ",", 
              RowBox[{"-", "2.018292683757872`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0149797487766716`", ",", 
              RowBox[{"-", "1.5091254382428234`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.971346897669585`", ",", 
              RowBox[{"-", "0.9940284300482617`"}]}], "}"}], ",", "1", ",", 
            "0.2896865585009006`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0010650605847173`", ",", 
              RowBox[{"-", "0.4609798283352218`"}]}], "}"}], ",", "1", ",", 
            "0.31344091957959347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0421379446443804`", ",", 
              RowBox[{"-", "0.04526529864158411`"}]}], "}"}], ",", "1", ",", 
            "0.3238470687237391`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.035065792562872`", ",", "0.5384768329852746`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.022388011595948`", ",", "0.9900294163368778`"}], 
             "}"}], ",", "1", ",", "0.35074038870470764`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.987780981651503`", ",", "1.5045396630444403`"}], 
             "}"}], ",", "1", ",", "0.3447233572601251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"2.9987479769333882`", ",", "1.9908477683802908`"}], 
             "}"}], ",", "1", ",", "0.3103998135249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0279036957624585`", ",", "2.5003699731301885`"}], 
             "}"}], ",", "1", ",", "0.3754926150324537`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0438426292653173`", ",", "3.0410854545733312`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.0032819845801577`", ",", "3.53712285676085`"}], "}"}],
             ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2975218867436036`", ",", 
              RowBox[{"-", "4.240621861668797`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.288302235803486`", ",", 
              RowBox[{"-", "3.753751704996327`"}]}], "}"}], ",", "1", ",", 
            "0.34749353835203883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2761749890740184`", ",", 
              RowBox[{"-", "3.2965934316205354`"}]}], "}"}], ",", "1", ",", 
            "0.3111230989400495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2372371752187687`", ",", 
              RowBox[{"-", "2.742771876661105`"}]}], "}"}], ",", "1", ",", 
            "0.33162162206011914`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2840370444296383`", ",", 
              RowBox[{"-", "2.201328132978951`"}]}], "}"}], ",", "1", ",", 
            "0.3000183592121354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2521713826558964`", ",", 
              RowBox[{"-", "1.7312487096463796`"}]}], "}"}], ",", "1", ",", 
            "0.3249594111290117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2116490328336904`", ",", 
              RowBox[{"-", "1.241357549315829`"}]}], "}"}], ",", "1", ",", 
            "0.3322325234409171`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.214390401004393`", ",", 
              RowBox[{"-", "0.7857883726908198`"}]}], "}"}], ",", "1", ",", 
            "0.3200532237011332`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.262901055900302`", ",", 
              RowBox[{"-", "0.28220531769611984`"}]}], "}"}], ",", "1", ",", 
            "0.3170463910804746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.236486705241935`", ",", "0.26384165417899186`"}], 
             "}"}], ",", "1", ",", "0.3284667372650815`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.269058426634985`", ",", "0.7267092277305489`"}], 
             "}"}], ",", "1", ",", "0.3003064888269091`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2832047206617774`", ",", "1.276718797418142`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.271536539891381`", ",", "1.767331089399346`"}], "}"}],
             ",", "1", ",", "0.33595690503808756`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2949024848582913`", ",", "2.2304705024144686`"}], 
             "}"}], ",", "1", ",", "0.32367383433817076`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2953615508173626`", ",", "2.7639245210198813`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2576653096395227`", ",", "3.273242379075574`"}], 
             "}"}], ",", "1", ",", "0.315621571247514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.2113245063877245`", ",", "3.7652526539988322`"}], 
             "}"}], ",", "1", ",", "0.30874730001717393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.455493926983626`", ",", 
              RowBox[{"-", "4.545508911278047`"}]}], "}"}], ",", "1", ",", 
            "0.3433821173518337`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5496754735540343`", ",", 
              RowBox[{"-", "4.0433897966853385`"}]}], "}"}], ",", "1", ",", 
            "0.32012797253442965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5411035259792327`", ",", 
              RowBox[{"-", "3.4597205385872267`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.486774417653732`", ",", 
              RowBox[{"-", "2.9611844789892188`"}]}], "}"}], ",", "1", ",", 
            "0.3183607945286048`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5046168207372976`", ",", 
              RowBox[{"-", "2.5235621927662186`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5177159910187474`", ",", 
              RowBox[{"-", "1.9878937067197677`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5214121000755205`", ",", 
              RowBox[{"-", "1.5002809901843606`"}]}], "}"}], ",", "1", ",", 
            "0.340942857879202`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.546179451127366`", ",", 
              RowBox[{"-", "0.9552247961191136`"}]}], "}"}], ",", "1", ",", 
            "0.32895225098420666`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5265096152172295`", ",", 
              RowBox[{"-", "0.5307514925988294`"}]}], "}"}], ",", "1", ",", 
            "0.3293929995329494`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4508179003100037`", ",", 
              RowBox[{"-", "0.0191493171389948`"}]}], "}"}], ",", "1", ",", 
            "0.3232819200666969`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.468844305577707`", ",", "0.496006128325597`"}], "}"}],
             ",", "1", ",", "0.30518570985543725`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5394933939222795`", ",", "1.0155980288621729`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4633503785940807`", ",", "1.4915150396036436`"}], 
             "}"}], ",", "1", ",", "0.2803388730249073`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5398179203682454`", ",", "2.0089878255475115`"}], 
             "}"}], ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.4722468526148482`", ",", "2.5012355781908706`"}], 
             "}"}], ",", "1", ",", "0.31669210706396017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.503043502714513`", ",", "3.02017230453673`"}], "}"}], 
            ",", "1", ",", "0.32984044582359534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.5176300318775504`", ",", "3.474797770957089`"}], 
             "}"}], ",", "1", ",", "0.32894715807376423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7853275116957654`", ",", 
              RowBox[{"-", "4.291933988743502`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7962179318020297`", ",", 
              RowBox[{"-", "3.7249212388585504`"}]}], "}"}], ",", "1", ",", 
            "0.35736488420471546`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.789148060568399`", ",", 
              RowBox[{"-", "3.2867091926243885`"}]}], "}"}], ",", "1", ",", 
            "0.3024219188012487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7197083165848004`", ",", 
              RowBox[{"-", "2.744169746259721`"}]}], "}"}], ",", "1", ",", 
            "0.30811044163465934`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7883301602583956`", ",", 
              RowBox[{"-", "2.217559875485394`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7008640110070936`", ",", 
              RowBox[{"-", "1.790175874585318`"}]}], "}"}], ",", "1", ",", 
            "0.26950981126778684`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.798836766336116`", ",", 
              RowBox[{"-", "1.2831579043475667`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7875136324130128`", ",", 
              RowBox[{"-", "0.7316909141889616`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.709018845967871`", ",", 
              RowBox[{"-", "0.24214572989507796`"}]}], "}"}], ",", "1", ",", 
            "0.3411673027133436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7652667797981647`", ",", "0.217073507620168`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.755975343253358`", ",", "0.7876819655681919`"}], 
             "}"}], ",", "1", ",", "0.3143408441383487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7976367479206146`", ",", "1.2922757366630788`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7706478315575924`", ",", "1.779615954311694`"}], 
             "}"}], ",", "1", ",", "0.32541343428614355`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.701418816118585`", ",", "2.217196975521629`"}], "}"}],
             ",", "1", ",", "0.2635638435754357`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.781499770989193`", ",", "2.766325146936083`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7817104995337845`", ",", "3.26136672178135`"}], "}"}],
             ",", "1", ",", "0.339545734989842`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.7931696107307973`", ",", "3.783885022421477`"}], 
             "}"}], ",", "1", ",", "0.31323803313398596`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.030846488526691`", ",", 
              RowBox[{"-", "4.498457403633332`"}]}], "}"}], ",", "1", ",", 
            "0.3208293765880256`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.044332844394681`", ",", 
              RowBox[{"-", "3.9829570732309567`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.043332856113678`", ",", 
              RowBox[{"-", "3.4667664894443706`"}]}], "}"}], ",", "1", ",", 
            "0.27895264941457243`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.03531399842681`", ",", 
              RowBox[{"-", "3.0408113433358785`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.978066076315513`", ",", 
              RowBox[{"-", "2.4838399970645386`"}]}], "}"}], ",", "1", ",", 
            "0.32696302694683627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.979338655173452`", ",", 
              RowBox[{"-", "2.028493308904071`"}]}], "}"}], ",", "1", ",", 
            "0.2687571612600585`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9804293283948984`", ",", 
              RowBox[{"-", "1.4761157337276174`"}]}], "}"}], ",", "1", ",", 
            "0.2649690218009145`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.00869082361586`", ",", 
              RowBox[{"-", "1.0081092632157649`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9790105122763135`", ",", 
              RowBox[{"-", "0.4933127092492464`"}]}], "}"}], ",", "1", ",", 
            "0.3057698866593313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.027191052626667`", ",", "0.02556558984815238`"}], 
             "}"}], ",", "1", ",", "0.3244681914550526`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9973000127425293`", ",", "0.5453205689694034`"}], 
             "}"}], ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.034021441895869`", ",", "1.0416805674266758`"}], 
             "}"}], ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.016453524215838`", ",", "1.4937779726027354`"}], 
             "}"}], ",", "1", ",", "0.2974624895292093`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.039688597501188`", ",", "1.9746376406576325`"}], 
             "}"}], ",", "1", ",", "0.33228962048900984`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.023120668102161`", ",", "2.510544462047106`"}], "}"}],
             ",", "1", ",", "0.33894906864377683`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.954374599074378`", ",", "2.965448983993511`"}], "}"}],
             ",", "1", ",", "0.2636968120208423`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"3.9950545917866473`", ",", "3.5443844591116442`"}], 
             "}"}], ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.275035943900926`", ",", 
              RowBox[{"-", "4.206057707102418`"}]}], "}"}], ",", "1", ",", 
            "0.3164203976821647`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.214625263391749`", ",", 
              RowBox[{"-", "3.7794998071607386`"}]}], "}"}], ",", "1", ",", 
            "0.2653193680918159`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.216345120285066`", ",", 
              RowBox[{"-", "3.2479484438866533`"}]}], "}"}], ",", "1", ",", 
            "0.27509642946763313`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.285614751115435`", ",", 
              RowBox[{"-", "2.736187097911492`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239154067658399`", ",", 
              RowBox[{"-", "2.223514033734806`"}]}], "}"}], ",", "1", ",", 
            "0.32486478984067857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.238314738372906`", ",", 
              RowBox[{"-", "1.7315076668808955`"}]}], "}"}], ",", "1", ",", 
            "0.3629461725921538`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2551326257625295`", ",", 
              RowBox[{"-", "1.2151946011614814`"}]}], "}"}], ",", "1", ",", 
            "0.3218973423894487`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.2718612141570675`", ",", 
              RowBox[{"-", "0.7752856394836308`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.265444028261341`", ",", 
              RowBox[{"-", "0.23983224181911386`"}]}], "}"}], ",", "1", ",", 
            "0.3566517761801607`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.298740546054907`", ",", "0.2641698984692633`"}], 
             "}"}], ",", "1", ",", "0.325790553685867`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.261069429186962`", ",", "0.744718774187375`"}], "}"}],
             ",", "1", ",", "0.33065684522717065`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.25368595426826`", ",", "1.2697854393576191`"}], "}"}],
             ",", "1", ",", "0.3166770130502563`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.286033485286037`", ",", "1.750776481289793`"}], "}"}],
             ",", "1", ",", "0.3328657723636406`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.239060690876511`", ",", "2.2492852465183577`"}], 
             "}"}], ",", "1", ",", "0.33041282391526744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.269688365000971`", ",", "2.7987249251764466`"}], 
             "}"}], ",", "1", ",", "0.32451428051074327`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.253445939761075`", ",", "3.2854723444298495`"}], 
             "}"}], ",", "1", ",", "0.3657889717269245`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.230534297342572`", ",", "3.722238958911252`"}], "}"}],
             ",", "1", ",", "0.2950981443988997`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.46513120138817`", ",", 
              RowBox[{"-", "4.533019988689255`"}]}], "}"}], ",", "1", ",", 
            "0.36069952071653727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.525401671580043`", ",", 
              RowBox[{"-", "4.012566439927267`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.493269987231102`", ",", 
              RowBox[{"-", "3.4577343492056243`"}]}], "}"}], ",", "1", ",", 
            "0.33172998887757593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.459957643318702`", ",", 
              RowBox[{"-", "2.9727341981081525`"}]}], "}"}], ",", "1", ",", 
            "0.29385366200414903`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.494529441176194`", ",", 
              RowBox[{"-", "2.5219042476748874`"}]}], "}"}], ",", "1", ",", 
            "0.2992699243637857`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.498888214131739`", ",", 
              RowBox[{"-", "2.0174529722955277`"}]}], "}"}], ",", "1", ",", 
            "0.33154635857707204`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.540843486907935`", ",", 
              RowBox[{"-", "1.4916896870325065`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512854728845702`", ",", 
              RowBox[{"-", "0.9682294535853206`"}]}], "}"}], ",", "1", ",", 
            "0.3087153859497263`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.501782796031424`", ",", 
              RowBox[{"-", "0.540974933550864`"}]}], "}"}], ",", "1", ",", 
            "0.3187463420686379`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.543166363844731`", ",", "0.033045621238232986`"}], 
             "}"}], ",", "1", ",", "0.306052011612458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.54833685627035`", ",", "0.47355272201928644`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.512632066502158`", ",", "1.010806662326981`"}], "}"}],
             ",", "1", ",", "0.35610597691053103`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.53320565488218`", ",", "1.4565727107085416`"}], "}"}],
             ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.5372303949221156`", ",", "1.9733731022542473`"}], 
             "}"}], ",", "1", ",", "0.32301776991647413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.489935667651078`", ",", "2.464307059914166`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.527272751603414`", ",", "2.9961073003624`"}], "}"}], 
            ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.545406226474884`", ",", "3.536211307589053`"}], "}"}],
             ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.728384537471674`", ",", 
              RowBox[{"-", "4.2864397273420725`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.704562739566948`", ",", 
              RowBox[{"-", "3.7720990053784402`"}]}], "}"}], ",", "1", ",", 
            "0.29987209833644535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.765529808625972`", ",", 
              RowBox[{"-", "3.2682102737567518`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.752779943535524`", ",", 
              RowBox[{"-", "2.781124071827576`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7723634447812415`", ",", 
              RowBox[{"-", "2.251255894994985`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.754443087265175`", ",", 
              RowBox[{"-", "1.7046767938468625`"}]}], "}"}], ",", "1", ",", 
            "0.3016426643263888`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.709731378279083`", ",", 
              RowBox[{"-", "1.2120625573219657`"}]}], "}"}], ",", "1", ",", 
            "0.3133927209907084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.7712374323829945`", ",", 
              RowBox[{"-", "0.7112495045554041`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.722500983356967`", ",", 
              RowBox[{"-", "0.23543565957621307`"}]}], "}"}], ",", "1", ",", 
            "0.32286700652647043`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731301764731916`", ",", "0.2744434355304301`"}], 
             "}"}], ",", "1", ",", "0.2704083314072458`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.745228231753553`", ",", "0.7184570400613869`"}], 
             "}"}], ",", "1", ",", "0.31423611939962304`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.735895538257032`", ",", "1.2882321279413769`"}], 
             "}"}], ",", "1", ",", "0.2634800573646887`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.716843694281878`", ",", "1.7048967674034592`"}], 
             "}"}], ",", "1", ",", "0.30884910012494077`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.731332798690084`", ",", "2.260331133319817`"}], "}"}],
             ",", "1", ",", "0.31603600032889617`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.751313885655906`", ",", "2.7731070411602112`"}], 
             "}"}], ",", "1", ",", "0.31610685748931466`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.77855285515456`", ",", "3.241455205147393`"}], "}"}], 
            ",", "1", ",", "0.325435861935482`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.778950440874664`", ",", "3.7243629361551958`"}], 
             "}"}], ",", "1", ",", "0.29990654446294107`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.974109767889385`", ",", 
              RowBox[{"-", "4.503868001005745`"}]}], "}"}], ",", "1", ",", 
            "0.32810965095864186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.019219062595581`", ",", 
              RowBox[{"-", "4.013574506522838`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.002872335506391`", ",", 
              RowBox[{"-", "3.49261849645034`"}]}], "}"}], ",", "1", ",", 
            "0.3266351565255603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.996718079238613`", ",", 
              RowBox[{"-", "2.9781388469466257`"}]}], "}"}], ",", "1", ",", 
            "0.3135612151805588`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.971570570774474`", ",", 
              RowBox[{"-", "2.46706193198077`"}]}], "}"}], ",", "1", ",", 
            "0.2936932492346285`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.95148984748506`", ",", 
              RowBox[{"-", "1.9965958870080123`"}]}], "}"}], ",", "1", ",", 
            "0.31134865956598495`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0356750325174415`", ",", 
              RowBox[{"-", "1.4552940599221469`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.034646153203182`", ",", 
              RowBox[{"-", "1.0014926544114717`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004342233827358`", ",", 
              RowBox[{"-", "0.515625193241964`"}]}], "}"}], ",", "1", ",", 
            "0.3043135219362981`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.983332267547277`", ",", "0.025400304428317255`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0257893786727985`", ",", "0.5429196016106428`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.004381826672613`", ",", "1.0010373682731215`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.001679610783413`", ",", "1.496787602616387`"}], "}"}],
             ",", "1", ",", "0.3378410265577992`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.0351627640770324`", ",", "1.96461187479596`"}], "}"}],
             ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.048807275277023`", ",", "2.539406099066727`"}], "}"}],
             ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"4.988444684838418`", ",", "2.9927507217425853`"}], 
             "}"}], ",", "1", ",", "0.32322494077764036`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.027236704502549`", ",", "3.456468031047497`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.236954837353358`", ",", 
              RowBox[{"-", "4.210653391249402`"}]}], "}"}], ",", "1", ",", 
            "0.29368172298329354`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.291561671985107`", ",", 
              RowBox[{"-", "3.788237909030356`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.252308684150176`", ",", 
              RowBox[{"-", "3.2591607368379307`"}]}], "}"}], ",", "1", ",", 
            "0.34164457781148744`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.237219438157749`", ",", 
              RowBox[{"-", "2.722612715788392`"}]}], "}"}], ",", "1", ",", 
            "0.3470536897021111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.2189764166028985`", ",", 
              RowBox[{"-", "2.234561041266248`"}]}], "}"}], ",", "1", ",", 
            "0.3395089346882117`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.261430059484951`", ",", 
              RowBox[{"-", "1.7155323173990347`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.264594589930286`", ",", 
              RowBox[{"-", "1.2855984095393693`"}]}], "}"}], ",", "1", ",", 
            "0.28495750126102376`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.209750448701537`", ",", 
              RowBox[{"-", "0.7623199200154217`"}]}], "}"}], ",", "1", ",", 
            "0.29642049723401154`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.279431825853254`", ",", 
              RowBox[{"-", "0.20021028433532917`"}]}], "}"}], ",", "1", ",", 
            "0.3596830577795727`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.210943173424514`", ",", "0.24827398091785124`"}], 
             "}"}], ",", "1", ",", "0.3185583151421701`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.240987141014835`", ",", "0.7570389939220854`"}], 
             "}"}], ",", "1", ",", "0.30357402899596186`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.233706468921965`", ",", "1.2418059498703542`"}], 
             "}"}], ",", "1", ",", "0.3325045885805734`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204032303661477`", ",", "1.7676923851714876`"}], 
             "}"}], ",", "1", ",", "0.2594112695960316`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.242144796936858`", ",", "2.23004385890071`"}], "}"}], 
            ",", "1", ",", "0.33659426630970746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.251723619511302`", ",", "2.7268531220094183`"}], 
             "}"}], ",", "1", ",", "0.2762452337461809`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.204925358779109`", ",", "3.252656574689102`"}], "}"}],
             ",", "1", ",", "0.2703929873379574`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.232747202908403`", ",", "3.761414163275666`"}], "}"}],
             ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493495299294159`", ",", 
              RowBox[{"-", "4.481811107911863`"}]}], "}"}], ",", "1", ",", 
            "0.3490471292742324`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.518152612978117`", ",", 
              RowBox[{"-", "4.002987427184965`"}]}], "}"}], ",", "1", ",", 
            "0.31218713952969657`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.483744850592621`", ",", 
              RowBox[{"-", "3.519491187896442`"}]}], "}"}], ",", "1", ",", 
            "0.3303924549076708`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.538720787124864`", ",", 
              RowBox[{"-", "3.0027771428496357`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.472801677168107`", ",", 
              RowBox[{"-", "2.4677651688142928`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.497733646110028`", ",", 
              RowBox[{"-", "1.959816136771721`"}]}], "}"}], ",", "1", ",", 
            "0.33987346095154664`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.539095208246142`", ",", 
              RowBox[{"-", "1.509571118684647`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.493701342448551`", ",", 
              RowBox[{"-", "1.0275085219432087`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4969504113092835`", ",", 
              RowBox[{"-", "0.539614977585357`"}]}], "}"}], ",", "1", ",", 
            "0.3241300755197718`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54197772293725`", ",", "0.04563835604737325`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.492025052530175`", ",", "0.5077284477255412`"}], 
             "}"}], ",", "1", ",", "0.35380189578746296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.509230520028847`", ",", "0.9842241927717074`"}], 
             "}"}], ",", "1", ",", "0.3344526802376814`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.548529753236016`", ",", "1.5395395556374045`"}], 
             "}"}], ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.54107790705073`", ",", "2.0372116199566723`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.514784902643395`", ",", "2.509030743533846`"}], "}"}],
             ",", "1", ",", "0.3395444154551384`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.452357119925867`", ",", "2.9899887628063078`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.4919832254752885`", ",", "3.526795912348139`"}], 
             "}"}], ",", "1", ",", "0.349641300570443`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.754623473815839`", ",", 
              RowBox[{"-", "4.250195100421971`"}]}], "}"}], ",", "1", ",", 
            "0.3420966263098593`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.752888017229147`", ",", 
              RowBox[{"-", "3.763632968967214`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.710922131367287`", ",", 
              RowBox[{"-", "3.2726865784787624`"}]}], "}"}], ",", "1", ",", 
            "0.3201630934391584`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705937605919863`", ",", 
              RowBox[{"-", "2.774017991381857`"}]}], "}"}], ",", "1", ",", 
            "0.2833588076417918`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.718944408430038`", ",", 
              RowBox[{"-", "2.268324934526136`"}]}], "}"}], ",", "1", ",", 
            "0.31680064899870086`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.763912553389689`", ",", 
              RowBox[{"-", "1.731746439107398`"}]}], "}"}], ",", "1", ",", 
            "0.31607706604931807`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.759713888401191`", ",", 
              RowBox[{"-", "1.202549127297843`"}]}], "}"}], ",", "1", ",", 
            "0.318436631258281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.765382800153673`", ",", 
              RowBox[{"-", "0.7212859947448025`"}]}], "}"}], ",", "1", ",", 
            "0.30290391385408166`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.768635981350461`", ",", 
              RowBox[{"-", "0.2897607472545153`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700597897510277`", ",", "0.21968326172135125`"}], 
             "}"}], ",", "1", ",", "0.23548246001059506`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.766278861424595`", ",", "0.7702504899391769`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.758614672034989`", ",", "1.242887349373212`"}], "}"}],
             ",", "1", ",", "0.3593036095767436`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.711655387608756`", ",", "1.720445590361148`"}], "}"}],
             ",", "1", ",", "0.24359180197407534`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.705726654805842`", ",", "2.206520318340426`"}], "}"}],
             ",", "1", ",", "0.23616656301374933`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.700733256241469`", ",", "2.7931321688399104`"}], 
             "}"}], ",", "1", ",", "0.31692778937656746`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.7997890488859785`", ",", "3.280538309722283`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.781788847811431`", ",", "3.761457103366046`"}], "}"}],
             ",", "1", ",", "0.3487219000116766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9858764954962895`", ",", 
              RowBox[{"-", "4.53771525117032`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.97207495941024`", ",", 
              RowBox[{"-", "3.985993769336111`"}]}], "}"}], ",", "1", ",", 
            "0.31222946876198954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0204936953426165`", ",", 
              RowBox[{"-", "3.516429256425517`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.003438978059779`", ",", 
              RowBox[{"-", "2.9962330220815954`"}]}], "}"}], ",", "1", ",", 
            "0.35351443958740264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019895797832339`", ",", 
              RowBox[{"-", "2.5361125181468682`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.037160116635184`", ",", 
              RowBox[{"-", "1.9664835120207724`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.961281125797351`", ",", 
              RowBox[{"-", "1.4789998675200802`"}]}], "}"}], ",", "1", ",", 
            "0.3206792522496296`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.025504729026428`", ",", 
              RowBox[{"-", "0.9869291023819204`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.955554470991509`", ",", 
              RowBox[{"-", "0.48552018586050605`"}]}], "}"}], ",", "1", ",", 
            "0.2706663621010621`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.024771472784959`", ",", "0.019938728778169212`"}], 
             "}"}], ",", "1", ",", "0.34782126199378954`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9557654221055305`", ",", "0.5339415044172112`"}], 
             "}"}], ",", "1", ",", "0.3028978265308462`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.0429826249735275`", ",", "0.9584816254121231`"}], 
             "}"}], ",", "1", ",", "0.3346579344996595`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.019888926609242`", ",", "1.5216567555875307`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.020907665563287`", ",", "1.9944753947482339`"}], 
             "}"}], ",", "1", ",", "0.3495086189859079`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.049395231266625`", ",", "2.4880860120130475`"}], 
             "}"}], ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.967468687503509`", ",", "3.0407084168298297`"}], 
             "}"}], ",", "1", ",", "0.29263430887664393`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"5.9794994334342855`", ",", "3.4741985301599154`"}], 
             "}"}], ",", "1", ",", "0.2641970917600207`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.230308570868324`", ",", 
              RowBox[{"-", "4.292808071149398`"}]}], "}"}], ",", "1", ",", 
            "0.3460152688776608`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.218218307636935`", ",", 
              RowBox[{"-", "3.7468016023200046`"}]}], "}"}], ",", "1", ",", 
            "0.30358926209579284`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.254803841841896`", ",", 
              RowBox[{"-", "3.2558789687674774`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.212663836645427`", ",", 
              RowBox[{"-", "2.7112814164594985`"}]}], "}"}], ",", "1", ",", 
            "0.2604681549132346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.280032369056936`", ",", 
              RowBox[{"-", "2.2258176975456467`"}]}], "}"}], ",", "1", ",", 
            "0.33171188443140087`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2068984145398955`", ",", 
              RowBox[{"-", "1.7952229208767096`"}]}], "}"}], ",", "1", ",", 
            "0.24112502950669049`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.287049744083409`", ",", 
              RowBox[{"-", "1.23429932295777`"}]}], "}"}], ",", "1", ",", 
            "0.33610594948183603`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237009487930655`", ",", 
              RowBox[{"-", "0.7668796764642403`"}]}], "}"}], ",", "1", ",", 
            "0.30521469965556297`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.216142078520122`", ",", 
              RowBox[{"-", "0.27877471770600387`"}]}], "}"}], ",", "1", ",", 
            "0.33264033098815665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.237614256664029`", ",", "0.2950343115227123`"}], 
             "}"}], ",", "1", ",", "0.3298042143385181`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.298673391016614`", ",", "0.7305168654641666`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.208114823229744`", ",", "1.2708357813627968`"}], 
             "}"}], ",", "1", ",", "0.31359232973661305`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.26836482014829`", ",", "1.7233249366135646`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.289896515592809`", ",", "2.2176373836828014`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.213560978306394`", ",", "2.779203905381042`"}], "}"}],
             ",", "1", ",", "0.3342155297710514`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.2772326789473825`", ",", "3.2289188001422997`"}], 
             "}"}], ",", "1", ",", "0.33272427227878343`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.233528609249457`", ",", "3.705021602926689`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.520334264407486`", ",", 
              RowBox[{"-", "4.525858278980991`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.496478865166048`", ",", 
              RowBox[{"-", "4.010679074115541`"}]}], "}"}], ",", "1", ",", 
            "0.3305894332780932`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.483324776476832`", ",", 
              RowBox[{"-", "3.4589786025167504`"}]}], "}"}], ",", "1", ",", 
            "0.3057307292300098`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4803367866459265`", ",", 
              RowBox[{"-", "3.0319043564095374`"}]}], "}"}], ",", "1", ",", 
            "0.3178517518795005`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.545710519812802`", ",", 
              RowBox[{"-", "2.454012914039463`"}]}], "}"}], ",", "1", ",", 
            "0.3456427966164088`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4816633956293135`", ",", 
              RowBox[{"-", "1.9624212218737038`"}]}], "}"}], ",", "1", ",", 
            "0.3199862082362895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.537595696583058`", ",", 
              RowBox[{"-", "1.5248486954022595`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5132985754810235`", ",", 
              RowBox[{"-", "0.9857461584872683`"}]}], "}"}], ",", "1", ",", 
            "0.31401234238825587`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.547699180990249`", ",", 
              RowBox[{"-", "0.5424860790850609`"}]}], "}"}], ",", "1", ",", 
            "0.3357571559839251`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.499737597174629`", ",", "0.03504993613168948`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.470466502042867`", ",", "0.5285951207726394`"}], 
             "}"}], ",", "1", ",", "0.2651136812300505`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466208987925173`", ",", "1.0300283332050004`"}], 
             "}"}], ",", "1", ",", "0.34318405490316084`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.5001322376353805`", ",", "1.50445339975363`"}], "}"}],
             ",", "1", ",", "0.3187803090783135`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.519730122759124`", ",", "1.9907074073205417`"}], 
             "}"}], ",", "1", ",", "0.32298715323500965`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.466807461158549`", ",", "2.51343200227038`"}], "}"}], 
            ",", "1", ",", "0.33539052940271463`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.4893933361131975`", ",", "2.972611763730079`"}], 
             "}"}], ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.471096941345746`", ",", "3.517444916309843`"}], "}"}],
             ",", "1", ",", "0.30269411255782197`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.707729940483884`", ",", 
              RowBox[{"-", "4.264967014396217`"}]}], "}"}], ",", "1", ",", 
            "0.32121860367788885`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.733501244762688`", ",", 
              RowBox[{"-", "3.7577063882878976`"}]}], "}"}], ",", "1", ",", 
            "0.3466623547553227`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.744431365002861`", ",", 
              RowBox[{"-", "3.229220855908949`"}]}], "}"}], ",", "1", ",", 
            "0.3296661148681017`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.7358020637724385`", ",", 
              RowBox[{"-", "2.7652203092028365`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.794693767828232`", ",", 
              RowBox[{"-", "2.2142707920406384`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.715335561729572`", ",", 
              RowBox[{"-", "1.743815429975476`"}]}], "}"}], ",", "1", ",", 
            "0.2820246274919235`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.778484779903059`", ",", 
              RowBox[{"-", "1.294299125245639`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.765203324094191`", ",", 
              RowBox[{"-", "0.798268829729106`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.708754657143935`", ",", 
              RowBox[{"-", "0.2350065325661806`"}]}], "}"}], ",", "1", ",", 
            "0.33034227712403413`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.748395862935642`", ",", "0.2382991680005137`"}], 
             "}"}], ",", "1", ",", "0.3211560109768174`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.769361321030737`", ",", "0.7423817037037406`"}], 
             "}"}], ",", "1", ",", "0.35062602338748516`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.727298921589896`", ",", "1.2708542516906707`"}], 
             "}"}], ",", "1", ",", "0.3258423917703637`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.761631380546853`", ",", "1.7073487180999578`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.793797676827208`", ",", "2.2285606399785682`"}], 
             "}"}], ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.717200015543992`", ",", "2.736569574008907`"}], "}"}],
             ",", "1", ",", "0.3280423730581927`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.75799561305477`", ",", "3.293780949181405`"}], "}"}], 
            ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.72250624771576`", ",", "3.750840366049545`"}], "}"}], 
            ",", "1", ",", "0.34304529626369923`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.992660051325198`", ",", 
              RowBox[{"-", "4.512403620843119`"}]}], "}"}], ",", "1", ",", 
            "0.3699639121853027`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.994021467812701`", ",", 
              RowBox[{"-", "4.004860508704816`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.027456727231007`", ",", 
              RowBox[{"-", "3.5141347911140133`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.985266810668766`", ",", 
              RowBox[{"-", "2.9698539761386353`"}]}], "}"}], ",", "1", ",", 
            "0.3226570897836281`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979060864295365`", ",", 
              RowBox[{"-", "2.452433959114527`"}]}], "}"}], ",", "1", ",", 
            "0.30118585692290745`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.015905489638029`", ",", 
              RowBox[{"-", "2.0122356798423757`"}]}], "}"}], ",", "1", ",", 
            "0.29958773744434136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.951761942705469`", ",", 
              RowBox[{"-", "1.5232882108051977`"}]}], "}"}], ",", "1", ",", 
            "0.28716019301820994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.954274109091176`", ",", 
              RowBox[{"-", "1.0195843979423336`"}]}], "}"}], ",", "1", ",", 
            "0.29108133308908674`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.95796426587826`", ",", 
              RowBox[{"-", "0.4518488507837658`"}]}], "}"}], ",", "1", ",", 
            "0.3301125659695432`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.037074093547184`", ",", "0.043846028048759644`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.99996865282349`", ",", "0.45437020003482936`"}], 
             "}"}], ",", "1", ",", "0.3210582124553661`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.014567845831424`", ",", "0.9930056619992144`"}], 
             "}"}], ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.957308601498292`", ",", "1.5167738208779487`"}], 
             "}"}], ",", "1", ",", "0.2731453207551938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.970546378018723`", ",", "2.04786617070403`"}], "}"}], 
            ",", "1", ",", "0.2527658889156018`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.979851874267285`", ",", "2.480908611991962`"}], "}"}],
             ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.035279567349957`", ",", "2.9677201468426655`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"6.950791009971921`", ",", "3.4833425711064887`"}], 
             "}"}], ",", "1", ",", "0.2703769102185136`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.219374077711929`", ",", 
              RowBox[{"-", "4.2200441733149585`"}]}], "}"}], ",", "1", ",", 
            "0.31158916589548485`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.299029067266452`", ",", 
              RowBox[{"-", "3.793369218088314`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.215099968620753`", ",", 
              RowBox[{"-", "3.2504597753726254`"}]}], "}"}], ",", "1", ",", 
            "0.32362710017158886`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.291064801388192`", ",", 
              RowBox[{"-", "2.791520367304548`"}]}], "}"}], ",", "1", ",", 
            "0.30274987486743865`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.228025875073569`", ",", 
              RowBox[{"-", "2.244305803421385`"}]}], "}"}], ",", "1", ",", 
            "0.31440674320901385`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.241096148564702`", ",", 
              RowBox[{"-", "1.7958905673393772`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.263458029242146`", ",", 
              RowBox[{"-", "1.2873114654205995`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2337875470664095`", ",", 
              RowBox[{"-", "0.7626643882173257`"}]}], "}"}], ",", "1", ",", 
            "0.3733048797470579`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.242911651223422`", ",", 
              RowBox[{"-", "0.2851776361246296`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203935672799124`", ",", "0.20642699979071238`"}], 
             "}"}], ",", "1", ",", "0.23297072563523785`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.257632083873466`", ",", "0.797102217032705`"}], "}"}],
             ",", "1", ",", "0.3121832531778481`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.203144662827205`", ",", "1.2730844286842238`"}], 
             "}"}], ",", "1", ",", "0.33764675543540484`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.238258006161537`", ",", "1.717146390347664`"}], "}"}],
             ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2041155955607525`", ",", "2.266453646772537`"}], 
             "}"}], ",", "1", ",", "0.3102984833924566`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.2231580375407844`", ",", "2.7676061657202893`"}], 
             "}"}], ",", "1", ",", "0.2744884788144892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.213050794172561`", ",", "3.257974014077085`"}], "}"}],
             ",", "1", ",", "0.34036732588565194`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.295132162467215`", ",", "3.711911969141674`"}], "}"}],
             ",", "1", ",", "0.32122767827394766`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.521954645607859`", ",", 
              RowBox[{"-", "4.496135418583537`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48167413322507`", ",", 
              RowBox[{"-", "3.9507765654377263`"}]}], "}"}], ",", "1", ",", 
            "0.24111468872428016`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.488167098541449`", ",", 
              RowBox[{"-", "3.533471030366212`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.538762482001648`", ",", 
              RowBox[{"-", "2.9655989293130967`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.484231425742324`", ",", 
              RowBox[{"-", "2.539898030156924`"}]}], "}"}], ",", "1", ",", 
            "0.31721781998494825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.481130398128181`", ",", 
              RowBox[{"-", "1.9627011463458017`"}]}], "}"}], ",", "1", ",", 
            "0.29230499522239`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.48108676291512`", ",", 
              RowBox[{"-", "1.512982458841148`"}]}], "}"}], ",", "1", ",", 
            "0.3135118227300521`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.542872391966645`", ",", 
              RowBox[{"-", "0.9798475366934658`"}]}], "}"}], ",", "1", ",", 
            "0.3155518938030942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4769711673543675`", ",", 
              RowBox[{"-", "0.47943610561368527`"}]}], "}"}], ",", "1", ",", 
            "0.3041713498337453`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.51971435442586`", ",", 
              RowBox[{"-", "0.04745370241375506`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.463920373181807`", ",", "0.4625898803092296`"}], 
             "}"}], ",", "1", ",", "0.3649814595135175`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.524582191958645`", ",", "1.0406343284445707`"}], 
             "}"}], ",", "1", ",", "0.35095637133716834`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.491965727573949`", ",", "1.5087252988927673`"}], 
             "}"}], ",", "1", ",", "0.3283397010224753`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.492908058733574`", ",", "2.041410893882297`"}], "}"}],
             ",", "1", ",", "0.3488585867884829`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.4537986290325`", ",", "2.492196329258979`"}], "}"}], 
            ",", "1", ",", "0.3366026974042665`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.504145576731927`", ",", "2.957009823195394`"}], "}"}],
             ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.519567203290176`", ",", "3.4820943594159033`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.723015178603745`", ",", 
              RowBox[{"-", "4.280289030458804`"}]}], "}"}], ",", "1", ",", 
            "0.29498305238620565`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.738480440375056`", ",", 
              RowBox[{"-", "3.7049231817429487`"}]}], "}"}], ",", "1", ",", 
            "0.303401729249554`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.730142786637101`", ",", 
              RowBox[{"-", "3.2504414937653388`"}]}], "}"}], ",", "1", ",", 
            "0.3431642573551165`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.711509273020688`", ",", 
              RowBox[{"-", "2.7754870761292634`"}]}], "}"}], ",", "1", ",", 
            "0.25687345236198983`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.760428432211241`", ",", 
              RowBox[{"-", "2.252987791351584`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.79758889983888`", ",", 
              RowBox[{"-", "1.788076956438493`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.785846240252596`", ",", 
              RowBox[{"-", "1.2436221197961543`"}]}], "}"}], ",", "1", ",", 
            "0.3360857238852205`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.755623172264931`", ",", 
              RowBox[{"-", "0.7468022553312602`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.742938181519022`", ",", 
              RowBox[{"-", "0.2350330136784513`"}]}], "}"}], ",", "1", ",", 
            "0.29157310403508696`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7518245432324315`", ",", "0.21100141540976067`"}], 
             "}"}], ",", "1", ",", "0.339990775682618`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.788792604787094`", ",", "0.757957163126155`"}], "}"}],
             ",", "1", ",", "0.3374630218423826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.782257339942256`", ",", "1.2789070559938573`"}], 
             "}"}], ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.765777426183349`", ",", "1.7382461935849596`"}], 
             "}"}], ",", "1", ",", "0.3508285579600609`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.7437768995672`", ",", "2.283830237736806`"}], "}"}], 
            ",", "1", ",", "0.3206728446222535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.735634639546248`", ",", "2.7886876873502984`"}], 
             "}"}], ",", "1", ",", "0.2862158759015776`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.732267626546512`", ",", "3.2593173138660694`"}], 
             "}"}], ",", "1", ",", "0.30801149666422695`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.775206207335007`", ",", "3.741675478701882`"}], "}"}],
             ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984678726707632`", ",", 
              RowBox[{"-", "4.502605729695437`"}]}], "}"}], ",", "1", ",", 
            "0.3433548123527416`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.039359967082412`", ",", 
              RowBox[{"-", "3.9647024015019636`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.0290555544427`", ",", 
              RowBox[{"-", "3.4558034743641772`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.996421785563389`", ",", 
              RowBox[{"-", "3.029669387823512`"}]}], "}"}], ",", "1", ",", 
            "0.34589713504331787`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.977231011210269`", ",", 
              RowBox[{"-", "2.466804889773938`"}]}], "}"}], ",", "1", ",", 
            "0.3045014118824152`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.007629180776295`", ",", 
              RowBox[{"-", "1.9876265509496673`"}]}], "}"}], ",", "1", ",", 
            "0.289718760672902`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.994973671268013`", ",", 
              RowBox[{"-", "1.5457119457677952`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.041851754592946`", ",", 
              RowBox[{"-", "1.0258727445346267`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.951196771700813`", ",", 
              RowBox[{"-", "0.5295421835046014`"}]}], "}"}], ",", "1", ",", 
            "0.2923199815380942`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.006217115046699`", ",", 
              RowBox[{"-", "0.014560431884925111`"}]}], "}"}], ",", "1", ",", 
            "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.018929145154301`", ",", "0.5111405026293293`"}], 
             "}"}], ",", "1", ",", "0.33339437637556046`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.031010907711691`", ",", "1.043764089413193`"}], "}"}],
             ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.984250418446669`", ",", "1.463746232324767`"}], "}"}],
             ",", "1", ",", "0.27380052021568346`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.04165094062928`", ",", "1.9584664909151566`"}], "}"}],
             ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.005194864003968`", ",", "2.4695497066889445`"}], 
             "}"}], ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.995229155065891`", ",", "3.038135878738669`"}], "}"}],
             ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"7.9779638527937005`", ",", "3.486354596462882`"}], 
             "}"}], ",", "1", ",", "0.3260359116711755`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.287599974289597`", ",", 
              RowBox[{"-", "4.274237570311664`"}]}], "}"}], ",", "1", ",", 
            "0.3793590627056994`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.282990181525687`", ",", 
              RowBox[{"-", "3.767933457769322`"}]}], "}"}], ",", "1", ",", 
            "0.31316720551062754`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29574821969665`", ",", 
              RowBox[{"-", "3.2983648257770373`"}]}], "}"}], ",", "1", ",", 
            "0.3096964736144095`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.281793409824875`", ",", 
              RowBox[{"-", "2.788391274264721`"}]}], "}"}], ",", "1", ",", 
            "0.3737005378857883`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.23953110464995`", ",", 
              RowBox[{"-", "2.233804393892112`"}]}], "}"}], ",", "1", ",", 
            "0.338204128673938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212864264670573`", ",", 
              RowBox[{"-", "1.7495317768940504`"}]}], "}"}], ",", "1", ",", 
            "0.2983602424145267`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.25852019693826`", ",", 
              RowBox[{"-", "1.2275684833053049`"}]}], "}"}], ",", "1", ",", 
            "0.29601754161974`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.278613846223905`", ",", 
              RowBox[{"-", "0.7632780092188172`"}]}], "}"}], ",", "1", ",", 
            "0.35357076102111`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.26686925630898`", ",", 
              RowBox[{"-", "0.23603497422046132`"}]}], "}"}], ",", "1", ",", 
            "0.3420387575222244`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.223418982219936`", ",", "0.21717228409223857`"}], 
             "}"}], ",", "1", ",", "0.317610929846083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.221640101243088`", ",", "0.7758291470408698`"}], 
             "}"}], ",", "1", ",", "0.3288291695858061`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.295455129426236`", ",", "1.2808176876293562`"}], 
             "}"}], ",", "1", ",", "0.3551410351190656`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.234040126953492`", ",", "1.7500667173525337`"}], 
             "}"}], ",", "1", ",", "0.2836266289251499`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.212464947900548`", ",", "2.248751145398679`"}], "}"}],
             ",", "1", ",", "0.30284136498560826`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.238291907256842`", ",", "2.7484315431295707`"}], 
             "}"}], ",", "1", ",", "0.36346844466848627`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.230671538075674`", ",", "3.2371424196633996`"}], 
             "}"}], ",", "1", ",", "0.30828026055547536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"8.29876080260689`", ",", "3.7822359370216825`"}], "}"}],
             ",", "1", ",", "0.4364131651317584`"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "False"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`PlotType -> Optica`Optica`TopView, 
     Optica`Optica`ThresholdIntensity -> 0.1, Optica`Optica`ReportedSurfaces -> 
     All, Optica`Optica`ColorView -> Log[Optica`Optica`Intensity], 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`ShowClones -> False, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     RuntimeAttributes -> {Listable}, Parallelization -> False, 
     CompilationTarget -> "MVM", RuntimeOptions -> "Speed", 
     Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`PlotType -> 
     Optica`Optica`TopView, Optica`Optica`ThresholdIntensity -> 0.1, 
     Optica`Optica`ReportedSurfaces -> All, Optica`Optica`ColorView -> 
     Log[Optica`Optica`Intensity], 
     Optica`Optica`CreateClones -> {{{
        1.9907689222339402`, -4.529077150335811}, 1, 0.3300023966525176}, {{
        2.0233663468946883`, -3.99105399895926}, 1, 0.33590735268637717`}, {{
        1.9858554053727502`, -3.485409892311437}, 1, 0.318153939931529}, {{
        2.0401710867365628`, -2.9825767694748495`}, 1, 
        0.33481280744268754`}, {{2.0101577616097117`, -2.4832623444953508`}, 
        1, 0.3370939643600844}, {{2.0260706177641596`, -1.950001373046383}, 1,
         0.3403660491721731}, {{1.9913871279479374`, -1.488002430284238}, 1, 
        0.31676570349672006`}, {{1.9648388984333083`, -1.016901462993699}, 1, 
        0.38409184093579324`}, {{2.001113922823207, -0.45088421904366716`}, 1,
         0.31762525081858006`}, {{1.958570210111544, -0.02152209955274949}, 1,
         0.3861241577085539}, {{2.0427467330474878`, 0.4576864744029721}, 1, 
        0.24073619836787136`}, {{1.991600406298163, 1.0008380278066993`}, 1, 
        0.33775782507244856`}, {{2.0019778108135475`, 1.5367636247387837`}, 1,
         0.3703752972844546}, {{2.018234059403475, 2.0418920267659595`}, 1, 
        0.2840274053251544}, {{1.9661224054407973`, 2.4721735170502206`}, 1, 
        0.36048458326182337`}, {{2.028062972666912, 2.9744687962408087`}, 1, 
        0.2607097141646608}, {{2.0059646438310854`, 3.505435861545571}, 1, 
        0.30303095454516915`}, {{2.2019923549027527`, -4.2755298307128085`}, 
        1, 0.3300023966525176}, {{2.2145775158831484`, -3.7065617081701907`}, 
        1, 0.318153939931529}, {{2.2871534564694445`, -3.2086283677191094`}, 
        1, 0.3027440395147296}, {{2.263463593059942, -2.7056774891265234`}, 1,
         0.3300028199598174}, {{2.2785832463579005`, -2.2371062681663596`}, 1,
         0.33977371548432994`}, {{2.270716860012454, -1.7133639635294955`}, 1,
         0.2973887395341897}, {{2.2369828400597376`, -1.2879442959730592`}, 1,
         0.31676570349672006`}, {{2.2187390491989065`, -0.7001275882682791}, 
        1, 0.3308820828217743}, {{2.2687487806562627`, -0.27983632273901843`},
         1, 0.31762525081858006`}, {{2.202616643758109, 0.27769889468150044`},
         1, 0.24073619836787136`}, {{2.2906858079893504`, 0.7956948810201728},
         1, 0.24606359095607133`}, {{2.2466519999270234`, 1.222263033135929}, 
        1, 0.3317932505256897}, {{2.2886934530865974`, 1.7712247117329811`}, 
        1, 0.2712542367897372}, {{2.232074484043875, 2.2288247413061195`}, 1, 
        0.2840274053251544}, {{2.201539996617153, 2.7798530794520904`}, 1, 
        0.2607097141646608}, {{2.2686108909839335`, 3.234502230432643}, 1, 
        0.317436694379581}, {{2.2229567502592524`, 3.71695934761845}, 1, 
        0.30303095454516915`}, {{2.5478940309714795`, -4.502133806037861}, 1, 
        0.3395875052353165}, {{2.535973910199515, -4.04509635640849}, 1, 
        0.3263680949199062}, {{2.529154981772573, -3.502006217769582}, 1, 
        0.3134077398631213}, {{2.4672251295432526`, -2.9652600336694723`}, 1, 
        0.3027440395147296}, {{2.5265383380144644`, -2.4797051124510827`}, 1, 
        0.32302005231676906`}, {{2.4765393215539024`, -1.9609549146896452`}, 
        1, 0.32196919848235284`}, {{
        2.4798863380874407`, -1.5019681455870117`}, 1, 0.2973887395341897}, {{
        2.487845868467305, -1.0321796264226264`}, 1, 0.3582566471289234}, {{
        2.547811854043566, -0.5307928868931314}, 1, 0.3387291298978924}, {{
        2.486305871850152, -0.012032705874716706`}, 1, 
        0.34503603454472387`}, {{2.479200963059632, 0.5347048826742254}, 1, 
        0.32195301354046985`}, {{2.463349121590899, 0.9710079465068331}, 1, 
        0.24606359095607133`}, {{2.481306932088153, 1.4868386887120868`}, 1, 
        0.34347541743583815`}, {{2.477375211391384, 1.9661043029153238`}, 1, 
        0.2712542367897372}, {{2.5021519503155796`, 2.538844906481669}, 1, 
        0.31091032155449055`}, {{2.4601500818481314`, 2.981364336584796}, 1, 
        0.317436694379581}, {{2.5256136123011155`, 3.468550018932752}, 1, 
        0.3476043240039293}, {{2.783610760294229, -4.257680748725559}, 1, 
        0.3263680949199062}, {{2.7457272742136745`, -3.729481835480237}, 1, 
        0.31408392907953414`}, {{2.7457648918269237`, -3.2755011223029324`}, 
        1, 0.3134077398631213}, {{2.747915420170109, -2.7486889485871053`}, 1,
         0.34641917456943816`}, {{2.709459019976772, -2.2134684164282157`}, 1,
         0.32302005231676906`}, {{2.7187144571104764`, -1.7333938312613306`}, 
        1, 0.33231437370795947`}, {{
        2.7961098983858728`, -1.2344763629350488`}, 1, 
        0.29752851014228643`}, {{2.787407525022324, -0.7702325199734176}, 1, 
        0.2896865585009006}, {{2.7687346869944887`, -0.25058066585037264`}, 1,
         0.31344091957959347`}, {{2.7352555747067444`, 0.24092257354491342`}, 
        1, 0.3549117185141242}, {{2.7585846051463574`, 0.7180549975648313}, 1,
         0.32968191365164135`}, {{2.7596419624056288`, 1.2223725546121618`}, 
        1, 0.35074038870470764`}, {{2.7749738448521284`, 1.77573574629039}, 1,
         0.3103998135249554}, {{2.7139146881919545`, 2.2518543900923986`}, 1, 
        0.3566609225164404}, {{2.7292089530252044`, 2.7512368685933226`}, 1, 
        0.31091032155449055`}, {{2.7659992680218455`, 3.2005433386795037`}, 1,
         0.32034941890174845`}, {{2.7197499330484325`, 3.764705285021538}, 1, 
        0.35411418026594893`}, {{2.997284810911369, -4.516062830059166}, 1, 
        0.3352877866272839}, {{2.9736400346625596`, -3.950818352043413}, 1, 
        0.3177012432140486}, {{3.009877285889045, -3.5458303100857482`}, 1, 
        0.32171899453998787`}, {{3.004905347668071, -3.0002376861930404`}, 1, 
        0.3467949266799934}, {{2.9746217111823006`, -2.4867528836306616`}, 1, 
        0.34641917456943816`}, {{3.0463207425217136`, -2.018292683757872}, 1, 
        0.3000183592121354}, {{3.0149797487766716`, -1.5091254382428234`}, 1, 
        0.3249594111290117}, {{2.971346897669585, -0.9940284300482617}, 1, 
        0.2896865585009006}, {{3.0010650605847173`, -0.4609798283352218}, 1, 
        0.31344091957959347`}, {{3.0421379446443804`, -0.04526529864158411}, 
        1, 0.3238470687237391}, {{3.035065792562872, 0.5384768329852746}, 1, 
        0.3003064888269091}, {{3.022388011595948, 0.9900294163368778}, 1, 
        0.35074038870470764`}, {{2.987780981651503, 1.5045396630444403`}, 1, 
        0.3447233572601251}, {{2.9987479769333882`, 1.9908477683802908`}, 1, 
        0.3103998135249554}, {{3.0279036957624585`, 2.5003699731301885`}, 1, 
        0.3754926150324537}, {{3.0438426292653173`, 3.0410854545733312`}, 1, 
        0.315621571247514}, {{3.0032819845801577`, 3.53712285676085}, 1, 
        0.30874730001717393`}, {{3.2975218867436036`, -4.240621861668797}, 1, 
        0.32012797253442965`}, {{3.288302235803486, -3.753751704996327}, 1, 
        0.34749353835203883`}, {{3.2761749890740184`, -3.2965934316205354`}, 
        1, 0.3111230989400495}, {{3.2372371752187687`, -2.742771876661105}, 1,
         0.33162162206011914`}, {{3.2840370444296383`, -2.201328132978951}, 1,
         0.3000183592121354}, {{3.2521713826558964`, -1.7312487096463796`}, 1,
         0.3249594111290117}, {{3.2116490328336904`, -1.241357549315829}, 1, 
        0.3322325234409171}, {{3.214390401004393, -0.7857883726908198}, 1, 
        0.3200532237011332}, {{3.262901055900302, -0.28220531769611984`}, 1, 
        0.3170463910804746}, {{3.236486705241935, 0.26384165417899186`}, 1, 
        0.3284667372650815}, {{3.269058426634985, 0.7267092277305489}, 1, 
        0.3003064888269091}, {{3.2832047206617774`, 1.276718797418142}, 1, 
        0.2803388730249073}, {{3.271536539891381, 1.767331089399346}, 1, 
        0.33595690503808756`}, {{3.2949024848582913`, 2.2304705024144686`}, 1,
         0.32367383433817076`}, {{3.2953615508173626`, 2.7639245210198813`}, 
        1, 0.31669210706396017`}, {{3.2576653096395227`, 3.273242379075574}, 
        1, 0.315621571247514}, {{3.2113245063877245`, 3.7652526539988322`}, 1,
         0.30874730001717393`}, {{3.455493926983626, -4.545508911278047}, 1, 
        0.3433821173518337}, {{3.5496754735540343`, -4.0433897966853385`}, 1, 
        0.32012797253442965`}, {{3.5411035259792327`, -3.4597205385872267`}, 
        1, 0.3024219188012487}, {{3.486774417653732, -2.9611844789892188`}, 1,
         0.3183607945286048}, {{3.5046168207372976`, -2.5235621927662186`}, 1,
         0.30811044163465934`}, {{3.5177159910187474`, -1.9878937067197677`}, 
        1, 0.26950981126778684`}, {{
        3.5214121000755205`, -1.5002809901843606`}, 1, 0.340942857879202}, {{
        3.546179451127366, -0.9552247961191136}, 1, 0.32895225098420666`}, {{
        3.5265096152172295`, -0.5307514925988294}, 1, 0.3293929995329494}, {{
        3.4508179003100037`, -0.0191493171389948}, 1, 0.3232819200666969}, {{
        3.468844305577707, 0.496006128325597}, 1, 0.30518570985543725`}, {{
        3.5394933939222795`, 1.0155980288621729`}, 1, 0.3143408441383487}, {{
        3.4633503785940807`, 1.4915150396036436`}, 1, 0.2803388730249073}, {{
        3.5398179203682454`, 2.0089878255475115`}, 1, 0.2635638435754357}, {{
        3.4722468526148482`, 2.5012355781908706`}, 1, 
        0.31669210706396017`}, {{3.503043502714513, 3.02017230453673}, 1, 
        0.32984044582359534`}, {{3.5176300318775504`, 3.474797770957089}, 1, 
        0.32894715807376423`}, {{3.7853275116957654`, -4.291933988743502}, 1, 
        0.3208293765880256}, {{3.7962179318020297`, -3.7249212388585504`}, 1, 
        0.35736488420471546`}, {{3.789148060568399, -3.2867091926243885`}, 1, 
        0.3024219188012487}, {{3.7197083165848004`, -2.744169746259721}, 1, 
        0.30811044163465934`}, {{3.7883301602583956`, -2.217559875485394}, 1, 
        0.2687571612600585}, {{3.7008640110070936`, -1.790175874585318}, 1, 
        0.26950981126778684`}, {{3.798836766336116, -1.2831579043475667`}, 1, 
        0.2649690218009145}, {{3.7875136324130128`, -0.7316909141889616}, 1, 
        0.3057698866593313}, {{3.709018845967871, -0.24214572989507796`}, 1, 
        0.3411673027133436}, {{3.7652667797981647`, 0.217073507620168}, 1, 
        0.3244681914550526}, {{3.755975343253358, 0.7876819655681919}, 1, 
        0.3143408441383487}, {{3.7976367479206146`, 1.2922757366630788`}, 1, 
        0.2974624895292093}, {{3.7706478315575924`, 1.779615954311694}, 1, 
        0.32541343428614355`}, {{3.701418816118585, 2.217196975521629}, 1, 
        0.2635638435754357}, {{3.781499770989193, 2.766325146936083}, 1, 
        0.2636968120208423}, {{3.7817104995337845`, 3.26136672178135}, 1, 
        0.339545734989842}, {{3.7931696107307973`, 3.783885022421477}, 1, 
        0.31323803313398596`}, {{4.030846488526691, -4.498457403633332}, 1, 
        0.3208293765880256}, {{4.044332844394681, -3.9829570732309567`}, 1, 
        0.2653193680918159}, {{4.043332856113678, -3.4667664894443706`}, 1, 
        0.27895264941457243`}, {{4.03531399842681, -3.0408113433358785`}, 1, 
        0.27509642946763313`}, {{3.978066076315513, -2.4838399970645386`}, 1, 
        0.32696302694683627`}, {{3.979338655173452, -2.028493308904071}, 1, 
        0.2687571612600585}, {{3.9804293283948984`, -1.4761157337276174`}, 1, 
        0.2649690218009145}, {{4.00869082361586, -1.0081092632157649`}, 1, 
        0.3218973423894487}, {{3.9790105122763135`, -0.4933127092492464}, 1, 
        0.3057698866593313}, {{4.027191052626667, 0.02556558984815238}, 1, 
        0.3244681914550526}, {{3.9973000127425293`, 0.5453205689694034}, 1, 
        0.33065684522717065`}, {{4.034021441895869, 1.0416805674266758`}, 1, 
        0.3166770130502563}, {{4.016453524215838, 1.4937779726027354`}, 1, 
        0.2974624895292093}, {{4.039688597501188, 1.9746376406576325`}, 1, 
        0.33228962048900984`}, {{4.023120668102161, 2.510544462047106}, 1, 
        0.33894906864377683`}, {{3.954374599074378, 2.965448983993511}, 1, 
        0.2636968120208423}, {{3.9950545917866473`, 3.5443844591116442`}, 1, 
        0.2950981443988997}, {{4.275035943900926, -4.206057707102418}, 1, 
        0.3164203976821647}, {{4.214625263391749, -3.7794998071607386`}, 1, 
        0.2653193680918159}, {{4.216345120285066, -3.2479484438866533`}, 1, 
        0.27509642946763313`}, {{4.285614751115435, -2.736187097911492}, 1, 
        0.29385366200414903`}, {{4.239154067658399, -2.223514033734806}, 1, 
        0.32486478984067857`}, {{4.238314738372906, -1.7315076668808955`}, 1, 
        0.3629461725921538}, {{4.2551326257625295`, -1.2151946011614814`}, 1, 
        0.3218973423894487}, {{4.2718612141570675`, -0.7752856394836308}, 1, 
        0.3087153859497263}, {{4.265444028261341, -0.23983224181911386`}, 1, 
        0.3566517761801607}, {{4.298740546054907, 0.2641698984692633}, 1, 
        0.325790553685867}, {{4.261069429186962, 0.744718774187375}, 1, 
        0.33065684522717065`}, {{4.25368595426826, 1.2697854393576191`}, 1, 
        0.3166770130502563}, {{4.286033485286037, 1.750776481289793}, 1, 
        0.3328657723636406}, {{4.239060690876511, 2.2492852465183577`}, 1, 
        0.33041282391526744`}, {{4.269688365000971, 2.7987249251764466`}, 1, 
        0.32451428051074327`}, {{4.253445939761075, 3.2854723444298495`}, 1, 
        0.3657889717269245}, {{4.230534297342572, 3.722238958911252}, 1, 
        0.2950981443988997}, {{4.46513120138817, -4.533019988689255}, 1, 
        0.36069952071653727`}, {{4.525401671580043, -4.012566439927267}, 1, 
        0.29987209833644535`}, {{4.493269987231102, -3.4577343492056243`}, 1, 
        0.33172998887757593`}, {{4.459957643318702, -2.9727341981081525`}, 1, 
        0.29385366200414903`}, {{4.494529441176194, -2.5219042476748874`}, 1, 
        0.2992699243637857}, {{4.498888214131739, -2.0174529722955277`}, 1, 
        0.33154635857707204`}, {{4.540843486907935, -1.4916896870325065`}, 1, 
        0.3016426643263888}, {{4.512854728845702, -0.9682294535853206}, 1, 
        0.3087153859497263}, {{4.501782796031424, -0.540974933550864}, 1, 
        0.3187463420686379}, {{4.543166363844731, 0.033045621238232986`}, 1, 
        0.306052011612458}, {{4.54833685627035, 0.47355272201928644`}, 1, 
        0.2704083314072458}, {{4.512632066502158, 1.010806662326981}, 1, 
        0.35610597691053103`}, {{4.53320565488218, 1.4565727107085416`}, 1, 
        0.2634800573646887}, {{4.5372303949221156`, 1.9733731022542473`}, 1, 
        0.32301776991647413`}, {{4.489935667651078, 2.464307059914166}, 1, 
        0.31603600032889617`}, {{4.527272751603414, 2.9961073003624}, 1, 
        0.31610685748931466`}, {{4.545406226474884, 3.536211307589053}, 1, 
        0.29990654446294107`}, {{4.728384537471674, -4.2864397273420725`}, 1, 
        0.32810965095864186`}, {{4.704562739566948, -3.7720990053784402`}, 1, 
        0.29987209833644535`}, {{4.765529808625972, -3.2682102737567518`}, 1, 
        0.3266351565255603}, {{4.752779943535524, -2.781124071827576}, 1, 
        0.3135612151805588}, {{4.7723634447812415`, -2.251255894994985}, 1, 
        0.2936932492346285}, {{4.754443087265175, -1.7046767938468625`}, 1, 
        0.3016426643263888}, {{4.709731378279083, -1.2120625573219657`}, 1, 
        0.3133927209907084}, {{4.7712374323829945`, -0.7112495045554041}, 1, 
        0.3043135219362981}, {{4.722500983356967, -0.23543565957621307`}, 1, 
        0.32286700652647043`}, {{4.731301764731916, 0.2744434355304301}, 1, 
        0.2704083314072458}, {{4.745228231753553, 0.7184570400613869}, 1, 
        0.31423611939962304`}, {{4.735895538257032, 1.2882321279413769`}, 1, 
        0.2634800573646887}, {{4.716843694281878, 1.7048967674034592`}, 1, 
        0.30884910012494077`}, {{4.731332798690084, 2.260331133319817}, 1, 
        0.31603600032889617`}, {{4.751313885655906, 2.7731070411602112`}, 1, 
        0.31610685748931466`}, {{4.77855285515456, 3.241455205147393}, 1, 
        0.325435861935482}, {{4.778950440874664, 3.7243629361551958`}, 1, 
        0.29990654446294107`}, {{4.974109767889385, -4.503868001005745}, 1, 
        0.32810965095864186`}, {{5.019219062595581, -4.013574506522838}, 1, 
        0.29368172298329354`}, {{5.002872335506391, -3.49261849645034}, 1, 
        0.3266351565255603}, {{4.996718079238613, -2.9781388469466257`}, 1, 
        0.3135612151805588}, {{4.971570570774474, -2.46706193198077}, 1, 
        0.2936932492346285}, {{4.95148984748506, -1.9965958870080123`}, 1, 
        0.31134865956598495`}, {{5.0356750325174415`, -1.4552940599221469`}, 
        1, 0.28495750126102376`}, {{5.034646153203182, -1.0014926544114717`}, 
        1, 0.29642049723401154`}, {{5.004342233827358, -0.515625193241964}, 1,
         0.3043135219362981}, {{4.983332267547277, 0.025400304428317255`}, 1, 
        0.3185583151421701}, {{5.0257893786727985`, 0.5429196016106428}, 1, 
        0.30357402899596186`}, {{5.004381826672613, 1.0010373682731215`}, 1, 
        0.3325045885805734}, {{5.001679610783413, 1.496787602616387}, 1, 
        0.3378410265577992}, {{5.0351627640770324`, 1.96461187479596}, 1, 
        0.2594112695960316}, {{5.048807275277023, 2.539406099066727}, 1, 
        0.2762452337461809}, {{4.988444684838418, 2.9927507217425853`}, 1, 
        0.32322494077764036`}, {{5.027236704502549, 3.456468031047497}, 1, 
        0.2703929873379574}, {{5.236954837353358, -4.210653391249402}, 1, 
        0.29368172298329354`}, {{5.291561671985107, -3.788237909030356}, 1, 
        0.31218713952969657`}, {{5.252308684150176, -3.2591607368379307`}, 1, 
        0.34164457781148744`}, {{5.237219438157749, -2.722612715788392}, 1, 
        0.3470536897021111}, {{5.2189764166028985`, -2.234561041266248}, 1, 
        0.3395089346882117}, {{5.261430059484951, -1.7155323173990347`}, 1, 
        0.33987346095154664`}, {{5.264594589930286, -1.2855984095393693`}, 1, 
        0.28495750126102376`}, {{5.209750448701537, -0.7623199200154217}, 1, 
        0.29642049723401154`}, {{5.279431825853254, -0.20021028433532917`}, 1,
         0.3596830577795727}, {{5.210943173424514, 0.24827398091785124`}, 1, 
        0.3185583151421701}, {{5.240987141014835, 0.7570389939220854}, 1, 
        0.30357402899596186`}, {{5.233706468921965, 1.2418059498703542`}, 1, 
        0.3325045885805734}, {{5.204032303661477, 1.7676923851714876`}, 1, 
        0.2594112695960316}, {{5.242144796936858, 2.23004385890071}, 1, 
        0.33659426630970746`}, {{5.251723619511302, 2.7268531220094183`}, 1, 
        0.2762452337461809}, {{5.204925358779109, 3.252656574689102}, 1, 
        0.2703929873379574}, {{5.232747202908403, 3.761414163275666}, 1, 
        0.349641300570443}, {{5.493495299294159, -4.481811107911863}, 1, 
        0.3490471292742324}, {{5.518152612978117, -4.002987427184965}, 1, 
        0.31218713952969657`}, {{5.483744850592621, -3.519491187896442}, 1, 
        0.3303924549076708}, {{5.538720787124864, -3.0027771428496357`}, 1, 
        0.2833588076417918}, {{5.472801677168107, -2.4677651688142928`}, 1, 
        0.31680064899870086`}, {{5.497733646110028, -1.959816136771721}, 1, 
        0.33987346095154664`}, {{5.539095208246142, -1.509571118684647}, 1, 
        0.31607706604931807`}, {{5.493701342448551, -1.0275085219432087`}, 1, 
        0.318436631258281}, {{5.4969504113092835`, -0.539614977585357}, 1, 
        0.3241300755197718}, {{5.54197772293725, 0.04563835604737325}, 1, 
        0.23548246001059506`}, {{5.492025052530175, 0.5077284477255412}, 1, 
        0.35380189578746296`}, {{5.509230520028847, 0.9842241927717074}, 1, 
        0.3344526802376814}, {{5.548529753236016, 1.5395395556374045`}, 1, 
        0.24359180197407534`}, {{5.54107790705073, 2.0372116199566723`}, 1, 
        0.23616656301374933`}, {{5.514784902643395, 2.509030743533846}, 1, 
        0.3395444154551384}, {{5.452357119925867, 2.9899887628063078`}, 1, 
        0.31692778937656746`}, {{5.4919832254752885`, 3.526795912348139}, 1, 
        0.349641300570443}, {{5.754623473815839, -4.250195100421971}, 1, 
        0.3420966263098593}, {{5.752888017229147, -3.763632968967214}, 1, 
        0.31222946876198954`}, {{5.710922131367287, -3.2726865784787624`}, 1, 
        0.3201630934391584}, {{5.705937605919863, -2.774017991381857}, 1, 
        0.2833588076417918}, {{5.718944408430038, -2.268324934526136}, 1, 
        0.31680064899870086`}, {{5.763912553389689, -1.731746439107398}, 1, 
        0.31607706604931807`}, {{5.759713888401191, -1.202549127297843}, 1, 
        0.318436631258281}, {{5.765382800153673, -0.7212859947448025}, 1, 
        0.30290391385408166`}, {{5.768635981350461, -0.2897607472545153}, 1, 
        0.2706663621010621}, {{5.700597897510277, 0.21968326172135125`}, 1, 
        0.23548246001059506`}, {{5.766278861424595, 0.7702504899391769}, 1, 
        0.3028978265308462}, {{5.758614672034989, 1.242887349373212}, 1, 
        0.3593036095767436}, {{5.711655387608756, 1.720445590361148}, 1, 
        0.24359180197407534`}, {{5.705726654805842, 2.206520318340426}, 1, 
        0.23616656301374933`}, {{5.700733256241469, 2.7931321688399104`}, 1, 
        0.31692778937656746`}, {{5.7997890488859785`, 3.280538309722283}, 1, 
        0.2641970917600207}, {{5.781788847811431, 3.761457103366046}, 1, 
        0.3487219000116766}, {{5.9858764954962895`, -4.53771525117032}, 1, 
        0.3460152688776608}, {{5.97207495941024, -3.985993769336111}, 1, 
        0.31222946876198954`}, {{6.0204936953426165`, -3.516429256425517}, 1, 
        0.30358926209579284`}, {{6.003438978059779, -2.9962330220815954`}, 1, 
        0.35351443958740264`}, {{6.019895797832339, -2.5361125181468682`}, 1, 
        0.2604681549132346}, {{6.037160116635184, -1.9664835120207724`}, 1, 
        0.24112502950669049`}, {{5.961281125797351, -1.4789998675200802`}, 1, 
        0.3206792522496296}, {{6.025504729026428, -0.9869291023819204}, 1, 
        0.30521469965556297`}, {{5.955554470991509, -0.48552018586050605`}, 1,
         0.2706663621010621}, {{6.024771472784959, 0.019938728778169212`}, 1, 
        0.34782126199378954`}, {{5.9557654221055305`, 0.5339415044172112}, 1, 
        0.3028978265308462}, {{6.0429826249735275`, 0.9584816254121231}, 1, 
        0.3346579344996595}, {{6.019888926609242, 1.5216567555875307`}, 1, 
        0.31359232973661305`}, {{6.020907665563287, 1.9944753947482339`}, 1, 
        0.3495086189859079}, {{6.049395231266625, 2.4880860120130475`}, 1, 
        0.3342155297710514}, {{5.967468687503509, 3.0407084168298297`}, 1, 
        0.29263430887664393`}, {{5.9794994334342855`, 3.4741985301599154`}, 1,
         0.2641970917600207}, {{6.230308570868324, -4.292808071149398}, 1, 
        0.3460152688776608}, {{6.218218307636935, -3.7468016023200046`}, 1, 
        0.30358926209579284`}, {{6.254803841841896, -3.2558789687674774`}, 1, 
        0.3057307292300098}, {{6.212663836645427, -2.7112814164594985`}, 1, 
        0.2604681549132346}, {{6.280032369056936, -2.2258176975456467`}, 1, 
        0.33171188443140087`}, {{6.2068984145398955`, -1.7952229208767096`}, 
        1, 0.24112502950669049`}, {{6.287049744083409, -1.23429932295777}, 1, 
        0.33610594948183603`}, {{6.237009487930655, -0.7668796764642403}, 1, 
        0.30521469965556297`}, {{6.216142078520122, -0.27877471770600387`}, 1,
         0.33264033098815665`}, {{6.237614256664029, 0.2950343115227123}, 1, 
        0.3298042143385181}, {{6.298673391016614, 0.7305168654641666}, 1, 
        0.2651136812300505}, {{6.208114823229744, 1.2708357813627968`}, 1, 
        0.31359232973661305`}, {{6.26836482014829, 1.7233249366135646`}, 1, 
        0.3187803090783135}, {{6.289896515592809, 2.2176373836828014`}, 1, 
        0.32298715323500965`}, {{6.213560978306394, 2.779203905381042}, 1, 
        0.3342155297710514}, {{6.2772326789473825`, 3.2289188001422997`}, 1, 
        0.33272427227878343`}, {{6.233528609249457, 3.705021602926689}, 1, 
        0.30269411255782197`}, {{6.520334264407486, -4.525858278980991}, 1, 
        0.32121860367788885`}, {{6.496478865166048, -4.010679074115541}, 1, 
        0.3305894332780932}, {{6.483324776476832, -3.4589786025167504`}, 1, 
        0.3057307292300098}, {{6.4803367866459265`, -3.0319043564095374`}, 1, 
        0.3178517518795005}, {{6.545710519812802, -2.454012914039463}, 1, 
        0.3456427966164088}, {{6.4816633956293135`, -1.9624212218737038`}, 1, 
        0.3199862082362895}, {{6.537595696583058, -1.5248486954022595`}, 1, 
        0.2820246274919235}, {{6.5132985754810235`, -0.9857461584872683}, 1, 
        0.31401234238825587`}, {{6.547699180990249, -0.5424860790850609}, 1, 
        0.3357571559839251}, {{6.499737597174629, 0.03504993613168948}, 1, 
        0.3211560109768174}, {{6.470466502042867, 0.5285951207726394}, 1, 
        0.2651136812300505}, {{6.466208987925173, 1.0300283332050004`}, 1, 
        0.34318405490316084`}, {{6.5001322376353805`, 1.50445339975363}, 1, 
        0.3187803090783135}, {{6.519730122759124, 1.9907074073205417`}, 1, 
        0.32298715323500965`}, {{6.466807461158549, 2.51343200227038}, 1, 
        0.33539052940271463`}, {{6.4893933361131975`, 2.972611763730079}, 1, 
        0.3280423730581927}, {{6.471096941345746, 3.517444916309843}, 1, 
        0.30269411255782197`}, {{6.707729940483884, -4.264967014396217}, 1, 
        0.32121860367788885`}, {{6.733501244762688, -3.7577063882878976`}, 1, 
        0.3466623547553227}, {{6.744431365002861, -3.229220855908949}, 1, 
        0.3296661148681017}, {{6.7358020637724385`, -2.7652203092028365`}, 1, 
        0.3226570897836281}, {{6.794693767828232, -2.2142707920406384`}, 1, 
        0.29958773744434136`}, {{6.715335561729572, -1.743815429975476}, 1, 
        0.2820246274919235}, {{6.778484779903059, -1.294299125245639}, 1, 
        0.28716019301820994`}, {{6.765203324094191, -0.798268829729106}, 1, 
        0.29108133308908674`}, {{6.708754657143935, -0.2350065325661806}, 1, 
        0.33034227712403413`}, {{6.748395862935642, 0.2382991680005137}, 1, 
        0.3211560109768174}, {{6.769361321030737, 0.7423817037037406}, 1, 
        0.35062602338748516`}, {{6.727298921589896, 1.2708542516906707`}, 1, 
        0.3258423917703637}, {{6.761631380546853, 1.7073487180999578`}, 1, 
        0.2731453207551938}, {{6.793797676827208, 2.2285606399785682`}, 1, 
        0.2527658889156018}, {{6.717200015543992, 2.736569574008907}, 1, 
        0.3280423730581927}, {{6.75799561305477, 3.293780949181405}, 1, 
        0.2703769102185136}, {{6.72250624771576, 3.750840366049545}, 1, 
        0.34304529626369923`}, {{6.992660051325198, -4.512403620843119}, 1, 
        0.3699639121853027}, {{6.994021467812701, -4.004860508704816}, 1, 
        0.31158916589548485`}, {{7.027456727231007, -3.5141347911140133`}, 1, 
        0.32362710017158886`}, {{6.985266810668766, -2.9698539761386353`}, 1, 
        0.3226570897836281}, {{6.979060864295365, -2.452433959114527}, 1, 
        0.30118585692290745`}, {{7.015905489638029, -2.0122356798423757`}, 1, 
        0.29958773744434136`}, {{6.951761942705469, -1.5232882108051977`}, 1, 
        0.28716019301820994`}, {{6.954274109091176, -1.0195843979423336`}, 1, 
        0.29108133308908674`}, {{6.95796426587826, -0.4518488507837658}, 1, 
        0.3301125659695432}, {{7.037074093547184, 0.043846028048759644`}, 1, 
        0.23297072563523785`}, {{6.99996865282349, 0.45437020003482936`}, 1, 
        0.3210582124553661}, {{7.014567845831424, 0.9930056619992144}, 1, 
        0.3121832531778481}, {{6.957308601498292, 1.5167738208779487`}, 1, 
        0.2731453207551938}, {{6.970546378018723, 2.04786617070403}, 1, 
        0.2527658889156018}, {{6.979851874267285, 2.480908611991962}, 1, 
        0.3102984833924566}, {{7.035279567349957, 2.9677201468426655`}, 1, 
        0.2744884788144892}, {{6.950791009971921, 3.4833425711064887`}, 1, 
        0.2703769102185136}, {{7.219374077711929, -4.2200441733149585`}, 1, 
        0.31158916589548485`}, {{7.299029067266452, -3.793369218088314}, 1, 
        0.24111468872428016`}, {{7.215099968620753, -3.2504597753726254`}, 1, 
        0.32362710017158886`}, {{7.291064801388192, -2.791520367304548}, 1, 
        0.30274987486743865`}, {{7.228025875073569, -2.244305803421385}, 1, 
        0.31440674320901385`}, {{7.241096148564702, -1.7958905673393772`}, 1, 
        0.29230499522239}, {{7.263458029242146, -1.2873114654205995`}, 1, 
        0.3135118227300521}, {{7.2337875470664095`, -0.7626643882173257}, 1, 
        0.3733048797470579}, {{7.242911651223422, -0.2851776361246296}, 1, 
        0.3041713498337453}, {{7.203935672799124, 0.20642699979071238`}, 1, 
        0.23297072563523785`}, {{7.257632083873466, 0.797102217032705}, 1, 
        0.3121832531778481}, {{7.203144662827205, 1.2730844286842238`}, 1, 
        0.33764675543540484`}, {{7.238258006161537, 1.717146390347664}, 1, 
        0.3283397010224753}, {{7.2041155955607525`, 2.266453646772537}, 1, 
        0.3102984833924566}, {{7.2231580375407844`, 2.7676061657202893`}, 1, 
        0.2744884788144892}, {{7.213050794172561, 3.257974014077085}, 1, 
        0.34036732588565194`}, {{7.295132162467215, 3.711911969141674}, 1, 
        0.32122767827394766`}, {{7.521954645607859, -4.496135418583537}, 1, 
        0.29498305238620565`}, {{7.48167413322507, -3.9507765654377263`}, 1, 
        0.24111468872428016`}, {{7.488167098541449, -3.533471030366212}, 1, 
        0.303401729249554}, {{7.538762482001648, -2.9655989293130967`}, 1, 
        0.25687345236198983`}, {{7.484231425742324, -2.539898030156924}, 1, 
        0.31721781998494825`}, {{7.481130398128181, -1.9627011463458017`}, 1, 
        0.29230499522239}, {{7.48108676291512, -1.512982458841148}, 1, 
        0.3135118227300521}, {{7.542872391966645, -0.9798475366934658}, 1, 
        0.3155518938030942}, {{7.4769711673543675`, -0.47943610561368527`}, 1,
         0.3041713498337453}, {{7.51971435442586, -0.04745370241375506}, 1, 
        0.29157310403508696`}, {{7.463920373181807, 0.4625898803092296}, 1, 
        0.3649814595135175}, {{7.524582191958645, 1.0406343284445707`}, 1, 
        0.35095637133716834`}, {{7.491965727573949, 1.5087252988927673`}, 1, 
        0.3283397010224753}, {{7.492908058733574, 2.041410893882297}, 1, 
        0.3488585867884829}, {{7.4537986290325, 2.492196329258979}, 1, 
        0.3366026974042665}, {{7.504145576731927, 2.957009823195394}, 1, 
        0.2862158759015776}, {{7.519567203290176, 3.4820943594159033`}, 1, 
        0.30801149666422695`}, {{7.723015178603745, -4.280289030458804}, 1, 
        0.29498305238620565`}, {{7.738480440375056, -3.7049231817429487`}, 1, 
        0.303401729249554}, {{7.730142786637101, -3.2504414937653388`}, 1, 
        0.3431642573551165}, {{7.711509273020688, -2.7754870761292634`}, 1, 
        0.25687345236198983`}, {{7.760428432211241, -2.252987791351584}, 1, 
        0.3045014118824152}, {{7.79758889983888, -1.788076956438493}, 1, 
        0.289718760672902}, {{7.785846240252596, -1.2436221197961543`}, 1, 
        0.3360857238852205}, {{7.755623172264931, -0.7468022553312602}, 1, 
        0.2923199815380942}, {{7.742938181519022, -0.2350330136784513}, 1, 
        0.29157310403508696`}, {{7.7518245432324315`, 0.21100141540976067`}, 
        1, 0.339990775682618}, {{7.788792604787094, 0.757957163126155}, 1, 
        0.3374630218423826}, {{7.782257339942256, 1.2789070559938573`}, 1, 
        0.27380052021568346`}, {{7.765777426183349, 1.7382461935849596`}, 1, 
        0.3508285579600609}, {{7.7437768995672, 2.283830237736806}, 1, 
        0.3206728446222535}, {{7.735634639546248, 2.7886876873502984`}, 1, 
        0.2862158759015776}, {{7.732267626546512, 3.2593173138660694`}, 1, 
        0.30801149666422695`}, {{7.775206207335007, 3.741675478701882}, 1, 
        0.3260359116711755}, {{7.984678726707632, -4.502605729695437}, 1, 
        0.3433548123527416}, {{8.039359967082412, -3.9647024015019636`}, 1, 
        0.31316720551062754`}, {{8.0290555544427, -3.4558034743641772`}, 1, 
        0.3096964736144095}, {{7.996421785563389, -3.029669387823512}, 1, 
        0.34589713504331787`}, {{7.977231011210269, -2.466804889773938}, 1, 
        0.3045014118824152}, {{8.007629180776295, -1.9876265509496673`}, 1, 
        0.289718760672902}, {{7.994973671268013, -1.5457119457677952`}, 1, 
        0.2983602424145267}, {{8.041851754592946, -1.0258727445346267`}, 1, 
        0.29601754161974}, {{7.951196771700813, -0.5295421835046014}, 1, 
        0.2923199815380942}, {{8.006217115046699, -0.014560431884925111`}, 1, 
        0.317610929846083}, {{8.018929145154301, 0.5111405026293293}, 1, 
        0.33339437637556046`}, {{8.031010907711691, 1.043764089413193}, 1, 
        0.3288291695858061}, {{7.984250418446669, 1.463746232324767}, 1, 
        0.27380052021568346`}, {{8.04165094062928, 1.9584664909151566`}, 1, 
        0.2836266289251499}, {{8.005194864003968, 2.4695497066889445`}, 1, 
        0.30284136498560826`}, {{7.995229155065891, 3.038135878738669}, 1, 
        0.30828026055547536`}, {{7.9779638527937005`, 3.486354596462882}, 1, 
        0.3260359116711755}, {{8.287599974289597, -4.274237570311664}, 1, 
        0.3793590627056994}, {{8.282990181525687, -3.767933457769322}, 1, 
        0.31316720551062754`}, {{8.29574821969665, -3.2983648257770373`}, 1, 
        0.3096964736144095}, {{8.281793409824875, -2.788391274264721}, 1, 
        0.3737005378857883}, {{8.23953110464995, -2.233804393892112}, 1, 
        0.338204128673938}, {{8.212864264670573, -1.7495317768940504`}, 1, 
        0.2983602424145267}, {{8.25852019693826, -1.2275684833053049`}, 1, 
        0.29601754161974}, {{8.278613846223905, -0.7632780092188172}, 1, 
        0.35357076102111}, {{8.26686925630898, -0.23603497422046132`}, 1, 
        0.3420387575222244}, {{8.223418982219936, 0.21717228409223857`}, 1, 
        0.317610929846083}, {{8.221640101243088, 0.7758291470408698}, 1, 
        0.3288291695858061}, {{8.295455129426236, 1.2808176876293562`}, 1, 
        0.3551410351190656}, {{8.234040126953492, 1.7500667173525337`}, 1, 
        0.2836266289251499}, {{8.212464947900548, 2.248751145398679}, 1, 
        0.30284136498560826`}, {{8.238291907256842, 2.7484315431295707`}, 1, 
        0.36346844466848627`}, {{8.230671538075674, 3.2371424196633996`}, 1, 
        0.30828026055547536`}, {{8.29876080260689, 3.7822359370216825`}, 1, 
        0.4364131651317584}}, Optica`Optica`ShowClones -> False, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     RuntimeAttributes -> {Listable}, Parallelization -> False, 
     CompilationTarget -> "MVM", RuntimeOptions -> "Speed", 
     Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147278999557953`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900027254*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900030121*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.01850100000000000008415490526658686576`4.287795116425592", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.01850100000000000008415490526658686576`4.287795116425592, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900033059*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900034893*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900037053*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279000391483`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279000412703`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900043195*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900044775*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900046032*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900047205*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279005694637`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900571155*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900572657*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900574003*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"LineOfRays", "[", 
              RowBox[{"0.5`", ",", 
               RowBox[{"IntrinsicMedium", "\[Rule]", "1.3`"}], ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "7"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "4.`"}]}], "}"}], ",", "55.`"}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "4.`"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "0.573576436351046`", ",", "0.8191520442889918`", ",", "0"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.8191520442889918`"}], ",", "0.573576436351046`",
               ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}], 
       "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`LineOfRays[{
           Optica`Optica`Ray[]}, 0.5, Optica`Optica`IntrinsicMedium -> 1.3, 
          Optica`Optica`NumberOfRays -> 7, 
          Optica`Optica`SourceTransformation -> {{
            0, -4., 0}, {{
             0.573576436351046, 0.8191520442889918, 0}, {-0.8191520442889918, 
              0.573576436351046, 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{0, -4, 0}, {{
              Sin[35 Degree], 
              Cos[35 Degree], 0}, {-Cos[35 Degree], 
              Sin[35 Degree], 0}, {
             0, 0, Cos[35 Degree]^2 + Sin[35 Degree]^2}}}]], 
       Optica`Optica`SourceTransformation :> {{
         0, -4., 0}, {{
          0.573576436351046, 0.8191520442889918, 0}, {-0.8191520442889918, 
           0.573576436351046, 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{0, -4, 0}, {{
           Sin[35 Degree], 
           Cos[35 Degree], 0}, {-Cos[35 Degree], 
           Sin[35 Degree], 0}, {0, 0, Cos[35 Degree]^2 + Sin[35 Degree]^2}}}, 
       Optica`Optica`SourceLevel :> {1, 1}, Optica`Optica`NumberOfRays :> 7, 
       Optica`Optica`BirthPoint :> {0, 0, 0}, Optica`Optica`CoordinateSystem :> 
       Optica`Optica`CartesianCoordinates, Optica`Optica`StartAtBirthPoint :> 
       True, Optica`Optica`MonteCarlo :> False, Optica`Optica`SourceID :> 
       85791, Optica`Optica`SourceFraction :> 1, Optica`Optica`SourceOffset :> 
       0, Optica`Optica`GridSpacing :> (#& ), Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues -> {}, Optica`Optica`IntrinsicMedium :> 
       1.3], False, False, False, 
      False, {{0, -4., 0}, {{
        0.573576436351046, 0.8191520442889918, 0}, {-0.8191520442889918, 
         0.573576436351046, 0}, {0, 0, 1.}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727900575904*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727901337223*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727901339291*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727901341185*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279015607033`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727901601799*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727901603361*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.61472790160529*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727901607082*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "10"}],
  SequenceForm["maximum used clone sort position = ", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727908843977*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1645", ",", "709", ",", "268", ",", "93", ",", "31", ",", "17", ",", "2",
      ",", "4", ",", "4", ",", "2"}], "}"}]}],
  SequenceForm[
  "Histogram of used sort positions: ", {1645, 709, 268, 93, 31, 17, 2, 4, 4, 
   2}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727908846528*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({1645, 709, 268, 93, 31, \
17, 2, 4, 4, 2}\\)\\), \\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \
\[Rule] All\\)\\)\\)\\)]\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/optx\\\", \
ButtonNote -> \\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614727908903214*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You may wish to set CloneSortLength -> \"\>", 
   "\[InvisibleSpace]", "11"}],
  SequenceForm["You may wish to set CloneSortLength -> ", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727908907299*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "7.36136700000000043786485548480413854122`6.887558383246247", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "5685",
    "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   7.36136700000000043786485548480413854122`6.887558383246247, 
   " seconds with ", 5685, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727908951812*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279089927473`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727908994356*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727908996039*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.61472790899798*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279089995327`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909001678*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909004833*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909007556*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279090097027`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909012162*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909014144*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909016657*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909019073*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727909021624*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.6147279090237427`*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727910741795*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"During evaluation of In[281]:="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.5, 
       0.}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.25000000000000006`, 
       0.4330127018922193}, {-0.25000000000000006`, 
       0.4330127018922193}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.2165063509461097}, \
{-0.25000000000000006`, -0.4330127018922193}, {-0.25000000000000006`, \
-0.4330127018922193}}, {{-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5,
        0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.5, 0.}}, {{0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {-0.24999999999999992`, \
-0.43301270189221935`}, {-0.24999999999999992`, -0.43301270189221935`}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {
       0.41284695471649935`, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.41284695471649935`, 0.282059199426845}, {
       0.5, 5.551115123125783*^-17}, {0.5, 5.551115123125783*^-17}, {
       0.4128469547164993, 0.282059199426845}, {0.25, 0.4330127018922193}, {
       0.03784695471649929, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}, {0.25, 
       0.4330127018922193}}, {{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}, {{-0.25000000000000006`, \
-0.4330127018922193}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.25000000000000006`, \
-0.4330127018922193}, {-0.25000000000000006`, -0.4330127018922193}}, \
{{-0.25000000000000006`, -0.4330127018922193}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.25000000000000006`, -0.4330127018922193}, {-0.25000000000000006`, \
-0.4330127018922193}}, {{-0.25000000000000006`, -0.4330127018922193}, \
{-0.45069390943299864`, -0.21650635094610965`}, {-0.45069390943299864`, \
-0.21650635094610965`}, {-0.25000000000000006`, -0.4330127018922193}, \
{-0.25000000000000006`, -0.4330127018922193}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.45069390943299864`, \
-0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}, {-0.45069390943299864`, -0.21650635094610965`}, \
{-0.45069390943299864`, -0.21650635094610965`}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 0.}}, {{-0.5, 
       0.}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.45069390943299864`, 
       0.21650635094610965`}, {-0.5, 0.}, {-0.5, 
       0.}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 
       0.2165063509461097}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 
       0.2165063509461097}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 
       0.2165063509461097}}, {{-0.45069390943299864`, 
       0.2165063509461097}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.24999999999999994`, 
       0.43301270189221935`}, {-0.45069390943299864`, 
       0.2165063509461097}, {-0.45069390943299864`, 0.2165063509461097}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.5, -5.551115123125783*^-17}, {
       0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}, {
       0.5, -5.551115123125783*^-17}, {0.5, -5.551115123125783*^-17}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.4128469547164993, -0.282059199426845}, {0.25, -0.4330127018922193}, {
       0.25, -0.4330127018922193}, {0.4128469547164993, -0.282059199426845}, {
       0.4128469547164993, -0.282059199426845}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.25, -0.4330127018922193}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.03784695471649935, -0.4985655503729547}, {
       0.25, -0.4330127018922193}, {0.25, -0.4330127018922193}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{
       0.03784695471649929, -0.4985655503729547}, {-0.25, \
-0.4330127018922193}, {-0.25, -0.4330127018922193}, {
       0.03784695471649929, -0.4985655503729547}, {
       0.03784695471649929, -0.4985655503729547}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{-0.24999999999999992`, 
       0.43301270189221935`}, {0.03784695471649935, 0.4985655503729547}, {
       0.03784695471649935, 0.4985655503729547}, {-0.24999999999999992`, 
       0.43301270189221935`}, {-0.24999999999999992`, 
       0.43301270189221935`}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.03784695471649935, 0.4985655503729547}, {
       0.25, 0.4330127018922193}, {0.25, 0.4330127018922193}, {
       0.03784695471649935, 0.4985655503729547}, {0.03784695471649935, 
       0.4985655503729547}}, {{0.25, 0.4330127018922193}, {0.4128469547164993,
        0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}, {{0.25, 
       0.4330127018922193}, {0.4128469547164993, 0.282059199426845}, {
       0.4128469547164993, 0.282059199426845}, {0.25, 0.4330127018922193}, {
       0.25, 0.4330127018922193}}, {{0.25, 0.4330127018922193}, {
       0.4128469547164993, 0.282059199426845}, {0.4128469547164993, 
       0.282059199426845}, {0.25, 0.4330127018922193}, {0.25, 
       0.4330127018922193}}, {{0.25, 0.4330127018922193}, {0.4128469547164993,
        0.282059199426845}, {0.4128469547164993, 0.282059199426845}, {0.25, 
       0.4330127018922193}, {0.25, 0.4330127018922193}}, {{
       0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}, {{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}, {{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}, {{0.41284695471649935`, 0.282059199426845}, {
       0.5, -8.326672684688674*^-17}, {0.5, -8.326672684688674*^-17}, {
       0.41284695471649935`, 0.282059199426845}, {0.41284695471649935`, 
       0.282059199426845}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIIGZYc0MBBygPFnzQQB0QO4+Ojq8epneGGP
l0/IPiz6UezDwidJPyH/ELKPUPgQch8R4UuufwAQKIsK
      "]],
     FontColor->GrayLevel[0.]]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{0.2047880110722482, -4.143394109087762}, {
     1.9560137310943797`, -1.6423845876826284`}}]}, 
   {Hue[0.000555743948504861], AbsoluteThickness[0.5], 
    LineBox[{{1.9560137310943797`, -1.6423845876826284`}, {
     2.1153223232689444`, -1.389386026533712}}]}, 
   {Hue[0.528565297505308], AbsoluteThickness[0.5], 
    LineBox[{{2.1153223232689444`, -1.389386026533712}, {
     1.8330044135591281`, -1.4877938379164908`}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{0.13652534071483213`, -4.095596072725175}, {
     1.882107769520672, -1.6026460064220551`}}]}, 
   {Hue[0.00044324200995078385`], AbsoluteThickness[0.5], 
    LineBox[{{1.882107769520672, -1.6026460064220551`}, {
     2.066922264313572, -1.3487919030164772`}}]}, 
   {Hue[0.5513248024577007], AbsoluteThickness[0.5], 
    LineBox[{{2.066922264313572, -1.3487919030164772`}, {
     1.954842265840816, -1.6421114851172183`}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{0.06826267035741607, -4.047798036362586}, {
     1.8367319093220917`, -1.5221622177504404`}}]}, 
   {Hue[0.0011983447582095796`], AbsoluteThickness[0.5], 
    LineBox[{{1.8367319093220917`, -1.5221622177504404`}, {
     2.004287914679665, -1.3301458579483183`}}]}, 
   {Hue[0.4516400298884454], AbsoluteThickness[0.5], 
    LineBox[{{2.004287914679665, -1.3301458579483183`}, {
     2.1384438337551965`, -1.5468195451833913`}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{0., -4.}, {1.9545106876515372`, -1.2086694572742964`}}]}, 
   {Hue[0.0007499774332230369], AbsoluteThickness[0.5], 
    LineBox[{{1.9545106876515372`, -1.2086694572742964`}, {
     2.1284527919113003`, -0.9163423787231371}}]}, 
   {Hue[0.49847348106340955`], AbsoluteThickness[0.5], 
    LineBox[{{2.1284527919113003`, -0.9163423787231371}, {
     1.789079174411768, -0.9395053714888068}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{-0.06826267035741584, -3.952201963637413}, {
     1.8700901255124163`, -1.1839472818529069`}}]}, 
   {Hue[0.00043266810522628595`], AbsoluteThickness[0.5], 
    LineBox[{{1.8700901255124163`, -1.1839472818529069`}, {
     2.0859887022917047`, -0.8678901862612524}}]}, 
   {Hue[0.5537564323070185], AbsoluteThickness[0.5], 
    LineBox[{{2.0859887022917047`, -0.8678901862612524}, {
     1.8206460083953961`, -1.1437480082004026`}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{-0.1365253407148319, -3.904403927274826}, {
     1.8078604291837093`, -1.1275332656564923`}}]}, 
   {Hue[0.000527278772796802], AbsoluteThickness[0.5], 
    LineBox[{{1.8078604291837093`, -1.1275332656564923`}, {
     2.0310311183536442`, -0.8366232735464462}}]}, 
   {Hue[0.5338522755616159], AbsoluteThickness[0.5], 
    LineBox[{{2.0310311183536442`, -0.8366232735464462}, {
     2.0129307740056084`, -1.2028283493557852`}}]}, 
   {Hue[0.], AbsoluteThickness[0.5], 
    LineBox[{{-0.20478801107224798`, -3.8566058909122383`}, {
     1.7733509799403857`, -1.0315306338386876`}}]}, 
   {Hue[0.0019210972152715609`], AbsoluteThickness[0.5], 
    LineBox[{{1.7733509799403857`, -1.0315306338386876`}, {
     1.9651450743716459`, -0.8248557865918168}}]}, 
   {Hue[0.4048828921182087], AbsoluteThickness[0.5], 
    LineBox[{{1.9651450743716459`, -0.8248557865918168}, {
     2.1562791974221627`, -1.0321411313437547`}}]}, 
   {Hue[0.5280095535567944], AbsoluteThickness[0.5], 
    LineBox[{{1.9560137310943797`, -1.6423845876826284`}, {
     1.97930662095472, -1.7863694982185387`}}]}, 
   {Hue[0.5284459890880805], AbsoluteThickness[0.5], 
    LineBox[{{1.97930662095472, -1.7863694982185387`}, {
     2.0381789055431354`, -2.119753107129809}}]}, 
   {Hue[0.0011114878970095664`], AbsoluteThickness[0.5], 
    LineBox[{{2.1153223232689444`, -1.389386026533712}, {
     2.2606948995445784`, -1.1313465119436217`}}]}, 
   {Hue[0.5322621731296068], AbsoluteThickness[0.5], 
    LineBox[{{2.2606948995445784`, -1.1313465119436217`}, {
     2.32315277239576, -1.4208347414127078`}}]}, 
   {Hue[0.00088648401990149], AbsoluteThickness[0.5], 
    LineBox[{{2.066922264313572, -1.3487919030164772`}, {
     2.0834706503543083`, -1.326920382741581}}]}, 
   {Hue[0.0018766248050255507`], AbsoluteThickness[0.5], 
    LineBox[{{2.0834706503543083`, -1.326920382741581}, {
     2.262372638884487, -1.1316097641396163`}}]}, 
   {Hue[0.4715600829794894], AbsoluteThickness[0.5], 
    LineBox[{{2.262372638884487, -1.1316097641396163`}, {
     2.370270436026428, -1.373498632446223}}]}, 
   {Hue[0.002396689516419392], AbsoluteThickness[0.5], 
    LineBox[{{2.004287914679665, -1.3301458579483183`}, {
     2.0812888098381914`, -1.2588840708996838`}}]}, 
   {Hue[0.0047066261592297095`], AbsoluteThickness[0.5], 
    LineBox[{{2.0812888098381914`, -1.2588840708996838`}, {
     2.2670682603612207`, -1.1324451152252941`}}]}, 
   {Hue[0.3891779694448897], AbsoluteThickness[0.5], 
    LineBox[{{2.2670682603612207`, -1.1324451152252941`}, {
     2.392280420828031, -1.319053605439171}}]}, 
   {Hue[0.45283837464665516`], AbsoluteThickness[0.5], 
    LineBox[{{2.1384438337551965`, -1.5468195451833913`}, {
     2.1671775229590065`, -1.6066417948719662`}}]}, 
   {Hue[0.4533508875274973], AbsoluteThickness[0.5], 
    LineBox[{{2.1671775229590065`, -1.6066417948719662`}, {
     2.3011391475046232`, -1.8589129244470415`}}]}, 
   {Hue[0.4977235036301653], AbsoluteThickness[0.5], 
    LineBox[{{1.9545106876515372`, -1.2086694572742964`}, {
     2.0228338803099546`, -1.3327728277793518`}}]}, 
   {Hue[0.49879359129930917`], AbsoluteThickness[0.5], 
    LineBox[{{2.0228338803099546`, -1.3327728277793518`}, {
     2.125358172331988, -1.5724825285002657`}}]}, 
   {Hue[0.0014999548664457628`], AbsoluteThickness[0.5], 
    LineBox[{{2.1284527919113003`, -0.9163423787231371}, {
     2.1592875673543537`, -0.8545175474288595}}]}, 
   {Hue[0.0019326459869130396`], AbsoluteThickness[0.5], 
    LineBox[{{2.1592875673543537`, -0.8545175474288595}, {
     2.303020693838452, -0.557764171057353}}]}, 
   {Hue[0.5552510297794911], AbsoluteThickness[0.5], 
    LineBox[{{2.303020693838452, -0.557764171057353}, {
     2.1119710972636905`, -0.8265053656766442}}]}, 
   {Hue[0.0008653362104527273], AbsoluteThickness[0.5], 
    LineBox[{{2.0859887022917047`, -0.8678901862612524}, {
     2.1129918794067524`, -0.827360737502542}}]}, 
   {Hue[0.0012996621585691147`], AbsoluteThickness[0.5], 
    LineBox[{{2.1129918794067524`, -0.827360737502542}, {
     2.2991858357518544`, -0.555562541606151}}]}, 
   {Hue[0.5542365944974024], AbsoluteThickness[0.5], 
    LineBox[{{2.2991858357518544`, -0.555562541606151}, {
     2.166356931192381, -0.8570570370542521}}]}, 
   {Hue[0.0010545575455936816`], AbsoluteThickness[0.5], 
    LineBox[{{2.0310311183536442`, -0.8366232735464462}, {
     2.0757367548146126`, -0.7833206287461137}}]}, 
   {Hue[0.0015818181047037249`], AbsoluteThickness[0.5], 
    LineBox[{{2.0757367548146126`, -0.7833206287461137}, {
     2.289049073240344, -0.5503703223263177}}]}, 
   {Hue[0.5349103073298415], AbsoluteThickness[0.5], 
    LineBox[{{2.289049073240344, -0.5503703223263177}, {
     2.2460771160867123`, -0.863294276908935}}]}, 
   {Hue[0.5343795543344128], AbsoluteThickness[0.5], 
    LineBox[{{2.0129307740056084`, -1.2028283493557852`}, {
     2.0010893252330284`, -1.3299170258479518`}}]}, 
   {Hue[0.5348061582410727], AbsoluteThickness[0.5], 
    LineBox[{{2.0010893252330284`, -1.329917025847952}, {
     1.9729260196673701`, -1.6453056890203372`}}]}, 
   {Hue[0.0038421944305432774`], AbsoluteThickness[0.5], 
    LineBox[{{1.9651450743716459`, -0.8248557865918168}, {
     2.060128630699806, -0.7471751527818549}}]}, 
   {Hue[0.004407162438395551], AbsoluteThickness[0.5], 
    LineBox[{{2.060128630699806, -0.7471751527818549}, {
     2.3106622827777135`, -0.5625744810277119}}]}, 
   {Hue[0.5307526888985317], AbsoluteThickness[0.5], 
    LineBox[{{2.3106622827777135`, -0.5625744810277119}, {
     2.2359485386695637`, -0.8646711133772247}}]}, 
   {Hue[0.4068039893334806], AbsoluteThickness[0.5], 
    LineBox[{{2.1562791974221627`, -1.0321411313437547`}, {
     2.2243809523618268`, -1.13006358101904}}]}, 
   {Hue[0.4075107785975091], AbsoluteThickness[0.5], 
    LineBox[{{2.2243809523618268`, -1.13006358101904}, {
     2.3699603171817376`, -1.3739798601672393`}}]}, 
   {Hue[0.5288824246193665], AbsoluteThickness[0.5], 
    LineBox[{{2.0381789055431354`, -2.119753107129809}, {
     2.0782629280729368`, -2.3290878605396204`}}]}, 
   {Hue[0.5297165335771912], AbsoluteThickness[0.5], 
    LineBox[{{2.0782629280729368`, -2.3290878605396204`}, {
     2.1095305011880603`, -2.6193988342058363`}}]}, 
   {Hue[0.0016502294340482004`], AbsoluteThickness[0.5], 
    LineBox[{{2.2606948995445784`, -1.1313465119436217`}, {
     2.3087600259747534`, -1.0360805649952733`}}]}, 
   {Hue[0.5328009146666454], AbsoluteThickness[0.5], 
    LineBox[{{2.32315277239576, -1.4208347414127078`}, {
     2.335355689863082, -1.4670266612985594`}}]}, 
   {Hue[0.0028667655901496113`], AbsoluteThickness[0.5], 
    LineBox[{{2.262372638884487, -1.1316097641396163`}, {
     2.316084107800785, -1.0830210846604835`}}]}, 
   {Hue[0.003477609746204102], AbsoluteThickness[0.5], 
    LineBox[{{2.316084107800785, -1.0830210846604835`}, {
     2.574210944452958, -0.8752464242217954}}]}, 
   {Hue[0.5219321086184421], AbsoluteThickness[0.5], 
    LineBox[{{2.574210944452958, -0.8752464242217954}, {
     2.536801312127581, -1.2044884214362297`}}]}, 
   {Hue[0.47255022376461353`], AbsoluteThickness[0.5], 
    LineBox[{{2.370270436026428, -1.373498632446223}, {
     2.3773046192308436`, -1.3943251868908686`}}]}, 
   {Hue[0.47314929704277575`], AbsoluteThickness[0.5], 
    LineBox[{{2.3773046192308436`, -1.3943251868908686`}, {
     2.48017325188623, -1.6506622385460314`}}]}, 
   {Hue[0.3868680328020806], AbsoluteThickness[0.5], 
    LineBox[{{2.0812888098381914`, -1.2588840708996838`}, {
     2.047667128693673, -1.1901675007515287`}}]}, 
   {Hue[0.3872939490754955], AbsoluteThickness[0.5], 
    LineBox[{{2.047667128693673, -1.1901675007515287`}, {
     1.8792487679544736`, -0.8449829790166183}}]}, 
   {Hue[0.007016562802040104], AbsoluteThickness[0.5], 
    LineBox[{{2.2670682603612207`, -1.1324451152252941`}, {
     2.324173623008653, -1.1049694084633594`}}]}, 
   {Hue[0.007443091505272525], AbsoluteThickness[0.5], 
    LineBox[{{2.324173623008653, -1.1049694084633594`}, {
     2.6474587511591996`, -0.9508735136032455}}]}, 
   {Hue[0.5622124407201573], AbsoluteThickness[0.5], 
    LineBox[{{2.6474587511591996`, -0.9508735136032455}, {
     2.332735100249149, -1.1217765342140673`}}]}, 
   {Hue[0.3914879060877002], AbsoluteThickness[0.5], 
    LineBox[{{2.392280420828031, -1.319053605439171}, {
     2.415422350562636, -1.367974078879432}}]}, 
   {Hue[0.3919137923411333], AbsoluteThickness[0.5], 
    LineBox[{{2.415422350562636, -1.367974078879432}, {
     2.5428036770174884`, -1.6366953665276778`}}]}, 
   {Hue[0.4538634004083394], AbsoluteThickness[0.5], 
    LineBox[{{2.3011391475046232`, -1.8589129244470415`}, {
     2.3265622170095095`, -1.902449279872797}}]}, 
   {Hue[0.45484290786057546`], AbsoluteThickness[0.5], 
    LineBox[{{2.3265622170095095`, -1.902449279872797}, {
     2.483692868014906, -2.121780497125626}}]}, 
   {Hue[0.4998636789684532], AbsoluteThickness[0.5], 
    LineBox[{{2.125358172331988, -1.5724825285002657`}, {
     2.144810781160395, -1.6342584965342704`}}]}, 
   {Hue[0.5009386664124803], AbsoluteThickness[0.5], 
    LineBox[{{2.144810781160395, -1.6342584965342704`}, {
     2.2410433501643467`, -1.8590674240708562`}}]}, 
   {Hue[0.5548183386590254], AbsoluteThickness[0.5], 
    LineBox[{{2.1592875673543537`, -0.8545175474288595}, {
     2.137440064265919, -0.9326965158612096}}]}, 
   {Hue[0.5564846482654002], AbsoluteThickness[0.5], 
    LineBox[{{2.137440064265919, -0.9326965158612096}, {
     2.024491448696766, -1.1994479195888008`}}]}, 
   {Hue[0.0023653371073804716`], AbsoluteThickness[0.5], 
    LineBox[{{2.303020693838452, -0.557764171057353}, {
     2.3807463399287565`, -0.3924329332847882}}]}, 
   {Hue[0.012314795345929774`], AbsoluteThickness[0.5], 
    LineBox[{{2.3807463399287565`, -0.3924329332847882}, {
     2.4143232804004513`, -0.2163578617178128}}]}, 
   {Hue[0.2525424554991802], AbsoluteThickness[0.5], 
    LineBox[{{2.4143232804004513`, -0.2163578617178128}, {
     2.262451499927947, -0.12114859717456194`}}]}, 
   {Hue[0.4927701156524304], AbsoluteThickness[0.5], 
    LineBox[{{2.262451499927947, -0.12114859717456194`}, {
     2.1186018844537418`, -0.22809311497084045`}}]}, 
   {Hue[0.5556837208999584], AbsoluteThickness[0.5], 
    LineBox[{{2.1119710972636905`, -0.8265053656766442}, {
     2.084240693932012, -0.8664858826835218}}]}, 
   {Hue[0.5561127107380589], AbsoluteThickness[0.5], 
    LineBox[{{2.084240693932012, -0.8664858826835218}, {
     1.8632187137707872`, -1.1798584316618623`}}]}, 
   {Hue[0.5538022685492865], AbsoluteThickness[0.5], 
    LineBox[{{2.1129918794067524`, -0.827360737502542}, {
     2.0778041290682894`, -0.861593729007438}}]}, 
   {Hue[0.5542505027434733], AbsoluteThickness[0.5], 
    LineBox[{{2.0778041290682894`, -0.861593729007438}, {
     1.8111568075446955`, -1.1320685177813679`}}]}, 
   {Hue[0.00173398810668558], AbsoluteThickness[0.5], 
    LineBox[{{2.2991858357518544`, -0.555562541606151}, {
     2.5798460427640495`, -0.1569902952206556}}]}, 
   {Hue[0.009771114149115877], AbsoluteThickness[0.5], 
    LineBox[{{2.5798460427640495`, -0.1569902952206556}, {2.6538509729954964`,
      0.02909034563879901}}]}, 
   {Hue[0.27069302276037815`], AbsoluteThickness[0.5], 
    LineBox[{{2.6538509729954964`, 0.02909034563879901}, {2.502101200611027, 
     0.1597606987510804}}]}, 
   {Hue[0.531614931371641], AbsoluteThickness[0.5], 
    LineBox[{{2.502101200611027, 0.1597606987510804}, {2.3290683843013364`, 
     0.058952072725509216`}}]}, 
   {Hue[0.5546709204455187], AbsoluteThickness[0.5], 
    LineBox[{{2.166356931192381, -0.8570570370542521}, {
     2.1344976513811247`, -0.9269151133813638}}]}, 
   {Hue[0.5556130433081603], AbsoluteThickness[0.5], 
    LineBox[{{2.1344976513811247`, -0.9269151133813637}, {
     1.9737597757056495`, -1.2087400762003564`}}]}, 
   {Hue[0.0021090786638139234`], AbsoluteThickness[0.5], 
    LineBox[{{2.289049073240344, -0.5503703223263177}, {
     2.423159903825275, -0.41613580177789505`}}]}, 
   {Hue[0.13809095116282608`], AbsoluteThickness[0.5], 
    LineBox[{{2.423159903825275, -0.41613580177789505`}, {
     2.5769096535090608`, -0.3639466285394853}}]}, 
   {Hue[0.16881244780599697`], AbsoluteThickness[0.5], 
    LineBox[{{2.5769096535090608`, -0.3639466285394853}, {
     2.7039167276434966`, -0.46509947551348524`}}]}, 
   {Hue[0.1995339444491678], AbsoluteThickness[0.5], 
    LineBox[{{2.7039167276434966`, -0.46509947551348524`}, {
     2.687453777822834, -0.6266286264873506}}]}, 
   {Hue[0.2302554410923314], AbsoluteThickness[0.5], 
    LineBox[{{2.687453777822834, -0.6266286264873506}, {
     2.542651272114298, -0.7000788114542039}}]}, 
   {Hue[0.26097693773549535`], AbsoluteThickness[0.5], 
    LineBox[{{2.542651272114298, -0.7000788114542039}, {
     2.4025916600511703`, -0.617944772226478}}]}, 
   {Hue[0.2916984343786571], AbsoluteThickness[0.5], 
    LineBox[{{2.4025916600511703`, -0.617944772226478}, {
     2.3959983788615347`, -0.4557127655992719}}]}, 
   {Hue[0.32241993102182087`], AbsoluteThickness[0.5], 
    LineBox[{{2.3959983788615347`, -0.4557127655992719}, {
     2.528931061332027, -0.3624840293516172}}]}, 
   {Hue[0.35314142766497975`], AbsoluteThickness[0.5], 
    LineBox[{{2.528931061332027, -0.3624840293516172}, {
     2.679216358875627, -0.4239415323383731}}]}, 
   {Hue[0.38386292430813856`], AbsoluteThickness[0.5], 
    LineBox[{{2.679216358875627, -0.4239415323383731}, {
     2.708732797502115, -0.5836020320931472}}]}, 
   {Hue[0.4145844209512964], AbsoluteThickness[0.5], 
    LineBox[{{2.708732797502115, -0.5836020320931472}, {
     2.5903529464070925`, -0.6947276645361432}}]}, 
   {Hue[0.44530591759445853`], AbsoluteThickness[0.5], 
    LineBox[{{2.5903529464070925`, -0.6947276645361432}, {
     2.4328752029803224`, -0.6551871074289425}}]}, 
   {Hue[0.4760274142376253], AbsoluteThickness[0.5], 
    LineBox[{{2.4328752029803224`, -0.6551871074289425}, {
     2.381031343372088, -0.5013205758112538}}]}, 
   {Hue[0.5067489108807841], AbsoluteThickness[0.5], 
    LineBox[{{2.381031343372088, -0.5013205758112538}, {
     2.4824690777940557`, -0.3745409190579958}}]}, 
   {Hue[0.5374704075239509], AbsoluteThickness[0.5], 
    LineBox[{{2.4824690777940557`, -0.3745409190579958}, {
     2.6439608608669043`, -0.39136647495037435`}}]}, 
   {Hue[0.568191904167128], AbsoluteThickness[0.5], 
    LineBox[{{2.6439608608669043`, -0.39136647495037435`}, {
     2.717085765993609, -0.5363335180372295}}]}, 
   {Hue[0.5989134008103097], AbsoluteThickness[0.5], 
    LineBox[{{2.717085765993609, -0.5363335180372295}, {
     2.634637487257481, -0.6762083787684762}}]}, 
   {Hue[0.6296348974535074], AbsoluteThickness[0.5], 
    LineBox[{{2.634637487257481, -0.6762083787684762}, {
     2.472391086977487, -0.682437417805097}}]}, 
   {Hue[0.6603563940967051], AbsoluteThickness[0.5], 
    LineBox[{{2.472391086977487, -0.682437417805097}, {
     2.3794610315889004`, -0.5492957634041916}}]}, 
   {Hue[0.6910778907399108], AbsoluteThickness[0.5], 
    LineBox[{{2.3794610315889004`, -0.5492957634041916}, {
     2.441255783782763, -0.3991488222683991}}]}, 
   {Hue[0.5354375678889517], AbsoluteThickness[0.5], 
    LineBox[{{2.2460771160867123`, -0.863294276908935}, {
     2.1966796432697526`, -1.1347751735741543`}}]}, 
   {Hue[0.5360382545780424], AbsoluteThickness[0.5], 
    LineBox[{{2.1966796432697526`, -1.1347751735741543`}, {
     2.160359371240067, -1.4265587676345128`}}]}, 
   {Hue[0.5352327621477326], AbsoluteThickness[0.5], 
    LineBox[{{1.9729260196673701`, -1.6453056890203372`}, {
     1.960306345369202, -1.7930385674724816`}}]}, 
   {Hue[0.5358808039546324], AbsoluteThickness[0.5], 
    LineBox[{{1.960306345369202, -1.7930385674724816`}, {
     1.9532882750253522`, -2.103835674951775}}]}, 
   {Hue[0.004972130446247824], AbsoluteThickness[0.5], 
    LineBox[{{2.3106622827777135`, -0.5625744810277119}, {
     2.3789798336257806`, -0.5173725760921701}}]}, 
   {Hue[0.005935256885100648], AbsoluteThickness[0.5], 
    LineBox[{{2.3789798336257806`, -0.5173725760921701}, {
     2.629954701912823, -0.3826817515782136}}]}, 
   {Hue[0.478409267731884], AbsoluteThickness[0.5], 
    LineBox[{{2.629954701912823, -0.3826817515782136}, {
     2.6485991144105494`, -0.6669041796210446}}]}, 
   {Hue[0.5313176569063838], AbsoluteThickness[0.5], 
    LineBox[{{2.2359485386695637`, -0.8646711133772247}, {
     2.1477440865800235`, -1.1570948687472213`}}]}, 
   {Hue[0.5332959915566512], AbsoluteThickness[0.5], 
    LineBox[{{2.1477440865800235`, -1.1570948687472213`}, {
     2.1123046943780666`, -1.3856197162041644`}}]}, 
   {Hue[0.4082175678615376], AbsoluteThickness[0.5], 
    LineBox[{{2.3699603171817376`, -1.3739798601672393`}, {
     2.3793082963431043`, -1.3924506898125644`}}]}, 
   {Hue[0.4087043114370972], AbsoluteThickness[0.5], 
    LineBox[{{2.3793082963431043`, -1.3924506898125644`}, {
     2.518442825919293, -1.6455766858849543`}}]}, 
   {Hue[0.5305506425350159], AbsoluteThickness[0.5], 
    LineBox[{{2.1095305011880603`, -2.6193988342058363`}, {
     2.11017117374207, -2.644629151925322}}]}, 
   {Hue[0.5377070225034712], AbsoluteThickness[0.5], 
    LineBox[{{2.11017117374207, -2.644629151925322}, {
     2.1586742043341216`, -2.8331319880891996`}}]}, 
   {Hue[0.0016502294340483559`], AbsoluteThickness[0.5], 
    LineBox[{{2.3087600259747534`, -1.0360805649952733`}, {
     2.2131441717851263`, -0.8654739989636542}}]}, 
   {Hue[0.0025369023171320725`], AbsoluteThickness[0.5], 
    LineBox[{{2.2131441717851263`, -0.8654739989636542}, {
     2.0629264913035983`, -0.6445111789519624}}]}, 
   {Hue[0.4833566036816303], AbsoluteThickness[0.5], 
    LineBox[{{2.0629264913035983`, -0.6445111789519624}, {
     2.3191080050454307`, -0.5686102476420434}}]}, 
   {Hue[0.5328009146666453], AbsoluteThickness[0.5], 
    LineBox[{{2.335355689863082, -1.4670266612985594`}, {
     2.2455719904600726`, -1.5668110681789522`}}]}, 
   {Hue[0.5379374632158346], AbsoluteThickness[0.5], 
    LineBox[{{2.2455719904600726`, -1.5668110681789522`}, {
     2.1381481554428183`, -1.6460174404628798`}}]}, 
   {Hue[0.5213212644623879], AbsoluteThickness[0.5], 
    LineBox[{{2.316084107800785, -1.0830210846604835`}, {
     2.1527176692662215`, -1.0566909470149246`}}]}, 
   {Hue[0.5217489155375125], AbsoluteThickness[0.5], 
    LineBox[{{2.1527176692662215`, -1.0566909470149246`}, {
     1.7742391635813046`, -0.9933775040856487}}]}, 
   {Hue[0.004088453902258593], AbsoluteThickness[0.5], 
    LineBox[{{2.574210944452958, -0.8752464242217954}, {
     2.651422997218358, -0.8201102077902793}}]}, 
   {Hue[0.004572462954861988], AbsoluteThickness[0.5], 
    LineBox[{{2.651422997218358, -0.8201102077902793}, {
     2.8860071186129446`, -0.6641302311772357}}]}, 
   {Hue[0.5465554080086175], AbsoluteThickness[0.5], 
    LineBox[{{2.8860071186129446`, -0.6641302311772357}, {
     2.7476184506268715`, -0.9095034972184168}}]}, 
   {Hue[0.5225429527744966], AbsoluteThickness[0.5], 
    LineBox[{{2.536801312127581, -1.2044884214362297`}, {
     2.5105920694408144`, -1.3564787175776614`}}]}, 
   {Hue[0.5229698478476883], AbsoluteThickness[0.5], 
    LineBox[{{2.5105920694408144`, -1.3564787175776614`}, {
     2.4587566273127757`, -1.6491535759903386`}}]}, 
   {Hue[0.473748370320938], AbsoluteThickness[0.5], 
    LineBox[{{2.48017325188623, -1.6506622385460314`}, {
     2.5612983471122264`, -1.824090204923959}}]}, 
   {Hue[0.4767318993392208], AbsoluteThickness[0.5], 
    LineBox[{{2.5612983471122264`, -1.824090204923959}, {
     2.6198483152858723`, -2.0342936732581705`}}]}, 
   {Hue[0.5617859120169263], AbsoluteThickness[0.5], 
    LineBox[{{2.324173623008653, -1.1049694084633594`}, {
     2.2599842816649476`, -1.1312405582638867`}}]}, 
   {Hue[0.5654404699169547], AbsoluteThickness[0.5], 
    LineBox[{{2.2599842816649476`, -1.1312405582638867`}, {
     2.0851808053722323`, -1.2427638799426985`}}]}, 
   {Hue[0.007869620208504945], AbsoluteThickness[0.5], 
    LineBox[{{2.6474587511591996`, -0.9508735136032455}, {
     2.740096425459754, -0.907131151822697}}]}, 
   {Hue[0.009288697590407412], AbsoluteThickness[0.5], 
    LineBox[{{2.740096425459754, -0.907131151822697}, {
     2.931201349397165, -0.7876368762005596}}]}, 
   {Hue[0.4427029542504101], AbsoluteThickness[0.5], 
    LineBox[{{2.931201349397165, -0.7876368762005596}, {
     2.774123703859658, -0.6259996678233535}}]}, 
   {Hue[0.5626389694233896], AbsoluteThickness[0.5], 
    LineBox[{{2.332735100249149, -1.1217765342140673`}, {
     2.296619448611408, -1.1412180111826447`}}]}, 
   {Hue[0.5636737762197197], AbsoluteThickness[0.5], 
    LineBox[{{2.296619448611408, -1.1412180111826447`}, {
     2.078600907196236, -1.2874047865993354`}}]}, 
   {Hue[0.39233967859456637`], AbsoluteThickness[0.5], 
    LineBox[{{2.5428036770174884`, -1.6366953665276778`}, {
     2.562217150517299, -1.6775654892448482`}}]}, 
   {Hue[0.39370399503767517`], AbsoluteThickness[0.5], 
    LineBox[{{2.562217150517299, -1.6775654892448482`}, {
     2.7003022448501075`, -1.8985277199181034`}}]}, 
   {Hue[0.4558224153128115], AbsoluteThickness[0.5], 
    LineBox[{{2.483692868014906, -2.121780497125626}, {
     2.548810127741544, -2.196812427316902}}]}, 
   {Hue[0.4570578361420102], AbsoluteThickness[0.5], 
    LineBox[{{2.548810127741544, -2.196812427316902}, {
     2.7382607349302366`, -2.3723896225821504`}}]}, 
   {Hue[0.5020136538565075], AbsoluteThickness[0.5], 
    LineBox[{{2.2410433501643467`, -1.8590674240708562`}, {
     2.321910742931102, -2.0057437957421413`}}]}, 
   {Hue[0.5254756246741039], AbsoluteThickness[0.5], 
    LineBox[{{2.321910742931102, -2.0057437957421413`}, {
     2.443694251257211, -2.1185532730251544`}}]}, 
   {Hue[0.6853157210631151], AbsoluteThickness[0.5], 
    LineBox[{{2.443694251257211, -2.1185532730251544`}, {
     2.600402777622443, -2.0637843143941987`}}]}, 
   {Hue[0.5581509578717753], AbsoluteThickness[0.5], 
    LineBox[{{2.024491448696766, -1.1994479195888008`}, {
     1.9442880785530654`, -1.3367846824037648`}}]}, 
   {Hue[0.5597387447221653], AbsoluteThickness[0.5], 
    LineBox[{{1.9442880785530654`, -1.3367846824037648`}, {
     1.8495775029757024`, -1.5585372301576133`}}]}, 
   {Hue[0.2425929972606323], AbsoluteThickness[0.5], 
    LineBox[{{2.3807463399287565`, -0.3924329332847881}, {
     2.6155283470124497`, -0.2835824825584455}}]}, 
   {Hue[0.24305765739712143`], AbsoluteThickness[0.5], 
    LineBox[{{2.6155283470124497`, -0.2835824825584455}, {
     2.8979618740896367`, -0.1619147951209822}}]}, 
   {Hue[0.022264253584479386`], AbsoluteThickness[0.5], 
    LineBox[{{2.4143232804004513`, -0.2163578617178128}, {
     2.411253035426065, -0.16736955928782737`}}]}, 
   {Hue[0.022950217343683008`], AbsoluteThickness[0.5], 
    LineBox[{{2.411253035426065, -0.16736955928782737`}, {2.4126996291739555`,
      0.1439948151678221}}]}, 
   {Hue[0.5296854794909717], AbsoluteThickness[0.5], 
    LineBox[{{2.4126996291739555`, 0.14399481516782203`}, {
     2.6539151761836637`, -0.05289329060405256}}]}, 
   {Hue[0.26249191373772984`], AbsoluteThickness[0.5], 
    LineBox[{{2.262451499927947, -0.12114859717456193`}, {
     2.141711857287462, -0.0826130429177578}}]}, 
   {Hue[0.26291789496006], AbsoluteThickness[0.5], 
    LineBox[{{2.141711857287462, -0.08261304291775778}, {1.7740790208741963`, 
     0.0353634643921054}}]}, 
   {Hue[0.50271957389098], AbsoluteThickness[0.5], 
    LineBox[{{2.1186018844537418`, -0.22809311497084045`}, {
     2.058217069745678, -0.3026928542448297}}]}, 
   {Hue[0.5032263704476683], AbsoluteThickness[0.5], 
    LineBox[{{2.058217069745678, -0.3026928542448297}, {
     1.875245734435293, -0.5477276449503136}}]}, 
   {Hue[0.2626558967179503], AbsoluteThickness[0.5], 
    LineBox[{{2.5798460427640495`, -0.1569902952206556}, {
     2.655151637011604, -0.14259829102322402`}}]}, 
   {Hue[0.2651388449953171], AbsoluteThickness[0.5], 
    LineBox[{{2.655151637011604, -0.14259829102322402`}, {
     2.8744853726716566`, -0.13491695072962218`}}]}, 
   {Hue[0.6423750149503273], AbsoluteThickness[0.5], 
    LineBox[{{2.8744853726716566`, -0.13491695072962218`}, {
     2.8864352266070274`, -0.35405957912086716`}}]}, 
   {Hue[0.017808240191546407`], AbsoluteThickness[0.5], 
    LineBox[{{2.6538509729954964`, 0.029090345638799003`}, {
     2.6611619520517373`, 0.07967519506538698}}]}, 
   {Hue[0.018301308215746857`], AbsoluteThickness[0.5], 
    LineBox[{{2.6611619520517373`, 0.07967519506538698}, {2.722458615129371, 
     0.4179164147096198}}]}, 
   {Hue[0.5584090903559406], AbsoluteThickness[0.5], 
    LineBox[{{2.722458615129371, 0.4179164147096198}, {2.8317742413597773`, 
     0.09201075745168691}}]}, 
   {Hue[0.27873014880280866`], AbsoluteThickness[0.5], 
    LineBox[{{2.502101200611027, 0.1597606987510804}, {2.3204988266757014`, 
     0.25336229155499407`}}]}, 
   {Hue[0.27921591968107334`], AbsoluteThickness[0.5], 
    LineBox[{{2.3204988266757014`, 0.25336229155499407`}, {2.109067595856449, 
     0.3534422438142576}}]}, 
   {Hue[0.5396520574140715], AbsoluteThickness[0.5], 
    LineBox[{{2.3290683843013364`, 0.058952072725509175`}, {
     1.954172895377911, -0.29916741070730857`}}]}, 
   {Hue[0.5448684448897382], AbsoluteThickness[0.5], 
    LineBox[{{1.954172895377911, -0.29916741070730857`}, {
     1.84260513162183, -0.4607032363707608}}]}, 
   {Hue[0.03283057530699004], AbsoluteThickness[0.5], 
    LineBox[{{2.423159903825275, -0.41613580177789533`}, {3.2634232508867824`,
      0.5766617632328972}}]}, 
   {Hue[0.03379619496043848], AbsoluteThickness[0.5], 
    LineBox[{{3.2634232508867824`, 0.5766617632328972}, {3.408057995502556, 
     0.7834993383354422}}]}, 
   {Hue[0.5060093858921483], AbsoluteThickness[0.5], 
    LineBox[{{3.408057995502556, 0.7834993383354422}, {3.159966240799088, 
     0.8298833126425694}}]}, 
   {Hue[0.2740728236618543], AbsoluteThickness[0.5], 
    LineBox[{{2.5769096535090608`, -0.3639466285394853}, {
     2.6762013362205685`, -0.37706735096495675`}}]}, 
   {Hue[0.2783786270583371], AbsoluteThickness[0.5], 
    LineBox[{{2.6762013362205685`, -0.37706735096495675`}, {
     2.8755537431412423`, -0.3652584394625332}}]}, 
   {Hue[0.6007172810862905], AbsoluteThickness[0.5], 
    LineBox[{{2.8755537431412423`, -0.3652584394625332}, {
     2.9014612406588123`, -0.16724421242741572`}}]}, 
   {Hue[0.3047943203050253], AbsoluteThickness[0.5], 
    LineBox[{{2.7039167276434966`, -0.46509947551348524`}, {
     2.7794061897962816`, -0.625610411778908}}]}, 
   {Hue[0.3053490670886742], AbsoluteThickness[0.5], 
    LineBox[{{2.7794061897962816`, -0.625610411778908}, {
     2.883620291830924, -0.8785038414166229}}]}, 
   {Hue[0.3355158169482161], AbsoluteThickness[0.5], 
    LineBox[{{2.687453777822834, -0.6266286264873506}, {
     2.540479052203211, -0.8609584119869239}}]}, 
   {Hue[0.33599680126286735`], AbsoluteThickness[0.5], 
    LineBox[{{2.540479052203211, -0.8609584119869239}, {
     2.364804464688661, -1.1623632246952014`}}]}, 
   {Hue[0.3662373135913794], AbsoluteThickness[0.5], 
    LineBox[{{2.542651272114298, -0.7000788114542039}, {
     2.3841717250278056`, -0.7017913043526123}}]}, 
   {Hue[0.3666634940738068], AbsoluteThickness[0.5], 
    LineBox[{{2.3841717250278056`, -0.7017913043526123}, {
     2.0533564989507083`, -0.7045264809154248}}]}, 
   {Hue[0.39695881023454943`], AbsoluteThickness[0.5], 
    LineBox[{{2.4025916600511703`, -0.6179447722264779}, {
     2.2841674357048465`, -0.43789869987502206`}}]}, 
   {Hue[0.39760986298669376`], AbsoluteThickness[0.5], 
    LineBox[{{2.2841674357048465`, -0.43789869987502206`}, {
     2.140468574822024, -0.18621133258939648`}}]}, 
   {Hue[0.42768030687770575`], AbsoluteThickness[0.5], 
    LineBox[{{2.3959983788615347`, -0.4557127655992718}, {
     2.5177240541125223`, -0.18166573363439392`}}]}, 
   {Hue[0.4285067162251376], AbsoluteThickness[0.5], 
    LineBox[{{2.5177240541125223`, -0.18166573363439392`}, {
     2.6166715037376287`, 0.10095963150338115`}}]}, 
   {Hue[0.45840180352088317`], AbsoluteThickness[0.5], 
    LineBox[{{2.528931061332027, -0.3624840293516172}, {
     2.643510929505017, -0.34481607892286503`}}]}, 
   {Hue[0.4590618633944876], AbsoluteThickness[0.5], 
    LineBox[{{2.643510929505017, -0.34481607892286503`}, {
     2.9219844819953007`, -0.28338009951826487`}}]}, 
   {Hue[0.48912330016404204`], AbsoluteThickness[0.5], 
    LineBox[{{2.679216358875627, -0.42394153233837295`}, {
     3.2619589972514156`, -1.083042926212759}}]}, 
   {Hue[0.49269492253041663`], AbsoluteThickness[0.5], 
    LineBox[{{3.2619589972514156`, -1.083042926212759}, {
     3.37534637495244, -1.2696027717655962`}}]}, 
   {Hue[0.519844796807204], AbsoluteThickness[0.5], 
    LineBox[{{2.708732797502115, -0.5836020320931472}, {
     2.684863534512477, -0.6679373316489396}}]}, 
   {Hue[0.5239815114713854], AbsoluteThickness[0.5], 
    LineBox[{{2.684863534512477, -0.6679373316489396}, {
     2.6685357177038673`, -0.8529916220037546}}]}, 
   {Hue[0.5505662934503499], AbsoluteThickness[0.5], 
    LineBox[{{2.5903529464070925`, -0.6947276645361432}, {
     2.372598550338595, -0.7609387064307097}}]}, 
   {Hue[0.5515490227960194], AbsoluteThickness[0.5], 
    LineBox[{{2.372598550338595, -0.7609387064307097}, {
     2.101132817557497, -0.8164869989844992}}]}, 
   {Hue[0.5812877900934983], AbsoluteThickness[0.5], 
    LineBox[{{2.4328752029803224`, -0.6551871074289425}, {
     2.1570223397878725`, -0.4206515296336353}}]}, 
   {Hue[0.5833014503473979], AbsoluteThickness[0.5], 
    LineBox[{{2.1570223397878725`, -0.4206515296336353}, {
     1.9617456151061339`, -0.29702848682388494`}}]}, 
   {Hue[0.6120092867366881], AbsoluteThickness[0.5], 
    LineBox[{{2.381031343372088, -0.5013205758112538}, {
     2.3984935067308664`, -0.37142101603007843`}}]}, 
   {Hue[0.6167496027378446], AbsoluteThickness[0.5], 
    LineBox[{{2.3984935067308664`, -0.37142101603007843`}, {
     2.385838402642073, -0.17254480204604178`}}]}, 
   {Hue[0.6427307833798237], AbsoluteThickness[0.5], 
    LineBox[{{2.4824690777940557`, -0.3745409190579958}, {
     2.623204345848806, -0.30873754268146186`}}]}, 
   {Hue[0.6431590973091063], AbsoluteThickness[0.5], 
    LineBox[{{2.623204345848806, -0.30873754268146186`}, {
     2.9076991244059474`, -0.17812248721164256`}}]}, 
   {Hue[0.6734522800229622], AbsoluteThickness[0.5], 
    LineBox[{{2.6439608608669043`, -0.39136647495037435`}, {
     2.8588444170177794`, -0.5268174396233847}}]}, 
   {Hue[0.6764885401694911], AbsoluteThickness[0.5], 
    LineBox[{{2.8588444170177794`, -0.5268174396233847}, {
     3.054282426788705, -0.6083881539177206}}]}, 
   {Hue[0.5366389412671333], AbsoluteThickness[0.5], 
    LineBox[{{2.160359371240067, -1.4265587676345128`}, {
     2.1464510977311293`, -1.631705920906158}}]}, 
   {Hue[0.5406702311274422], AbsoluteThickness[0.5], 
    LineBox[{{2.1464510977311293`, -1.631705920906158}, {
     2.16906619524273, -1.8218865784643872`}}]}, 
   {Hue[0.5365288457615323], AbsoluteThickness[0.5], 
    LineBox[{{1.9532882750253522`, -2.103835674951775}, {
     1.9620222814340973`, -2.3217350689340313`}}]}, 
   {Hue[0.5370044120680572], AbsoluteThickness[0.5], 
    LineBox[{{1.9620222814340973`, -2.3217350689340313`}, {
     1.985347630274077, -2.6499732996995844`}}]}, 
   {Hue[0.4774461412930338], AbsoluteThickness[0.5], 
    LineBox[{{2.3789798336257806`, -0.5173725760921701}, {
     2.291522475395858, -0.4370075949782518}}]}, 
   {Hue[0.4784610914270569], AbsoluteThickness[0.5], 
    LineBox[{{2.291522475395858, -0.4370075949782518}, {
     2.1148926316422156`, -0.2404696439362687}}]}, 
   {Hue[0.006898383323953627], AbsoluteThickness[0.5], 
    LineBox[{{2.629954701912823, -0.3826817515782136}, {
     2.6648354158248377`, -0.3679103039097336}}]}, 
   {Hue[0.007507085649400057], AbsoluteThickness[0.5], 
    LineBox[{{2.6648354158248377`, -0.3679103039097336}, {
     2.925073830099004, -0.23965478601984286`}}]}, 
   {Hue[0.5263165643898176], AbsoluteThickness[0.5], 
    LineBox[{{2.925073830099004, -0.23965478601984286`}, {
     2.6495257388589515`, -0.14884311525500898`}}]}, 
   {Hue[0.4793723941707371], AbsoluteThickness[0.5], 
    LineBox[{{2.6485991144105494`, -0.6669041796210446}, {
     2.646782752406624, -0.7355302308442172}}]}, 
   {Hue[0.5040006811746445], AbsoluteThickness[0.5], 
    LineBox[{{2.646782752406624, -0.7355302308442172}, {
     2.690371713485878, -0.8777668253065867}}]}, 
   {Hue[0.6594831368056107], AbsoluteThickness[0.5], 
    LineBox[{{2.690371713485878, -0.8777668253065867}, {
     2.8363232530478886`, -0.9065660341794002}}]}, 
   {Hue[0.5352743262069187], AbsoluteThickness[0.5], 
    LineBox[{{2.1123046943780666`, -1.3856197162041644`}, {
     2.1123034084346246`, -1.3857068739721101`}}]}, 
   {Hue[0.5369974010920051], AbsoluteThickness[0.5], 
    LineBox[{{2.1123034084346246`, -1.3857068739721101`}, {
     2.078017662571191, -1.6205930717293728`}}]}, 
   {Hue[0.40919105501265673`], AbsoluteThickness[0.5], 
    LineBox[{{2.518442825919293, -1.6455766858849543`}, {
     2.554734798811934, -1.706581848725127}}]}, 
   {Hue[0.4110312668113856], AbsoluteThickness[0.5], 
    LineBox[{{2.554734798811934, -1.706581848725127}, {
     2.7076667795030884`, -1.899183335038595}}]}, 
   {Hue[0.5448634024719267], AbsoluteThickness[0.5], 
    LineBox[{{2.1586742043341216`, -2.8331319880891996`}, {
     2.2751201929545424`, -3.057735395932465}}]}, 
   {Hue[0.545429649266566], AbsoluteThickness[0.5], 
    LineBox[{{2.2751201929545424`, -3.057735395932465}, {
     2.393134201378885, -3.3167096800439704`}}]}, 
   {Hue[0.482469930798545], AbsoluteThickness[0.5], 
    LineBox[{{2.2131441717851263`, -0.8654739989636542}, {
     2.1492564307405275`, -0.9633121977806226}}]}, 
   {Hue[0.48408564384880554`], AbsoluteThickness[0.5], 
    LineBox[{{2.1492564307405275`, -0.9633121977806226}, {
     2.0366300390519143`, -1.1950240828291405`}}]}, 
   {Hue[0.0034235752002157115`], AbsoluteThickness[0.5], 
    LineBox[{{2.0629264913035983`, -0.6445111789519624}, {
     2.0320985584625126`, -0.6066449404842503}}]}, 
   {Hue[0.004181106829925485], AbsoluteThickness[0.5], 
    LineBox[{{2.0320985584625126`, -0.6066449404842503}, {
     1.847271505294995, -0.41146391262087556`}}]}, 
   {Hue[0.500892472476125], AbsoluteThickness[0.5], 
    LineBox[{{1.847271505294995, -0.41146391262087556`}, {
     2.103186015179828, -0.32921771604743205`}}]}, 
   {Hue[0.48424327656471394`], AbsoluteThickness[0.5], 
    LineBox[{{2.3191080050454307`, -0.5686102476420434}, {
     2.3790497841045997`, -0.5450659247709372}}]}, 
   {Hue[0.4847612504040829], AbsoluteThickness[0.5], 
    LineBox[{{2.3790497841045997`, -0.5450659247709372}, {
     2.6720433260647805`, -0.4156803453531759}}]}, 
   {Hue[0.5460713989560138], AbsoluteThickness[0.5], 
    LineBox[{{2.651422997218358, -0.8201102077902793}, {
     2.288089331680456, -0.8503317043997892}}]}, 
   {Hue[0.5559627283731884], AbsoluteThickness[0.5], 
    LineBox[{{2.288089331680456, -0.8503317043997892}, {
     2.1038395450194773`, -0.8191605338020271}}]}, 
   {Hue[0.0050564720074653844`], AbsoluteThickness[0.5], 
    LineBox[{{2.8860071186129446`, -0.6641302311772357}, {
     2.967157759073773, -0.6139883164036005}}]}, 
   {Hue[0.006486440308966678], AbsoluteThickness[0.5], 
    LineBox[{{2.967157759073773, -0.6139883164036005}, {
     3.1577784649027465`, -0.46246691400162326`}}]}, 
   {Hue[0.4391311493423405], AbsoluteThickness[0.5], 
    LineBox[{{3.1577784649027465`, -0.46246691400162326`}, {
     2.9700674613476745`, -0.3073554443388491}}]}, 
   {Hue[0.547039417061221], AbsoluteThickness[0.5], 
    LineBox[{{2.7476184506268715`, -0.9095034972184168}, {
     2.6666790829818736`, -1.0424576461443802`}}]}, 
   {Hue[0.5515827513292538], AbsoluteThickness[0.5], 
    LineBox[{{2.6666790829818736`, -1.0424576461443802`}, {
     2.5139109132996174`, -1.2094014358618261`}}]}, 
   {Hue[0.5233967429208798], AbsoluteThickness[0.5], 
    LineBox[{{2.4587566273127757`, -1.6491535759903386`}, {
     2.43009597290372, -1.806815184058637}}]}, 
   {Hue[0.5240339846587148], AbsoluteThickness[0.5], 
    LineBox[{{2.43009597290372, -1.806815184058637}, {
     2.3951811122213136`, -2.099868135684037}}]}, 
   {Hue[0.4797154283575035], AbsoluteThickness[0.5], 
    LineBox[{{2.6198483152858723`, -2.0342936732581705`}, {
     2.6243009138330495`, -2.0762329053252344`}}]}, 
   {Hue[0.4803283181397604], AbsoluteThickness[0.5], 
    LineBox[{{2.6243009138330495`, -2.0762329053252344`}, {
     2.6729522905381424`, -2.3707984747622057`}}]}, 
   {Hue[0.5690950278169832], AbsoluteThickness[0.5], 
    LineBox[{{2.0851808053722323`, -1.2427638799426985`}, {
     1.9914411268648968`, -1.329619587741051}}]}, 
   {Hue[0.5706434689429886], AbsoluteThickness[0.5], 
    LineBox[{{1.9914411268648968`, -1.329619587741051}, {
     1.8353071003896857`, -1.5149125162253567`}}]}, 
   {Hue[0.44128387686850995`], AbsoluteThickness[0.5], 
    LineBox[{{2.740096425459754, -0.907131151822697}, {
     2.831658970348625, -1.0900219858138995`}}]}, 
   {Hue[0.4423609088872814], AbsoluteThickness[0.5], 
    LineBox[{{2.831658970348625, -1.0900219858138995`}, {
     2.918870272988863, -1.3185042988504667`}}]}, 
   {Hue[0.01070777497230988], AbsoluteThickness[0.5], 
    LineBox[{{2.931201349397165, -0.7876368762005594}, {
     3.54642225443388, -0.29373187659846317`}}]}, 
   {Hue[0.011251157046026227`], AbsoluteThickness[0.5], 
    LineBox[{{3.54642225443388, -0.29373187659846317`}, {
     3.807916497826408, -0.10315639013464126`}}]}, 
   {Hue[0.5415347649077462], AbsoluteThickness[0.5], 
    LineBox[{{3.807916497826408, -0.10315639013464128`}, {
     3.713574143989146, -0.4126685476354376}}]}, 
   {Hue[0.4441220316323126], AbsoluteThickness[0.5], 
    LineBox[{{2.774123703859658, -0.6259996678233535}, {
     2.7113080913982186`, -0.5749894504610937}}]}, 
   {Hue[0.44470485081227806`], AbsoluteThickness[0.5], 
    LineBox[{{2.7113080913982186`, -0.5749894504610937}, {
     2.4553447994822006`, -0.38889785639138563`}}]}, 
   {Hue[0.5647085830160495], AbsoluteThickness[0.5], 
    LineBox[{{2.078600907196236, -1.2874047865993354`}, {
     2.023249170537805, -1.3328575368138296`}}]}, 
   {Hue[0.5657154035608999], AbsoluteThickness[0.5], 
    LineBox[{{2.023249170537805, -1.3328575368138296`}, {
     1.836060267659236, -1.5189652176393398`}}]}, 
   {Hue[0.3950683114807838], AbsoluteThickness[0.5], 
    LineBox[{{2.7003022448501075`, -1.8985277199181034`}, {
     3.042689761235615, -2.32747858661673}}]}, 
   {Hue[0.3995249887848342], AbsoluteThickness[0.5], 
    LineBox[{{3.042689761235615, -2.32747858661673}, {
     3.1441878051681753`, -2.522092675618111}}]}, 
   {Hue[0.4582932569712089], AbsoluteThickness[0.5], 
    LineBox[{{2.7382607349302366`, -2.3723896225821504`}, {
     2.8119910722609522`, -2.427147209308691}}]}, 
   {Hue[0.4587864756224064], AbsoluteThickness[0.5], 
    LineBox[{{2.8119910722609522`, -2.427147209308691}, {
     3.0883208281917383`, -2.6174206758314056`}}]}, 
   {Hue[0.6618537502455195], AbsoluteThickness[0.5], 
    LineBox[{{2.321910742931102, -2.0057437957421413`}, {
     2.3260102973432244`, -2.0739737475938442`}}]}, 
   {Hue[0.6623790106283481], AbsoluteThickness[0.5], 
    LineBox[{{2.3260102973432244`, -2.0739737475938442`}, {
     2.3314978924638656`, -2.398542276110644}}]}, 
   {Hue[0.5489375954917005], AbsoluteThickness[0.5], 
    LineBox[{{2.443694251257211, -2.1185532730251544`}, {
     2.5542213709426225`, -2.1688953205964}}]}, 
   {Hue[0.5493801845313778], AbsoluteThickness[0.5], 
    LineBox[{{2.5542213709426225`, -2.1688953205964}, {
     2.848069007808303, -2.2963705263110463`}}]}, 
   {Hue[0.2435223175336104], AbsoluteThickness[0.5], 
    LineBox[{{2.8979618740896367`, -0.16191479512098222`}, {
     2.921011221208363, -0.1527248159022446}}]}, 
   {Hue[0.2440497727192054], AbsoluteThickness[0.5], 
    LineBox[{{2.921011221208363, -0.1527248159022446}, {
     3.2028927965575797`, -0.02584601527156932}}]}, 
   {Hue[0.5289995157317693], AbsoluteThickness[0.5], 
    LineBox[{{2.411253035426065, -0.16736955928782737`}, {
     2.39256163352278, -0.18037865609413065`}}]}, 
   {Hue[0.5294289259876118], AbsoluteThickness[0.5], 
    LineBox[{{2.39256163352278, -0.18037865609413065`}, {
     2.1338622705850345`, -0.36366399949434736`}}]}, 
   {Hue[0.023636181102886632`], AbsoluteThickness[0.5], 
    LineBox[{{2.4126996291739555`, 0.14399481516782203`}, {2.429801370341958, 
     0.3814954966325231}}]}, 
   {Hue[0.02410780183132779], AbsoluteThickness[0.5], 
    LineBox[{{2.429801370341958, 0.3814954966325231}, {2.4617187016170377`, 
     0.6947292753985856}}]}, 
   {Hue[0.5687128316074138], AbsoluteThickness[0.5], 
    LineBox[{{2.4617187016170377`, 0.6947292753985856}, {2.5605159539933817`, 
     0.39577573533144594`}}]}, 
   {Hue[0.5303714432501755], AbsoluteThickness[0.5], 
    LineBox[{{2.6539151761836637`, -0.052893290604052595`}, {
     2.709964277402691, -0.10529700719208579`}}]}, 
   {Hue[0.530969552894856], AbsoluteThickness[0.5], 
    LineBox[{{2.709964277402691, -0.10529700719208579`}, {
     2.91127129289365, -0.3157314025727806}}]}, 
   {Hue[0.6398920666729621], AbsoluteThickness[0.5], 
    LineBox[{{2.655151637011604, -0.14259829102322402`}, {2.684849360189823, 
     0.07077617915838408}}]}, 
   {Hue[0.640335106203177], AbsoluteThickness[0.5], 
    LineBox[{{2.684849360189823, 0.07077617915838408}, {2.7397297840415797`, 
     0.418322019529083}}]}, 
   {Hue[0.26762179327268365`], AbsoluteThickness[0.5], 
    LineBox[{{2.8744853726716566`, -0.13491695072962218`}, {
     2.9102352421079885`, -0.13918498797154147`}}]}, 
   {Hue[0.2688026799820737], AbsoluteThickness[0.5], 
    LineBox[{{2.9102352421079885`, -0.13918498797154144`}, {
     3.171519452508126, -0.1426288257096963}}]}, 
   {Hue[0.6448579632276941], AbsoluteThickness[0.5], 
    LineBox[{{2.8864352266070274`, -0.35405957912086716`}, {
     2.886429673673211, -0.35411528517719115`}}]}, 
   {Hue[0.6470652020078611], AbsoluteThickness[0.5], 
    LineBox[{{2.886429673673211, -0.35411528517719115`}, {
     2.8969255330815686`, -0.5780962717927747}}]}, 
   {Hue[0.557916022331742], AbsoluteThickness[0.5], 
    LineBox[{{2.6611619520517373`, 0.07967519506538698}, {2.6433791494945784`,
      0.059314695855296445`}}]}, 
   {Hue[0.5585065306075846], AbsoluteThickness[0.5], 
    LineBox[{{2.6433791494945784`, 0.059314695855296445`}, {
     2.419022155961783, -0.17088914376704845`}}]}, 
   {Hue[0.018794376239947307`], AbsoluteThickness[0.5], 
    LineBox[{{2.722458615129371, 0.4179164147096198}, {2.7520351076478033`, 
     0.5533442051747498}}]}, 
   {Hue[0.019243979514961283`], AbsoluteThickness[0.5], 
    LineBox[{{2.7520351076478033`, 0.5533442051747498}, {2.8146889283717056`, 
     0.8730545006694468}}]}, 
   {Hue[0.5686842830784996], AbsoluteThickness[0.5], 
    LineBox[{{2.8146889283717056`, 0.8730545006694468}, {2.6581905308479152`, 
     0.587312613874572}}]}, 
   {Hue[0.558902158380141], AbsoluteThickness[0.5], 
    LineBox[{{2.8317742413597773`, 0.09201075745168685}, {
     2.9514974383124053`, -0.3123044997194935}}]}, 
   {Hue[0.5593288759400041], AbsoluteThickness[0.5], 
    LineBox[{{2.9514974383124053`, -0.3123044997194935}, {
     3.041691233436149, -0.612343022659902}}]}, 
   {Hue[0.279701690559338], AbsoluteThickness[0.5], 
    LineBox[{{2.109067595856449, 0.3534422438142576}, {2.105514139511791, 
     0.3549794542587837}}]}, 
   {Hue[0.2805531075514593], AbsoluteThickness[0.5], 
    LineBox[{{2.105514139511791, 0.3549794542587837}, {1.9224697964012654`, 
     0.45300269258115633`}}]}, 
   {Hue[0.5050437662387053], AbsoluteThickness[0.5], 
    LineBox[{{3.2634232508867824`, 0.5766617632328972}, {3.3164374231681903`, 
     0.5035375006576159}}]}, 
   {Hue[0.5070418865557857], AbsoluteThickness[0.5], 
    LineBox[{{3.3164374231681903`, 0.5035375006576159}, {3.470776885602129, 
     0.3434255118979491}}]}, 
   {Hue[0.034761814613887006`], AbsoluteThickness[0.5], 
    LineBox[{{3.408057995502556, 0.7834993383354422}, {3.462314943381548, 
     0.8786818926855546}}]}, 
   {Hue[0.03518768593278666], AbsoluteThickness[0.5], 
    LineBox[{{3.462314943381548, 0.8786818926855546}, {3.6178230018253923`, 
     1.1518588599881683`}}]}, 
   {Hue[0.5901130572345801], AbsoluteThickness[0.5], 
    LineBox[{{3.6178230018253923`, 1.1518588599881683`}, {3.460018192302461, 
     0.8800021812085975}}]}, 
   {Hue[0.5069750055455967], AbsoluteThickness[0.5], 
    LineBox[{{3.159966240799088, 0.8298833126425694}, {3.1044498196933112`, 
     0.8350437243554116}}]}, 
   {Hue[0.5099472373334208], AbsoluteThickness[0.5], 
    LineBox[{{3.1044498196933112`, 0.8350437243554116}, {2.8744799920017368`, 
     0.8958066865584389}}]}, 
   {Hue[0.5964114776898078], AbsoluteThickness[0.5], 
    LineBox[{{2.6762013362205685`, -0.37706735096495675`}, {
     2.7928454955418593`, -0.625491357823003}}]}, 
   {Hue[0.597053280469377], AbsoluteThickness[0.5], 
    LineBox[{{2.7928454955418593`, -0.625491357823003}, {
     2.890485253564109, -0.8719898657656994}}]}, 
   {Hue[0.2826844304548199], AbsoluteThickness[0.5], 
    LineBox[{{2.8755537431412423`, -0.3652584394625332}, {
     2.877322838130137, -0.3648072496096495}}]}, 
   {Hue[0.2848116124826744], AbsoluteThickness[0.5], 
    LineBox[{{2.877322838130137, -0.3648072496096495}, {
     3.1018180483063533`, -0.34093759417620123`}}]}, 
   {Hue[0.6775467202542972], AbsoluteThickness[0.5], 
    LineBox[{{3.1018180483063533`, -0.3409375941762013}, {
     3.117237858127878, -0.5661710049030364}}]}, 
   {Hue[0.6050230844827733], AbsoluteThickness[0.5], 
    LineBox[{{2.9014612406588123`, -0.16724421242741572`}, {
     2.8986160894568522`, -0.12023668027330925`}}]}, 
   {Hue[0.6115452517929664], AbsoluteThickness[0.5], 
    LineBox[{{2.8986160894568522`, -0.12023668027330925`}, {
     2.9293165302647544`, 0.0708835689276705}}]}, 
   {Hue[0.30590381387232307`], AbsoluteThickness[0.5], 
    LineBox[{{2.883620291830924, -0.8785038414166229}, {
     2.883695959357303, -0.8787162947068309}}]}, 
   {Hue[0.30640785499058537`], AbsoluteThickness[0.5], 
    LineBox[{{2.883695959357303, -0.8787162947068309}, {
     2.987425314468647, -1.1379765458999795`}}]}, 
   {Hue[0.3364777855775186], AbsoluteThickness[0.5], 
    LineBox[{{2.364804464688661, -1.1623632246952014`}, {
     2.3543915688244548`, -1.1816413414619258`}}]}, 
   {Hue[0.3370009880522424], AbsoluteThickness[0.5], 
    LineBox[{{2.3543915688244548`, -1.1816413414619258`}, {
     2.199205008435226, -1.4417557492712223`}}]}, 
   {Hue[0.3982609157388381], AbsoluteThickness[0.5], 
    LineBox[{{2.140468574822024, -0.18621133258939648`}, {
     2.1151219681162017`, -0.13450224540672737`}}]}, 
   {Hue[0.39891830550450924`], AbsoluteThickness[0.5], 
    LineBox[{{2.1151219681162017`, -0.13450224540672734`}, {
     1.9405492154643096`, 0.1706970723408454}}]}, 
   {Hue[0.42933312557256953`], AbsoluteThickness[0.5], 
    LineBox[{{2.6166715037376287`, 0.10095963150338116`}, {
     2.6183569061448178`, 0.10741121345480317`}}]}, 
   {Hue[0.4299606724709503], AbsoluteThickness[0.5], 
    LineBox[{{2.6183569061448178`, 0.10741121345480317`}, {
     2.7196230336576193`, 0.417688536459185}}]}, 
   {Hue[0.4597219232680921], AbsoluteThickness[0.5], 
    LineBox[{{2.9219844819953007`, -0.28338009951826487`}, {
     3.1139669781935817`, -0.2279075827347336}}]}, 
   {Hue[0.46060859296841256`], AbsoluteThickness[0.5], 
    LineBox[{{3.1139669781935817`, -0.2279075827347336}, {
     3.3799972597589214`, -0.17534988935394846`}}]}, 
   {Hue[0.4962665448967913], AbsoluteThickness[0.5], 
    LineBox[{{3.37534637495244, -1.2696027717655962`}, {
     3.413450121288922, -1.3683540436526096`}}]}, 
   {Hue[0.4967761648970224], AbsoluteThickness[0.5], 
    LineBox[{{3.413450121288922, -1.3683540436526096`}, {
     3.5435339516639304`, -1.6693109631684728`}}]}, 
   {Hue[0.5281182261355667], AbsoluteThickness[0.5], 
    LineBox[{{2.6685357177038673`, -0.8529916220037544}, {
     2.695741233857145, -1.1246722884769857`}}]}, 
   {Hue[0.5290265981265849], AbsoluteThickness[0.5], 
    LineBox[{{2.695741233857145, -1.1246722884769857`}, {
     2.742997833435222, -1.3734364728355164`}}]}, 
   {Hue[0.5525317521416886], AbsoluteThickness[0.5], 
    LineBox[{{2.101132817557497, -0.8164869989844992}, {
     1.9979304555414987`, -0.827728038812296}}]}, 
   {Hue[0.5678638017931454], AbsoluteThickness[0.5], 
    LineBox[{{1.9979304555414987`, -0.827728038812296}, {
     1.8075272898144665`, -0.9067438787694884}}]}, 
   {Hue[0.6214899187390011], AbsoluteThickness[0.5], 
    LineBox[{{2.385838402642073, -0.17254480204604178`}, {
     2.3790692077681626`, -0.14717250075451344`}}]}, 
   {Hue[0.6238023345525596], AbsoluteThickness[0.5], 
    LineBox[{{2.3790692077681626`, -0.14717250075451344`}, {
     2.3518329379068703`, 0.09603901253612764}}]}, 
   {Hue[0.6435874112383888], AbsoluteThickness[0.5], 
    LineBox[{{2.9076991244059474`, -0.17812248721164256`}, {
     2.9343580553247985`, -0.16610703993364878`}}]}, 
   {Hue[0.6441711097705844], AbsoluteThickness[0.5], 
    LineBox[{{2.9343580553247985`, -0.16610703993364875`}, {
     3.2030553613724972`, -0.027242646955745624`}}]}, 
   {Hue[0.6795248003160198], AbsoluteThickness[0.5], 
    LineBox[{{3.054282426788705, -0.6083881539177206}, {
     3.164027038471075, -0.6338935136115558}}]}, 
   {Hue[0.682944111236301], AbsoluteThickness[0.5], 
    LineBox[{{3.164027038471075, -0.6338935136115558}, {
     3.358898172766486, -0.7170423153440393}}]}, 
   {Hue[0.5447015209877512], AbsoluteThickness[0.5], 
    LineBox[{{2.16906619524273, -1.8218865784643872`}, {
     2.247069636944187, -2.070167845820794}}]}, 
   {Hue[0.5451379286549897], AbsoluteThickness[0.5], 
    LineBox[{{2.247069636944187, -2.070167845820794}, {
     2.3437168296833732`, -2.394011209951793}}]}, 
   {Hue[0.5374799783745822], AbsoluteThickness[0.5], 
    LineBox[{{1.985347630274077, -2.6499732996995844`}, {
     2.0026620430220237`, -2.819426606598638}}]}, 
   {Hue[0.537917566963476], AbsoluteThickness[0.5], 
    LineBox[{{2.0026620430220237`, -2.819426606598638}, {
     2.041510205117525, -3.149977817168331}}]}, 
   {Hue[0.4794760415610802], AbsoluteThickness[0.5], 
    LineBox[{{2.1148926316422156`, -0.24046964393626868`}, {
     2.069728570390491, -0.1793726150147869}}]}, 
   {Hue[0.4799022933179588], AbsoluteThickness[0.5], 
    LineBox[{{2.069728570390491, -0.1793726150147869}, {1.84111944293852, 
     0.13170415009790004`}}]}, 
   {Hue[0.5257078620643721], AbsoluteThickness[0.5], 
    LineBox[{{2.6648354158248377`, -0.3679103039097336}, {
     2.6555893827758243`, -0.40014695254876287`}}]}, 
   {Hue[0.5262840169304845], AbsoluteThickness[0.5], 
    LineBox[{{2.6555893827758243`, -0.40014695254876287`}, {
     2.5522874143439527`, -0.7000983068310159}}]}, 
   {Hue[0.008115787974846566], AbsoluteThickness[0.5], 
    LineBox[{{2.925073830099004, -0.23965478601984283`}, {
     2.994867762358509, -0.2001354405247115}}]}, 
   {Hue[0.009376321936738062], AbsoluteThickness[0.5], 
    LineBox[{{2.994867762358509, -0.2001354405247115}, {
     3.2040138646207814`, -0.0491918126213549}}]}, 
   {Hue[0.4547204965201773], AbsoluteThickness[0.5], 
    LineBox[{{3.2040138646207814`, -0.0491918126213549}, {3.002432095541512, 
     0.11171456161844992`}}]}, 
   {Hue[0.5269252667152641], AbsoluteThickness[0.5], 
    LineBox[{{2.6495257388589515`, -0.14884311525500893`}, {
     2.6052305817759183`, -0.13701022246333888`}}]}, 
   {Hue[0.5276629863947178], AbsoluteThickness[0.5], 
    LineBox[{{2.6052305817759183`, -0.13701022246333888`}, {
     2.3155337868584303`, -0.03651456183310251}}]}, 
   {Hue[0.6348548498017046], AbsoluteThickness[0.5], 
    LineBox[{{2.646782752406624, -0.7355302308442173}, {
     2.577185601750455, -0.8769205900997441}}]}, 
   {Hue[0.6352838588554585], AbsoluteThickness[0.5], 
    LineBox[{{2.577185601750455, -0.8769205900997441}, {
     2.416699435871233, -1.1965728788141616`}}]}, 
   {Hue[0.5286289681785522], AbsoluteThickness[0.5], 
    LineBox[{{2.690371713485878, -0.8777668253065867}, {
     2.845153921284303, -1.0940289086868127`}}]}, 
   {Hue[0.5311978888359522], AbsoluteThickness[0.5], 
    LineBox[{{2.845153921284303, -1.0940289086868127`}, {
     2.9380283572672012`, -1.2790852702924465`}}]}, 
   {Hue[0.6841114238095185], AbsoluteThickness[0.5], 
    LineBox[{{2.8363232530478886`, -0.9065660341794002}, {
     2.858085826372166, -0.9037427430730558}}]}, 
   {Hue[0.6855543701278459], AbsoluteThickness[0.5], 
    LineBox[{{2.858085826372166, -0.9037427430730558}, {
     3.082727986220084, -0.9014334590329316}}]}, 
   {Hue[0.5387204759770915], AbsoluteThickness[0.5], 
    LineBox[{{2.078017662571191, -1.6205930717293728`}, {
     2.0330291626145383`, -1.7799606705342086`}}]}, 
   {Hue[0.5391897936847012], AbsoluteThickness[0.5], 
    LineBox[{{2.0330291626145383`, -1.7799606705342086`}, {
     1.9518141333919388`, -2.1031295428452372`}}]}, 
   {Hue[0.4128714786101145], AbsoluteThickness[0.5], 
    LineBox[{{2.7076667795030884`, -1.899183335038595}, {
     2.9290319228351374`, -2.1118131988474245`}}]}, 
   {Hue[0.4617305128589265], AbsoluteThickness[0.5], 
    LineBox[{{2.9290319228351374`, -2.1118131988474245`}, {
     3.065872672627265, -2.1670222235111876`}}]}, 
   {Hue[0.5591578610517753], AbsoluteThickness[0.5], 
    LineBox[{{3.065872672627265, -2.1670222235111876`}, {
     3.1837951812311966`, -2.0783221154359914`}}]}, 
   {Hue[0.6565852092446215], AbsoluteThickness[0.5], 
    LineBox[{{3.1837951812311966`, -2.0783221154359914`}, {
     3.168698874062078, -1.9315381629144324`}}]}, 
   {Hue[0.5459958960612052], AbsoluteThickness[0.5], 
    LineBox[{{2.393134201378885, -3.3167096800439704`}, {
     2.4214296292536326`, -3.3882022139902883`}}]}, 
   {Hue[0.5465481435875863], AbsoluteThickness[0.5], 
    LineBox[{{2.4214296292536326`, -3.3882022139902883`}, {
     2.5436032382851548`, -3.658042594090215}}]}, 
   {Hue[0.4857013568990659], AbsoluteThickness[0.5], 
    LineBox[{{2.0366300390519143`, -1.1950240828291405`}, {
     1.9910692994908148`, -1.3296198974309754`}}]}, 
   {Hue[0.4862497275318182], AbsoluteThickness[0.5], 
    LineBox[{{1.9910692994908148`, -1.3296198974309754`}, {
     1.8834319046706502`, -1.6038937478843676`}}]}, 
   {Hue[0.5001349408464137], AbsoluteThickness[0.5], 
    LineBox[{{2.0320985584625126`, -0.6066449404842502}, {
     1.966842330709091, -0.8248659927610411}}]}, 
   {Hue[0.5006461115764796], AbsoluteThickness[0.5], 
    LineBox[{{1.966842330709091, -0.8248659927610411}, {
     1.8484822509982604`, -1.1696848592317641`}}]}, 
   {Hue[0.5016500041058347], AbsoluteThickness[0.5], 
    LineBox[{{2.103186015179828, -0.32921771604743205`}, {
     2.1161826614835735`, -0.32393880872310166`}}]}, 
   {Hue[0.5020866141538606], AbsoluteThickness[0.5], 
    LineBox[{{2.1161826614835735`, -0.32393880872310166`}, {
     2.4066262376848373`, -0.20102479545572685`}}]}, 
   {Hue[0.48527922424345177`], AbsoluteThickness[0.5], 
    LineBox[{{2.6720433260647805`, -0.4156803453531759}, {
     2.7112539567093674`, -0.39637939068229444`}}]}, 
   {Hue[0.4871212948588479], AbsoluteThickness[0.5], 
    LineBox[{{2.7112539567093674`, -0.39637939068229444`}, {
     2.9023906921905986`, -0.33241815598626767`}}]}, 
   {Hue[0.43770118104083927`], AbsoluteThickness[0.5], 
    LineBox[{{2.967157759073773, -0.6139883164036005}, {
     3.057931494139547, -0.7521858882137853}}]}, 
   {Hue[0.439037209989595], AbsoluteThickness[0.5], 
    LineBox[{{3.057931494139547, -0.7521858882137853}, {
     3.2192798656454715`, -0.9457402705723252}}]}, 
   {Hue[0.007916408610467973], AbsoluteThickness[0.5], 
    LineBox[{{3.1577784649027465`, -0.46246691400162326`}, {
     3.1946424122747805`, -0.42527998734344896`}}]}, 
   {Hue[0.008437146405616701], AbsoluteThickness[0.5], 
    LineBox[{{3.1946424122747805`, -0.42527998734344896`}, {
     3.3990146158818657`, -0.20094830376234563`}}]}, 
   {Hue[0.5430242048751504], AbsoluteThickness[0.5], 
    LineBox[{{3.3990146158818657`, -0.20094830376234563`}, {
     3.104570135527935, -0.27439998757321493`}}]}, 
   {Hue[0.4405611176438418], AbsoluteThickness[0.5], 
    LineBox[{{2.9700674613476745`, -0.3073554443388491}, {
     2.923187428018483, -0.2771448015769557}}]}, 
   {Hue[0.4411301876166111], AbsoluteThickness[0.5], 
    LineBox[{{2.923187428018483, -0.2771448015769557}, {
     2.667939463661042, -0.1305738932502986}}]}, 
   {Hue[0.5561260855972869], AbsoluteThickness[0.5], 
    LineBox[{{2.5139109132996174`, -1.2094014358618261`}, {
     2.395105263680846, -1.2970232208064103`}}]}, 
   {Hue[0.5571662628018159], AbsoluteThickness[0.5], 
    LineBox[{{2.395105263680846, -1.2970232208064103`}, {
     2.169966978836697, -1.43145040062536}}]}, 
   {Hue[0.5246712263965495], AbsoluteThickness[0.5], 
    LineBox[{{2.3951811122213136`, -2.099868135684037}, {
     2.3944358909455734`, -2.112849641882089}}]}, 
   {Hue[0.5257121040572599], AbsoluteThickness[0.5], 
    LineBox[{{2.3944358909455734`, -2.112849641882089}, {
     2.3511367779655084`, -2.390721142071104}}]}, 
   {Hue[0.4809412079220173], AbsoluteThickness[0.5], 
    LineBox[{{2.6729522905381424`, -2.3707984747622057`}, {
     2.7195920054289435`, -2.577810789348592}}]}, 
   {Hue[0.48136953499426005`], AbsoluteThickness[0.5], 
    LineBox[{{2.7195920054289435`, -2.577810789348592}, {
     2.7932771806279204`, -2.915853154730379}}]}, 
   {Hue[0.443437940906053], AbsoluteThickness[0.5], 
    LineBox[{{2.918870272988863, -1.3185042988504667`}, {
     2.9326005183672703`, -1.369077885185002}}]}, 
   {Hue[0.44392104671239224`], AbsoluteThickness[0.5], 
    LineBox[{{2.9326005183672703`, -1.369077885185002}, {
     3.0254739900655676`, -1.6712658885323761`}}]}, 
   {Hue[0.5409913828340323], AbsoluteThickness[0.5], 
    LineBox[{{3.54642225443388, -0.29373187659846317`}, {
     3.421379595664816, -0.2859677581801132}}]}, 
   {Hue[0.541418336815564], AbsoluteThickness[0.5], 
    LineBox[{{3.421379595664816, -0.2859677581801132}, {
     3.105033394132903, -0.267803759017199}}]}, 
   {Hue[0.011794539119742653`], AbsoluteThickness[0.5], 
    LineBox[{{3.807916497826408, -0.10315639013464128`}, {
     3.884903728405023, -0.05237168738407452}}]}, 
   {Hue[0.012225470283733775`], AbsoluteThickness[0.5], 
    LineBox[{{3.884903728405023, -0.05237168738407452}, {4.156816545678254, 
     0.1231213860248081}}]}, 
   {Hue[0.5659561193559554], AbsoluteThickness[0.5], 
    LineBox[{{4.156816545678254, 0.1231213860248081}, {
     3.912912540912218, -0.08958788850512524}}]}, 
   {Hue[0.5420781469814627], AbsoluteThickness[0.5], 
    LineBox[{{3.713574143989146, -0.4126685476354376}, {
     3.6860491112516196`, -0.4898603414726842}}]}, 
   {Hue[0.544877157157866], AbsoluteThickness[0.5], 
    LineBox[{{3.6860491112516196`, -0.4898603414726842}, {
     3.5769857017156714`, -0.6875223499898963}}]}, 
   {Hue[0.44528766999224356`], AbsoluteThickness[0.5], 
    LineBox[{{2.4553447994822006`, -0.38889785639138563`}, {
     2.4071803639480085`, -0.35767042025888424`}}]}, 
   {Hue[0.4457165123040786], AbsoluteThickness[0.5], 
    LineBox[{{2.4071803639480085`, -0.35767042025888424`}, {
     2.139761018832615, -0.18718856351561686`}}]}, 
   {Hue[0.4039816660888847], AbsoluteThickness[0.5], 
    LineBox[{{3.1441878051681753`, -2.522092675618111}, {
     3.1652919596707547`, -2.593382750503289}}]}, 
   {Hue[0.40442746311527755`], AbsoluteThickness[0.5], 
    LineBox[{{3.1652919596707547`, -2.593382750503289}, {
     3.264676947477828, -2.9062964434785012`}}]}, 
   {Hue[0.45927969427360404`], AbsoluteThickness[0.5], 
    LineBox[{{3.0883208281917383`, -2.6174206758314056`}, {
     3.1128972363889433`, -2.633077735221184}}]}, 
   {Hue[0.4597241586122616], AbsoluteThickness[0.5], 
    LineBox[{{3.1128972363889433`, -2.633077735221184}, {
     3.386563277143628, -2.8148478111911044`}}]}, 
   {Hue[0.6629042710111767], AbsoluteThickness[0.5], 
    LineBox[{{2.3314978924638656`, -2.398542276110644}, {
     2.327434815791053, -2.553581637908798}}]}, 
   {Hue[0.6634496338378161], AbsoluteThickness[0.5], 
    LineBox[{{2.327434815791053, -2.553581637908798}, {
     2.304553422966435, -2.8654807781215044`}}]}, 
   {Hue[0.5498227735710551], AbsoluteThickness[0.5], 
    LineBox[{{2.848069007808303, -2.2963705263110463`}, {
     2.9151914681536426`, -2.3240580547610956`}}]}, 
   {Hue[0.5514042141462198], AbsoluteThickness[0.5], 
    LineBox[{{2.9151914681536426`, -2.3240580547610956`}, {
     3.1447535838815814`, -2.4542458533267646`}}]}, 
   {Hue[0.24457722790480033`], AbsoluteThickness[0.5], 
    LineBox[{{3.2028927965575797`, -0.02584601527156932}, {
     3.2939975871991227`, 0.02003217538372385}}]}, 
   {Hue[0.2456721568274758], AbsoluteThickness[0.5], 
    LineBox[{{3.2939975871991227`, 0.02003217538372385}, {3.541313591527726, 
     0.11478473316759906`}}]}, 
   {Hue[0.5298583362434541], AbsoluteThickness[0.5], 
    LineBox[{{2.1338622705850345`, -0.36366399949434736`}, {
     1.8764595299316007`, -0.5492850946607903}}]}, 
   {Hue[0.5682412108789743], AbsoluteThickness[0.5], 
    LineBox[{{2.429801370341958, 0.381495496632523}, {
     2.138429615933889, -0.0916901865208875}}]}, 
   {Hue[0.6007559813448732], AbsoluteThickness[0.5], 
    LineBox[{{2.138429615933889, -0.09169018652088749}, {
     1.9863370144834238`, -0.2125769892219459}}]}, 
   {Hue[0.024579422559769026`], AbsoluteThickness[0.5], 
    LineBox[{{2.4617187016170377`, 0.6947292753985856}, {2.482132497875498, 
     0.8494184425441128}}]}, 
   {Hue[0.025071120582756356`], AbsoluteThickness[0.5], 
    LineBox[{{2.482132497875498, 0.8494184425441128}, {2.504947851783013, 
     1.0867938193279718`}}]}, 
   {Hue[0.5654602588522433], AbsoluteThickness[0.5], 
    LineBox[{{2.504947851783013, 1.086793819327972}, {2.371480714505708, 
     0.8891726333579317}}]}, 
   {Hue[0.5691844523358549], AbsoluteThickness[0.5], 
    LineBox[{{2.5605159539933817`, 0.39577573533144594`}, {2.580680340447848, 
     0.32808379736875365`}}]}, 
   {Hue[0.5704784473009911], AbsoluteThickness[0.5], 
    LineBox[{{2.580680340447848, 0.32808379736875365`}, {2.690486310399715, 
     0.06920683472616213}}]}, 
   {Hue[0.5315676625395365], AbsoluteThickness[0.5], 
    LineBox[{{2.91127129289365, -0.3157314025727806}, {
     2.920516700428693, -0.3265429874287922}}]}, 
   {Hue[0.5320151935974115], AbsoluteThickness[0.5], 
    LineBox[{{2.920516700428693, -0.3265429874287922}, {
     3.1171403047075903`, -0.5662786422817271}}]}, 
   {Hue[0.640778145733392], AbsoluteThickness[0.5], 
    LineBox[{{2.7397297840415797`, 0.418322019529083}, {2.7635845918498396`, 
     0.5532898884542642}}]}, 
   {Hue[0.6412369520345229], AbsoluteThickness[0.5], 
    LineBox[{{2.7635845918498396`, 0.5532898884542642}, {2.811952547829774, 
     0.8740178256393171}}]}, 
   {Hue[0.2699835666914635], AbsoluteThickness[0.5], 
    LineBox[{{3.171519452508126, -0.1426288257096963}, {
     3.191249574488383, -0.14079927561953187`}}]}, 
   {Hue[0.2783918642779039], AbsoluteThickness[0.5], 
    LineBox[{{3.191249574488383, -0.14079927561953187`}, {
     3.3721983348153373`, -0.1673849869787014}}]}, 
   {Hue[0.534920420164375], AbsoluteThickness[0.5], 
    LineBox[{{3.3721983348153373`, -0.1673849869787014}, {
     3.407664798502683, -0.3468045619025335}}]}, 
   {Hue[0.6492724407880281], AbsoluteThickness[0.5], 
    LineBox[{{2.8969255330815686`, -0.5780962717927747}, {
     2.9267478380425977`, -0.730686942326404}}]}, 
   {Hue[0.5590970388834273], AbsoluteThickness[0.5], 
    LineBox[{{2.419022155961783, -0.17088914376704845`}, {
     2.3991409566983712`, -0.1891757998175434}}]}, 
   {Hue[0.5595370354737166], AbsoluteThickness[0.5], 
    LineBox[{{2.3991409566983712`, -0.1891757998175434}, {
     2.1635134522749517`, -0.3987773823015981}}]}, 
   {Hue[0.5682346798034867], AbsoluteThickness[0.5], 
    LineBox[{{2.7520351076478033`, 0.5533442051747498}, {2.7709342348645136`, 
     0.4147547201519453}}]}, 
   {Hue[0.5687567366473716], AbsoluteThickness[0.5], 
    LineBox[{{2.7709342348645136`, 0.4147547201519453}, {2.802495474961314, 
     0.07669901312066196}}]}, 
   {Hue[0.019693582789975104`], AbsoluteThickness[0.5], 
    LineBox[{{2.8146889283717056`, 0.8730545006694468}, {2.8491804988459193`, 
     1.0715827818843235`}}]}, 
   {Hue[0.020777881631438264`], AbsoluteThickness[0.5], 
    LineBox[{{2.8491804988459193`, 1.0715827818843235`}, {2.8699034112844646`,
      1.358743805095254}}]}, 
   {Hue[0.48130005623580846`], AbsoluteThickness[0.5], 
    LineBox[{{2.8699034112844646`, 1.358743805095254}, {2.5934467582038794`, 
     1.2783534367731393`}}]}, 
   {Hue[0.5691338863535136], AbsoluteThickness[0.5], 
    LineBox[{{2.6581905308479152`, 0.587312613874572}, {2.6393432229402185`, 
     0.5510722994614338}}]}, 
   {Hue[0.5720829282290585], AbsoluteThickness[0.5], 
    LineBox[{{2.6393432229402185`, 0.5510722994614338}, {2.5079532784937957`, 
     0.3763169409326842}}]}, 
   {Hue[0.5597555934998671], AbsoluteThickness[0.5], 
    LineBox[{{3.041691233436149, -0.612343022659902}, {
     3.0722065375490804`, -0.7123563260538588}}]}, 
   {Hue[0.5611794177705978], AbsoluteThickness[0.5], 
    LineBox[{{3.0722065375490804`, -0.7123563260538588}, {
     3.172315126401446, -0.9401845765543168}}]}, 
   {Hue[0.509040006872866], AbsoluteThickness[0.5], 
    LineBox[{{3.470776885602129, 0.3434255118979491}, {3.6044922354954103`, 
     0.23878635452631666`}}]}, 
   {Hue[0.5097492480227706], AbsoluteThickness[0.5], 
    LineBox[{{3.6044922354954103`, 0.23878635452631666`}, {3.845415070345941, 
     0.07601978261158354}}]}, 
   {Hue[0.5896871859156814], AbsoluteThickness[0.5], 
    LineBox[{{3.462314943381548, 0.8786818926855546}, {3.4085632318398025`, 
     0.782246657745382}}]}, 
   {Hue[0.5907012941034959], AbsoluteThickness[0.5], 
    LineBox[{{3.4085632318398025`, 0.782246657745382}, {3.2666524021743855`, 
     0.5765752613732266}}]}, 
   {Hue[0.03561355725168631], AbsoluteThickness[0.5], 
    LineBox[{{3.6178230018253923`, 1.1518588599881683`}, {3.6624253767691752`,
      1.2303171353185003`}}]}, 
   {Hue[0.03648598780898396], AbsoluteThickness[0.5], 
    LineBox[{{3.6624253767691752`, 1.2303171353185003`}, {3.8069893194456044`,
      1.4407126342832417`}}]}, 
   {Hue[0.5189400086396476], AbsoluteThickness[0.5], 
    LineBox[{{3.8069893194456044`, 1.4407126342832417`}, {3.924002031051037, 
     1.2138359611114051`}}]}, 
   {Hue[0.5905389285534798], AbsoluteThickness[0.5], 
    LineBox[{{3.460018192302461, 0.8800021812085975}, {3.406372815122055, 
     0.7874608163707536}}]}, 
   {Hue[0.5914213451124586], AbsoluteThickness[0.5], 
    LineBox[{{3.406372815122055, 0.7874608163707536}, {3.2588200743615783`, 
     0.5769054462341787}}]}, 
   {Hue[0.5129194691212451], AbsoluteThickness[0.5], 
    LineBox[{{2.8744799920017368`, 0.8958066865584389}, {2.569306273058282, 
     1.033537177682878}}]}, 
   {Hue[0.5154876280378955], AbsoluteThickness[0.5], 
    LineBox[{{2.569306273058282, 1.033537177682878}, {2.4041673239288466`, 
     1.078870532810134}}]}, 
   {Hue[0.5976950832489463], AbsoluteThickness[0.5], 
    LineBox[{{2.890485253564109, -0.8719898657656994}, {
     2.8909853077603636`, -0.873522868304058}}]}, 
   {Hue[0.5981810977849742], AbsoluteThickness[0.5], 
    LineBox[{{2.8909853077603636`, -0.8735228683040581}, {
     2.987280783468024, -1.1379926159674905`}}]}, 
   {Hue[0.6754195382264437], AbsoluteThickness[0.5], 
    LineBox[{{2.877322838130137, -0.3648072496096495}, {
     2.8773231897304594`, -0.36358438079057}}]}, 
   {Hue[0.6767052147839963], AbsoluteThickness[0.5], 
    LineBox[{{2.8773231897304594`, -0.36358438079057}, {
     2.8497938171440436`, -0.11645117641526448`}}]}, 
   {Hue[0.28693879451052895`], AbsoluteThickness[0.5], 
    LineBox[{{3.1018180483063533`, -0.3409375941762013}, {
     3.1158728123015993`, -0.3414699708088216}}]}, 
   {Hue[0.28752429007515923`], AbsoluteThickness[0.5], 
    LineBox[{{3.1158728123015993`, -0.3414699708088216}, {
     3.41174783892464, -0.3367418990667374}}]}, 
   {Hue[0.6796739022821519], AbsoluteThickness[0.5], 
    LineBox[{{3.117237858127878, -0.5661710049030364}, {
     3.10979303852501, -0.6646772325643706}}]}, 
   {Hue[0.6810518771530467], AbsoluteThickness[0.5], 
    LineBox[{{3.10979303852501, -0.6646772325643706}, {
     3.1198857684185297`, -0.9149293457403631}}]}, 
   {Hue[0.6180674191031595], AbsoluteThickness[0.5], 
    LineBox[{{2.9293165302647544`, 0.07088356892767045}, {3.0563410254756547`,
      0.3898384756464186}}]}, 
   {Hue[0.6187647391025418], AbsoluteThickness[0.5], 
    LineBox[{{3.0563410254756547`, 0.3898384756464186}, {3.138847016711832, 
     0.6469915984415477}}]}, 
   {Hue[0.3069118961088478], AbsoluteThickness[0.5], 
    LineBox[{{2.987425314468647, -1.1379765458999795`}, {
     3.0494547587399192`, -1.277241109049703}}]}, 
   {Hue[0.3343674399672677], AbsoluteThickness[0.5], 
    LineBox[{{3.0494547587399192`, -1.277241109049703}, {
     3.1650188531458756`, -1.4007948057845165`}}]}, 
   {Hue[0.48018734177230166`], AbsoluteThickness[0.5], 
    LineBox[{{3.1650188531458756`, -1.4007948057845165`}, {
     3.328946830215382, -1.3589833931486515`}}]}, 
   {Hue[0.6260072435773345], AbsoluteThickness[0.5], 
    LineBox[{{3.328946830215382, -1.3589833931486515`}, {
     3.3712158956692546`, -1.195172825728954}}]}, 
   {Hue[0.33752419052696614`], AbsoluteThickness[0.5], 
    LineBox[{{2.199205008435226, -1.4417557492712223`}, {
     2.145827699435372, -1.5231199132033997`}}]}, 
   {Hue[0.3469750419208268], AbsoluteThickness[0.5], 
    LineBox[{{2.145827699435372, -1.5231199132033997`}, {
     2.0133206542809177`, -1.6448592061995406`}}]}, 
   {Hue[0.5921689451032832], AbsoluteThickness[0.5], 
    LineBox[{{2.0133206542809177`, -1.6448592061995406`}, {
     1.8525029590990179`, -1.5641359667257289`}}]}, 
   {Hue[0.4305882193693311], AbsoluteThickness[0.5], 
    LineBox[{{2.7196230336576193`, 0.417688536459185}, {2.7732941583723996`, 
     0.5538716546486198}}]}, 
   {Hue[0.43121700254404816`], AbsoluteThickness[0.5], 
    LineBox[{{2.7732941583723996`, 0.5538716546486198}, {2.8672739652667496`, 
     0.8419870920515773}}]}, 
   {Hue[0.4614952626687331], AbsoluteThickness[0.5], 
    LineBox[{{3.3799972597589214`, -0.17534988935394846`}, {
     3.401309089088587, -0.17302159395306133`}}]}, 
   {Hue[0.46804719688144086`], AbsoluteThickness[0.5], 
    LineBox[{{3.401309089088587, -0.17302159395306133`}, {
     3.5840648922115754`, -0.11065362911217447`}}]}, 
   {Hue[0.49728578489725345`], AbsoluteThickness[0.5], 
    LineBox[{{3.5435339516639304`, -1.6693109631684728`}, {
     3.576573755415063, -1.7381103681797592`}}]}, 
   {Hue[0.4984287379471077], AbsoluteThickness[0.5], 
    LineBox[{{3.576573755415063, -1.7381103681797592`}, {
     3.6912088490828845`, -1.9245844399396763`}}]}, 
   {Hue[0.5299349701176034], AbsoluteThickness[0.5], 
    LineBox[{{2.742997833435222, -1.3734364728355164`}, {
     2.804576016554494, -1.591140524259104}}]}, 
   {Hue[0.5314602535039169], AbsoluteThickness[0.5], 
    LineBox[{{2.804576016554494, -1.591140524259104}, {
     2.8435131356013508`, -1.8430911447660823`}}]}, 
   {Hue[0.6261147503661182], AbsoluteThickness[0.5], 
    LineBox[{{2.3518329379068703`, 0.09603901253612762}, {2.364125958951203, 
     0.4221385504012387}}]}, 
   {Hue[0.6273729882492705], AbsoluteThickness[0.5], 
    LineBox[{{2.364125958951203, 0.4221385504012387}, {2.401822527333583, 
     0.675864414469061}}]}, 
   {Hue[0.6447548083027801], AbsoluteThickness[0.5], 
    LineBox[{{3.2030553613724972`, -0.027242646955745624`}, {
     3.2959879902517977`, 0.02727803376400663}}]}, 
   {Hue[0.6462966024816809], AbsoluteThickness[0.5], 
    LineBox[{{3.2959879902517977`, 0.02727803376400663}, {3.523212509713359, 
     0.12537341633168847`}}]}, 
   {Hue[0.6863634221565822], AbsoluteThickness[0.5], 
    LineBox[{{3.358898172766486, -0.7170423153440393}, {
     3.488077867947964, -0.8013527652332468}}]}, 
   {Hue[0.6872514379416971], AbsoluteThickness[0.5], 
    LineBox[{{3.488077867947964, -0.8013527652332468}, {
     3.7094842569265682`, -0.9748190876291161}}]}, 
   {Hue[0.5455743363222284], AbsoluteThickness[0.5], 
    LineBox[{{2.3437168296833732`, -2.394011209951793}, {
     2.36530097440838, -2.470324220860121}}]}, 
   {Hue[0.5564859596658962], AbsoluteThickness[0.5], 
    LineBox[{{2.36530097440838, -2.470324220860121}, {
     2.4569846820912624`, -2.6254712865018512`}}]}, 
   {Hue[0.5383551555523698], AbsoluteThickness[0.5], 
    LineBox[{{2.041510205117525, -3.149977817168331}, {
     2.0679891998160014`, -3.349176555040993}}]}, 
   {Hue[0.5393459852382991], AbsoluteThickness[0.5], 
    LineBox[{{2.0679891998160014`, -3.349176555040993}, {
     2.0781608854372218`, -3.614967527067387}}]}, 
   {Hue[0.526860171796597], AbsoluteThickness[0.5], 
    LineBox[{{2.5522874143439527`, -0.7000983068310159}, {
     2.4904727821533448`, -0.8530705657151887}}]}, 
   {Hue[0.5274036488293495], AbsoluteThickness[0.5], 
    LineBox[{{2.4904727821533448`, -0.8530705657151888}, {
     2.3780146564078732`, -1.173686026138578}}]}, 
   {Hue[0.4534599625582863], AbsoluteThickness[0.5], 
    LineBox[{{2.994867762358509, -0.2001354405247115}, {
     3.0509229539618303`, -0.3124015897377686}}]}, 
   {Hue[0.4548337690847463], AbsoluteThickness[0.5], 
    LineBox[{{3.0509229539618303`, -0.3124015897377686}, {
     3.1345136989709275`, -0.5431550279369981}}]}, 
   {Hue[0.01063685589862956], AbsoluteThickness[0.5], 
    LineBox[{{3.2040138646207814`, -0.0491918126213549}, {3.2991904040201376`,
      0.03685873879378392}}]}, 
   {Hue[0.015356948625732047`], AbsoluteThickness[0.5], 
    LineBox[{{3.2991904040201376`, 0.03685873879378392}, {3.4734619823938733`,
      0.14089769316448297`}}]}, 
   {Hue[0.328589228563672], AbsoluteThickness[0.5], 
    LineBox[{{3.4734619823938733`, 0.14089769316448297`}, {
     3.6120315163355317`, -0.007403255310613}}]}, 
   {Hue[0.6418215085016113], AbsoluteThickness[0.5], 
    LineBox[{{3.6120315163355317`, -0.007403255310613}, {
     3.496421805515521, -0.1742237631012768}}]}, 
   {Hue[0.4559810304820688], AbsoluteThickness[0.5], 
    LineBox[{{3.002432095541512, 0.11171456161844992`}, {2.900474365867585, 
     0.17616662376411898`}}]}, 
   {Hue[0.45643499916249614`], AbsoluteThickness[0.5], 
    LineBox[{{2.900474365867585, 0.17616662376411898`}, {2.600353778455782, 
     0.3562138887118683}}]}, 
   {Hue[0.5284007060741717], AbsoluteThickness[0.5], 
    LineBox[{{2.3155337868584303`, -0.03651456183310251}, {
     2.1421723582663987`, 0.03817059249961044}}]}, 
   {Hue[0.5295264540155233], AbsoluteThickness[0.5], 
    LineBox[{{2.1421723582663987`, 0.03817059249961044}, {1.8420612403559908`,
      0.1324214818595156}}]}, 
   {Hue[0.6357128679092124], AbsoluteThickness[0.5], 
    LineBox[{{2.416699435871233, -1.1965728788141616`}, {
     2.3902877718480044`, -1.248160811744829}}]}, 
   {Hue[0.6373751185765557], AbsoluteThickness[0.5], 
    LineBox[{{2.3902877718480044`, -1.248160811744829}, {
     2.2551226669478193`, -1.445284927751419}}]}, 
   {Hue[0.5337668094933523], AbsoluteThickness[0.5], 
    LineBox[{{2.9380283572672012`, -1.2790852702924465`}, {
     2.9623945332917825`, -1.355390439518602}}]}, 
   {Hue[0.5341929782873324], AbsoluteThickness[0.5], 
    LineBox[{{2.9623945332917825`, -1.355390439518602}, {
     3.061999712864387, -1.6646528560749165`}}]}, 
   {Hue[0.6869973164461733], AbsoluteThickness[0.5], 
    LineBox[{{3.082727986220084, -0.9014334590329316}, {
     3.1065576420532666`, -0.9040280132406799}}]}, 
   {Hue[0.6893891984280165], AbsoluteThickness[0.5], 
    LineBox[{{3.1065576420532666`, -0.9040280132406799}, {
     3.331968753454761, -0.8943418043981085}}]}, 
   {Hue[0.5396591113923108], AbsoluteThickness[0.5], 
    LineBox[{{1.9518141333919388`, -2.1031295428452372`}, {
     1.8950791924924286`, -2.3601160569673945`}}]}, 
   {Hue[0.5423576683643332], AbsoluteThickness[0.5], 
    LineBox[{{1.8950791924924286`, -2.3601160569673945`}, {
     1.8815974727513747`, -2.5922593046853506`}}]}, 
   {Hue[0.5102988268029629], AbsoluteThickness[0.5], 
    LineBox[{{2.9290319228351374`, -2.1118131988474245`}, {
     3.0656876087539757`, -2.3394146217065845`}}]}, 
   {Hue[0.5151508906361325], AbsoluteThickness[0.5], 
    LineBox[{{3.0656876087539757`, -2.3394146217065845`}, {
     3.1382978158283796`, -2.543424692276835}}]}, 
   {Hue[0.5105895471077382], AbsoluteThickness[0.5], 
    LineBox[{{3.065872672627265, -2.1670222235111876`}, {
     3.1379747395987327`, -2.1671439689030354`}}]}, 
   {Hue[0.5110565417225761], AbsoluteThickness[0.5], 
    LineBox[{{3.1379747395987327`, -2.1671439689030354`}, {
     3.431878604854097, -2.1759189421743104`}}]}, 
   {Hue[0.6080168953005889], AbsoluteThickness[0.5], 
    LineBox[{{3.1837951812311966`, -2.0783221154359914`}, {
     3.2997957524280057`, -1.8865921167293258`}}]}, 
   {Hue[0.6096667925664758], AbsoluteThickness[0.5], 
    LineBox[{{3.2997957524280057`, -1.8865921167293258`}, {
     3.399182256776903, -1.662057253450502}}]}, 
   {Hue[0.5471003911139677], AbsoluteThickness[0.5], 
    LineBox[{{2.5436032382851548`, -3.658042594090215}, {
     2.5898093112378646`, -3.7482372999635114`}}]}, 
   {Hue[0.5567431118096939], AbsoluteThickness[0.5], 
    LineBox[{{2.5898093112378646`, -3.7482372999635114`}, {
     2.707429285425359, -3.8817823367311504`}}]}, 
   {Hue[0.5025232242018862], AbsoluteThickness[0.5], 
    LineBox[{{2.4066262376848373`, -0.20102479545572682`}, {
     2.4519001014433246`, -0.18108509197529693`}}]}, 
   {Hue[0.5108643553840542], AbsoluteThickness[0.5], 
    LineBox[{{2.4519001014433246`, -0.18108509197529693`}, {
     2.577214412043428, -0.15865502205992243`}}]}, 
   {Hue[0.488963365474244], AbsoluteThickness[0.5], 
    LineBox[{{2.9023906921905986`, -0.33241815598626767`}, {
     2.914983776499029, -0.3300167990220439}}]}, 
   {Hue[0.4403732389383506], AbsoluteThickness[0.5], 
    LineBox[{{3.2192798656454715`, -0.9457402705723252}, {
     4.057405249004845, -1.7457988427041333`}}]}, 
   {Hue[0.4420197795044325], AbsoluteThickness[0.5], 
    LineBox[{{4.057405249004845, -1.7457988427041333`}, {
     4.278299163020615, -1.9085210190196962`}}]}, 
   {Hue[0.5425034670800014], AbsoluteThickness[0.5], 
    LineBox[{{3.1946424122747805`, -0.42527998734344896`}, {
     3.172024215894543, -0.6314717408599966}}]}, 
   {Hue[0.543052749836482], AbsoluteThickness[0.5], 
    LineBox[{{3.172024215894543, -0.6314717408599966}, {
     3.153408471987272, -0.9337401243996883}}]}, 
   {Hue[0.008957884200765508], AbsoluteThickness[0.5], 
    LineBox[{{3.3990146158818657`, -0.20094830376234563`}, {
     3.4185949773709208`, -0.17754591810557013`}}]}, 
   {Hue[0.009622680443480568], AbsoluteThickness[0.5], 
    LineBox[{{3.4185949773709208`, -0.17754591810557013`}, {
     3.5920844047750737`, 0.05941005325514016}}]}, 
   {Hue[0.5195246155174289], AbsoluteThickness[0.5], 
    LineBox[{{3.5920844047750737`, 0.05941005325514016}, {3.2992593397092693`,
      0.037045012371518166`}}]}, 
   {Hue[0.5435449426702991], AbsoluteThickness[0.5], 
    LineBox[{{3.104570135527935, -0.27439998757321493`}, {
     3.0032153208638563`, -0.30427412040645085`}}]}, 
   {Hue[0.5570747208462458], AbsoluteThickness[0.5], 
    LineBox[{{3.0032153208638563`, -0.30427412040645085`}, {
     2.8588749051573092`, -0.3950763973452136}}]}, 
   {Hue[0.4416992575893804], AbsoluteThickness[0.5], 
    LineBox[{{2.667939463661042, -0.1305738932502986}, {
     2.6280839081704492`, -0.11032540499701866`}}]}, 
   {Hue[0.44213926573405404`], AbsoluteThickness[0.5], 
    LineBox[{{2.6280839081704492`, -0.11032540499701866`}, {2.325289069167548,
      0.04990319274198501}}]}, 
   {Hue[0.558206440006345], AbsoluteThickness[0.5], 
    LineBox[{{2.169966978836697, -1.43145040062536}, {
     2.1435167538243722`, -1.4439376523018297`}}]}, 
   {Hue[0.5586517677017035], AbsoluteThickness[0.5], 
    LineBox[{{2.1435167538243722`, -1.4439376523018297`}, {
     1.857301328615357, -1.5723002721622243`}}]}, 
   {Hue[0.5267529817179701], AbsoluteThickness[0.5], 
    LineBox[{{2.3511367779655084`, -2.390721142071104}, {
     2.310773909659867, -2.547604090863018}}]}, 
   {Hue[0.5271799771823389], AbsoluteThickness[0.5], 
    LineBox[{{2.310773909659867, -2.547604090863018}, {
     2.227082392631202, -2.866618079254439}}]}, 
   {Hue[0.4817978620665028], AbsoluteThickness[0.5], 
    LineBox[{{2.7932771806279204`, -2.915853154730379}, {
     2.843188089378053, -3.1527622799161756`}}]}, 
   {Hue[0.4836826515507408], AbsoluteThickness[0.5], 
    LineBox[{{2.843188089378053, -3.1527622799161756`}, {
     2.859720938202348, -3.383065625490599}}]}, 
   {Hue[0.44440415251873155`], AbsoluteThickness[0.5], 
    LineBox[{{3.0254739900655676`, -1.6712658885323761`}, {
     3.096163245793098, -1.8768060100612742`}}]}, 
   {Hue[0.4453827077498267], AbsoluteThickness[0.5], 
    LineBox[{{3.096163245793098, -1.8768060100612742`}, {
     3.1554957807363624`, -2.1211691387751177`}}]}, 
   {Hue[0.5418452907970958], AbsoluteThickness[0.5], 
    LineBox[{{3.105033394132903, -0.267803759017199}, {
     2.9252638617607993`, -0.2583214644979997}}]}, 
   {Hue[0.5422711529545001], AbsoluteThickness[0.5], 
    LineBox[{{2.925263861760799, -0.2583214644979997}, {
     2.6122527995224583`, -0.24193651118284243`}}]}, 
   {Hue[0.5655251881919658], AbsoluteThickness[0.5], 
    LineBox[{{3.884903728405023, -0.05237168738407455}, {
     3.7926496941309757`, -0.09346935872032053}}]}, 
   {Hue[0.5664303801574813], AbsoluteThickness[0.5], 
    LineBox[{{3.7926496941309757`, -0.09346935872032053}, {
     3.5386068305073883`, -0.23449542945190396`}}]}, 
   {Hue[0.012656401447724897`], AbsoluteThickness[0.5], 
    LineBox[{{4.156816545678254, 0.1231213860248081}, {4.189225606921999, 
     0.1435823811863723}}]}, 
   {Hue[0.013141238837568769`], AbsoluteThickness[0.5], 
    LineBox[{{4.189225606921999, 0.1435823811863723}, {4.451198752175418, 
     0.3215403316578994}}]}, 
   {Hue[0.5549512669185432], AbsoluteThickness[0.5], 
    LineBox[{{4.451198752175418, 0.3215403316578994}, {4.136896266024384, 
     0.282644211423682}}]}, 
   {Hue[0.5663870505199465], AbsoluteThickness[0.5], 
    LineBox[{{3.912912540912218, -0.08958788850512525}, {
     3.848805183656618, -0.14437783176004537`}}]}, 
   {Hue[0.5668200044840498], AbsoluteThickness[0.5], 
    LineBox[{{3.848805183656618, -0.14437783176004537`}, {
     3.587800657812252, -0.3621662821786081}}]}, 
   {Hue[0.5476761673342694], AbsoluteThickness[0.5], 
    LineBox[{{3.5769857017156714`, -0.6875223499898963}, {
     3.4873467099434725`, -0.8016308365318853}}]}, 
   {Hue[0.551247713227243], AbsoluteThickness[0.5], 
    LineBox[{{3.4873467099434725`, -0.8016308365318853}, {
     3.3859963571708316`, -0.9925580556527532}}]}, 
   {Hue[0.44614535461591354`], AbsoluteThickness[0.5], 
    LineBox[{{2.139761018832615, -0.18718856351561686`}, {
     2.0943766571603772`, -0.15874299895042718`}}]}, 
   {Hue[0.44661330295122414`], AbsoluteThickness[0.5], 
    LineBox[{{2.0943766571603772`, -0.15874299895042718`}, {
     1.7797216303160575`, 0.051183827280435495`}}]}, 
   {Hue[0.4048732601416704], AbsoluteThickness[0.5], 
    LineBox[{{3.264676947477828, -2.9062964434785012`}, {
     3.3508414929905452`, -3.1601225231220638`}}]}, 
   {Hue[0.40644687009399], AbsoluteThickness[0.5], 
    LineBox[{{3.3508414929905452`, -3.1601225231220638`}, {
     3.3986537858289845`, -3.39250140844713}}]}, 
   {Hue[0.46016862295091915`], AbsoluteThickness[0.5], 
    LineBox[{{3.386563277143628, -2.8148478111911044`}, {
     3.4027026334376216`, -2.82601667967318}}]}, 
   {Hue[0.46074353589665307`], AbsoluteThickness[0.5], 
    LineBox[{{3.4027026334376216`, -2.82601667967318}, {
     3.638814938514066, -3.0083234107732495`}}]}, 
   {Hue[0.6639949966644555], AbsoluteThickness[0.5], 
    LineBox[{{2.304553422966435, -2.8654807781215044`}, {
     2.2813653033362145`, -3.0573670519482543`}}]}, 
   {Hue[0.6644401645294707], AbsoluteThickness[0.5], 
    LineBox[{{2.2813653033362145`, -3.0573670519482543`}, {
     2.2511803257171965`, -3.355663813205243}}]}, 
   {Hue[0.5529856547213846], AbsoluteThickness[0.5], 
    LineBox[{{3.1447535838815814`, -2.4542458533267646`}, {
     3.5677581170152814`, -2.769549815445197}}]}, 
   {Hue[0.5544478943633273], AbsoluteThickness[0.5], 
    LineBox[{{3.5677581170152814`, -2.769549815445197}, {
     3.7744662660850783`, -2.88816480877091}}]}, 
   {Hue[0.2467670857501512], AbsoluteThickness[0.5], 
    LineBox[{{3.541313591527726, 0.11478473316759906`}, {3.624027140379621, 
     0.13725329668679637`}}]}, 
   {Hue[0.24724247791479204`], AbsoluteThickness[0.5], 
    LineBox[{{3.624027140379621, 0.13725329668679637`}, {3.927010759369448, 
     0.22967457459770826`}}]}, 
   {Hue[0.6993224884986244], AbsoluteThickness[0.5], 
    LineBox[{{2.138429615933889, -0.0916901865208875}, {
     2.093688570159478, -0.3218439747012276}}]}, 
   {Hue[0.6999165393930341], AbsoluteThickness[0.5], 
    LineBox[{{2.093688570159478, -0.3218439747012276}, {
     2.0213869079510305`, -0.6083975710599281}}]}, 
   {Hue[0.5649685608292575], AbsoluteThickness[0.5], 
    LineBox[{{2.482132497875498, 0.8494184425441129}, {2.5659678087631828`, 
     0.6702959967584593}}]}, 
   {Hue[0.568157978201497], AbsoluteThickness[0.5], 
    LineBox[{{2.5659678087631828`, 0.6702959967584593}, {2.6229656444915594`, 
     0.4622814603253479}}]}, 
   {Hue[0.02556281860574353], AbsoluteThickness[0.5], 
    LineBox[{{2.504947851783013, 1.086793819327972}, {2.5190155640516547`, 
     1.3192919797885094`}}]}, 
   {Hue[0.026053185492385233`], AbsoluteThickness[0.5], 
    LineBox[{{2.5190155640516547`, 1.3192919797885094`}, {2.5274721935336997`,
      1.6522551607798501`}}]}, 
   {Hue[0.5667164519685304], AbsoluteThickness[0.5], 
    LineBox[{{2.5274721935336997`, 1.6522551607798501`}, {2.362286154398631, 
     1.363032812139679}}]}, 
   {Hue[0.5659519568752306], AbsoluteThickness[0.5], 
    LineBox[{{2.371480714505708, 0.8891726333579317}, {2.371199918287638, 
     0.8887233752648093}}]}, 
   {Hue[0.5663962095249212], AbsoluteThickness[0.5], 
    LineBox[{{2.371199918287638, 0.8887233752648093}, {2.2380901154912967`, 
     0.6844720603887963}}]}, 
   {Hue[0.5717724422661271], AbsoluteThickness[0.5], 
    LineBox[{{2.690486310399715, 0.06920683472616213}, {
     2.78264982922463, -0.09447918817177972}}]}, 
   {Hue[0.5725999455841686], AbsoluteThickness[0.5], 
    LineBox[{{2.78264982922463, -0.09447918817177972}, {
     2.89638267856279, -0.3415053201818803}}]}, 
   {Hue[0.5324627246552863], AbsoluteThickness[0.5], 
    LineBox[{{3.1171403047075903`, -0.5662786422817271}, {
     3.169067722296185, -0.6323140383704375}}]}, 
   {Hue[0.5330135354117043], AbsoluteThickness[0.5], 
    LineBox[{{3.169067722296185, -0.6323140383704375}, {
     3.344514968547143, -0.878934029713486}}]}, 
   {Hue[0.6416957583356536], AbsoluteThickness[0.5], 
    LineBox[{{2.811952547829774, 0.8740178256393171}, {2.835760818831584, 
     1.064383236101108}}]}, 
   {Hue[0.6424724346871379], AbsoluteThickness[0.5], 
    LineBox[{{2.835760818831584, 1.064383236101108}, {2.8504652200761806`, 
     1.372392023126388}}]}, 
   {Hue[0.5265121225779376], AbsoluteThickness[0.5], 
    LineBox[{{3.191249574488383, -0.14079927561953187`}, {
     3.289536127319963, -0.029919166798651253`}}]}, 
   {Hue[0.5278514597316039], AbsoluteThickness[0.5], 
    LineBox[{{3.289536127319963, -0.029919166798651253`}, {3.478832091460528, 
     0.14004554789968798`}}]}, 
   {Hue[0.2868001618643447], AbsoluteThickness[0.5], 
    LineBox[{{3.3721983348153373`, -0.1673849869787014}, {
     3.5385993365039807`, -0.23466422575074872`}}]}, 
   {Hue[0.28732374641994207`], AbsoluteThickness[0.5], 
    LineBox[{{3.5385993365039807`, -0.23466422575074872`}, {
     3.84593915521684, -0.34388859709146324`}}]}, 
   {Hue[0.5433287177508158], AbsoluteThickness[0.5], 
    LineBox[{{3.407664798502683, -0.3468045619025335}, {
     3.4044962120503044`, -0.42012750567486323`}}]}, 
   {Hue[0.54520619876226], AbsoluteThickness[0.5], 
    LineBox[{{3.4044962120503044`, -0.4201275056748632}, {
     3.426936758056564, -0.6619390802441175}}]}, 
   {Hue[0.559977032064006], AbsoluteThickness[0.5], 
    LineBox[{{2.1635134522749517`, -0.3987773823015981}, {
     2.153784801293811, -0.40714575934964553`}}]}, 
   {Hue[0.5605720660974753], AbsoluteThickness[0.5], 
    LineBox[{{2.153784801293811, -0.40714575934964553`}, {
     1.9195075863051674`, -0.5871261209295994}}]}, 
   {Hue[0.5692787934912564], AbsoluteThickness[0.5], 
    LineBox[{{2.802495474961314, 0.07669901312066196}, {
     2.8114425088230464`, -0.09979159306528826}}]}, 
   {Hue[0.5697938117615603], AbsoluteThickness[0.5], 
    LineBox[{{2.8114425088230464`, -0.09979159306528826}, {
     2.8143653596071507`, -0.4005111305119663}}]}, 
   {Hue[0.48021575739434663`], AbsoluteThickness[0.5], 
    LineBox[{{2.8491804988459193`, 1.0715827818843235`}, {2.864511271559174, 
     1.0663814956965336`}}]}, 
   {Hue[0.4806531964216413], AbsoluteThickness[0.5], 
    LineBox[{{2.864511271559174, 1.0663814956965336`}, {3.192984939731563, 
     0.9493920790979014}}]}, 
   {Hue[0.021862180472901505`], AbsoluteThickness[0.5], 
    LineBox[{{2.8699034112844646`, 1.358743805095254}, {2.869328094565325, 
     1.3793299916882624`}}]}, 
   {Hue[0.023230566769968118`], AbsoluteThickness[0.5], 
    LineBox[{{2.869328094565325, 1.3793299916882624`}, {2.8928937953556026`, 
     1.6484318801272975`}}]}, 
   {Hue[0.4603067103427761], AbsoluteThickness[0.5], 
    LineBox[{{2.8928937953556026`, 1.6484318801272975`}, {3.1495247004763645`,
      1.5641007046813786`}}]}, 
   {Hue[0.48238435507727173`], AbsoluteThickness[0.5], 
    LineBox[{{2.5934467582038794`, 1.2783534367731393`}, {2.4116605288467894`,
      1.2051202312256348`}}]}, 
   {Hue[0.4830376697903067], AbsoluteThickness[0.5], 
    LineBox[{{2.4116605288467894`, 1.2051202312256348`}, {2.1244601508959042`,
      1.1100541105675477`}}]}, 
   {Hue[0.5750319701046033], AbsoluteThickness[0.5], 
    LineBox[{{2.5079532784937957`, 0.37631694093268414`}, {
     2.1445633694285053`, 0.030241893519951487`}}]}, 
   {Hue[0.5756889357576186], AbsoluteThickness[0.5], 
    LineBox[{{2.1445633694285053`, 0.030241893519951487`}, {
     1.874983000978898, -0.19555124872308344`}}]}, 
   {Hue[0.5626032420413285], AbsoluteThickness[0.5], 
    LineBox[{{3.172315126401446, -0.9401845765543168}, {
     3.255207901587195, -1.0810539705632172`}}]}, 
   {Hue[0.5640236709225931], AbsoluteThickness[0.5], 
    LineBox[{{3.255207901587195, -1.0810539705632172`}, {
     3.3592112532337337`, -1.31764649686781}}]}, 
   {Hue[0.510458489172675], AbsoluteThickness[0.5], 
    LineBox[{{3.845415070345941, 0.07601978261158354}, {3.8691668643818113`, 
     0.06228421926269668}}]}, 
   {Hue[0.5109561213686011], AbsoluteThickness[0.5], 
    LineBox[{{3.8691668643818113`, 0.06228421926269668}, {
     4.14627945721463, -0.08460633810639392}}]}, 
   {Hue[0.5917154022913104], AbsoluteThickness[0.5], 
    LineBox[{{3.2666524021743855`, 0.5765752613732265}, {
     2.678572548484716, -0.12239294687515356`}}]}, 
   {Hue[0.6097275009505257], AbsoluteThickness[0.5], 
    LineBox[{{2.678572548484716, -0.12239294687515356`}, {
     2.613886922866226, -0.27473584047618027`}}]}, 
   {Hue[0.5180675780823516], AbsoluteThickness[0.5], 
    LineBox[{{3.6624253767691752`, 1.2303171353185003`}, {3.423372449835725, 
     1.2774106286385942`}}]}, 
   {Hue[0.5185244653243606], AbsoluteThickness[0.5], 
    LineBox[{{3.423372449835725, 1.2774106286385942`}, {3.151290158714302, 
     1.3241109832553086`}}]}, 
   {Hue[0.0373584183662817], AbsoluteThickness[0.5], 
    LineBox[{{3.8069893194456044`, 1.4407126342832417`}, {3.869537641731128, 
     1.5169449025453825`}}]}, 
   {Hue[0.04107389461120747], AbsoluteThickness[0.5], 
    LineBox[{{3.869537641731128, 1.5169449025453825`}, {4.0176555195281995`, 
     1.6425043602294702`}}]}, 
   {Hue[0.3780664835866211], AbsoluteThickness[0.5], 
    LineBox[{{4.0176555195281995`, 1.6425043602294702`}, {4.16372465786189, 
     1.5145673055366111`}}]}, 
   {Hue[0.5198124391969452], AbsoluteThickness[0.5], 
    LineBox[{{3.924002031051037, 1.2138359611114051`}, {3.9418888998920107`, 
     1.1704543122371585`}}]}, 
   {Hue[0.5202800968249084], AbsoluteThickness[0.5], 
    LineBox[{{3.9418888998920107`, 1.1704543122371585`}, {4.068248954316944, 
     0.887085742021447}}]}, 
   {Hue[0.5923037616714374], AbsoluteThickness[0.5], 
    LineBox[{{3.2588200743615783`, 0.5769054462341787}, {3.167705498388444, 
     0.4681013738649792}}]}, 
   {Hue[0.6181098667748889], AbsoluteThickness[0.5], 
    LineBox[{{3.167705498388444, 0.4681013738649792}, {3.0363891395748825`, 
     0.38832942021844596`}}]}, 
   {Hue[0.5180557869545459], AbsoluteThickness[0.5], 
    LineBox[{{2.4041673239288466`, 1.078870532810134}, {2.3411990055765988`, 
     1.0859451913238614`}}]}, 
   {Hue[0.5197705142083687], AbsoluteThickness[0.5], 
    LineBox[{{2.3411990055765988`, 1.0859451913238614`}, {2.0995693575766055`,
      1.1455272097362947`}}]}, 
   {Hue[0.5986671123210022], AbsoluteThickness[0.5], 
    LineBox[{{2.987280783468024, -1.1379926159674905`}, {
     3.076184737213957, -1.3586142954303382`}}]}, 
   {Hue[0.5999669058805543], AbsoluteThickness[0.5], 
    LineBox[{{3.076184737213957, -1.3586142954303382`}, {
     3.145078508779958, -1.606459745483055}}]}, 
   {Hue[0.677990891341549], AbsoluteThickness[0.5], 
    LineBox[{{2.8497938171440436`, -0.11645117641526453`}, {
     2.8058440929851294`, 0.0781102795621667}}]}, 
   {Hue[0.6784438746013072], AbsoluteThickness[0.5], 
    LineBox[{{2.8058440929851294`, 0.0781102795621667}, {2.7208725285273085`, 
     0.4177945893282545}}]}, 
   {Hue[0.28810978563978934`], AbsoluteThickness[0.5], 
    LineBox[{{3.41174783892464, -0.3367418990667374}, {
     3.560654364505059, -0.3263286423562513}}]}, 
   {Hue[0.2887193335668926], AbsoluteThickness[0.5], 
    LineBox[{{3.560654364505059, -0.3263286423562513}, {
     3.8737988550753357`, -0.2862629681214036}}]}, 
   {Hue[0.6824298520239417], AbsoluteThickness[0.5], 
    LineBox[{{3.1198857684185297`, -0.9149293457403631}, {
     3.147157575061578, -1.0882710891620724`}}]}, 
   {Hue[0.682902544313232], AbsoluteThickness[0.5], 
    LineBox[{{3.147157575061578, -1.0882710891620724`}, {
     3.207228918527008, -1.4074149941880651`}}]}, 
   {Hue[0.6194620591019242], AbsoluteThickness[0.5], 
    LineBox[{{3.138847016711832, 0.6469915984415477}, {3.1397038260890135`, 
     0.6504636762178289}}]}, 
   {Hue[0.6208781164159304], AbsoluteThickness[0.5], 
    LineBox[{{3.1397038260890135`, 0.6504636762178289}, {3.2219270916722413`, 
     0.8692737186548891}}]}, 
   {Hue[0.45273179791388346`], AbsoluteThickness[0.5], 
    LineBox[{{3.0494547587399192`, -1.277241109049703}, {
     3.050660638812664, -1.3506119410049922`}}]}, 
   {Hue[0.4532025418967321], AbsoluteThickness[0.5], 
    LineBox[{{3.050660638812664, -1.3506119410049922`}, {
     3.046543546294097, -1.6685098208109015`}}]}, 
   {Hue[0.36182298382568795`], AbsoluteThickness[0.5], 
    LineBox[{{3.1650188531458756`, -1.4007948057845165`}, {
     3.3509456967470728`, -1.498972013113322}}]}, 
   {Hue[0.3624666251264118], AbsoluteThickness[0.5], 
    LineBox[{{3.3509456967470728`, -1.498972013113322}, {
     3.6352167805309112`, -1.6272022365978587`}}]}, 
   {Hue[0.5076428856307224], AbsoluteThickness[0.5], 
    LineBox[{{3.328946830215382, -1.3589833931486515`}, {
     3.8479833320655925`, -1.016917039266986}}]}, 
   {Hue[0.508349572357499], AbsoluteThickness[0.5], 
    LineBox[{{3.8479833320655925`, -1.016917039266986}, {
     4.099473804110332, -0.8752073248857024}}]}, 
   {Hue[0.6534627874357551], AbsoluteThickness[0.5], 
    LineBox[{{3.3712158956692546`, -1.195172825728954}, {
     3.3455984668310763`, -0.8774014719855858}}]}, 
   {Hue[0.6553634945174489], AbsoluteThickness[0.5], 
    LineBox[{{3.3455984668310763`, -0.8774014719855858}, {
     3.294922024812482, -0.6475018076629606}}]}, 
   {Hue[0.5827180937094223], AbsoluteThickness[0.5], 
    LineBox[{{2.145827699435372, -1.5231199132033997`}, {
     2.1583002583351814`, -1.6160370748102575`}}]}, 
   {Hue[0.5838524821569481], AbsoluteThickness[0.5], 
    LineBox[{{2.1583002583351814`, -1.6160370748102575`}, {
     2.21495956084175, -1.8512085832635357`}}]}, 
   {Hue[0.4318457857187651], AbsoluteThickness[0.5], 
    LineBox[{{2.8672739652667496`, 0.8419870920515773}, {2.8794052328933395`, 
     0.8884881436362503}}]}, 
   {Hue[0.43290106772170206`], AbsoluteThickness[0.5], 
    LineBox[{{2.8794052328933395`, 0.8884881436362503}, {2.9795838196579805`, 
     1.1600955982182852`}}]}, 
   {Hue[0.4745991310941486], AbsoluteThickness[0.5], 
    LineBox[{{3.5840648922115754`, -0.11065362911217447`}, {
     3.8695674218698506`, 0.0639673195431418}}]}, 
   {Hue[0.4759775500329202], AbsoluteThickness[0.5], 
    LineBox[{{3.8695674218698506`, 0.0639673195431418}, {4.100012932166327, 
     0.1705375722338511}}]}, 
   {Hue[0.49957169099696186`], AbsoluteThickness[0.5], 
    LineBox[{{3.6912088490828845`, -1.9245844399396763`}, {
     3.815002685571069, -2.0858549806424684`}}]}, 
   {Hue[0.5012985870888289], AbsoluteThickness[0.5], 
    LineBox[{{3.815002685571069, -2.0858549806424684`}, {
     3.9157900243279067`, -2.260122605467422}}]}, 
   {Hue[0.5329855368902303], AbsoluteThickness[0.5], 
    LineBox[{{2.8435131356013508`, -1.8430911447660823`}, {
     2.852685994144883, -2.138825785041525}}]}, 
   {Hue[0.5385730642534825], AbsoluteThickness[0.5], 
    LineBox[{{2.852685994144883, -2.138825785041525}, {
     2.8177681146040965`, -2.3332792196585226`}}]}, 
   {Hue[0.6286312261324227], AbsoluteThickness[0.5], 
    LineBox[{{2.401822527333583, 0.675864414469061}, {2.447385673473047, 
     0.8490161802980523}}]}, 
   {Hue[0.6290694050320351], AbsoluteThickness[0.5], 
    LineBox[{{2.447385673473047, 0.8490161802980523}, {2.505931481764063, 
     1.086435695772909}}]}, 
   {Hue[0.6478383966605816], AbsoluteThickness[0.5], 
    LineBox[{{3.523212509713359, 0.12537341633168847`}, {3.6163844655982325`, 
     0.15262229867106586`}}]}, 
   {Hue[0.6482759596450003], AbsoluteThickness[0.5], 
    LineBox[{{3.6163844655982325`, 0.15262229867106586`}, {
     3.9245568350508115`, 0.24784004974204057`}}]}, 
   {Hue[0.6881394537268118], AbsoluteThickness[0.5], 
    LineBox[{{3.7094842569265682`, -0.9748190876291161}, {
     4.796006158988256, -1.98889396745425}}]}, 
   {Hue[0.6892045056074548], AbsoluteThickness[0.5], 
    LineBox[{{4.796006158988256, -1.98889396745425}, {
     4.999869176008277, -2.1445618882550104`}}]}, 
   {Hue[0.567397583009564], AbsoluteThickness[0.5], 
    LineBox[{{2.4569846820912624`, -2.6254712865018512`}, {
     2.5748420459737513`, -2.741821032481738}}]}, 
   {Hue[0.5685844652757696], AbsoluteThickness[0.5], 
    LineBox[{{2.5748420459737513`, -2.741821032481738}, {
     2.793195593260454, -2.9158752729448443`}}]}, 
   {Hue[0.5403368149242286], AbsoluteThickness[0.5], 
    LineBox[{{2.0781608854372218`, -3.614967527067387}, {
     2.0775606679728065`, -3.6257417492355133`}}]}, 
   {Hue[0.5451688904761579], AbsoluteThickness[0.5], 
    LineBox[{{2.0775606679728065`, -3.6257417492355133`}, {
     2.1058929305551946`, -3.8227216982079804`}}]}, 
   {Hue[0.5279471258621019], AbsoluteThickness[0.5], 
    LineBox[{{2.3780146564078732`, -1.173686026138578}, {
     2.3696945115220314`, -1.201499284632744}}]}, 
   {Hue[0.5290161875050089], AbsoluteThickness[0.5], 
    LineBox[{{2.3696945115220314`, -1.201499284632744}, {
     2.270626372471267, -1.442712640458672}}]}, 
   {Hue[0.45620757561120645`], AbsoluteThickness[0.5], 
    LineBox[{{3.1345136989709275`, -0.5431550279369981}, {
     3.1565829982300766`, -0.6365676613774776}}]}, 
   {Hue[0.4566478926235212], AbsoluteThickness[0.5], 
    LineBox[{{3.1565829982300766`, -0.6365676613774776}, {
     3.2348264890996035`, -0.9445047322878591}}]}, 
   {Hue[0.3238691358365717], AbsoluteThickness[0.5], 
    LineBox[{{3.2991904040201376`, 0.03685873879378393}, {3.2899593040027857`,
      0.10855713932270283`}}]}, 
   {Hue[0.3243273809935452], AbsoluteThickness[0.5], 
    LineBox[{{3.2899593040027857`, 0.10855713932270283`}, {3.240666333570582, 
     0.42802182983801107`}}]}, 
   {Hue[0.020077041352834765`], AbsoluteThickness[0.5], 
    LineBox[{{3.4734619823938733`, 0.14089769316448297`}, {3.605683347230671, 
     0.18786683258680675`}}]}, 
   {Hue[0.02052266309828784], AbsoluteThickness[0.5], 
    LineBox[{{3.605683347230671, 0.18786683258680675`}, {3.910466138693451, 
     0.2894409588183831}}]}, 
   {Hue[0.5708626398935188], AbsoluteThickness[0.5], 
    LineBox[{{3.910466138693451, 0.2894409588183831}, {3.645869735467924, 
     0.10723613865254043`}}]}, 
   {Hue[0.3333093212907748], AbsoluteThickness[0.5], 
    LineBox[{{3.6120315163355317`, -0.007403255310613033}, {
     3.65684057460534, -0.07973818663494281}}]}, 
   {Hue[0.3337824592922127], AbsoluteThickness[0.5], 
    LineBox[{{3.65684057460534, -0.07973818663494281}, {
     3.8237994056141953`, -0.36833687553315786`}}]}, 
   {Hue[0.6465416012287141], AbsoluteThickness[0.5], 
    LineBox[{{3.496421805515521, -0.1742237631012768}, {
     3.418089406844513, -0.24986062330113895`}}]}, 
   {Hue[0.6473001253340117], AbsoluteThickness[0.5], 
    LineBox[{{3.418089406844513, -0.24986062330113895`}, {
     3.2025720961858997`, -0.4288000657059525}}]}, 
   {Hue[0.4568889678429236], AbsoluteThickness[0.5], 
    LineBox[{{2.600353778455782, 0.3562138887118683}, {2.544898308455016, 
     0.38774470255747706`}}]}, 
   {Hue[0.4577811157773892], AbsoluteThickness[0.5], 
    LineBox[{{2.544898308455016, 0.38774470255747706`}, {2.318485121746895, 
     0.5438620701838605}}]}, 
   {Hue[0.6390373692438989], AbsoluteThickness[0.5], 
    LineBox[{{2.2551226669478193`, -1.445284927751419}, {
     1.92963311692479, -1.809779868671608}}]}, 
   {Hue[0.659663240330369], AbsoluteThickness[0.5], 
    LineBox[{{1.92963311692479, -1.809779868671608}, {
     1.8572927721261545`, -1.9718256869889161`}}]}, 
   {Hue[0.5346191470813124], AbsoluteThickness[0.5], 
    LineBox[{{3.061999712864387, -1.6646528560749165`}, {
     3.0915138924470917`, -1.7555144377445904`}}]}, 
   {Hue[0.5716537423416769], AbsoluteThickness[0.5], 
    LineBox[{{3.0915138924470917`, -1.7555144377445904`}, {
     3.1925286556133647`, -1.8823857330101423`}}]}, 
   {Hue[0.691672339984889], AbsoluteThickness[0.5], 
    LineBox[{{3.1925286556133647`, -1.8823857330101423`}, {
     3.352961699215932, -1.8586887614670546`}}]}, 
   {Hue[0.6917810804098597], AbsoluteThickness[0.5], 
    LineBox[{{3.331968753454761, -0.8943418043981085}, {
     3.399365231500996, -0.8810764261276292}}]}, 
   {Hue[0.6927396923504797], AbsoluteThickness[0.5], 
    LineBox[{{3.399365231500996, -0.8810764261276292}, {
     3.67478466887847, -0.8526914170463196}}]}, 
   {Hue[0.5450562253363557], AbsoluteThickness[0.5], 
    LineBox[{{1.8815974727513747`, -2.5922593046853506`}, {
     1.9105000314377572`, -2.876697964114156}}]}, 
   {Hue[0.5464210551528567], AbsoluteThickness[0.5], 
    LineBox[{{1.9105000314377572`, -2.876697964114156}, {
     1.9668586684760148`, -3.133076581221257}}]}, 
   {Hue[0.5200029544693021], AbsoluteThickness[0.5], 
    LineBox[{{3.1382978158283796`, -2.543424692276835}, {
     3.1469819862980706`, -2.603677570784354}}]}, 
   {Hue[0.5205990130244673], AbsoluteThickness[0.5], 
    LineBox[{{3.1469819862980706`, -2.603677570784354}, {
     3.2078155051133845`, -2.905951502787212}}]}, 
   {Hue[0.511523536337414], AbsoluteThickness[0.5], 
    LineBox[{{3.431878604854097, -2.1759189421743104`}, {
     3.657023007734484, -2.188993555662858}}]}, 
   {Hue[0.5119681344775368], AbsoluteThickness[0.5], 
    LineBox[{{3.657023007734484, -2.188993555662858}, {
     3.9224673504585112`, -2.2095089663839724`}}]}, 
   {Hue[0.6113166898323629], AbsoluteThickness[0.5], 
    LineBox[{{3.399182256776903, -1.662057253450502}, {
     3.4091506491479495`, -1.6285692387511952`}}]}, 
   {Hue[0.6119100281313165], AbsoluteThickness[0.5], 
    LineBox[{{3.4091506491479495`, -1.6285692387511952`}, {
     3.5162745890663967`, -1.329886993619515}}]}, 
   {Hue[0.5663858325054203], AbsoluteThickness[0.5], 
    LineBox[{{2.707429285425359, -3.8817823367311504`}, {
     2.8148522483041796`, -3.9552858892109652`}}]}, 
   {Hue[0.5672667440734139], AbsoluteThickness[0.5], 
    LineBox[{{2.8148522483041796`, -3.9552858892109652`}, {
     3.0517514858070856`, -4.089137263205388}}]}, 
   {Hue[0.5192054865662219], AbsoluteThickness[0.5], 
    LineBox[{{2.577214412043428, -0.15865502205992243`}, {
     2.6391651408582075`, -0.1624158472957849}}]}, 
   {Hue[0.5200722775476244], AbsoluteThickness[0.5], 
    LineBox[{{2.6391651408582075`, -0.1624158472957849}, {
     2.8939237855199935`, -0.15629921419047987`}}]}, 
   {Hue[0.4889633654742442], AbsoluteThickness[0.5], 
    LineBox[{{2.914983776499029, -0.3300167990220439}, {
     3.0018042321119895`, -0.20208501236914456`}}]}, 
   {Hue[0.4895262970337474], AbsoluteThickness[0.5], 
    LineBox[{{3.0018042321119895`, -0.20208501236914456`}, {
     3.1818690174757296`, 0.03655437054400782}}]}, 
   {Hue[0.4436663200705143], AbsoluteThickness[0.5], 
    LineBox[{{4.278299163020615, -1.9085210190196962`}, {
     4.348550949237148, -1.9475998853526975`}}]}, 
   {Hue[0.44409615508777217`], AbsoluteThickness[0.5], 
    LineBox[{{4.348550949237148, -1.9475998853526972`}, {
     4.639109351522435, -2.1058768355920874`}}]}, 
   {Hue[0.5436020325929626], AbsoluteThickness[0.5], 
    LineBox[{{3.153408471987272, -0.9337401243996883}, {
     3.151305118618698, -1.0865892566160853`}}]}, 
   {Hue[0.5441577013145511], AbsoluteThickness[0.5], 
    LineBox[{{3.151305118618698, -1.0865892566160853`}, {
     3.1623200033787944`, -1.39998055918835}}]}, 
   {Hue[0.5188598192747139], AbsoluteThickness[0.5], 
    LineBox[{{3.4185949773709208`, -0.17754591810557008`}, {
     3.478151862134879, -0.37331431543868465`}}]}, 
   {Hue[0.5192856787393221], AbsoluteThickness[0.5], 
    LineBox[{{3.478151862134879, -0.3733143154386846}, {
     3.574124515855573, -0.6884149261290209}}]}, 
   {Hue[0.010287476686195706`], AbsoluteThickness[0.5], 
    LineBox[{{3.5920844047750737`, 0.05941005325514018}, {3.632831859405407, 
     0.1233670848035215}}]}, 
   {Hue[0.010844888690809427`], AbsoluteThickness[0.5], 
    LineBox[{{3.632831859405407, 0.1233670848035215}, {3.8097742510123007`, 
     0.37308308047597394`}}]}, 
   {Hue[0.5385514820711623], AbsoluteThickness[0.5], 
    LineBox[{{3.8097742510123007`, 0.37308308047597394`}, {
     3.8283244317125025`, 0.06759563517217518}}]}, 
   {Hue[0.5201894117601441], AbsoluteThickness[0.5], 
    LineBox[{{3.2992593397092693`, 0.037045012371518145`}, {3.189659271666363,
      0.02149313943116333}}]}, 
   {Hue[0.5206808718639772], AbsoluteThickness[0.5], 
    LineBox[{{3.189659271666363, 0.021493139431163315`}, {
     2.880638565505912, -0.03355284722743368}}]}, 
   {Hue[0.5706044990221925], AbsoluteThickness[0.5], 
    LineBox[{{2.8588749051573092`, -0.3950763973452136}, {
     2.715611644604337, -0.5537621304180527}}]}, 
   {Hue[0.573345284433037], AbsoluteThickness[0.5], 
    LineBox[{{2.715611644604337, -0.5537621304180527}, {
     2.533857887329201, -0.6995816385126639}}]}, 
   {Hue[0.5276069726467076], AbsoluteThickness[0.5], 
    LineBox[{{2.227082392631202, -2.866618079254439}, {
     2.2045492007821896`, -2.9508791413346174`}}]}, 
   {Hue[0.5331241545621834], AbsoluteThickness[0.5], 
    LineBox[{{2.2045492007821896`, -2.9508791413346174`}, {
     2.1117957317369798`, -3.133887093760662}}]}, 
   {Hue[0.4855674410349788], AbsoluteThickness[0.5], 
    LineBox[{{2.859720938202348, -3.383065625490599}, {
     2.8507592165571816`, -3.5222248472846185`}}]}, 
   {Hue[0.5654022653425786], AbsoluteThickness[0.5], 
    LineBox[{{2.8507592165571816`, -3.5222248472846185`}, {
     2.905166622587093, -3.667942778133939}}]}, 
   {Hue[0.6269175036118623], AbsoluteThickness[0.5], 
    LineBox[{{2.905166622587093, -3.667942778133939}, {
     3.057478615756991, -3.6994854149692444`}}]}, 
   {Hue[0.6884327418811448], AbsoluteThickness[0.5], 
    LineBox[{{3.057478615756991, -3.6994854149692444`}, {
     3.165283312333833, -3.587360357119154}}]}, 
   {Hue[0.4463612629809218], AbsoluteThickness[0.5], 
    LineBox[{{3.1554957807363624`, -2.1211691387751177`}, {
     3.155828803312165, -2.1234474493940643`}}]}, 
   {Hue[0.44825458066095436`], AbsoluteThickness[0.5], 
    LineBox[{{3.155828803312165, -2.1234474493940643`}, {
     3.2171591548162497`, -2.335604347726556}}]}, 
   {Hue[0.5426970151119044], AbsoluteThickness[0.5], 
    LineBox[{{2.6122527995224583`, -0.24193651118284243`}, {
     2.420172665885642, -0.23195880221600895`}}]}, 
   {Hue[0.5432325003296476], AbsoluteThickness[0.5], 
    LineBox[{{2.420172665885642, -0.23195880221600895`}, {
     2.1179845350488153`, -0.22992047119055006`}}]}, 
   {Hue[0.5673355721229967], AbsoluteThickness[0.5], 
    LineBox[{{3.5386068305073883`, -0.23449542945190396`}, {
     3.4177347101580113`, -0.3162074210647702}}]}, 
   {Hue[0.5688201561749424], AbsoluteThickness[0.5], 
    LineBox[{{3.4177347101580113`, -0.3162074210647702}, {
     3.2001675692989426`, -0.42778729866603715`}}]}, 
   {Hue[0.5544664295287013], AbsoluteThickness[0.5], 
    LineBox[{{4.189225606921999, 0.1435823811863723}, {4.16923866084256, 
     0.1039389196017886}}]}, 
   {Hue[0.5552900036242974], AbsoluteThickness[0.5], 
    LineBox[{{4.16923866084256, 0.1039389196017886}, {
     4.02243613138682, -0.13659880988412862`}}]}, 
   {Hue[0.013626076227412486`], AbsoluteThickness[0.5], 
    LineBox[{{4.451198752175418, 0.3215403316578994}, {4.491445746573083, 
     0.350900497983086}}]}, 
   {Hue[0.014303689697933896`], AbsoluteThickness[0.5], 
    LineBox[{{4.491445746573083, 0.350900497983086}, {4.679116423821506, 
     0.5078582774694631}}]}, 
   {Hue[0.5222762924763102], AbsoluteThickness[0.5], 
    LineBox[{{4.679116423821506, 0.5078582774694631}, {4.438566414851184, 
     0.5524869770310002}}]}, 
   {Hue[0.5554361043083872], AbsoluteThickness[0.5], 
    LineBox[{{4.136896266024384, 0.282644211423682}, {3.92431606735339, 
     0.24906141071967297`}}]}, 
   {Hue[0.5558632698820962], AbsoluteThickness[0.5], 
    LineBox[{{3.92431606735339, 0.24906141071967297`}, {3.604299755622625, 
     0.19683693319168713`}}]}, 
   {Hue[0.5672529584481532], AbsoluteThickness[0.5], 
    LineBox[{{3.587800657812252, -0.3621662821786081}, {
     3.5743201610525532`, -0.3731472771023624}}]}, 
   {Hue[0.5680636000637738], AbsoluteThickness[0.5], 
    LineBox[{{3.5743201610525532`, -0.3731472771023624}, {
     3.36695648301001, -0.5715894043744553}}]}, 
   {Hue[0.5548192591202165], AbsoluteThickness[0.5], 
    LineBox[{{3.3859963571708316`, -0.9925580556527532}, {
     3.3400405699881848`, -1.135952494431891}}]}, 
   {Hue[0.5555956964333645], AbsoluteThickness[0.5], 
    LineBox[{{3.3400405699881848`, -1.135952494431891}, {
     3.229840200074263, -1.4064747617511333`}}]}, 
   {Hue[0.4080204800463095], AbsoluteThickness[0.5], 
    LineBox[{{3.3986537858289845`, -3.39250140844713}, {
     3.3997236315803296`, -3.4060877155903695`}}]}, 
   {Hue[0.41386029527284907`], AbsoluteThickness[0.5], 
    LineBox[{{3.3997236315803296`, -3.4060877155903695`}, {
     3.452333541529669, -3.5821323194895625`}}]}, 
   {Hue[0.46131844884238676`], AbsoluteThickness[0.5], 
    LineBox[{{3.638814938514066, -3.0083234107732495`}, {
     3.7868950477920436`, -3.135515018873259}}]}, 
   {Hue[0.46299551701961983`], AbsoluteThickness[0.5], 
    LineBox[{{3.7868950477920436`, -3.135515018873259}, {
     3.9392658844890005`, -3.3048583850086404`}}]}, 
   {Hue[0.6648853323944861], AbsoluteThickness[0.5], 
    LineBox[{{2.2511803257171965`, -3.3556638132052425`}, {
     2.235412780993065, -3.548855100504918}}]}, 
   {Hue[0.6653130591546318], AbsoluteThickness[0.5], 
    LineBox[{{2.235412780993065, -3.548855100504918}, {
     2.2076330665813475`, -3.8654870271013904`}}]}, 
   {Hue[0.5559101340052701], AbsoluteThickness[0.5], 
    LineBox[{{3.7744662660850783`, -2.88816480877091}, {
     3.9288710969867626`, -2.9536940654314097`}}]}, 
   {Hue[0.5564018545011649], AbsoluteThickness[0.5], 
    LineBox[{{3.9288710969867626`, -2.9536940654314097`}, {
     4.170448244085874, -3.0664676686108665`}}]}, 
   {Hue[0.24771787007943272`], AbsoluteThickness[0.5], 
    LineBox[{{3.927010759369448, 0.22967457459770826`}, {4.140297146276947, 
     0.30199264671073334`}}]}, 
   {Hue[0.2484744897035916], AbsoluteThickness[0.5], 
    LineBox[{{4.140297146276947, 0.30199264671073334`}, {4.419188767958661, 
     0.37383802081098927`}}]}, 
   {Hue[0.5713473955737366], AbsoluteThickness[0.5], 
    LineBox[{{2.6229656444915594`, 0.4622814603253479}, {2.6305731596590065`, 
     0.3842130964849716}}]}, 
   {Hue[0.5720623700255906], AbsoluteThickness[0.5], 
    LineBox[{{2.6305731596590065`, 0.3842130964849716}, {2.6835407204020045`, 
     0.07116935316632464}}]}, 
   {Hue[0.5662260850818902], AbsoluteThickness[0.5], 
    LineBox[{{2.5190155640516547`, 1.3192919797885094`}, {2.58604087321451, 
     1.197525685617465}}]}, 
   {Hue[0.5754505682575936], AbsoluteThickness[0.5], 
    LineBox[{{2.58604087321451, 1.197525685617465}, {2.7220540537297215`, 
     1.0510779131648766`}}]}, 
   {Hue[0.026543552379027013`], AbsoluteThickness[0.5], 
    LineBox[{{2.5274721935336997`, 1.6522551607798501`}, {2.525666926114915, 
     1.8393658891128908`}}]}, 
   {Hue[0.02707646443220094], AbsoluteThickness[0.5], 
    LineBox[{{2.525666926114915, 1.8393658891128908`}, {2.5116464490997754`, 
     2.097330053094283}}]}, 
   {Hue[0.5593270543369641], AbsoluteThickness[0.5], 
    LineBox[{{2.5116464490997754`, 2.097330053094283}, {2.373278637298292, 
     1.8791639871453822`}}]}, 
   {Hue[0.5672068188551722], AbsoluteThickness[0.5], 
    LineBox[{{2.362286154398631, 1.363032812139679}, {2.3545372197557013`, 
     1.3482887036007936`}}]}, 
   {Hue[0.5676722743449911], AbsoluteThickness[0.5], 
    LineBox[{{2.3545372197557013`, 1.3482887036007936`}, {2.1952462708023224`,
      1.0645318019648047`}}]}, 
   {Hue[0.5668404621746118], AbsoluteThickness[0.5], 
    LineBox[{{2.238090115491296, 0.6844720603887963}, {2.1358764615667534`, 
     0.5339448048795937}}]}, 
   {Hue[0.5673340195725408], AbsoluteThickness[0.5], 
    LineBox[{{2.1358764615667534`, 0.5339448048795937}, {1.998089003311542, 
     0.3459091668849209}}]}, 
   {Hue[0.5734274489022101], AbsoluteThickness[0.5], 
    LineBox[{{2.89638267856279, -0.3415053201818803}, {
     2.8971659229120377`, -0.34365007206001763`}}]}, 
   {Hue[0.5739748007651297], AbsoluteThickness[0.5], 
    LineBox[{{2.8971659229120377`, -0.34365007206001763`}, {
     3.012075970114718, -0.6173130058377834}}]}, 
   {Hue[0.5335643461681223], AbsoluteThickness[0.5], 
    LineBox[{{3.344514968547143, -0.878934029713486}, {
     3.3825787474244895`, -0.9382776546251114}}]}, 
   {Hue[0.5355864928900224], AbsoluteThickness[0.5], 
    LineBox[{{3.3825787474244895`, -0.9382776546251114}, {
     3.538629961930491, -1.119527568675636}}]}, 
   {Hue[0.6432491110386221], AbsoluteThickness[0.5], 
    LineBox[{{2.8504652200761806`, 1.372392023126388}, {2.8496209452056838`, 
     1.4014845681220502`}}]}, 
   {Hue[0.6458371699515549], AbsoluteThickness[0.5], 
    LineBox[{{2.8496209452056838`, 1.4014845681220502`}, {2.8800906107945172`,
      1.6391180130300818`}}]}, 
   {Hue[0.5291907968852703], AbsoluteThickness[0.5], 
    LineBox[{{3.478832091460528, 0.14004554789968798`}, {3.6034414316840495`, 
     0.22858257032194945`}}]}, 
   {Hue[0.5302195394008777], AbsoluteThickness[0.5], 
    LineBox[{{3.6034414316840495`, 0.22858257032194945`}, {3.836881639250934, 
     0.36264553007671096`}}]}, 
   {Hue[0.28784733097553944`], AbsoluteThickness[0.5], 
    LineBox[{{3.84593915521684, -0.34388859709146324`}, {
     3.9021002567403578`, -0.3611816436730201}}]}, 
   {Hue[0.289054306206907], AbsoluteThickness[0.5], 
    LineBox[{{3.9021002567403578`, -0.3611816436730201}, {
     4.127796544945433, -0.4581484890887056}}]}, 
   {Hue[0.5470836797737041], AbsoluteThickness[0.5], 
    LineBox[{{3.426936758056564, -0.6619390802441175}, {
     3.4622144262913097`, -0.8137954128171471}}]}, 
   {Hue[0.5475875602974173], AbsoluteThickness[0.5], 
    LineBox[{{3.4622144262913097`, -0.8137954128171471}, {
     3.5457773299901305`, -1.1197004300454954`}}]}, 
   {Hue[0.5703088300318641], AbsoluteThickness[0.5], 
    LineBox[{{2.8143653596071507`, -0.4005111305119663}, {
     2.8073012553122583`, -0.6267619130911182}}]}, 
   {Hue[0.5707432951756204], AbsoluteThickness[0.5], 
    LineBox[{{2.8073012553122583`, -0.6267619130911182}, {
     2.794553200267312, -0.9148994300438171}}]}, 
   {Hue[0.48109063544893593`], AbsoluteThickness[0.5], 
    LineBox[{{3.192984939731563, 0.9493920790979014}, {3.5991312609422605`, 
     0.7978049798125796}}]}, 
   {Hue[0.4815865716399152], AbsoluteThickness[0.5], 
    LineBox[{{3.5991312609422605`, 0.7978049798125796}, {3.887695862273753, 
     0.701936724053574}}]}, 
   {Hue[0.45893832404571155`], AbsoluteThickness[0.5], 
    LineBox[{{2.869328094565325, 1.3793299916882624`}, {2.8394923350469017`, 
     1.3785091072071007`}}]}, 
   {Hue[0.46324355705247616`], AbsoluteThickness[0.5], 
    LineBox[{{2.8394923350469017`, 1.3785091072071007`}, {2.621312545441995, 
     1.3301671624071878`}}]}, 
   {Hue[0.02459895306703473], AbsoluteThickness[0.5], 
    LineBox[{{2.8928937953556026`, 1.6484318801272975`}, {2.9002177191131056`,
      1.6840788697388607`}}]}, 
   {Hue[0.030833013043631584`], AbsoluteThickness[0.5], 
    LineBox[{{2.9002177191131056`, 1.6840788697388607`}, {2.897632969309187, 
     1.870823864614971}}]}, 
   {Hue[0.3166154311048215], AbsoluteThickness[0.5], 
    LineBox[{{2.897632969309187, 1.870823864614971}, {2.7174256772008842`, 
     1.9198718606374405`}}]}, 
   {Hue[0.6023978491660122], AbsoluteThickness[0.5], 
    LineBox[{{2.7174256772008842`, 1.9198718606374405`}, {2.620553822944589, 
     1.7601965090775502`}}]}, 
   {Hue[0.46167509663984263`], AbsoluteThickness[0.5], 
    LineBox[{{3.1495247004763645`, 1.5641007046813786`}, {3.323394845154216, 
     1.4837742649795072`}}]}, 
   {Hue[0.4623302479141566], AbsoluteThickness[0.5], 
    LineBox[{{3.323394845154216, 1.4837742649795072`}, {3.5616347332862177`, 
     1.3915767758856412`}}]}, 
   {Hue[0.48369098450334175`], AbsoluteThickness[0.5], 
    LineBox[{{2.1244601508959042`, 1.1100541105675477`}, {2.1211424270745507`,
      1.1091844719227275`}}]}, 
   {Hue[0.48429448761114213`], AbsoluteThickness[0.5], 
    LineBox[{{2.1211424270745507`, 1.1091844719227275`}, {1.8231434831868973`,
      1.012769170053058}}]}, 
   {Hue[0.5654440998038576], AbsoluteThickness[0.5], 
    LineBox[{{3.3592112532337337`, -1.31764649686781}, {
     3.384127692957319, -1.3992191296883587`}}]}, 
   {Hue[0.5663503119605681], AbsoluteThickness[0.5], 
    LineBox[{{3.384127692957319, -1.3992191296883587`}, {
     3.4929405491548646`, -1.668357992992246}}]}, 
   {Hue[0.5114537535645272], AbsoluteThickness[0.5], 
    LineBox[{{4.14627945721463, -0.08460633810639392}, {
     4.16399499970387, -0.09317544188177346}}]}, 
   {Hue[0.5121429243504692], AbsoluteThickness[0.5], 
    LineBox[{{4.16399499970387, -0.09317544188177349}, {
     4.4433252556650915`, -0.25241760238014127`}}]}, 
   {Hue[0.6277395996097399], AbsoluteThickness[0.5], 
    LineBox[{{2.613886922866226, -0.27473584047618027`}, {
     2.603878533203422, -0.37097773320509236`}}]}, 
   {Hue[0.6282087423036183], AbsoluteThickness[0.5], 
    LineBox[{{2.603878533203422, -0.37097773320509236`}, {
     2.56006851440558, -0.6997133715511978}}]}, 
   {Hue[0.5189813525663695], AbsoluteThickness[0.5], 
    LineBox[{{3.151290158714302, 1.3241109832553086`}, {3.040291686765865, 
     1.3403715354783214`}}]}, 
   {Hue[0.5244050236328072], AbsoluteThickness[0.5], 
    LineBox[{{3.040291686765865, 1.3403715354783214`}, {2.8414852280782195`, 
     1.4134018512065536`}}]}, 
   {Hue[0.3743510073416967], AbsoluteThickness[0.5], 
    LineBox[{{3.869537641731128, 1.5169449025453825`}, {3.8263989900674567`, 
     1.6267588833981}}]}, 
   {Hue[0.37477731459618846`], AbsoluteThickness[0.5], 
    LineBox[{{3.8263989900674567`, 1.6267588833981}, {3.7083505205399137`, 
     1.9299240407323592`}}]}, 
   {Hue[0.0447893708561334], AbsoluteThickness[0.5], 
    LineBox[{{4.0176555195281995`, 1.6425043602294702`}, {4.12603715712162, 
     1.7049389357979698`}}]}, 
   {Hue[0.045262454450213714`], AbsoluteThickness[0.5], 
    LineBox[{{4.12603715712162, 1.7049389357979698`}, {4.41268226628067, 
     1.858757923562918}}]}, 
   {Hue[0.5895542854595602], AbsoluteThickness[0.5], 
    LineBox[{{4.41268226628067, 1.858757923562918}, {4.215473890714598, 
     1.6000407880491905`}}]}, 
   {Hue[0.381781959831547], AbsoluteThickness[0.5], 
    LineBox[{{4.16372465786189, 1.5145673055366111`}, {4.233381405410529, 
     1.4268166717424287`}}]}, 
   {Hue[0.3825094257049792], AbsoluteThickness[0.5], 
    LineBox[{{4.233381405410529, 1.4268166717424287`}, {4.39255822188669, 
     1.193722465874306}}]}, 
   {Hue[0.5207477544528715], AbsoluteThickness[0.5], 
    LineBox[{{4.068248954316944, 0.887085742021447}, {4.107374648939192, 
     0.8056400500151667}}]}, 
   {Hue[0.5219569788542839], AbsoluteThickness[0.5], 
    LineBox[{{4.107374648939192, 0.8056400500151667}, {4.247308564901417, 
     0.5799640293755455}}]}, 
   {Hue[0.64391597187834], AbsoluteThickness[0.5], 
    LineBox[{{3.0363891395748825`, 0.3883294202184459}, {2.8734748785572934`, 
     0.3522150082731187}}]}, 
   {Hue[0.6445393795708293], AbsoluteThickness[0.5], 
    LineBox[{{2.8734748785572934`, 0.3522150082731187}, {2.55913678640031, 
     0.2626654894058446}}]}, 
   {Hue[0.6012666994401065], AbsoluteThickness[0.5], 
    LineBox[{{3.145078508779958, -1.606459745483055}, {
     3.1454442132364955`, -1.6087376243191693`}}]}, 
   {Hue[0.6020173182568277], AbsoluteThickness[0.5], 
    LineBox[{{3.1454442132364955`, -1.6087376243191693`}, {
     3.211984839798013, -1.888680270946711}}]}, 
   {Hue[0.6788968578610654], AbsoluteThickness[0.5], 
    LineBox[{{2.7208725285273085`, 0.4177945893282545}, {2.6778761239829936`, 
     0.5743237131638527}}]}, 
   {Hue[0.6802398630167784], AbsoluteThickness[0.5], 
    LineBox[{{2.6778761239829936`, 0.5743237131638527}, {2.6381005443934678`, 
     0.8305544737935947}}]}, 
   {Hue[0.2893288814939959], AbsoluteThickness[0.5], 
    LineBox[{{3.8737988550753357`, -0.28626296812140356`}, {
     4.087238682039786, -0.24638792188844788`}}]}, 
   {Hue[0.28977150114443795`], AbsoluteThickness[0.5], 
    LineBox[{{4.087238682039786, -0.24638792188844788`}, {
     4.435993113235755, -0.18774450835425613`}}]}, 
   {Hue[0.6833752366025225], AbsoluteThickness[0.5], 
    LineBox[{{3.207228918527008, -1.4074149941880651`}, {
     3.242702585974599, -1.5690451443041322`}}]}, 
   {Hue[0.6838202130609511], AbsoluteThickness[0.5], 
    LineBox[{{3.242702585974599, -1.5690451443041322`}, {
     3.305613394973361, -1.8846879681162658`}}]}, 
   {Hue[0.6222941737299366], AbsoluteThickness[0.5], 
    LineBox[{{3.2219270916722413`, 0.8692737186548891}, {3.3801723148727585`, 
     1.175502412355479}}]}, 
   {Hue[0.633475867925141], AbsoluteThickness[0.5], 
    LineBox[{{3.3801723148727585`, 1.175502412355479}, {3.4137418567264928`, 
     1.3277827479139734`}}]}, 
   {Hue[0.4536732858795807], AbsoluteThickness[0.5], 
    LineBox[{{3.046543546294097, -1.6685098208109015`}, {
     3.0380715622980987`, -1.868510491920111}}]}, 
   {Hue[0.45410631256737116`], AbsoluteThickness[0.5], 
    LineBox[{{3.0380715622980987`, -1.868510491920111}, {
     3.028966809539099, -2.167294680308658}}]}, 
   {Hue[0.3631102664271356], AbsoluteThickness[0.5], 
    LineBox[{{3.6352167805309112`, -1.6272022365978587`}, {
     3.7107691049818214`, -1.655785496560136}}]}, 
   {Hue[0.37778945283883214`], AbsoluteThickness[0.5], 
    LineBox[{{3.7107691049818214`, -1.655785496560136}, {
     3.827064209344114, -1.7429276520568864`}}]}, 
   {Hue[0.5809115011344681], AbsoluteThickness[0.5], 
    LineBox[{{3.827064209344114, -1.7429276520568864`}, {
     3.796591792647296, -1.88501825126708}}]}, 
   {Hue[0.5090562590842758], AbsoluteThickness[0.5], 
    LineBox[{{4.099473804110332, -0.8752073248857024}, {
     4.140200229009566, -0.8558566167056519}}]}, 
   {Hue[0.5094905671370583], AbsoluteThickness[0.5], 
    LineBox[{{4.140200229009566, -0.8558566167056519}, {
     4.416120584123474, -0.7203717836964305}}]}, 
   {Hue[0.6572642015991426], AbsoluteThickness[0.5], 
    LineBox[{{3.294922024812482, -0.6475018076629606}, {
     3.216010973702181, -0.43363491756266437`}}]}, 
   {Hue[0.6582027685843069], AbsoluteThickness[0.5], 
    LineBox[{{3.216010973702181, -0.43363491756266437`}, {
     3.1462584637628876`, -0.1748549137669631}}]}, 
   {Hue[0.5849868706044737], AbsoluteThickness[0.5], 
    LineBox[{{2.21495956084175, -1.8512085832635357`}, {
     2.2913976423613227`, -2.067703388354433}}]}, 
   {Hue[0.5855669122346896], AbsoluteThickness[0.5], 
    LineBox[{{2.2913976423613227`, -2.067703388354433}, {
     2.3811745057225373`, -2.3725188892010487`}}]}, 
   {Hue[0.4339563497246389], AbsoluteThickness[0.5], 
    LineBox[{{2.9795838196579805`, 1.1600955982182852`}, {3.074333893331677, 
     1.3554855059744109`}}]}, 
   {Hue[0.43675831850250746`], AbsoluteThickness[0.5], 
    LineBox[{{3.074333893331677, 1.3554855059744109`}, {3.1418295240649248`, 
     1.5818545700189248`}}]}, 
   {Hue[0.4773559689716919], AbsoluteThickness[0.5], 
    LineBox[{{4.100012932166327, 0.17053757223385108`}, {4.154517626684406, 
     0.18844261972516752`}}]}, 
   {Hue[0.4778030851568291], AbsoluteThickness[0.5], 
    LineBox[{{4.154517626684406, 0.18844261972516752`}, {4.4586423288574695`, 
     0.2952551212334307}}]}, 
   {Hue[0.5030254831806958], AbsoluteThickness[0.5], 
    LineBox[{{3.9157900243279067`, -2.260122605467422}, {
     3.94246457314049, -2.324282050790346}}]}, 
   {Hue[0.5034748660284717], AbsoluteThickness[0.5], 
    LineBox[{{3.94246457314049, -2.324282050790346}, {
     4.060103597551317, -2.6252473885157794`}}]}, 
   {Hue[0.5441605916167342], AbsoluteThickness[0.5], 
    LineBox[{{2.8177681146040965`, -2.3332792196585226`}, {
     2.7181948909947153`, -2.5780482404519205`}}]}, 
   {Hue[0.5449133260623089], AbsoluteThickness[0.5], 
    LineBox[{{2.7181948909947153`, -2.5780482404519205`}, {
     2.6240995773547167`, -2.8698136702390324`}}]}, 
   {Hue[0.6295075839316476], AbsoluteThickness[0.5], 
    LineBox[{{2.505931481764063, 1.086435695772909}, {2.5633682056566798`, 
     1.335975214086874}}]}, 
   {Hue[0.63064403050699], AbsoluteThickness[0.5], 
    LineBox[{{2.5633682056566798`, 1.335975214086874}, {2.597668256400706, 
     1.6131473693318668`}}]}, 
   {Hue[0.6487135226294192], AbsoluteThickness[0.5], 
    LineBox[{{3.9245568350508115`, 0.24784004974204057`}, {4.145653198580038, 
     0.31983977596908175`}}]}, 
   {Hue[0.6496760510181068], AbsoluteThickness[0.5], 
    LineBox[{{4.145653198580038, 0.31983977596908175`}, {4.412863363736051, 
     0.3804060963692818}}]}, 
   {Hue[0.6902695574880978], AbsoluteThickness[0.5], 
    LineBox[{{4.999869176008277, -2.1445618882550104`}, {
     5.058057853142013, -2.1805074094089347`}}]}, 
   {Hue[0.6907369653935619], AbsoluteThickness[0.5], 
    LineBox[{{5.058057853142013, -2.1805074094089347`}, {
     5.3459175401646295`, -2.3472665439365543`}}]}, 
   {Hue[0.569771347541975], AbsoluteThickness[0.5], 
    LineBox[{{2.793195593260454, -2.9158752729448443`}, {
     2.8402603199053207`, -2.94584379751289}}]}, 
   {Hue[0.5702462224610031], AbsoluteThickness[0.5], 
    LineBox[{{2.8402603199053207`, -2.94584379751289}, {
     3.131353864412593, -3.118886128685371}}]}, 
   {Hue[0.5500009660280872], AbsoluteThickness[0.5], 
    LineBox[{{2.1058929305551946`, -3.8227216982079804`}, {
     2.115900187673482, -3.850890074542464}}]}, 
   {Hue[0.5522527357120861], AbsoluteThickness[0.5], 
    LineBox[{{2.115900187673482, -3.850890074542464}, {
     2.1620289508920636`, -4.085822768339576}}]}, 
   {Hue[0.5300852491479159], AbsoluteThickness[0.5], 
    LineBox[{{2.270626372471267, -1.442712640458672}, {
     2.194641816608529, -1.5856040192138983`}}]}, 
   {Hue[0.5335606175460874], AbsoluteThickness[0.5], 
    LineBox[{{2.194641816608529, -1.5856040192138983`}, {
     2.1342470320728197`, -1.7724063352853814`}}]}, 
   {Hue[0.4570882096358359], AbsoluteThickness[0.5], 
    LineBox[{{3.2348264890996035`, -0.9445047322878591}, {
     3.27366435617465, -1.0872513778660908`}}]}, 
   {Hue[0.45801376309859565`], AbsoluteThickness[0.5], 
    LineBox[{{3.27366435617465, -1.0872513778660908`}, {
     3.323097674527077, -1.3645395799561744`}}]}, 
   {Hue[0.3247856261505185], AbsoluteThickness[0.5], 
    LineBox[{{3.240666333570582, 0.42802182983801107`}, {3.211886925183049, 
     0.5878660923956758}}]}, 
   {Hue[0.3255545185403171], AbsoluteThickness[0.5], 
    LineBox[{{3.211886925183049, 0.5878660923956758}, {3.184902846418019, 
     0.8510628972631865}}]}, 
   {Hue[0.5704170181480676], AbsoluteThickness[0.5], 
    LineBox[{{3.605683347230671, 0.18786683258680675`}, {3.3795498013047305`, 
     0.18318466491383734`}}]}, 
   {Hue[0.5711323728233285], AbsoluteThickness[0.5], 
    LineBox[{{3.3795498013047305`, 0.18318466491383734`}, {
     3.0861107801812167`, 0.1978137772289844}}]}, 
   {Hue[0.020968284843740914`], AbsoluteThickness[0.5], 
    LineBox[{{3.910466138693451, 0.2894409588183831}, {4.177108797616254, 
     0.37252389696259214`}}]}, 
   {Hue[0.024508474303225322`], AbsoluteThickness[0.5], 
    LineBox[{{4.177108797616254, 0.37252389696259214`}, {4.389842820438779, 
     0.39920784432087075`}}]}, 
   {Hue[0.3663126314483891], AbsoluteThickness[0.5], 
    LineBox[{{4.389842820438779, 0.39920784432087075`}, {4.444755429037103, 
     0.19195822929155187`}}]}, 
   {Hue[0.5713082616389717], AbsoluteThickness[0.5], 
    LineBox[{{3.645869735467924, 0.10723613865254043`}, {3.58679616480224, 
     0.06824468463562373}}]}, 
   {Hue[0.5717342268816012], AbsoluteThickness[0.5], 
    LineBox[{{3.58679616480224, 0.06824468463562373}, {
     3.3167401095728355`, -0.10943190677588277`}}]}, 
   {Hue[0.3342555972936505], AbsoluteThickness[0.5], 
    LineBox[{{3.8237994056141953`, -0.3683368755331578}, {
     3.848361974809687, -0.4139101554191172}}]}, 
   {Hue[0.3349656670906626], AbsoluteThickness[0.5], 
    LineBox[{{3.848361974809687, -0.4139101554191172}, {
     3.99486063570663, -0.6453738136913714}}]}, 
   {Hue[0.6480586494393094], AbsoluteThickness[0.5], 
    LineBox[{{3.2025720961858997`, -0.4288000657059525}, {
     3.157785145408415, -0.46063700246368344`}}]}, 
   {Hue[0.6489137715473159], AbsoluteThickness[0.5], 
    LineBox[{{3.157785145408415, -0.46063700246368344`}, {
     2.9253258579521546`, -0.598183602704985}}]}, 
   {Hue[0.4586732637118548], AbsoluteThickness[0.5], 
    LineBox[{{2.318485121746895, 0.5438620701838605}, {1.9675695668716078`, 
     0.8336776082814037}}]}, 
   {Hue[0.46210786748500915`], AbsoluteThickness[0.5], 
    LineBox[{{1.9675695668716078`, 0.8336776082814037}, {1.8227475357554996`, 
     1.0038036995552715`}}]}, 
   {Hue[0.6546377447245249], AbsoluteThickness[0.5], 
    LineBox[{{3.0915138924470917`, -1.7555144377445904`}, {
     3.0898137820951135`, -1.8747269863411415`}}]}, 
   {Hue[0.6551271706766698], AbsoluteThickness[0.5], 
    LineBox[{{3.0898137820951135`, -1.8747269863411415`}, {
     3.0755426109860546`, -2.165428119223086}}]}, 
   {Hue[0.6086883376020414], AbsoluteThickness[0.5], 
    LineBox[{{3.1925286556133647`, -1.8823857330101423`}, {
     3.383250355716764, -1.996718530527269}}]}, 
   {Hue[0.609523240987575], AbsoluteThickness[0.5], 
    LineBox[{{3.383250355716764, -1.996718530527269}, {
     3.5925917171879176`, -2.0999316923453533`}}]}, 
   {Hue[0.6936983042910998], AbsoluteThickness[0.5], 
    LineBox[{{3.67478466887847, -0.8526914170463196}, {
     3.69379332041341, -0.8524812656894527}}]}, 
   {Hue[0.6957407501531171], AbsoluteThickness[0.5], 
    LineBox[{{3.69379332041341, -0.8524812656894527}, {
     3.9131313759086774`, -0.8188344074398776}}]}, 
   {Hue[0.5477858849693575], AbsoluteThickness[0.5], 
    LineBox[{{1.9668586684760148`, -3.133076581221257}, {
     2.0361920733606826`, -3.3345069359806834`}}]}, 
   {Hue[0.5487237487780312], AbsoluteThickness[0.5], 
    LineBox[{{2.0361920733606826`, -3.3345069359806834`}, {
     2.1004892235165156`, -3.595703002301458}}]}, 
   {Hue[0.5211950715796324], AbsoluteThickness[0.5], 
    LineBox[{{3.2078155051133845`, -2.905951502787212}, {
     3.2689025253677793`, -3.1412019680674934`}}]}, 
   {Hue[0.5216545565149165], AbsoluteThickness[0.5], 
    LineBox[{{3.2689025253677793`, -3.1412019680674934`}, {
     3.3382291948537137`, -3.4392422003448613`}}]}, 
   {Hue[0.5124127326176595], AbsoluteThickness[0.5], 
    LineBox[{{3.9224673504585112`, -2.2095089663839724`}, {
     4.076724109865788, -2.224403826434102}}]}, 
   {Hue[0.5128464268161476], AbsoluteThickness[0.5], 
    LineBox[{{4.076724109865788, -2.224403826434102}, {
     4.3991567350297, -2.2515038417660493`}}]}, 
   {Hue[0.6125033664302701], AbsoluteThickness[0.5], 
    LineBox[{{3.5162745890663967`, -1.329886993619515}, {
     3.6105276280677896`, -1.1065909349393204`}}]}, 
   {Hue[0.6139433369123835], AbsoluteThickness[0.5], 
    LineBox[{{3.6105276280677896`, -1.1065909349393204`}, {
     3.6812551840616616`, -0.8613794860116978}}]}, 
   {Hue[0.5681476556414075], AbsoluteThickness[0.5], 
    LineBox[{{3.0517514858070856`, -4.089137263205388}, {
     3.1704096458448334`, -4.143344125709102}}]}, 
   {Hue[0.5686133272369259], AbsoluteThickness[0.5], 
    LineBox[{{3.1704096458448334`, -4.143344125709102}, {
     3.4522368339784095`, -4.281655564912378}}]}, 
   {Hue[0.5209390685290269], AbsoluteThickness[0.5], 
    LineBox[{{2.8939237855199935`, -0.15629921419047987`}, {
     2.9215148336319983`, -0.15328981470129202`}}]}, 
   {Hue[0.5220771571819345], AbsoluteThickness[0.5], 
    LineBox[{{2.9215148336319983`, -0.15328981470129202`}, {
     3.1639291432910492`, -0.15197113218618075`}}]}, 
   {Hue[0.4900892285932506], AbsoluteThickness[0.5], 
    LineBox[{{3.1818690174757296`, 0.036554370544007786`}, {3.234617772047323,
      0.09961891987857258}}]}, 
   {Hue[0.49154367757936324`], AbsoluteThickness[0.5], 
    LineBox[{{3.234617772047323, 0.09961891987857258}, {3.400519433396651, 
     0.2557260231799236}}]}, 
   {Hue[0.44452599010503013`], AbsoluteThickness[0.5], 
    LineBox[{{4.639109351522435, -2.1058768355920874`}, {
     4.687282570207236, -2.131568067948035}}]}, 
   {Hue[0.4451527392053662], AbsoluteThickness[0.5], 
    LineBox[{{4.687282570207236, -2.131568067948035}, {
     4.917632112659011, -2.272725531566585}}]}, 
   {Hue[0.5447133700361395], AbsoluteThickness[0.5], 
    LineBox[{{3.1623200033787944`, -1.39998055918835}, {
     3.1665918981940973`, -1.4507010352132959`}}]}, 
   {Hue[0.5598264890808399], AbsoluteThickness[0.5], 
    LineBox[{{3.1665918981940973`, -1.4507010352132959`}, {
     3.131942390823277, -1.6219057338879679`}}]}, 
   {Hue[0.5197115382039301], AbsoluteThickness[0.5], 
    LineBox[{{3.574124515855573, -0.6884149261290209}, {
     3.6091511002407173`, -0.803280835183382}}]}, 
   {Hue[0.5207406146542497], AbsoluteThickness[0.5], 
    LineBox[{{3.6091511002407173`, -0.803280835183382}, {
     3.6632365107472387`, -1.0707671721118366`}}]}, 
   {Hue[0.5379940700665482], AbsoluteThickness[0.5], 
    LineBox[{{3.632831859405407, 0.1233670848035215}, {3.5541898582113727`, 
     0.10511668094632262`}}]}, 
   {Hue[0.5389211597482667], AbsoluteThickness[0.5], 
    LineBox[{{3.5541898582113727`, 0.10511668094632262`}, {
     3.2938941600275777`, 0.019615869514447506`}}]}, 
   {Hue[0.011402300695422918`], AbsoluteThickness[0.5], 
    LineBox[{{3.8097742510123007`, 0.37308308047597394`}, {3.866063410878982, 
     0.44476987700159554`}}]}, 
   {Hue[0.0118786341452486], AbsoluteThickness[0.5], 
    LineBox[{{3.866063410878982, 0.44476987700159554`}, {4.073134215022028, 
     0.6922309535190612}}]}, 
   {Hue[0.555478132418322], AbsoluteThickness[0.5], 
    LineBox[{{4.073134215022028, 0.6922309535190612}, {3.991346857638227, 
     0.38009936189173915`}}]}, 
   {Hue[0.5391088940757759], AbsoluteThickness[0.5], 
    LineBox[{{3.8283244317125025`, 0.06759563517217512}, {
     3.830499715660793, -0.1223910623082743}}]}, 
   {Hue[0.5405613195400433], AbsoluteThickness[0.5], 
    LineBox[{{3.830499715660793, -0.12239106230827432`}, {
     3.8020944026519126`, -0.3850992987841766}}]}, 
   {Hue[0.5211723319678102], AbsoluteThickness[0.5], 
    LineBox[{{2.880638565505912, -0.03355284722743368}, {
     2.642797676487066, -0.08464662578728467}}]}, 
   {Hue[0.5220928278191752], AbsoluteThickness[0.5], 
    LineBox[{{2.642797676487066, -0.08464662578728467}, {
     2.3521572266955513`, -0.12050669947120973`}}]}, 
   {Hue[0.5760860698438817], AbsoluteThickness[0.5], 
    LineBox[{{2.533857887329201, -0.6995816385126639}, {
     2.3455788186223403`, -0.8063462828362743}}]}, 
   {Hue[0.5854919033085256], AbsoluteThickness[0.5], 
    LineBox[{{2.3455788186223403`, -0.8063462828362743}, {
     2.164271473251518, -0.8563454532950882}}]}, 
   {Hue[0.5386413364776593], AbsoluteThickness[0.5], 
    LineBox[{{2.1117957317369798`, -3.133887093760662}, {
     1.9546839175193478`, -3.3294168773444395`}}]}, 
   {Hue[0.5404954589128528], AbsoluteThickness[0.5], 
    LineBox[{{1.9546839175193478`, -3.3294168773444395`}, {
     1.833404308771588, -3.5308427605743136`}}]}, 
   {Hue[0.547082679304263], AbsoluteThickness[0.5], 
    LineBox[{{2.8507592165571816`, -3.5222248472846185`}, {
     2.8328106739363874`, -3.5987964877198864`}}]}, 
   {Hue[0.5476177549148398], AbsoluteThickness[0.5], 
    LineBox[{{2.8328106739363874`, -3.5987964877198864`}, {
     2.751560304362209, -3.88641543413201}}]}, 
   {Hue[0.6452370896501792], AbsoluteThickness[0.5], 
    LineBox[{{2.905166622587093, -3.667942778133939}, {
     3.043684583412172, -3.8082445775426264`}}]}, 
   {Hue[0.6560538822462082], AbsoluteThickness[0.5], 
    LineBox[{{3.043684583412172, -3.8082445775426264`}, {
     3.1320904881121656`, -3.9620866166193007`}}]}, 
   {Hue[0.45014789834098684`], AbsoluteThickness[0.5], 
    LineBox[{{3.2171591548162497`, -2.335604347726556}, {
     3.3401631984443028`, -2.612773958226143}}]}, 
   {Hue[0.4548309829994654], AbsoluteThickness[0.5], 
    LineBox[{{3.3401631984443028`, -2.612773958226143}, {
     3.3859282651490497`, -2.816148881436383}}]}, 
   {Hue[0.570304740226888], AbsoluteThickness[0.5], 
    LineBox[{{3.2001675692989426`, -0.42778729866603715`}, {
     3.1568373392507523`, -0.44376646968804306`}}]}, 
   {Hue[0.5707776726599273], AbsoluteThickness[0.5], 
    LineBox[{{3.1568373392507523`, -0.44376646968804306`}, {
     2.866355509659457, -0.541071272361659}}]}, 
   {Hue[0.5561135777198933], AbsoluteThickness[0.5], 
    LineBox[{{4.02243613138682, -0.13659880988412865`}, {
     3.546531309648815, -0.7907490469872884}}]}, 
   {Hue[0.5569915439739824], AbsoluteThickness[0.5], 
    LineBox[{{3.546531309648815, -0.7907490469872884}, {
     3.400756430162679, -1.0320658062009593`}}]}, 
   {Hue[0.5215986790057907], AbsoluteThickness[0.5], 
    LineBox[{{4.491445746573083, 0.350900497983086}, {4.503696613820916, 
     0.18089384505599004`}}]}, 
   {Hue[0.5220522688818204], AbsoluteThickness[0.5], 
    LineBox[{{4.503696613820916, 0.18089384505599004`}, {
     4.532373323050984, -0.11959928933343514`}}]}, 
   {Hue[0.014981303168455461`], AbsoluteThickness[0.5], 
    LineBox[{{4.679116423821506, 0.5078582774694631}, {4.735395395473899, 
     0.5616469638081976}}]}, 
   {Hue[0.01618986653326009], AbsoluteThickness[0.5], 
    LineBox[{{4.735395395473899, 0.5616469638081976}, {4.898146920049021, 
     0.7545397153201191}}]}, 
   {Hue[0.46577593817316576`], AbsoluteThickness[0.5], 
    LineBox[{{4.898146920049021, 0.7545397153201191}, {4.666333701422613, 
     0.8543310175835525}}]}, 
   {Hue[0.5229539059468317], AbsoluteThickness[0.5], 
    LineBox[{{4.438566414851184, 0.5524869770310002}, {4.1576579621197105`, 
     0.58555507400478}}]}, 
   {Hue[0.5234928139144123], AbsoluteThickness[0.5], 
    LineBox[{{4.1576579621197105`, 0.58555507400478}, {3.844295840556849, 
     0.607956106946425}}]}, 
   {Hue[0.5562904354558053], AbsoluteThickness[0.5], 
    LineBox[{{3.604299755622625, 0.19683693319168713`}, {3.360098816289504, 
     0.15570911802656662`}}]}, 
   {Hue[0.5582250309210002], AbsoluteThickness[0.5], 
    LineBox[{{3.360098816289504, 0.15570911802656662`}, {3.1193955008706493`, 
     0.14867981487762486`}}]}, 
   {Hue[0.5688742416793944], AbsoluteThickness[0.5], 
    LineBox[{{3.36695648301001, -0.5715894043744553}, {
     3.2978188222779274`, -0.6492299052705329}}]}, 
   {Hue[0.5693249301171698], AbsoluteThickness[0.5], 
    LineBox[{{3.2978188222779274`, -0.6492299052705329}, {
     3.092835143837827, -0.8898692833110765}}]}, 
   {Hue[0.5563721337465125], AbsoluteThickness[0.5], 
    LineBox[{{3.229840200074263, -1.4064747617511333`}, {
     3.1774449538368374`, -1.511296121335016}}]}, 
   {Hue[0.5619373237008153], AbsoluteThickness[0.5], 
    LineBox[{{3.1774449538368374`, -1.511296121335016}, {
     3.0536484716566408`, -1.6669366691206056`}}]}, 
   {Hue[0.41970011049938843`], AbsoluteThickness[0.5], 
    LineBox[{{3.452333541529669, -3.5821323194895625`}, {
     3.6294309293819533`, -3.9046110268196563`}}]}, 
   {Hue[0.4231436570043963], AbsoluteThickness[0.5], 
    LineBox[{{3.6294309293819533`, -3.9046110268196563`}, {
     3.69737656653835, -4.105073399295673}}]}, 
   {Hue[0.4646725851968529], AbsoluteThickness[0.5], 
    LineBox[{{3.9392658844890005`, -3.3048583850086404`}, {
     3.9693955772809164`, -3.3485001630760474`}}]}, 
   {Hue[0.4650999957988736], AbsoluteThickness[0.5], 
    LineBox[{{3.9693955772809164`, -3.3485001630760474`}, {
     4.126480307603231, -3.5787492848401135`}}]}, 
   {Hue[0.6657407859147775], AbsoluteThickness[0.5], 
    LineBox[{{2.2076330665813475`, -3.8654870271013904`}, {
     2.1845465608855306`, -4.1114535078621}}]}, 
   {Hue[0.6661976959014397], AbsoluteThickness[0.5], 
    LineBox[{{2.1845465608855306`, -4.1114535078621}, {
     2.162125030422836, -4.435642265857348}}]}, 
   {Hue[0.5568935749970596], AbsoluteThickness[0.5], 
    LineBox[{{4.170448244085874, -3.0664676686108665`}, {
     4.603360612283352, -3.287543745436931}}]}, 
   {Hue[0.5577007754814679], AbsoluteThickness[0.5], 
    LineBox[{{4.603360612283352, -3.287543745436931}, {
     4.866552645109435, -3.396534152588616}}]}, 
   {Hue[0.2492311093277504], AbsoluteThickness[0.5], 
    LineBox[{{4.419188767958661, 0.37383802081098927`}, {4.451143353713708, 
     0.3795655447854486}}]}, 
   {Hue[0.2500391582303109], AbsoluteThickness[0.5], 
    LineBox[{{4.451143353713708, 0.3795655447854486}, {4.67917960446723, 
     0.4394889337992326}}]}, 
   {Hue[0.5727773444774443], AbsoluteThickness[0.5], 
    LineBox[{{2.6835407204020045`, 0.07116935316632467}, {
     2.7250962228028857`, -0.10005828558842125`}}]}, 
   {Hue[0.5732046586566398], AbsoluteThickness[0.5], 
    LineBox[{{2.7250962228028857`, -0.10005828558842125`}, {
     2.8005962921515257`, -0.40402818337197466`}}]}, 
   {Hue[0.5846750514332971], AbsoluteThickness[0.5], 
    LineBox[{{2.7220540537297215`, 1.0510779131648766`}, {2.8482949628559364`,
      0.9689032371368842}}]}, 
   {Hue[0.5857294761988624], AbsoluteThickness[0.5], 
    LineBox[{{2.8482949628559364`, 0.9689032371368842}, {3.1052599163791137`, 
     0.8354753725049795}}]}, 
   {Hue[0.5587941422837924], AbsoluteThickness[0.5], 
    LineBox[{{2.525666926114915, 1.8393658891128908`}, {2.630201762448393, 
     1.7198067268499622`}}]}, 
   {Hue[0.5686713758390292], AbsoluteThickness[0.5], 
    LineBox[{{2.630201762448393, 1.7198067268499622`}, {2.77472404321967, 
     1.6205360405618476`}}]}, 
   {Hue[0.027609376485374867`], AbsoluteThickness[0.5], 
    LineBox[{{2.5116464490997754`, 2.097330053094283}, {2.4831332413603877`, 
     2.3845575261747984`}}]}, 
   {Hue[0.028073903158629242`], AbsoluteThickness[0.5], 
    LineBox[{{2.4831332413603877`, 2.3845575261747984`}, {2.461301538075794, 
     2.6888367423665556`}}]}, 
   {Hue[0.5742117099883574], AbsoluteThickness[0.5], 
    LineBox[{{2.461301538075794, 2.6888367423665556`}, {2.5967814192246537`, 
     2.415509710263129}}]}, 
   {Hue[0.559859966390138], AbsoluteThickness[0.5], 
    LineBox[{{2.373278637298292, 1.8791639871453822`}, {2.372521578388031, 
     1.8778434748684765`}}]}, 
   {Hue[0.5603020834811193], AbsoluteThickness[0.5], 
    LineBox[{{2.372521578388031, 1.8778434748684765`}, {2.23457102969019, 
     1.6468644345951597`}}]}, 
   {Hue[0.56813772983481], AbsoluteThickness[0.5], 
    LineBox[{{2.1952462708023224`, 1.0645318019648047`}, {2.1603917606671907`,
      1.0062754711109572`}}]}, 
   {Hue[0.5712207794558598], AbsoluteThickness[0.5], 
    LineBox[{{2.1603917606671907`, 1.0062754711109572`}, {2.012513876617879, 
     0.8332590498333149}}]}, 
   {Hue[0.5745221526280495], AbsoluteThickness[0.5], 
    LineBox[{{3.012075970114718, -0.6173130058377834}, {
     3.065024533269208, -0.7283570741151549}}]}, 
   {Hue[0.5757805728504417], AbsoluteThickness[0.5], 
    LineBox[{{3.065024533269208, -0.7283570741151549}, {
     3.1993376340714916`, -0.9451054486997513}}]}, 
   {Hue[0.5376086396119224], AbsoluteThickness[0.5], 
    LineBox[{{3.538629961930491, -1.119527568675636}, {
     3.6741828852832823`, -1.2382852448877202`}}]}, 
   {Hue[0.5381554673663796], AbsoluteThickness[0.5], 
    LineBox[{{3.6741828852832823`, -1.2382852448877202`}, {
     3.870555839385122, -1.3945514418150728`}}]}, 
   {Hue[0.6484252288644878], AbsoluteThickness[0.5], 
    LineBox[{{2.8800906107945172`, 1.6391180130300818`}, {2.8893490443411864`,
      1.6708294795523158`}}]}, 
   {Hue[0.6537598052412471], AbsoluteThickness[0.5], 
    LineBox[{{2.8893490443411864`, 1.6708294795523158`}, {2.904370029991087, 
     1.861430777246485}}]}, 
   {Hue[0.5312482819164852], AbsoluteThickness[0.5], 
    LineBox[{{3.836881639250934, 0.36264553007671096`}, {3.918912009342402, 
     0.39975680889555143`}}]}, 
   {Hue[0.5321825699508331], AbsoluteThickness[0.5], 
    LineBox[{{3.918912009342402, 0.39975680889555143`}, {4.162443090685365, 
     0.5374942587619648}}]}, 
   {Hue[0.2902612814382743], AbsoluteThickness[0.5], 
    LineBox[{{4.127796544945433, -0.4581484890887056}, {
     4.347789588935941, -0.5820346439003257}}]}, 
   {Hue[0.2915780289577219], AbsoluteThickness[0.5], 
    LineBox[{{4.347789588935941, -0.5820346439003257}, {
     4.579591659378131, -0.6800633530193007}}]}, 
   {Hue[0.5480914408211306], AbsoluteThickness[0.5], 
    LineBox[{{3.5457773299901305`, -1.1197004300454954`}, {
     3.622363046451694, -1.3629150027258037`}}]}, 
   {Hue[0.5504734087153144], AbsoluteThickness[0.5], 
    LineBox[{{3.622363046451694, -1.3629150027258037`}, {
     3.65924211823773, -1.6005974603082358`}}]}, 
   {Hue[0.5711777603193767], AbsoluteThickness[0.5], 
    LineBox[{{2.794553200267312, -0.9148994300438171}, {
     2.7847444112898487`, -1.0861469009595455`}}]}, 
   {Hue[0.5716172542846217], AbsoluteThickness[0.5], 
    LineBox[{{2.7847444112898487`, -1.0861469009595455`}, {
     2.772669635934027, -1.3813823113614512`}}]}, 
   {Hue[0.4820825078308945], AbsoluteThickness[0.5], 
    LineBox[{{3.887695862273753, 0.7019367240535739}, {3.9212659190632206`, 
     0.6921275985090763}}]}, 
   {Hue[0.4835573123952896], AbsoluteThickness[0.5], 
    LineBox[{{3.9212659190632206`, 0.6921275985090763}, {4.156003136412604, 
     0.5916542053608773}}]}, 
   {Hue[0.46754879005924094`], AbsoluteThickness[0.5], 
    LineBox[{{2.621312545441995, 1.3301671624071878`}, {2.4116613197848524`, 
     1.2393982201397922`}}]}, 
   {Hue[0.4680513452158673], AbsoluteThickness[0.5], 
    LineBox[{{2.4116613197848524`, 1.2393982201397922`}, {2.1133427234313578`,
      1.12351928865658}}]}, 
   {Hue[0.31038137112822756`], AbsoluteThickness[0.5], 
    LineBox[{{2.9002177191131056`, 1.6840788697388607`}, {3.106673698528938, 
     1.7995336366370183`}}]}, 
   {Hue[0.31145046722107445`], AbsoluteThickness[0.5], 
    LineBox[{{3.106673698528938, 1.7995336366370183`}, {3.360219020803376, 
     1.9099921495734042`}}]}, 
   {Hue[0.03706707302022859], AbsoluteThickness[0.5], 
    LineBox[{{2.897632969309187, 1.870823864614971}, {2.8969615058558817`, 
     1.8736875133247912`}}]}, 
   {Hue[0.03951600241512168], AbsoluteThickness[0.5], 
    LineBox[{{2.8969615058558817`, 1.8736875133247912`}, {2.8801173632573795`,
      2.0909166874207967`}}]}, 
   {Hue[0.4181336532929431], AbsoluteThickness[0.5], 
    LineBox[{{2.8801173632573795`, 2.0909166874207967`}, {3.097078106504986, 
     2.1109235639325776`}}]}, 
   {Hue[0.32284949108141847`], AbsoluteThickness[0.5], 
    LineBox[{{2.7174256772008842`, 1.9198718606374405`}, {2.6067279049864913`,
      1.9253293608088546`}}]}, 
   {Hue[0.3233278747687232], AbsoluteThickness[0.5], 
    LineBox[{{2.6067279049864913`, 1.9253293608088546`}, {2.343140203813161, 
     1.9467218886031135`}}]}, 
   {Hue[0.6086319091426093], AbsoluteThickness[0.5], 
    LineBox[{{2.620553822944589, 1.7601965090775502`}, {2.576134638443621, 
     1.6300223005642884`}}]}, 
   {Hue[0.609110300559283], AbsoluteThickness[0.5], 
    LineBox[{{2.576134638443621, 1.6300223005642884`}, {2.4579944884376674`, 
     1.3166906044833075`}}]}, 
   {Hue[0.4629853991884705], AbsoluteThickness[0.5], 
    LineBox[{{3.5616347332862177`, 1.3915767758856412`}, {3.6647321040134373`,
      1.3590390409337267`}}]}, 
   {Hue[0.46343089387386016`], AbsoluteThickness[0.5], 
    LineBox[{{3.6647321040134373`, 1.3590390409337267`}, {3.9438288042975254`,
      1.264910323793567}}]}, 
   {Hue[0.5672565241172788], AbsoluteThickness[0.5], 
    LineBox[{{3.4929405491548646`, -1.668357992992246}, {
     3.568800826376346, -1.8169751256491935`}}]}, 
   {Hue[0.5836643487279993], AbsoluteThickness[0.5], 
    LineBox[{{3.568800826376346, -1.8169751256491935`}, {
     3.667994600658004, -1.920860557910116}}]}, 
   {Hue[0.5128320951364113], AbsoluteThickness[0.5], 
    LineBox[{{4.4433252556650915`, -0.25241760238014127`}, {
     4.8524053507428055`, -0.5238022016722822}}]}, 
   {Hue[0.5137377185110934], AbsoluteThickness[0.5], 
    LineBox[{{4.8524053507428055`, -0.5238022016722822}, {
     5.080074778128918, -0.6475958780243454}}]}, 
   {Hue[0.6286778849974969], AbsoluteThickness[0.5], 
    LineBox[{{2.56006851440558, -0.6997133715511978}, {
     2.5341199300189636`, -0.8591314610739935}}]}, 
   {Hue[0.6291113012216517], AbsoluteThickness[0.5], 
    LineBox[{{2.5341199300189636`, -0.8591314610739935}, {
     2.4724964360531594`, -1.2106490950372273`}}]}, 
   {Hue[0.5298286946992452], AbsoluteThickness[0.5], 
    LineBox[{{2.8414852280782195`, 1.4134018512065536`}, {2.645976330680334, 
     1.5356016845487888`}}]}, 
   {Hue[0.5315074640927568], AbsoluteThickness[0.5], 
    LineBox[{{2.645976330680334, 1.5356016845487888`}, {2.4108605486042376`, 
     1.643462913050846}}]}, 
   {Hue[0.37520362185068035`], AbsoluteThickness[0.5], 
    LineBox[{{3.7083505205399137`, 1.9299240407323592`}, {3.670044197131379, 
     2.0291767272134233`}}]}, 
   {Hue[0.40000940086089765`], AbsoluteThickness[0.5], 
    LineBox[{{3.670044197131379, 2.0291767272134233`}, {3.5836502108315287`, 
     2.1332665655749454`}}]}, 
   {Hue[0.5548490893219883], AbsoluteThickness[0.5], 
    LineBox[{{3.5836502108315287`, 2.1332665655749454`}, {3.451071248830629, 
     2.1064070392635883`}}]}, 
   {Hue[0.5890812018654806], AbsoluteThickness[0.5], 
    LineBox[{{4.12603715712162, 1.7049389357979698`}, {3.9110093371949493`, 
     1.6973230412590516`}}]}, 
   {Hue[0.5898450422998631], AbsoluteThickness[0.5], 
    LineBox[{{3.9110093371949493`, 1.6973230412590516`}, {3.6241478653428914`,
      1.7088258723611338`}}]}, 
   {Hue[0.045735538044294186`], AbsoluteThickness[0.5], 
    LineBox[{{4.41268226628067, 1.858757923562918}, {4.419918012736193, 
     1.862364431843702}}]}, 
   {Hue[0.04623285737822047], AbsoluteThickness[0.5], 
    LineBox[{{4.419918012736193, 1.862364431843702}, {4.694086663171179, 
     2.0118598666211183`}}]}, 
   {Hue[0.5854725140030794], AbsoluteThickness[0.5], 
    LineBox[{{4.694086663171179, 2.0118598666211183`}, {4.381859501284938, 
     2.0174753168339925`}}]}, 
   {Hue[0.5900273690536406], AbsoluteThickness[0.5], 
    LineBox[{{4.215473890714598, 1.6000407880491905`}, {4.160214871972851, 
     1.5319048405611166`}}]}, 
   {Hue[0.590912424675971], AbsoluteThickness[0.5], 
    LineBox[{{4.160214871972851, 1.5319048405611166`}, {3.9834888866365374`, 
     1.3487458525792932`}}]}, 
   {Hue[0.3832368915784114], AbsoluteThickness[0.5], 
    LineBox[{{4.39255822188669, 1.193722465874306}, {4.413102796728485, 
     1.1584440260130422`}}]}, 
   {Hue[0.38366600744522406`], AbsoluteThickness[0.5], 
    LineBox[{{4.413102796728485, 1.1584440260130422`}, {4.594466704811155, 
     0.8526739374700221}}]}, 
   {Hue[0.5231662032556963], AbsoluteThickness[0.5], 
    LineBox[{{4.247308564901417, 0.5799640293755455}, {4.3865691967089635`, 
     0.4013595458265752}}]}, 
   {Hue[0.5337191971153012], AbsoluteThickness[0.5], 
    LineBox[{{4.3865691967089635`, 0.4013595458265752}, {4.458768633077512, 
     0.23374157972469037`}}]}, 
   {Hue[0.6451627872633185], AbsoluteThickness[0.5], 
    LineBox[{{2.55913678640031, 0.2626654894058446}, {2.105463341028473, 
     0.10375908171944724`}}]}, 
   {Hue[0.6457061809620024], AbsoluteThickness[0.5], 
    LineBox[{{2.105463341028473, 0.10375908171944724`}, {
     1.7658670946961699`, -0.03328966517797777}}]}, 
   {Hue[0.6027679370735489], AbsoluteThickness[0.5], 
    LineBox[{{3.211984839798013, -1.888680270946711}, {
     3.264065614233258, -2.0526543426122674`}}]}, 
   {Hue[0.6032171878904303], AbsoluteThickness[0.5], 
    LineBox[{{3.264065614233258, -2.0526543426122674`}, {
     3.3477777418829935`, -2.33712164333289}}]}, 
   {Hue[0.6815828681724915], AbsoluteThickness[0.5], 
    LineBox[{{2.6381005443934678`, 0.8305544737935947}, {2.627030467388034, 
     1.1076167423132597`}}]}, 
   {Hue[0.6836060104825318], AbsoluteThickness[0.5], 
    LineBox[{{2.627030467388034, 1.1076167423132597`}, {2.6526424993522344`, 
     1.361317939470629}}]}, 
   {Hue[0.29021412079487996`], AbsoluteThickness[0.5], 
    LineBox[{{4.435993113235755, -0.18774450835425613`}, {
     4.576413824997724, -0.16673836604609965`}}]}, 
   {Hue[0.2910163514190628], AbsoluteThickness[0.5], 
    LineBox[{{4.576413824997724, -0.16673836604609965`}, {
     4.857677848746491, -0.14718606445360888`}}]}, 
   {Hue[0.6842651895193796], AbsoluteThickness[0.5], 
    LineBox[{{3.305613394973361, -1.8846879681162658`}, {
     3.33723881185513, -2.0610700640171644`}}]}, 
   {Hue[0.6849891084973938], AbsoluteThickness[0.5], 
    LineBox[{{3.33723881185513, -2.0610700640171644`}, {
     3.365556617672992, -2.327253956956033}}]}, 
   {Hue[0.6446575621203456], AbsoluteThickness[0.5], 
    LineBox[{{3.4137418567264928`, 1.3277827479139734`}, {3.4123136812347523`,
      1.3609672458464486`}}]}, 
   {Hue[0.6452382884063622], AbsoluteThickness[0.5], 
    LineBox[{{3.4123136812347523`, 1.3609672458464486`}, {3.414954873719436, 
     1.6230648250088164`}}]}, 
   {Hue[0.45453933925516166`], AbsoluteThickness[0.5], 
    LineBox[{{3.028966809539099, -2.167294680308658}, {
     3.026101899370447, -2.321370443959892}}]}, 
   {Hue[0.45503038827388387`], AbsoluteThickness[0.5], 
    LineBox[{{3.026101899370447, -2.321370443959892}, {
     3.0080396428515948`, -2.656708180606923}}]}, 
   {Hue[0.5662323147227719], AbsoluteThickness[0.5], 
    LineBox[{{3.7107691049818214`, -1.655785496560136}, {
     3.946997977209621, -1.6043128100845299`}}]}, 
   {Hue[0.5712577424612009], AbsoluteThickness[0.5], 
    LineBox[{{3.946997977209621, -1.6043128100845299`}, {
     4.09768783450564, -1.5377808646624544`}}]}, 
   {Hue[0.39246863925052866`], AbsoluteThickness[0.5], 
    LineBox[{{3.827064209344114, -1.7429276520568864`}, {
     3.944578867111358, -1.8986882240035956`}}]}, 
   {Hue[0.3930236646536934], AbsoluteThickness[0.5], 
    LineBox[{{3.944578867111358, -1.8986882240035956`}, {
     4.087338978544364, -2.108452880463202}}]}, 
   {Hue[0.5955906875461647], AbsoluteThickness[0.5], 
    LineBox[{{3.796591792647296, -1.88501825126708}, {
     3.5349106003259507`, -2.3725148558836695`}}]}, 
   {Hue[0.5960876398883852], AbsoluteThickness[0.5], 
    LineBox[{{3.5349106003259507`, -2.3725148558836695`}, {
     3.4037427383378476`, -2.639998572653027}}]}, 
   {Hue[0.509924875189841], AbsoluteThickness[0.5], 
    LineBox[{{4.416120584123474, -0.7203717836964305}, {
     4.464381933662128, -0.6958974404359751}}]}, 
   {Hue[0.5117155862593719], AbsoluteThickness[0.5], 
    LineBox[{{4.464381933662128, -0.6958974404359751}, {
     4.659813013498005, -0.5616209504306261}}]}, 
   {Hue[0.6591413355694714], AbsoluteThickness[0.5], 
    LineBox[{{3.1462584637628876`, -0.17485491376696308`}, {
     3.145406813010575, -0.16998406950870415`}}]}, 
   {Hue[0.6598350365090028], AbsoluteThickness[0.5], 
    LineBox[{{3.145406813010575, -0.16998406950870412`}, {3.075758299408, 
     0.11312946997723078`}}]}, 
   {Hue[0.5861469538649053], AbsoluteThickness[0.5], 
    LineBox[{{2.3811745057225373`, -2.3725188892010487`}, {
     2.387229484546252, -2.3979828272710035`}}]}, 
   {Hue[0.5876129230831306], AbsoluteThickness[0.5], 
    LineBox[{{2.387229484546252, -2.3979828272710035`}, {
     2.473613824776061, -2.632297656332362}}]}, 
   {Hue[0.439560287280376], AbsoluteThickness[0.5], 
    LineBox[{{3.1418295240649248`, 1.5818545700189248`}, {3.1506870973904535`,
      1.6506598729065554`}}]}, 
   {Hue[0.44055180385379983`], AbsoluteThickness[0.5], 
    LineBox[{{3.1506870973904535`, 1.6506598729065554`}, {3.212514634689869, 
     1.924598934863943}}]}, 
   {Hue[0.4782502013419662], AbsoluteThickness[0.5], 
    LineBox[{{4.4586423288574695`, 0.2952551212334307}, {4.624474550426871, 
     0.3573175129457271}}]}, 
   {Hue[0.4816014848510173], AbsoluteThickness[0.5], 
    LineBox[{{4.624474550426871, 0.3573175129457271}, {4.801044893522486, 
     0.3902711628245228}}]}, 
   {Hue[0.5039242488762473], AbsoluteThickness[0.5], 
    LineBox[{{4.060103597551317, -2.6252473885157794`}, {
     4.238524828533939, -3.112200250828864}}]}, 
   {Hue[0.504610860819669], AbsoluteThickness[0.5], 
    LineBox[{{4.238524828533939, -3.112200250828864}, {
     4.308047176886715, -3.3504679258961136`}}]}, 
   {Hue[0.5456660605078836], AbsoluteThickness[0.5], 
    LineBox[{{2.6240995773547167`, -2.8698136702390324`}, {
     2.611826615758962, -2.920495108229659}}]}, 
   {Hue[0.5492596937096382], AbsoluteThickness[0.5], 
    LineBox[{{2.611826615758962, -2.920495108229659}, {
     2.5315428000286158`, -3.1022882264940157`}}]}, 
   {Hue[0.6317804770823323], AbsoluteThickness[0.5], 
    LineBox[{{2.597668256400706, 1.6131473693318668`}, {2.6037487164854354`, 
     1.9168655737040676`}}]}, 
   {Hue[0.6415538401114146], AbsoluteThickness[0.5], 
    LineBox[{{2.6037487164854354`, 1.9168655737040676`}, {2.5688233227755406`,
      2.0662639662951823`}}]}, 
   {Hue[0.6506385794067944], AbsoluteThickness[0.5], 
    LineBox[{{4.412863363736051, 0.3804060963692818}, {4.446328663635255, 
     0.3848143703390006}}]}, 
   {Hue[0.6514352942802396], AbsoluteThickness[0.5], 
    LineBox[{{4.446328663635255, 0.3848143703390006}, {4.677628553363748, 
     0.43400751388578807`}}]}, 
   {Hue[0.6912043732990258], AbsoluteThickness[0.5], 
    LineBox[{{5.3459175401646295`, -2.3472665439365543`}, {
     5.3610730804224636`, -2.355482563435058}}]}, 
   {Hue[0.6916994453252704], AbsoluteThickness[0.5], 
    LineBox[{{5.3610730804224636`, -2.355482563435058}, {
     5.62511319171315, -2.511260747192958}}]}, 
   {Hue[0.5707210973800313], AbsoluteThickness[0.5], 
    LineBox[{{3.131353864412593, -3.118886128685371}, {
     3.20370342863158, -3.1589443538882347`}}]}, 
   {Hue[0.5715099847366725], AbsoluteThickness[0.5], 
    LineBox[{{3.20370342863158, -3.1589443538882347`}, {
     3.431228106757085, -3.309160307536053}}]}, 
   {Hue[0.5545045053960851], AbsoluteThickness[0.5], 
    LineBox[{{2.1620289508920636`, -4.085822768339576}, {
     2.163388955414454, -4.115107971238957}}]}, 
   {Hue[0.5549583390955242], AbsoluteThickness[0.5], 
    LineBox[{{2.163388955414454, -4.115107971238957}, {
     2.1860585077864014`, -4.439759876578886}}]}, 
   {Hue[0.5370359859442592], AbsoluteThickness[0.5], 
    LineBox[{{2.1342470320728197`, -1.7724063352853814`}, {
     2.128512484589587, -1.8141046262913925`}}]}, 
   {Hue[0.5377175077532041], AbsoluteThickness[0.5], 
    LineBox[{{2.128512484589587, -1.8141046262913925`}, {
     2.0663854584882513`, -2.1153403444797982`}}]}, 
   {Hue[0.45893931656135534`], AbsoluteThickness[0.5], 
    LineBox[{{3.323097674527077, -1.3645395799561744`}, {
     3.343401281597634, -1.5967988667330877`}}]}, 
   {Hue[0.4599532794962084], AbsoluteThickness[0.5], 
    LineBox[{{3.343401281597634, -1.5967988667330877`}, {
     3.3411644414695765`, -1.8671894695505136`}}]}, 
   {Hue[0.32632341093011574`], AbsoluteThickness[0.5], 
    LineBox[{{3.184902846418019, 0.8510628972631865}, {3.1831006268414668`, 
     0.9198428053050849}}]}, 
   {Hue[0.3322652497091947], AbsoluteThickness[0.5], 
    LineBox[{{3.1831006268414668`, 0.9198428053050849}, {3.13273502040938, 
     1.1263314438827319`}}]}, 
   {Hue[0.6227695284989436], AbsoluteThickness[0.5], 
    LineBox[{{3.13273502040938, 1.1263314438827319`}, {2.920285479445115, 
     1.132611946808077}}]}, 
   {Hue[0.5718477274985895], AbsoluteThickness[0.5], 
    LineBox[{{3.0861107801812167`, 0.1978137772289844}, {2.9113452383940666`, 
     0.2189450321185387}}]}, 
   {Hue[0.5722735926109335], AbsoluteThickness[0.5], 
    LineBox[{{2.9113452383940666`, 0.2189450321185387}, {2.559021702046973, 
     0.26171209282751745`}}]}, 
   {Hue[0.36277244198890624`], AbsoluteThickness[0.5], 
    LineBox[{{4.177108797616254, 0.37252389696259214`}, {4.217303729559287, 
     0.585288379155573}}]}, 
   {Hue[0.36320327115260365`], AbsoluteThickness[0.5], 
    LineBox[{{4.217303729559287, 0.585288379155573}, {4.281732054404205, 
     0.9087509150714959}}]}, 
   {Hue[0.02804866376270981], AbsoluteThickness[0.5], 
    LineBox[{{4.389842820438779, 0.39920784432087075`}, {4.437081230983911, 
     0.3967259541207454}}]}, 
   {Hue[0.028994622045711536`], AbsoluteThickness[0.5], 
    LineBox[{{4.437081230983911, 0.3967259541207454}, {4.665137078625659, 
     0.4054507801867442}}]}, 
   {Hue[0.5032832592109143], AbsoluteThickness[0.5], 
    LineBox[{{4.665137078625659, 0.4054507801867442}, {4.5603946019304935`, 
     0.6082181488860513}}]}, 
   {Hue[0.3698528209078736], AbsoluteThickness[0.5], 
    LineBox[{{4.444755429037103, 0.19195822929155187`}, {4.447959225057141, 
     0.15284778806708732`}}]}, 
   {Hue[0.3706581381843331], AbsoluteThickness[0.5], 
    LineBox[{{4.447959225057141, 0.15284778806708732`}, {
     4.49079502644678, -0.11073964042706433`}}]}, 
   {Hue[0.5721601921242306], AbsoluteThickness[0.5], 
    LineBox[{{3.3167401095728355`, -0.10943190677588277`}, {
     3.291143553221309, -0.12621825134329295`}}]}, 
   {Hue[0.5736478033595471], AbsoluteThickness[0.5], 
    LineBox[{{3.291143553221309, -0.12621825134329295`}, {
     3.1043868007369175`, -0.2838888955190176}}]}, 
   {Hue[0.3356757368876746], AbsoluteThickness[0.5], 
    LineBox[{{3.99486063570663, -0.6453738136913714}, {
     4.1247085584548495`, -0.8218945796164712}}]}, 
   {Hue[0.3470282299320922], AbsoluteThickness[0.5], 
    LineBox[{{4.1247085584548495`, -0.8218945796164712}, {
     4.258482507852719, -0.9290624504732728}}]}, 
   {Hue[0.5745729612697127], AbsoluteThickness[0.5], 
    LineBox[{{4.258482507852719, -0.9290624504732728}, {
     4.4087538605964935`, -0.8466067494815299}}]}, 
   {Hue[0.6497688936553226], AbsoluteThickness[0.5], 
    LineBox[{{2.9253258579521546`, -0.598183602704985}, {
     2.844689017074558, -0.6371971629727549}}]}, 
   {Hue[0.6508708074861603], AbsoluteThickness[0.5], 
    LineBox[{{2.844689017074558, -0.6371971629727549}, {
     2.6428324755735395`, -0.761421695897005}}]}, 
   {Hue[0.6556165966288148], AbsoluteThickness[0.5], 
    LineBox[{{3.0755426109860546`, -2.165428119223086}, {
     3.061148166396154, -2.3367037794165153`}}]}, 
   {Hue[0.6562191721652396], AbsoluteThickness[0.5], 
    LineBox[{{3.061148166396154, -2.3367037794165153`}, {
     3.0162205194355254`, -2.65489300459902}}]}, 
   {Hue[0.6103581443731086], AbsoluteThickness[0.5], 
    LineBox[{{3.5925917171879176`, -2.0999316923453533`}, {
     3.6820915288073315`, -2.135274055810639}}]}, 
   {Hue[0.610849068397173], AbsoluteThickness[0.5], 
    LineBox[{{3.6820915288073315`, -2.135274055810639}, {
     3.9209158724811153`, -2.2394375318163497`}}]}, 
   {Hue[0.6977831960151345], AbsoluteThickness[0.5], 
    LineBox[{{3.9131313759086774`, -0.8188344074398776}, {
     4.11861949735822, -0.756757994920331}}]}, 
   {Hue[0.6983621718246114], AbsoluteThickness[0.5], 
    LineBox[{{4.11861949735822, -0.756757994920331}, {
     4.399131192434798, -0.6879434961065193}}]}, 
   {Hue[0.5496616125867049], AbsoluteThickness[0.5], 
    LineBox[{{2.1004892235165156`, -3.595703002301458}, {
     2.13868860700938, -3.8463699907697473`}}]}, 
   {Hue[0.5221140414502008], AbsoluteThickness[0.5], 
    LineBox[{{3.3382291948537137`, -3.4392422003448613`}, {
     3.3715846842686177`, -3.6012657267007553`}}]}, 
   {Hue[0.523183519893751], AbsoluteThickness[0.5], 
    LineBox[{{3.3715846842686177`, -3.6012657267007553`}, {
     3.401271406897694, -3.885758925182923}}]}, 
   {Hue[0.5132801210146356], AbsoluteThickness[0.5], 
    LineBox[{{4.3991567350297, -2.2515038417660493`}, {
     4.626448328908075, -2.2677698321760076`}}]}, 
   {Hue[0.5137322712567355], AbsoluteThickness[0.5], 
    LineBox[{{4.626448328908075, -2.2677698321760076`}, {
     4.915972694255348, -2.2819204449995443`}}]}, 
   {Hue[0.6153833073944968], AbsoluteThickness[0.5], 
    LineBox[{{3.6812551840616616`, -0.8613794860116978}, {
     3.6840576684865716`, -0.8442549822789431}}]}, 
   {Hue[0.6161731145185628], AbsoluteThickness[0.5], 
    LineBox[{{3.6840576684865716`, -0.8442549822789431}, {
     3.7477771064635728`, -0.5840602452804162}}]}, 
   {Hue[0.5690789988324442], AbsoluteThickness[0.5], 
    LineBox[{{3.4522368339784095`, -4.281655564912378}, {
     3.658394097674074, -4.390019566813182}}]}, 
   {Hue[0.5753189974775234], AbsoluteThickness[0.5], 
    LineBox[{{3.658394097674074, -4.390019566813182}, {
     3.844545781496441, -4.441018088305729}}]}, 
   {Hue[0.5232152458348419], AbsoluteThickness[0.5], 
    LineBox[{{3.1639291432910492`, -0.15197113218618072`}, {
     3.171464667587677, -0.15271018104369116`}}]}, 
   {Hue[0.52689661665914], AbsoluteThickness[0.5], 
    LineBox[{{3.171464667587677, -0.15271018104369116`}, {
     3.3319283654551537`, -0.1394999076378219}}]}, 
   {Hue[0.4929981265654759], AbsoluteThickness[0.5], 
    LineBox[{{3.400519433396651, 0.2557260231799236}, {3.8348949742610765`, 
     0.5762736108188564}}]}, 
   {Hue[0.49594384846476264`], AbsoluteThickness[0.5], 
    LineBox[{{3.8348949742610765`, 0.5762736108188564}, {3.9613647483339505`, 
     0.7066963543146088}}]}, 
   {Hue[0.4457794883057022], AbsoluteThickness[0.5], 
    LineBox[{{4.917632112659011, -2.272725531566585}, {
     4.986764207077132, -2.32100343487293}}]}, 
   {Hue[0.44996522999844596`], AbsoluteThickness[0.5], 
    LineBox[{{4.986764207077132, -2.32100343487293}, {
     5.117970787198835, -2.455620437655351}}]}, 
   {Hue[0.5749396081255401], AbsoluteThickness[0.5], 
    LineBox[{{3.131942390823277, -1.6219057338879679`}, {
     3.1318784549313543`, -1.6220275291922817`}}]}, 
   {Hue[0.5935433711179008], AbsoluteThickness[0.5], 
    LineBox[{{3.1318784549313543`, -1.6220275291922817`}, {
     3.1007759154558303`, -1.7902323279789494`}}]}, 
   {Hue[0.5217696911045692], AbsoluteThickness[0.5], 
    LineBox[{{3.6632365107472387`, -1.0707671721118366`}, {
     3.6792935045414423`, -1.226047886066853}}]}, 
   {Hue[0.5251857814538637], AbsoluteThickness[0.5], 
    LineBox[{{3.6792935045414423`, -1.226047886066853}, {
     3.7274248220795267`, -1.3947485842721337`}}]}, 
   {Hue[0.5398482494299851], AbsoluteThickness[0.5], 
    LineBox[{{3.2938941600275777`, 0.019615869514447513`}, {
     3.202068127005653, -0.01993611092997956}}]}, 
   {Hue[0.5403238488679573], AbsoluteThickness[0.5], 
    LineBox[{{3.202068127005653, -0.01993611092997956}, {
     2.908002025708583, -0.13596693165603835`}}]}, 
   {Hue[0.5550017989684959], AbsoluteThickness[0.5], 
    LineBox[{{3.866063410878982, 0.44476987700159554`}, {3.399780792933778, 
     0.24630197638034096`}}]}, 
   {Hue[0.5556834997013713], AbsoluteThickness[0.5], 
    LineBox[{{3.399780792933778, 0.24630197638034096`}, {3.119539377966469, 
     0.1485337098927587}}]}, 
   {Hue[0.012354967595074207`], AbsoluteThickness[0.5], 
    LineBox[{{4.073134215022028, 0.6922309535190612}, {4.097640180602828, 
     0.7197314167616415}}]}, 
   {Hue[0.013390551705159548`], AbsoluteThickness[0.5], 
    LineBox[{{4.097640180602828, 0.7197314167616415}, {4.298837142995916, 
     0.9056755606784739}}]}, 
   {Hue[0.4785480080055848], AbsoluteThickness[0.5], 
    LineBox[{{4.298837142995916, 0.9056755606784739}, {4.396327160415123, 
     0.6496459943452623}}]}, 
   {Hue[0.5559544658681476], AbsoluteThickness[0.5], 
    LineBox[{{3.991346857638227, 0.38009936189173915`}, {3.9234180149788087`, 
     0.15026947300286572`}}]}, 
   {Hue[0.5588029894876779], AbsoluteThickness[0.5], 
    LineBox[{{3.9234180149788087`, 0.15026947300286572`}, {
     3.895877214233578, -0.06970548479154029}}]}, 
   {Hue[0.5420137450043105], AbsoluteThickness[0.5], 
    LineBox[{{3.8020944026519126`, -0.38509929878417665`}, {
     3.756653504886061, -0.5819529483087769}}]}, 
   {Hue[0.542607606055086], AbsoluteThickness[0.5], 
    LineBox[{{3.756653504886061, -0.5819529483087769}, {
     3.708030344303194, -0.8622903506661785}}]}, 
   {Hue[0.5230133236705401], AbsoluteThickness[0.5], 
    LineBox[{{2.3521572266955513`, -0.12050669947120973`}, {
     2.2909519346586746`, -0.12258343741815494`}}]}, 
   {Hue[0.5570964779068516], AbsoluteThickness[0.5], 
    LineBox[{{2.2909519346586746`, -0.12258343741815494`}, {
     2.1432995060760303`, -0.18245085412750045`}}]}, 
   {Hue[0.6841438478833242], AbsoluteThickness[0.5], 
    LineBox[{{2.1432995060760303`, -0.18245085412750045`}, {
     2.1219115626357787`, -0.3403365821880188}}]}, 
   {Hue[0.5948977367731697], AbsoluteThickness[0.5], 
    LineBox[{{2.164271473251518, -0.8563454532950882}, {
     2.0732447343954563`, -0.858377615268161}}]}, 
   {Hue[0.5973777161590434], AbsoluteThickness[0.5], 
    LineBox[{{2.0732447343954563`, -0.858377615268161}, {
     1.8084083200979795`, -0.9054963027450094}}]}, 
   {Hue[0.5481528305254166], AbsoluteThickness[0.5], 
    LineBox[{{2.751560304362209, -3.88641543413201}, {
     2.699156214243068, -4.044342040526546}}]}, 
   {Hue[0.5596841872935492], AbsoluteThickness[0.5], 
    LineBox[{{2.699156214243068, -4.044342040526546}, {
     2.599617653095895, -4.19535781965024}}]}, 
   {Hue[0.6668706748422372], AbsoluteThickness[0.5], 
    LineBox[{{3.1320904881121656`, -3.9620866166193007`}, {
     3.1784835148416066`, -4.133615573467248}}]}, 
   {Hue[0.6676490945633354], AbsoluteThickness[0.5], 
    LineBox[{{3.1784835148416066`, -4.133615573467248}, {
     3.2725711112263487`, -4.398729225510076}}]}, 
   {Hue[0.4595140676579443], AbsoluteThickness[0.5], 
    LineBox[{{3.3859282651490497`, -2.816148881436383}, {
     3.3864644990840134`, -2.8375870716144784`}}]}, 
   {Hue[0.4604598228635413], AbsoluteThickness[0.5], 
    LineBox[{{3.3864644990840134`, -2.8375870716144784`}, {
     3.4174906615261245`, -3.1044958882003186`}}]}, 
   {Hue[0.5712506050929665], AbsoluteThickness[0.5], 
    LineBox[{{2.866355509659457, -0.541071272361659}, {
     2.706771068262922, -0.5892422160176876}}]}, 
   {Hue[0.5721698564448013], AbsoluteThickness[0.5], 
    LineBox[{{2.706771068262922, -0.5892422160176876}, {
     2.4251862500558343`, -0.6476146190622353}}]}, 
   {Hue[0.5578695102280715], AbsoluteThickness[0.5], 
    LineBox[{{3.400756430162679, -1.0320658062009593`}, {
     3.3458576933660087`, -1.1434665494940845`}}]}, 
   {Hue[0.5585184387285389], AbsoluteThickness[0.5], 
    LineBox[{{3.3458576933660087`, -1.1434665494940845`}, {
     3.194959763043209, -1.4066333209275217`}}]}, 
   {Hue[0.5225058587578503], AbsoluteThickness[0.5], 
    LineBox[{{4.532373323050984, -0.11959928933343511`}, {
     4.565086297397799, -0.39471326953635977`}}]}, 
   {Hue[0.5232109607388102], AbsoluteThickness[0.5], 
    LineBox[{{4.565086297397799, -0.39471326953635977`}, {
     4.579080526750309, -0.6803480603409489}}]}, 
   {Hue[0.4645673748083634], AbsoluteThickness[0.5], 
    LineBox[{{4.735395395473899, 0.5616469638081976}, {5.056401702060079, 
     0.16693018740902887`}}]}, 
   {Hue[0.47144439792204973`], AbsoluteThickness[0.5], 
    LineBox[{{5.056401702060079, 0.16693018740902887`}, {
     5.140157044809715, -0.002453587097661601}}]}, 
   {Hue[0.01739842989806487], AbsoluteThickness[0.5], 
    LineBox[{{4.898146920049021, 0.7545397153201191}, {4.956964695785292, 
     0.8416904478284554}}]}, 
   {Hue[0.01790062038425978], AbsoluteThickness[0.5], 
    LineBox[{{4.956964695785292, 0.8416904478284554}, {5.126178237952539, 
     1.114198578747892}}]}, 
   {Hue[0.5561546774588916], AbsoluteThickness[0.5], 
    LineBox[{{5.126178237952539, 1.114198578747892}, {4.8419841293515, 
     0.9654450480118034}}]}, 
   {Hue[0.4669845015379705], AbsoluteThickness[0.5], 
    LineBox[{{4.666333701422613, 0.8543310175835525}, {4.619870235621538, 
     0.8686699612896548}}]}, 
   {Hue[0.4678588529577992], AbsoluteThickness[0.5], 
    LineBox[{{4.619870235621538, 0.8686699612896548}, {4.336721111390517, 
     0.9832711839479705}}]}, 
   {Hue[0.5240317218819929], AbsoluteThickness[0.5], 
    LineBox[{{3.844295840556849, 0.607956106946425}, {3.564227844171144, 
     0.6151134746161853}}]}, 
   {Hue[0.5262502008012991], AbsoluteThickness[0.5], 
    LineBox[{{3.564227844171144, 0.6151134746161852}, {3.347704197658437, 
     0.5887943475578863}}]}, 
   {Hue[0.5601596263861952], AbsoluteThickness[0.5], 
    LineBox[{{3.1193955008706493`, 0.14867981487762486`}, {2.8990616405705, 
     0.17267189757096252`}}]}, 
   {Hue[0.5606522513933628], AbsoluteThickness[0.5], 
    LineBox[{{2.8990616405705, 0.17267189757096252`}, {2.558807073214661, 
     0.22204114600724026`}}]}, 
   {Hue[0.5697756185549451], AbsoluteThickness[0.5], 
    LineBox[{{3.092835143837827, -0.8898692833110765}, {
     3.0830743428614054`, -0.9018516784514915}}]}, 
   {Hue[0.5702318510044395], AbsoluteThickness[0.5], 
    LineBox[{{3.0830743428614054`, -0.9018516784514915}, {
     2.8975364589647024`, -1.1186542487304942`}}]}, 
   {Hue[0.5675025136551183], AbsoluteThickness[0.5], 
    LineBox[{{3.0536484716566408`, -1.6669366691206056`}, {
     2.850136542184638, -1.8350621463746841`}}]}, 
   {Hue[0.590970214773226], AbsoluteThickness[0.5], 
    LineBox[{{2.850136542184638, -1.8350621463746841`}, {
     2.6904392574098814`, -1.8971275291525094`}}]}, 
   {Hue[0.4265872035094042], AbsoluteThickness[0.5], 
    LineBox[{{3.69737656653835, -4.105073399295673}, {
     3.7047240034049493`, -4.153240273414806}}]}, 
   {Hue[0.42713489735180704`], AbsoluteThickness[0.5], 
    LineBox[{{3.7047240034049493`, -4.153240273414806}, {
     3.7647254054280057`, -4.451020208881506}}]}, 
   {Hue[0.46552740640089446`], AbsoluteThickness[0.5], 
    LineBox[{{4.126480307603231, -3.5787492848401135`}, {
     4.176214657218403, -3.6525225765067497`}}]}, 
   {Hue[0.4660268613378898], AbsoluteThickness[0.5], 
    LineBox[{{4.176214657218403, -3.6525225765067497`}, {
     4.311429297359505, -3.870205764951446}}]}, 
   {Hue[0.5585079759658763], AbsoluteThickness[0.5], 
    LineBox[{{4.866552645109435, -3.396534152588616}, {
     4.870004332023912, -3.3976515284025006`}}]}, 
   {Hue[0.55901184360736], AbsoluteThickness[0.5], 
    LineBox[{{4.870004332023912, -3.3976515284025006`}, {
     5.165635998102884, -3.5060580465839615`}}]}, 
   {Hue[0.25084720713287145`], AbsoluteThickness[0.5], 
    LineBox[{{4.67917960446723, 0.4394889337992326}, {4.8778408283595125`, 
     0.5090002232200023}}]}, 
   {Hue[0.251282448719055], AbsoluteThickness[0.5], 
    LineBox[{{4.8778408283595125`, 0.5090002232200023}, {5.164343881056505, 
     0.6049030481057666}}]}, 
   {Hue[0.5736319728358356], AbsoluteThickness[0.5], 
    LineBox[{{2.8005962921515257`, -0.40402818337197466`}, {
     2.8621133236673666`, -0.6461413470688542}}]}, 
   {Hue[0.5750229619921005], AbsoluteThickness[0.5], 
    LineBox[{{2.8621133236673666`, -0.6461413470688542}, {
     2.891999297777917, -0.8704330020873585}}]}, 
   {Hue[0.5867839009644278], AbsoluteThickness[0.5], 
    LineBox[{{3.1052599163791137`, 0.8354753725049795}, {3.149625290426641, 
     0.8177131989808507}}]}, 
   {Hue[0.5872687189808963], AbsoluteThickness[0.5], 
    LineBox[{{3.149625290426641, 0.8177131989808507}, {3.416849354965225, 
     0.7001792765211605}}]}, 
   {Hue[0.5785486093942662], AbsoluteThickness[0.5], 
    LineBox[{{2.77472404321967, 1.6205360405618476`}, {2.841679720437085, 
     1.5959889371352134`}}]}, 
   {Hue[0.5790082899768496], AbsoluteThickness[0.5], 
    LineBox[{{2.841679720437085, 1.5959889371352134`}, {3.1568858531110866`, 
     1.4711916389828747`}}]}, 
   {Hue[0.5737471833151055], AbsoluteThickness[0.5], 
    LineBox[{{2.4831332413603877`, 2.3845575261747984`}, {2.311192343658984, 
     1.9049726656130592`}}]}, 
   {Hue[0.5741974373936108], AbsoluteThickness[0.5], 
    LineBox[{{2.311192343658984, 1.9049726656130592`}, {2.2262734739843877`, 
     1.6508151545833287`}}]}, 
   {Hue[0.02853842983188369], AbsoluteThickness[0.5], 
    LineBox[{{2.461301538075794, 2.6888367423665556`}, {2.4553658991945575`, 
     2.8227181096173823`}}]}, 
   {Hue[0.02896846260639394], AbsoluteThickness[0.5], 
    LineBox[{{2.4553658991945575`, 2.8227181096173823`}, {2.4442065604453065`,
      3.1392798768585024`}}]}, 
   {Hue[0.5829102080531605], AbsoluteThickness[0.5], 
    LineBox[{{2.4442065604453065`, 3.1392798768585024`}, {2.496549054894154, 
     2.8268760571075044`}}]}, 
   {Hue[0.5746762366616118], AbsoluteThickness[0.5], 
    LineBox[{{2.5967814192246537`, 2.415509710263129}, {2.60659325329779, 
     2.3942758176404584`}}]}, 
   {Hue[0.5751376551346407], AbsoluteThickness[0.5], 
    LineBox[{{2.60659325329779, 2.3942758176404584`}, {2.7618915889961704`, 
     2.0800988358829584`}}]}, 
   {Hue[0.5607442005721007], AbsoluteThickness[0.5], 
    LineBox[{{2.23457102969019, 1.6468644345951597`}, {2.184730507095609, 
     1.5666955009124146`}}]}, 
   {Hue[0.5624572562343597], AbsoluteThickness[0.5], 
    LineBox[{{2.184730507095609, 1.5666955009124146`}, {2.0087149825373074`, 
     1.3516985666462265`}}]}, 
   {Hue[0.5770389930728338], AbsoluteThickness[0.5], 
    LineBox[{{3.1993376340714916`, -0.9451054486997513}, {
     3.501644407419519, -1.3309595609092468`}}]}, 
   {Hue[0.5777754840665695], AbsoluteThickness[0.5], 
    LineBox[{{3.501644407419519, -1.3309595609092468`}, {
     3.6707414689482185`, -1.582507796499523}}]}, 
   {Hue[0.5387022951208371], AbsoluteThickness[0.5], 
    LineBox[{{3.870555839385122, -1.3945514418150728`}, {
     3.874087907454328, -1.3970989771447644`}}]}, 
   {Hue[0.5391283000688261], AbsoluteThickness[0.5], 
    LineBox[{{3.874087907454328, -1.3970989771447644`}, {
     4.088706606993858, -1.552458228890774}}]}, 
   {Hue[0.6590943816180065], AbsoluteThickness[0.5], 
    LineBox[{{2.904370029991087, 1.861430777246485}, {2.90349210895599, 
     1.8683188710745766`}}]}, 
   {Hue[0.6604714338182289], AbsoluteThickness[0.5], 
    LineBox[{{2.90349210895599, 1.8683188710745766`}, {2.90080222810362, 
     2.1112373083962646`}}]}, 
   {Hue[0.5331168579851812], AbsoluteThickness[0.5], 
    LineBox[{{4.162443090685365, 0.5374942587619648}, {4.227936108140761, 
     0.582744484992004}}]}, 
   {Hue[0.5343972045191033], AbsoluteThickness[0.5], 
    LineBox[{{4.227936108140761, 0.582744484992004}, {4.42607923087754, 
     0.7549780465754505}}]}, 
   {Hue[0.2928947764771694], AbsoluteThickness[0.5], 
    LineBox[{{4.579591659378131, -0.6800633530193007}, {
     4.6202918371372, -0.6920894632138163}}]}, 
   {Hue[0.29334058453165157`], AbsoluteThickness[0.5], 
    LineBox[{{4.6202918371372, -0.6920894632138163}, {
     4.9108503612329555`, -0.7717466946244831}}]}, 
   {Hue[0.5528553766094981], AbsoluteThickness[0.5], 
    LineBox[{{3.65924211823773, -1.6005974603082358`}, {
     3.6594143428959165`, -1.6619541540935356`}}]}, 
   {Hue[0.5533605737736245], AbsoluteThickness[0.5], 
    LineBox[{{3.6594143428959165`, -1.6619541540935356`}, {
     3.670191454039778, -1.921393551906197}}]}, 
   {Hue[0.5720567482498666], AbsoluteThickness[0.5], 
    LineBox[{{2.772669635934027, -1.3813823113614512`}, {
     2.7679256299805832`, -1.5746913700076475`}}]}, 
   {Hue[0.5725443481518536], AbsoluteThickness[0.5], 
    LineBox[{{2.7679256299805832`, -1.5746913700076475`}, {
     2.7489515606340333`, -1.896776597530402}}]}, 
   {Hue[0.48503211695968473`], AbsoluteThickness[0.5], 
    LineBox[{{4.156003136412604, 0.5916542053608773}, {4.417237585926015, 
     0.4404899372183064}}]}, 
   {Hue[0.4863413844079691], AbsoluteThickness[0.5], 
    LineBox[{{4.417237585926015, 0.4404899372183064}, {4.613088873014978, 
     0.3548626097473871}}]}, 
   {Hue[0.4685539003724936], AbsoluteThickness[0.5], 
    LineBox[{{2.1133427234313578`, 1.12351928865658}, {2.109164242468748, 
     1.1220767655280788`}}]}, 
   {Hue[0.4691865996632072], AbsoluteThickness[0.5], 
    LineBox[{{2.1091642424687485`, 1.1220767655280788`}, {1.8227396857308165`,
      1.0033167671827168`}}]}, 
   {Hue[0.3125195633139214], AbsoluteThickness[0.5], 
    LineBox[{{3.360219020803376, 1.9099921495734042`}, {3.4320476343576836`, 
     1.9331456185433251`}}]}, 
   {Hue[0.31302009039162565`], AbsoluteThickness[0.5], 
    LineBox[{{3.4320476343576836`, 1.9331456185433251`}, {3.671117109764292, 
     2.020257154454116}}]}, 
   {Hue[0.41568472389805283`], AbsoluteThickness[0.5], 
    LineBox[{{2.8969615058558817`, 1.8736875133247912`}, {2.8952310987790635`,
      1.8738438699959958`}}]}, 
   {Hue[0.4170055259349774], AbsoluteThickness[0.5], 
    LineBox[{{2.8952310987790635`, 1.8738438699959958`}, {2.65035634237969, 
     1.8682424440836503`}}]}, 
   {Hue[0.041964931810014934`], AbsoluteThickness[0.5], 
    LineBox[{{2.8801173632573795`, 2.0909166874207967`}, {2.890321390842795, 
     2.225731054309474}}]}, 
   {Hue[0.13295676438864645`], AbsoluteThickness[0.5], 
    LineBox[{{2.890321390842795, 2.225731054309474}, {2.8303990840176247`, 
     2.3868845309562006`}}]}, 
   {Hue[0.18601651825875565`], AbsoluteThickness[0.5], 
    LineBox[{{2.8303990840176247`, 2.3868845309562006`}, {2.662199417619902, 
     2.4225215638611965`}}]}, 
   {Hue[0.23907627212886018`], AbsoluteThickness[0.5], 
    LineBox[{{2.662199417619902, 2.4225215638611965`}, {2.542071365513782, 
     2.299515966477313}}]}, 
   {Hue[0.29213602599896044`], AbsoluteThickness[0.5], 
    LineBox[{{2.542071365513782, 2.299515966477313}, {2.5816792257406163`, 
     2.1322068415055164`}}]}, 
   {Hue[0.3451957798690555], AbsoluteThickness[0.5], 
    LineBox[{{2.5816792257406163`, 2.1322068415055164`}, {2.74420575343871, 
     2.0761153654598874`}}]}, 
   {Hue[0.3982555337391495], AbsoluteThickness[0.5], 
    LineBox[{{2.74420575343871, 2.0761153654598874`}, {2.8785754062154014`, 
     2.183381027734672}}]}, 
   {Hue[0.45131528760924233`], AbsoluteThickness[0.5], 
    LineBox[{{2.8785754062154014`, 2.183381027734672}, {2.8598856930012864`, 
     2.3542956862942894`}}]}, 
   {Hue[0.5043750414793299], AbsoluteThickness[0.5], 
    LineBox[{{2.8598856930012864`, 2.3542956862942894`}, {2.7055095227053085`,
      2.4299866628722397`}}]}, 
   {Hue[0.5574347953494214], AbsoluteThickness[0.5], 
    LineBox[{{2.7055095227053085`, 2.4299866628722397`}, {2.558946322715039, 
     2.340095871913494}}]}, 
   {Hue[0.6104945492195131], AbsoluteThickness[0.5], 
    LineBox[{{2.558946322715039, 2.340095871913494}, {2.5564330215303284`, 
     2.1681807498103716`}}]}, 
   {Hue[0.6635543030896047], AbsoluteThickness[0.5], 
    LineBox[{{2.5564330215303284`, 2.1681807498103716`}, {2.70030584293602, 
     2.074043949613304}}]}, 
   {Hue[0.42058258268783644`], AbsoluteThickness[0.5], 
    LineBox[{{3.097078106504986, 2.1109235639325776`}, {3.1925707472574927`, 
     2.105093458110518}}]}, 
   {Hue[0.42304791959674304`], AbsoluteThickness[0.5], 
    LineBox[{{3.1925707472574927`, 2.105093458110518}, {3.4185276209826, 
     2.126029066781672}}]}, 
   {Hue[0.32380625845602795`], AbsoluteThickness[0.5], 
    LineBox[{{2.343140203813161, 1.9467218886031135`}, {2.1405039869104985`, 
     1.9696566021367503`}}]}, 
   {Hue[0.324391657289351], AbsoluteThickness[0.5], 
    LineBox[{{2.1405039869104985`, 1.9696566021367503`}, {1.8790671355290522`,
      2.013599641867095}}]}, 
   {Hue[0.6095886919759566], AbsoluteThickness[0.5], 
    LineBox[{{2.4579944884376674`, 1.3166906044833075`}, {2.4116008477677413`,
      1.2045551854513425`}}]}, 
   {Hue[0.6245443397444183], AbsoluteThickness[0.5], 
    LineBox[{{2.4116008477677413`, 1.2045551854513425`}, {2.300004252940477, 
     1.0651795286805303`}}]}, 
   {Hue[0.4638763885592498], AbsoluteThickness[0.5], 
    LineBox[{{3.9438288042975254`, 1.264910323793567}, {4.108939937432847, 
     1.2056007584836719`}}]}, 
   {Hue[0.465148159589493], AbsoluteThickness[0.5], 
    LineBox[{{4.108939937432847, 1.2056007584836719`}, {4.353830044473137, 
     1.1471386136928445`}}]}, 
   {Hue[0.6000721733387203], AbsoluteThickness[0.5], 
    LineBox[{{3.667994600658004, -1.920860557910116}, {
     3.8451245530852476`, -2.0218466757113767`}}]}, 
   {Hue[0.6007052133972927], AbsoluteThickness[0.5], 
    LineBox[{{3.8451245530852476`, -2.0218466757113767`}, {
     4.066453256022715, -2.130809726213391}}]}, 
   {Hue[0.5146433418857755], AbsoluteThickness[0.5], 
    LineBox[{{5.080074778128918, -0.6475958780243454}, {
     5.104327300128489, -0.6581458467531188}}]}, 
   {Hue[0.515186645756531], AbsoluteThickness[0.5], 
    LineBox[{{5.104327300128489, -0.6581458467531188}, {
     5.3566224881569395`, -0.7821915536001413}}]}, 
   {Hue[0.6295447174458065], AbsoluteThickness[0.5], 
    LineBox[{{2.4724964360531594`, -1.2106490950372273`}, {
     2.444913929630336, -1.3574449770390487`}}]}, 
   {Hue[0.6301321456274172], AbsoluteThickness[0.5], 
    LineBox[{{2.444913929630336, -1.3574449770390487`}, {
     2.408519678648831, -1.6324166623321517`}}]}, 
   {Hue[0.5331862334862685], AbsoluteThickness[0.5], 
    LineBox[{{2.4108605486042376`, 1.643462913050846}, {2.363605887772754, 
     1.658163478883308}}]}, 
   {Hue[0.534201962182187], AbsoluteThickness[0.5], 
    LineBox[{{2.363605887772754, 1.658163478883308}, {2.155539157905669, 
     1.7454439258844865`}}]}, 
   {Hue[0.5300433103117739], AbsoluteThickness[0.5], 
    LineBox[{{3.670044197131379, 2.0291767272134233`}, {3.67364338520756, 
     2.0883753921290507`}}]}, 
   {Hue[0.5304868024819827], AbsoluteThickness[0.5], 
    LineBox[{{3.67364338520756, 2.0883753921290507`}, {3.6943331902074075`, 
     2.3487882701254557`}}]}, 
   {Hue[0.42481517987111567`], AbsoluteThickness[0.5], 
    LineBox[{{3.5836502108315287`, 2.1332665655749454`}, {3.455720210058759, 
     2.2123363627839217`}}]}, 
   {Hue[0.42541979093548565`], AbsoluteThickness[0.5], 
    LineBox[{{3.455720210058759, 2.2123363627839217`}, {3.19197115856725, 
     2.3553557690665468`}}]}, 
   {Hue[0.5796548683322063], AbsoluteThickness[0.5], 
    LineBox[{{3.451071248830629, 2.1064070392635883`}, {3.1399794450362157`, 
     1.9264996256207536`}}]}, 
   {Hue[0.5821675207045577], AbsoluteThickness[0.5], 
    LineBox[{{3.1399794450362157`, 1.9264996256207536`}, {2.937759861217782, 
     1.8481331552513556`}}]}, 
   {Hue[0.5906088827342456], AbsoluteThickness[0.5], 
    LineBox[{{3.6241478653428914`, 1.7088258723611338`}, {3.4354780327678927`,
      1.7307257971028294`}}]}, 
   {Hue[0.5910429524604454], AbsoluteThickness[0.5], 
    LineBox[{{3.4354780327678927`, 1.7307257971028294`}, {3.1036720617805367`,
      1.7735179706222566`}}]}, 
   {Hue[0.5849751946691536], AbsoluteThickness[0.5], 
    LineBox[{{4.419918012736193, 1.862364431843702}, {4.415752882099558, 
     1.8550491224433903`}}]}, 
   {Hue[0.5855236744041968], AbsoluteThickness[0.5], 
    LineBox[{{4.415752882099558, 1.8550491224433903`}, {4.247010356843755, 
     1.5889830912845524`}}]}, 
   {Hue[0.04673017671214675], AbsoluteThickness[0.5], 
    LineBox[{{4.694086663171179, 2.0118598666211183`}, {5.074015023527236, 
     2.237547479451589}}]}, 
   {Hue[0.0475192370931197], AbsoluteThickness[0.5], 
    LineBox[{{5.074015023527236, 2.237547479451589}, {5.33854629295506, 
     2.3679955772430166`}}]}, 
   {Hue[0.5401128788056705], AbsoluteThickness[0.5], 
    LineBox[{{5.33854629295506, 2.3679955772430166`}, {5.3069920653208165`, 
     2.074741712066606}}]}, 
   {Hue[0.5859698333370057], AbsoluteThickness[0.5], 
    LineBox[{{4.381859501284938, 2.0174753168339925`}, {4.201085952100827, 
     2.0140710262518358`}}]}, 
   {Hue[0.5864340693327351], AbsoluteThickness[0.5], 
    LineBox[{{4.201085952100827, 2.0140710262518358`}, {3.875348644171166, 
     1.9990605338250842`}}]}, 
   {Hue[0.5917974802983015], AbsoluteThickness[0.5], 
    LineBox[{{3.9834888866365374`, 1.3487458525792932`}, {3.944641975325874, 
     1.3148687949942717`}}]}, 
   {Hue[0.5925596664662872], AbsoluteThickness[0.5], 
    LineBox[{{3.944641975325874, 1.3148687949942717`}, {3.734340156847673, 
     1.1576855262918428`}}]}, 
   {Hue[0.3840951233120369], AbsoluteThickness[0.5], 
    LineBox[{{4.594466704811155, 0.8526739374700221}, {4.619015177980589, 
     0.8120324093694274}}]}, 
   {Hue[0.3846538710471925], AbsoluteThickness[0.5], 
    LineBox[{{4.619015177980589, 0.8120324093694274}, {4.784525291916614, 
     0.5663326641501796}}]}, 
   {Hue[0.5442721909749062], AbsoluteThickness[0.5], 
    LineBox[{{4.458768633077512, 0.23374157972469037`}, {4.468956358975643, 
     0.1668732477969448}}]}, 
   {Hue[0.544805590180192], AbsoluteThickness[0.5], 
    LineBox[{{4.468956358975643, 0.1668732477969448}, {
     4.525693627236717, -0.11897958038450793`}}]}, 
   {Hue[0.6036664387073118], AbsoluteThickness[0.5], 
    LineBox[{{3.3477777418829935`, -2.33712164333289}, {
     3.375537514166408, -2.439469721781864}}]}, 
   {Hue[0.6048164723355801], AbsoluteThickness[0.5], 
    LineBox[{{3.375537514166408, -2.439469721781864}, {
     3.46562600974435, -2.6726015423326617`}}]}, 
   {Hue[0.6856291527925723], AbsoluteThickness[0.5], 
    LineBox[{{2.6526424993522344`, 1.361317939470629}, {2.7189680195666193`, 
     1.6309933592948358`}}]}, 
   {Hue[0.6860674984505334], AbsoluteThickness[0.5], 
    LineBox[{{2.7189680195666193`, 1.6309933592948358`}, {2.7973084901403107`,
      1.9293201682834191`}}]}, 
   {Hue[0.29181858204324573`], AbsoluteThickness[0.5], 
    LineBox[{{4.857677848746491, -0.14718606445360888`}, {
     5.10685860870514, -0.14959941360022094`}}]}, 
   {Hue[0.29230591289030855`], AbsoluteThickness[0.5], 
    LineBox[{{5.10685860870514, -0.14959941360022094`}, {
     5.455779527888165, -0.1649333300957412}}]}, 
   {Hue[0.6857130274754081], AbsoluteThickness[0.5], 
    LineBox[{{3.365556617672992, -2.327253956956033}, {
     3.3697678503786523`, -2.449072151456729}}]}, 
   {Hue[0.6892826476405711], AbsoluteThickness[0.5], 
    LineBox[{{3.3697678503786523`, -2.449072151456729}, {
     3.412449600404937, -2.647005356032891}}]}, 
   {Hue[0.6458190146923787], AbsoluteThickness[0.5], 
    LineBox[{{3.414954873719436, 1.6230648250088164`}, {3.41899041161737, 
     1.6868691964082645`}}]}, 
   {Hue[0.6518125854308328], AbsoluteThickness[0.5], 
    LineBox[{{3.41899041161737, 1.6868691964082645`}, {3.3885060107795724`, 
     1.8878918765186625`}}]}, 
   {Hue[0.4555214372926061], AbsoluteThickness[0.5], 
    LineBox[{{3.0080396428515948`, -2.656708180606923}, {
     2.9928150125384714`, -2.827262242591356}}]}, 
   {Hue[0.455966681522963], AbsoluteThickness[0.5], 
    LineBox[{{2.9928150125384714`, -2.827262242591356}, {
     2.968938335114981, -3.16986390557186}}]}, 
   {Hue[0.5762831701996297], AbsoluteThickness[0.5], 
    LineBox[{{4.09768783450564, -1.5377808646624544`}, {
     4.5530578555330425`, -1.2147377513029625`}}]}, 
   {Hue[0.5771073046720386], AbsoluteThickness[0.5], 
    LineBox[{{4.5530578555330425`, -1.2147377513029625`}, {
     4.78703558262428, -1.0757621193804605`}}]}, 
   {Hue[0.3935786900568583], AbsoluteThickness[0.5], 
    LineBox[{{4.087338978544364, -2.108452880463202}, {
     4.103274098611256, -2.134514500414094}}]}, 
   {Hue[0.3941841090541557], AbsoluteThickness[0.5], 
    LineBox[{{4.103274098611256, -2.134514500414094}, {
     4.274654803422165, -2.3820194931984733`}}]}, 
   {Hue[0.5965845922306057], AbsoluteThickness[0.5], 
    LineBox[{{3.4037427383378476`, -2.639998572653027}, {
     3.3883545445415804`, -2.674531377370734}}]}, 
   {Hue[0.5977310070750966], AbsoluteThickness[0.5], 
    LineBox[{{3.3883545445415804`, -2.674531377370734}, {
     3.253933874468722, -2.90773988958665}}]}, 
   {Hue[0.5135062973289026], AbsoluteThickness[0.5], 
    LineBox[{{4.659813013498005, -0.5616209504306261}, {
     5.104078001683028, -0.16028520622277437`}}]}, 
   {Hue[0.5160901425550454], AbsoluteThickness[0.5], 
    LineBox[{{5.104078001683028, -0.16028520622277437`}, {
     5.31347489928499, -0.02362023743364991}}]}, 
   {Hue[0.6605287374485341], AbsoluteThickness[0.5], 
    LineBox[{{3.075758299408, 0.11312946997723078`}, {2.9850673048689633`, 
     0.39689241281056514`}}]}, 
   {Hue[0.6614556208902518], AbsoluteThickness[0.5], 
    LineBox[{{2.9850673048689633`, 0.39689241281056514`}, {
     2.9295195072603133`, 0.6452756085715027}}]}, 
   {Hue[0.589078892301356], AbsoluteThickness[0.5], 
    LineBox[{{2.473613824776061, -2.632297656332362}, {
     2.723378518511601, -3.1204045293638405`}}]}, 
   {Hue[0.5895957212157543], AbsoluteThickness[0.5], 
    LineBox[{{2.723378518511601, -3.1204045293638405`}, {
     2.849084613548839, -3.3933193634832923`}}]}, 
   {Hue[0.44154332042722344`], AbsoluteThickness[0.5], 
    LineBox[{{3.212514634689869, 1.924598934863943}, {3.260785018771603, 
     2.0722706722419395`}}]}, 
   {Hue[0.441977294653713], AbsoluteThickness[0.5], 
    LineBox[{{3.260785018771603, 2.0722706722419395`}, {3.3570581450909547`, 
     2.379895606261965}}]}, 
   {Hue[0.48495276836006834`], AbsoluteThickness[0.5], 
    LineBox[{{4.801044893522486, 0.3902711628245228}, {5.005455427726417, 
     0.39250075901065323`}}]}, 
   {Hue[0.5285015846987284], AbsoluteThickness[0.5], 
    LineBox[{{5.005455427726417, 0.39250075901065323`}, {5.14472231394781, 
     0.44861024535644956`}}]}, 
   {Hue[0.6351377069156405], AbsoluteThickness[0.5], 
    LineBox[{{5.14472231394781, 0.44861024535644956`}, {5.16761545401311, 
     0.5969997469855804}}]}, 
   {Hue[0.5052974727630907], AbsoluteThickness[0.5], 
    LineBox[{{4.308047176886715, -3.3504679258961136`}, {
     4.328163571833944, -3.4418892245648927`}}]}, 
   {Hue[0.5178129564592474], AbsoluteThickness[0.5], 
    LineBox[{{4.328163571833944, -3.4418892245648927`}, {
     4.4131073162696675`, -3.602941589261029}}]}, 
   {Hue[0.5528533269113928], AbsoluteThickness[0.5], 
    LineBox[{{2.5315428000286158`, -3.1022882264940157`}, {
     2.4334544859021965`, -3.2474806154319644`}}]}, 
   {Hue[0.5637089597659923], AbsoluteThickness[0.5], 
    LineBox[{{2.4334544859021965`, -3.2474806154319644`}, {
     2.306277269148326, -3.358787510477874}}]}, 
   {Hue[0.6513272031404963], AbsoluteThickness[0.5], 
    LineBox[{{2.5688233227755406`, 2.0662639662951823`}, {2.2588045524409313`,
      2.662749879618523}}]}, 
   {Hue[0.6517535074665273], AbsoluteThickness[0.5], 
    LineBox[{{2.2588045524409313`, 2.662749879618523}, {2.1392900170502025`, 
     2.89438398710967}}]}, 
   {Hue[0.6522320091536848], AbsoluteThickness[0.5], 
    LineBox[{{4.677628553363748, 0.43400751388578807`}, {4.881913445055596, 
     0.4945562529260387}}]}, 
   {Hue[0.6526588433972536], AbsoluteThickness[0.5], 
    LineBox[{{4.881913445055596, 0.4945562529260387}, {5.172443462141257, 
     0.5820588092193381}}]}, 
   {Hue[0.6921945173515149], AbsoluteThickness[0.5], 
    LineBox[{{5.62511319171315, -2.511260747192958}, {
     6.335718044669704, -2.9660040262705167`}}]}, 
   {Hue[0.6926357285312357], AbsoluteThickness[0.5], 
    LineBox[{{6.335718044669704, -2.9660040262705167`}, {
     6.604281118647672, -3.1313791602940277`}}]}, 
   {Hue[0.5722988720933135], AbsoluteThickness[0.5], 
    LineBox[{{3.431228106757085, -3.309160307536053}, {
     3.460386550126647, -3.3318552811790068`}}]}, 
   {Hue[0.5728263462458628], AbsoluteThickness[0.5], 
    LineBox[{{3.460386550126647, -3.3318552811790068`}, {
     3.6802485641753515`, -3.5189101710261763`}}]}, 
   {Hue[0.5383990295621492], AbsoluteThickness[0.5], 
    LineBox[{{2.0663854584882513`, -2.1153403444797982`}, {
     2.011182278463024, -2.3147184761191424`}}]}, 
   {Hue[0.5388809525627721], AbsoluteThickness[0.5], 
    LineBox[{{2.011182278463024, -2.3147184761191424`}, {
     1.9340264560267877`, -2.6336355785240135`}}]}, 
   {Hue[0.46096724243106135`], AbsoluteThickness[0.5], 
    LineBox[{{3.3411644414695765`, -1.8671894695505136`}, {
     3.3214989742050234`, -2.0560719531324825`}}]}, 
   {Hue[0.46141003396874586`], AbsoluteThickness[0.5], 
    LineBox[{{3.3214989742050234`, -2.0560719531324825`}, {
     3.285317833121037, -2.351331844754405}}]}, 
   {Hue[0.6168276897198665], AbsoluteThickness[0.5], 
    LineBox[{{3.1831006268414668`, 0.9198428053050849}, {3.6550895563626815`, 
     1.3347172416808657`}}]}, 
   {Hue[0.6200673693777978], AbsoluteThickness[0.5], 
    LineBox[{{3.6550895563626815`, 1.3347172416808657`}, {3.8245468937546936`,
      1.4385522803070183`}}]}, 
   {Hue[0.33820708848827385`], AbsoluteThickness[0.5], 
    LineBox[{{3.13273502040938, 1.1263314438827319`}, {3.030148446382024, 
     1.3374661876137752`}}]}, 
   {Hue[0.33866544938913407`], AbsoluteThickness[0.5], 
    LineBox[{{3.030148446382024, 1.3374661876137752`}, {2.889599785236892, 
     1.6462047643600732`}}]}, 
   {Hue[0.6287113672780228], AbsoluteThickness[0.5], 
    LineBox[{{2.920285479445115, 1.132611946808077}, {2.9090360699304214`, 
     1.1305242791571866`}}]}, 
   {Hue[0.6298823867914634], AbsoluteThickness[0.5], 
    LineBox[{{2.9090360699304214`, 1.1305242791571866`}, {2.6264240693090732`,
      1.1083212590206737`}}]}, 
   {Hue[0.5726994577232773], AbsoluteThickness[0.5], 
    LineBox[{{2.559021702046973, 0.26171209282751745`}, {2.3222957412072325`, 
     0.29055941313593847`}}]}, 
   {Hue[0.5731664893363309], AbsoluteThickness[0.5], 
    LineBox[{{2.3222957412072325`, 0.29055941313593847`}, {
     2.0873863473289016`, 0.3124905328434315}}]}, 
   {Hue[0.363634100316301], AbsoluteThickness[0.5], 
    LineBox[{{4.281732054404205, 0.9087509150714959}, {4.328084447451636, 
     1.1300143877744993`}}]}, 
   {Hue[0.36468233660870075`], AbsoluteThickness[0.5], 
    LineBox[{{4.328084447451636, 1.1300143877744993`}, {4.356502702671689, 
     1.390200550105208}}]}, 
   {Hue[0.5023373009279138], AbsoluteThickness[0.5], 
    LineBox[{{4.437081230983911, 0.3967259541207454}, {4.426859044604077, 
     0.36477070138475753`}}]}, 
   {Hue[0.503153180403674], AbsoluteThickness[0.5], 
    LineBox[{{4.426859044604077, 0.36477070138475753`}, {4.319098309622813, 
     0.10255172906913318`}}]}, 
   {Hue[0.02994058032871326], AbsoluteThickness[0.5], 
    LineBox[{{4.665137078625659, 0.4054507801867442}, {4.916104201405458, 
     0.43799839470735574`}}]}, 
   {Hue[0.030834529957675803`], AbsoluteThickness[0.5], 
    LineBox[{{4.916104201405458, 0.43799839470735574`}, {5.169304849603043, 
     0.49349686014600713`}}]}, 
   {Hue[0.5108293668866085], AbsoluteThickness[0.5], 
    LineBox[{{5.169304849603043, 0.49349686014600713`}, {5.003964204848791, 
     0.6931293201968985}}]}, 
   {Hue[0.5042292174939159], AbsoluteThickness[0.5], 
    LineBox[{{4.5603946019304935`, 0.6082181488860513}, {4.378093845906849, 
     0.8941776183589415}}]}, 
   {Hue[0.547247472579245], AbsoluteThickness[0.5], 
    LineBox[{{4.378093845906849, 0.8941776183589415}, {4.34368724697569, 
     1.0670251170640146`}}]}, 
   {Hue[0.654879679937884], AbsoluteThickness[0.5], 
    LineBox[{{4.34368724697569, 1.0670251170640146`}, {4.474800008947868, 
     1.184794024279106}}]}, 
   {Hue[0.3714634554607925], AbsoluteThickness[0.5], 
    LineBox[{{4.49079502644678, -0.11073964042706436`}, {
     4.559906356428303, -0.39257864191146796`}}]}, 
   {Hue[0.37231454439533096`], AbsoluteThickness[0.5], 
    LineBox[{{4.559906356428303, -0.39257864191146796`}, {
     4.602930845205276, -0.6641369398428141}}]}, 
   {Hue[0.5751354145948638], AbsoluteThickness[0.5], 
    LineBox[{{3.1043868007369175`, -0.2838888955190176}, {
     3.0704113245616727`, -0.3204366029945327}}]}, 
   {Hue[0.5756302133674336], AbsoluteThickness[0.5], 
    LineBox[{{3.0704113245616727`, -0.3204366029945327}, {
     2.872041463125974, -0.5499416955342045}}]}, 
   {Hue[0.5632204682252959], AbsoluteThickness[0.5], 
    LineBox[{{4.1247085584548495`, -0.8218945796164712}, {
     4.123192519573862, -0.8949994211060319}}]}, 
   {Hue[0.5645263017657878], AbsoluteThickness[0.5], 
    LineBox[{{4.123192519573862, -0.8949994211060319}, {
     4.089438586324126, -1.1473366799732305`}}]}, 
   {Hue[0.3583807229765098], AbsoluteThickness[0.5], 
    LineBox[{{4.258482507852719, -0.9290624504732728}, {
     4.358573036354729, -0.9730726697319552}}]}, 
   {Hue[0.3589896204812675], AbsoluteThickness[0.5], 
    LineBox[{{4.358573036354729, -0.9730726697319552}, {
     4.6262989754744615`, -1.0729037115829547`}}]}, 
   {Hue[0.5859254543141303], AbsoluteThickness[0.5], 
    LineBox[{{4.4087538605964935`, -0.8466067494815299}, {
     4.5886371250438085`, -0.6746017765777904}}]}, 
   {Hue[0.6167368070474589], AbsoluteThickness[0.5], 
    LineBox[{{4.5886371250438085`, -0.6746017765777904}, {
     4.660826431990412, -0.5307314230940288}}]}, 
   {Hue[0.6519727213169982], AbsoluteThickness[0.5], 
    LineBox[{{2.6428324755735395`, -0.761421695897005}, {
     2.519331834821384, -0.855840208748176}}]}, 
   {Hue[0.6531669212448115], AbsoluteThickness[0.5], 
    LineBox[{{2.519331834821384, -0.855840208748176}, {
     2.3100955296172025`, -1.054355589573939}}]}, 
   {Hue[0.6568217477016645], AbsoluteThickness[0.5], 
    LineBox[{{3.0162205194355254`, -2.65489300459902}, {
     2.981643880278723, -2.8284075828128707`}}]}, 
   {Hue[0.6573395859785963], AbsoluteThickness[0.5], 
    LineBox[{{2.981643880278723, -2.8284075828128707`}, {
     2.930286895460987, -3.156758505520581}}]}, 
   {Hue[0.6113399924212376], AbsoluteThickness[0.5], 
    LineBox[{{3.9209158724811153`, -2.2394375318163497`}, {
     4.121418218061436, -2.3354182456271126`}}]}, 
   {Hue[0.6203828051016493], AbsoluteThickness[0.5], 
    LineBox[{{4.121418218061436, -2.3354182456271126`}, {
     4.303221756540129, -2.372777606521038}}]}, 
   {Hue[0.6989411476340883], AbsoluteThickness[0.5], 
    LineBox[{{4.399131192434798, -0.6879434961065193}, {
     4.428306944287558, -0.6824002030611167}}]}, 
   {Hue[0.5505878545477585], AbsoluteThickness[0.5], 
    LineBox[{{2.13868860700938, -3.8463699907697473`}, {
     2.1401776200995464`, -3.8703744072734554`}}]}, 
   {Hue[0.5536648384664313], AbsoluteThickness[0.5], 
    LineBox[{{2.1401776200995464`, -3.8703744072734554`}, {
     2.181596714296033, -4.047370854599717}}]}, 
   {Hue[0.5242529983373011], AbsoluteThickness[0.5], 
    LineBox[{{3.401271406897694, -3.885758925182923}, {
     3.401745676734339, -3.982256704888549}}]}, 
   {Hue[0.5317258602347265], AbsoluteThickness[0.5], 
    LineBox[{{3.401745676734339, -3.982256704888549}, {
     3.445359949645161, -4.16479305517278}}]}, 
   {Hue[0.5141844214988354], AbsoluteThickness[0.5], 
    LineBox[{{4.915972694255348, -2.2819204449995443`}, {
     5.057083590643016, -2.2856226911221245`}}]}, 
   {Hue[0.514702573510796], AbsoluteThickness[0.5], 
    LineBox[{{5.057083590643016, -2.2856226911221245`}, {
     5.382363156587488, -2.280619182571443}}]}, 
   {Hue[0.6169629216426289], AbsoluteThickness[0.5], 
    LineBox[{{3.7477771064635728`, -0.5840602452804161}, {
     3.8168398742851455`, -0.3743327487841506}}]}, 
   {Hue[0.620086259968883], AbsoluteThickness[0.5], 
    LineBox[{{3.8168398742851455`, -0.3743327487841506}, {
     3.8509368454384716`, -0.14749868273333522`}}]}, 
   {Hue[0.5815589961226026], AbsoluteThickness[0.5], 
    LineBox[{{3.844545781496441, -4.441018088305729}, {
     3.8803811801200676`, -4.442842089316454}}]}, 
   {Hue[0.5820604963287552], AbsoluteThickness[0.5], 
    LineBox[{{3.8803811801200676`, -4.442842089316454}, {
     4.18876420918295, -4.470264040527862}}]}, 
   {Hue[0.5305779874834379], AbsoluteThickness[0.5], 
    LineBox[{{3.3319283654551537`, -0.1394999076378219}, {
     3.3404240117050903`, -0.13722128383383958`}}]}, 
   {Hue[0.5314977657541674], AbsoluteThickness[0.5], 
    LineBox[{{3.3404240117050903`, -0.13722128383383958`}, {
     3.5947493312535497`, -0.0927125086619691}}]}, 
   {Hue[0.49888957036404935`], AbsoluteThickness[0.5], 
    LineBox[{{3.9613647483339505`, 0.7066963543146088}, {4.090785769215985, 
     0.8938668542857668}}]}, 
   {Hue[0.508892981888928], AbsoluteThickness[0.5], 
    LineBox[{{4.090785769215985, 0.8938668542857668}, {4.172312201551862, 
     0.9645654039218462}}]}, 
   {Hue[0.4541509716911898], AbsoluteThickness[0.5], 
    LineBox[{{5.117970787198835, -2.455620437655351}, {
     5.185042711013411, -2.5571160238925486`}}]}, 
   {Hue[0.4546397349958439], AbsoluteThickness[0.5], 
    LineBox[{{5.185042711013411, -2.5571160238925486`}, {
     5.36088310168888, -2.844345473113697}}]}, 
   {Hue[0.6121471341102611], AbsoluteThickness[0.5], 
    LineBox[{{3.1007759154558303`, -1.7902323279789494`}, {
     3.1117850257075648`, -1.883321643926921}}]}, 
   {Hue[0.6129169607567655], AbsoluteThickness[0.5], 
    LineBox[{{3.1117850257075648`, -1.883321643926921}, {
     3.1227897861535574`, -2.1473478631662033`}}]}, 
   {Hue[0.5286018718031583], AbsoluteThickness[0.5], 
    LineBox[{{3.7274248220795267`, -1.3947485842721337`}, {
     3.970516655893753, -1.894404624590852}}]}, 
   {Hue[0.5291587758793563], AbsoluteThickness[0.5], 
    LineBox[{{3.970516655893753, -1.894404624590852}, {
     4.070116070943026, -2.127574405579164}}]}, 
   {Hue[0.5407994483059295], AbsoluteThickness[0.5], 
    LineBox[{{2.908002025708583, -0.13596693165603835`}, {
     2.8841346875768807`, -0.14454226534230563`}}]}, 
   {Hue[0.5413652816078467], AbsoluteThickness[0.5], 
    LineBox[{{2.8841346875768807`, -0.14454226534230563`}, {
     2.6121947735827535`, -0.2581011728659748}}]}, 
   {Hue[0.5563652004342468], AbsoluteThickness[0.5], 
    LineBox[{{3.119539377966469, 0.14853370989275866`}, {2.655691006749438, 
     0.020695605397598064`}}]}, 
   {Hue[0.5567956504691087], AbsoluteThickness[0.5], 
    LineBox[{{2.655691006749438, 0.020695605397598064`}, {
     2.3229832627797613`, -0.06760420621461552}}]}, 
   {Hue[0.4775124238954984], AbsoluteThickness[0.5], 
    LineBox[{{4.097640180602828, 0.7197314167616415}, {3.9060247893182547`, 
     0.8344548776971155}}]}, 
   {Hue[0.4791627038709632], AbsoluteThickness[0.5], 
    LineBox[{{3.9060247893182547`, 0.8344548776971155}, {3.6883927250872293`, 
     0.929580278790068}}]}, 
   {Hue[0.014426135815244967`], AbsoluteThickness[0.5], 
    LineBox[{{4.298837142995916, 0.9056755606784739}, {4.348002517568493, 
     0.942983522354338}}]}, 
   {Hue[0.014905504141515568`], AbsoluteThickness[0.5], 
    LineBox[{{4.348002517568493, 0.942983522354338}, {4.631017753262138, 
     1.1438017594855563`}}]}, 
   {Hue[0.5578627297253594], AbsoluteThickness[0.5], 
    LineBox[{{4.631017753262138, 1.1438017594855563`}, {4.464336560092193, 
     0.8394286860334795}}]}, 
   {Hue[0.47958359211567014`], AbsoluteThickness[0.5], 
    LineBox[{{4.396327160415123, 0.6496459943452623}, {4.427756484500875, 
     0.5347126792425215}}]}, 
   {Hue[0.48119317486607066`], AbsoluteThickness[0.5], 
    LineBox[{{4.427756484500875, 0.5347126792425215}, {4.506327584579076, 
     0.34504051436732264`}}]}, 
   {Hue[0.5616515131072083], AbsoluteThickness[0.5], 
    LineBox[{{3.895877214233578, -0.06970548479154026}, {
     3.9069359963231944`, -0.35848292749818567`}}]}, 
   {Hue[0.5622675008706356], AbsoluteThickness[0.5], 
    LineBox[{{3.9069359963231944`, -0.35848292749818567`}, {
     3.9341723791717165`, -0.6394747690206163}}]}, 
   {Hue[0.5432014671058613], AbsoluteThickness[0.5], 
    LineBox[{{3.708030344303194, -0.8622903506661785}, {
     3.7029660642838844`, -0.905522142348893}}]}, 
   {Hue[0.5496281275274572], AbsoluteThickness[0.5], 
    LineBox[{{3.7029660642838844`, -0.905522142348893}, {
     3.638132910570667, -1.091595457015449}}]}, 
   {Hue[0.6500606936470129], AbsoluteThickness[0.5], 
    LineBox[{{2.2909519346586746`, -0.12258343741815493`}, {
     2.1441268510293403`, -0.07482969097122466}}]}, 
   {Hue[0.6504874514995976], AbsoluteThickness[0.5], 
    LineBox[{{2.1441268510293403`, -0.07482969097122466}, {
     1.7766056597911652`, 0.042990447430278356`}}]}, 
   {Hue[0.5911796321431632], AbsoluteThickness[0.5], 
    LineBox[{{2.1432995060760303`, -0.18245085412750045`}, {
     2.021015462764307, -0.2933235047226021}}]}, 
   {Hue[0.5922663378281766], AbsoluteThickness[0.5], 
    LineBox[{{2.021015462764307, -0.2933235047226021}, {
     1.8464146066656095`, -0.4867948242984278}}]}, 
   {Hue[0.571215544061682], AbsoluteThickness[0.5], 
    LineBox[{{2.599617653095895, -4.19535781965024}, {
     2.1367530315442353`, -4.605979915422519}}]}, 
   {Hue[0.5804810189572019], AbsoluteThickness[0.5], 
    LineBox[{{2.1367530315442353`, -4.605979915422519}, {
     1.970053679429226, -4.692772825796842}}]}, 
   {Hue[0.6684275142844336], AbsoluteThickness[0.5], 
    LineBox[{{3.2725711112263487`, -4.398729225510076}, {
     3.3028491815458554`, -4.4669124653056285`}}]}, 
   {Hue[0.669425432763559], AbsoluteThickness[0.5], 
    LineBox[{{3.3028491815458554`, -4.4669124653056285`}, {
     3.443364383551205, -4.716770973058752}}]}, 
   {Hue[0.46140557806913846`], AbsoluteThickness[0.5], 
    LineBox[{{3.4174906615261245`, -3.1044958882003186`}, {
     3.464571171216305, -3.329307529583912}}]}, 
   {Hue[0.461919148893945], AbsoluteThickness[0.5], 
    LineBox[{{3.464571171216305, -3.329307529583912}, {
     3.5355722169225214`, -3.610830296256864}}]}, 
   {Hue[0.5730891077966362], AbsoluteThickness[0.5], 
    LineBox[{{2.4251862500558343`, -0.6476146190622353}, {
     2.3773757882684055`, -0.6531688489270813}}]}, 
   {Hue[0.5735378449389373], AbsoluteThickness[0.5], 
    LineBox[{{2.3773757882684055`, -0.6531688489270813}, {
     2.0533148580585987`, -0.697766408755024}}]}, 
   {Hue[0.5591673672290063], AbsoluteThickness[0.5], 
    LineBox[{{3.194959763043209, -1.4066333209275217`}, {
     3.1663264402903892`, -1.4500167782328033`}}]}, 
   {Hue[0.5600210750501322], AbsoluteThickness[0.5], 
    LineBox[{{3.1663264402903892`, -1.4500167782328033`}, {
     2.993045356880677, -1.6701177895284713`}}]}, 
   {Hue[0.5239160627197701], AbsoluteThickness[0.5], 
    LineBox[{{4.579080526750309, -0.6803480603409489}, {
     4.576073729758322, -0.8274116446827098}}]}, 
   {Hue[0.5244846382211462], AbsoluteThickness[0.5], 
    LineBox[{{4.576073729758322, -0.8274116446827098}, {
     4.555344940697731, -1.1166237906649132`}}]}, 
   {Hue[0.4783214210357365], AbsoluteThickness[0.5], 
    LineBox[{{5.140157044809715, -0.002453587097661636}, {
     5.156192080025614, -0.06923341400413527}}]}, 
   {Hue[0.4790162305600502], AbsoluteThickness[0.5], 
    LineBox[{{5.156192080025614, -0.06923341400413527}, {
     5.253061036184714, -0.37810788680841895`}}]}, 
   {Hue[0.5556524869726986], AbsoluteThickness[0.5], 
    LineBox[{{4.956964695785292, 0.8416904478284554}, {4.959435063325379, 
     0.6794348117704834}}]}, 
   {Hue[0.5562531012547228], AbsoluteThickness[0.5], 
    LineBox[{{4.959435063325379, 0.6794348117704834}, {4.979527091609839, 
     0.3983543963712262}}]}, 
   {Hue[0.018402810870454686`], AbsoluteThickness[0.5], 
    LineBox[{{5.126178237952539, 1.114198578747892}, {5.126489653930631, 
     1.1147454133537078`}}]}, 
   {Hue[0.018854689449220606`], AbsoluteThickness[0.5], 
    LineBox[{{5.126489653930631, 1.1147454133537078`}, {5.29528763204957, 
     1.3962325852174842`}}]}, 
   {Hue[0.5677844400417462], AbsoluteThickness[0.5], 
    LineBox[{{5.29528763204957, 1.3962325852174842`}, {5.224069537822892, 
     1.075833196335999}}]}, 
   {Hue[0.5566568679450865], AbsoluteThickness[0.5], 
    LineBox[{{4.8419841293515, 0.9654450480118034}, {4.425426690763544, 
     0.7268252588551792}}]}, 
   {Hue[0.5575387385397073], AbsoluteThickness[0.5], 
    LineBox[{{4.425426690763544, 0.7268252588551792}, {4.16858720689973, 
     0.6076767153707066}}]}, 
   {Hue[0.46873320437762794`], AbsoluteThickness[0.5], 
    LineBox[{{4.336721111390517, 0.9832711839479705}, {4.191622344076222, 
     1.0569461588186566`}}]}, 
   {Hue[0.4694982125246163], AbsoluteThickness[0.5], 
    LineBox[{{4.191622344076222, 1.0569461588186566`}, {3.9337523145171382`, 
     1.1642251909044765`}}]}, 
   {Hue[0.5284686797206055], AbsoluteThickness[0.5], 
    LineBox[{{3.347704197658437, 0.5887943475578863}, {3.185108499917856, 
     0.5442372824011829}}]}, 
   {Hue[0.5289360109746531], AbsoluteThickness[0.5], 
    LineBox[{{3.185108499917856, 0.5442372824011829}, {2.899215867751619, 
     0.4745175120330984}}]}, 
   {Hue[0.5611448764005306], AbsoluteThickness[0.5], 
    LineBox[{{2.558807073214661, 0.22204114600724026`}, {2.322313689189595, 
     0.26500651050332086`}}]}, 
   {Hue[0.5615748664681816], AbsoluteThickness[0.5], 
    LineBox[{{2.322313689189595, 0.26500651050332086`}, {2.085577862160112, 
     0.3058129997394623}}]}, 
   {Hue[0.570688083453934], AbsoluteThickness[0.5], 
    LineBox[{{2.8975364589647024`, -1.1186542487304942`}, {
     2.8940665022196996`, -1.1225151761236594`}}]}, 
   {Hue[0.5711140708417354], AbsoluteThickness[0.5], 
    LineBox[{{2.8940665022196996`, -1.1225151761236594`}, {
     2.6955577071126555`, -1.3441123990592472`}}]}, 
   {Hue[0.6144379158913341], AbsoluteThickness[0.5], 
    LineBox[{{2.6904392574098814`, -1.8971275291525094`}, {
     2.62571070599671, -1.9004244326474686`}}]}, 
   {Hue[0.6149578335794887], AbsoluteThickness[0.5], 
    LineBox[{{2.62571070599671, -1.9004244326474686`}, {
     2.3187547323913162`, -1.9290164642633}}]}, 
   {Hue[0.466526316274885], AbsoluteThickness[0.5], 
    LineBox[{{4.311429297359505, -3.870205764951446}, {
     4.3777566891820845`, -3.986455560721802}}]}, 
   {Hue[0.46840214815028147`], AbsoluteThickness[0.5], 
    LineBox[{{4.3777566891820845`, -3.986455560721802}, {
     4.512307747935011, -4.161929648261025}}]}, 
   {Hue[0.5595157112488437], AbsoluteThickness[0.5], 
    LineBox[{{5.165635998102884, -3.5060580465839615`}, {
     5.327276231908237, -3.572475760481111}}]}, 
   {Hue[0.5606263309447593], AbsoluteThickness[0.5], 
    LineBox[{{5.327276231908237, -3.572475760481111}, {
     5.586033213136125, -3.6492096694368454`}}]}, 
   {Hue[0.2517176903052384], AbsoluteThickness[0.5], 
    LineBox[{{5.164343881056505, 0.6049030481057666}, {5.191440709558567, 
     0.6135661780294586}}]}, 
   {Hue[0.25400555801857483`], AbsoluteThickness[0.5], 
    LineBox[{{5.191440709558567, 0.6135661780294586}, {5.384954384187497, 
     0.7089481355031108}}]}, 
   {Hue[0.6394390087017174], AbsoluteThickness[0.5], 
    LineBox[{{5.384954384187497, 0.7089481355031108}, {5.2876174936953975`, 
     0.9014858975894767}}]}, 
   {Hue[0.5764139511483657], AbsoluteThickness[0.5], 
    LineBox[{{2.891999297777917, -0.8704330020873585}, {
     2.892037884276396, -0.8728275392156326}}]}, 
   {Hue[0.5771739451358017], AbsoluteThickness[0.5], 
    LineBox[{{2.892037884276396, -0.8728275392156326}, {
     2.915342894437466, -1.1276065987960056`}}]}, 
   {Hue[0.5877535369973645], AbsoluteThickness[0.5], 
    LineBox[{{3.416849354965225, 0.7001792765211605}, {3.839101424119106, 
     0.4972925159019191}}]}, 
   {Hue[0.5889523155523382], AbsoluteThickness[0.5], 
    LineBox[{{3.839101424119106, 0.4972925159019191}, {4.089760435622246, 
     0.4082638014429499}}]}, 
   {Hue[0.5794679705594331], AbsoluteThickness[0.5], 
    LineBox[{{3.1568858531110866`, 1.4711916389828747`}, {3.284422441895183, 
     1.4168829443574233`}}]}, 
   {Hue[0.5870670223509006], AbsoluteThickness[0.5], 
    LineBox[{{3.284422441895183, 1.4168829443574233`}, {3.4165796844797143`, 
     1.319830164350574}}]}, 
   {Hue[0.5746476914721161], AbsoluteThickness[0.5], 
    LineBox[{{2.2262734739843877`, 1.6508151545833287`}, {2.186656915114887, 
     1.5230489011144468`}}]}, 
   {Hue[0.5973163762600338], AbsoluteThickness[0.5], 
    LineBox[{{2.186656915114887, 1.5230489011144468`}, {2.075759357699447, 
     1.3669085437174588`}}]}, 
   {Hue[0.5824801752786526], AbsoluteThickness[0.5], 
    LineBox[{{2.4553658991945575`, 2.8227181096173823`}, {2.4405479678113124`,
      2.681572816688093}}]}, 
   {Hue[0.5831653325862358], AbsoluteThickness[0.5], 
    LineBox[{{2.4405479678113124`, 2.681572816688093}, {2.4300385752989495`, 
     2.4011279207609886`}}]}, 
   {Hue[0.029398495380904263`], AbsoluteThickness[0.5], 
    LineBox[{{2.4442065604453065`, 3.1392798768585024`}, {2.4395402838905484`,
      3.3175580534084768`}}]}, 
   {Hue[0.030128816204666252`], AbsoluteThickness[0.5], 
    LineBox[{{2.4395402838905484`, 3.3175580534084768`}, {2.4537550958978676`,
      3.626801543844461}}]}, 
   {Hue[0.5305347097885421], AbsoluteThickness[0.5], 
    LineBox[{{2.4537550958978676`, 3.626801543844461}, {2.6959441012932404`, 
     3.4339853543710817`}}]}, 
   {Hue[0.5833402408276708], AbsoluteThickness[0.5], 
    LineBox[{{2.496549054894154, 2.8268760571075044`}, {2.517650154593274, 
     2.693525586194573}}]}, 
   {Hue[0.5838189295289944], AbsoluteThickness[0.5], 
    LineBox[{{2.517650154593274, 2.693525586194573}, {2.5554739994304447`, 
     2.392820709546808}}]}, 
   {Hue[0.5755990736076696], AbsoluteThickness[0.5], 
    LineBox[{{2.7618915889961704`, 2.0800988358829584`}, {2.8510682654980593`,
      1.91100085711222}}]}, 
   {Hue[0.578658979514088], AbsoluteThickness[0.5], 
    LineBox[{{2.8510682654980593`, 1.91100085711222}, {2.9165029292430855`, 
     1.7120448573773035`}}]}, 
   {Hue[0.5785119750603054], AbsoluteThickness[0.5], 
    LineBox[{{3.6707414689482185`, -1.582507796499523}, {
     3.71269912291465, -1.655941695932729}}]}, 
   {Hue[0.5793497363780619], AbsoluteThickness[0.5], 
    LineBox[{{3.71269912291465, -1.655941695932729}, {
     3.81138591091258, -1.867271881185408}}]}, 
   {Hue[0.5395543050168149], AbsoluteThickness[0.5], 
    LineBox[{{4.088706606993858, -1.552458228890774}, {
     4.132363224271533, -1.584175532879348}}]}, 
   {Hue[0.5400647831245676], AbsoluteThickness[0.5], 
    LineBox[{{4.132363224271533, -1.584175532879348}, {
     4.40622252463615, -1.8003513765572345`}}]}, 
   {Hue[0.6618484860184516], AbsoluteThickness[0.5], 
    LineBox[{{2.90080222810362, 2.1112373083962646`}, {2.9251635684157935`, 
     2.343229455698278}}]}, 
   {Hue[0.6624879063556692], AbsoluteThickness[0.5], 
    LineBox[{{2.9251635684157935`, 2.343229455698278}, {2.9820464542371536`, 
     2.6824298242387385`}}]}, 
   {Hue[0.5356775510530256], AbsoluteThickness[0.5], 
    LineBox[{{4.42607923087754, 0.7549780465754505}, {4.4982451322919, 
     0.8333358680483712}}]}, 
   {Hue[0.5366395728364841], AbsoluteThickness[0.5], 
    LineBox[{{4.4982451322919, 0.8333358680483712}, {4.6800793411320205`, 
     1.0713399334832834`}}]}, 
   {Hue[0.2937863925861336], AbsoluteThickness[0.5], 
    LineBox[{{4.9108503612329555`, -0.7717466946244831}, {
     5.07013378816538, -0.8120538711539176}}]}, 
   {Hue[0.29459222619081576`], AbsoluteThickness[0.5], 
    LineBox[{{5.07013378816538, -0.8120538711539176}, {
     5.325080940614883, -0.8554067366445256}}]}, 
   {Hue[0.5538657709377506], AbsoluteThickness[0.5], 
    LineBox[{{3.670191454039778, -1.921393551906197}, {
     3.6869145842777113`, -2.129398183801039}}]}, 
   {Hue[0.5551888366251023], AbsoluteThickness[0.5], 
    LineBox[{{3.6869145842777113`, -2.129398183801039}, {
     3.7276451287722563`, -2.3374553711708765`}}]}, 
   {Hue[0.5730319480538405], AbsoluteThickness[0.5], 
    LineBox[{{2.7489515606340333`, -1.896776597530402}, {
     2.734275555157212, -2.053876348544752}}]}, 
   {Hue[0.573460612782714], AbsoluteThickness[0.5], 
    LineBox[{{2.734275555157212, -2.053876348544752}, {
     2.7018848520677237`, -2.374800745891865}}]}, 
   {Hue[0.4876506518562534], AbsoluteThickness[0.5], 
    LineBox[{{4.613088873014978, 0.3548626097473871}, {4.620874611240969, 
     0.3524563203347966}}]}, 
   {Hue[0.4881589529819419], AbsoluteThickness[0.5], 
    LineBox[{{4.620874611240969, 0.3524563203347966}, {4.866235095972698, 
     0.2658899249132473}}]}, 
   {Hue[0.31352061746932997`], AbsoluteThickness[0.5], 
    LineBox[{{3.671117109764292, 2.020257154454116}, {4.085230158198107, 
     2.189041360788817}}]}, 
   {Hue[0.3139466134638051], AbsoluteThickness[0.5], 
    LineBox[{{4.085230158198107, 2.189041360788817}, {4.391390388949588, 
     2.313229140964039}}]}, 
   {Hue[0.418326327971902], AbsoluteThickness[0.5], 
    LineBox[{{2.65035634237969, 1.8682424440836503`}, {2.5555657946828645`, 
     1.8552848645092674`}}]}, 
   {Hue[0.4231258764403467], AbsoluteThickness[0.5], 
    LineBox[{{2.5555657946828645`, 1.8552848645092674`}, {2.3860423127182275`,
      1.8658395690152396`}}]}, 
   {Hue[0.09502468568013081], AbsoluteThickness[0.5], 
    LineBox[{{2.890321390842795, 2.225731054309474}, {2.9175721093547935`, 
     2.3484633668658605`}}]}, 
   {Hue[0.0956001686331912], AbsoluteThickness[0.5], 
    LineBox[{{2.9175721093547935`, 2.3484633668658605`}, {3.0116467868853407`,
      2.6874111153950353`}}]}, 
   {Hue[0.6200817030494242], AbsoluteThickness[0.5], 
    LineBox[{{3.0116467868853407`, 2.6874111153950353`}, {3.162789103474615, 
     2.3697767008214554`}}]}, 
   {Hue[0.22394859696728778`], AbsoluteThickness[0.5], 
    LineBox[{{2.8303990840176247`, 2.3868845309562006`}, {2.6560994633846904`,
      2.56044282842141}}]}, 
   {Hue[0.2261807032377456], AbsoluteThickness[0.5], 
    LineBox[{{2.6560994633846904`, 2.56044282842141}, {2.4775859008800314`, 
     2.692346750859544}}]}, 
   {Hue[0.6140875486270945], AbsoluteThickness[0.5], 
    LineBox[{{2.4775859008800314`, 2.692346750859544}, {2.3491529950487253`, 
     2.511319886962505}}]}, 
   {Hue[0.2770083508374036], AbsoluteThickness[0.5], 
    LineBox[{{2.662199417619902, 2.4225215638611965`}, {2.578892363031384, 
     2.4036516519587927`}}]}, 
   {Hue[0.29116449787529586`], AbsoluteThickness[0.5], 
    LineBox[{{2.578892363031384, 2.4036516519587927`}, {2.410847975523442, 
     2.4130280109571176`}}]}, 
   {Hue[0.4977089591709782], AbsoluteThickness[0.5], 
    LineBox[{{2.410847975523442, 2.4130280109571176`}, {2.3498266585744396`, 
     2.5698821825904985`}}]}, 
   {Hue[0.33006810470751424`], AbsoluteThickness[0.5], 
    LineBox[{{2.542071365513782, 2.299515966477313}, {2.471612872527464, 
     2.101608954846219}}]}, 
   {Hue[0.33062299316469973`], AbsoluteThickness[0.5], 
    LineBox[{{2.471612872527464, 2.101608954846219}, {2.3975762742192255`, 
     1.8564373303561725`}}]}, 
   {Hue[0.38312785857762227`], AbsoluteThickness[0.5], 
    LineBox[{{2.5816792257406163`, 2.1322068415055164`}, {2.7419581941578115`,
      1.9273832911709867`}}]}, 
   {Hue[0.3837407698583639], AbsoluteThickness[0.5], 
    LineBox[{{2.7419581941578115`, 1.9273832911709867`}, {2.9053838705261663`,
      1.6915916064898158`}}]}, 
   {Hue[0.43618761244771886`], AbsoluteThickness[0.5], 
    LineBox[{{2.74420575343871, 2.0761153654598874`}, {2.8789606288799083`, 
     2.0895290852816992`}}]}, 
   {Hue[0.43756781989129373`], AbsoluteThickness[0.5], 
    LineBox[{{2.8789606288799083`, 2.0895290852816992`}, {3.121751090010434, 
     2.0854904925192193`}}]}, 
   {Hue[0.4892473663178144], AbsoluteThickness[0.5], 
    LineBox[{{2.8785754062154014`, 2.183381027734672}, {2.951639050795792, 
     2.3288112953721516`}}]}, 
   {Hue[0.48967489847798895`], AbsoluteThickness[0.5], 
    LineBox[{{2.951639050795792, 2.3288112953721516`}, {3.1181313831665896`, 
     2.665013953924143}}]}, 
   {Hue[0.5423071201879148], AbsoluteThickness[0.5], 
    LineBox[{{2.8598856930012864`, 2.3542956862942894`}, {2.7145675290434816`,
      2.5964727392995273`}}]}, 
   {Hue[0.543202265547484], AbsoluteThickness[0.5], 
    LineBox[{{2.7145675290434816`, 2.5964727392995273`}, {2.5982775007980297`,
      2.835041771969929}}]}, 
   {Hue[0.5953668740579968], AbsoluteThickness[0.5], 
    LineBox[{{2.7055095227053085`, 2.4299866628722397`}, {2.615242413993646, 
     2.432182569936105}}]}, 
   {Hue[0.5965280251143309], AbsoluteThickness[0.5], 
    LineBox[{{2.615242413993646, 2.432182569936105}, {2.365611798758583, 
     2.4645273848257925`}}]}, 
   {Hue[0.648426627928088], AbsoluteThickness[0.5], 
    LineBox[{{2.558946322715039, 2.340095871913494}, {2.26841070049422, 
     1.9053266326415652`}}]}, 
   {Hue[0.6496131977137215], AbsoluteThickness[0.5], 
    LineBox[{{2.26841070049422, 1.9053266326415652`}, {2.1668295928704393`, 
     1.7116939229148214`}}]}, 
   {Hue[0.4255132565056498], AbsoluteThickness[0.5], 
    LineBox[{{3.4185276209826, 2.126029066781672}, {3.5797882213529095`, 
     2.166477419855079}}]}, 
   {Hue[0.42595620098123094`], AbsoluteThickness[0.5], 
    LineBox[{{3.5797882213529095`, 2.166477419855079}, {3.832037190564209, 
     2.234670245600436}}]}, 
   {Hue[0.6394999875128806], AbsoluteThickness[0.5], 
    LineBox[{{2.300004252940477, 1.0651795286805303`}, {2.156473193497614, 
     0.9642723179065449}}]}, 
   {Hue[0.6410905134003678], AbsoluteThickness[0.5], 
    LineBox[{{2.156473193497614, 0.9642723179065449}, {1.9294173035234974`, 
     0.8438241786444898}}]}, 
   {Hue[0.4664199306197362], AbsoluteThickness[0.5], 
    LineBox[{{4.353830044473137, 1.1471386136928445`}, {4.392595523613329, 
     1.142313677611904}}]}, 
   {Hue[0.46750202934329854`], AbsoluteThickness[0.5], 
    LineBox[{{4.392595523613329, 1.142313677611904}, {4.677743162875105, 
     1.0774489353402452`}}]}, 
   {Hue[0.6013382534558649], AbsoluteThickness[0.5], 
    LineBox[{{4.066453256022715, -2.130809726213391}, {
     4.097593981750876, -2.1438583685413506`}}]}, 
   {Hue[0.6017742857212991], AbsoluteThickness[0.5], 
    LineBox[{{4.097593981750876, -2.1438583685413506`}, {
     4.39387803801167, -2.2729587090565953`}}]}, 
   {Hue[0.5157299496272861], AbsoluteThickness[0.5], 
    LineBox[{{5.3566224881569395`, -0.7821915536001413}, {
     5.51563881029458, -0.8698087453540041}}]}, 
   {Hue[0.5247153134716546], AbsoluteThickness[0.5], 
    LineBox[{{5.51563881029458, -0.8698087453540041}, {
     5.649247792446061, -0.9935118467388195}}]}, 
   {Hue[0.6307195738090278], AbsoluteThickness[0.5], 
    LineBox[{{2.408519678648831, -1.6324166623321517`}, {
     2.4068751848047687`, -1.653606736433653}}]}, 
   {Hue[0.6352270090109187], AbsoluteThickness[0.5], 
    LineBox[{{2.4068751848047687`, -1.653606736433653}, {
     2.356499694709475, -1.834818979365718}}]}, 
   {Hue[0.5309302946521917], AbsoluteThickness[0.5], 
    LineBox[{{3.6943331902074075`, 2.3487882701254557`}, {3.723685930449232, 
     2.6478280498851055`}}]}, 
   {Hue[0.5314643522031551], AbsoluteThickness[0.5], 
    LineBox[{{3.723685930449232, 2.6478280498851055`}, {3.759391032351048, 
     2.8963067065640513`}}]}, 
   {Hue[0.4260244019998557], AbsoluteThickness[0.5], 
    LineBox[{{3.19197115856725, 2.3553557690665468`}, {3.1623378121617125`, 
     2.369312183075841}}]}, 
   {Hue[0.42654303119045267`], AbsoluteThickness[0.5], 
    LineBox[{{3.1623378121617125`, 2.369312183075841}, {2.843573568852771, 
     2.536022186237316}}]}, 
   {Hue[0.5846801730769089], AbsoluteThickness[0.5], 
    LineBox[{{2.937759861217782, 1.8481331552513556`}, {2.9147853015418934`, 
     1.8431135440977373`}}]}, 
   {Hue[0.5851493883941438], AbsoluteThickness[0.5], 
    LineBox[{{2.9147853015418934`, 1.8431135440977373`}, {2.6198914423033774`,
      1.769697577794151}}]}, 
   {Hue[0.5914770221866452], AbsoluteThickness[0.5], 
    LineBox[{{3.1036720617805367`, 1.7735179706222566`}, {2.9285139219738845`,
      1.7983732323815393`}}]}, 
   {Hue[0.591970166389945], AbsoluteThickness[0.5], 
    LineBox[{{2.9285139219738845`, 1.7983732323815393`}, {2.6295476063155676`,
      1.8299410984632989`}}]}, 
   {Hue[0.5860721541392402], AbsoluteThickness[0.5], 
    LineBox[{{4.247010356843755, 1.5889830912845524`}, {4.163247021394698, 
     1.4698478168316425`}}]}, 
   {Hue[0.5916069234017249], AbsoluteThickness[0.5], 
    LineBox[{{4.163247021394698, 1.4698478168316425`}, {4.029935210352771, 
     1.345659009238371}}]}, 
   {Hue[0.5393238184246976], AbsoluteThickness[0.5], 
    LineBox[{{5.074015023527236, 2.237547479451589}, {4.58517547924136, 
     2.590398561071933}}]}, 
   {Hue[0.04830829747409242], AbsoluteThickness[0.5], 
    LineBox[{{5.33854629295506, 2.3679955772430166`}, {5.393692590609882, 
     2.3900380778646078`}}]}, 
   {Hue[0.04887263853250995], AbsoluteThickness[0.5], 
    LineBox[{{5.393692590609882, 2.3900380778646078`}, {5.683949227031474, 
     2.5233846235325736`}}]}, 
   {Hue[0.5753304012057154], AbsoluteThickness[0.5], 
    LineBox[{{5.683949227031474, 2.5233846235325736`}, {5.375374700117173, 
     2.605919328766012}}]}, 
   {Hue[0.5409019391866433], AbsoluteThickness[0.5], 
    LineBox[{{5.3069920653208165`, 2.074741712066606}, {5.270374826169663, 
     1.8791474048233952`}}]}, 
   {Hue[0.5414331106915686], AbsoluteThickness[0.5], 
    LineBox[{{5.270374826169663, 1.8791474048233952`}, {5.214160881866805, 
     1.6383828201660526`}}]}, 
   {Hue[0.5868983053284644], AbsoluteThickness[0.5], 
    LineBox[{{3.875348644171166, 1.9990605338250842`}, {3.66919537582917, 
     1.9839289163828941`}}]}, 
   {Hue[0.5873804817679897], AbsoluteThickness[0.5], 
    LineBox[{{3.66919537582917, 1.9839289163828941`}, {3.4128891061860096`, 
     1.973554069884928}}]}, 
   {Hue[0.593321852634273], AbsoluteThickness[0.5], 
    LineBox[{{3.734340156847673, 1.1576855262918428`}, {3.663258997445845, 
     1.1124722615448115`}}]}, 
   {Hue[0.5937549146155614], AbsoluteThickness[0.5], 
    LineBox[{{3.663258997445845, 1.1124722615448115`}, {3.401019743745326, 
     0.9412502664205687}}]}, 
   {Hue[0.3852126187823481], AbsoluteThickness[0.5], 
    LineBox[{{4.784525291916614, 0.5663326641501796}, {5.059613941115887, 
     0.19858179354965283`}}]}, 
   {Hue[0.3967479813853432], AbsoluteThickness[0.5], 
    LineBox[{{5.059613941115887, 0.19858179354965283`}, {5.198405079948534, 
     0.08948907531110878}}]}, 
   {Hue[0.6227625991304867], AbsoluteThickness[0.5], 
    LineBox[{{5.198405079948534, 0.08948907531110878}, {5.352597952318563, 
     0.17544696908135815`}}]}, 
   {Hue[0.5453389893854778], AbsoluteThickness[0.5], 
    LineBox[{{4.525693627236717, -0.11897958038450801`}, {
     4.598104254999193, -0.4140025578628632}}]}, 
   {Hue[0.5473037214550593], AbsoluteThickness[0.5], 
    LineBox[{{4.598104254999193, -0.4140025578628632}, {
     4.621835901029157, -0.6457941094011712}}]}, 
   {Hue[0.6059665059638483], AbsoluteThickness[0.5], 
    LineBox[{{3.46562600974435, -2.6726015423326617`}, {
     3.5357348359372636`, -2.809720700102243}}]}, 
   {Hue[0.607333485222584], AbsoluteThickness[0.5], 
    LineBox[{{3.5357348359372636`, -2.809720700102243}, {
     3.6230339038348536`, -3.043475130334787}}]}, 
   {Hue[0.6865058441084945], AbsoluteThickness[0.5], 
    LineBox[{{2.7973084901403107`, 1.9293201682834191`}, {2.8581038199797644`,
      2.1469198977324164`}}]}, 
   {Hue[0.6959768272931892], AbsoluteThickness[0.5], 
    LineBox[{{2.8581038199797644`, 2.1469198977324164`}, {2.8631994554352547`,
      2.3494034120335914`}}]}, 
   {Hue[0.2927932437373713], AbsoluteThickness[0.5], 
    LineBox[{{5.455779527888165, -0.1649333300957412}, {
     5.685559071715601, -0.18292771407293268`}}]}, 
   {Hue[0.29438751095241833`], AbsoluteThickness[0.5], 
    LineBox[{{5.685559071715601, -0.18292771407293268`}, {
     5.887195054990402, -0.22450114297365203`}}]}, 
   {Hue[0.6928522678057343], AbsoluteThickness[0.5], 
    LineBox[{{3.412449600404937, -2.647005356032891}, {
     3.4763421381129906`, -2.802346302165116}}]}, 
   {Hue[0.6933660650735601], AbsoluteThickness[0.5], 
    LineBox[{{3.4763421381129906`, -2.802346302165116}, {
     3.5810065881669577`, -3.089475931992088}}]}, 
   {Hue[0.6578061561692871], AbsoluteThickness[0.5], 
    LineBox[{{3.3885060107795724`, 1.8878918765186625`}, {3.318930014503819, 
     2.0704271783489934`}}]}, 
   {Hue[0.658268360352239], AbsoluteThickness[0.5], 
    LineBox[{{3.318930014503819, 2.0704271783489934`}, {3.2136054633634656`, 
     2.3704061378146886`}}]}, 
   {Hue[0.4564119257533197], AbsoluteThickness[0.5], 
    LineBox[{{2.968938335114981, -3.16986390557186}, {
     2.9577098483196322`, -3.3936648201762534`}}]}, 
   {Hue[0.4569636418696293], AbsoluteThickness[0.5], 
    LineBox[{{2.9577098483196322`, -3.3936648201762534`}, {
     2.9571195956218665`, -3.6977921604944206`}}]}, 
   {Hue[0.5779314391444474], AbsoluteThickness[0.5], 
    LineBox[{{4.78703558262428, -1.0757621193804605`}, {
     4.888498193442631, -1.0261310726428217`}}]}, 
   {Hue[0.5784248768529657], AbsoluteThickness[0.5], 
    LineBox[{{4.888498193442631, -1.0261310726428217`}, {
     5.1507075569410965`, -0.9093187516108442}}]}, 
   {Hue[0.39478952805145295`], AbsoluteThickness[0.5], 
    LineBox[{{4.274654803422165, -2.3820194931984733`}, {
     4.350937593987363, -2.4798090777847914`}}]}, 
   {Hue[0.3956597975783241], AbsoluteThickness[0.5], 
    LineBox[{{4.350937593987363, -2.4798090777847914`}, {
     4.525598323934774, -2.668278242739961}}]}, 
   {Hue[0.5988774219195875], AbsoluteThickness[0.5], 
    LineBox[{{3.253933874468722, -2.90773988958665}, {
     3.1778430669037814`, -3.0128561472044404`}}]}, 
   {Hue[0.6022158102109659], AbsoluteThickness[0.5], 
    LineBox[{{3.1778430669037814`, -3.0128561472044404`}, {
     3.0124985993287705`, -3.173468811635216}}]}, 
   {Hue[0.518673987781188], AbsoluteThickness[0.5], 
    LineBox[{{5.31347489928499, -0.02362023743364991}, {5.425758695108408, 
     0.026766821566061215`}}]}, 
   {Hue[0.5191544685534004], AbsoluteThickness[0.5], 
    LineBox[{{5.425758695108408, 0.026766821566061215`}, {5.637942021250768, 
     0.11385749333563341`}}]}, 
   {Hue[0.6623825043319694], AbsoluteThickness[0.5], 
    LineBox[{{2.9295195072603133`, 0.6452756085715027}, {2.9223844924026183`, 
     0.6995580253237254}}]}, 
   {Hue[0.6824589690772194], AbsoluteThickness[0.5], 
    LineBox[{{2.9223844924026183`, 0.6995580253237254}, {2.8493775599042275`, 
     0.8556383556194573}}]}, 
   {Hue[0.5901125501301526], AbsoluteThickness[0.5], 
    LineBox[{{2.849084613548839, -3.3933193634832923`}, {
     2.875470429793317, -3.4574528531387556`}}]}, 
   {Hue[0.5909345907009538], AbsoluteThickness[0.5], 
    LineBox[{{2.875470429793317, -3.4574528531387556`}, {
     3.0023509734820317`, -3.706513639910305}}]}, 
   {Hue[0.44241126888020255`], AbsoluteThickness[0.5], 
    LineBox[{{3.3570581450909547`, 2.379895606261965}, {3.3599581898129403`, 
     2.38959002800945}}]}, 
   {Hue[0.4430780100058984], AbsoluteThickness[0.5], 
    LineBox[{{3.3599581898129403`, 2.38959002800945}, {3.4600665634003063`, 
     2.6591124708123144`}}]}, 
   {Hue[0.5915888905769779], AbsoluteThickness[0.5], 
    LineBox[{{5.005455427726417, 0.39250075901065323`}, {5.102251515141763, 
     0.36470410355069993`}}]}, 
   {Hue[0.5923130368996061], AbsoluteThickness[0.5], 
    LineBox[{{5.102251515141763, 0.36470410355069993`}, {5.369122818861001, 
     0.266956855593384}}]}, 
   {Hue[0.572050401037387], AbsoluteThickness[0.5], 
    LineBox[{{5.14472231394781, 0.44861024535644956`}, {5.538982958579427, 
     0.8196658711047793}}]}, 
   {Hue[0.5750678248974348], AbsoluteThickness[0.5], 
    LineBox[{{5.538982958579427, 0.8196658711047793}, {5.6757222728810515`, 
     0.9998813017558928}}]}, 
   {Hue[0.6786865232542992], AbsoluteThickness[0.5], 
    LineBox[{{5.16761545401311, 0.5969997469855804}, {5.160659621602938, 
     0.628249291712081}}]}, 
   {Hue[0.6800167521383805], AbsoluteThickness[0.5], 
    LineBox[{{5.160659621602938, 0.628249291712081}, {5.135452087512763, 
     0.866133678726273}}]}, 
   {Hue[0.530328440155404], AbsoluteThickness[0.5], 
    LineBox[{{4.4131073162696675`, -3.602941589261029}, {
     4.555641268664587, -3.7546859543978455`}}]}, 
   {Hue[0.5313901380069792], AbsoluteThickness[0.5], 
    LineBox[{{4.555641268664587, -3.7546859543978455`}, {
     4.741797068861107, -3.917338199682835}}]}, 
   {Hue[0.5745645926205917], AbsoluteThickness[0.5], 
    LineBox[{{2.306277269148326, -3.358787510477874}, {
     2.1388891216458528`, -3.4419799020151878`}}]}, 
   {Hue[0.5750169162487285], AbsoluteThickness[0.5], 
    LineBox[{{2.1388891216458528`, -3.4419799020151878`}, {
     1.8546185335805976`, -3.5753118714648395`}}]}, 
   {Hue[0.6521798117925584], AbsoluteThickness[0.5], 
    LineBox[{{2.1392900170502025`, 2.89438398710967}, {2.135832861369907, 
     2.901133676046601}}]}, 
   {Hue[0.6528494575815322], AbsoluteThickness[0.5], 
    LineBox[{{2.135832861369907, 2.901133676046601}, {2.014524380409262, 
     3.104118691283712}}]}, 
   {Hue[0.6530856776408223], AbsoluteThickness[0.5], 
    LineBox[{{5.172443462141257, 0.5820588092193381}, {5.248920028847998, 
     0.6054594205593241}}]}, 
   {Hue[0.6729449242312824], AbsoluteThickness[0.5], 
    LineBox[{{5.248920028847998, 0.6054594205593241}, {5.379745568298565, 
     0.6955134168995504}}]}, 
   {Hue[0.6930769397109565], AbsoluteThickness[0.5], 
    LineBox[{{6.604281118647672, -3.1313791602940277`}, {
     6.609537627405712, -3.1344916820493167`}}]}, 
   {Hue[0.6935073381791217], AbsoluteThickness[0.5], 
    LineBox[{{6.609537627405712, -3.1344916820493167`}, {
     6.890948348469827, -3.3047371480504326`}}]}, 
   {Hue[0.5733538203984122], AbsoluteThickness[0.5], 
    LineBox[{{3.6802485641753515`, -3.5189101710261763`}, {
     3.725417864035083, -3.560864036883574}}]}, 
   {Hue[0.5739338335872692], AbsoluteThickness[0.5], 
    LineBox[{{3.725417864035083, -3.560864036883574}, {
     3.9579131397521676`, -3.8009611944189277`}}]}, 
   {Hue[0.46185282550643036`], AbsoluteThickness[0.5], 
    LineBox[{{3.285317833121037, -2.351331844754405}, {
     3.2533822714168323`, -2.5777489663631665`}}]}, 
   {Hue[0.46228004241270326`], AbsoluteThickness[0.5], 
    LineBox[{{3.2533822714168323`, -2.5777489663631665`}, {
     3.208800251604743, -2.9061259902604144`}}]}, 
   {Hue[0.6233070490357294], AbsoluteThickness[0.5], 
    LineBox[{{3.8245468937546936`, 1.4385522803070183`}, {3.8722138687463463`,
      1.457502568273203}}]}, 
   {Hue[0.6237461971509141], AbsoluteThickness[0.5], 
    LineBox[{{3.8722138687463463`, 1.457502568273203}, {4.148504562306456, 
     1.5622141217376697`}}]}, 
   {Hue[0.3391238102899944], AbsoluteThickness[0.5], 
    LineBox[{{2.889599785236892, 1.6462047643600732`}, {2.8822217725565222`, 
     1.6635533365186488`}}]}, 
   {Hue[0.3396611625371793], AbsoluteThickness[0.5], 
    LineBox[{{2.8822217725565222`, 1.6635533365186488`}, {2.754495564169349, 
     1.929578689187876}}]}, 
   {Hue[0.6310534063049039], AbsoluteThickness[0.5], 
    LineBox[{{2.6264240693090732`, 1.1083212590206737`}, {2.3732744022285965`,
      1.1150788108409506`}}]}, 
   {Hue[0.6320470355948825], AbsoluteThickness[0.5], 
    LineBox[{{2.3732744022285965`, 1.1150788108409508`}, {2.098065380224596, 
     1.1484815536237436`}}]}, 
   {Hue[0.36573057290110045`], AbsoluteThickness[0.5], 
    LineBox[{{4.356502702671689, 1.390200550105208}, {4.358839660412945, 
     1.6011129704857203`}}]}, 
   {Hue[0.36635835234568365`], AbsoluteThickness[0.5], 
    LineBox[{{4.358839660412945, 1.6011129704857203`}, {4.343878916477926, 
     1.9068335596074242`}}]}, 
   {Hue[0.503969059879434], AbsoluteThickness[0.5], 
    LineBox[{{4.319098309622813, 0.1025517290691331}, {
     4.2343244177942845`, -0.06424268573022085}}]}, 
   {Hue[0.5048886006019223], AbsoluteThickness[0.5], 
    LineBox[{{4.2343244177942845`, -0.06424268573022088}, {
     4.121612420112719, -0.34524851599201867`}}]}, 
   {Hue[0.5099354172576482], AbsoluteThickness[0.5], 
    LineBox[{{4.916104201405458, 0.43799839470735574`}, {4.861901501790627, 
     0.12847512756330134`}}]}, 
   {Hue[0.5136553754662672], AbsoluteThickness[0.5], 
    LineBox[{{4.861901501790627, 0.12847512756330134`}, {
     4.86340820383138, -0.07942368604342576}}]}, 
   {Hue[0.031728479586638346`], AbsoluteThickness[0.5], 
    LineBox[{{5.169304849603043, 0.49349686014600713`}, {5.318081509531999, 
     0.5399400793970732}}]}, 
   {Hue[0.032380861849745986`], AbsoluteThickness[0.5], 
    LineBox[{{5.318081509531999, 0.5399400793970733}, {5.631569481869561, 
     0.6164542386219324}}]}, 
   {Hue[0.5441873414194791], AbsoluteThickness[0.5], 
    LineBox[{{5.631569481869561, 0.6164542386219324}, {5.480729955501762, 
     0.3311884631644808}}]}, 
   {Hue[0.511723316515571], AbsoluteThickness[0.5], 
    LineBox[{{5.003964204848791, 0.6931293201968987}, {4.690685044745722, 
     1.0107463593579638`}}]}, 
   {Hue[0.5131197431577057], AbsoluteThickness[0.5], 
    LineBox[{{4.690685044745722, 1.0107463593579638`}, {4.473810454277735, 
     1.1845759033397314`}}]}, 
   {Hue[0.6118614248525566], AbsoluteThickness[0.5], 
    LineBox[{{4.378093845906849, 0.8941776183589415}, {4.191862733854361, 
     1.054218876781705}}]}, 
   {Hue[0.6132455135659222], AbsoluteThickness[0.5], 
    LineBox[{{4.191862733854361, 1.054218876781705}, {3.9866593162957247`, 
     1.1927696527612697`}}]}, 
   {Hue[0.5902657276645749], AbsoluteThickness[0.5], 
    LineBox[{{4.34368724697569, 1.0670251170640146`}, {4.358518224804768, 
     1.151120879767283}}]}, 
   {Hue[0.592294748186058], AbsoluteThickness[0.5], 
    LineBox[{{4.358518224804768, 1.151120879767283}, {4.366300897560018, 
     1.3810911319164552`}}]}, 
   {Hue[0.6978979350232141], AbsoluteThickness[0.5], 
    LineBox[{{4.474800008947868, 1.184794024279106}, {4.61433987619585, 
     1.2374418121509356`}}]}, 
   {Hue[0.698324708852512], AbsoluteThickness[0.5], 
    LineBox[{{4.61433987619585, 1.2374418121509356`}, {4.86034271500321, 
     1.3314563729565374`}}]}, 
   {Hue[0.3731656333298693], AbsoluteThickness[0.5], 
    LineBox[{{4.602930845205276, -0.6641369398428141}, {
     4.616987270382442, -0.8542877528185631}}]}, 
   {Hue[0.37466821843680875`], AbsoluteThickness[0.5], 
    LineBox[{{4.616987270382442, -0.8542877528185631}, {
     4.605693564104849, -1.0915471248585296`}}]}, 
   {Hue[0.5761250121400034], AbsoluteThickness[0.5], 
    LineBox[{{2.872041463125974, -0.5499416955342045}, {
     2.81002862733002, -0.6271665866615048}}]}, 
   {Hue[0.5768204207781085], AbsoluteThickness[0.5], 
    LineBox[{{2.81002862733002, -0.6271665866615048}, {
     2.661073537576901, -0.841079532332187}}]}, 
   {Hue[0.5658321353062796], AbsoluteThickness[0.5], 
    LineBox[{{4.089438586324126, -1.1473366799732305`}, {
     4.037125927813706, -1.3563758437874784`}}]}, 
   {Hue[0.5662882383635754], AbsoluteThickness[0.5], 
    LineBox[{{4.037125927813706, -1.3563758437874784`}, {
     3.9676447759930236`, -1.6079819570314533`}}]}, 
   {Hue[0.35959851798602516`], AbsoluteThickness[0.5], 
    LineBox[{{4.6262989754744615`, -1.0729037115829547`}, {
     4.633536209709451, -1.0751390543024502`}}]}, 
   {Hue[0.36087493987067576`], AbsoluteThickness[0.5], 
    LineBox[{{4.633536209709451, -1.0751390543024502`}, {
     4.861848818704677, -1.1744589177260953`}}]}, 
   {Hue[0.6475481597807874], AbsoluteThickness[0.5], 
    LineBox[{{4.660826431990412, -0.5307314230940288}, {
     4.678052039461066, -0.3906293042991206}}]}, 
   {Hue[0.6479928557755842], AbsoluteThickness[0.5], 
    LineBox[{{4.678052039461066, -0.39062930429912057`}, {
     4.723160045545716, -0.074003501649509}}]}, 
   {Hue[0.6543611211726247], AbsoluteThickness[0.5], 
    LineBox[{{2.3100955296172025`, -1.054355589573939}, {
     2.2458541561332237`, -1.129810088797422}}]}, 
   {Hue[0.6552890644990673], AbsoluteThickness[0.5], 
    LineBox[{{2.2458541561332237`, -1.129810088797422}, {
     2.0907984583524093`, -1.3488971816536337`}}]}, 
   {Hue[0.6578574242555282], AbsoluteThickness[0.5], 
    LineBox[{{2.930286895460987, -3.156758505520581}, {
     2.8992147167385225`, -3.429084545062082}}]}, 
   {Hue[0.6596989926638077], AbsoluteThickness[0.5], 
    LineBox[{{2.8992147167385225`, -3.429084545062082}, {
     2.9041828076495344`, -3.667092237876926}}]}, 
   {Hue[0.629425617782061], AbsoluteThickness[0.5], 
    LineBox[{{4.303221756540129, -2.372777606521038}, {
     4.671139318395649, -2.357640139124329}}]}, 
   {Hue[0.6307247635878569], AbsoluteThickness[0.5], 
    LineBox[{{4.671139318395649, -2.357640139124329}, {
     4.90093696271851, -2.3221979956597747`}}]}, 
   {Hue[0.5567418223851041], AbsoluteThickness[0.5], 
    LineBox[{{2.181596714296033, -4.047370854599717}, {
     2.2081844053182893`, -4.110644858805867}}]}, 
   {Hue[0.5574125135721322], AbsoluteThickness[0.5], 
    LineBox[{{2.2081844053182893`, -4.110644858805867}, {
     2.337538330466895, -4.3696185333155455`}}]}, 
   {Hue[0.5391987221321521], AbsoluteThickness[0.5], 
    LineBox[{{3.445359949645161, -4.16479305517278}, {
     3.573551974212511, -4.420848905206494}}]}, 
   {Hue[0.5491588455592559], AbsoluteThickness[0.5], 
    LineBox[{{3.573551974212511, -4.420848905206494}, {
     3.6145209771742794`, -4.610225346106586}}]}, 
   {Hue[0.5152207255227566], AbsoluteThickness[0.5], 
    LineBox[{{5.382363156587488, -2.280619182571443}, {
     5.560558371633942, -2.27045240944379}}]}, 
   {Hue[0.5156480048566441], AbsoluteThickness[0.5], 
    LineBox[{{5.560558371633942, -2.27045240944379}, {
     5.876704329874874, -2.254095739636099}}]}, 
   {Hue[0.6232095982951371], AbsoluteThickness[0.5], 
    LineBox[{{3.8509368454384716`, -0.14749868273333525`}, {3.846517256354208,
      0.07665177897412104}}]}, 
   {Hue[0.6238854160233185], AbsoluteThickness[0.5], 
    LineBox[{{3.846517256354208, 0.07665177897412104}, {3.8213562285466582`, 
     0.3693031878918492}}]}, 
   {Hue[0.5825619965349078], AbsoluteThickness[0.5], 
    LineBox[{{4.18876420918295, -4.470264040527862}, {
     4.291752031408928, -4.483364178570054}}]}, 
   {Hue[0.583005673724356], AbsoluteThickness[0.5], 
    LineBox[{{4.291752031408928, -4.483364178570054}, {
     4.645469199757275, -4.535079698743982}}]}, 
   {Hue[0.5324175440248969], AbsoluteThickness[0.5], 
    LineBox[{{3.5947493312535497`, -0.09271250866196912}, {
     3.6329106438501926`, -0.08948164217111723}}]}, 
   {Hue[0.5188963934138066], AbsoluteThickness[0.5], 
    LineBox[{{4.172312201551862, 0.9645654039218462}, {4.338392741187189, 
     1.0474607782164038`}}]}, 
   {Hue[0.5202645936624573], AbsoluteThickness[0.5], 
    LineBox[{{4.338392741187189, 1.0474607782164038`}, {4.5492255834463196`, 
     1.185058724626135}}]}, 
   {Hue[0.4551284983004981], AbsoluteThickness[0.5], 
    LineBox[{{5.36088310168888, -2.844345473113697}, {
     5.413260099956304, -2.9369541267972146`}}]}, 
   {Hue[0.4559043340888032], AbsoluteThickness[0.5], 
    LineBox[{{5.413260099956304, -2.9369541267972146`}, {
     5.552172974635186, -3.1438164711174337`}}]}, 
   {Hue[0.6136867874032698], AbsoluteThickness[0.5], 
    LineBox[{{3.1227897861535574`, -2.1473478631662033`}, {
     3.1146185519650706`, -2.384760503041784}}]}, 
   {Hue[0.615784214110483], AbsoluteThickness[0.5], 
    LineBox[{{3.1146185519650706`, -2.384760503041784}, {
     3.07050071907062, -2.631005360121342}}]}, 
   {Hue[0.5297156799555545], AbsoluteThickness[0.5], 
    LineBox[{{4.070116070943026, -2.127574405579164}, {
     4.085806194235774, -2.169953669319358}}]}, 
   {Hue[0.5316119179028576], AbsoluteThickness[0.5], 
    LineBox[{{4.085806194235774, -2.169953669319358}, {
     4.198515819063912, -2.3807807360933464`}}]}, 
   {Hue[0.541931114909764], AbsoluteThickness[0.5], 
    LineBox[{{2.6121947735827535`, -0.2581011728659748}, {
     2.4082992390576368`, -0.3556460816712159}}]}, 
   {Hue[0.5443625307474872], AbsoluteThickness[0.5], 
    LineBox[{{2.4082992390576368`, -0.3556460816712159}, {
     2.194619661868609, -0.42028675434090923`}}]}, 
   {Hue[0.5572261005039707], AbsoluteThickness[0.5], 
    LineBox[{{2.3229832627797613`, -0.06760420621461552}, {
     2.125841814232591, -0.11792322374903015`}}]}, 
   {Hue[0.5585399075713237], AbsoluteThickness[0.5], 
    LineBox[{{2.125841814232591, -0.11792322374903015`}, {
     1.8236974851035952`, -0.15966084987453746`}}]}, 
   {Hue[0.4808129838464278], AbsoluteThickness[0.5], 
    LineBox[{{3.6883927250872293`, 0.929580278790068}, {3.6737417609233836`, 
     0.9338672664104539}}]}, 
   {Hue[0.48129407954669795`], AbsoluteThickness[0.5], 
    LineBox[{{3.6737417609233836`, 0.9338672664104539}, {3.3829237941441628`, 
     1.0293276318689153`}}]}, 
   {Hue[0.5573833613990886], AbsoluteThickness[0.5], 
    LineBox[{{4.348002517568493, 0.942983522354338}, {4.1270401396359455`, 
     0.9135454648226339}}]}, 
   {Hue[0.5617915467904756], AbsoluteThickness[0.5], 
    LineBox[{{4.1270401396359455`, 0.913545464822634}, {3.926398459228007, 
     0.9255410984668038}}]}, 
   {Hue[0.015384872467786246`], AbsoluteThickness[0.5], 
    LineBox[{{4.631017753262138, 1.1438017594855563`}, {4.673716147708276, 
     1.1720892911058227`}}]}, 
   {Hue[0.016047377472255087`], AbsoluteThickness[0.5], 
    LineBox[{{4.673716147708276, 1.1720892911058227`}, {4.864464361371456, 
     1.3169635198359015`}}]}, 
   {Hue[0.5262981331714159], AbsoluteThickness[0.5], 
    LineBox[{{4.864464361371456, 1.3169635198359015`}, {4.630191051364813, 
     1.3668578019167235`}}]}, 
   {Hue[0.55834209805163], AbsoluteThickness[0.5], 
    LineBox[{{4.464336560092193, 0.8394286860334795}, {4.424224171525848, 
     0.7714398777616649}}]}, 
   {Hue[0.560205296904491], AbsoluteThickness[0.5], 
    LineBox[{{4.424224171525848, 0.7714398777616649}, {4.272954651652534, 
     0.5798181107234576}}]}, 
   {Hue[0.4828027576164711], AbsoluteThickness[0.5], 
    LineBox[{{4.506327584579076, 0.34504051436732264`}, {4.6043084280735505`, 
     0.1733260775920918}}]}, 
   {Hue[0.485097157525402], AbsoluteThickness[0.5], 
    LineBox[{{4.6043084280735505`, 0.1733260775920918}, {
     4.68288619855647, -0.02936692750905308}}]}, 
   {Hue[0.5628834886340628], AbsoluteThickness[0.5], 
    LineBox[{{3.9341723791717165`, -0.6394747690206163}, {
     3.9674585863345757`, -0.8525317025968653}}]}, 
   {Hue[0.5633175537608452], AbsoluteThickness[0.5], 
    LineBox[{{3.9674585863345757`, -0.8525317025968653}, {
     4.020956396031442, -1.168589886633876}}]}, 
   {Hue[0.556054787949053], AbsoluteThickness[0.5], 
    LineBox[{{3.638132910570667, -1.091595457015449}, {
     3.4888475734876003`, -1.3329488065112427`}}]}, 
   {Hue[0.5572660543789661], AbsoluteThickness[0.5], 
    LineBox[{{3.4888475734876003`, -1.3329488065112427`}, {
     3.370628148175305, -1.579809022563283}}]}, 
   {Hue[0.46243271971875155`], AbsoluteThickness[0.5], 
    LineBox[{{3.5355722169225214`, -3.610830296256864}, {
     3.621184616190776, -3.900187414655188}}]}, 
   {Hue[0.4636610187201668], AbsoluteThickness[0.5], 
    LineBox[{{3.621184616190776, -3.900187414655188}, {
     3.6669229679746858`, -4.152355409388753}}]}, 
   {Hue[0.5608747828712582], AbsoluteThickness[0.5], 
    LineBox[{{2.993045356880677, -1.6701177895284713`}, {
     2.870031839608193, -1.8020324537509171`}}]}, 
   {Hue[0.572433245212146], AbsoluteThickness[0.5], 
    LineBox[{{2.870031839608193, -1.8020324537509171`}, {
     2.7138211637930056`, -1.8994789492693493`}}]}, 
   {Hue[0.5250532137225224], AbsoluteThickness[0.5], 
    LineBox[{{4.555344940697731, -1.1166237906649132`}, {
     4.527629002674005, -1.34144837566339}}]}, 
   {Hue[0.5255137569001518], AbsoluteThickness[0.5], 
    LineBox[{{4.527629002674005, -1.34144837566339}, {
     4.498983326186483, -1.6365855157504334`}}]}, 
   {Hue[0.4797110400843641], AbsoluteThickness[0.5], 
    LineBox[{{5.253061036184714, -0.3781078868084189}, {
     5.447118590518882, -0.8752570219360182}}]}, 
   {Hue[0.4801411617791793], AbsoluteThickness[0.5], 
    LineBox[{{5.447118590518882, -0.8752570219360182}, {
     5.559938625622877, -1.1722948968182805`}}]}, 
   {Hue[0.556853715536747], AbsoluteThickness[0.5], 
    LineBox[{{4.979527091609839, 0.3983543963712262}, {5.007147926648903, 
     0.1828889212173082}}]}, 
   {Hue[0.5573420092531032], AbsoluteThickness[0.5], 
    LineBox[{{5.007147926648903, 0.1828889212173082}, {
     5.035862718667926, -0.12496725105362691`}}]}, 
   {Hue[0.5673325614629815], AbsoluteThickness[0.5], 
    LineBox[{{5.126489653930631, 1.1147454133537078`}, {5.126024357912831, 
     1.114363975697225}}]}, 
   {Hue[0.5677614351564861], AbsoluteThickness[0.5], 
    LineBox[{{5.126024357912831, 1.114363975697225}, {4.870909306565453, 
     0.9019166755141031}}]}, 
   {Hue[0.019306568027986526`], AbsoluteThickness[0.5], 
    LineBox[{{5.29528763204957, 1.3962325852174842`}, {5.734004832019249, 
     2.0918730067063587`}}]}, 
   {Hue[0.02076132664957294], AbsoluteThickness[0.5], 
    LineBox[{{5.734004832019249, 2.0918730067063587`}, {5.812453746192833, 
     2.2570474331947743`}}]}, 
   {Hue[0.4516761471502431], AbsoluteThickness[0.5], 
    LineBox[{{5.812453746192833, 2.2570474331947743`}, {5.634971682049219, 
     2.3010581160810193`}}]}, 
   {Hue[0.5682363186205123], AbsoluteThickness[0.5], 
    LineBox[{{5.224069537822892, 1.075833196335999}, {5.1798189151372585`, 
     0.895955320943786}}]}, 
   {Hue[0.569180228235229], AbsoluteThickness[0.5], 
    LineBox[{{5.1798189151372585`, 0.895955320943786}, {5.141353261498219, 
     0.6425296588324133}}]}, 
   {Hue[0.5584206091343282], AbsoluteThickness[0.5], 
    LineBox[{{4.16858720689973, 0.6076767153707066}, {4.152650559629251, 
     0.601886414723647}}]}, 
   {Hue[0.5588464635588486], AbsoluteThickness[0.5], 
    LineBox[{{4.152650559629251, 0.601886414723647}, {3.8418806851008642`, 
     0.488943978798402}}]}, 
   {Hue[0.47026322067160475`], AbsoluteThickness[0.5], 
    LineBox[{{3.9337523145171382`, 1.1642251909044765`}, {3.892594162445232, 
     1.177802715404667}}]}, 
   {Hue[0.47101734036922593`], AbsoluteThickness[0.5], 
    LineBox[{{3.892594162445232, 1.177802715404667}, {3.649534138781242, 
     1.2786155633355174`}}]}, 
   {Hue[0.5294033422287008], AbsoluteThickness[0.5], 
    LineBox[{{2.899215867751619, 0.4745175120330984}, {2.5745454926538405`, 
     0.4050019281650601}}]}, 
   {Hue[0.5358523377056557], AbsoluteThickness[0.5], 
    LineBox[{{2.5745454926538405`, 0.4050019281650601}, {2.381797109943083, 
     0.40654121726941117`}}]}, 
   {Hue[0.5715400582295368], AbsoluteThickness[0.5], 
    LineBox[{{2.6955577071126555`, -1.3441123990592472`}, {
     2.6132765981708244`, -1.4362638526121927`}}]}, 
   {Hue[0.5720947218070519], AbsoluteThickness[0.5], 
    LineBox[{{2.6132765981708244`, -1.4362638526121927`}, {
     2.4162735284091204`, -1.6363683912908917`}}]}, 
   {Hue[0.6154777512676434], AbsoluteThickness[0.5], 
    LineBox[{{2.3187547323913162`, -1.9290164642633}, {
     2.196197910776716, -1.9456463725310658`}}]}, 
   {Hue[0.6159126643730416], AbsoluteThickness[0.5], 
    LineBox[{{2.196197910776716, -1.9456463725310658`}, {
     1.859896175716929, -1.9867208047898095`}}]}, 
   {Hue[0.47027798002567794`], AbsoluteThickness[0.5], 
    LineBox[{{4.512307747935011, -4.161929648261025}, {
     4.5761747874095215`, -4.2252337002771885`}}]}, 
   {Hue[0.4708441614478004], AbsoluteThickness[0.5], 
    LineBox[{{4.5761747874095215`, -4.2252337002771885`}, {
     4.805968574458224, -4.430989728960613}}]}, 
   {Hue[0.561736950640675], AbsoluteThickness[0.5], 
    LineBox[{{5.586033213136125, -3.6492096694368454`}, {
     5.637148476883293, -3.658865755148297}}]}, 
   {Hue[0.5624743708754992], AbsoluteThickness[0.5], 
    LineBox[{{5.637148476883293, -3.658865755148297}, {
     5.905355307612585, -3.7300839651968913`}}]}, 
   {Hue[0.6371511409883819], AbsoluteThickness[0.5], 
    LineBox[{{5.191440709558567, 0.6135661780294586}, {5.501804644416222, 
     0.1563141031887581}}]}, 
   {Hue[0.637626105516658], AbsoluteThickness[0.5], 
    LineBox[{{5.501804644416222, 0.15631410318875807`}, {
     5.625038908274706, -0.0378112499043458}}]}, 
   {Hue[0.2562934257319114], AbsoluteThickness[0.5], 
    LineBox[{{5.384954384187497, 0.7089481355031108}, {5.546928522158454, 
     0.8213024033604124}}]}, 
   {Hue[0.26457700099788856`], AbsoluteThickness[0.5], 
    LineBox[{{5.546928522158454, 0.8213024033604124}, {5.6754312883889755`, 
     0.965732210021195}}]}, 
   {Hue[0.5225589048343273], AbsoluteThickness[0.5], 
    LineBox[{{5.6754312883889755`, 0.965732210021195}, {5.581817563310506, 
     1.1348753460270635`}}]}, 
   {Hue[0.6417268764150539], AbsoluteThickness[0.5], 
    LineBox[{{5.2876174936953975`, 0.9014858975894766}, {5.1469121424063795`, 
     1.1000083115208736`}}]}, 
   {Hue[0.648860480979794], AbsoluteThickness[0.5], 
    LineBox[{{5.1469121424063795`, 1.1000083115208736`}, {5.072251297053539, 
     1.2814550713451227`}}]}, 
   {Hue[0.5779339391232375], AbsoluteThickness[0.5], 
    LineBox[{{2.915342894437466, -1.1276065987960056`}, {
     2.9192779236403914`, -1.15104710462734}}]}, 
   {Hue[0.5841708579540468], AbsoluteThickness[0.5], 
    LineBox[{{2.9192779236403914`, -1.15104710462734}, {
     2.9102977330877557`, -1.329828038289851}}]}, 
   {Hue[0.5901510941073118], AbsoluteThickness[0.5], 
    LineBox[{{4.089760435622246, 0.4082638014429499}, {4.1889900402520555`, 
     0.3845430586577133}}]}, 
   {Hue[0.5909694844360928], AbsoluteThickness[0.5], 
    LineBox[{{4.1889900402520555`, 0.3845430586577133}, {4.458350924669539, 
     0.29671829714307896`}}]}, 
   {Hue[0.594666074142368], AbsoluteThickness[0.5], 
    LineBox[{{3.4165796844797143`, 1.319830164350574}, {3.542114506599032, 
     1.1727465934173038`}}]}, 
   {Hue[0.595798551673495], AbsoluteThickness[0.5], 
    LineBox[{{3.542114506599032, 1.1727465934173038`}, {3.6873050669779572`, 
     0.9621728392800676}}]}, 
   {Hue[0.5838504898938189], AbsoluteThickness[0.5], 
    LineBox[{{2.4300385752989495`, 2.4011279207609886`}, {2.4390932660442264`,
      2.0962165925137044`}}]}, 
   {Hue[0.5843290303237759], AbsoluteThickness[0.5], 
    LineBox[{{2.4390932660442264`, 2.0962165925137044`}, {2.455333636661464, 
     1.832280223514339}}]}, 
   {Hue[0.5298043889647833], AbsoluteThickness[0.5], 
    LineBox[{{2.4395402838905484`, 3.3175580534084768`}, {2.4121287615096514`,
      3.302282275980151}}]}, 
   {Hue[0.5302336425869015], AbsoluteThickness[0.5], 
    LineBox[{{2.4121287615096514`, 3.302282275980151}, {2.134071685559335, 
     3.1502958414922753`}}]}, 
   {Hue[0.5312650306123041], AbsoluteThickness[0.5], 
    LineBox[{{2.6959441012932404`, 3.4339853543710817`}, {2.7757912001308074`,
      3.3604184637404257`}}]}, 
   {Hue[0.5332136792998738], AbsoluteThickness[0.5], 
    LineBox[{{2.7757912001308074`, 3.3604184637404257`}, {2.924754069947133, 
     3.1792630564131725`}}]}, 
   {Hue[0.584297618230318], AbsoluteThickness[0.5], 
    LineBox[{{2.5554739994304447`, 2.392820709546808}, {2.560204933801538, 
     2.342270455135108}}]}, 
   {Hue[0.5867480430059956], AbsoluteThickness[0.5], 
    LineBox[{{2.560204933801538, 2.342270455135108}, {2.6212358691620845`, 
     2.099498261512685}}]}, 
   {Hue[0.5817188854205062], AbsoluteThickness[0.5], 
    LineBox[{{2.9165029292430855`, 1.7120448573773035`}, {2.92369145687353, 
     1.6645430413647324`}}]}, 
   {Hue[0.5821868652363876], AbsoluteThickness[0.5], 
    LineBox[{{2.92369145687353, 1.6645430413647324`}, {2.983709504481396, 
     1.3322260787458533`}}]}, 
   {Hue[0.5801874976958186], AbsoluteThickness[0.5], 
    LineBox[{{3.81138591091258, -1.867271881185408}, {
     3.853567066763506, -1.9811740688321895`}}]}, 
   {Hue[0.5819254301285957], AbsoluteThickness[0.5], 
    LineBox[{{3.853567066763506, -1.9811740688321895`}, {
     3.9473806771221565`, -2.159016450802411}}]}, 
   {Hue[0.5405752612323204], AbsoluteThickness[0.5], 
    LineBox[{{4.40622252463615, -1.8003513765572345`}, {
     4.469277237634642, -1.8543458386614726`}}]}, 
   {Hue[0.5415883745465523], AbsoluteThickness[0.5], 
    LineBox[{{4.469277237634642, -1.8543458386614726`}, {
     4.66081251694832, -2.052967295163823}}]}, 
   {Hue[0.663127326692887], AbsoluteThickness[0.5], 
    LineBox[{{2.9820464542371536`, 2.6824298242387385`}, {3.028748512502552, 
     2.883998180428226}}]}, 
   {Hue[0.663566448055356], AbsoluteThickness[0.5], 
    LineBox[{{3.028748512502552, 2.883998180428226}, {3.0945805724511977`, 
     3.1905173962071527`}}]}, 
   {Hue[0.5376015946199426], AbsoluteThickness[0.5], 
    LineBox[{{4.6800793411320205`, 1.0713399334832834`}, {4.733539415857952, 
     1.1565131701392994`}}]}, 
   {Hue[0.5383294534147073], AbsoluteThickness[0.5], 
    LineBox[{{4.733539415857952, 1.1565131701392994`}, {4.843774195796624, 
     1.3638471423543908`}}]}, 
   {Hue[0.2953980597954978], AbsoluteThickness[0.5], 
    LineBox[{{5.325080940614883, -0.8554067366445256}, {
     5.478056079514354, -0.8690607457533852}}]}, 
   {Hue[0.3260162435014068], AbsoluteThickness[0.5], 
    LineBox[{{5.478056079514354, -0.8690607457533852}, {
     5.624208606997544, -0.9363036649907435}}]}, 
   {Hue[0.4622905182688787], AbsoluteThickness[0.5], 
    LineBox[{{5.624208606997544, -0.9363036649907435}, {
     5.63711661754022, -1.0966643669757272`}}]}, 
   {Hue[0.5985647930363487], AbsoluteThickness[0.5], 
    LineBox[{{5.63711661754022, -1.0966643669757272`}, {
     5.503601368676467, -1.1864187529306036`}}]}, 
   {Hue[0.5565119023124542], AbsoluteThickness[0.5], 
    LineBox[{{3.7276451287722563`, -2.3374553711708765`}, {
     3.8190762046716302`, -2.626445348286151}}]}, 
   {Hue[0.5597078997169739], AbsoluteThickness[0.5], 
    LineBox[{{3.8190762046716302`, -2.626445348286151}, {
     3.8470464308022323`, -2.8308762381079355`}}]}, 
   {Hue[0.5738892775115875], AbsoluteThickness[0.5], 
    LineBox[{{2.7018848520677237`, -2.374800745891865}, {
     2.6785487431868042`, -2.5899759206037776`}}]}, 
   {Hue[0.5745851048545011], AbsoluteThickness[0.5], 
    LineBox[{{2.6785487431868042`, -2.5899759206037776`}, {
     2.6661888115363617`, -2.901405426311577}}]}, 
   {Hue[0.4886672541076303], AbsoluteThickness[0.5], 
    LineBox[{{4.866235095972698, 0.2658899249132473}, {5.063796737833672, 
     0.1873004085322279}}]}, 
   {Hue[0.4899757908159229], AbsoluteThickness[0.5], 
    LineBox[{{5.063796737833672, 0.1873004085322279}, {5.30676519214427, 
     0.12104194578115585`}}]}, 
   {Hue[0.3143726094582801], AbsoluteThickness[0.5], 
    LineBox[{{4.391390388949588, 2.313229140964039}, {4.417609000493265, 
     2.323813139783029}}]}, 
   {Hue[0.31546864337193464`], AbsoluteThickness[0.5], 
    LineBox[{{4.417609000493265, 2.323813139783029}, {4.64668851181943, 
     2.4443512532127567`}}]}, 
   {Hue[0.4279254249087915], AbsoluteThickness[0.5], 
    LineBox[{{2.3860423127182275`, 1.8658395690152396`}, {2.385805910615825, 
     1.8659025118591441`}}]}, 
   {Hue[0.4315178354606375], AbsoluteThickness[0.5], 
    LineBox[{{2.385805910615825, 1.8659025118591441`}, {2.2083328961782596`, 
     1.8804808151665078`}}]}, 
   {Hue[0.6195062200963658], AbsoluteThickness[0.5], 
    LineBox[{{2.9175721093547935`, 2.3484633668658605`}, {2.876813274309119, 
     2.324420250203048}}]}, 
   {Hue[0.6199419217098793], AbsoluteThickness[0.5], 
    LineBox[{{2.876813274309119, 2.324420250203048}, {2.568674459886656, 
     2.148379612999648}}]}, 
   {Hue[0.09617565158625158], AbsoluteThickness[0.5], 
    LineBox[{{3.0116467868853407`, 2.6874111153950353`}, {3.0784910961259984`,
      2.887125304523418}}]}, 
   {Hue[0.09690606839134218], AbsoluteThickness[0.5], 
    LineBox[{{3.0784910961259984`, 2.887125304523418}, {3.1482674309292404`, 
     3.1594058030204084`}}]}, 
   {Hue[0.5972986888732889], AbsoluteThickness[0.5], 
    LineBox[{{3.1482674309292404`, 3.1594058030204084`}, {2.8867699510477567`,
      3.056330710122189}}]}, 
   {Hue[0.6206571860024847], AbsoluteThickness[0.5], 
    LineBox[{{3.162789103474615, 2.3697767008214554`}, {3.1753021913380426`, 
     2.3394978271943776`}}]}, 
   {Hue[0.6212602424062758], AbsoluteThickness[0.5], 
    LineBox[{{3.1753021913380426`, 2.3394978271943776`}, {3.3054391489621895`,
      2.0689769531056648`}}]}, 
   {Hue[0.6118554423566396], AbsoluteThickness[0.5], 
    LineBox[{{2.6560994633846904`, 2.56044282842141}, {2.680225733468291, 
     2.6037005977507994`}}]}, 
   {Hue[0.6123088084625408], AbsoluteThickness[0.5], 
    LineBox[{{2.680225733468291, 2.6037005977507994`}, {2.823379125732227, 
     2.874923107054231}}]}, 
   {Hue[0.22841280950820356`], AbsoluteThickness[0.5], 
    LineBox[{{2.4775859008800314`, 2.692346750859544}, {2.331533004406791, 
     2.7701470663283585`}}]}, 
   {Hue[0.2289928659447768], AbsoluteThickness[0.5], 
    LineBox[{{2.331533004406791, 2.7701470663283585`}, {2.1105729632646173`, 
     2.87322003082137}}]}, 
   {Hue[0.6163196548975524], AbsoluteThickness[0.5], 
    LineBox[{{2.3491529950487253`, 2.511319886962505}, {2.2744758488708143`, 
     2.3643607734331806`}}]}, 
   {Hue[0.6167669940414856], AbsoluteThickness[0.5], 
    LineBox[{{2.2744758488708143`, 2.3643607734331806`}, {2.152336807627857, 
     2.1113096584286044`}}]}, 
   {Hue[0.4835528121330895], AbsoluteThickness[0.5], 
    LineBox[{{2.578892363031384, 2.4036516519587927`}, {2.365132283871131, 
     2.1791909458733225`}}]}, 
   {Hue[0.49072688620692434`], AbsoluteThickness[0.5], 
    LineBox[{{2.365132283871131, 2.1791909458733225`}, {2.2253443957365415`, 
     2.0869705991201744`}}]}, 
   {Hue[0.3053206449131886], AbsoluteThickness[0.5], 
    LineBox[{{2.410847975523442, 2.4130280109571176`}, {2.1431653660628056`, 
     2.505982891291053}}]}, 
   {Hue[0.3060203659790275], AbsoluteThickness[0.5], 
    LineBox[{{2.1431653660628056`, 2.505982891291053}, {1.8305624197278572`, 
     2.5909622958379077`}}]}, 
   {Hue[0.5118651062088709], AbsoluteThickness[0.5], 
    LineBox[{{2.3498266585744396`, 2.5698821825904985`}, {2.3313982572150262`,
      2.7684855414842775`}}]}, 
   {Hue[0.5444126959476575], AbsoluteThickness[0.5], 
    LineBox[{{2.3313982572150262`, 2.7684855414842775`}, {2.275539695366952, 
     2.887167725935661}}]}, 
   {Hue[0.675407243030873], AbsoluteThickness[0.5], 
    LineBox[{{2.275539695366952, 2.887167725935661}, {2.1447527533827624`, 
     2.8971884866009683`}}]}, 
   {Hue[0.3311778816218853], AbsoluteThickness[0.5], 
    LineBox[{{2.3975762742192255`, 1.8564373303561725`}, {2.3967622845666146`,
      1.853174958264882}}]}, 
   {Hue[0.3321760325024911], AbsoluteThickness[0.5], 
    LineBox[{{2.3967622845666146`, 1.853174958264882}, {2.3214797899905504`, 
     1.6396201093950835`}}]}, 
   {Hue[0.3843536811391055], AbsoluteThickness[0.5], 
    LineBox[{{2.9053838705261663`, 1.6915916064898158`}, {2.9222549490951333`,
      1.6639601363770538`}}]}, 
   {Hue[0.38479876814242064`], AbsoluteThickness[0.5], 
    LineBox[{{2.9222549490951333`, 1.6639601363770538`}, {3.0944903810164766`,
      1.3691821647396196`}}]}, 
   {Hue[0.43894802733486865`], AbsoluteThickness[0.5], 
    LineBox[{{3.121751090010434, 2.0854904925192193`}, {3.4135202344812337`, 
     2.0466092217157823`}}]}, 
   {Hue[0.43939282795693263`], AbsoluteThickness[0.5], 
    LineBox[{{3.4135202344812337`, 2.0466092217157823`}, {3.6715870978324103`,
      2.007155127950634}}]}, 
   {Hue[0.4901024306381635], AbsoluteThickness[0.5], 
    LineBox[{{3.1181313831665896`, 2.665013953924143}, {3.1438870322856913`, 
     2.7177840517466816`}}]}, 
   {Hue[0.4916398893031526], AbsoluteThickness[0.5], 
    LineBox[{{3.1438870322856913`, 2.7177840517466816`}, {3.2761975537919015`,
      2.921106625240307}}]}, 
   {Hue[0.5440974109070532], AbsoluteThickness[0.5], 
    LineBox[{{2.5982775007980297`, 2.835041771969929}, {2.5814125211469308`, 
     2.8789586016381445`}}]}, 
   {Hue[0.5447707132856118], AbsoluteThickness[0.5], 
    LineBox[{{2.5814125211469308`, 2.8789586016381445`}, {2.460894550157647, 
     3.1400809378009105`}}]}, 
   {Hue[0.5976891761706651], AbsoluteThickness[0.5], 
    LineBox[{{2.365611798758583, 2.4645273848257925`}, {2.140426610746494, 
     2.518057367205935}}]}, 
   {Hue[0.5983476148150086], AbsoluteThickness[0.5], 
    LineBox[{{2.140426610746494, 2.518057367205935}, {1.8169841535242632`, 
     2.57339142805239}}]}, 
   {Hue[0.6507997674993548], AbsoluteThickness[0.5], 
    LineBox[{{2.1668295928704393`, 1.7116939229148214`}, {2.144414724477216, 
     1.6551113785645564`}}]}, 
   {Hue[0.651469904893686], AbsoluteThickness[0.5], 
    LineBox[{{2.144414724477216, 1.6551113785645564`}, {2.000571477384569, 
     1.3515813160915384`}}]}, 
   {Hue[0.42639914545681223`], AbsoluteThickness[0.5], 
    LineBox[{{3.832037190564209, 2.234670245600436}, {4.0846130611649, 
     2.3079289864091637`}}]}, 
   {Hue[0.4273176480982612], AbsoluteThickness[0.5], 
    LineBox[{{4.0846130611649, 2.3079289864091637`}, {4.359929523871454, 
     2.361907996273263}}]}, 
   {Hue[0.4685841280668609], AbsoluteThickness[0.5], 
    LineBox[{{4.677743162875105, 1.0774489353402452`}, {4.839610111793959, 
     1.023175736160832}}]}, 
   {Hue[0.4690380280711693], AbsoluteThickness[0.5], 
    LineBox[{{4.839610111793959, 1.023175736160832}, {5.152847052521294, 
     0.9262182392319177}}]}, 
   {Hue[0.6022103179867332], AbsoluteThickness[0.5], 
    LineBox[{{4.39387803801167, -2.2729587090565953`}, {
     4.824726827219966, -2.4679817908810704`}}]}, 
   {Hue[0.6028053144199883], AbsoluteThickness[0.5], 
    LineBox[{{4.824726827219966, -2.4679817908810704`}, {
     5.079438222480103, -2.566703795055541}}]}, 
   {Hue[0.5337006773160232], AbsoluteThickness[0.5], 
    LineBox[{{5.649247792446061, -0.9935118467388195}, {
     5.691880695858395, -1.0585035441610022`}}]}, 
   {Hue[0.5341416144120172], AbsoluteThickness[0.5], 
    LineBox[{{5.691880695858395, -1.0585035441610022`}, {
     5.860652410341793, -1.3256827409873113`}}]}, 
   {Hue[0.6397344442128094], AbsoluteThickness[0.5], 
    LineBox[{{2.356499694709475, -1.834818979365718}, {
     2.237413607860656, -2.0722833167927335`}}]}, 
   {Hue[0.6408240625428447], AbsoluteThickness[0.5], 
    LineBox[{{2.237413607860656, -2.0722833167927335`}, {
     2.1380784156283608`, -2.332604629278842}}]}, 
   {Hue[0.5319984097541185], AbsoluteThickness[0.5], 
    LineBox[{{3.759391032351048, 2.8963067065640513`}, {3.796585259902219, 
     3.092246740580341}}]}, 
   {Hue[0.5324856121332263], AbsoluteThickness[0.5], 
    LineBox[{{3.796585259902219, 3.092246740580341}, {3.8469645428393435`, 
     3.418098136531949}}]}, 
   {Hue[0.42706166038104976`], AbsoluteThickness[0.5], 
    LineBox[{{2.843573568852771, 2.536022186237316}, {2.739475322174636, 
     2.5961210774024615`}}]}, 
   {Hue[0.4299065128011357], AbsoluteThickness[0.5], 
    LineBox[{{2.739475322174636, 2.5961210774024615`}, {2.575107300949637, 
     2.7307676761358777`}}]}, 
   {Hue[0.5856186037113786], AbsoluteThickness[0.5], 
    LineBox[{{2.6198914423033774`, 1.769697577794151}, {2.4102248303351193`, 
     1.7110180710014709`}}]}, 
   {Hue[0.5867832056305016], AbsoluteThickness[0.5], 
    LineBox[{{2.4102248303351193`, 1.7110180710014709`}, {2.1938402461294837`,
      1.6742835730247596`}}]}, 
   {Hue[0.5924633105932448], AbsoluteThickness[0.5], 
    LineBox[{{2.6295476063155676`, 1.8299410984632989`}, {2.5205236831105733`,
      1.8375238820403166`}}]}, 
   {Hue[0.6000920846897455], AbsoluteThickness[0.5], 
    LineBox[{{2.5205236831105733`, 1.8375238820403166`}, {2.369066545241023, 
     1.8844712943904298`}}]}, 
   {Hue[0.5971416926642098], AbsoluteThickness[0.5], 
    LineBox[{{4.029935210352771, 1.345659009238371}, {3.9463367652785033`, 
     1.2953233598340559`}}]}, 
   {Hue[0.5978394371147752], AbsoluteThickness[0.5], 
    LineBox[{{3.9463367652785033`, 1.2953233598340559`}, {3.70827888104162, 
     1.173380174104737}}]}, 
   {Hue[0.5554748835459236], AbsoluteThickness[0.5], 
    LineBox[{{4.58517547924136, 2.590398561071933}, {4.414387791226357, 
     2.7253120134109037`}}]}, 
   {Hue[0.555931650527758], AbsoluteThickness[0.5], 
    LineBox[{{4.414387791226357, 2.7253120134109037`}, {4.158838720553369, 
     2.9172143166412163`}}]}, 
   {Hue[0.5747660601472991], AbsoluteThickness[0.5], 
    LineBox[{{5.393692590609882, 2.3900380778646078`}, {5.3716367495405635`, 
     2.3375415762672778`}}]}, 
   {Hue[0.5754120430893221], AbsoluteThickness[0.5], 
    LineBox[{{5.3716367495405635`, 2.3375415762672778`}, {5.235027469109616, 
     2.061897289882064}}]}, 
   {Hue[0.04943697959092732], AbsoluteThickness[0.5], 
    LineBox[{{5.683949227031474, 2.5233846235325736`}, {6.0578531024600615`, 
     2.718540386817912}}]}, 
   {Hue[0.049871937012759854`], AbsoluteThickness[0.5], 
    LineBox[{{6.0578531024600615`, 2.718540386817912}, {6.3548009301530115`, 
     2.86851393330289}}]}, 
   {Hue[0.6026619138036624], AbsoluteThickness[0.5], 
    LineBox[{{6.3548009301530115`, 2.86851393330289}, {6.0919982295605974`, 
     2.6645413430409204`}}]}, 
   {Hue[0.5758947422641328], AbsoluteThickness[0.5], 
    LineBox[{{5.375374700117173, 2.605919328766012}, {5.332807193744282, 
     2.615034915614058}}]}, 
   {Hue[0.5770579520300696], AbsoluteThickness[0.5], 
    LineBox[{{5.332807193744282, 2.615034915614058}, {5.120277233704552, 
     2.6844301924758085`}}]}, 
   {Hue[0.5419642821964941], AbsoluteThickness[0.5], 
    LineBox[{{5.214160881866805, 1.6383828201660526`}, {5.169798715175338, 
     1.4803526841540386`}}]}, 
   {Hue[0.5754823070123801], AbsoluteThickness[0.5], 
    LineBox[{{5.169798715175338, 1.4803526841540386`}, {5.0707370028066245`, 
     1.3426278918831367`}}]}, 
   {Hue[0.587862658207515], AbsoluteThickness[0.5], 
    LineBox[{{3.4128891061860096`, 1.973554069884928}, {3.1527453950941866`, 
     1.9715654900167259`}}]}, 
   {Hue[0.5883018461213259], AbsoluteThickness[0.5], 
    LineBox[{{3.1527453950941866`, 1.9715654900167259`}, {2.8444445960652796`,
      1.9741901061267448`}}]}, 
   {Hue[0.5941879765968499], AbsoluteThickness[0.5], 
    LineBox[{{3.401019743745326, 0.9412502664205687}, {3.3000861271510757`, 
     0.8736217139547306}}]}, 
   {Hue[0.5955001419669015], AbsoluteThickness[0.5], 
    LineBox[{{3.3000861271510757`, 0.8736217139547306}, {3.1190446972062684`, 
     0.7202379225473263}}]}, 
   {Hue[0.6112272365274943], AbsoluteThickness[0.5], 
    LineBox[{{5.059613941115887, 0.19858179354965283`}, {5.059358732289802, 
     0.16536396648139487`}}]}, 
   {Hue[0.6118846322622683], AbsoluteThickness[0.5], 
    LineBox[{{5.059358732289802, 0.16536396648139487`}, {
     5.0386364356491855`, -0.12396936795235833`}}]}, 
   {Hue[0.4082833439883386], AbsoluteThickness[0.5], 
    LineBox[{{5.198405079948534, 0.08948907531110878}, {
     5.440398280331889, -0.013898305625454258`}}]}, 
   {Hue[0.4106182415676398], AbsoluteThickness[0.5], 
    LineBox[{{5.440398280331889, -0.013898305625454258`}, {
     5.601783148631202, -0.05578308301126747}}]}, 
   {Hue[0.6342979617334821], AbsoluteThickness[0.5], 
    LineBox[{{5.352597952318563, 0.17544696908135815`}, {5.513933538429766, 
     0.33218938195587233`}}]}, 
   {Hue[0.6365420755806055], AbsoluteThickness[0.5], 
    LineBox[{{5.513933538429766, 0.33218938195587233`}, {5.667158822449169, 
     0.5326705406541905}}]}, 
   {Hue[0.5492684535246409], AbsoluteThickness[0.5], 
    LineBox[{{4.621835901029157, -0.6457941094011712}, {
     4.6200732002744225`, -0.6938985726108623}}]}, 
   {Hue[0.6339870083807603], AbsoluteThickness[0.5], 
    LineBox[{{4.6200732002744225`, -0.6938985726108623}, {
     4.6758723598925735`, -0.8298124956496539}}]}, 
   {Hue[0.691598746252905], AbsoluteThickness[0.5], 
    LineBox[{{4.6758723598925735`, -0.8298124956496539}, {
     4.820587912611849, -0.8551807729076975}}]}, 
   {Hue[0.6087004644813198], AbsoluteThickness[0.5], 
    LineBox[{{3.6230339038348536`, -3.043475130334787}, {
     3.6626564498671175`, -3.2038561500426423`}}]}, 
   {Hue[0.6099210608773348], AbsoluteThickness[0.5], 
    LineBox[{{3.6626564498671175`, -3.2038561500426423`}, {
     3.7457843596801177`, -3.431568930606096}}]}, 
   {Hue[0.29598177816746524`], AbsoluteThickness[0.5], 
    LineBox[{{5.887195054990402, -0.22450114297365203`}, {
     6.0498259656785445`, -0.27993577724167495`}}]}, 
   {Hue[0.2965022649801599], AbsoluteThickness[0.5], 
    LineBox[{{6.0498259656785445`, -0.27993577724167495`}, {
     6.355282433923198, -0.36989199898833375`}}]}, 
   {Hue[0.6938798623413861], AbsoluteThickness[0.5], 
    LineBox[{{3.5810065881669577`, -3.089475931992088}, {
     3.6387991483155235`, -3.2705859538916044`}}]}, 
   {Hue[0.6587305645351911], AbsoluteThickness[0.5], 
    LineBox[{{3.2136054633634656`, 2.3704061378146886`}, {3.197624378045497, 
     2.4200981474915655`}}]}, 
   {Hue[0.6602515025190221], AbsoluteThickness[0.5], 
    LineBox[{{3.197624378045497, 2.4200981474915655`}, {3.0766089198113646`, 
     2.681688690135145}}]}, 
   {Hue[0.4575153579859389], AbsoluteThickness[0.5], 
    LineBox[{{2.9571195956218665`, -3.6977921604944206`}, {
     2.961499648924807, -3.792432333029497}}]}, 
   {Hue[0.45794189882349223`], AbsoluteThickness[0.5], 
    LineBox[{{2.961499648924807, -3.792432333029497}, {
     2.977349793592353, -4.10962564933677}}]}, 
   {Hue[0.5789183145614839], AbsoluteThickness[0.5], 
    LineBox[{{5.1507075569410965`, -0.9093187516108442}, {
     5.164921165766611, -0.9035877974209203}}]}, 
   {Hue[0.5808149984044131], AbsoluteThickness[0.5], 
    LineBox[{{5.164921165766611, -0.9035877974209203}, {
     5.3542505241943035`, -0.79527452481808}}]}, 
   {Hue[0.3965300671051952], AbsoluteThickness[0.5], 
    LineBox[{{4.525598323934774, -2.668278242739961}, {
     4.602076222654699, -2.7378973737226815`}}]}, 
   {Hue[0.3971528474680168], AbsoluteThickness[0.5], 
    LineBox[{{4.602076222654699, -2.7378973737226815`}, {
     4.826806545392832, -2.9193276214702566`}}]}, 
   {Hue[0.6055541985023444], AbsoluteThickness[0.5], 
    LineBox[{{3.0124985993287705`, -3.173468811635216}, {
     2.9003454639463264`, -3.2497921827144225`}}]}, 
   {Hue[0.6061505310364116], AbsoluteThickness[0.5], 
    LineBox[{{2.9003454639463264`, -3.2497921827144225`}, {
     2.650739971745474, -3.4001059673734253`}}]}, 
   {Hue[0.5196349493256128], AbsoluteThickness[0.5], 
    LineBox[{{5.637942021250768, 0.11385749333563343`}, {5.644347592592848, 
     0.11624777245457843`}}]}, 
   {Hue[0.5207429971046716], AbsoluteThickness[0.5], 
    LineBox[{{5.644347592592848, 0.11624777245457844`}, {5.816917502326904, 
     0.20144191367730124`}}]}, 
   {Hue[0.591756631271755], AbsoluteThickness[0.5], 
    LineBox[{{3.0023509734820317`, -3.706513639910305}, {
     3.08033559344067, -3.8331341231851472`}}]}, 
   {Hue[0.607022271862838], AbsoluteThickness[0.5], 
    LineBox[{{3.08033559344067, -3.8331341231851472`}, {
     3.125427393250031, -3.997659762760602}}]}, 
   {Hue[0.4437447511315944], AbsoluteThickness[0.5], 
    LineBox[{{3.4600665634003063`, 2.6591124708123144`}, {3.5509835072287217`,
      2.862373584984084}}]}, 
   {Hue[0.44485275518530853`], AbsoluteThickness[0.5], 
    LineBox[{{3.5509835072287217`, 2.862373584984084}, {3.635571266519463, 
     3.1183307058385874`}}]}, 
   {Hue[0.5930371832222343], AbsoluteThickness[0.5], 
    LineBox[{{5.369122818861001, 0.266956855593384}, {5.596464143212425, 
     0.164736392301929}}]}, 
   {Hue[0.5951452480899141], AbsoluteThickness[0.5], 
    LineBox[{{5.596464143212425, 0.164736392301929}, {5.7597720729195645`, 
     0.11789222966159069`}}]}, 
   {Hue[0.5780852487574827], AbsoluteThickness[0.5], 
    LineBox[{{5.6757222728810515`, 0.9998813017558928}, {5.712109905397977, 
     1.0693590299444908`}}]}, 
   {Hue[0.5785494149301519], AbsoluteThickness[0.5], 
    LineBox[{{5.712109905397977, 1.0693590299444908`}, {5.867147252684627, 
     1.386049669490096}}]}, 
   {Hue[0.6813469810224619], AbsoluteThickness[0.5], 
    LineBox[{{5.135452087512763, 0.866133678726273}, {5.135711702556476, 
     0.8990947910194856}}]}, 
   {Hue[0.683543545382053], AbsoluteThickness[0.5], 
    LineBox[{{5.135711702556476, 0.8990947910194856}, {5.102963552857302, 
     1.1349084578303186`}}]}, 
   {Hue[0.5324518358585544], AbsoluteThickness[0.5], 
    LineBox[{{4.741797068861107, -3.917338199682835}, {
     4.872410489698688, -4.010495297600626}}]}, 
   {Hue[0.5332734038723556], AbsoluteThickness[0.5], 
    LineBox[{{4.872410489698688, -4.010495297600626}, {
     5.091453646427579, -4.141419739137227}}]}, 
   {Hue[0.692804170821741], AbsoluteThickness[0.5], 
    LineBox[{{5.379745568298565, 0.6955134168995505}, {5.476882257887095, 
     0.8201564056654302}}]}, 
   {Hue[0.6934357387462461], AbsoluteThickness[0.5], 
    LineBox[{{5.476882257887095, 0.8201564056654302}, {5.650697549979796, 
     1.0733966563823958`}}]}, 
   {Hue[0.6939377366472869], AbsoluteThickness[0.5], 
    LineBox[{{6.890948348469827, -3.3047371480504326`}, {
     6.979642462293934, -3.3595468838900158`}}]}, 
   {Hue[0.6950512985060765], AbsoluteThickness[0.5], 
    LineBox[{{6.979642462293934, -3.3595468838900158`}, {
     7.189142590104454, -3.5205618229512616`}}]}, 
   {Hue[0.5745138467761262], AbsoluteThickness[0.5], 
    LineBox[{{3.9579131397521676`, -3.8009611944189277`}, {
     4.005835866428553, -3.8560060021104827`}}]}, 
   {Hue[0.5751001465357635], AbsoluteThickness[0.5], 
    LineBox[{{4.005835866428553, -3.8560060021104827`}, {
     4.1580838141123415`, -4.051216201993724}}]}, 
   {Hue[0.462707259318976], AbsoluteThickness[0.5], 
    LineBox[{{3.208800251604743, -2.9061259902604144`}, {
     3.173045622896959, -3.1801300060078868`}}]}, 
   {Hue[0.4644342289453921], AbsoluteThickness[0.5], 
    LineBox[{{3.173045622896959, -3.1801300060078868`}, {
     3.1731807903817484`, -3.4131764094056827`}}]}, 
   {Hue[0.6241853452660987], AbsoluteThickness[0.5], 
    LineBox[{{4.148504562306456, 1.5622141217376697`}, {4.233477237518182, 
     1.5928595840831465`}}]}, 
   {Hue[0.6262555273357759], AbsoluteThickness[0.5], 
    LineBox[{{4.233477237518182, 1.5928595840831465`}, {4.446294214219085, 
     1.7058720899159108`}}]}, 
   {Hue[0.34019851478436436`], AbsoluteThickness[0.5], 
    LineBox[{{2.754495564169349, 1.929578689187876}, {2.6748018205244657`, 
     2.0778660657847166`}}]}, 
   {Hue[0.34130251607476275`], AbsoluteThickness[0.5], 
    LineBox[{{2.6748018205244657`, 2.0778660657847166`}, {2.563370815805376, 
     2.3474488245508085`}}]}, 
   {Hue[0.6330406648848611], AbsoluteThickness[0.5], 
    LineBox[{{2.098065380224596, 1.1484815536237436`}, {2.052069493123557, 
     1.1585199121115255`}}]}, 
   {Hue[0.6743566364749161], AbsoluteThickness[0.5], 
    LineBox[{{2.052069493123557, 1.1585199121115255`}, {1.886503591680112, 
     1.1330301102343423`}}]}, 
   {Hue[0.3669861317902668], AbsoluteThickness[0.5], 
    LineBox[{{4.343878916477926, 1.9068335596074242`}, {4.322060514933681, 
     2.106442018613097}}]}, 
   {Hue[0.36756846767586815`], AbsoluteThickness[0.5], 
    LineBox[{{4.322060514933681, 2.106442018613097}, {4.272196170622946, 
     2.411134554622807}}]}, 
   {Hue[0.5058081413244107], AbsoluteThickness[0.5], 
    LineBox[{{4.121612420112719, -0.34524851599201867`}, {
     4.103667316430436, -0.40480007130982154`}}]}, 
   {Hue[0.506763434545063], AbsoluteThickness[0.5], 
    LineBox[{{4.103667316430436, -0.40480007130982154`}, {
     4.007160184692961, -0.6435838037410032}}]}, 
   {Hue[0.517375333674886], AbsoluteThickness[0.5], 
    LineBox[{{4.86340820383138, -0.07942368604342581}, {
     4.922004430287397, -0.3876714280901201}}]}, 
   {Hue[0.5179297651945615], AbsoluteThickness[0.5], 
    LineBox[{{4.922004430287397, -0.3876714280901201}, {
     4.989343389943048, -0.6670408945098727}}]}, 
   {Hue[0.5435349591563736], AbsoluteThickness[0.5], 
    LineBox[{{5.318081509531999, 0.5399400793970733}, {5.235305633743881, 
     0.6053583483362349}}]}, 
   {Hue[0.5459227823429423], AbsoluteThickness[0.5], 
    LineBox[{{5.235305633743881, 0.6053583483362349}, {5.089277547606241, 
     0.7618863682638778}}]}, 
   {Hue[0.03303324411285371], AbsoluteThickness[0.5], 
    LineBox[{{5.631569481869561, 0.6164542386219324}, {5.708677078518348, 
     0.6301833348481304}}]}, 
   {Hue[0.03618599776585093], AbsoluteThickness[0.5], 
    LineBox[{{5.708677078518348, 0.6301833348481304}, {5.899967567888557, 
     0.6990879780858823}}]}, 
   {Hue[0.38954625796859327`], AbsoluteThickness[0.5], 
    LineBox[{{5.899967567888557, 0.6990879780858823}, {5.850305337571834, 
     0.8962517781689212}}]}, 
   {Hue[0.5448397236825869], AbsoluteThickness[0.5], 
    LineBox[{{5.480729955501762, 0.3311884631644808}, {
     5.265035476530226, -0.020945896796740415`}}]}, 
   {Hue[0.5457238882111594], AbsoluteThickness[0.5], 
    LineBox[{{5.265035476530226, -0.020945896796740415`}, {
     5.12740123528053, -0.296281482118664}}]}, 
   {Hue[0.5145161697998405], AbsoluteThickness[0.5], 
    LineBox[{{4.473810454277735, 1.1845759033397314`}, {4.406114449015091, 
     1.226929440503045}}]}, 
   {Hue[0.5150081207463543], AbsoluteThickness[0.5], 
    LineBox[{{4.406114449015091, 1.226929440503045}, {4.1403594608289325`, 
     1.3803665794012725`}}]}, 
   {Hue[0.6146296022792878], AbsoluteThickness[0.5], 
    LineBox[{{3.9866593162957247`, 1.1927696527612697`}, {3.9290423467398363`,
      1.2226082997345502`}}]}, 
   {Hue[0.6150555260677534], AbsoluteThickness[0.5], 
    LineBox[{{3.9290423467398363`, 1.2226082997345502`}, {3.6650698239341186`,
      1.3597071376123941`}}]}, 
   {Hue[0.5943237687075412], AbsoluteThickness[0.5], 
    LineBox[{{4.366300897560018, 1.3810911319164552`}, {4.343394762380359, 
     1.594540795568127}}]}, 
   {Hue[0.5947974084285276], AbsoluteThickness[0.5], 
    LineBox[{{4.343394762380359, 1.594540795568127}, {4.2989143009305, 
     1.9167101734416405`}}]}, 
   {Hue[0.6987514826818099], AbsoluteThickness[0.5], 
    LineBox[{{4.86034271500321, 1.3314563729565374`}, {4.9141810480873795`, 
     1.3522948992278243`}}]}, 
   {Hue[0.6996978262292097], AbsoluteThickness[0.5], 
    LineBox[{{4.9141810480873795`, 1.3522948992278243`}, {5.169648697002298, 
     1.478884366003982}}]}, 
   {Hue[0.37617080354374827`], AbsoluteThickness[0.5], 
    LineBox[{{4.605693564104849, -1.0915471248585296`}, {
     4.605021439422993, -1.095488211528203}}]}, 
   {Hue[0.3782201291620933], AbsoluteThickness[0.5], 
    LineBox[{{4.605021439422993, -1.095488211528203}, {
     4.598762474420038, -1.32269551700764}}]}, 
   {Hue[0.5775158294162137], AbsoluteThickness[0.5], 
    LineBox[{{2.661073537576901, -0.841079532332187}, {
     2.6194019017522057`, -0.9106067412493424}}]}, 
   {Hue[0.5780077238529251], AbsoluteThickness[0.5], 
    LineBox[{{2.6194019017522057`, -0.9106067412493424}, {
     2.4304867263221803`, -1.2018760763424463`}}]}, 
   {Hue[0.5667443414208713], AbsoluteThickness[0.5], 
    LineBox[{{3.9676447759930236`, -1.6079819570314533`}, {
     3.8578495987142163`, -1.9710649875566215`}}]}, 
   {Hue[0.609297149638592], AbsoluteThickness[0.5], 
    LineBox[{{3.8578495987142163`, -1.9710649875566215`}, {
     3.86801761611934, -2.103761025729109}}]}, 
   {Hue[0.36215136175532625`], AbsoluteThickness[0.5], 
    LineBox[{{4.861848818704677, -1.1744589177260953`}, {
     5.128404240285763, -1.3274598840109417`}}]}, 
   {Hue[0.36367965468812113`], AbsoluteThickness[0.5], 
    LineBox[{{5.128404240285763, -1.3274598840109417`}, {
     5.329797749713981, -1.4122820404292893`}}]}, 
   {Hue[0.648437551770381], AbsoluteThickness[0.5], 
    LineBox[{{4.723160045545716, -0.07400350164950903}, {4.758160474877428, 
     0.14193390337167516`}}]}, 
   {Hue[0.648974809813918], AbsoluteThickness[0.5], 
    LineBox[{{4.758160474877428, 0.14193390337167516`}, {4.787709350489831, 
     0.39731878168488094`}}]}, 
   {Hue[0.6562170078255101], AbsoluteThickness[0.5], 
    LineBox[{{2.0907984583524093`, -1.3488971816536337`}, {
     2.084439879908477, -1.3598372513918677`}}]}, 
   {Hue[0.6566506637707824], AbsoluteThickness[0.5], 
    LineBox[{{2.084439879908477, -1.3598372513918677`}, {
     1.9225301817417328`, -1.6306342944910095`}}]}, 
   {Hue[0.6615405610720875], AbsoluteThickness[0.5], 
    LineBox[{{2.9041828076495344`, -3.667092237876926}, {
     2.9249377686464806`, -3.799617792289697}}]}, 
   {Hue[0.6619851721162942], AbsoluteThickness[0.5], 
    LineBox[{{2.9249377686464806`, -3.799617792289697}, {
     2.979572465429276, -4.109558158803205}}]}, 
   {Hue[0.632023909393653], AbsoluteThickness[0.5], 
    LineBox[{{4.90093696271851, -2.3221979956597747`}, {
     5.055490565157455, -2.2802661346414888`}}]}, 
   {Hue[0.6324498076135803], AbsoluteThickness[0.5], 
    LineBox[{{5.055490565157455, -2.2802661346414888`}, {
     5.383063580816792, -2.191064125013209}}]}, 
   {Hue[0.5580832047591602], AbsoluteThickness[0.5], 
    LineBox[{{2.337538330466895, -4.3696185333155455`}, {
     2.3856670118423073`, -4.4520108303435775`}}]}, 
   {Hue[0.5599668655521278], AbsoluteThickness[0.5], 
    LineBox[{{2.3856670118423073`, -4.4520108303435775`}, {
     2.4686369601773515`, -4.652294503815678}}]}, 
   {Hue[0.5160752841905316], AbsoluteThickness[0.5], 
    LineBox[{{5.876704329874874, -2.254095739636099}, {
     6.11507194893921, -2.24302970971277}}]}, 
   {Hue[0.5165036314348739], AbsoluteThickness[0.5], 
    LineBox[{{6.11507194893921, -2.24302970971277}, {
     6.445887644850395, -2.2253475276472057`}}]}, 
   {Hue[0.6245612337514997], AbsoluteThickness[0.5], 
    LineBox[{{3.8213562285466582`, 0.3693031878918492}, {3.7810843196770705`, 
     0.6325301661060011}}]}, 
   {Hue[0.624987143628497], AbsoluteThickness[0.5], 
    LineBox[{{3.7810843196770705`, 0.6325301661060011}, {3.7332208275790237`, 
     0.9431965101928954}}]}, 
   {Hue[0.5834493509138043], AbsoluteThickness[0.5], 
    LineBox[{{4.645469199757275, -4.535079698743982}, {
     4.821546688326888, -4.564187919088061}}]}, 
   {Hue[0.5841738371385475], AbsoluteThickness[0.5], 
    LineBox[{{4.821546688326888, -4.564187919088061}, {
     5.113001254393057, -4.591178600246907}}]}, 
   {Hue[0.532417544024897], AbsoluteThickness[0.5], 
    LineBox[{{3.6329106438501926`, -0.08948164217111729}, {3.762173207614026, 
     0.05486890957291879}}]}, 
   {Hue[0.5340457212961627], AbsoluteThickness[0.5], 
    LineBox[{{3.762173207614026, 0.05486890957291879}, {3.9262586308343446`, 
     0.19703540101119452`}}]}, 
   {Hue[0.521632793911108], AbsoluteThickness[0.5], 
    LineBox[{{4.5492255834463196`, 1.185058724626135}, {4.613805276087313, 
     1.2387406838267192`}}]}, 
   {Hue[0.5221646259201336], AbsoluteThickness[0.5], 
    LineBox[{{4.613805276087313, 1.2387406838267192`}, {4.796734310103455, 
     1.40508279759048}}]}, 
   {Hue[0.4566801698771082], AbsoluteThickness[0.5], 
    LineBox[{{5.552172974635186, -3.1438164711174337`}, {
     5.580553916982512, -3.1797875457698135`}}]}, 
   {Hue[0.457171466761246], AbsoluteThickness[0.5], 
    LineBox[{{5.580553916982512, -3.1797875457698135`}, {
     5.7812551175476035`, -3.4164898213319477`}}]}, 
   {Hue[0.6178816408176961], AbsoluteThickness[0.5], 
    LineBox[{{3.07050071907062, -2.631005360121342}, {
     3.005568175646746, -2.826841489718561}}]}, 
   {Hue[0.6183905411206128], AbsoluteThickness[0.5], 
    LineBox[{{3.005568175646746, -2.826841489718561}, {
     2.9131862379494273`, -3.147391636888103}}]}, 
   {Hue[0.5335081558501605], AbsoluteThickness[0.5], 
    LineBox[{{4.198515819063912, -2.3807807360933464`}, {
     4.367974100266702, -2.614513636237666}}]}, 
   {Hue[0.5434679412518565], AbsoluteThickness[0.5], 
    LineBox[{{4.367974100266702, -2.614513636237666}, {
     4.4288926281203445`, -2.7687285119753944`}}]}, 
   {Hue[0.5467939465852105], AbsoluteThickness[0.5], 
    LineBox[{{2.194619661868609, -0.42028675434090923`}, {
     2.1578866572680244`, -0.42551179850312243`}}]}, 
   {Hue[0.5472200758185471], AbsoluteThickness[0.5], 
    LineBox[{{2.1578866572680244`, -0.42551179850312243`}, {
     1.8435763195734411`, -0.4709678828456456}}]}, 
   {Hue[0.48177517524696817`], AbsoluteThickness[0.5], 
    LineBox[{{3.3829237941441628`, 1.0293276318689153`}, {3.143883050646855, 
     1.116495461397206}}]}, 
   {Hue[0.4884905854045931], AbsoluteThickness[0.5], 
    LineBox[{{3.143883050646855, 1.116495461397206}, {2.936825549559755, 
     1.1431103431615066`}}]}, 
   {Hue[0.5661997321818625], AbsoluteThickness[0.5], 
    LineBox[{{3.926398459228007, 0.9255410984668038}, {3.693738302648156, 
     0.9854144289186859}}]}, 
   {Hue[0.5666281723713877], AbsoluteThickness[0.5], 
    LineBox[{{3.693738302648156, 0.9854144289186859}, {3.389168923748963, 
     1.0614793457625638`}}]}, 
   {Hue[0.5256356281669472], AbsoluteThickness[0.5], 
    LineBox[{{4.673716147708276, 1.1720892911058227`}, {4.673939756648458, 
     1.0861903196906042`}}]}, 
   {Hue[0.5316875412510573], AbsoluteThickness[0.5], 
    LineBox[{{4.673939756648458, 1.0861903196906042`}, {4.62870933134975, 
     0.8757920879901597}}]}, 
   {Hue[0.016709882476723847`], AbsoluteThickness[0.5], 
    LineBox[{{4.864464361371456, 1.3169635198359015`}, {4.909005178363968, 
     1.3555587479791689`}}]}, 
   {Hue[0.017197446051123687`], AbsoluteThickness[0.5], 
    LineBox[{{4.909005178363968, 1.3555587479791689`}, {5.1493897750713575`, 
     1.5787378751750272`}}]}, 
   {Hue[0.5584404618289043], AbsoluteThickness[0.5], 
    LineBox[{{5.1493897750713575`, 1.5787378751750272`}, {4.832803675062183, 
     1.4929071205991715`}}]}, 
   {Hue[0.5269606381758847], AbsoluteThickness[0.5], 
    LineBox[{{4.630191051364813, 1.3668578019167235`}, {4.629738343566065, 
     1.3669240901241446`}}]}, 
   {Hue[0.5277906872233246], AbsoluteThickness[0.5], 
    LineBox[{{4.629738343566065, 1.3669240901241446`}, {4.407139248055496, 
     1.4183274988901455`}}]}, 
   {Hue[0.5620684957573518], AbsoluteThickness[0.5], 
    LineBox[{{4.272954651652534, 0.5798181107234576}, {3.925182144058255, 
     0.24440440753383197`}}]}, 
   {Hue[0.5628890498210186], AbsoluteThickness[0.5], 
    LineBox[{{3.925182144058255, 0.24440440753383197`}, {3.7070697616364563`, 
     0.06563702293561796}}]}, 
   {Hue[0.4873915574343328], AbsoluteThickness[0.5], 
    LineBox[{{4.68288619855647, -0.029366927509053092`}, {
     4.693510860990209, -0.0766265012099483}}]}, 
   {Hue[0.487818648040712], AbsoluteThickness[0.5], 
    LineBox[{{4.693510860990209, -0.0766265012099483}, {
     4.762728437708023, -0.39177672229575156`}}]}, 
   {Hue[0.5637516188876277], AbsoluteThickness[0.5], 
    LineBox[{{4.020956396031442, -1.168589886633876}, {
     4.057367629320503, -1.36826100050179}}]}, 
   {Hue[0.5651851225979825], AbsoluteThickness[0.5], 
    LineBox[{{4.057367629320503, -1.36826100050179}, {
     4.07012990744971, -1.5736142042067225`}}]}, 
   {Hue[0.5584773208088792], AbsoluteThickness[0.5], 
    LineBox[{{3.370628148175305, -1.579809022563283}, {
     3.360057852068775, -1.609757292509396}}]}, 
   {Hue[0.5590340259378761], AbsoluteThickness[0.5], 
    LineBox[{{3.360057852068775, -1.609757292509396}, {
     3.243953403072276, -1.8935204555909269`}}]}, 
   {Hue[0.46488931772158204`], AbsoluteThickness[0.5], 
    LineBox[{{3.6669229679746858`, -4.152355409388753}, {
     3.668999795074863, -4.181477053396589}}]}, 
   {Hue[0.4660789557066483], AbsoluteThickness[0.5], 
    LineBox[{{3.668999795074863, -4.181477053396589}, {
     3.7145968835518772`, -4.435913329146341}}]}, 
   {Hue[0.583991707553034], AbsoluteThickness[0.5], 
    LineBox[{{2.7138211637930056`, -1.8994789492693493`}, {
     2.633221917970274, -1.923987291381314}}]}, 
   {Hue[0.5844205957787001], AbsoluteThickness[0.5], 
    LineBox[{{2.633221917970274, -1.923987291381314}, {
     2.324944115093903, -2.0151299511104215`}}]}, 
   {Hue[0.5259743000777812], AbsoluteThickness[0.5], 
    LineBox[{{4.498983326186483, -1.6365855157504334`}, {
     4.483668131752684, -1.852379970069834}}]}, 
   {Hue[0.5264205550952139], AbsoluteThickness[0.5], 
    LineBox[{{4.483668131752684, -1.852379970069834}, {
     4.466969022399495, -2.1801241503529494`}}]}, 
   {Hue[0.4805712834739945], AbsoluteThickness[0.5], 
    LineBox[{{5.559938625622877, -1.1722948968182805`}, {
     5.639410493963196, -1.3874522365570583`}}]}, 
   {Hue[0.4843119521575211], AbsoluteThickness[0.5], 
    LineBox[{{5.639410493963196, -1.3874522365570583`}, {
     5.674854981263543, -1.5904751479467907`}}]}, 
   {Hue[0.5578303029694592], AbsoluteThickness[0.5], 
    LineBox[{{5.035862718667926, -0.124967251053627}, {
     5.050249326828036, -0.37055893692938946`}}]}, 
   {Hue[0.558370627898809], AbsoluteThickness[0.5], 
    LineBox[{{5.050249326828036, -0.37055893692938946`}, {
     5.053840529477327, -0.6595056944784647}}]}, 
   {Hue[0.5681903088499906], AbsoluteThickness[0.5], 
    LineBox[{{4.870909306565453, 0.9019166755141031}, {4.818397980953666, 
     0.8574975826589549}}]}, 
   {Hue[0.5687449954062901], AbsoluteThickness[0.5], 
    LineBox[{{4.818397980953666, 0.8574975826589549}, {4.601464635682168, 
     0.655068451747265}}]}, 
   {Hue[0.45022138852865823`], AbsoluteThickness[0.5], 
    LineBox[{{5.734004832019249, 2.0918730067063587`}, {5.848910807608059, 
     2.025397062553965}}]}, 
   {Hue[0.4507490504057102], AbsoluteThickness[0.5], 
    LineBox[{{5.848910807608059, 2.025397062553965}, {6.144664772822665, 
     1.8710928713133896`}}]}, 
   {Hue[0.022216085271159355`], AbsoluteThickness[0.5], 
    LineBox[{{5.812453746192833, 2.2570474331947743`}, {5.883455291137228, 
     2.4683644158583733`}}]}, 
   {Hue[0.028016022830388263`], AbsoluteThickness[0.5], 
    LineBox[{{5.883455291137228, 2.4683644158583733`}, {5.987169457190278, 
     2.6431761732923356`}}]}, 
   {Hue[0.3209002096798664], AbsoluteThickness[0.5], 
    LineBox[{{5.987169457190278, 2.6431761732923356`}, {6.182948291025892, 
     2.588527961984032}}]}, 
   {Hue[0.6137843965293438], AbsoluteThickness[0.5], 
    LineBox[{{6.182948291025892, 2.588527961984032}, {6.181131863724281, 
     2.385273246493621}}]}, 
   {Hue[0.4531309057718295], AbsoluteThickness[0.5], 
    LineBox[{{5.634971682049219, 2.3010581160810193`}, {5.374952993802574, 
     2.33341652392111}}]}, 
   {Hue[0.4544975527769087], AbsoluteThickness[0.5], 
    LineBox[{{5.374952993802574, 2.33341652392111}, {5.111135082510246, 
     2.33568655743686}}]}, 
   {Hue[0.5701241378499455], AbsoluteThickness[0.5], 
    LineBox[{{5.141353261498219, 0.6425296588324133}, {5.141285795165151, 
     0.641407547815421}}]}, 
   {Hue[0.5715797273269844], AbsoluteThickness[0.5], 
    LineBox[{{5.141285795165151, 0.641407547815421}, {5.099360318457141, 
     0.4101543403806851}}]}, 
   {Hue[0.5592723179833688], AbsoluteThickness[0.5], 
    LineBox[{{3.8418806851008642`, 0.488943978798402}, {3.583112476783197, 
     0.39487569559467006`}}]}, 
   {Hue[0.5636333251167459], AbsoluteThickness[0.5], 
    LineBox[{{3.583112476783197, 0.39487569559467006`}, {3.391464181893433, 
     0.36448846474538343`}}]}, 
   {Hue[0.4717714600668471], AbsoluteThickness[0.5], 
    LineBox[{{3.649534138781242, 1.2786155633355174`}, {3.497280348552251, 
     1.3555142011104326`}}]}, 
   {Hue[0.4735239777569556], AbsoluteThickness[0.5], 
    LineBox[{{3.497280348552251, 1.3555142011104326`}, {3.324333895295766, 
     1.4735737937275017`}}]}, 
   {Hue[0.5423013331826106], AbsoluteThickness[0.5], 
    LineBox[{{2.381797109943083, 0.40654121726941117`}, {2.163113040172356, 
     0.45702965610568025`}}]}, 
   {Hue[0.542765803364415], AbsoluteThickness[0.5], 
    LineBox[{{2.163113040172356, 0.45702965610568025`}, {1.931589046094528, 
     0.5038649101974159}}]}, 
   {Hue[0.5726493853845669], AbsoluteThickness[0.5], 
    LineBox[{{2.4162735284091204`, -1.6363683912908917`}, {
     2.4040794606589424`, -1.6476035472501045`}}]}, 
   {Hue[0.5731420435558605], AbsoluteThickness[0.5], 
    LineBox[{{2.4040794606589424`, -1.6476035472501045`}, {
     2.1853897164995115`, -1.83513955295675}}]}, 
   {Hue[0.47141034286992284`], AbsoluteThickness[0.5], 
    LineBox[{{4.805968574458224, -4.430989728960613}, {
     4.821538394170795, -4.443569064989654}}]}, 
   {Hue[0.47191183706058965`], AbsoluteThickness[0.5], 
    LineBox[{{4.821538394170795, -4.443569064989654}, {
     5.075175994138445, -4.6330949474017045`}}]}, 
   {Hue[0.5632117911103234], AbsoluteThickness[0.5], 
    LineBox[{{5.905355307612585, -3.7300839651968913`}, {
     6.072012634958054, -3.787612278514879}}]}, 
   {Hue[0.5640447978987667], AbsoluteThickness[0.5], 
    LineBox[{{6.072012634958054, -3.787612278514879}, {
     6.326838357332485, -3.8528360062609104`}}]}, 
   {Hue[0.6381010700449342], AbsoluteThickness[0.5], 
    LineBox[{{5.625038908274706, -0.03781124990434581}, {
     5.70390793969209, -0.17091062939034146`}}]}, 
   {Hue[0.6385279092596081], AbsoluteThickness[0.5], 
    LineBox[{{5.70390793969209, -0.17091062939034146`}, {
     5.8407912711761565`, -0.4042539088119889}}]}, 
   {Hue[0.5142753295683511], AbsoluteThickness[0.5], 
    LineBox[{{5.546928522158454, 0.8213024033604124}, {5.620168530329591, 
     0.8101070386681664}}]}, 
   {Hue[0.514711162558633], AbsoluteThickness[0.5], 
    LineBox[{{5.620168530329591, 0.8101070386681664}, {5.917407499966679, 
     0.7604063067991825}}]}, 
   {Hue[0.2728605762638661], AbsoluteThickness[0.5], 
    LineBox[{{5.6754312883889755`, 0.965732210021195}, {5.728755433775245, 
     1.0657343170698752`}}]}, 
   {Hue[0.27337333499760014`], AbsoluteThickness[0.5], 
    LineBox[{{5.728755433775245, 1.0657343170698752`}, {5.8786741028400895`, 
     1.3765305461266364`}}]}, 
   {Hue[0.5308424801003049], AbsoluteThickness[0.5], 
    LineBox[{{5.581817563310506, 1.1348753460270635`}, {4.688066926719729, 
     2.1083516850426998`}}]}, 
   {Hue[0.5342271967418523], AbsoluteThickness[0.5], 
    LineBox[{{4.688066926719729, 2.1083516850426998`}, {4.575246650437302, 
     2.2849644988954356`}}]}, 
   {Hue[0.655994085544534], AbsoluteThickness[0.5], 
    LineBox[{{5.072251297053539, 1.2814550713451227`}, {5.062676544835845, 
     1.3392645444864415`}}]}, 
   {Hue[0.6564529035805374], AbsoluteThickness[0.5], 
    LineBox[{{5.062676544835845, 1.3392645444864415`}, {5.0000997586313725`, 
     1.665700727842299}}]}, 
   {Hue[0.5904077767848563], AbsoluteThickness[0.5], 
    LineBox[{{2.9102977330877557`, -1.329828038289851}, {
     2.8895195271298184`, -1.405881128449736}}]}, 
   {Hue[0.5968962558012995], AbsoluteThickness[0.5], 
    LineBox[{{2.8895195271298184`, -1.405881128449736}, {
     2.880319745354753, -1.600044843205336}}]}, 
   {Hue[0.5917878747648738], AbsoluteThickness[0.5], 
    LineBox[{{4.458350924669539, 0.29671829714307896`}, {4.601397169787153, 
     0.23696060431599633`}}]}, 
   {Hue[0.5927837732393024], AbsoluteThickness[0.5], 
    LineBox[{{4.601397169787153, 0.23696060431599633`}, {4.817046216678165, 
     0.1699060958663165}}]}, 
   {Hue[0.596931029204622], AbsoluteThickness[0.5], 
    LineBox[{{3.6873050669779572`, 0.9621728392800676}, {3.7020134271579166`, 
     0.9352985404665106}}]}, 
   {Hue[0.5973742059743931], AbsoluteThickness[0.5], 
    LineBox[{{3.7020134271579166`, 0.9352985404665106}, {3.84656440802801, 
     0.6592445764766337}}]}, 
   {Hue[0.584807570753733], AbsoluteThickness[0.5], 
    LineBox[{{2.455333636661464, 1.832280223514339}, {2.4715991170959613`, 
     1.6583018011408486`}}]}, 
   {Hue[0.5852344338995236], AbsoluteThickness[0.5], 
    LineBox[{{2.4715991170959613`, 1.6583018011408486`}, {2.502030092082712, 
     1.3163558707053424`}}]}, 
   {Hue[0.5306628962090199], AbsoluteThickness[0.5], 
    LineBox[{{2.134071685559335, 3.1502958414922753`}, {2.0467320792549346`, 
     3.103479854775183}}]}, 
   {Hue[0.5330085008427028], AbsoluteThickness[0.5], 
    LineBox[{{2.0467320792549346`, 3.103479854775183}, {1.899033733051258, 
     2.9930118296809156`}}]}, 
   {Hue[0.5351623279874436], AbsoluteThickness[0.5], 
    LineBox[{{2.924754069947133, 3.1792630564131725`}, {2.937811645886469, 
     3.1579686211239593`}}]}, 
   {Hue[0.5356152380373208], AbsoluteThickness[0.5], 
    LineBox[{{2.937811645886469, 3.1579686211239593`}, {3.106635100216443, 
     2.896305104901701}}]}, 
   {Hue[0.5891984677816733], AbsoluteThickness[0.5], 
    LineBox[{{2.6212358691620845`, 2.099498261512685}, {2.7004085994373153`, 
     1.9118497985969407`}}]}, 
   {Hue[0.5896321878365736], AbsoluteThickness[0.5], 
    LineBox[{{2.7004085994373153`, 1.9118497985969407`}, {2.8241205362221615`,
      1.6285229282803386`}}]}, 
   {Hue[0.582654845052269], AbsoluteThickness[0.5], 
    LineBox[{{2.983709504481396, 1.3322260787458533`}, {3.0187810335310328`, 
     1.1653625129741687`}}]}, 
   {Hue[0.5831077268674928], AbsoluteThickness[0.5], 
    LineBox[{{3.0187810335310328`, 1.1653625129741687`}, {3.082181626089391, 
     0.8251675689221656}}]}, 
   {Hue[0.5836633625613727], AbsoluteThickness[0.5], 
    LineBox[{{3.9473806771221565`, -2.159016450802411}, {
     4.101446276857584, -2.376585480321616}}]}, 
   {Hue[0.650723615821463], AbsoluteThickness[0.5], 
    LineBox[{{4.101446276857584, -2.376585480321616}, {
     4.134289872279304, -2.532009809418578}}]}, 
   {Hue[0.5426014878607842], AbsoluteThickness[0.5], 
    LineBox[{{4.66081251694832, -2.052967295163823}, {
     4.712031722638801, -2.1173752972041706`}}]}, 
   {Hue[0.5430765807825659], AbsoluteThickness[0.5], 
    LineBox[{{4.712031722638801, -2.1173752972041706`}, {
     4.883534128008964, -2.3471986401724068`}}]}, 
   {Hue[0.6640055694178253], AbsoluteThickness[0.5], 
    LineBox[{{3.0945805724511977`, 3.1905173962071527`}, {3.1039156474988108`,
      3.2376715279358512`}}]}, 
   {Hue[0.6704606896404608], AbsoluteThickness[0.5], 
    LineBox[{{3.1039156474988108`, 3.2376715279358512`}, {3.1799936591151465`,
      3.4106154432621407`}}]}, 
   {Hue[0.539057312209472], AbsoluteThickness[0.5], 
    LineBox[{{4.843774195796624, 1.3638471423543908`}, {4.861140793596736, 
     1.40307004465537}}]}, 
   {Hue[0.5398214228795473], AbsoluteThickness[0.5], 
    LineBox[{{4.861140793596736, 1.4030700446553703`}, {5.002015558906721, 
     1.6657077818291306`}}]}, 
   {Hue[0.4316723345629716], AbsoluteThickness[0.5], 
    LineBox[{{5.478056079514354, -0.8690607457533852}, {
     5.649413390702043, -0.8186964219508803}}]}, 
   {Hue[0.4322505055480068], AbsoluteThickness[0.5], 
    LineBox[{{5.649413390702043, -0.8186964219508803}, {
     5.916799579681213, -0.7245500619221745}}]}, 
   {Hue[0.3566344272073164], AbsoluteThickness[0.5], 
    LineBox[{{5.624208606997544, -0.9363036649907435}, {
     5.735700585775407, -1.0451520710077615`}}]}, 
   {Hue[0.35755479877286506`], AbsoluteThickness[0.5], 
    LineBox[{{5.735700585775407, -1.0451520710077615`}, {
     5.911580236495629, -1.2503725979815952`}}]}, 
   {Hue[0.4929087019747889], AbsoluteThickness[0.5], 
    LineBox[{{5.63711661754022, -1.0966643669757272`}, {
     5.635400499280283, -1.1030672027233044`}}]}, 
   {Hue[0.49972467645159824`], AbsoluteThickness[0.5], 
    LineBox[{{5.635400499280283, -1.1030672027233044`}, {
     5.628034126328007, -1.292052827177402}}]}, 
   {Hue[0.629182976742259], AbsoluteThickness[0.5], 
    LineBox[{{5.503601368676467, -1.1864187529306036`}, {
     5.388751258987784, -1.2157033745956884`}}]}, 
   {Hue[0.6296644659682044], AbsoluteThickness[0.5], 
    LineBox[{{5.388751258987784, -1.2157033745956884`}, {
     5.1223070965712445`, -1.2929783563435397`}}]}, 
   {Hue[0.5629038971214936], AbsoluteThickness[0.5], 
    LineBox[{{3.8470464308022323`, -2.8308762381079355`}, {
     3.8362834735531193`, -3.1430324475136464`}}]}, 
   {Hue[0.5633946254977911], AbsoluteThickness[0.5], 
    LineBox[{{3.8362834735531193`, -3.1430324475136464`}, {
     3.815892011362471, -3.4355363250256463`}}]}, 
   {Hue[0.5752809321974148], AbsoluteThickness[0.5], 
    LineBox[{{2.6661888115363617`, -2.901405426311577}, {
     2.6729438880490295`, -3.136745206175701}}]}, 
   {Hue[0.5758989543566795], AbsoluteThickness[0.5], 
    LineBox[{{2.6729438880490295`, -3.136745206175701}, {
     2.6981643487968836`, -3.424800456376373}}]}, 
   {Hue[0.4912843275242157], AbsoluteThickness[0.5], 
    LineBox[{{5.30676519214427, 0.12104194578115585`}, {5.437906972134828, 
     0.10070446241581546`}}]}, 
   {Hue[0.49180313834838946`], AbsoluteThickness[0.5], 
    LineBox[{{5.437906972134828, 0.10070446241581546`}, {5.659182913247572, 
     0.056860682342823037`}}]}, 
   {Hue[0.3165646772855891], AbsoluteThickness[0.5], 
    LineBox[{{4.64668851181943, 2.4443512532127567`}, {5.116640025942918, 
     2.7556677023555256`}}]}, 
   {Hue[0.3179760802086593], AbsoluteThickness[0.5], 
    LineBox[{{5.116640025942918, 2.7556677023555256`}, {5.308685378550107, 
     2.8526832269091424`}}]}, 
   {Hue[0.6203776233233927], AbsoluteThickness[0.5], 
    LineBox[{{2.568674459886656, 2.148379612999648}, {2.4840263750203015`, 
     2.101568236368022}}]}, 
   {Hue[0.6237087053568773], AbsoluteThickness[0.5], 
    LineBox[{{2.4840263750203015`, 2.101568236368022}, {2.343590900732108, 
     1.9883859874458532`}}]}, 
   {Hue[0.5965682720681995], AbsoluteThickness[0.5], 
    LineBox[{{3.0784910961259984`, 2.887125304523418}, {3.146103076080292, 
     2.8167958779942954`}}]}, 
   {Hue[0.597196934324991], AbsoluteThickness[0.5], 
    LineBox[{{3.146103076080292, 2.8167958779942954`}, {3.3601069865548876`, 
     2.619420191602695}}]}, 
   {Hue[0.09763648519643302], AbsoluteThickness[0.5], 
    LineBox[{{3.1482674309292404`, 3.1594058030204084`}, {3.148282594742523, 
     3.1594897274979115`}}]}, 
   {Hue[0.09843692774576408], AbsoluteThickness[0.5], 
    LineBox[{{3.148282594742523, 3.1594897274979115`}, {3.218553109259726, 
     3.426129526477303}}]}, 
   {Hue[0.589584494122089], AbsoluteThickness[0.5], 
    LineBox[{{3.218553109259726, 3.426129526477303}, {3.4082364232599773`, 
     3.2259921536551213`}}]}, 
   {Hue[0.5980291056783796], AbsoluteThickness[0.5], 
    LineBox[{{2.8867699510477567`, 3.056330710122189}, {2.6074413946513397`, 
     2.9222307343998595`}}]}, 
   {Hue[0.5996106645445302], AbsoluteThickness[0.5], 
    LineBox[{{2.6074413946513397`, 2.9222307343998595`}, {2.3781153272002955`,
      2.845490083083523}}]}, 
   {Hue[0.6218632988100669], AbsoluteThickness[0.5], 
    LineBox[{{3.3054391489621895`, 2.0689769531056648`}, {3.6825906648621802`,
      1.3865380405928065`}}]}, 
   {Hue[0.622414319834399], AbsoluteThickness[0.5], 
    LineBox[{{3.6825906648621802`, 1.3865380405928065`}, {3.830313603754135, 
     1.1471785062895667`}}]}, 
   {Hue[0.6127621745684418], AbsoluteThickness[0.5], 
    LineBox[{{2.823379125732227, 2.874923107054231}, {2.8895972093529014`, 
     3.0077298778997097`}}]}, 
   {Hue[0.6147692333353766], AbsoluteThickness[0.5], 
    LineBox[{{2.8895972093529014`, 3.0077298778997097`}, {3.019838149164961, 
     3.1970599043857892`}}]}, 
   {Hue[0.2295729223813501], AbsoluteThickness[0.5], 
    LineBox[{{2.1105729632646173`, 2.87322003082137}, {2.110301775097096, 
     2.8733294461351058`}}]}, 
   {Hue[0.23024845882905245`], AbsoluteThickness[0.5], 
    LineBox[{{2.110301775097096, 2.8733294461351058`}, {1.8977158772629603`, 
     2.975891288668856}}]}, 
   {Hue[0.6172143331854189], AbsoluteThickness[0.5], 
    LineBox[{{2.152336807627857, 2.1113096584286044`}, {2.1474901867528327`, 
     2.100720126230259}}]}, 
   {Hue[0.6183189541281026], AbsoluteThickness[0.5], 
    LineBox[{{2.1474901867528327`, 2.100720126230259}, {2.0299799417280275`, 
     1.9003649057171914`}}]}, 
   {Hue[0.49790096028075953`], AbsoluteThickness[0.5], 
    LineBox[{{2.2253443957365415`, 2.0869705991201744`}, {2.1587908018567843`,
      2.0621822681358646`}}]}, 
   {Hue[0.4983624704075822], AbsoluteThickness[0.5], 
    LineBox[{{2.1587908018567843`, 2.0621822681358646`}, {1.8947949242020603`,
      1.9716732853598242`}}]}, 
   {Hue[0.6428596532920914], AbsoluteThickness[0.5], 
    LineBox[{{2.3313982572150262`, 2.7684855414842775`}, {2.356713798599465, 
     2.8609797485248603`}}]}, 
   {Hue[0.6434655939719659], AbsoluteThickness[0.5], 
    LineBox[{{2.356713798599465, 2.8609797485248603`}, {2.4503673539669237`, 
     3.139780913905041}}]}, 
   {Hue[0.5769602856864459], AbsoluteThickness[0.5], 
    LineBox[{{2.275539695366952, 2.887167725935661}, {2.1539506625774423`, 
     3.008301890895969}}]}, 
   {Hue[0.5807830442536919], AbsoluteThickness[0.5], 
    LineBox[{{2.1539506625774423`, 3.008301890895969}, {2.0142594144994366`, 
     3.1040907486519336`}}]}, 
   {Hue[0.333174183383097], AbsoluteThickness[0.5], 
    LineBox[{{2.3214797899905504`, 1.6396201093950835`}, {2.202355807142818, 
     1.382136538065374}}]}, 
   {Hue[0.3342456990375309], AbsoluteThickness[0.5], 
    LineBox[{{2.202355807142818, 1.382136538065374}, {2.1128218230914357`, 
     1.1242264377148508`}}]}, 
   {Hue[0.3852438551457357], AbsoluteThickness[0.5], 
    LineBox[{{3.0944903810164766`, 1.3691821647396196`}, {3.143138300091241, 
     1.2820917631519235`}}]}, 
   {Hue[0.3886751098828588], AbsoluteThickness[0.5], 
    LineBox[{{3.143138300091241, 1.2820917631519235`}, {3.2604210857285847`, 
     1.138413421848536}}]}, 
   {Hue[0.4398376285789966], AbsoluteThickness[0.5], 
    LineBox[{{3.6715870978324103`, 2.007155127950634}, {3.87356037226229, 
     1.97229014195547}}]}, 
   {Hue[0.44029005395985804`], AbsoluteThickness[0.5], 
    LineBox[{{3.87356037226229, 1.97229014195547}, {4.1978854965930115`, 
     1.9238652161644683`}}]}, 
   {Hue[0.49317734796814167`], AbsoluteThickness[0.5], 
    LineBox[{{3.2761975537919015`, 2.921106625240307}, {3.339806887758208, 
     2.9966672526779456`}}]}, 
   {Hue[0.4943258083304826], AbsoluteThickness[0.5], 
    LineBox[{{3.339806887758208, 2.9966672526779456`}, {3.5324534443507174`, 
     3.1824490288635174`}}]}, 
   {Hue[0.5454440156641703], AbsoluteThickness[0.5], 
    LineBox[{{2.460894550157647, 3.1400809378009105`}, {2.4248218334374143`, 
     3.206401426307954}}]}, 
   {Hue[0.5474461622193997], AbsoluteThickness[0.5], 
    LineBox[{{2.4248218334374143`, 3.206401426307954}, {2.2870984284353653`, 
     3.392140184915822}}]}, 
   {Hue[0.6521400422880173], AbsoluteThickness[0.5], 
    LineBox[{{2.000571477384569, 1.3515813160915384`}, {1.8713219531957874`, 
     1.1193841404326197`}}]}, 
   {Hue[0.6687227754242708], AbsoluteThickness[0.5], 
    LineBox[{{1.8713219531957874`, 1.1193841404326197`}, {1.832654370812486, 
     0.9437745114165953}}]}, 
   {Hue[0.4282361507397102], AbsoluteThickness[0.5], 
    LineBox[{{4.359929523871454, 2.361907996273263}, {4.368797389841387, 
     2.3628417652303493`}}]}, 
   {Hue[0.4290461476833128], AbsoluteThickness[0.5], 
    LineBox[{{4.368797389841387, 2.3628417652303493`}, {4.639537132703694, 
     2.4134239582979853`}}]}, 
   {Hue[0.4694919280754776], AbsoluteThickness[0.5], 
    LineBox[{{5.152847052521294, 0.9262182392319177}, {5.2194575570081945`, 
     0.9072913642285511}}]}, 
   {Hue[0.4760782451988091], AbsoluteThickness[0.5], 
    LineBox[{{5.2194575570081945`, 0.9072913642285511}, {5.37870716527936, 
     0.8208550787815384}}]}, 
   {Hue[0.6034003108532434], AbsoluteThickness[0.5], 
    LineBox[{{5.079438222480103, -2.566703795055541}, {
     5.132762394262444, -2.584047598011166}}]}, 
   {Hue[0.6042446211571294], AbsoluteThickness[0.5], 
    LineBox[{{5.132762394262444, -2.584047598011166}, {
     5.409273624878352, -2.7000534002873837`}}]}, 
   {Hue[0.5345825515080114], AbsoluteThickness[0.5], 
    LineBox[{{5.860652410341793, -1.3256827409873113`}, {
     5.872634796773307, -1.3453936399092152`}}]}, 
   {Hue[0.5350095822629376], AbsoluteThickness[0.5], 
    LineBox[{{5.872634796773307, -1.3453936399092152`}, {
     6.04042966489375, -1.6184427033516537`}}]}, 
   {Hue[0.6419136808728799], AbsoluteThickness[0.5], 
    LineBox[{{2.1380784156283608`, -2.332604629278842}, {
     2.129514534827693, -2.3642579500849306`}}]}, 
   {Hue[0.6426130250440859], AbsoluteThickness[0.5], 
    LineBox[{{2.129514534827693, -2.3642579500849306`}, {
     2.0304868959379276`, -2.650578845473183}}]}, 
   {Hue[0.5329728145123341], AbsoluteThickness[0.5], 
    LineBox[{{3.8469645428393435`, 3.418098136531949}, {3.856134482617609, 
     3.4946659316255957`}}]}, 
   {Hue[0.5381776422183553], AbsoluteThickness[0.5], 
    LineBox[{{3.856134482617609, 3.4946659316255957`}, {3.9140288639236123`, 
     3.667695286418835}}]}, 
   {Hue[0.43275136522122154`], AbsoluteThickness[0.5], 
    LineBox[{{2.575107300949637, 2.7307676761358777`}, {2.4914919059395064`, 
     2.8257712654110314`}}]}, 
   {Hue[0.43345112453074874`], AbsoluteThickness[0.5], 
    LineBox[{{2.4914919059395064`, 2.8257712654110314`}, {2.318193479160022, 
     3.0523561437734363`}}]}, 
   {Hue[0.5879478075496246], AbsoluteThickness[0.5], 
    LineBox[{{2.1938402461294837`, 1.6742835730247596`}, {2.1303363014725223`,
      1.6702498153555922`}}]}, 
   {Hue[0.5891425998252143], AbsoluteThickness[0.5], 
    LineBox[{{2.1303363014725223`, 1.6702498153555922`}, {1.8364761820140563`,
      1.619851987788927}}]}, 
   {Hue[0.6077208587862464], AbsoluteThickness[0.5], 
    LineBox[{{2.369066545241023, 1.8844712943904298`}, {2.1565056417511945`, 
     2.009505899195767}}]}, 
   {Hue[0.6082215170546097], AbsoluteThickness[0.5], 
    LineBox[{{2.1565056417511945`, 2.009505899195767}, {1.9151122723416771`, 
     2.139533149133106}}]}, 
   {Hue[0.5985371815653406], AbsoluteThickness[0.5], 
    LineBox[{{3.70827888104162, 1.173380174104737}, {3.6336842411743127`, 
     1.1414178439444824`}}]}, 
   {Hue[0.5992375081151188], AbsoluteThickness[0.5], 
    LineBox[{{3.6336842411743127`, 1.1414178439444824`}, {3.3823518890304434`,
      1.0125832297425772`}}]}, 
   {Hue[0.5563884175095923], AbsoluteThickness[0.5], 
    LineBox[{{4.158838720553369, 2.9172143166412163`}, {4.086173841284693, 
     2.969049250688563}}]}, 
   {Hue[0.5573109510917669], AbsoluteThickness[0.5], 
    LineBox[{{4.086173841284693, 2.969049250688563}, {3.8932286341939153`, 
     3.0822615395957498`}}]}, 
   {Hue[0.5760580260313449], AbsoluteThickness[0.5], 
    LineBox[{{5.235027469109616, 2.061897289882064}, {5.1610787306997326`, 
     1.9334875909033589`}}]}, 
   {Hue[0.591547059414517], AbsoluteThickness[0.5], 
    LineBox[{{5.1610787306997326`, 1.9334875909033589`}, {5.060518603409003, 
     1.8374087572629074`}}]}, 
   {Hue[0.6022269563818299], AbsoluteThickness[0.5], 
    LineBox[{{6.0578531024600615`, 2.718540386817912}, {5.65156259960226, 
     2.6096014357424715`}}]}, 
   {Hue[0.6027724025161783], AbsoluteThickness[0.5], 
    LineBox[{{5.65156259960226, 2.6096014357424715`}, {5.3450343976905925`, 
     2.5117452572953383`}}]}, 
   {Hue[0.05030689443459232], AbsoluteThickness[0.5], 
    LineBox[{{6.3548009301530115`, 2.86851393330289}, {6.360430408576479, 
     2.8712632908675246`}}]}, 
   {Hue[0.05076790993511786], AbsoluteThickness[0.5], 
    LineBox[{{6.36043040857648, 2.8712632908675246`}, {6.646342957806336, 
     3.0202538237274514`}}]}, 
   {Hue[0.5976730601775783], AbsoluteThickness[0.5], 
    LineBox[{{6.646342957806336, 3.0202538237274514`}, {6.325853697968179, 
     2.9851710784330763`}}]}, 
   {Hue[0.6030968712254949], AbsoluteThickness[0.5], 
    LineBox[{{6.0919982295605974`, 2.6645413430409204`}, {6.0766520860337785`,
      2.6529558666052027`}}]}, 
   {Hue[0.6043611178859292], AbsoluteThickness[0.5], 
    LineBox[{{6.0766520860337785`, 2.6529558666052027`}, {5.883236249619, 
     2.4703040575968256`}}]}, 
   {Hue[0.5782211617960064], AbsoluteThickness[0.5], 
    LineBox[{{5.120277233704552, 2.6844301924758085`}, {4.909267414317625, 
     2.7787256816767094`}}]}, 
   {Hue[0.5788404363602351], AbsoluteThickness[0.5], 
    LineBox[{{4.909267414317625, 2.7787256816767094`}, {4.636581764061996, 
     2.8818150289647098`}}]}, 
   {Hue[0.6704395960625603], AbsoluteThickness[0.5], 
    LineBox[{{5.169798715175338, 1.4803526841540386`}, {5.176312758460555, 
     1.3978373164485391`}}]}, 
   {Hue[0.6709260198959198], AbsoluteThickness[0.5], 
    LineBox[{{5.176312758460555, 1.3978373164485391`}, {5.212659511690699, 
     1.076891272087904}}]}, 
   {Hue[0.6090003318282668], AbsoluteThickness[0.5], 
    LineBox[{{5.0707370028066245`, 1.3426278918831367`}, {4.678424204141662, 
     1.0757361147717286`}}]}, 
   {Hue[0.6094657870885313], AbsoluteThickness[0.5], 
    LineBox[{{4.678424204141662, 1.0757361147717286`}, {4.384338141156319, 
     0.8873419490798059}}]}, 
   {Hue[0.5887410340351368], AbsoluteThickness[0.5], 
    LineBox[{{2.8444445960652796`, 1.9741901061267448`}, {2.6122969953780584`,
      1.9799183338241064`}}]}, 
   {Hue[0.5891791167107433], AbsoluteThickness[0.5], 
    LineBox[{{2.6122969953780584`, 1.9799183338241064`}, {2.342730173988915, 
     1.982396299324096}}]}, 
   {Hue[0.5968123073369532], AbsoluteThickness[0.5], 
    LineBox[{{3.1190446972062684`, 0.7202379225473263}, {3.0821498837890564`, 
     0.6810569338454261}}]}, 
   {Hue[0.5974121446239926], AbsoluteThickness[0.5], 
    LineBox[{{3.0821498837890564`, 0.6810569338454261}, {2.9026570920761134`, 
     0.4676677033246549}}]}, 
   {Hue[0.6125420279970424], AbsoluteThickness[0.5], 
    LineBox[{{5.0386364356491855`, -0.12396936795235836`}, {
     5.006028146292369, -0.3634777726017219}}]}, 
   {Hue[0.6129796321288611], AbsoluteThickness[0.5], 
    LineBox[{{5.006028146292369, -0.3634777726017219}, {
     4.969772267979173, -0.6638027805133653}}]}, 
   {Hue[0.4129531391469409], AbsoluteThickness[0.5], 
    LineBox[{{5.601783148631202, -0.05578308301126747}, {
     5.886491299069149, -0.08552928120999569}}]}, 
   {Hue[0.4141997480122184], AbsoluteThickness[0.5], 
    LineBox[{{5.886491299069149, -0.08552928120999569}, {
     6.164120942303901, -0.08411237846499005}}]}, 
   {Hue[0.6387861894277291], AbsoluteThickness[0.5], 
    LineBox[{{5.667158822449169, 0.5326705406541905}, {5.718997792847909, 
     0.626371117256626}}]}, 
   {Hue[0.63923944226972], AbsoluteThickness[0.5], 
    LineBox[{{5.718997792847909, 0.626371117256626}, {5.857574073008361, 
     0.8910890503044555}}]}, 
   {Hue[0.6068801913967852], AbsoluteThickness[0.5], 
    LineBox[{{4.6200732002744225`, -0.6938985726108623}, {
     4.592461953018718, -0.8359835189030431}}]}, 
   {Hue[0.6074100695377621], AbsoluteThickness[0.5], 
    LineBox[{{4.592461953018718, -0.8359835189030431}, {
     4.523635158925179, -1.122210230657732}}]}, 
   {Hue[0.6111416572733499], AbsoluteThickness[0.5], 
    LineBox[{{3.7457843596801177`, -3.431568930606096}, {
     3.802341795942255, -3.5463437671448585`}}]}, 
   {Hue[0.6118017113734987], AbsoluteThickness[0.5], 
    LineBox[{{3.802341795942255, -3.5463437671448585`}, {
     3.927065475731581, -3.8466025248612326`}}]}, 
   {Hue[0.29702275179285464`], AbsoluteThickness[0.5], 
    LineBox[{{6.355282433923198, -0.36989199898833375`}, {
     6.463961858250947, -0.39698254741294836`}}]}, 
   {Hue[0.29847657156861673`], AbsoluteThickness[0.5], 
    LineBox[{{6.463961858250947, -0.39698254741294836`}, {
     6.706972523600871, -0.4894274390511977}}]}, 
   {Hue[0.661772440502853], AbsoluteThickness[0.5], 
    LineBox[{{3.0766089198113646`, 2.681688690135145}, {2.8420810038096076`, 
     3.0595911942219143`}}]}, 
   {Hue[0.6622010465220934], AbsoluteThickness[0.5], 
    LineBox[{{2.8420810038096076`, 3.0595911942219143`}, {2.6754014121303173`,
      3.3326340879980303`}}]}, 
   {Hue[0.45836843966104573`], AbsoluteThickness[0.5], 
    LineBox[{{2.977349793592353, -4.10962564933677}, {
     2.9901715910937674`, -4.348569913584521}}]}, 
   {Hue[0.45879438720031523`], AbsoluteThickness[0.5], 
    LineBox[{{2.9901715910937674`, -4.348569913584521}, {
     3.0076818245459727`, -4.683384009450293}}]}, 
   {Hue[0.5827116822473424], AbsoluteThickness[0.5], 
    LineBox[{{5.3542505241943035`, -0.79527452481808}, {
     5.47738118998655, -0.7004941932750637}}]}, 
   {Hue[0.5841162185961662], AbsoluteThickness[0.5], 
    LineBox[{{5.47738118998655, -0.7004941932750637}, {
     5.658265170428947, -0.5240385545595725}}]}, 
   {Hue[0.39777562783083836`], AbsoluteThickness[0.5], 
    LineBox[{{4.826806545392832, -2.9193276214702566`}, {
     4.846467946300593, -2.933360990047434}}]}, 
   {Hue[0.3982928499151771], AbsoluteThickness[0.5], 
    LineBox[{{4.846467946300593, -2.933360990047434}, {
     5.098134082027737, -3.097700351180445}}]}, 
   {Hue[0.6067468635704788], AbsoluteThickness[0.5], 
    LineBox[{{2.650739971745474, -3.4001059673734253`}, {
     2.648989428982989, -3.4010319234501787`}}]}, 
   {Hue[0.6072085406285301], AbsoluteThickness[0.5], 
    LineBox[{{2.648989428982989, -3.4010319234501787`}, {
     2.3806805784753817`, -3.55212063103633}}]}, 
   {Hue[0.5218510448837305], AbsoluteThickness[0.5], 
    LineBox[{{5.816917502326904, 0.20144191367730124`}, {6.093214459799741, 
     0.3746672419875282}}]}, 
   {Hue[0.5260192514414221], AbsoluteThickness[0.5], 
    LineBox[{{6.093214459799741, 0.3746672419875282}, {6.29002986004452, 
     0.4513842698569598}}]}, 
   {Hue[0.6222879124539208], AbsoluteThickness[0.5], 
    LineBox[{{3.125427393250031, -3.997659762760602}, {
     3.118574173198093, -4.400333120989129}}]}, 
   {Hue[0.6236838781364762], AbsoluteThickness[0.5], 
    LineBox[{{3.118574173198093, -4.400333120989129}, {
     3.0837131023082884`, -4.659710403695357}}]}, 
   {Hue[0.44596075923902273`], AbsoluteThickness[0.5], 
    LineBox[{{3.635571266519463, 3.1183307058385874`}, {3.6449591173825366`, 
     3.160759137488856}}]}, 
   {Hue[0.4470789375819186], AbsoluteThickness[0.5], 
    LineBox[{{3.6449591173825366`, 3.160759137488856}, {3.732035461120855, 
     3.4237096215217515`}}]}, 
   {Hue[0.5972533129575938], AbsoluteThickness[0.5], 
    LineBox[{{5.7597720729195645`, 0.11789222966159069`}, {5.871736954024567, 
     0.1025543667743342}}]}, 
   {Hue[0.5977893142274452], AbsoluteThickness[0.5], 
    LineBox[{{5.871736954024567, 0.1025543667743342}, {6.197163991517701, 
     0.042867467485724994`}}]}, 
   {Hue[0.5790135811028209], AbsoluteThickness[0.5], 
    LineBox[{{5.867147252684627, 1.386049669490096}, {5.889373429728811, 
     1.4347617477248034`}}]}, 
   {Hue[0.579760860581392], AbsoluteThickness[0.5], 
    LineBox[{{5.889373429728811, 1.4347617477248034`}, {6.023086964271189, 
     1.6784203032397893`}}]}, 
   {Hue[0.685740109741644], AbsoluteThickness[0.5], 
    LineBox[{{5.102963552857302, 1.1349084578303186`}, {5.100989108287168, 
     1.141676396076695}}]}, 
   {Hue[0.6948832342691942], AbsoluteThickness[0.5], 
    LineBox[{{5.100989108287168, 1.141676396076695}, {5.093548512656405, 
     1.3312239159188244`}}]}, 
   {Hue[0.5340949718861567], AbsoluteThickness[0.5], 
    LineBox[{{5.091453646427579, -4.141419739137227}, {
     5.104274801589908, -4.147738792677858}}]}, 
   {Hue[0.5345209978137364], AbsoluteThickness[0.5], 
    LineBox[{{5.104274801589908, -4.147738792677858}, {
     5.367914906090301, -4.277074013047335}}]}, 
   {Hue[0.6940673066707512], AbsoluteThickness[0.5], 
    LineBox[{{5.650697549979796, 1.0733966563823958`}, {5.661660781367264, 
     1.0916434600814127`}}]}, 
   {Hue[0.6944937927692986], AbsoluteThickness[0.5], 
    LineBox[{{5.661660781367264, 1.0916434600814127`}, {5.847734715102041, 
     1.3988757748651253`}}]}, 
   {Hue[0.6961648603648662], AbsoluteThickness[0.5], 
    LineBox[{{7.189142590104454, -3.5205618229512616`}, {
     7.525694603762206, -3.8385434533301988`}}]}, 
   {Hue[0.575686446295401], AbsoluteThickness[0.5], 
    LineBox[{{4.1580838141123415`, -4.051216201993724}, {
     4.17858464828893, -4.080647920434463}}]}, 
   {Hue[0.5761139739671328], AbsoluteThickness[0.5], 
    LineBox[{{4.17858464828893, -4.080647920434463}, {
     4.360770809630589, -4.33902386751796}}]}, 
   {Hue[0.4661611985718082], AbsoluteThickness[0.5], 
    LineBox[{{3.1731807903817484`, -3.4131764094056827`}, {
     3.198444107391091, -3.6050457651105026`}}]}, 
   {Hue[0.4667392463150786], AbsoluteThickness[0.5], 
    LineBox[{{3.198444107391091, -3.6050457651105026`}, {
     3.2578120590135815`, -3.9248022499192396`}}]}, 
   {Hue[0.6283257094054533], AbsoluteThickness[0.5], 
    LineBox[{{4.446294214219085, 1.7058720899159108`}, {5.084421260458788, 
     2.171330904035591}}]}, 
   {Hue[0.6288122009612966], AbsoluteThickness[0.5], 
    LineBox[{{5.084421260458788, 2.171330904035591}, {5.354975044337821, 
     2.3549168355593135`}}]}, 
   {Hue[0.34240651736516114`], AbsoluteThickness[0.5], 
    LineBox[{{2.563370815805376, 2.3474488245508085`}, {2.5503250927452377`, 
     2.391042148182877}}]}, 
   {Hue[0.34283281416097633`], AbsoluteThickness[0.5], 
    LineBox[{{2.5503250927452377`, 2.391042148182877}, {2.460328661948918, 
     2.688568383473349}}]}, 
   {Hue[0.36815080356146956`], AbsoluteThickness[0.5], 
    LineBox[{{4.272196170622946, 2.411134554622807}, {4.221235859878862, 
     2.6438710123707203`}}]}, 
   {Hue[0.36884491852831086`], AbsoluteThickness[0.5], 
    LineBox[{{4.221235859878862, 2.6438710123707203`}, {4.17833609037992, 
     2.9328224325560073`}}]}, 
   {Hue[0.5077187277657154], AbsoluteThickness[0.5], 
    LineBox[{{4.007160184692961, -0.6435838037410032}, {
     3.7386036746321514`, -1.1651573946354679`}}]}, 
   {Hue[0.5101863755322277], AbsoluteThickness[0.5], 
    LineBox[{{3.7386036746321514`, -1.1651573946354679`}, {
     3.6798132369816634`, -1.3413433414305957`}}]}, 
   {Hue[0.518484196714237], AbsoluteThickness[0.5], 
    LineBox[{{4.989343389943048, -0.6670408945098727}, {
     5.044035598292144, -0.8535801258142093}}]}, 
   {Hue[0.5190131854181796], AbsoluteThickness[0.5], 
    LineBox[{{5.044035598292144, -0.8535801258142093}, {
     5.11161588158823, -1.1281494296248273`}}]}, 
   {Hue[0.548310605529511], AbsoluteThickness[0.5], 
    LineBox[{{5.089277547606241, 0.7618863682638778}, {5.037227662264037, 
     0.8380619822754647}}]}, 
   {Hue[0.5488783625615109], AbsoluteThickness[0.5], 
    LineBox[{{5.037227662264037, 0.8380619822754647}, {4.874356195091991, 
     1.1046383358788552`}}]}, 
   {Hue[0.38639350431559766`], AbsoluteThickness[0.5], 
    LineBox[{{5.708677078518348, 0.6301833348481304}, {5.813844797291337, 
     0.48107081705997407`}}]}, 
   {Hue[0.40449551942239675`], AbsoluteThickness[0.5], 
    LineBox[{{5.813844797291337, 0.48107081705997407`}, {5.940310911108822, 
     0.3832831776671432}}]}, 
   {Hue[0.5880372558253856], AbsoluteThickness[0.5], 
    LineBox[{{5.940310911108822, 0.3832831776671432}, {6.083996405717554, 
     0.4533587012196888}}]}, 
   {Hue[0.039338751418848225`], AbsoluteThickness[0.5], 
    LineBox[{{5.899967567888557, 0.6990879780858823}, {6.065139394700103, 
     0.7926260833395771}}]}, 
   {Hue[0.0474585022967084], AbsoluteThickness[0.5], 
    LineBox[{{6.065139394700103, 0.7926260833395771}, {6.206924443618032, 
     0.9249844108946891}}]}, 
   {Hue[0.3073844094667363], AbsoluteThickness[0.5], 
    LineBox[{{6.206924443618032, 0.9249844108946891}, {6.1284238386568015`, 
     1.102352339197882}}]}, 
   {Hue[0.5673103166367632], AbsoluteThickness[0.5], 
    LineBox[{{6.1284238386568015`, 1.102352339197882}, {5.935117421608894, 
     1.0864037938740474`}}]}, 
   {Hue[0.3926990116215905], AbsoluteThickness[0.5], 
    LineBox[{{5.850305337571834, 0.8962517781689212}, {5.776100360386775, 
     1.064088519213215}}]}, 
   {Hue[0.39320934872925134`], AbsoluteThickness[0.5], 
    LineBox[{{5.776100360386775, 1.064088519213215}, {5.649134368392715, 
     1.3853262277671203`}}]}, 
   {Hue[0.5466080527397318], AbsoluteThickness[0.5], 
    LineBox[{{5.12740123528053, -0.296281482118664}, {
     5.090228452745488, -0.39002568166542373`}}]}, 
   {Hue[0.5470728241635622], AbsoluteThickness[0.5], 
    LineBox[{{5.090228452745488, -0.39002568166542373`}, {
     4.9726144442567275`, -0.6644372467768852}}]}, 
   {Hue[0.5155000716928679], AbsoluteThickness[0.5], 
    LineBox[{{4.1403594608289325`, 1.3803665794012725`}, {4.12272980478784, 
     1.389728295250953}}]}, 
   {Hue[0.5159928676602079], AbsoluteThickness[0.5], 
    LineBox[{{4.12272980478784, 1.389728295250953}, {3.8732239497467686`, 
     1.5338562979998627`}}]}, 
   {Hue[0.6154814498562191], AbsoluteThickness[0.5], 
    LineBox[{{3.6650698239341186`, 1.3597071376123941`}, {3.5749190981394525`,
      1.40666286372568}}]}, 
   {Hue[0.6159296088905146], AbsoluteThickness[0.5], 
    LineBox[{{3.5749190981394525`, 1.40666286372568}, {3.3317688946549024`, 
     1.5398242935471955`}}]}, 
   {Hue[0.5952710481495139], AbsoluteThickness[0.5], 
    LineBox[{{4.2989143009305, 1.9167101734416405`}, {4.270118368627519, 
     2.0870244095778627`}}]}, 
   {Hue[0.5956972530354029], AbsoluteThickness[0.5], 
    LineBox[{{4.270118368627519, 2.0870244095778627`}, {4.214188723332955, 
     2.4126086795658774`}}]}, 
   {Hue[0.38026945478043855`], AbsoluteThickness[0.5], 
    LineBox[{{4.598762474420038, -1.32269551700764}, {
     4.602338664720017, -1.3539747011328558`}}]}, 
   {Hue[0.3809844381115661], AbsoluteThickness[0.5], 
    LineBox[{{4.602338664720017, -1.3539747011328558`}, {
     4.614035767685453, -1.6235607007924133`}}]}, 
   {Hue[0.5784996182896365], AbsoluteThickness[0.5], 
    LineBox[{{2.4304867263221803`, -1.2018760763424463`}, {
     2.3922194612452787`, -1.2565322095915437`}}]}, 
   {Hue[0.5797639478683405], AbsoluteThickness[0.5], 
    LineBox[{{2.3922194612452787`, -1.2565322095915437`}, {
     2.2257841832936305`, -1.445930744172194}}]}, 
   {Hue[0.6752628829085604], AbsoluteThickness[0.5], 
    LineBox[{{3.8578495987142163`, -1.9710649875566215`}, {
     3.7827875004958296`, -2.083295651453459}}]}, 
   {Hue[0.6761492617003096], AbsoluteThickness[0.5], 
    LineBox[{{3.7827875004958296`, -2.083295651453459}, {
     3.671913047482954, -2.284676630362037}}]}, 
   {Hue[0.6518499578563167], AbsoluteThickness[0.5], 
    LineBox[{{3.86801761611934, -2.103761025729109}, {
     3.8722562577285387`, -2.1126122071188536`}}]}, 
   {Hue[0.6574310369834911], AbsoluteThickness[0.5], 
    LineBox[{{3.8722562577285387`, -2.1126122071188536`}, {
     3.911017260253714, -2.2723821193913127`}}]}, 
   {Hue[0.365207947620916], AbsoluteThickness[0.5], 
    LineBox[{{5.329797749713981, -1.4122820404292893`}, {
     5.401124755534605, -1.432497568752392}}]}, 
   {Hue[0.36567688531744347`], AbsoluteThickness[0.5], 
    LineBox[{{5.401124755534605, -1.432497568752392}, {
     5.6963360179209825`, -1.5254300497137785`}}]}, 
   {Hue[0.649512067857455], AbsoluteThickness[0.5], 
    LineBox[{{4.787709350489831, 0.39731878168488094`}, {4.799843005125469, 
     0.5711366028730326}}]}, 
   {Hue[0.6501009179969653], AbsoluteThickness[0.5], 
    LineBox[{{4.799843005125469, 0.5711366028730326}, {4.804334597548648, 
     0.8640335567333075}}]}, 
   {Hue[0.6624297831605006], AbsoluteThickness[0.5], 
    LineBox[{{2.979572465429276, -4.109558158803205}, {
     3.0269241428174483`, -4.35105984533005}}]}, 
   {Hue[0.6629747145578027], AbsoluteThickness[0.5], 
    LineBox[{{3.0269241428174483`, -4.35105984533005}, {
     3.073367681871516, -4.6654478082591755`}}]}, 
   {Hue[0.6328757058335074], AbsoluteThickness[0.5], 
    LineBox[{{5.383063580816792, -2.191064125013209}, {
     5.940604504186381, -2.0386800054833154`}}]}, 
   {Hue[0.6334235211987558], AbsoluteThickness[0.5], 
    LineBox[{{5.940604504186381, -2.0386800054833154`}, {
     6.157711678015688, -1.968108631208171}}]}, 
   {Hue[0.5169319786792165], AbsoluteThickness[0.5], 
    LineBox[{{6.445887644850395, -2.2253475276472057`}, {
     6.644902975496441, -2.213310771536058}}]}, 
   {Hue[0.5173611946301352], AbsoluteThickness[0.5], 
    LineBox[{{6.644902975496441, -2.213310771536058}, {
     6.94356657203474, -2.1976849162890946`}}]}, 
   {Hue[0.6254130535054944], AbsoluteThickness[0.5], 
    LineBox[{{3.7332208275790237`, 0.9431965101928954}, {3.6958950884369717`, 
     1.1837878668584636`}}]}, 
   {Hue[0.6275142394495219], AbsoluteThickness[0.5], 
    LineBox[{{3.6958950884369717`, 1.1837878668584636`}, {3.693549841600772, 
     1.39851555547878}}]}, 
   {Hue[0.5848983233632907], AbsoluteThickness[0.5], 
    LineBox[{{5.113001254393057, -4.591178600246907}, {
     5.361832491604998, -4.5963684284333075`}}]}, 
   {Hue[0.5860768072003408], AbsoluteThickness[0.5], 
    LineBox[{{5.361832491604998, -4.5963684284333075`}, {
     5.6425788131142305`, -4.572544676786376}}]}, 
   {Hue[0.5356738985674282], AbsoluteThickness[0.5], 
    LineBox[{{3.9262586308343446`, 0.19703540101119452`}, {4.163527342935499, 
     0.3550118541941684}}]}, 
   {Hue[0.5226964579291593], AbsoluteThickness[0.5], 
    LineBox[{{4.796734310103455, 1.40508279759048}, {4.8399471897518955`, 
     1.448035538109427}}]}, 
   {Hue[0.5234591372612953], AbsoluteThickness[0.5], 
    LineBox[{{4.8399471897518955`, 1.448035538109427}, {5.0266015784679166`, 
     1.663859549193721}}]}, 
   {Hue[0.45766276364538366`], AbsoluteThickness[0.5], 
    LineBox[{{5.7812551175476035`, -3.4164898213319477`}, {
     5.868747683613169, -3.512587650098315}}]}, 
   {Hue[0.45912925651396413`], AbsoluteThickness[0.5], 
    LineBox[{{5.868747683613169, -3.512587650098315}, {
     6.046353393366213, -3.6660049430630695`}}]}, 
   {Hue[0.6188994414235293], AbsoluteThickness[0.5], 
    LineBox[{{2.9131862379494273`, -3.147391636888103}, {
     2.8941089111794867`, -3.2250020651448636`}}]}, 
   {Hue[0.6220132341042629], AbsoluteThickness[0.5], 
    LineBox[{{2.8941089111794867`, -3.2250020651448636`}, {
     2.8101200646589803`, -3.4183804930367216`}}]}, 
   {Hue[0.5534277266535523], AbsoluteThickness[0.5], 
    LineBox[{{4.4288926281203445`, -2.7687285119753944`}, {
     4.436311804560128, -2.8277225848569523`}}]}, 
   {Hue[0.5538545827144578], AbsoluteThickness[0.5], 
    LineBox[{{4.436311804560128, -2.8277225848569523`}, {
     4.474254493612124, -3.11896379066725}}]}, 
   {Hue[0.495205995562218], AbsoluteThickness[0.5], 
    LineBox[{{2.936825549559755, 1.1431103431615066`}, {2.9150192096787206`, 
     1.1410545609267615`}}]}, 
   {Hue[0.4959873574032458], AbsoluteThickness[0.5], 
    LineBox[{{2.9150192096787206`, 1.1410545609267615`}, {2.6070905982741728`,
      1.1358694542699528`}}]}, 
   {Hue[0.567056612560913], AbsoluteThickness[0.5], 
    LineBox[{{3.389168923748963, 1.0614793457625638`}, {3.137347330190338, 
     1.1224645330374565`}}]}, 
   {Hue[0.5718887005472458], AbsoluteThickness[0.5], 
    LineBox[{{3.137347330190338, 1.1224645330374565`}, {2.918124987337289, 
     1.13103979481882}}]}, 
   {Hue[0.5377394543351672], AbsoluteThickness[0.5], 
    LineBox[{{4.62870933134975, 0.8757920879901597}, {4.50412260644416, 
     0.6013230884424914}}]}, 
   {Hue[0.5389996781324768], AbsoluteThickness[0.5], 
    LineBox[{{4.50412260644416, 0.6013230884424914}, {4.437151694909127, 
     0.3966240127054583}}]}, 
   {Hue[0.5579528982545049], AbsoluteThickness[0.5], 
    LineBox[{{4.909005178363968, 1.3555587479791689`}, {4.757918191821211, 
     0.8750617960470043}}]}, 
   {Hue[0.558418235745716], AbsoluteThickness[0.5], 
    LineBox[{{4.757918191821211, 0.8750617960470043}, {4.6736170162304465`, 
     0.5786074119062264}}]}, 
   {Hue[0.017685009625523527`], AbsoluteThickness[0.5], 
    LineBox[{{5.1493897750713575`, 1.5787378751750272`}, {5.209070085780812, 
     1.6380846213235052`}}]}, 
   {Hue[0.01925411392366857], AbsoluteThickness[0.5], 
    LineBox[{{5.209070085780812, 1.6380846213235052`}, {5.331052317504082, 
     1.7939501036896806`}}]}, 
   {Hue[0.4425560915191441], AbsoluteThickness[0.5], 
    LineBox[{{5.331052317504082, 1.7939501036896806`}, {5.157267893420717, 
     1.888674374050784}}]}, 
   {Hue[0.5589280254033042], AbsoluteThickness[0.5], 
    LineBox[{{4.832803675062183, 1.4929071205991715`}, {4.6640063097284274`, 
     1.440868448579493}}]}, 
   {Hue[0.5595112864134761], AbsoluteThickness[0.5], 
    LineBox[{{4.6640063097284274`, 1.440868448579493}, {4.425270812334687, 
     1.3810379179208954`}}]}, 
   {Hue[0.5286207362707643], AbsoluteThickness[0.5], 
    LineBox[{{4.407139248055496, 1.4183274988901455`}, {4.165175541964043, 
     1.4954346578870643`}}]}, 
   {Hue[0.5291315642139164], AbsoluteThickness[0.5], 
    LineBox[{{4.165175541964043, 1.4954346578870643`}, {3.8895115973416425`, 
     1.5712810717065464`}}]}, 
   {Hue[0.5637096038846854], AbsoluteThickness[0.5], 
    LineBox[{{3.7070697616364563`, 0.06563702293561798}, {
     3.6113960068514652`, -0.0006433272961997236}}]}, 
   {Hue[0.5643684467961305], AbsoluteThickness[0.5], 
    LineBox[{{3.6113960068514652`, -0.0006433272961997236}, {
     3.359307661904399, -0.15239223900523113`}}]}, 
   {Hue[0.4882457386470911], AbsoluteThickness[0.5], 
    LineBox[{{4.762728437708023, -0.39177672229575156`}, {
     4.799166013771788, -0.5616778687084697}}]}, 
   {Hue[0.4888096429310074], AbsoluteThickness[0.5], 
    LineBox[{{4.799166013771788, -0.5616778687084697}, {
     4.845049405270576, -0.8443039015769286}}]}, 
   {Hue[0.566618626308337], AbsoluteThickness[0.5], 
    LineBox[{{4.07012990744971, -1.5736142042067225`}, {
     4.064101774323483, -1.6806910927447152`}}]}, 
   {Hue[0.589113853603183], AbsoluteThickness[0.5], 
    LineBox[{{4.064101774323483, -1.6806910927447152`}, {
     4.11238417025681, -1.8621750808132935`}}]}, 
   {Hue[0.559590731066873], AbsoluteThickness[0.5], 
    LineBox[{{3.243953403072276, -1.8935204555909269`}, {
     3.1949825440683317`, -1.9982322070187872`}}]}, 
   {Hue[0.5626708288428728], AbsoluteThickness[0.5], 
    LineBox[{{3.1949825440683317`, -1.9982322070187872`}, {
     3.0799027578563583`, -2.1644946064953965`}}]}, 
   {Hue[0.584849484004366], AbsoluteThickness[0.5], 
    LineBox[{{2.324944115093903, -2.0151299511104215`}, {
     2.151584258649266, -2.064929993542033}}]}, 
   {Hue[0.5882507757561353], AbsoluteThickness[0.5], 
    LineBox[{{2.151584258649266, -2.064929993542033}, {
     1.927311216125051, -2.088597341404607}}]}, 
   {Hue[0.5268668101126465], AbsoluteThickness[0.5], 
    LineBox[{{4.466969022399495, -2.1801241503529494`}, {
     4.460899190175212, -2.3760974298480537`}}]}, 
   {Hue[0.5273458728157924], AbsoluteThickness[0.5], 
    LineBox[{{4.460899190175212, -2.3760974298480537`}, {
     4.461178090981471, -2.66777511298858}}]}, 
   {Hue[0.48805262084104795`], AbsoluteThickness[0.5], 
    LineBox[{{5.674854981263543, -1.5904751479467907`}, {
     5.6747672818807064`, -1.6012500847974942`}}]}, 
   {Hue[0.48889118125619646`], AbsoluteThickness[0.5], 
    LineBox[{{5.6747672818807064`, -1.6012500847974942`}, {
     5.695025981945947, -1.873981519855125}}]}, 
   {Hue[0.5589109528281587], AbsoluteThickness[0.5], 
    LineBox[{{5.053840529477327, -0.6595056944784647}, {
     5.047297986333426, -0.8538233992716184}}]}, 
   {Hue[0.5593388247677057], AbsoluteThickness[0.5], 
    LineBox[{{5.047297986333426, -0.8538233992716184}, {
     5.03546764935036, -1.1497006263265979`}}]}, 
   {Hue[0.5692996819625897], AbsoluteThickness[0.5], 
    LineBox[{{4.601464635682168, 0.655068451747265}, {4.5562215104857104`, 
     0.6085267886080832}}]}, 
   {Hue[0.5703994372312775], AbsoluteThickness[0.5], 
    LineBox[{{4.5562215104857104`, 0.6085267886080832}, {4.418720121257387, 
     0.4350862635367063}}]}, 
   {Hue[0.45127671228276234`], AbsoluteThickness[0.5], 
    LineBox[{{6.144664772822665, 1.8710928713133896`}, {6.178769379060579, 
     1.8551501174414886`}}]}, 
   {Hue[0.45199568107147464`], AbsoluteThickness[0.5], 
    LineBox[{{6.178769379060579, 1.8551501174414886`}, {6.427610932939978, 
     1.7165502097000112`}}]}, 
   {Hue[0.3151002721206389], AbsoluteThickness[0.5], 
    LineBox[{{5.883455291137228, 2.4683644158583733`}, {5.769241653649726, 
     2.6502426821576086`}}]}, 
   {Hue[0.3155359359879785], AbsoluteThickness[0.5], 
    LineBox[{{5.769241653649726, 2.6502426821576086`}, {5.605257118565848, 
     2.9196039564224585`}}]}, 
   {Hue[0.03381596038961717], AbsoluteThickness[0.5], 
    LineBox[{{5.987169457190278, 2.6431761732923356`}, {6.057580694396513, 
     2.7192442846648537`}}]}, 
   {Hue[0.03443648468700624], AbsoluteThickness[0.5], 
    LineBox[{{6.057580694396513, 2.7192442846648537`}, {6.279828006159819, 
     2.932610835160989}}]}, 
   {Hue[0.551302047259978], AbsoluteThickness[0.5], 
    LineBox[{{6.279828006159819, 2.932610835160989}, {6.276828801386665, 
     2.6245359137094626`}}]}, 
   {Hue[0.3267001472390953], AbsoluteThickness[0.5], 
    LineBox[{{6.182948291025892, 2.588527961984032}, {6.299680882035237, 
     2.5272308556212146`}}]}, 
   {Hue[0.32726840756270226`], AbsoluteThickness[0.5], 
    LineBox[{{6.299680882035237, 2.5272308556212146`}, {6.5857205405867205`, 
     2.395189110965374}}]}, 
   {Hue[0.6195843340885728], AbsoluteThickness[0.5], 
    LineBox[{{6.181131863724281, 2.385273246493621}, {6.1670763427356174`, 
     2.3224962432419414`}}]}, 
   {Hue[0.6241974566304368], AbsoluteThickness[0.5], 
    LineBox[{{6.1670763427356174`, 2.3224962432419414`}, {6.161994848413446, 
     2.1190405337257494`}}]}, 
   {Hue[0.4558641997819877], AbsoluteThickness[0.5], 
    LineBox[{{5.111135082510246, 2.33568655743686}, {4.880986934659348, 
     2.3110591134024534`}}]}, 
   {Hue[0.45632822132107514`], AbsoluteThickness[0.5], 
    LineBox[{{4.880986934659348, 2.3110591134024534`}, {4.573592747317461, 
     2.2696994079172903`}}]}, 
   {Hue[0.5730353168040231], AbsoluteThickness[0.5], 
    LineBox[{{5.099360318457141, 0.4101543403806851}, {5.075155686023031, 
     0.33153026177249056`}}]}, 
   {Hue[0.5919609313858794], AbsoluteThickness[0.5], 
    LineBox[{{5.075155686023031, 0.33153026177249056`}, {5.075711793652341, 
     0.16411743654090535`}}]}, 
   {Hue[0.567994332250123], AbsoluteThickness[0.5], 
    LineBox[{{3.391464181893433, 0.36448846474538343`}, {3.3655753290362544`, 
     0.3653735534977806}}]}, 
   {Hue[0.5690570868488118], AbsoluteThickness[0.5], 
    LineBox[{{3.3655753290362544`, 0.3653735534977806}, {3.0954159310744322`, 
     0.34793467438978865`}}]}, 
   {Hue[0.4752764954470641], AbsoluteThickness[0.5], 
    LineBox[{{3.324333895295766, 1.4735737937275017`}, {2.9170110757860397`, 
     1.8382852154145046`}}]}, 
   {Hue[0.4816285618808637], AbsoluteThickness[0.5], 
    LineBox[{{2.9170110757860397`, 1.8382852154145046`}, {2.7546851027732324`,
      1.9296038001675277`}}]}, 
   {Hue[0.5736347017271541], AbsoluteThickness[0.5], 
    LineBox[{{2.1853897164995115`, -1.83513955295675}, {
     2.164859214736997, -1.851512859972117}}]}, 
   {Hue[0.5740629194001685], AbsoluteThickness[0.5], 
    LineBox[{{2.164859214736997, -1.851512859972117}, {
     1.897637446634574, -2.0616579107451094`}}]}, 
   {Hue[0.5648778046872099], AbsoluteThickness[0.5], 
    LineBox[{{6.326838357332485, -3.8528360062609104`}, {
     6.413659285504493, -3.867629220660649}}]}, 
   {Hue[0.5667533629777655], AbsoluteThickness[0.5], 
    LineBox[{{6.413659285504493, -3.867629220660649}, {
     6.646229973474925, -3.9407008710159626`}}]}, 
   {Hue[0.638954748474282], AbsoluteThickness[0.5], 
    LineBox[{{5.8407912711761565`, -0.4042539088119889}, {
     5.8437237245645, -0.40930369127545096`}}]}, 
   {Hue[0.6395644632524845], AbsoluteThickness[0.5], 
    LineBox[{{5.8437237245645, -0.40930369127545096`}, {
     5.981721594978085, -0.6182995197778255}}]}, 
   {Hue[0.515146995548915], AbsoluteThickness[0.5], 
    LineBox[{{5.917407499966679, 0.7604063067991825}, {6.167019569940139, 
     0.7150705911625426}}]}, 
   {Hue[0.5156448707581818], AbsoluteThickness[0.5], 
    LineBox[{{6.167019569940139, 0.7150705911625426}, {6.420651282882985, 
     0.6786255377718334}}]}, 
   {Hue[0.2738860937313342], AbsoluteThickness[0.5], 
    LineBox[{{5.8786741028400895`, 1.3765305461266364`}, {5.89853997888626, 
     1.4223618906451072`}}]}, 
   {Hue[0.2745273025187467], AbsoluteThickness[0.5], 
    LineBox[{{5.89853997888626, 1.4223618906451072`}, {6.028746077079593, 
     1.678202557840273}}]}, 
   {Hue[0.5376119133833996], AbsoluteThickness[0.5], 
    LineBox[{{4.575246650437302, 2.2849644988954356`}, {4.5596363699332585`, 
     2.322492037870158}}]}, 
   {Hue[0.5380407187084282], AbsoluteThickness[0.5], 
    LineBox[{{4.5596363699332585`, 2.322492037870158}, {4.436223318357509, 
     2.612916184497205}}]}, 
   {Hue[0.6569117216165408], AbsoluteThickness[0.5], 
    LineBox[{{5.0000997586313725`, 1.665700727842299}, {4.957595346322087, 
     1.8606558869877243`}}]}, 
   {Hue[0.6586460579869536], AbsoluteThickness[0.5], 
    LineBox[{{4.957595346322087, 1.860655886987724}, {4.941295591444154, 
     2.054124475027803}}]}, 
   {Hue[0.6033847348177428], AbsoluteThickness[0.5], 
    LineBox[{{2.880319745354753, -1.600044843205336}, {
     2.9354287580840905`, -1.917269311444474}}]}, 
   {Hue[0.6043381976967567], AbsoluteThickness[0.5], 
    LineBox[{{2.9354287580840905`, -1.917269311444474}, {
     3.0012204405350444`, -2.161361606752339}}]}, 
   {Hue[0.593779671713731], AbsoluteThickness[0.5], 
    LineBox[{{4.817046216678165, 0.1699060958663165}, {4.890106036306915, 
     0.15454642262500617`}}]}, 
   {Hue[0.5949631567909964], AbsoluteThickness[0.5], 
    LineBox[{{4.890106036306915, 0.15454642262500617`}, {5.134549006606511, 
     0.07543377187607667}}]}, 
   {Hue[0.597817382744164], AbsoluteThickness[0.5], 
    LineBox[{{3.84656440802801, 0.6592445764766337}, {3.858570678318699, 
     0.6352519822476194}}]}, 
   {Hue[0.5985293140998984], AbsoluteThickness[0.5], 
    LineBox[{{3.858570678318699, 0.6352519822476194}, {4.009291959826065, 
     0.3804276324043645}}]}, 
   {Hue[0.5856612970453141], AbsoluteThickness[0.5], 
    LineBox[{{2.502030092082712, 1.3163558707053424`}, {2.522076462665045, 
     1.0791186402836752`}}]}, 
   {Hue[0.5864526318004546], AbsoluteThickness[0.5], 
    LineBox[{{2.522076462665045, 1.0791186402836752`}, {2.523414247914907, 
     0.8636347501390702}}]}, 
   {Hue[0.5360681480871979], AbsoluteThickness[0.5], 
    LineBox[{{3.106635100216443, 2.896305104901701}, {3.1515169728410926`, 
     2.830122784259799}}]}, 
   {Hue[0.5367974173639238], AbsoluteThickness[0.5], 
    LineBox[{{3.1515169728410926`, 2.830122784259799}, {3.3262496546134708`, 
     2.6086203107967405`}}]}, 
   {Hue[0.5900659078914738], AbsoluteThickness[0.5], 
    LineBox[{{2.8241205362221615`, 1.6285229282803386`}, {2.840027108296158, 
     1.5932940498017472`}}]}, 
   {Hue[0.5909011662366185], AbsoluteThickness[0.5], 
    LineBox[{{2.840027108296158, 1.5932940498017472`}, {2.984742285533544, 
     1.3322047722472612`}}]}, 
   {Hue[0.5835606086827166], AbsoluteThickness[0.5], 
    LineBox[{{3.082181626089391, 0.8251675689221656}, {3.107428581396026, 
     0.6700428757173374}}]}, 
   {Hue[0.5845246079696926], AbsoluteThickness[0.5], 
    LineBox[{{3.107428581396026, 0.6700428757173374}, {3.12491390770137, 
     0.4181717499091807}}]}, 
   {Hue[0.6572310069933437], AbsoluteThickness[0.5], 
    LineBox[{{4.101446276857584, -2.376585480321616}, {
     4.336931860002722, -2.598513396705479}}]}, 
   {Hue[0.6646112391380556], AbsoluteThickness[0.5], 
    LineBox[{{4.336931860002722, -2.598513396705479}, {
     4.4324159165967165`, -2.7422625799211477`}}]}, 
   {Hue[0.5435516737043475], AbsoluteThickness[0.5], 
    LineBox[{{4.883534128008964, -2.3471986401724068`}, {
     4.884608123679783, -2.3487341501338954`}}]}, 
   {Hue[0.5439779397564917], AbsoluteThickness[0.5], 
    LineBox[{{4.884608123679783, -2.3487341501338954`}, {
     5.05358911366978, -2.588868704300002}}]}, 
   {Hue[0.5405855335496226], AbsoluteThickness[0.5], 
    LineBox[{{5.002015558906721, 1.6657077818291306`}, {5.0749096304458154`, 
     1.779975990505332}}]}, 
   {Hue[0.5455248910728362], AbsoluteThickness[0.5], 
    LineBox[{{5.0749096304458154`, 1.779975990505332}, {5.1872302508618775`, 
     1.896305147835524}}]}, 
   {Hue[0.43282867653304197`], AbsoluteThickness[0.5], 
    LineBox[{{5.916799579681213, -0.7245500619221745}, {
     6.380063384559379, -0.5334607423272762}}]}, 
   {Hue[0.43343694427929236`], AbsoluteThickness[0.5], 
    LineBox[{{6.380063384559379, -0.5334607423272762}, {
     6.673719973607622, -0.4315718023814172}}]}, 
   {Hue[0.3584751703384137], AbsoluteThickness[0.5], 
    LineBox[{{5.911580236495629, -1.2503725979815952`}, {
     5.960305109050531, -1.318663212019364}}]}, 
   {Hue[0.35932596811705636`], AbsoluteThickness[0.5], 
    LineBox[{{5.960305109050531, -1.318663212019364}, {
     6.101678468992531, -1.5564426317371467`}}]}, 
   {Hue[0.5065406509284076], AbsoluteThickness[0.5], 
    LineBox[{{5.628034126328007, -1.292052827177402}, {
     5.647025741926383, -1.3941277220779786`}}]}, 
   {Hue[0.5088928452055843], AbsoluteThickness[0.5], 
    LineBox[{{5.647025741926383, -1.3941277220779786`}, {
     5.6545434956788805`, -1.6174964208590392`}}]}, 
   {Hue[0.6301459551941497], AbsoluteThickness[0.5], 
    LineBox[{{5.1223070965712445`, -1.2929783563435397`}, {
     5.056644671571893, -1.3143668850439225`}}]}, 
   {Hue[0.6353582176902048], AbsoluteThickness[0.5], 
    LineBox[{{5.056644671571893, -1.3143668850439225`}, {
     4.903664071944285, -1.4016908821265712`}}]}, 
   {Hue[0.5638853538740887], AbsoluteThickness[0.5], 
    LineBox[{{3.815892011362471, -3.4355363250256463`}, {
     3.804235974302889, -3.546418784785457}}]}, 
   {Hue[0.5643139027285851], AbsoluteThickness[0.5], 
    LineBox[{{3.804235974302889, -3.546418784785457}, {
     3.769513866241796, -3.901596953087239}}]}, 
   {Hue[0.576516976515944], AbsoluteThickness[0.5], 
    LineBox[{{2.6981643487968836`, -3.424800456376373}, {
     2.7201768875721344`, -3.574532307023461}}]}, 
   {Hue[0.5769430591120962], AbsoluteThickness[0.5], 
    LineBox[{{2.7201768875721344`, -3.574532307023461}, {
     2.7665145473648067`, -3.8851419392366253`}}]}, 
   {Hue[0.4923219491725633], AbsoluteThickness[0.5], 
    LineBox[{{5.659182913247572, 0.056860682342823037`}, {5.85112115312046, 
     0.010426943764014021`}}]}, 
   {Hue[0.4928175277795932], AbsoluteThickness[0.5], 
    LineBox[{{5.85112115312046, 0.010426943764014021`}, {
     6.180859700032221, -0.05675138067895061}}]}, 
   {Hue[0.3193874831317296], AbsoluteThickness[0.5], 
    LineBox[{{5.308685378550107, 2.8526832269091424`}, {5.351022710873723, 
     2.8681604267681253`}}]}, 
   {Hue[0.32009214013612125`], AbsoluteThickness[0.5], 
    LineBox[{{5.351022710873723, 2.8681604267681253`}, {5.610710636197575, 
     2.984075235587679}}]}, 
   {Hue[0.6270397873903619], AbsoluteThickness[0.5], 
    LineBox[{{2.343590900732108, 1.9883859874458532`}, {2.271195913429626, 
     1.9057183969009042`}}]}, 
   {Hue[0.6287310192411183], AbsoluteThickness[0.5], 
    LineBox[{{2.271195913429626, 1.9057183969009042`}, {2.157656418759747, 
     1.7362388448876456`}}]}, 
   {Hue[0.5978255965817825], AbsoluteThickness[0.5], 
    LineBox[{{3.3601069865548876`, 2.619420191602695}, {3.3636789570261683`, 
     2.6165025930589505`}}]}, 
   {Hue[0.5982644192159513], AbsoluteThickness[0.5], 
    LineBox[{{3.3636789570261683`, 2.6165025930589505`}, {3.6041428001278377`,
      2.413617476757415}}]}, 
   {Hue[0.5887840515727595], AbsoluteThickness[0.5], 
    LineBox[{{3.148282594742523, 3.1594897274979115`}, {3.1481944172734098`, 
     3.1594702018962084`}}]}, 
   {Hue[0.5896696728694519], AbsoluteThickness[0.5], 
    LineBox[{{3.1481944172734098`, 3.1594702018962084`}, {2.890561718319046, 
     3.0786248525262647`}}]}, 
   {Hue[0.09923737029509508], AbsoluteThickness[0.5], 
    LineBox[{{3.218553109259726, 3.426129526477303}, {3.290939934047091, 
     3.632993032437337}}]}, 
   {Hue[0.10112157899545843`], AbsoluteThickness[0.5], 
    LineBox[{{3.290939934047091, 3.632993032437337}, {3.3362781348509327`, 
     3.8559048164156895`}}]}, 
   {Hue[0.5060303315624045], AbsoluteThickness[0.5], 
    LineBox[{{3.3362781348509327`, 3.8559048164156895`}, {3.1103020074212386`,
      3.881981735720313}}]}, 
   {Hue[0.5903849366714201], AbsoluteThickness[0.5], 
    LineBox[{{3.4082364232599773`, 3.2259921536551213`}, {3.448723833526105, 
     3.1758901694865775`}}]}, 
   {Hue[0.5909109050340877], AbsoluteThickness[0.5], 
    LineBox[{{3.448723833526105, 3.1758901694865775`}, {3.635951462874396, 
     2.9225293116933315`}}]}, 
   {Hue[0.6011922234106806], AbsoluteThickness[0.5], 
    LineBox[{{2.3781153272002955`, 2.845490083083523}, {2.320184506887052, 
     2.8338518659918885`}}]}, 
   {Hue[0.6016594619367227], AbsoluteThickness[0.5], 
    LineBox[{{2.320184506887052, 2.8338518659918885`}, {2.0712288167245934`, 
     2.7764788891842294`}}]}, 
   {Hue[0.622965340858731], AbsoluteThickness[0.5], 
    LineBox[{{3.830313603754135, 1.1471785062895667`}, {3.8793660101359153`, 
     1.0756331825800078`}}]}, 
   {Hue[0.6242043870388156], AbsoluteThickness[0.5], 
    LineBox[{{3.8793660101359153`, 1.0756331825800078`}, {4.044295943175192, 
     0.8836757660057404}}]}, 
   {Hue[0.6167762921023113], AbsoluteThickness[0.5], 
    LineBox[{{3.019838149164961, 3.1970599043857892`}, {3.100270309016337, 
     3.284690428604411}}]}, 
   {Hue[0.6188260809607532], AbsoluteThickness[0.5], 
    LineBox[{{3.100270309016337, 3.284690428604411}, {3.2772725092471884`, 
     3.4298303791992506`}}]}, 
   {Hue[0.6440715346518404], AbsoluteThickness[0.5], 
    LineBox[{{2.4503673539669237`, 3.139780913905041}, {2.5126352620511856`, 
     3.29523310128953}}]}, 
   {Hue[0.6445747156149019], AbsoluteThickness[0.5], 
    LineBox[{{2.5126352620511856`, 3.29523310128953}, {2.6252884179580267`, 
     3.6109302304574373`}}]}, 
   {Hue[0.3353172146919648], AbsoluteThickness[0.5], 
    LineBox[{{2.112821823091436, 1.1242264377148508`}, {2.111704907020527, 
     1.1195603761900148`}}]}, 
   {Hue[0.3360658942751467], AbsoluteThickness[0.5], 
    LineBox[{{2.111704907020527, 1.1195603761900148`}, {2.020724857731649, 
     0.8344894377071249}}]}, 
   {Hue[0.3921063646199819], AbsoluteThickness[0.5], 
    LineBox[{{3.2604210857285847`, 1.138413421848536}, {3.383247620069476, 
     1.0326215339813019`}}]}, 
   {Hue[0.3929353650760928], AbsoluteThickness[0.5], 
    LineBox[{{3.383247620069476, 1.0326215339813019`}, {3.603609521882085, 
     0.8721000717030405}}]}, 
   {Hue[0.4407424793407195], AbsoluteThickness[0.5], 
    LineBox[{{4.1978854965930115`, 1.9238652161644683`}, {4.263161493768721, 
     1.9156302880606486`}}]}, 
   {Hue[0.45813544119870214`], AbsoluteThickness[0.5], 
    LineBox[{{4.263161493768721, 1.9156302880606486`}, {4.424160597144562, 
     1.8436247799949024`}}]}, 
   {Hue[0.6453833465778801], AbsoluteThickness[0.5], 
    LineBox[{{4.424160597144562, 1.8436247799949024`}, {4.430050381438902, 
     1.6673556252326556`}}]}, 
   {Hue[0.4954742686928234], AbsoluteThickness[0.5], 
    LineBox[{{3.5324534443507174`, 3.1824490288635174`}, {3.6127107728498493`,
      3.245182812543988}}]}, 
   {Hue[0.4962418941359786], AbsoluteThickness[0.5], 
    LineBox[{{3.6127107728498493`, 3.245182812543988}, {3.8617675529751447`, 
     3.411078761149382}}]}, 
   {Hue[0.5494483087746291], AbsoluteThickness[0.5], 
    LineBox[{{2.2870984284353653`, 3.392140184915822}, {2.156211239504322, 
     3.5250037010211495`}}]}, 
   {Hue[0.5516781938819093], AbsoluteThickness[0.5], 
    LineBox[{{2.156211239504322, 3.5250037010211495`}, {1.983443869947798, 
     3.6552682832600882`}}]}, 
   {Hue[0.6853055085605253], AbsoluteThickness[0.5], 
    LineBox[{{1.832654370812486, 0.9437745114165952}, {1.8911679438151703`, 
     0.15939197062878113`}}]}, 
   {Hue[0.6857960568925828], AbsoluteThickness[0.5], 
    LineBox[{{1.8911679438151703`, 0.1593919706287811}, {
     1.932100564987038, -0.21276101865270095`}}]}, 
   {Hue[0.42985614462691557`], AbsoluteThickness[0.5], 
    LineBox[{{4.639537132703694, 2.4134239582979853`}, {4.920055448765317, 
     2.4893978551286517`}}]}, 
   {Hue[0.4302905143921735], AbsoluteThickness[0.5], 
    LineBox[{{4.920055448765317, 2.4893978551286517`}, {5.184589124164372, 
     2.5647269759197044`}}]}, 
   {Hue[0.48266456232214067`], AbsoluteThickness[0.5], 
    LineBox[{{5.37870716527936, 0.8208550787815385}, {5.543522291918182, 
     0.676967863055171}}]}, 
   {Hue[0.4891366137802503], AbsoluteThickness[0.5], 
    LineBox[{{5.543522291918182, 0.676967863055171}, {5.668920925154639, 
     0.5063884424531362}}]}, 
   {Hue[0.6050889314610155], AbsoluteThickness[0.5], 
    LineBox[{{5.409273624878352, -2.7000534002873837`}, {
     5.564421861688596, -2.780825898675234}}]}, 
   {Hue[0.6057957862319036], AbsoluteThickness[0.5], 
    LineBox[{{5.564421861688596, -2.780825898675234}, {
     5.797415686478516, -2.882206781209404}}]}, 
   {Hue[0.535436613017864], AbsoluteThickness[0.5], 
    LineBox[{{6.04042966489375, -1.6184427033516537`}, {
     6.107688697831032, -1.726719256199573}}]}, 
   {Hue[0.5360129205412508], AbsoluteThickness[0.5], 
    LineBox[{{6.107688697831032, -1.726719256199573}, {
     6.236722713600695, -1.9120382929352815`}}]}, 
   {Hue[0.643312369215292], AbsoluteThickness[0.5], 
    LineBox[{{2.0304868959379276`, -2.650578845473183}, {
     1.9491213004833698`, -2.8420960219321296`}}]}, 
   {Hue[0.6461045792528431], AbsoluteThickness[0.5], 
    LineBox[{{1.9491213004833698`, -2.8420960219321296`}, {
     1.894501854931514, -3.0650714899861677`}}]}, 
   {Hue[0.434150883840276], AbsoluteThickness[0.5], 
    LineBox[{{2.318193479160022, 3.0523561437734363`}, {2.300558525932044, 
     3.0790324187138367`}}]}, 
   {Hue[0.4347033988126987], AbsoluteThickness[0.5], 
    LineBox[{{2.300558525932044, 3.0790324187138367`}, {2.147409975784109, 
     3.3369807739887647`}}]}, 
   {Hue[0.5999378346648969], AbsoluteThickness[0.5], 
    LineBox[{{3.3823518890304434`, 1.0125832297425772`}, {3.1554283218170402`,
      0.8757710209190447}}]}, 
   {Hue[0.61194798393707], AbsoluteThickness[0.5], 
    LineBox[{{3.1554283218170402`, 0.8757710209190447}, {2.9693614755620596`, 
     0.8228681422826606}}]}, 
   {Hue[0.5582334846739414], AbsoluteThickness[0.5], 
    LineBox[{{3.8932286341939153`, 3.0822615395957498`}, {3.8463992243204004`,
      3.104401135034033}}]}, 
   {Hue[0.5594167191199451], AbsoluteThickness[0.5], 
    LineBox[{{3.8463992243204004`, 3.104401135034033}, {3.6125517004921526`, 
     3.2469401059536245`}}]}, 
   {Hue[0.6070360927976892], AbsoluteThickness[0.5], 
    LineBox[{{5.060518603409003, 1.8374087572629074`}, {4.867724319518835, 
     1.737790210368606}}]}, 
   {Hue[0.6075172194388475], AbsoluteThickness[0.5], 
    LineBox[{{4.867724319518835, 1.737790210368606}, {4.59620343551852, 
     1.6084972361415986`}}]}, 
   {Hue[0.6033178486505266], AbsoluteThickness[0.5], 
    LineBox[{{5.3450343976905925`, 2.5117452572953383`}, {5.139650267523764, 
     2.435360877881277}}]}, 
   {Hue[0.6125046436548122], AbsoluteThickness[0.5], 
    LineBox[{{5.139650267523764, 2.435360877881277}, {4.983121121773206, 
     2.417902245095984}}]}, 
   {Hue[0.5972120446770526], AbsoluteThickness[0.5], 
    LineBox[{{6.36043040857648, 2.8712632908675246`}, {6.356232867142325, 
     2.8662081421803145`}}]}, 
   {Hue[0.5977292404776652], AbsoluteThickness[0.5], 
    LineBox[{{6.356232867142325, 2.8662081421803145`}, {6.141541667929228, 
     2.6284119161447648`}}]}, 
   {Hue[0.0512289254356434], AbsoluteThickness[0.5], 
    LineBox[{{6.646342957806336, 3.0202538237274514`}, {7.043745709615809, 
     3.240703592082571}}]}, 
   {Hue[0.05180025185786264], AbsoluteThickness[0.5], 
    LineBox[{{7.043745709615809, 3.240703592082571}, {7.330620812462799, 
     3.381017786499221}}]}, 
   {Hue[0.5770145031212278], AbsoluteThickness[0.5], 
    LineBox[{{7.330620812462799, 3.381017786499221}, {7.203497340519563, 
     3.0880587097165377`}}]}, 
   {Hue[0.598134075678104], AbsoluteThickness[0.5], 
    LineBox[{{6.325853697968179, 2.9851710784330763`}, {6.084058045322277, 
     2.952302357499403}}]}, 
   {Hue[0.5994949150399363], AbsoluteThickness[0.5], 
    LineBox[{{6.084058045322277, 2.952302357499403}, {5.854541211793543, 
     2.947670279957346}}]}, 
   {Hue[0.6056253645463633], AbsoluteThickness[0.5], 
    LineBox[{{5.883236249619, 2.4703040575968256`}, {5.751650982657643, 
     2.3153073464402505`}}]}, 
   {Hue[0.606127545380106], AbsoluteThickness[0.5], 
    LineBox[{{5.751650982657643, 2.3153073464402505`}, {5.61090457888218, 
     2.136146777226175}}]}, 
   {Hue[0.5794597109244638], AbsoluteThickness[0.5], 
    LineBox[{{4.636581764061996, 2.8818150289647098`}, {4.636477245254755, 
     2.881847662238097}}]}, 
   {Hue[0.5801362275848089], AbsoluteThickness[0.5], 
    LineBox[{{4.636477245254755, 2.881847662238097}, {4.3696117486724635`, 
     2.984976510060298}}]}, 
   {Hue[0.6714124437292794], AbsoluteThickness[0.5], 
    LineBox[{{5.212659511690699, 1.076891272087904}, {5.2375087126678945`, 
     0.9087861464701497}}]}, 
   {Hue[0.6718499718711776], AbsoluteThickness[0.5], 
    LineBox[{{5.2375087126678945`, 0.9087861464701497}, {5.277118089101512, 
     0.6096149376742391}}]}, 
   {Hue[0.6099312423487956], AbsoluteThickness[0.5], 
    LineBox[{{4.384338141156319, 0.8873419490798059}, {4.363285812372184, 
     0.8746622170093514}}]}, 
   {Hue[0.6104695492301841], AbsoluteThickness[0.5], 
    LineBox[{{4.363285812372184, 0.8746622170093514}, {4.101790137821902, 
     0.7004063079262833}}]}, 
   {Hue[0.5896171993863499], AbsoluteThickness[0.5], 
    LineBox[{{2.342730173988915, 1.982396299324096}, {2.1466082829414375`, 
     1.9811635287196538`}}]}, 
   {Hue[0.590228615952237], AbsoluteThickness[0.5], 
    LineBox[{{2.1466082829414375`, 1.9811635287196538`}, {1.8843038987663467`,
      1.9946627581325378`}}]}, 
   {Hue[0.5980119819110321], AbsoluteThickness[0.5], 
    LineBox[{{2.9026570920761134`, 0.4676677033246549}, {2.840036535027855, 
     0.384141051189553}}]}, 
   {Hue[0.5984379383095539], AbsoluteThickness[0.5], 
    LineBox[{{2.840036535027855, 0.384141051189553}, {2.62755756444237, 
     0.09988456246365596}}]}, 
   {Hue[0.6134172362606797], AbsoluteThickness[0.5], 
    LineBox[{{4.969772267979173, -0.6638027805133653}, {
     4.946769066627097, -0.8821448624335134}}]}, 
   {Hue[0.6146053442307461], AbsoluteThickness[0.5], 
    LineBox[{{4.946769066627097, -0.8821448624335134}, {
     4.947026905438245, -1.1210298670953103`}}]}, 
   {Hue[0.415446356877496], AbsoluteThickness[0.5], 
    LineBox[{{6.164120942303901, -0.08411237846499005}, {
     6.37061134562709, -0.06040532568198426}}]}, 
   {Hue[0.4161451811218838], AbsoluteThickness[0.5], 
    LineBox[{{6.37061134562709, -0.06040532568198426}, {
     6.654473890816603, -0.007868303307741062}}]}, 
   {Hue[0.6396926951117109], AbsoluteThickness[0.5], 
    LineBox[{{5.857574073008361, 0.8910890503044555}, {5.877772185808005, 
     0.9319393182096611}}]}, 
   {Hue[0.6422102606140534], AbsoluteThickness[0.5], 
    LineBox[{{5.877772185808005, 0.9319393182096611}, {6.012425319489084, 
     1.1229967747523133`}}]}, 
   {Hue[0.607939947678739], AbsoluteThickness[0.5], 
    LineBox[{{4.523635158925179, -1.122210230657732}, {
     4.45254148122499, -1.3694201894959181`}}]}, 
   {Hue[0.6100270232130056], AbsoluteThickness[0.5], 
    LineBox[{{4.45254148122499, -1.3694201894959181`}, {
     4.422663080900482, -1.5853938271299113`}}]}, 
   {Hue[0.6124617654736476], AbsoluteThickness[0.5], 
    LineBox[{{3.927065475731581, -3.8466025248612326`}, {
     3.9440136939574426`, -3.8961546549080155`}}]}, 
   {Hue[0.6131684513951391], AbsoluteThickness[0.5], 
    LineBox[{{3.9440136939574426`, -3.8961546549080155`}, {
     4.036476761505741, -4.115383935055898}}]}, 
   {Hue[0.2999303913443787], AbsoluteThickness[0.5], 
    LineBox[{{6.706972523600871, -0.4894274390511977}, {
     6.827031107400988, -0.5523480277152938}}]}, 
   {Hue[0.3060200744987097], AbsoluteThickness[0.5], 
    LineBox[{{6.827031107400988, -0.5523480277152938}, {
     7.019232425682434, -0.6051126402023993}}]}, 
   {Hue[0.5941062242769029], AbsoluteThickness[0.5], 
    LineBox[{{7.019232425682434, -0.6051126402023993}, {
     7.1220950596559565`, -0.4343943646368669}}]}, 
   {Hue[0.6626296525413338], AbsoluteThickness[0.5], 
    LineBox[{{2.6754014121303173`, 3.3326340879980303`}, {2.659983374861286, 
     3.3583140972643566`}}]}, 
   {Hue[0.6631549762321058], AbsoluteThickness[0.5], 
    LineBox[{{2.659983374861286, 3.3583140972643566`}, {2.4769299553677895`, 
     3.635394536565653}}]}, 
   {Hue[0.5855207549449902], AbsoluteThickness[0.5], 
    LineBox[{{5.658265170428947, -0.5240385545595725}, {
     5.740760743574224, -0.4221920162666866}}]}, 
   {Hue[0.5861589693953319], AbsoluteThickness[0.5], 
    LineBox[{{5.740760743574224, -0.4221920162666866}, {
     5.884755934411642, -0.22025372318985614`}}]}, 
   {Hue[0.3988100719995159], AbsoluteThickness[0.5], 
    LineBox[{{5.098134082027737, -3.097700351180445}, {
     5.145459656154907, -3.125880807353167}}]}, 
   {Hue[0.3993454305058215], AbsoluteThickness[0.5], 
    LineBox[{{5.145459656154907, -3.125880807353167}, {
     5.416970456311492, -3.304622315953623}}]}, 
   {Hue[0.6076702176865814], AbsoluteThickness[0.5], 
    LineBox[{{2.3806805784753817`, -3.55212063103633}, {
     2.3206670706834696`, -3.5880269506694544`}}]}, 
   {Hue[0.6081708371848441], AbsoluteThickness[0.5], 
    LineBox[{{2.3206670706834696`, -3.5880269506694544`}, {
     2.063221520531135, -3.7555192923067677`}}]}, 
   {Hue[0.5301874579991139], AbsoluteThickness[0.5], 
    LineBox[{{6.29002986004452, 0.4513842698569598}, {6.355029276143757, 
     0.46343713683701493`}}]}, 
   {Hue[0.5307048423057799], AbsoluteThickness[0.5], 
    LineBox[{{6.355029276143757, 0.46343713683701493`}, {6.602749596928553, 
     0.5200804979799486}}]}, 
   {Hue[0.4481971159248145], AbsoluteThickness[0.5], 
    LineBox[{{3.732035461120855, 3.4237096215217515`}, {3.824833107959342, 
     3.630500084133293}}]}, 
   {Hue[0.4490720626222032], AbsoluteThickness[0.5], 
    LineBox[{{3.824833107959342, 3.630500084133293}, {3.9135427317209452`, 
     3.884083964998249}}]}, 
   {Hue[0.5983253154972967], AbsoluteThickness[0.5], 
    LineBox[{{6.197163991517701, 0.042867467485724994`}, {6.3411802675744315`,
      0.009655663614258361}}]}, 
   {Hue[0.5988809301284392], AbsoluteThickness[0.5], 
    LineBox[{{6.3411802675744315`, 0.009655663614258361}, {
     6.639539576810848, -0.04394817989919969}}]}, 
   {Hue[0.5805081400599629], AbsoluteThickness[0.5], 
    LineBox[{{6.023086964271189, 1.6784203032397893`}, {6.157417571799584, 
     1.8853694178921672`}}]}, 
   {Hue[0.6481831706494787], AbsoluteThickness[0.5], 
    LineBox[{{6.157417571799584, 1.8853694178921672`}, {6.185653580246528, 
     2.0527664942535755`}}]}, 
   {Hue[0.5349470237413161], AbsoluteThickness[0.5], 
    LineBox[{{5.367914906090301, -4.277074013047335}, {
     5.44429031912354, -4.3143675516307844`}}]}, 
   {Hue[0.536536107785746], AbsoluteThickness[0.5], 
    LineBox[{{5.44429031912354, -4.3143675516307844`}, {
     5.666622839602663, -4.459780914985501}}]}, 
   {Hue[0.6949202788678459], AbsoluteThickness[0.5], 
    LineBox[{{5.847734715102041, 1.3988757748651253`}, {5.879752667176417, 
     1.451322794305762}}]}, 
   {Hue[0.695671017821905], AbsoluteThickness[0.5], 
    LineBox[{{5.879752667176417, 1.451322794305762}, {6.041601846714769, 
     1.6769422552901756`}}]}, 
   {Hue[0.5765415016388645], AbsoluteThickness[0.5], 
    LineBox[{{4.360770809630589, -4.33902386751796}, {
     4.384199783584399, -4.37184883223266}}]}, 
   {Hue[0.5769856907521048], AbsoluteThickness[0.5], 
    LineBox[{{4.384199783584399, -4.37184883223266}, {
     4.586284622976261, -4.666615963549215}}]}, 
   {Hue[0.46731729405834915`], AbsoluteThickness[0.5], 
    LineBox[{{3.2578120590135815`, -3.9248022499192396`}, {
     3.295310816923169, -4.080573147615855}}]}, 
   {Hue[0.4677821239101621], AbsoluteThickness[0.5], 
    LineBox[{{3.295310816923169, -4.080573147615855}, {
     3.360414554769831, -4.387812187466024}}]}, 
   {Hue[0.6292986925171401], AbsoluteThickness[0.5], 
    LineBox[{{5.354975044337821, 2.3549168355593135`}, {5.400427587111442, 
     2.3835516341131218`}}]}, 
   {Hue[0.6297831630222527], AbsoluteThickness[0.5], 
    LineBox[{{5.400427587111442, 2.3835516341131218`}, {5.673702084602934, 
     2.568762910703068}}]}, 
   {Hue[0.34325911095679146`], AbsoluteThickness[0.5], 
    LineBox[{{2.460328661948918, 2.688568383473349}, {2.417560163418063, 
     2.828466944250005}}]}, 
   {Hue[0.3440273466264602], AbsoluteThickness[0.5], 
    LineBox[{{2.417560163418063, 2.828466944250005}, {2.35630424816141, 
     3.1013958181243013`}}]}, 
   {Hue[0.3695390334951522], AbsoluteThickness[0.5], 
    LineBox[{{4.17833609037992, 2.9328224325560073`}, {4.16295804956611, 
     3.1265310512196702`}}]}, 
   {Hue[0.37035722486997524`], AbsoluteThickness[0.5], 
    LineBox[{{4.16295804956611, 3.1265310512196702`}, {4.1633701963243706`, 
     3.444647573041544}}]}, 
   {Hue[0.5126540232987401], AbsoluteThickness[0.5], 
    LineBox[{{3.6798132369816634`, -1.3413433414305957`}, {
     3.6676646372876474`, -1.4126984380194179`}}]}, 
   {Hue[0.5144318437759045], AbsoluteThickness[0.5], 
    LineBox[{{3.6676646372876474`, -1.4126984380194179`}, {
     3.592404676609603, -1.6552666739159938`}}]}, 
   {Hue[0.5195421741221223], AbsoluteThickness[0.5], 
    LineBox[{{5.11161588158823, -1.1281494296248273`}, {
     5.132456014196594, -1.2323105949444468`}}]}, 
   {Hue[0.5224993753758673], AbsoluteThickness[0.5], 
    LineBox[{{5.132456014196594, -1.2323105949444468`}, {
     5.201093626560587, -1.413143781985224}}]}, 
   {Hue[0.5494461195935108], AbsoluteThickness[0.5], 
    LineBox[{{4.874356195091991, 1.1046383358788552`}, {4.826560889913316, 
     1.1926537351621134`}}]}, 
   {Hue[0.5499269181624833], AbsoluteThickness[0.5], 
    LineBox[{{4.826560889913316, 1.1926537351621134`}, {4.696866315528102, 
     1.414058019276986}}]}, 
   {Hue[0.5699352407185894], AbsoluteThickness[0.5], 
    LineBox[{{5.813844797291337, 0.48107081705997407`}, {5.855614660955978, 
     0.060322891337182404`}}]}, 
   {Hue[0.5808777798945047], AbsoluteThickness[0.5], 
    LineBox[{{5.855614660955978, 0.060322891337182404`}, {
     5.923453268094582, -0.12141023291613229`}}]}, 
   {Hue[0.42259753452919646`], AbsoluteThickness[0.5], 
    LineBox[{{5.940310911108822, 0.3832831776671432}, {6.076884685342428, 
     0.3318949931718065}}]}, 
   {Hue[0.42303718594842193`], AbsoluteThickness[0.5], 
    LineBox[{{6.076884685342428, 0.3318949931718065}, {6.385268158618309, 
     0.2216106764551272}}]}, 
   {Hue[0.6061392709321853], AbsoluteThickness[0.5], 
    LineBox[{{6.083996405717554, 0.4533587012196888}, {6.248925516908843, 
     0.6076491926791963}}]}, 
   {Hue[0.6067368066710634], AbsoluteThickness[0.5], 
    LineBox[{{6.248925516908843, 0.6076491926791963}, {6.419193823879621, 
     0.7857087240698564}}]}, 
   {Hue[0.2992646585888774], AbsoluteThickness[0.5], 
    LineBox[{{6.065139394700103, 0.7926260833395771}, {6.170862139953335, 
     0.7656679692231767}}]}, 
   {Hue[0.2996907754568142], AbsoluteThickness[0.5], 
    LineBox[{{6.170862139953335, 0.7656679692231767}, {6.4275712886359875`, 
     0.699587138935426}}]}, 
   {Hue[0.055578253174568576`], AbsoluteThickness[0.5], 
    LineBox[{{6.206924443618032, 0.9249844108946891}, {6.297678230151587, 
     1.0622960813322682`}}]}, 
   {Hue[0.06313531912684102], AbsoluteThickness[0.5], 
    LineBox[{{6.297678230151587, 1.0622960813322682`}, {6.443788578625388, 
     1.200149317012919}}]}, 
   {Hue[0.33006327551537074`], AbsoluteThickness[0.5], 
    LineBox[{{6.443788578625388, 1.200149317012919}, {6.620625327355075, 
     1.1048575922018204`}}]}, 
   {Hue[0.5969912319039002], AbsoluteThickness[0.5], 
    LineBox[{{6.620625327355075, 1.1048575922018204`}, {6.5858397908744095`, 
     0.9070149401509726}}]}, 
   {Hue[0.3155041603445965], AbsoluteThickness[0.5], 
    LineBox[{{6.1284238386568015`, 1.102352339197882}, {5.745559795809597, 
     1.603463828527112}}]}, 
   {Hue[0.3160483387147255], AbsoluteThickness[0.5], 
    LineBox[{{5.745559795809597, 1.603463828527112}, {5.614085241302615, 
     1.7933448910919676`}}]}, 
   {Hue[0.5754300675146234], AbsoluteThickness[0.5], 
    LineBox[{{5.935117421608894, 1.0864037938740474`}, {5.675616825289117, 
     1.0009647498525993`}}]}, 
   {Hue[0.5758932141723917], AbsoluteThickness[0.5], 
    LineBox[{{5.675616825289117, 1.0009647498525993`}, {5.361070255815992, 
     0.9066794641441657}}]}, 
   {Hue[0.39371968583691214`], AbsoluteThickness[0.5], 
    LineBox[{{5.649134368392715, 1.3853262277671203`}, {5.627596398559442, 
     1.4468966546975925`}}]}, 
   {Hue[0.39426362198917175`], AbsoluteThickness[0.5], 
    LineBox[{{5.627596398559442, 1.4468966546975925`}, {5.54122112442311, 
     1.6611159737542394`}}]}, 
   {Hue[0.5475375955873927], AbsoluteThickness[0.5], 
    LineBox[{{4.9726144442567275`, -0.6644372467768852}, {
     4.783669741883618, -1.0739073265850387`}}]}, 
   {Hue[0.5479660748100883], AbsoluteThickness[0.5], 
    LineBox[{{4.783669741883618, -1.0739073265850387`}, {
     4.65050019908954, -1.3571329430121755`}}]}, 
   {Hue[0.5164856636275479], AbsoluteThickness[0.5], 
    LineBox[{{3.8732239497467686`, 1.5338562979998627`}, {3.7338861248009745`,
      1.6211165766478812`}}]}, 
   {Hue[0.5275467023951417], AbsoluteThickness[0.5], 
    LineBox[{{3.7338861248009745`, 1.6211165766478812`}, {3.610056072478961, 
     1.7534670973671465`}}]}, 
   {Hue[0.6163777679248102], AbsoluteThickness[0.5], 
    LineBox[{{3.3317688946549024`, 1.5398242935471955`}, {3.202233651245524, 
     1.614315174749815}}]}, 
   {Hue[0.685413091711559], AbsoluteThickness[0.5], 
    LineBox[{{3.202233651245524, 1.614315174749815}, {3.105015897254079, 
     1.7452486056995329`}}]}, 
   {Hue[0.5961234579212917], AbsoluteThickness[0.5], 
    LineBox[{{4.214188723332955, 2.4126086795658774`}, {4.169018992833336, 
     2.6714729818858807`}}]}, 
   {Hue[0.5977760363848397], AbsoluteThickness[0.5], 
    LineBox[{{4.169018992833336, 2.6714729818858807`}, {4.157929058531749, 
     2.916356710767629}}]}, 
   {Hue[0.3816994214426937], AbsoluteThickness[0.5], 
    LineBox[{{4.614035767685453, -1.6235607007924133`}, {
     4.613275787411451, -1.6515837840669534`}}]}, 
   {Hue[0.392688927050476], AbsoluteThickness[0.5], 
    LineBox[{{4.613275787411451, -1.6515837840669534`}, {
     4.65185905915806, -1.815237145749338}}]}, 
   {Hue[0.6233495553635819], AbsoluteThickness[0.5], 
    LineBox[{{4.65185905915806, -1.815237145749338}, {
     4.817938396125092, -1.8414811066014845`}}]}, 
   {Hue[0.5810282774470443], AbsoluteThickness[0.5], 
    LineBox[{{2.2257841832936305`, -1.445930744172194}, {
     2.146923254857596, -1.5178962583075204`}}]}, 
   {Hue[0.5833230640938696], AbsoluteThickness[0.5], 
    LineBox[{{2.146923254857596, -1.5178962583075204`}, {
     1.9600927445277831`, -1.6432628221885979`}}]}, 
   {Hue[0.6770356404920589], AbsoluteThickness[0.5], 
    LineBox[{{3.671913047482954, -2.284676630362037}, {
     3.6140939482450616`, -2.415175064315812}}]}, 
   {Hue[0.677582034217201], AbsoluteThickness[0.5], 
    LineBox[{{3.6140939482450616`, -2.415175064315812}, {
     3.4833971172949005`, -2.676149004931926}}]}, 
   {Hue[0.6630121161106656], AbsoluteThickness[0.5], 
    LineBox[{{3.911017260253714, -2.2723821193913127`}, {
     3.912827897222405, -2.333939412555422}}]}, 
   {Hue[0.6635643483348018], AbsoluteThickness[0.5], 
    LineBox[{{3.912827897222405, -2.333939412555422}, {
     3.9368108184635235`, -2.6420304169613367`}}]}, 
   {Hue[0.36614582301397086`], AbsoluteThickness[0.5], 
    LineBox[{{5.6963360179209825`, -1.5254300497137785`}, {
     5.830677712674249, -1.572013544936048}}]}, 
   {Hue[0.36866682192036193`], AbsoluteThickness[0.5], 
    LineBox[{{5.830677712674249, -1.572013544936048}, {
     6.0510234328383525`, -1.6118724155983193`}}]}, 
   {Hue[0.6506897681364755], AbsoluteThickness[0.5], 
    LineBox[{{4.804334597548648, 0.8640335567333075}, {4.7924178250816, 
     1.1692335302633108`}}]}, 
   {Hue[0.6512607566651276], AbsoluteThickness[0.5], 
    LineBox[{{4.7924178250816, 1.1692335302633108`}, {4.770064234682562, 
     1.4154639452741689`}}]}, 
   {Hue[0.6339713365640042], AbsoluteThickness[0.5], 
    LineBox[{{6.157711678015688, -1.968108631208171}, {
     6.333721235702375, -1.9015039773405542`}}]}, 
   {Hue[0.635205465810992], AbsoluteThickness[0.5], 
    LineBox[{{6.333721235702375, -1.9015039773405542`}, {
     6.581487511470669, -1.8373894688593146`}}]}, 
   {Hue[0.5177904105810541], AbsoluteThickness[0.5], 
    LineBox[{{6.94356657203474, -2.1976849162890946`}, {
     7.079898438563966, -2.1916639702758896`}}]}, 
   {Hue[0.518346132857053], AbsoluteThickness[0.5], 
    LineBox[{{7.079898438563966, -2.1916639702758896`}, {
     7.376648486803633, -2.1930786687527424`}}]}, 
   {Hue[0.6296154253935494], AbsoluteThickness[0.5], 
    LineBox[{{3.693549841600772, 1.39851555547878}, {3.72349008603967, 
     1.623893050276538}}]}, 
   {Hue[0.6300614715398145], AbsoluteThickness[0.5], 
    LineBox[{{3.72349008603967, 1.623893050276538}, {3.7722387829221264`, 
     1.9423148930827605`}}]}, 
   {Hue[0.5872552910373909], AbsoluteThickness[0.5], 
    LineBox[{{5.6425788131142305`, -4.572544676786376}, {
     5.81288097990175, -4.539762971439139}}]}, 
   {Hue[0.587705756101358], AbsoluteThickness[0.5], 
    LineBox[{{5.81288097990175, -4.539762971439139}, {
     6.149841977810634, -4.4825159560340175`}}]}, 
   {Hue[0.5356738985674281], AbsoluteThickness[0.5], 
    LineBox[{{4.163527342935499, 0.3550118541941684}, {4.210557743467874, 
     0.5872955963204793}}]}, 
   {Hue[0.5361118689533713], AbsoluteThickness[0.5], 
    LineBox[{{4.210557743467874, 0.5872955963204793}, {4.2706920586795425`, 
     0.9097669257236609}}]}, 
   {Hue[0.5242218165934313], AbsoluteThickness[0.5], 
    LineBox[{{5.0266015784679166`, 1.663859549193721}, {5.078724029735301, 
     1.7342052505673058`}}]}, 
   {Hue[0.5255993609674462], AbsoluteThickness[0.5], 
    LineBox[{{5.078724029735301, 1.7342052505673058`}, {5.169968565015996, 
     1.892845145460059}}]}, 
   {Hue[0.4605957493825444], AbsoluteThickness[0.5], 
    LineBox[{{6.046353393366213, -3.6660049430630695`}, {
     6.07843894252419, -3.6876125906400925`}}]}, 
   {Hue[0.4610503164158551], AbsoluteThickness[0.5], 
    LineBox[{{6.07843894252419, -3.6876125906400925`}, {
     6.330560553127594, -3.848884068459315}}]}, 
   {Hue[0.6251270267849965], AbsoluteThickness[0.5], 
    LineBox[{{2.8101200646589803`, -3.4183804930367216`}, {
     2.706229287649097, -3.577488126124047}}]}, 
   {Hue[0.6267268147568307], AbsoluteThickness[0.5], 
    LineBox[{{2.706229287649097, -3.577488126124047}, {
     2.6017292195545387`, -3.79214553215458}}]}, 
   {Hue[0.5542814387753632], AbsoluteThickness[0.5], 
    LineBox[{{4.474254493612124, -3.11896379066725}, {
     4.49757008874635, -3.2919251048700393`}}]}, 
   {Hue[0.5547269620737119], AbsoluteThickness[0.5], 
    LineBox[{{4.49757008874635, -3.2919251048700393`}, {
     4.535067203686278, -3.6182466200037733`}}]}, 
   {Hue[0.4967687192442738], AbsoluteThickness[0.5], 
    LineBox[{{2.6070905982741728`, 1.1358694542699528`}, {2.3953266560280184`,
      1.1486591140361173`}}]}, 
   {Hue[0.4973355021893278], AbsoluteThickness[0.5], 
    LineBox[{{2.3953266560280184`, 1.1486591140361173`}, {2.08540959683888, 
     1.1832428111995856`}}]}, 
   {Hue[0.5767207885335787], AbsoluteThickness[0.5], 
    LineBox[{{2.918124987337289, 1.13103979481882}, {2.9083851847677877`, 
     1.129473906244687}}]}, 
   {Hue[0.5778355683616814], AbsoluteThickness[0.5], 
    LineBox[{{2.9083851847677877`, 1.129473906244687}, {2.6225585474188384`, 
     1.112997775056993}}]}, 
   {Hue[0.5402599019297867], AbsoluteThickness[0.5], 
    LineBox[{{4.437151694909127, 0.3966240127054583}, {4.429705033561572, 
     0.361036684468657}}]}, 
   {Hue[0.5414071344124849], AbsoluteThickness[0.5], 
    LineBox[{{4.429705033561572, 0.361036684468657}, {4.349044585260537, 
     0.10923644547303538`}}]}, 
   {Hue[0.5588835732369272], AbsoluteThickness[0.5], 
    LineBox[{{4.6736170162304465`, 0.5786074119062264}, {4.664484860941158, 
     0.5427611567263547}}]}, 
   {Hue[0.5602448063044605], AbsoluteThickness[0.5], 
    LineBox[{{4.664484860941158, 0.5427611567263547}, {4.588889136609498, 
     0.344573347765463}}]}, 
   {Hue[0.4409869872209994], AbsoluteThickness[0.5], 
    LineBox[{{5.209070085780812, 1.6380846213235052`}, {5.5926837492009565`, 
     1.3117473509065098`}}]}, 
   {Hue[0.44149313249091293`], AbsoluteThickness[0.5], 
    LineBox[{{5.5926837492009565`, 1.3117473509065098`}, {5.86477877654838, 
     1.0979599403830935`}}]}, 
   {Hue[0.02082321822181361], AbsoluteThickness[0.5], 
    LineBox[{{5.331052317504082, 1.7939501036896806`}, {5.440125870914012, 
     1.975955209914272}}]}, 
   {Hue[0.0214753806403278], AbsoluteThickness[0.5], 
    LineBox[{{5.440125870914012, 1.975955209914272}, {5.5623011206984225`, 
     2.1533720115447528`}}]}, 
   {Hue[0.5333159153141338], AbsoluteThickness[0.5], 
    LineBox[{{5.5623011206984225`, 2.1533720115447528`}, {5.613847025178291, 
     1.9442152930487302`}}]}, 
   {Hue[0.444125195817289], AbsoluteThickness[0.5], 
    LineBox[{{5.157267893420717, 1.888674374050784}, {5.143916500358886, 
     1.8939282377708788`}}]}, 
   {Hue[0.44458273195170234`], AbsoluteThickness[0.5], 
    LineBox[{{5.143916500358886, 1.8939282377708788`}, {4.908669136179076, 
     1.993298348953123}}]}, 
   {Hue[0.5600945474236482], AbsoluteThickness[0.5], 
    LineBox[{{4.425270812334687, 1.3810379179208954`}, {4.3752001145446195`, 
     1.3713009135521437`}}]}, 
   {Hue[0.5607691796998866], AbsoluteThickness[0.5], 
    LineBox[{{4.3752001145446195`, 1.3713009135521437`}, {4.0979059816517305`,
      1.2981347388234161`}}]}, 
   {Hue[0.5296423921570683], AbsoluteThickness[0.5], 
    LineBox[{{3.8895115973416425`, 1.5712810717065464`}, {3.4158870944840727`,
      1.681426037746518}}]}, 
   {Hue[0.5301467293102441], AbsoluteThickness[0.5], 
    LineBox[{{3.4158870944840727`, 1.681426037746518}, {3.1035587515737224`, 
     1.7668587096786859`}}]}, 
   {Hue[0.5650272897075758], AbsoluteThickness[0.5], 
    LineBox[{{3.359307661904399, -0.15239223900523113`}, {
     3.356164761264016, -0.15401996445278462`}}]}, 
   {Hue[0.5656551720255302], AbsoluteThickness[0.5], 
    LineBox[{{3.356164761264016, -0.15401996445278462`}, {
     3.105797122138783, -0.3033703246874862}}]}, 
   {Hue[0.4893735472149239], AbsoluteThickness[0.5], 
    LineBox[{{4.845049405270576, -0.8443039015769286}, {
     4.906288531459489, -1.3956339583029564`}}]}, 
   {Hue[0.4928865764959599], AbsoluteThickness[0.5], 
    LineBox[{{4.906288531459489, -1.3956339583029564`}, {
     4.959510765793979, -1.5757066790935146`}}]}, 
   {Hue[0.6116090808980289], AbsoluteThickness[0.5], 
    LineBox[{{4.11238417025681, -1.8621750808132935`}, {
     4.241658023936777, -2.061100939673665}}]}, 
   {Hue[0.6124178959381053], AbsoluteThickness[0.5], 
    LineBox[{{4.241658023936777, -2.061100939673665}, {
     4.376586172468551, -2.3100975164957145`}}]}, 
   {Hue[0.5657509266188725], AbsoluteThickness[0.5], 
    LineBox[{{3.0799027578563583`, -2.1644946064953965`}, {
     2.928189033107664, -2.3198829716208573`}}]}, 
   {Hue[0.569550951186022], AbsoluteThickness[0.5], 
    LineBox[{{2.928189033107664, -2.3198829716208573`}, {
     2.8025887730608914`, -2.506908015202004}}]}, 
   {Hue[0.5278249355189382], AbsoluteThickness[0.5], 
    LineBox[{{4.461178090981471, -2.66777511298858}, {
     4.466379930934326, -2.8259477958424988`}}]}, 
   {Hue[0.5282552141686814], AbsoluteThickness[0.5], 
    LineBox[{{4.466379930934326, -2.8259477958424988`}, {
     4.473282129244128, -3.119055596895669}}]}, 
   {Hue[0.4897297416713451], AbsoluteThickness[0.5], 
    LineBox[{{5.695025981945947, -1.873981519855125}, {
     5.7323274872143966`, -2.1104909837938832`}}]}, 
   {Hue[0.49020176461946313`], AbsoluteThickness[0.5], 
    LineBox[{{5.7323274872143966`, -2.1104909837938832`}, {
     5.771450275177425, -2.4177698968320134`}}]}, 
   {Hue[0.5597666967072527], AbsoluteThickness[0.5], 
    LineBox[{{5.03546764935036, -1.1497006263265979`}, {
     5.027905337343509, -1.3130273167312811`}}]}, 
   {Hue[0.5602002498154315], AbsoluteThickness[0.5], 
    LineBox[{{5.027905337343509, -1.3130273167312811`}, {
     5.018264684782464, -1.5967050714204696`}}]}, 
   {Hue[0.5714991924999653], AbsoluteThickness[0.5], 
    LineBox[{{4.418720121257387, 0.4350862635367063}, {4.393929642774809, 
     0.3963588052783632}}]}, 
   {Hue[0.5719272951699572], AbsoluteThickness[0.5], 
    LineBox[{{4.393929642774809, 0.3963588052783632}, {4.216668505879211, 
     0.12346079627919576`}}]}, 
   {Hue[0.45271464986018706`], AbsoluteThickness[0.5], 
    LineBox[{{6.427610932939978, 1.7165502097000112`}, {6.508559290312965, 
     1.6636206267420572`}}]}, 
   {Hue[0.4565106425533859], AbsoluteThickness[0.5], 
    LineBox[{{6.508559290312965, 1.6636206267420572`}, {6.658700978555639, 
     1.5206143331109643`}}]}, 
   {Hue[0.3159715998553181], AbsoluteThickness[0.5], 
    LineBox[{{5.605257118565848, 2.9196039564224585`}, {5.599066951225226, 
     2.930096932646486}}]}, 
   {Hue[0.31690180675822455`], AbsoluteThickness[0.5], 
    LineBox[{{5.599066951225226, 2.930096932646486}, {5.442554220958551, 
     3.1481491532067367`}}]}, 
   {Hue[0.550681522962591], AbsoluteThickness[0.5], 
    LineBox[{{6.057580694396513, 2.7192442846648537`}, {5.849313028394842, 
     2.7380426305714565`}}]}, 
   {Hue[0.5511639078144751], AbsoluteThickness[0.5], 
    LineBox[{{5.849313028394842, 2.7380426305714565`}, {5.543214711492126, 
     2.775848824839728}}]}, 
   {Hue[0.035057008984395385`], AbsoluteThickness[0.5], 
    LineBox[{{6.279828006159819, 2.932610835160989}, {6.32537628123876, 
     2.9714475727112744`}}]}, 
   {Hue[0.03611474859335281], AbsoluteThickness[0.5], 
    LineBox[{{6.32537628123876, 2.9714475727112744`}, {6.547552688606352, 
     3.1259755122105775`}}]}, 
   {Hue[0.4991374856065688], AbsoluteThickness[0.5], 
    LineBox[{{6.547552688606352, 3.1259755122105775`}, {6.611394669557018, 
     2.8629822774212283`}}]}, 
   {Hue[0.5519225715573671], AbsoluteThickness[0.5], 
    LineBox[{{6.276828801386665, 2.6245359137094626`}, {6.259742824263138, 
     2.3762908746242517`}}]}, 
   {Hue[0.5524011462865687], AbsoluteThickness[0.5], 
    LineBox[{{6.259742824263138, 2.3762908746242517`}, {6.248113747025567, 
     2.061642590373633}}]}, 
   {Hue[0.3278366678863093], AbsoluteThickness[0.5], 
    LineBox[{{6.5857205405867205`, 2.395189110965374}, {6.729661068797752, 
     2.337460337683839}}]}, 
   {Hue[0.3287833001659972], AbsoluteThickness[0.5], 
    LineBox[{{6.729661068797752, 2.337460337683839}, {6.919620978567895, 
     2.240441102465169}}]}, 
   {Hue[0.628810579172301], AbsoluteThickness[0.5], 
    LineBox[{{6.161994848413446, 2.1190405337257494`}, {6.1668991638026736`, 
     2.0905251273255736`}}]}, 
   {Hue[0.635681383704971], AbsoluteThickness[0.5], 
    LineBox[{{6.1668991638026736`, 2.0905251273255736`}, {6.155879709729385, 
     1.8834726200982996`}}]}, 
   {Hue[0.4567922428601627], AbsoluteThickness[0.5], 
    LineBox[{{4.573592747317461, 2.2696994079172903`}, {4.404114849816348, 
     2.2421941839337824`}}]}, 
   {Hue[0.45725056651283236`], AbsoluteThickness[0.5], 
    LineBox[{{4.404114849816348, 2.2421941839337824`}, {4.081960773279959, 
     2.198169941148322}}]}, 
   {Hue[0.6108865459677365], AbsoluteThickness[0.5], 
    LineBox[{{5.075711793652341, 0.16411743654090533`}, {5.079386415248376, 
     0.15245718439146574`}}]}, 
   {Hue[0.6134073171939138], AbsoluteThickness[0.5], 
    LineBox[{{5.079386415248376, 0.15245718439146574`}, {
     5.112731920695278, -0.06747369517184743}}]}, 
   {Hue[0.5701198414475006], AbsoluteThickness[0.5], 
    LineBox[{{3.0954159310744322`, 0.34793467438978865`}, {
     2.8964235126874884`, 0.31518883608516335`}}]}, 
   {Hue[0.570603914250432], AbsoluteThickness[0.5], 
    LineBox[{{2.8964235126874884`, 0.31518883608516335`}, {2.55793410054191, 
     0.2478274113179615}}]}, 
   {Hue[0.4879806283146636], AbsoluteThickness[0.5], 
    LineBox[{{2.7546851027732324`, 1.9296038001675277`}, {2.61284454365136, 
     1.972644582812383}}]}, 
   {Hue[0.48850583344202975`], AbsoluteThickness[0.5], 
    LineBox[{{2.61284454365136, 1.972644582812383}, {2.3618405557934183`, 
     2.037142733359381}}]}, 
   {Hue[0.5686289212683209], AbsoluteThickness[0.5], 
    LineBox[{{6.646229973474925, -3.9407008710159626`}, {
     6.840653637279135, -4.032251394657781}}]}, 
   {Hue[0.5694861313195639], AbsoluteThickness[0.5], 
    LineBox[{{6.840653637279135, -4.032251394657781}, {
     7.092177551255954, -4.125845364612247}}]}, 
   {Hue[0.640174178030687], AbsoluteThickness[0.5], 
    LineBox[{{5.981721594978085, -0.6182995197778255}, {
     6.084762693803288, -0.7563955503967843}}]}, 
   {Hue[0.6419418748262757], AbsoluteThickness[0.5], 
    LineBox[{{6.084762693803288, -0.7563955503967843}, {
     6.243677502779739, -0.9193412808091745}}]}, 
   {Hue[0.5161427459674485], AbsoluteThickness[0.5], 
    LineBox[{{6.420651282882985, 0.6786255377718334}, {6.61573845983758, 
     0.6579147362670072}}]}, 
   {Hue[0.5169833242253801], AbsoluteThickness[0.5], 
    LineBox[{{6.61573845983758, 0.6579147362670072}, {6.918880804779869, 
     0.6508471416600876}}]}, 
   {Hue[0.2751685113061592], AbsoluteThickness[0.5], 
    LineBox[{{6.028746077079593, 1.678202557840273}, {6.139477083886224, 
     1.866099533602457}}]}, 
   {Hue[0.28941653626868563`], AbsoluteThickness[0.5], 
    LineBox[{{6.139477083886224, 1.866099533602457}, {6.1868978564583355`, 
     2.0491226747627462`}}]}, 
   {Hue[0.49535009046863726`], AbsoluteThickness[0.5], 
    LineBox[{{6.1868978564583355`, 2.0491226747627462`}, {6.040025914953818, 
     2.1681807810395077`}}]}, 
   {Hue[0.5384695240334565], AbsoluteThickness[0.5], 
    LineBox[{{4.436223318357509, 2.612916184497205}, {4.398439856171458, 
     2.699980643897846}}]}, 
   {Hue[0.5391482375855542], AbsoluteThickness[0.5], 
    LineBox[{{4.398439856171458, 2.699980643897846}, {4.263989323872711, 
     2.96088194936618}}]}, 
   {Hue[0.6603803943573665], AbsoluteThickness[0.5], 
    LineBox[{{4.941295591444154, 2.054124475027803}, {4.959016081021514, 
     2.4344518293773048`}}]}, 
   {Hue[0.6613368220524796], AbsoluteThickness[0.5], 
    LineBox[{{4.959016081021514, 2.4344518293773048`}, {4.991026902274692, 
     2.66486240934079}}]}, 
   {Hue[0.6052916605757704], AbsoluteThickness[0.5], 
    LineBox[{{3.0012204405350444`, -2.161361606752339}, {
     3.0675726141050053`, -2.3405964921412825`}}]}, 
   {Hue[0.6075092198226097], AbsoluteThickness[0.5], 
    LineBox[{{3.0675726141050053`, -2.3405964921412825`}, {
     3.118721016232729, -2.5828619436163174`}}]}, 
   {Hue[0.5961466418682617], AbsoluteThickness[0.5], 
    LineBox[{{5.134549006606511, 0.0754337718760767}, {
     5.697012489318121, -0.17493415938241547`}}]}, 
   {Hue[0.5969602420897329], AbsoluteThickness[0.5], 
    LineBox[{{5.697012489318121, -0.17493415938241547`}, {
     5.9039533550722, -0.28769235118339}}]}, 
   {Hue[0.5992412454556326], AbsoluteThickness[0.5], 
    LineBox[{{4.009291959826065, 0.3804276324043645}, {
     4.320407359755508, -0.0701880419354213}}]}, 
   {Hue[0.6014291438291518], AbsoluteThickness[0.5], 
    LineBox[{{4.320407359755508, -0.0701880419354213}, {
     4.433552143658904, -0.2993283248884692}}]}, 
   {Hue[0.5872439665555951], AbsoluteThickness[0.5], 
    LineBox[{{2.523414247914907, 0.8636347501390702}, {2.5110907617902707`, 
     0.6924910559241869}}]}, 
   {Hue[0.5876822143403245], AbsoluteThickness[0.5], 
    LineBox[{{2.5110907617902707`, 0.6924910559241869}, {2.483143492607851, 
     0.37377666205177246`}}]}, 
   {Hue[0.5375266866406497], AbsoluteThickness[0.5], 
    LineBox[{{3.3262496546134708`, 2.6086203107967405`}, {3.342031659152929, 
     2.5913326151056757`}}]}, 
   {Hue[0.5379927050340941], AbsoluteThickness[0.5], 
    LineBox[{{3.342031659152929, 2.5913326151056757`}, {3.557687103684855, 
     2.3679185268949206`}}]}, 
   {Hue[0.591736424581763], AbsoluteThickness[0.5], 
    LineBox[{{2.984742285533544, 1.3322047722472612`}, {3.1126554897489394`, 
     1.1403839555270252`}}]}, 
   {Hue[0.5975503709358814], AbsoluteThickness[0.5], 
    LineBox[{{3.1126554897489394`, 1.1403839555270252`}, {3.1910796081671067`,
      0.9420935183745383}}]}, 
   {Hue[0.5854886072566686], AbsoluteThickness[0.5], 
    LineBox[{{3.12491390770137, 0.41817174990918066`}, {3.1241290017165273`, 
     0.38362623511864646`}}]}, 
   {Hue[0.5868165057294249], AbsoluteThickness[0.5], 
    LineBox[{{3.1241290017165273`, 0.38362623511864646`}, {3.147559446731981, 
     0.12576724646237025`}}]}, 
   {Hue[0.6719914712827677], AbsoluteThickness[0.5], 
    LineBox[{{4.4324159165967165`, -2.7422625799211477`}, {
     4.463652308976099, -2.825853828031031}}]}, 
   {Hue[0.6725449950051243], AbsoluteThickness[0.5], 
    LineBox[{{4.463652308976099, -2.825853828031031}, {
     4.548095986003144, -3.0902889777521634`}}]}, 
   {Hue[0.5444042058086359], AbsoluteThickness[0.5], 
    LineBox[{{5.05358911366978, -2.588868704300002}, {
     5.08689986996324, -2.6359201941860144`}}]}, 
   {Hue[0.5449994851252065], AbsoluteThickness[0.5], 
    LineBox[{{5.08689986996324, -2.6359201941860144`}, {
     5.2876892184364195`, -2.8886379161725055`}}]}, 
   {Hue[0.5504642485960498], AbsoluteThickness[0.5], 
    LineBox[{{5.1872302508618775`, 1.896305147835524}, {5.425244695335637, 
     2.060153468949252}}]}, 
   {Hue[0.5518903780086695], AbsoluteThickness[0.5], 
    LineBox[{{5.425244695335637, 2.060153468949252}, {5.587650402673223, 
     2.1457227439160373`}}]}, 
   {Hue[0.4340452120255427], AbsoluteThickness[0.5], 
    LineBox[{{6.673719973607622, -0.4315718023814172}, {
     6.803066821291612, -0.3948369378771183}}]}, 
   {Hue[0.43492866850479955`], AbsoluteThickness[0.5], 
    LineBox[{{6.803066821291612, -0.3948369378771183}, {
     7.0805021179439285`, -0.3412683309627705}}]}, 
   {Hue[0.3601767658956989], AbsoluteThickness[0.5], 
    LineBox[{{6.101678468992531, -1.5564426317371467`}, {
     6.16322260101549, -1.6828496888477609`}}]}, 
   {Hue[0.36060774362389963`], AbsoluteThickness[0.5], 
    LineBox[{{6.16322260101549, -1.6828496888477609`}, {
     6.266322004214191, -1.9001236213218047`}}]}, 
   {Hue[0.5112450394827609], AbsoluteThickness[0.5], 
    LineBox[{{5.6545434956788805`, -1.6174964208590392`}, {
     5.654521244447223, -1.617686281960214}}]}, 
   {Hue[0.5131482460859559], AbsoluteThickness[0.5], 
    LineBox[{{5.654521244447223, -1.617686281960214}, {
     5.6591549305776745`, -1.8500765636884273`}}]}, 
   {Hue[0.6405704801862602], AbsoluteThickness[0.5], 
    LineBox[{{4.903664071944285, -1.4016908821265712`}, {
     4.728481165630987, -1.5561067670563256`}}]}, 
   {Hue[0.6439746714525906], AbsoluteThickness[0.5], 
    LineBox[{{4.728481165630987, -1.5561067670563256`}, {
     4.603813660107468, -1.712282706653468}}]}, 
   {Hue[0.5647424515830813], AbsoluteThickness[0.5], 
    LineBox[{{3.769513866241796, -3.901596953087239}, {
     3.7483358953744865`, -4.135842693206549}}]}, 
   {Hue[0.5652551878131874], AbsoluteThickness[0.5], 
    LineBox[{{3.7483358953744865`, -4.135842693206549}, {
     3.733017588675908, -4.443580103676005}}]}, 
   {Hue[0.5773691417082483], AbsoluteThickness[0.5], 
    LineBox[{{2.7665145473648067`, -3.8851419392366253`}, {
     2.7983015600003998`, -4.09515932321678}}]}, 
   {Hue[0.5778408989225678], AbsoluteThickness[0.5], 
    LineBox[{{2.7983015600003998`, -4.09515932321678}, {
     2.8366691762425877`, -4.411998077118915}}]}, 
   {Hue[0.4933131063866232], AbsoluteThickness[0.5], 
    LineBox[{{6.180859700032221, -0.05675138067895061}, {
     6.403912011786069, -0.09380173452715453}}]}, 
   {Hue[0.4982056195009046], AbsoluteThickness[0.5], 
    LineBox[{{6.403912011786069, -0.09380173452715453}, {
     6.604283576296392, -0.08683293426488228}}]}, 
   {Hue[0.320796797140513], AbsoluteThickness[0.5], 
    LineBox[{{5.610710636197575, 2.984075235587679}, {5.835396136006095, 
     3.103681036466389}}]}, 
   {Hue[0.32313346287476424`], AbsoluteThickness[0.5], 
    LineBox[{{5.835396136006095, 3.103681036466389}, {6.030754299574667, 
     3.1726312768189406`}}]}, 
   {Hue[0.6304222510918748], AbsoluteThickness[0.5], 
    LineBox[{{2.157656418759747, 1.7362388448876456`}, {2.1265963766100686`, 
     1.6737478510878607`}}]}, 
   {Hue[0.6309102119837697], AbsoluteThickness[0.5], 
    LineBox[{{2.1265963766100686`, 1.6737478510878607`}, {1.9555908711882988`,
      1.357479724062118}}]}, 
   {Hue[0.5987032418501201], AbsoluteThickness[0.5], 
    LineBox[{{3.6041428001278377`, 2.413617476757415}, {3.6802807212167044`, 
     2.347272552990973}}]}, 
   {Hue[0.5997437080844055], AbsoluteThickness[0.5], 
    LineBox[{{3.6802807212167044`, 2.347272552990973}, {3.8300739101308108`, 
     2.1886603027168055`}}]}, 
   {Hue[0.5905552941661444], AbsoluteThickness[0.5], 
    LineBox[{{2.890561718319046, 3.0786248525262647`}, {2.830175844927783, 
     3.0537874034526507`}}]}, 
   {Hue[0.5041461228620435], AbsoluteThickness[0.5], 
    LineBox[{{3.290939934047091, 3.632993032437337}, {3.427390763408736, 
     3.6123057075549987`}}]}, 
   {Hue[0.5057845249206152], AbsoluteThickness[0.5], 
    LineBox[{{3.427390763408736, 3.6123057075549987`}, {3.6667702180398356`, 
     3.544143016451502}}]}, 
   {Hue[0.5079145402627677], AbsoluteThickness[0.5], 
    LineBox[{{3.1103020074212386`, 3.881981735720313}, {2.85693251899886, 
     3.876643443297927}}]}, 
   {Hue[0.5088764298018306], AbsoluteThickness[0.5], 
    LineBox[{{2.85693251899886, 3.876643443297927}, {2.560981468826584, 
     3.843074845024079}}]}, 
   {Hue[0.5914368733967552], AbsoluteThickness[0.5], 
    LineBox[{{3.635951462874396, 2.9225293116933315`}, {3.6825283869697825`, 
     2.853438104139769}}]}, 
   {Hue[0.591915160455997], AbsoluteThickness[0.5], 
    LineBox[{{3.6825283869697825`, 2.853438104139769}, {3.832923973619446, 
     2.644918583887245}}]}, 
   {Hue[0.6254434332189004], AbsoluteThickness[0.5], 
    LineBox[{{4.044295943175192, 0.8836757660057404}, {4.113383847834265, 
     0.819032005744157}}]}, 
   {Hue[0.6259358897846993], AbsoluteThickness[0.5], 
    LineBox[{{4.113383847834265, 0.819032005744157}, {4.35493863644751, 
     0.6086230018350616}}]}, 
   {Hue[0.6208758698191951], AbsoluteThickness[0.5], 
    LineBox[{{3.2772725092471884`, 3.4298303791992506`}, {3.3531600164170454`,
      3.4758804600273105`}}]}, 
   {Hue[0.6216179458648723], AbsoluteThickness[0.5], 
    LineBox[{{3.3531600164170454`, 3.4758804600273105`}, {3.6131952360076776`,
      3.608659079634274}}]}, 
   {Hue[0.6450778965779635], AbsoluteThickness[0.5], 
    LineBox[{{2.6252884179580267`, 3.6109302304574373`}, {2.6263445052290515`,
      3.614290394733925}}]}, 
   {Hue[0.6455541542411756], AbsoluteThickness[0.5], 
    LineBox[{{2.6263445052290515`, 3.614290394733925}, {2.740157001677315, 
     3.94058241462153}}]}, 
   {Hue[0.3937643655322037], AbsoluteThickness[0.5], 
    LineBox[{{3.603609521882085, 0.8721000717030405}, {3.618149347167909, 
     0.8632235857285788}}]}, 
   {Hue[0.3941918596656482], AbsoluteThickness[0.5], 
    LineBox[{{3.618149347167909, 0.8632235857285788}, {3.887144540448363, 
     0.7010956890538372}}]}, 
   {Hue[0.6279903847198999], AbsoluteThickness[0.5], 
    LineBox[{{4.263161493768721, 1.9156302880606486`}, {4.376023012578823, 
     1.9635090362327425`}}]}, 
   {Hue[0.6285138080669109], AbsoluteThickness[0.5], 
    LineBox[{{4.376023012578823, 1.9635090362327425`}, {4.6652295836195075`, 
     2.071868419976779}}]}, 
   {Hue[0.47552840305668537`], AbsoluteThickness[0.5], 
    LineBox[{{4.424160597144562, 1.8436247799949024`}, {4.563431402034506, 
     1.722549253047222}}]}, 
   {Hue[0.4763546639131082], AbsoluteThickness[0.5], 
    LineBox[{{4.563431402034506, 1.722549253047222}, {4.7793265659589705`, 
     1.5636776737617692`}}]}, 
   {Hue[0.6627763084358633], AbsoluteThickness[0.5], 
    LineBox[{{4.430050381438902, 1.6673556252326556`}, {4.355952381765815, 
     1.3906682770786762`}}]}, 
   {Hue[0.6633801234775932], AbsoluteThickness[0.5], 
    LineBox[{{4.355952381765815, 1.3906682770786762`}, {4.264069245203251, 
     1.1117877497606905`}}]}, 
   {Hue[0.4970095195791338], AbsoluteThickness[0.5], 
    LineBox[{{3.8617675529751447`, 3.411078761149382}, {3.8992767578767955`, 
     3.4321466079274052`}}]}, 
   {Hue[0.497541204865414], AbsoluteThickness[0.5], 
    LineBox[{{3.8992767578767955`, 3.4321466079274057`}, {4.13809054093353, 
     3.580598350901521}}]}, 
   {Hue[0.6862866052246402], AbsoluteThickness[0.5], 
    LineBox[{{1.932100564987038, -0.21276101865270092`}, {
     1.9451369549030761`, -0.30226379967990635`}}]}, 
   {Hue[0.6867489613181472], AbsoluteThickness[0.5], 
    LineBox[{{1.9451369549030761`, -0.30226379967990635`}, {
     1.9982837505427073`, -0.6096716244455257}}]}, 
   {Hue[0.4307248841574314], AbsoluteThickness[0.5], 
    LineBox[{{5.184589124164372, 2.5647269759197044`}, {5.268241675928239, 
     2.5897217576025935`}}]}, 
   {Hue[0.4658657710364045], AbsoluteThickness[0.5], 
    LineBox[{{5.268241675928239, 2.5897217576025935`}, {5.378824022427172, 
     2.672785156720405}}]}, 
   {Hue[0.5903140056049029], AbsoluteThickness[0.5], 
    LineBox[{{5.378824022427172, 2.672785156720405}, {5.361972014576235, 
     2.8100585826323665`}}]}, 
   {Hue[0.49560866523836], AbsoluteThickness[0.5], 
    LineBox[{{5.668920925154639, 0.5063884424531362}, {5.747629279287962, 
     0.327623274558306}}]}, 
   {Hue[0.49717035771531937`], AbsoluteThickness[0.5], 
    LineBox[{{5.747629279287962, 0.327623274558306}, {5.799207899309057, 
     0.15534769777414545`}}]}, 
   {Hue[0.6065026410027916], AbsoluteThickness[0.5], 
    LineBox[{{5.797415686478516, -2.882206781209404}, {
     5.853773011255052, -2.9021946621979535`}}]}, 
   {Hue[0.606966644027798], AbsoluteThickness[0.5], 
    LineBox[{{5.853773011255052, -2.9021946621979535`}, {
     6.17749837761565, -3.026997289917003}}]}, 
   {Hue[0.5365892280646374], AbsoluteThickness[0.5], 
    LineBox[{{6.236722713600695, -1.9120382929352815`}, {
     6.374758637244785, -2.089673921766283}}]}, 
   {Hue[0.5499461678178552], AbsoluteThickness[0.5], 
    LineBox[{{6.374758637244785, -2.089673921766283}, {
     6.442920364339203, -2.257053807437599}}]}, 
   {Hue[0.6488967892903943], AbsoluteThickness[0.5], 
    LineBox[{{1.894501854931514, -3.0650714899861677`}, {
     1.869940708520334, -3.376463733925282}}]}, 
   {Hue[0.6509022923462252], AbsoluteThickness[0.5], 
    LineBox[{{1.869940708520334, -3.376463733925282}, {
     1.884126463978585, -3.607707500040743}}]}, 
   {Hue[0.4352559137851214], AbsoluteThickness[0.5], 
    LineBox[{{2.147409975784109, 3.3369807739887647`}, {2.114275358125566, 
     3.399484320631064}}]}, 
   {Hue[0.43576060385159493`], AbsoluteThickness[0.5], 
    LineBox[{{2.114275358125566, 3.399484320631064}, {1.9676454627333546`, 
     3.6520256982094352`}}]}, 
   {Hue[0.6239581332092432], AbsoluteThickness[0.5], 
    LineBox[{{2.9693614755620596`, 0.8228681422826606}, {2.8865883325605624`, 
     0.8219183058855372}}]}, 
   {Hue[0.624937288918799], AbsoluteThickness[0.5], 
    LineBox[{{2.8865883325605624`, 0.8219183058855372}, {2.6118063006772863`, 
     0.7930794628040901}}]}, 
   {Hue[0.5605999535659486], AbsoluteThickness[0.5], 
    LineBox[{{3.6125517004921526`, 3.2469401059536245`}, {3.5291902180439294`,
      3.310730954394445}}]}, 
   {Hue[0.5622831694744684], AbsoluteThickness[0.5], 
    LineBox[{{3.5291902180439294`, 3.310730954394445}, {3.3534855206748517`, 
     3.4851966960567613`}}]}, 
   {Hue[0.6079983460800058], AbsoluteThickness[0.5], 
    LineBox[{{4.59620343551852, 1.6084972361415986`}, {4.548075774922849, 
     1.587470818743765}}]}, 
   {Hue[0.6118157709790062], AbsoluteThickness[0.5], 
    LineBox[{{4.548075774922849, 1.587470818743765}, {4.406209685955791, 
     1.4916078221493894`}}]}, 
   {Hue[0.6216914386590977], AbsoluteThickness[0.5], 
    LineBox[{{4.983121121773206, 2.417902245095984}, {4.647948696892337, 
     2.463053678099788}}]}, 
   {Hue[0.6221293792025169], AbsoluteThickness[0.5], 
    LineBox[{{4.647948696892337, 2.463053678099788}, {4.336046545093241, 
     2.500193357220387}}]}, 
   {Hue[0.5982464362782777], AbsoluteThickness[0.5], 
    LineBox[{{6.141541667929228, 2.6284119161447648`}, {6.1409933321549195`, 
     2.6278529358494613`}}]}, 
   {Hue[0.5987021082688903], AbsoluteThickness[0.5], 
    LineBox[{{6.1409933321549195`, 2.6278529358494613`}, {5.9161068560005745`,
      2.387293085158171}}]}, 
   {Hue[0.5764431766990084], AbsoluteThickness[0.5], 
    LineBox[{{7.043745709615809, 3.240703592082571}, {6.89305343023182, 
     3.28783919740285}}]}, 
   {Hue[0.5769229207244744], AbsoluteThickness[0.5], 
    LineBox[{{6.89305343023182, 3.28783919740285}, {6.639234003826936, 
     3.3583688626671555`}}]}, 
   {Hue[0.05237157828008196], AbsoluteThickness[0.5], 
    LineBox[{{7.330620812462799, 3.381017786499221}, {7.38636086643582, 
     3.404803723882367}}]}, 
   {Hue[0.05280883714290435], AbsoluteThickness[0.5], 
    LineBox[{{7.38636086643582, 3.404803723882367}, {7.666193767785579, 
     3.52919447728847}}]}, 
   {Hue[0.6050650299705228], AbsoluteThickness[0.5], 
    LineBox[{{7.666193767785579, 3.52919447728847}, {7.366268648274585, 
     3.4673524616593014`}}]}, 
   {Hue[0.5775858295434471], AbsoluteThickness[0.5], 
    LineBox[{{7.203497340519563, 3.0880587097165377`}, {7.165402091607253, 
     3.0113562549571933`}}]}, 
   {Hue[0.5789570439485763], AbsoluteThickness[0.5], 
    LineBox[{{7.165402091607253, 3.0113562549571933`}, {7.048221893017178, 
     2.8310875099772495`}}]}, 
   {Hue[0.6008557544017686], AbsoluteThickness[0.5], 
    LineBox[{{5.854541211793543, 2.947670279957346}, {5.609672078993629, 
     2.9709412019837855`}}]}, 
   {Hue[0.6012821056196744], AbsoluteThickness[0.5], 
    LineBox[{{5.609672078993629, 2.9709412019837855`}, {5.294341901364093, 
     3.0019049963830016`}}]}, 
   {Hue[0.6066297262138488], AbsoluteThickness[0.5], 
    LineBox[{{5.61090457888218, 2.136146777226175}, {5.609135375186374, 
     2.133709508028887}}]}, 
   {Hue[0.607055719748679], AbsoluteThickness[0.5], 
    LineBox[{{5.609135375186374, 2.133709508028887}, {5.470728206406311, 
     1.9423718551389946`}}]}, 
   {Hue[0.580812744245154], AbsoluteThickness[0.5], 
    LineBox[{{4.3696117486724635`, 2.984976510060298}, {3.9344059201199726`, 
     3.187157995411366}}]}, 
   {Hue[0.5812388274034886], AbsoluteThickness[0.5], 
    LineBox[{{3.9344059201199726`, 3.187157995411366}, {3.6268088513745607`, 
     3.3308527342946896`}}]}, 
   {Hue[0.6722875000130758], AbsoluteThickness[0.5], 
    LineBox[{{5.277118089101512, 0.6096149376742391}, {5.304304755912163, 
     0.37732228564114645`}}]}, 
   {Hue[0.6734867758729691], AbsoluteThickness[0.5], 
    LineBox[{{5.304304755912163, 0.37732228564114645`}, {5.306827145722862, 
     0.12108862840882945`}}]}, 
   {Hue[0.6110078561115727], AbsoluteThickness[0.5], 
    LineBox[{{4.101790137821902, 0.7004063079262833}, {4.083073079714961, 
     0.6866587036183337}}]}, 
   {Hue[0.611568513626107], AbsoluteThickness[0.5], 
    LineBox[{{4.083073079714961, 0.6866587036183337}, {3.8415017106892604`, 
     0.4899999001266035}}]}, 
   {Hue[0.5988638947080757], AbsoluteThickness[0.5], 
    LineBox[{{2.62755756444237, 0.09988456246365594}, {2.6227900508772657`, 
     0.09348760098079673}}]}, 
   {Hue[0.5993496005933556], AbsoluteThickness[0.5], 
    LineBox[{{2.6227900508772657`, 0.09348760098079673}, {
     2.413468058204143, -0.16842042657828155`}}]}, 
   {Hue[0.6157934522008124], AbsoluteThickness[0.5], 
    LineBox[{{4.947026905438245, -1.1210298670953103`}, {
     4.969408956651143, -1.3291631692945394`}}]}, 
   {Hue[0.616342297595284], AbsoluteThickness[0.5], 
    LineBox[{{4.969408956651143, -1.3291631692945394`}, {
     5.010987358099255, -1.5956176613335031`}}]}, 
   {Hue[0.41684400536627175`], AbsoluteThickness[0.5], 
    LineBox[{{6.654473890816603, -0.007868303307741062}, {6.9218421862591475`,
      0.06088854234429891}}]}, 
   {Hue[0.4174101035340442], AbsoluteThickness[0.5], 
    LineBox[{{6.9218421862591475`, 0.06088854234429891}, {7.136449877648672, 
     0.10461849948909832`}}]}, 
   {Hue[0.6447278261163958], AbsoluteThickness[0.5], 
    LineBox[{{6.012425319489084, 1.1229967747523133`}, {6.075104392386629, 
     1.1878101069943345`}}]}, 
   {Hue[0.6452011137521333], AbsoluteThickness[0.5], 
    LineBox[{{6.075104392386629, 1.1878101069943345`}, {6.29468685449111, 
     1.4015657347808643`}}]}, 
   {Hue[0.6121140987472722], AbsoluteThickness[0.5], 
    LineBox[{{4.422663080900482, -1.5853938271299113`}, {
     4.424108395377657, -1.8695045837320294`}}]}, 
   {Hue[0.6127408744217911], AbsoluteThickness[0.5], 
    LineBox[{{4.424108395377657, -1.8695045837320294`}, {
     4.443895978058326, -2.173839036070645}}]}, 
   {Hue[0.5880165411225748], AbsoluteThickness[0.5], 
    LineBox[{{6.827031107400988, -0.5523480277152938}, {
     6.856925272870647, -0.6852680787100127}}]}, 
   {Hue[0.5900840720957913], AbsoluteThickness[0.5], 
    LineBox[{{6.856925272870647, -0.6852680787100127}, {
     6.873615815093204, -0.8953709276138526}}]}, 
   {Hue[0.31210975765304094`], AbsoluteThickness[0.5], 
    LineBox[{{7.019232425682434, -0.6051126402023993}, {
     7.1253321080338905`, -0.6107547076337472}}]}, 
   {Hue[0.3141348639939495], AbsoluteThickness[0.5], 
    LineBox[{{7.1253321080338905`, -0.6107547076337472}, {
     7.3916018672745745`, -0.6629960700416081}}]}, 
   {Hue[0.6001959074312342], AbsoluteThickness[0.5], 
    LineBox[{{7.1220950596559565`, -0.4343943646368669}, {
     7.136030098092374, -0.3933736901895336}}]}, 
   {Hue[0.6008110484506446], AbsoluteThickness[0.5], 
    LineBox[{{7.136030098092374, -0.3933736901895336}, {
     7.241714821620361, -0.1330966704720473}}]}, 
   {Hue[0.5867971838456734], AbsoluteThickness[0.5], 
    LineBox[{{5.884755934411642, -0.22025372318985614`}, {
     5.9399294410506425`, -0.13187278997100665`}}]}, 
   {Hue[0.5872248018817146], AbsoluteThickness[0.5], 
    LineBox[{{5.9399294410506425`, -0.13187278997100665`}, {6.122211200392516,
      0.16398874459733975`}}]}, 
   {Hue[0.3998807890121273], AbsoluteThickness[0.5], 
    LineBox[{{5.416970456311492, -3.304622315953623}, {
     5.485493744790768, -3.3543042182709204`}}]}, 
   {Hue[0.40241665354090256`], AbsoluteThickness[0.5], 
    LineBox[{{5.485493744790768, -3.3543042182709204`}, {
     5.6489191178851, -3.516797679149116}}]}, 
   {Hue[0.5312222266124458], AbsoluteThickness[0.5], 
    LineBox[{{6.602749596928553, 0.5200804979799486}, {6.775433554894894, 
     0.5671738841150324}}]}, 
   {Hue[0.5530602844316358], AbsoluteThickness[0.5], 
    LineBox[{{6.775433554894894, 0.5671738841150324}, {6.927572078853873, 
     0.666856819207575}}]}, 
   {Hue[0.5994365447595816], AbsoluteThickness[0.5], 
    LineBox[{{6.639539576810848, -0.04394817989919969}, {
     7.410340891620723, -0.14384438859855914`}}]}, 
   {Hue[0.6011437217165481], AbsoluteThickness[0.5], 
    LineBox[{{7.410340891620723, -0.14384438859855914`}, {
     7.629224775075198, -0.1436887610897335}}]}, 
   {Hue[0.6534243277951486], AbsoluteThickness[0.5], 
    LineBox[{{6.157417571799584, 1.8853694178921672`}, {6.328523004809647, 
     2.0608312306801357`}}]}, 
   {Hue[0.6567216889553308], AbsoluteThickness[0.5], 
    LineBox[{{6.328523004809647, 2.0608312306801357`}, {6.450055413653725, 
     2.238357003868196}}]}, 
   {Hue[0.5381251918301759], AbsoluteThickness[0.5], 
    LineBox[{{5.666622839602663, -4.459780914985501}, {
     5.821347775019696, -4.591212369900724}}]}, 
   {Hue[0.541486316533777], AbsoluteThickness[0.5], 
    LineBox[{{5.821347775019696, -4.591212369900724}, {
     6.019513175547149, -4.707421513073869}}]}, 
   {Hue[0.696421756775964], AbsoluteThickness[0.5], 
    LineBox[{{6.041601846714769, 1.6769422552901756`}, {6.114181697599858, 
     1.7637326844502292`}}]}, 
   {Hue[0.4682469537619751], AbsoluteThickness[0.5], 
    LineBox[{{3.360414554769831, -4.387812187466024}, {
     3.3628281185192015`, -4.400972176947664}}]}, 
   {Hue[0.468805131570648], AbsoluteThickness[0.5], 
    LineBox[{{3.3628281185192015`, -4.400972176947664}, {
     3.4368728465648415`, -4.7161871904857255`}}]}, 
   {Hue[0.6302676335273653], AbsoluteThickness[0.5], 
    LineBox[{{5.673702084602934, 2.568762910703068}, {6.0632670650185165`, 
     2.852256932105827}}]}, 
   {Hue[0.6348148545221193], AbsoluteThickness[0.5], 
    LineBox[{{6.0632670650185165`, 2.852256932105827}, {6.254706340892061, 
     2.9411670623727795`}}]}, 
   {Hue[0.34479558229612883`], AbsoluteThickness[0.5], 
    LineBox[{{2.35630424816141, 3.1013958181243013`}, {2.3561960067740184`, 
     3.1021377290484113`}}]}, 
   {Hue[0.3453985957080754], AbsoluteThickness[0.5], 
    LineBox[{{2.3561960067740184`, 3.1021377290484113`}, {2.2973116542492193`,
      3.3906040559269304`}}]}, 
   {Hue[0.3711754162447981], AbsoluteThickness[0.5], 
    LineBox[{{4.1633701963243706`, 3.444647573041544}, {4.174925218812607, 
     3.5855701655019057`}}]}, 
   {Hue[0.37167769875295453`], AbsoluteThickness[0.5], 
    LineBox[{{4.174925218812607, 3.5855701655019057`}, {4.208956812216446, 
     3.8682017652783203`}}]}, 
   {Hue[0.5162096642530689], AbsoluteThickness[0.5], 
    LineBox[{{3.592404676609603, -1.6552666739159938`}, {
     3.5004082124758993`, -1.8542549197067482`}}]}, 
   {Hue[0.5169672774010636], AbsoluteThickness[0.5], 
    LineBox[{{3.5004082124758993`, -1.8542549197067482`}, {
     3.416908937667367, -2.0773186617771313`}}]}, 
   {Hue[0.5254565766296123], AbsoluteThickness[0.5], 
    LineBox[{{5.201093626560587, -1.413143781985224}, {
     5.278878885979814, -1.546493769077216}}]}, 
   {Hue[0.5263433254161086], AbsoluteThickness[0.5], 
    LineBox[{{5.278878885979814, -1.546493769077216}, {
     5.403174721065136, -1.809271014201979}}]}, 
   {Hue[0.5504077167314557], AbsoluteThickness[0.5], 
    LineBox[{{4.696866315528102, 1.414058019276986}, {4.664665849048992, 
     1.4651548145793216`}}]}, 
   {Hue[0.5547798854915668], AbsoluteThickness[0.5], 
    LineBox[{{4.664665849048992, 1.4651548145793216`}, {4.55004205643889, 
     1.5872324625062781`}}]}, 
   {Hue[0.5918203190704199], AbsoluteThickness[0.5], 
    LineBox[{{5.923453268094582, -0.12141023291613232`}, {
     6.051520528696543, -0.3024842681796183}}]}, 
   {Hue[0.5967710454345805], AbsoluteThickness[0.5], 
    LineBox[{{6.051520528696543, -0.3024842681796183}, {
     6.202472105974226, -0.4445321588679984}}]}, 
   {Hue[0.42347683736764746`], AbsoluteThickness[0.5], 
    LineBox[{{6.385268158618309, 0.22161067645512722`}, {6.470037766440813, 
     0.19285746415560245`}}]}, 
   {Hue[0.4275205184640772], AbsoluteThickness[0.5], 
    LineBox[{{6.470037766440813, 0.19285746415560245`}, {6.6501224423531555`, 
     0.09134997331876671}}]}, 
   {Hue[0.6073343424099418], AbsoluteThickness[0.5], 
    LineBox[{{6.419193823879621, 0.7857087240698564}, {6.4819936840200905`, 
     0.8591638627784808}}]}, 
   {Hue[0.6087653722945185], AbsoluteThickness[0.5], 
    LineBox[{{6.4819936840200905`, 0.8591638627784808}, {6.63011922812077, 
     1.0807950254742982`}}]}, 
   {Hue[0.3001168923247511], AbsoluteThickness[0.5], 
    LineBox[{{6.4275712886359875`, 0.699587138935426}, {6.620741939951525, 
     0.6493928246011168}}]}, 
   {Hue[0.3016148529201651], AbsoluteThickness[0.5], 
    LineBox[{{6.620741939951525, 0.6493928246011168}, {6.888291722798584, 
     0.613578708379607}}]}, 
   {Hue[0.3225062095631], AbsoluteThickness[0.5], 
    LineBox[{{6.297678230151587, 1.0622960813322682`}, {6.282920638743464, 
     1.1330347389765494`}}]}, 
   {Hue[0.32300157439264826`], AbsoluteThickness[0.5], 
    LineBox[{{6.282920638743464, 1.1330347389765494`}, {6.210207727521903, 
     1.4276179776384996`}}]}, 
   {Hue[0.07069238507911363], AbsoluteThickness[0.5], 
    LineBox[{{6.443788578625388, 1.200149317012919}, {6.564379290859342, 
     1.2701401149547122`}}]}, 
   {Hue[0.07139015739235721], AbsoluteThickness[0.5], 
    LineBox[{{6.564379290859342, 1.2701401149547122`}, {6.827262885059063, 
     1.3995030840841007`}}]}, 
   {Hue[0.5764011923126022], AbsoluteThickness[0.5], 
    LineBox[{{6.827262885059063, 1.3995030840841007`}, {6.766857456221529, 
     1.1128085671356798`}}]}, 
   {Hue[0.33762034146764336`], AbsoluteThickness[0.5], 
    LineBox[{{6.620625327355075, 1.1048575922018204`}, {6.861695802697349, 
     0.8914085320417565}}]}, 
   {Hue[0.37289645919893866`], AbsoluteThickness[0.5], 
    LineBox[{{6.861695802697349, 0.8914085320417565}, {6.944582686502063, 
     0.7367137983151183}}]}, 
   {Hue[0.49701906891008635`], AbsoluteThickness[0.5], 
    LineBox[{{6.944582686502063, 0.7367137983151183}, {6.851871680841061, 
     0.5876991494414672}}]}, 
   {Hue[0.6211416786212351], AbsoluteThickness[0.5], 
    LineBox[{{6.851871680841061, 0.5876991494414672}, {6.676473013188744, 
     0.5936994440512137}}]}, 
   {Hue[0.6045482978561729], AbsoluteThickness[0.5], 
    LineBox[{{6.5858397908744095`, 0.9070149401509726}, {6.480426194911038, 
     0.6607772697633745}}]}, 
   {Hue[0.6050649232200082], AbsoluteThickness[0.5], 
    LineBox[{{6.480426194911038, 0.6607772697633745}, {6.390117073498233, 
     0.42316606725138245`}}]}, 
   {Hue[0.3165925170848544], AbsoluteThickness[0.5], 
    LineBox[{{5.614085241302615, 1.7933448910919676`}, {5.535348375932354, 
     1.9192674219450898`}}]}, 
   {Hue[0.3174308662532324], AbsoluteThickness[0.5], 
    LineBox[{{5.535348375932354, 1.9192674219450898`}, {5.44161162851695, 
     2.1008521793985264`}}]}, 
   {Hue[0.5763563608301597], AbsoluteThickness[0.5], 
    LineBox[{{5.361070255815992, 0.9066794641441657}, {5.309197783668218, 
     0.8926362136539916}}]}, 
   {Hue[0.5779990794100011], AbsoluteThickness[0.5], 
    LineBox[{{5.309197783668218, 0.8926362136539916}, {5.096987919537466, 
     0.8050340143317275}}]}, 
   {Hue[0.3948075581414312], AbsoluteThickness[0.5], 
    LineBox[{{5.54122112442311, 1.6611159737542394`}, {5.342307257353229, 
     2.094798132345371}}]}, 
   {Hue[0.3952670873257023], AbsoluteThickness[0.5], 
    LineBox[{{5.342307257353229, 2.094798132345371}, {5.196659372336918, 
     2.392077809593476}}]}, 
   {Hue[0.5483945540327839], AbsoluteThickness[0.5], 
    LineBox[{{4.65050019908954, -1.3571329430121755`}, {
     4.640340478095087, -1.3783432138620353`}}]}, 
   {Hue[0.5488809874796937], AbsoluteThickness[0.5], 
    LineBox[{{4.640340478095087, -1.3783432138620353`}, {
     4.504850056414801, -1.638153154138869}}]}, 
   {Hue[0.5386077411627357], AbsoluteThickness[0.5], 
    LineBox[{{3.610056072478961, 1.7534670973671465`}, {3.5435488419766474`, 
     1.8772587280253006`}}]}, 
   {Hue[0.5392364330648284], AbsoluteThickness[0.5], 
    LineBox[{{3.5435488419766474`, 1.8772587280253006`}, {3.441908484463648, 
     2.0971933654580392`}}]}, 
   {Hue[0.6878809414275642], AbsoluteThickness[0.5], 
    LineBox[{{3.202233651245524, 1.614315174749815}, {2.916391321683664, 
     1.711797429877743}}]}, 
   {Hue[0.6883137614141193], AbsoluteThickness[0.5], 
    LineBox[{{2.916391321683664, 1.711797429877743}, {2.62483621605374, 
     1.8150511819089745`}}]}, 
   {Hue[0.5994286148483877], AbsoluteThickness[0.5], 
    LineBox[{{4.157929058531749, 2.916356710767629}, {4.17474585598341, 
     3.120376342744016}}]}, 
   {Hue[0.5999672239938455], AbsoluteThickness[0.5], 
    LineBox[{{4.17474585598341, 3.120376342744016}, {4.219114605262637, 
     3.465115747956994}}]}, 
   {Hue[0.6123600497558016], AbsoluteThickness[0.5], 
    LineBox[{{4.613275787411451, -1.6515837840669534`}, {
     4.437591827242721, -1.8634286238119815`}}]}, 
   {Hue[0.616677102664721], AbsoluteThickness[0.5], 
    LineBox[{{4.437591827242721, -1.8634286238119815`}, {
     4.336060454326416, -2.048563542978325}}]}, 
   {Hue[0.40367843265825853`], AbsoluteThickness[0.5], 
    LineBox[{{4.65185905915806, -1.815237145749338}, {
     4.808589223863012, -2.1089476939262584`}}]}, 
   {Hue[0.404865827189591], AbsoluteThickness[0.5], 
    LineBox[{{4.808589223863012, -2.1089476939262584`}, {
     4.89730892546485, -2.328408717485419}}]}, 
   {Hue[0.6343390609713644], AbsoluteThickness[0.5], 
    LineBox[{{4.817938396125092, -1.8414811066014845`}, {
     5.120528191874583, -1.8105331388097257`}}]}, 
   {Hue[0.6349981208529982], AbsoluteThickness[0.5], 
    LineBox[{{5.120528191874583, -1.8105331388097257`}, {
     5.425596819191235, -1.7594386651443743`}}]}, 
   {Hue[0.6781284279423432], AbsoluteThickness[0.5], 
    LineBox[{{3.4833971172949005`, -2.676149004931926}, {
     3.3972955649728562`, -2.8295336764996963`}}]}, 
   {Hue[0.6833481597344899], AbsoluteThickness[0.5], 
    LineBox[{{3.3972955649728562`, -2.8295336764996963`}, {
     3.3377198487469006`, -3.0170515924032815`}}]}, 
   {Hue[0.664116580558938], AbsoluteThickness[0.5], 
    LineBox[{{3.9368108184635235`, -2.6420304169613367`}, {
     3.971857544864544, -2.918775324563714}}]}, 
   {Hue[0.664648900758553], AbsoluteThickness[0.5], 
    LineBox[{{3.971857544864544, -2.918775324563714}, {
     4.0163239959262445`, -3.177042364698447}}]}, 
   {Hue[0.3711878208267532], AbsoluteThickness[0.5], 
    LineBox[{{6.0510234328383525`, -1.6118724155983193`}, {
     6.434570421969874, -1.6211309129653566`}}]}, 
   {Hue[0.3725139673060588], AbsoluteThickness[0.5], 
    LineBox[{{6.434570421969874, -1.6211309129653566`}, {
     6.656058319055695, -1.6013410460322093`}}]}, 
   {Hue[0.6518317451937797], AbsoluteThickness[0.5], 
    LineBox[{{4.770064234682562, 1.4154639452741689`}, {4.750234635371748, 
     1.5541254613962177`}}]}, 
   {Hue[0.6522619435183232], AbsoluteThickness[0.5], 
    LineBox[{{4.750234635371748, 1.5541254613962177`}, {4.703790114254977, 
     1.8587686157399164`}}]}, 
   {Hue[0.6364395950579798], AbsoluteThickness[0.5], 
    LineBox[{{6.581487511470669, -1.8373894688593146`}, {
     6.606697459070814, -1.8337166829072054`}}]}, 
   {Hue[0.6371734622981889], AbsoluteThickness[0.5], 
    LineBox[{{6.606697459070814, -1.8337166829072054`}, {
     6.851715824070499, -1.7796608853611917`}}]}, 
   {Hue[0.5189018551330516], AbsoluteThickness[0.5], 
    LineBox[{{7.376648486803633, -2.1930786687527424`}, {
     7.615636654223439, -2.2059174345786943`}}]}, 
   {Hue[0.5193822489496404], AbsoluteThickness[0.5], 
    LineBox[{{7.615636654223439, -2.2059174345786943`}, {
     7.911138843765136, -2.231385724115977}}]}, 
   {Hue[0.6305075176860796], AbsoluteThickness[0.5], 
    LineBox[{{3.7722387829221264`, 1.9423148930827605`}, {3.8060166767685373`,
      2.1370361218739955`}}]}, 
   {Hue[0.635221391381427], AbsoluteThickness[0.5], 
    LineBox[{{3.8060166767685373`, 2.1370361218739955`}, {3.801874768326722, 
     2.3024910349631913`}}]}, 
   {Hue[0.5881562211653253], AbsoluteThickness[0.5], 
    LineBox[{{6.149841977810634, -4.4825159560340175`}, {
     6.379499916392318, -4.448650544547609}}]}, 
   {Hue[0.5890809433971649], AbsoluteThickness[0.5], 
    LineBox[{{6.379499916392318, -4.448650544547609}, {
     6.65142678716684, -4.433067663540734}}]}, 
   {Hue[0.5365498393393144], AbsoluteThickness[0.5], 
    LineBox[{{4.2706920586795425`, 0.9097669257236609}, {4.306650767283426, 
     1.1205681105017637`}}]}, 
   {Hue[0.5373543634539731], AbsoluteThickness[0.5], 
    LineBox[{{4.306650767283426, 1.1205681105017637`}, {4.371335710079582, 
     1.375755329449778}}]}, 
   {Hue[0.5269769053414611], AbsoluteThickness[0.5], 
    LineBox[{{5.169968565015996, 1.892845145460059}, {5.242624631635802, 
     2.061747409779511}}]}, 
   {Hue[0.5276113541194319], AbsoluteThickness[0.5], 
    LineBox[{{5.242624631635802, 2.061747409779511}, {5.377762976520847, 
     2.329701444635402}}]}, 
   {Hue[0.46150488344916557`], AbsoluteThickness[0.5], 
    LineBox[{{6.330560553127594, -3.848884068459315}, {
     6.3895125968559325`, -3.8846609770318636`}}]}, 
   {Hue[0.46201682679702116`], AbsoluteThickness[0.5], 
    LineBox[{{6.3895125968559325`, -3.8846609770318636`}, {
     6.654172447446525, -4.060227812306669}}]}, 
   {Hue[0.6283266027286646], AbsoluteThickness[0.5], 
    LineBox[{{2.6017292195545387`, -3.79214553215458}, {
     2.569998535097514, -3.885498868189024}}]}, 
   {Hue[0.6287629689198924], AbsoluteThickness[0.5], 
    LineBox[{{2.569998535097514, -3.885498868189024}, {
     2.4699506456783737`, -4.194327592707677}}]}, 
   {Hue[0.5551724853720607], AbsoluteThickness[0.5], 
    LineBox[{{4.535067203686278, -3.6182466200037733`}, {
     4.5586643982363615`, -3.8663665430204537`}}]}, 
   {Hue[0.5556826613324464], AbsoluteThickness[0.5], 
    LineBox[{{4.5586643982363615`, -3.8663665430204537`}, {
     4.574502971991735, -4.154234647857121}}]}, 
   {Hue[0.578950348189784], AbsoluteThickness[0.5], 
    LineBox[{{2.6225585474188384`, 1.112997775056993}, {2.380118737347767, 
     1.12373222437104}}]}, 
   {Hue[0.5797591512366622], AbsoluteThickness[0.5], 
    LineBox[{{2.380118737347767, 1.12373222437104}, {2.0930915371358, 
     1.1594866479186665`}}]}, 
   {Hue[0.5425543668951832], AbsoluteThickness[0.5], 
    LineBox[{{4.349044585260537, 0.10923644547303532`}, {
     4.273984222769974, -0.06171097009428422}}]}, 
   {Hue[0.543095288887507], AbsoluteThickness[0.5], 
    LineBox[{{4.273984222769974, -0.06171097009428422}, {
     4.152322038791029, -0.3776855619147659}}]}, 
   {Hue[0.5616060393719938], AbsoluteThickness[0.5], 
    LineBox[{{4.588889136609498, 0.344573347765463}, {4.503829950955594, 
     0.1809293765125139}}]}, 
   {Hue[0.5627930039975648], AbsoluteThickness[0.5], 
    LineBox[{{4.503829950955594, 0.1809293765125139}, {
     4.413847884344333, -0.04876934874106441}}]}, 
   {Hue[0.4419992777608266], AbsoluteThickness[0.5], 
    LineBox[{{5.86477877654838, 1.0979599403830935`}, {5.9125746001161925`, 
     1.0633278477270125`}}]}, 
   {Hue[0.44242702061540035`], AbsoluteThickness[0.5], 
    LineBox[{{5.9125746001161925`, 1.0633278477270125`}, {6.182106164247197, 
     0.8655105325882662}}]}, 
   {Hue[0.5326637528956191], AbsoluteThickness[0.5], 
    LineBox[{{5.440125870914012, 1.975955209914272}, {5.164765408893111, 
     1.9594440749707507`}}]}, 
   {Hue[0.5330971395919999], AbsoluteThickness[0.5], 
    LineBox[{{5.164765408893111, 1.9594440749707507`}, {4.906642608275437, 
     1.9471155537229472`}}]}, 
   {Hue[0.02212754305884199], AbsoluteThickness[0.5], 
    LineBox[{{5.5623011206984225`, 2.1533720115447528`}, {5.58917574795608, 
     2.1875585809746148`}}]}, 
   {Hue[0.02332858529778583], AbsoluteThickness[0.5], 
    LineBox[{{5.58917574795608, 2.1875585809746148`}, {5.721787506516539, 
     2.323506259434896}}]}, 
   {Hue[0.4735436969152517], AbsoluteThickness[0.5], 
    LineBox[{{5.721787506516539, 2.323506259434896}, {5.8128551426721735`, 
     2.156849920124739}}]}, 
   {Hue[0.5339680777326481], AbsoluteThickness[0.5], 
    LineBox[{{5.613847025178291, 1.9442152930487302`}, {5.636871336410821, 
     1.8165787645710376`}}]}, 
   {Hue[0.5346169162411903], AbsoluteThickness[0.5], 
    LineBox[{{5.636871336410821, 1.8165787645710376`}, {5.690004646627714, 
     1.6005894811625923`}}]}, 
   {Hue[0.4450402680861158], AbsoluteThickness[0.5], 
    LineBox[{{4.908669136179076, 1.993298348953123}, {4.4020405227289, 
     2.22225317369213}}]}, 
   {Hue[0.44552041136279436`], AbsoluteThickness[0.5], 
    LineBox[{{4.4020405227289, 2.22225317369213}, {4.1046091761300945`, 
     2.3452849795091817`}}]}, 
   {Hue[0.561443811976125], AbsoluteThickness[0.5], 
    LineBox[{{4.0979059816517305`, 1.2981347388234161`}, {3.9385300678630557`,
      1.2446306365495763`}}]}, 
   {Hue[0.5623734398762685], AbsoluteThickness[0.5], 
    LineBox[{{3.9385300678630557`, 1.2446306365495763`}, {3.6934624853434057`,
      1.186121574306045}}]}, 
   {Hue[0.5306510664634199], AbsoluteThickness[0.5], 
    LineBox[{{3.1035587515737224`, 1.7668587096786859`}, {2.9224897296714687`,
      1.8239651438094229`}}]}, 
   {Hue[0.5315178880828144], AbsoluteThickness[0.5], 
    LineBox[{{2.9224897296714687`, 1.8239651438094229`}, {2.6622370933964734`,
      1.882400810535004}}]}, 
   {Hue[0.5662830543434846], AbsoluteThickness[0.5], 
    LineBox[{{3.105797122138783, -0.3033703246874862}, {
     3.0762662504357596`, -0.3234804335666891}}]}, 
   {Hue[0.5669202879543397], AbsoluteThickness[0.5], 
    LineBox[{{3.0762662504357596`, -0.3234804335666891}, {
     2.8491339179551556`, -0.4994275905067842}}]}, 
   {Hue[0.49639960577699593`], AbsoluteThickness[0.5], 
    LineBox[{{4.959510765793979, -1.5757066790935146`}, {
     5.2046611478220575`, -2.0654112488838345`}}]}, 
   {Hue[0.4969507874612277], AbsoluteThickness[0.5], 
    LineBox[{{5.2046611478220575`, -2.0654112488838345`}, {
     5.334395925244653, -2.3590396185724534`}}]}, 
   {Hue[0.6132267109781815], AbsoluteThickness[0.5], 
    LineBox[{{4.376586172468551, -2.3100975164957145`}, {
     4.414417813612987, -2.3955209060655185`}}]}, 
   {Hue[0.6136693598647859], AbsoluteThickness[0.5], 
    LineBox[{{4.414417813612987, -2.3955209060655185`}, {
     4.539477099095544, -2.6646289125185705`}}]}, 
   {Hue[0.5733509757531715], AbsoluteThickness[0.5], 
    LineBox[{{2.8025887730608914`, -2.506908015202004}, {
     2.7721026438503973`, -2.577176443684453}}]}, 
   {Hue[0.5738353015565434], AbsoluteThickness[0.5], 
    LineBox[{{2.7721026438503973`, -2.577176443684453}, {
     2.6484390094968067`, -2.890484593255407}}]}, 
   {Hue[0.5286854928184247], AbsoluteThickness[0.5], 
    LineBox[{{4.473282129244128, -3.119055596895669}, {
     4.475751632044982, -3.2927970774573865`}}]}, 
   {Hue[0.5291176903032082], AbsoluteThickness[0.5], 
    LineBox[{{4.475751632044982, -3.2927970774573865`}, {
     4.484142604719942, -3.623348017930987}}]}, 
   {Hue[0.490673787567581], AbsoluteThickness[0.5], 
    LineBox[{{5.771450275177425, -2.4177698968320134`}, {
     5.795386472110417, -2.6641455480474665`}}]}, 
   {Hue[0.49201856263667854`], AbsoluteThickness[0.5], 
    LineBox[{{5.795386472110417, -2.6641455480474665`}, {
     5.791530589925796, -2.8869201373136533`}}]}, 
   {Hue[0.5606338029236105], AbsoluteThickness[0.5], 
    LineBox[{{5.018264684782464, -1.5967050714204696`}, {
     5.012698864542937, -1.8534597518632054`}}]}, 
   {Hue[0.561187063355852], AbsoluteThickness[0.5], 
    LineBox[{{5.012698864542937, -1.8534597518632054`}, {
     4.992084335219275, -2.146884224942067}}]}, 
   {Hue[0.5723553978399492], AbsoluteThickness[0.5], 
    LineBox[{{4.216668505879211, 0.12346079627919578`}, {4.18267379132616, 
     0.07187994812972015}}]}, 
   {Hue[0.5734120956220395], AbsoluteThickness[0.5], 
    LineBox[{{4.18267379132616, 0.07187994812972015}, {
     4.014121849651803, -0.13614123669336992`}}]}, 
   {Hue[0.4603066352465849], AbsoluteThickness[0.5], 
    LineBox[{{6.658700978555639, 1.5206143331109643`}, {6.721786931164236, 
     1.4336821793634298`}}]}, 
   {Hue[0.4611195410886266], AbsoluteThickness[0.5], 
    LineBox[{{6.721786931164236, 1.4336821793634298`}, {6.869550375697416, 
     1.1914323411561465`}}]}, 
   {Hue[0.31783201366113106`], AbsoluteThickness[0.5], 
    LineBox[{{5.442554220958551, 3.1481491532067367`}, {5.339271642832133, 
     3.2677948659245852`}}]}, 
   {Hue[0.320554195043768], AbsoluteThickness[0.5], 
    LineBox[{{5.339271642832133, 3.2677948659245852`}, {5.196690725453032, 
     3.3876020552150212`}}]}, 
   {Hue[0.6885851053426821], AbsoluteThickness[0.5], 
    LineBox[{{5.196690725453032, 3.3876020552150212`}, {5.069735205569932, 
     3.251347232997411}}]}, 
   {Hue[0.5516462926663591], AbsoluteThickness[0.5], 
    LineBox[{{5.543214711492126, 2.775848824839728}, {5.36657004310784, 
     2.803587444701125}}]}, 
   {Hue[0.5528526572902848], AbsoluteThickness[0.5], 
    LineBox[{{5.36657004310784, 2.803587444701125}, {5.14488508447451, 
     2.814393882361741}}]}, 
   {Hue[0.4980797459976138], AbsoluteThickness[0.5], 
    LineBox[{{6.32537628123876, 2.9714475727112744`}, {5.930670035657218, 
     3.298432250747103}}]}, 
   {Hue[0.499652398899822], AbsoluteThickness[0.5], 
    LineBox[{{5.930670035657218, 3.298432250747103}, {5.760770670023549, 
     3.406742873564329}}]}, 
   {Hue[0.037172488202310325`], AbsoluteThickness[0.5], 
    LineBox[{{6.547552688606352, 3.1259755122105775`}, {6.667757912857175, 
     3.1931177689322365`}}]}, 
   {Hue[0.03768989957518852], AbsoluteThickness[0.5], 
    LineBox[{{6.667757912857175, 3.1931177689322365`}, {6.888579848334961, 
     3.3287620282258708`}}]}, 
   {Hue[0.5729248910418544], AbsoluteThickness[0.5], 
    LineBox[{{6.888579848334961, 3.3287620282258708`}, {6.629521208981891, 
     3.3358552393470893`}}]}, 
   {Hue[0.5001952252155262], AbsoluteThickness[0.5], 
    LineBox[{{6.611394669557018, 2.8629822774212283`}, {6.611530601785223, 
     2.8620164736369595`}}]}, 
   {Hue[0.5009502029311346], AbsoluteThickness[0.5], 
    LineBox[{{6.611530601785223, 2.8620164736369595`}, {6.673267135335926, 
     2.578541564886991}}]}, 
   {Hue[0.5528797210157703], AbsoluteThickness[0.5], 
    LineBox[{{6.248113747025567, 2.061642590373633}, {6.2471821628492, 
     1.8813012525402426`}}]}, 
   {Hue[0.5533202243385278], AbsoluteThickness[0.5], 
    LineBox[{{6.2471821628492, 1.8813012525402426`}, {6.250904282396079, 
     1.5648940337397252`}}]}, 
   {Hue[0.32972993244568516`], AbsoluteThickness[0.5], 
    LineBox[{{6.919620978567895, 2.240441102465169}, {7.3288438986128135`, 
     1.9821780503081132`}}]}, 
   {Hue[0.3318492604956816], AbsoluteThickness[0.5], 
    LineBox[{{7.3288438986128135`, 1.9821780503081132`}, {7.558492112243443, 
     1.8797807286307913`}}]}, 
   {Hue[0.642552188237641], AbsoluteThickness[0.5], 
    LineBox[{{6.155879709729385, 1.8834726200982996`}, {6.135336901530586, 
     1.811124675976833}}]}, 
   {Hue[0.6555279966052777], AbsoluteThickness[0.5], 
    LineBox[{{6.135336901530586, 1.811124675976833}, {6.134454509787367, 
     1.6368769745609075`}}]}, 
   {Hue[0.457708890165502], AbsoluteThickness[0.5], 
    LineBox[{{4.081960773279959, 2.198169941148322}, {3.8242727079978507`, 
     2.1695168312246373`}}]}, 
   {Hue[0.45835574262805506`], AbsoluteThickness[0.5], 
    LineBox[{{3.8242727079978507`, 2.1695168312246373`}, {3.583730704152318, 
     2.1579012487626157`}}]}, 
   {Hue[0.6159280884200913], AbsoluteThickness[0.5], 
    LineBox[{{5.112731920695278, -0.06747369517184743}, {
     5.112445316505352, -0.13343842492420574`}}]}, 
   {Hue[0.6243607888286278], AbsoluteThickness[0.5], 
    LineBox[{{5.112445316505352, -0.13343842492420574`}, {
     5.160580187971834, -0.3351816282803301}}]}, 
   {Hue[0.5710879870533633], AbsoluteThickness[0.5], 
    LineBox[{{2.55793410054191, 0.2478274113179615}, {2.2752278492150846`, 
     0.1816984147699986}}]}, 
   {Hue[0.5777253511126733], AbsoluteThickness[0.5], 
    LineBox[{{2.2752278492150846`, 0.1816984147699986}, {2.131704988628372, 
     0.18043627869819978`}}]}, 
   {Hue[0.4890310385693956], AbsoluteThickness[0.5], 
    LineBox[{{2.3618405557934183`, 2.037142733359381}, {2.1547750807018176`, 
     2.080936120387664}}]}, 
   {Hue[0.48968489692093925`], AbsoluteThickness[0.5], 
    LineBox[{{2.1547750807018176`, 2.080936120387664}, {1.898566813819421, 
     2.1183619036996943`}}]}, 
   {Hue[0.5703433413708068], AbsoluteThickness[0.5], 
    LineBox[{{7.092177551255954, -4.125845364612247}, {
     7.094742595783512, -4.126561844566751}}]}, 
   {Hue[0.5708881363742545], AbsoluteThickness[0.5], 
    LineBox[{{7.094742595783512, -4.126561844566751}, {
     7.375166765175819, -4.219275662651597}}]}, 
   {Hue[0.6437095716218645], AbsoluteThickness[0.5], 
    LineBox[{{6.243677502779739, -0.9193412808091745}, {
     6.358059137715835, -1.0092334902937574`}}]}, 
   {Hue[0.6452222861174954], AbsoluteThickness[0.5], 
    LineBox[{{6.358059137715835, -1.0092334902937574`}, {
     6.5644794331739575`, -1.1341761338926948`}}]}, 
   {Hue[0.5178239024833117], AbsoluteThickness[0.5], 
    LineBox[{{6.918880804779869, 0.6508471416600876}, {7.173072686183387, 
     0.6658989238062495}}]}, 
   {Hue[0.5202090475578292], AbsoluteThickness[0.5], 
    LineBox[{{7.173072686183387, 0.6658989238062495}, {7.388403003789321, 
     0.711875681285104}}]}, 
   {Hue[0.48110206550611156`], AbsoluteThickness[0.5], 
    LineBox[{{6.139477083886224, 1.866099533602457}, {6.359200134119851, 
     1.973092128833142}}]}, 
   {Hue[0.48162792133534926`], AbsoluteThickness[0.5], 
    LineBox[{{6.359200134119851, 1.973092128833142}, {6.642143572427722, 
     2.0960407953271347`}}]}, 
   {Hue[0.30366456123121244`], AbsoluteThickness[0.5], 
    LineBox[{{6.1868978564583355`, 2.0491226747627462`}, {6.185748529403535, 
     2.0942138354376123`}}]}, 
   {Hue[0.3048074833495649], AbsoluteThickness[0.5], 
    LineBox[{{6.185748529403535, 2.0942138354376123`}, {6.206189280531699, 
     2.355743408486711}}]}, 
   {Hue[0.5095981154311641], AbsoluteThickness[0.5], 
    LineBox[{{6.040025914953818, 2.1681807810395077`}, {5.806953226079654, 
     2.2673219847615016`}}]}, 
   {Hue[0.5120217092146414], AbsoluteThickness[0.5], 
    LineBox[{{5.806953226079654, 2.2673219847615016`}, {5.646026875172219, 
     2.308400628916752}}]}, 
   {Hue[0.5398269511376518], AbsoluteThickness[0.5], 
    LineBox[{{4.263989323872711, 2.96088194936618}, {4.164822497154927, 
     3.125483974915391}}]}, 
   {Hue[0.5436866606528457], AbsoluteThickness[0.5], 
    LineBox[{{4.164822497154927, 3.125483974915391}, {4.081432225660939, 
     3.3476147222467385`}}]}, 
   {Hue[0.6622932497475927], AbsoluteThickness[0.5], 
    LineBox[{{4.991026902274692, 2.66486240934079}, {5.03122426982882, 
     2.836903047094465}}]}, 
   {Hue[0.6629597847899623], AbsoluteThickness[0.5], 
    LineBox[{{5.03122426982882, 2.836903047094465}, {5.079308969156486, 
     3.1264005343894525`}}]}, 
   {Hue[0.6097267790694489], AbsoluteThickness[0.5], 
    LineBox[{{3.118721016232729, -2.5828619436163174`}, {
     3.121273654555606, -2.624257375734634}}]}, 
   {Hue[0.6108266297348781], AbsoluteThickness[0.5], 
    LineBox[{{3.121273654555606, -2.624257375734634}, {
     3.1651919845681658`, -2.8921128139775836`}}]}, 
   {Hue[0.5977738423112041], AbsoluteThickness[0.5], 
    LineBox[{{5.9039533550722, -0.28769235118339}, {
     6.392839922891703, -0.6073075811485849}}]}, 
   {Hue[0.6005497324010843], AbsoluteThickness[0.5], 
    LineBox[{{6.392839922891703, -0.6073075811485849}, {
     6.603463194870228, -0.7008325084878011}}]}, 
   {Hue[0.6036170422026712], AbsoluteThickness[0.5], 
    LineBox[{{4.433552143658904, -0.2993283248884693}, {
     4.461830627412921, -0.38669067684197966`}}]}, 
   {Hue[0.6040455743311002], AbsoluteThickness[0.5], 
    LineBox[{{4.461830627412921, -0.38669067684197966`}, {
     4.557654897968823, -0.6902334873112135}}]}, 
   {Hue[0.5881204621250541], AbsoluteThickness[0.5], 
    LineBox[{{2.483143492607851, 0.3737766620517724}, {2.4608921338625533`, 
     0.15860318778510113`}}]}, 
   {Hue[0.5885965947573506], AbsoluteThickness[0.5], 
    LineBox[{{2.4608921338625533`, 0.15860318778510113`}, {
     2.4366708621308497`, -0.1772562880104147}}]}, 
   {Hue[0.5384587234275386], AbsoluteThickness[0.5], 
    LineBox[{{3.557687103684855, 2.3679185268949206`}, {3.612367763502233, 
     2.314338032433647}}]}, 
   {Hue[0.5388867362137825], AbsoluteThickness[0.5], 
    LineBox[{{3.612367763502233, 2.314338032433647}, {3.7992055211933065`, 
     2.1288553928966074`}}]}, 
   {Hue[0.6033643172899998], AbsoluteThickness[0.5], 
    LineBox[{{3.1910796081671067`, 0.9420935183745383}, {3.2043893665789605`, 
     0.8622227306716097}}]}, 
   {Hue[0.6038538564440757], AbsoluteThickness[0.5], 
    LineBox[{{3.2043893665789605`, 0.8622227306716097}, {3.2622496447919174`, 
     0.5767104367430875}}]}, 
   {Hue[0.5881444042021812], AbsoluteThickness[0.5], 
    LineBox[{{3.147559446731981, 0.12576724646237025`}, {3.159960814396034, 
     0.06580676059801213}}]}, 
   {Hue[0.5915099326829428], AbsoluteThickness[0.5], 
    LineBox[{{3.159960814396034, 0.06580676059801213}, {
     3.1664225351941844`, -0.1490562979243117}}]}, 
   {Hue[0.673098518727481], AbsoluteThickness[0.5], 
    LineBox[{{4.548095986003144, -3.0902889777521634`}, {
     4.616460235735505, -3.3466696876178688`}}]}, 
   {Hue[0.6780352620065105], AbsoluteThickness[0.5], 
    LineBox[{{4.616460235735505, -3.3466696876178688`}, {
     4.628983332378161, -3.553092014493604}}]}, 
   {Hue[0.545594764441777], AbsoluteThickness[0.5], 
    LineBox[{{5.2876892184364195`, -2.8886379161725055`}, {
     5.397340152732863, -3.01197332064043}}]}, 
   {Hue[0.547710558295979], AbsoluteThickness[0.5], 
    LineBox[{{5.397340152732863, -3.01197332064043}, {
     5.55351247328033, -3.143682286431134}}]}, 
   {Hue[0.5533165074212889], AbsoluteThickness[0.5], 
    LineBox[{{5.587650402673223, 2.1457227439160373`}, {5.601487793034783, 
     2.1510413036762666`}}]}, 
   {Hue[0.5537537138091984], AbsoluteThickness[0.5], 
    LineBox[{{5.601487793034783, 2.1510413036762666`}, {5.819384485417921, 
     2.2385446670767823`}}]}, 
   {Hue[0.43581212498405647`], AbsoluteThickness[0.5], 
    LineBox[{{7.0805021179439285`, -0.3412683309627705}, {
     7.10072211136499, -0.33914232151950796`}}]}, 
   {Hue[0.436291331687052], AbsoluteThickness[0.5], 
    LineBox[{{7.10072211136499, -0.33914232151950796`}, {
     7.39439141910835, -0.2987398054366874}}]}, 
   {Hue[0.3610387213521004], AbsoluteThickness[0.5], 
    LineBox[{{6.266322004214191, -1.9001236213218047`}, {
     6.346671465818868, -2.0739380598353474`}}]}, 
   {Hue[0.36271724163568503`], AbsoluteThickness[0.5], 
    LineBox[{{6.346671465818868, -2.0739380598353474`}, {
     6.421575284465714, -2.312268820533387}}]}, 
   {Hue[0.515051452689151], AbsoluteThickness[0.5], 
    LineBox[{{5.6591549305776745`, -1.8500765636884273`}, {
     5.700339713273538, -2.1110209990393427`}}]}, 
   {Hue[0.5154784378228285], AbsoluteThickness[0.5], 
    LineBox[{{5.700339713273538, -2.1110209990393427`}, {
     5.748222733078297, -2.4239958775671884`}}]}, 
   {Hue[0.6473788627189211], AbsoluteThickness[0.5], 
    LineBox[{{4.603813660107468, -1.712282706653468}, {
     4.526568675498383, -1.8540071432574061`}}]}, 
   {Hue[0.6478967060580308], AbsoluteThickness[0.5], 
    LineBox[{{4.526568675498383, -1.854007143257406}, {
     4.386231449035498, -2.139063828099931}}]}, 
   {Hue[0.5783126561368873], AbsoluteThickness[0.5], 
    LineBox[{{2.8366691762425877`, -4.411998077118915}, {
     2.840693768727832, -4.4561986464998}}]}, 
   {Hue[0.5837100650503357], AbsoluteThickness[0.5], 
    LineBox[{{2.840693768727832, -4.4561986464998}, {
     2.9010332091859445`, -4.653322088874905}}]}, 
   {Hue[0.5030981326151861], AbsoluteThickness[0.5], 
    LineBox[{{6.604283576296392, -0.08683293426488228}, {
     6.932980707187242, -0.008435963754079366}}]}, 
   {Hue[0.5035663170783425], AbsoluteThickness[0.5], 
    LineBox[{{6.932980707187242, -0.008435963754079366}, {7.153350389928379, 
     0.050821890047449365`}}]}, 
   {Hue[0.32547012860901564`], AbsoluteThickness[0.5], 
    LineBox[{{6.030754299574667, 3.1726312768189406`}, {6.115749137172537, 
     3.188925974826835}}]}, 
   {Hue[0.3258981231783121], AbsoluteThickness[0.5], 
    LineBox[{{6.115749137172537, 3.188925974826835}, {6.441750375671983, 
     3.253622803973537}}]}, 
   {Hue[0.600784174318691], AbsoluteThickness[0.5], 
    LineBox[{{3.8300739101308108`, 2.1886603027168055`}, {3.9128360935846356`,
      2.081934146757708}}]}, 
   {Hue[0.6012442836977735], AbsoluteThickness[0.5], 
    LineBox[{{3.9128360935846356`, 2.081934146757708}, {4.119628625037054, 
     1.828988438913347}}]}, 
   {Hue[0.606960186734396], AbsoluteThickness[0.5], 
    LineBox[{{2.830175844927783, 3.0537874034526507`}, {2.616619576882717, 
     2.9547408345934993`}}]}, 
   {Hue[0.6077897716079219], AbsoluteThickness[0.5], 
    LineBox[{{2.616619576882717, 2.9547408345934993`}, {2.358296061078627, 
     2.8596381184239403`}}]}, 
   {Hue[0.5074229269791867], AbsoluteThickness[0.5], 
    LineBox[{{3.6667702180398356`, 3.544143016451502}, {3.878934534114134, 
     3.45335226198859}}]}, 
   {Hue[0.5116999910552853], AbsoluteThickness[0.5], 
    LineBox[{{3.878934534114134, 3.45335226198859}, {4.062850046859226, 
     3.413332923529567}}]}, 
   {Hue[0.5098383193408932], AbsoluteThickness[0.5], 
    LineBox[{{2.560981468826584, 3.843074845024079}, {2.350158517056993, 
     3.7992797604980777`}}]}, 
   {Hue[0.5103819392749916], AbsoluteThickness[0.5], 
    LineBox[{{2.350158517056993, 3.7992797604980777`}, {2.071826526585228, 
     3.727757280076954}}]}, 
   {Hue[0.5923934475152388], AbsoluteThickness[0.5], 
    LineBox[{{3.832923973619446, 2.644918583887245}, {3.874172118149276, 
     2.5913896675360766`}}]}, 
   {Hue[0.5929753197387475], AbsoluteThickness[0.5], 
    LineBox[{{3.874172118149276, 2.5913896675360766`}, {4.080612067517458, 
     2.351119380027708}}]}, 
   {Hue[0.626428346350498], AbsoluteThickness[0.5], 
    LineBox[{{4.35493863644751, 0.6086230018350616}, {4.433519167029783, 
     0.544946451863507}}]}, 
   {Hue[0.6268660430894133], AbsoluteThickness[0.5], 
    LineBox[{{4.433519167029783, 0.544946451863507}, {4.644904950112239, 
     0.378923077217265}}]}, 
   {Hue[0.6223600219105496], AbsoluteThickness[0.5], 
    LineBox[{{3.6131952360076776`, 3.608659079634274}, {3.711658447001786, 
     3.6501485407197576`}}]}, 
   {Hue[0.6232333855577342], AbsoluteThickness[0.5], 
    LineBox[{{3.711658447001786, 3.6501485407197576`}, {3.949547455523821, 
     3.775196753992091}}]}, 
   {Hue[0.39461935379909274`], AbsoluteThickness[0.5], 
    LineBox[{{3.887144540448363, 0.7010956890538372}, {3.911468427407236, 
     0.6866231743336588}}]}, 
   {Hue[0.3952747054368135], AbsoluteThickness[0.5], 
    LineBox[{{3.911468427407236, 0.6866231743336588}, {4.16008456639786, 
     0.5164298020164279}}]}, 
   {Hue[0.6290372314139219], AbsoluteThickness[0.5], 
    LineBox[{{4.6652295836195075`, 2.071868419976779}, {5.07558438060904, 
     2.2059284542628754`}}]}, 
   {Hue[0.629485923151569], AbsoluteThickness[0.5], 
    LineBox[{{5.07558438060904, 2.2059284542628754`}, {5.39401071867388, 
     2.3025743134912293`}}]}, 
   {Hue[0.47718092476953106`], AbsoluteThickness[0.5], 
    LineBox[{{4.7793265659589705`, 1.5636776737617692`}, {4.835819138464659, 
     1.5287945320006096`}}]}, 
   {Hue[0.47771950262233465`], AbsoluteThickness[0.5], 
    LineBox[{{4.835819138464659, 1.5287945320006096`}, {5.11639912409441, 
     1.3727973890021872`}}]}, 
   {Hue[0.663983938519323], AbsoluteThickness[0.5], 
    LineBox[{{4.264069245203251, 1.1117877497606905`}, {4.175232201306691, 
     0.8860179519405613}}]}, 
   {Hue[0.6661995848922061], AbsoluteThickness[0.5], 
    LineBox[{{4.175232201306691, 0.8860179519405613}, {4.121700246132638, 
     0.6557821780153458}}]}, 
   {Hue[0.49807289015169404`], AbsoluteThickness[0.5], 
    LineBox[{{4.13809054093353, 3.580598350901521}, {4.157611475341534, 
     3.5939697469454672`}}]}, 
   {Hue[0.49868954009124034`], AbsoluteThickness[0.5], 
    LineBox[{{4.157611475341534, 3.5939697469454672`}, {4.37296435057171, 
     3.7607669830503565`}}]}, 
   {Hue[0.6872113174116541], AbsoluteThickness[0.5], 
    LineBox[{{1.9982837505427073`, -0.6096716244455256}, {
     2.0449042094700456`, -0.8423414975464287}}]}, 
   {Hue[0.6880913590528934], AbsoluteThickness[0.5], 
    LineBox[{{2.0449042094700456`, -0.8423414975464287}, {
     2.081693283977317, -1.169304508066604}}]}, 
   {Hue[0.5551731187259339], AbsoluteThickness[0.5], 
    LineBox[{{5.268241675928239, 2.5897217576025935`}, {5.362922067393716, 
     2.5849272637875544`}}]}, 
   {Hue[0.5557513701400077], AbsoluteThickness[0.5], 
    LineBox[{{5.362922067393716, 2.5849272637875544`}, {5.67898607833694, 
     2.5521651430028407`}}]}, 
   {Hue[0.5010066579153792], AbsoluteThickness[0.5], 
    LineBox[{{5.378824022427172, 2.672785156720405}, {5.483115079832187, 
     2.8345385977302273`}}]}, 
   {Hue[0.5023013398079824], AbsoluteThickness[0.5], 
    LineBox[{{5.483115079832187, 2.8345385977302273`}, {5.594806016273934, 
     3.0594086291919242`}}]}, 
   {Hue[0.6254548924838782], AbsoluteThickness[0.5], 
    LineBox[{{5.361972014576235, 2.8100585826323665`}, {5.2034771345762865`, 
     3.117467837928067}}]}, 
   {Hue[0.6261085205605894], AbsoluteThickness[0.5], 
    LineBox[{{5.2034771345762865`, 3.117467837928067}, {5.104605520113022, 
     3.3432878158281074`}}]}, 
   {Hue[0.4987320501922788], AbsoluteThickness[0.5], 
    LineBox[{{5.799207899309057, 0.15534769777414542`}, {
     5.8569773786551345`, -0.1872382257506345}}]}, 
   {Hue[0.5006150070557034], AbsoluteThickness[0.5], 
    LineBox[{{5.8569773786551345`, -0.1872382257506345}, {
     5.863187908244088, -0.3865853464737124}}]}, 
   {Hue[0.6074306470528041], AbsoluteThickness[0.5], 
    LineBox[{{6.17749837761565, -3.026997289917003}, {
     6.3331787543959255`, -3.0919205841110893`}}]}, 
   {Hue[0.6087848516282282], AbsoluteThickness[0.5], 
    LineBox[{{6.3331787543959255`, -3.0919205841110893`}, {
     6.57301106451763, -3.161012498151936}}]}, 
   {Hue[0.5633031075710727], AbsoluteThickness[0.5], 
    LineBox[{{6.442920364339203, -2.257053807437599}, {
     6.449008522529084, -2.3107789814866537`}}]}, 
   {Hue[0.5639500227838037], AbsoluteThickness[0.5], 
    LineBox[{{6.449008522529084, -2.3107789814866537`}, {
     6.5040977593809135`, -2.621749653850517}}]}, 
   {Hue[0.652907795402056], AbsoluteThickness[0.5], 
    LineBox[{{1.884126463978585, -3.607707500040743}, {
     1.933399541419282, -3.849228714507781}}]}, 
   {Hue[0.6534474400170983], AbsoluteThickness[0.5], 
    LineBox[{{1.933399541419282, -3.849228714507781}, {
     2.0114709502235355`, -4.158585897221139}}]}, 
   {Hue[0.6259164446283546], AbsoluteThickness[0.5], 
    LineBox[{{2.6118063006772863`, 0.7930794628040901}, {2.405614636523107, 
     0.7517837540657487}}]}, 
   {Hue[0.6266753035663435], AbsoluteThickness[0.5], 
    LineBox[{{2.405614636523107, 0.7517837540657487}, {2.189863958109595, 
     0.7251840500410016}}]}, 
   {Hue[0.5639663853829882], AbsoluteThickness[0.5], 
    LineBox[{{3.3534855206748517`, 3.4851966960567613`}, {3.251715682917253, 
     3.616256759171041}}]}, 
   {Hue[0.5645300184472193], AbsoluteThickness[0.5], 
    LineBox[{{3.251715682917253, 3.616256759171041}, {3.085286358754047, 
     3.8543908004797025`}}]}, 
   {Hue[0.6156331958780064], AbsoluteThickness[0.5], 
    LineBox[{{4.406209685955791, 1.4916078221493894`}, {4.324556213461355, 
     1.4113781263527871`}}]}, 
   {Hue[0.6161503396714983], AbsoluteThickness[0.5], 
    LineBox[{{4.324556213461355, 1.4113781263527871`}, {4.117011463966711, 
     1.1898406687380232`}}]}, 
   {Hue[0.6225673197459362], AbsoluteThickness[0.5], 
    LineBox[{{4.336046545093241, 2.500193357220387}, {4.192535403757152, 
     2.515046142463403}}]}, 
   {Hue[0.6230059970940163], AbsoluteThickness[0.5], 
    LineBox[{{4.192535403757152, 2.515046142463403}, {3.8570624548722, 
     2.544401331401697}}]}, 
   {Hue[0.5991577802595027], AbsoluteThickness[0.5], 
    LineBox[{{5.9161068560005745`, 2.387293085158171}, {5.807865107025737, 
     2.265777368128244}}]}, 
   {Hue[0.5996672994671982], AbsoluteThickness[0.5], 
    LineBox[{{5.807865107025737, 2.265777368128244}, {5.650185126947786, 
     2.1023147520081773`}}]}, 
   {Hue[0.5774026647499405], AbsoluteThickness[0.5], 
    LineBox[{{6.639234003826936, 3.3583688626671555`}, {6.539797346712844, 
     3.3825887494256834`}}]}, 
   {Hue[0.5791684806009089], AbsoluteThickness[0.5], 
    LineBox[{{6.539797346712844, 3.3825887494256834`}, {6.329358695684978, 
     3.46437702431007}}]}, 
   {Hue[0.6046277711077018], AbsoluteThickness[0.5], 
    LineBox[{{7.38636086643582, 3.404803723882367}, {7.340860526854635, 
     3.3703446123863143`}}]}, 
   {Hue[0.6050576442043679], AbsoluteThickness[0.5], 
    LineBox[{{7.340860526854635, 3.3703446123863143`}, {7.071917710051005, 
     3.162874425755288}}]}, 
   {Hue[0.05324609600572674], AbsoluteThickness[0.5], 
    LineBox[{{7.666193767785579, 3.52919447728847}, {7.773158465343258, 
     3.5786703846785697`}}]}, 
   {Hue[0.05894248249364829], AbsoluteThickness[0.5], 
    LineBox[{{7.773158465343258, 3.5786703846785697`}, {7.932245611135388, 
     3.697932141165355}}]}, 
   {Hue[0.35360150925241673`], AbsoluteThickness[0.5], 
    LineBox[{{7.932245611135388, 3.697932141165355}, {7.857724876518616, 
     3.882265390007707}}]}, 
   {Hue[0.6482605360111844], AbsoluteThickness[0.5], 
    LineBox[{{7.857724876518616, 3.882265390007707}, {7.6604514382132205`, 
     3.8574606111180048`}}]}, 
   {Hue[0.6055022888333452], AbsoluteThickness[0.5], 
    LineBox[{{7.366268648274585, 3.4673524616593014`}, {7.056076347233666, 
     3.3985433013424853`}}]}, 
   {Hue[0.6075172851897254], AbsoluteThickness[0.5], 
    LineBox[{{7.056076347233666, 3.3985433013424853`}, {6.8599606263435575`, 
     3.3832138549220097`}}]}, 
   {Hue[0.5803282583537055], AbsoluteThickness[0.5], 
    LineBox[{{7.048221893017178, 2.8310875099772495`}, {6.48216279774539, 
     2.147770679220838}}]}, 
   {Hue[0.5825956602869329], AbsoluteThickness[0.5], 
    LineBox[{{6.48216279774539, 2.147770679220838}, {6.363186588319081, 
     1.9510299941773805`}}]}, 
   {Hue[0.6017084568375802], AbsoluteThickness[0.5], 
    LineBox[{{5.294341901364093, 3.0019049963830016`}, {5.148271236630896, 
     3.016710352943919}}]}, 
   {Hue[0.6021841304309477], AbsoluteThickness[0.5], 
    LineBox[{{5.148271236630896, 3.016710352943919}, {4.8335343415254055`, 
     3.0388091207575525`}}]}, 
   {Hue[0.6074817132835091], AbsoluteThickness[0.5], 
    LineBox[{{5.470728206406311, 1.9423718551389946`}, {5.332632816513495, 
     1.750796829763213}}]}, 
   {Hue[0.6119237086391494], AbsoluteThickness[0.5], 
    LineBox[{{5.332632816513495, 1.750796829763213}, {5.212702987534832, 
     1.6382768878787577`}}]}, 
   {Hue[0.5816649105618233], AbsoluteThickness[0.5], 
    LineBox[{{3.6268088513745607`, 3.3308527342946896`}, {3.6100319012506503`,
      3.338733621609959}}]}, 
   {Hue[0.5823817203073048], AbsoluteThickness[0.5], 
    LineBox[{{3.6100319012506503`, 3.338733621609959}, {3.353326043150201, 
     3.482264864734766}}]}, 
   {Hue[0.6746860517328626], AbsoluteThickness[0.5], 
    LineBox[{{5.306827145722862, 0.12108862840882945`}, {
     5.293038408433579, -0.020884222582162187`}}]}, 
   {Hue[0.6751122393235679], AbsoluteThickness[0.5], 
    LineBox[{{5.293038408433579, -0.020884222582162187`}, {
     5.259192939370284, -0.37890936935633684`}}]}, 
   {Hue[0.6121291711406414], AbsoluteThickness[0.5], 
    LineBox[{{3.841501710689261, 0.48999990012660344`}, {3.7061956020406743`, 
     0.3681711508012287}}]}, 
   {Hue[0.621390916908464], AbsoluteThickness[0.5], 
    LineBox[{{3.7061956020406743`, 0.3681711508012287}, {3.603048087742365, 
     0.21483793963108413`}}]}, 
   {Hue[0.5998353064786357], AbsoluteThickness[0.5], 
    LineBox[{{2.413468058204143, -0.16842042657828155`}, {
     2.397582674945494, -0.18697471780101071`}}]}, 
   {Hue[0.6003061935128398], AbsoluteThickness[0.5], 
    LineBox[{{2.397582674945494, -0.18697471780101071`}, {
     2.1886393392389287`, -0.4169637356993533}}]}, 
   {Hue[0.6168911429897557], AbsoluteThickness[0.5], 
    LineBox[{{5.010987358099255, -1.5956176613335031`}, {
     5.073434788260743, -1.8998284938809924`}}]}, 
   {Hue[0.621950945586736], AbsoluteThickness[0.5], 
    LineBox[{{5.073434788260743, -1.8998284938809924`}, {
     5.07358023395044, -2.093179708045068}}]}, 
   {Hue[0.4179762017018167], AbsoluteThickness[0.5], 
    LineBox[{{7.136449877648672, 0.10461849948909832`}, {7.145050776013664, 
     0.10592123537235645`}}]}, 
   {Hue[0.41994710086772497`], AbsoluteThickness[0.5], 
    LineBox[{{7.145050776013664, 0.10592123537235645`}, {7.308185128128607, 
     0.154456904406362}}]}, 
   {Hue[0.6456744013878708], AbsoluteThickness[0.5], 
    LineBox[{{6.29468685449111, 1.4015657347808643`}, {6.349645810356557, 
     1.4519266773271198`}}]}, 
   {Hue[0.6462466889829351], AbsoluteThickness[0.5], 
    LineBox[{{6.349645810356557, 1.4519266773271198`}, {6.5802317485468125`, 
     1.6422550315138007`}}]}, 
   {Hue[0.6133676500963101], AbsoluteThickness[0.5], 
    LineBox[{{4.443895978058326, -2.173839036070645}, {
     4.4690570206278455`, -2.374453314484946}}]}, 
   {Hue[0.613795114346933], AbsoluteThickness[0.5], 
    LineBox[{{4.4690570206278455`, -2.374453314484946}, {
     4.507939832892837, -2.670937073928645}}]}, 
   {Hue[0.5921516030690078], AbsoluteThickness[0.5], 
    LineBox[{{6.873615815093204, -0.8953709276138526}, {
     6.873414889346306, -0.8985725299273292}}]}, 
   {Hue[0.5930853578677568], AbsoluteThickness[0.5], 
    LineBox[{{6.873414889346306, -0.8985725299273292}, {
     6.880104052986749, -1.144807751977019}}]}, 
   {Hue[0.31615997033485815`], AbsoluteThickness[0.5], 
    LineBox[{{7.3916018672745745`, -0.6629960700416081}, {
     7.609684860517986, -0.7387553884838882}}]}, 
   {Hue[0.3166490840313338], AbsoluteThickness[0.5], 
    LineBox[{{7.609684860517986, -0.7387553884838882}, {
     7.880670043153048, -0.8224727448413636}}]}, 
   {Hue[0.601426189470055], AbsoluteThickness[0.5], 
    LineBox[{{7.241714821620361, -0.13309667047204726`}, {7.439042419874142, 
     0.28180284015873647`}}]}, 
   {Hue[0.6019298946053829], AbsoluteThickness[0.5], 
    LineBox[{{7.439042419874142, 0.28180284015873647`}, {7.577874835180306, 
     0.6051284611839773}}]}, 
   {Hue[0.5876524199177557], AbsoluteThickness[0.5], 
    LineBox[{{6.122211200392516, 0.16398874459733975`}, {6.127341487335728, 
     0.17242672083792238`}}]}, 
   {Hue[0.5881051831981716], AbsoluteThickness[0.5], 
    LineBox[{{6.127341487335728, 0.17242672083792238`}, {6.302711337739858, 
     0.44654363461627244`}}]}, 
   {Hue[0.4049525180696777], AbsoluteThickness[0.5], 
    LineBox[{{5.6489191178851, -3.516797679149116}, {
     5.718331423866652, -3.611390884949595}}]}, 
   {Hue[0.40552814779109975`], AbsoluteThickness[0.5], 
    LineBox[{{5.718331423866652, -3.611390884949595}, {
     5.878808672295261, -3.8559140554290106`}}]}, 
   {Hue[0.6975512397383475], AbsoluteThickness[0.5], 
    LineBox[{{6.775433554894894, 0.5671738841150324}, {6.8698180062293055`, 
     0.5483404247731707}}]}, 
   {Hue[0.6981434960073937], AbsoluteThickness[0.5], 
    LineBox[{{6.8698180062293055`, 0.5483404247731707}, {7.159310893986256, 
     0.4738546586489607}}]}, 
   {Hue[0.5748983422508246], AbsoluteThickness[0.5], 
    LineBox[{{6.927572078853873, 0.666856819207575}, {7.073539544386659, 
     0.8484825335363742}}]}, 
   {Hue[0.5790751070218271], AbsoluteThickness[0.5], 
    LineBox[{{7.073539544386659, 0.8484825335363742}, {7.167347752578515, 
     1.0249884071210174`}}]}, 
   {Hue[0.6028508986735144], AbsoluteThickness[0.5], 
    LineBox[{{7.629224775075198, -0.1436887610897335}, {
     7.6293270089283896`, -0.14367536368817702`}}]}, 
   {Hue[0.6043204519125366], AbsoluteThickness[0.5], 
    LineBox[{{7.6293270089283896`, -0.14367536368817702`}, {
     7.8546266865640595`, -0.14133457938006783`}}]}, 
   {Hue[0.660019050115513], AbsoluteThickness[0.5], 
    LineBox[{{6.450055413653725, 2.238357003868196}, {6.500581714710136, 
     2.349173055481198}}]}, 
   {Hue[0.6609050588241738], AbsoluteThickness[0.5], 
    LineBox[{{6.500581714710136, 2.349173055481198}, {6.5966959731051595`, 
     2.619501207356274}}]}, 
   {Hue[0.6393620755168734], AbsoluteThickness[0.5], 
    LineBox[{{6.254706340892061, 2.9411670623727795`}, {6.325968056558144, 
     2.9586429544477717`}}]}, 
   {Hue[0.6398064317908896], AbsoluteThickness[0.5], 
    LineBox[{{6.325968056558144, 2.9586429544477717`}, {6.643032610432254, 
     3.030039309534566}}]}, 
   {Hue[0.3460016091200219], AbsoluteThickness[0.5], 
    LineBox[{{2.2973116542492193`, 3.3906040559269304`}, {2.2505349344244308`,
      3.5679748396611104`}}]}, 
   {Hue[0.3464316829478934], AbsoluteThickness[0.5], 
    LineBox[{{2.2505349344244308`, 3.5679748396611104`}, {2.1760952336697454`,
      3.861045912280359}}]}, 
   {Hue[0.5177248905490583], AbsoluteThickness[0.5], 
    LineBox[{{3.416908937667367, -2.0773186617771313`}, {
     3.4061648756066316`, -2.114221607287191}}]}, 
   {Hue[0.518698292427812], AbsoluteThickness[0.5], 
    LineBox[{{3.4061648756066316`, -2.114221607287191}, {
     3.313726285250286, -2.3483699737780213`}}]}, 
   {Hue[0.5272300742026049], AbsoluteThickness[0.5], 
    LineBox[{{5.403174721065136, -1.809271014201979}, {
     5.4059660798882705`, -1.816787446801733}}]}, 
   {Hue[0.527692179826448], AbsoluteThickness[0.5], 
    LineBox[{{5.4059660798882705`, -1.816787446801733}, {
     5.530437087684105, -2.126576375659792}}]}, 
   {Hue[0.5591520542516778], AbsoluteThickness[0.5], 
    LineBox[{{4.55004205643889, 1.5872324625062781`}, {4.432636378383718, 
     1.6719888087883112`}}]}, 
   {Hue[0.5595912292458192], AbsoluteThickness[0.5], 
    LineBox[{{4.432636378383718, 1.6719888087883112`}, {4.161472469369289, 
     1.8611597178640045`}}]}, 
   {Hue[0.6017217717987411], AbsoluteThickness[0.5], 
    LineBox[{{6.202472105974226, -0.4445321588679984}, {
     6.380267234522648, -0.5547237361595964}}]}, 
   {Hue[0.6026018032306769], AbsoluteThickness[0.5], 
    LineBox[{{6.380267234522648, -0.5547237361595964}, {
     6.636815982541633, -0.6847583976500393}}]}, 
   {Hue[0.431564199560507], AbsoluteThickness[0.5], 
    LineBox[{{6.6501224423531555`, 0.09134997331876665}, {
     7.0909288338970535`, -0.279585163285153}}]}, 
   {Hue[0.4325246273051859], AbsoluteThickness[0.5], 
    LineBox[{{7.0909288338970535`, -0.279585163285153}, {
     7.301021752762318, -0.4257239580760057}}]}, 
   {Hue[0.6101964021790954], AbsoluteThickness[0.5], 
    LineBox[{{6.63011922812077, 1.0807950254742982`}, {6.653052513443418, 
     1.1258342980773683`}}]}, 
   {Hue[0.6106222599138755], AbsoluteThickness[0.5], 
    LineBox[{{6.653052513443418, 1.1258342980773683`}, {6.800981047292761, 
     1.4161617202549708`}}]}, 
   {Hue[0.3031128135155791], AbsoluteThickness[0.5], 
    LineBox[{{6.888291722798584, 0.613578708379607}, {6.9727359361623815`, 
     0.6125725169885153}}]}, 
   {Hue[0.33499859484329414`], AbsoluteThickness[0.5], 
    LineBox[{{6.9727359361623815`, 0.6125725169885153}, {7.124261249833905, 
     0.5559622483194528}}]}, 
   {Hue[0.467762117217744], AbsoluteThickness[0.5], 
    LineBox[{{7.124261249833905, 0.5559622483194528}, {7.149588554323984, 
     0.39620251982286314`}}]}, 
   {Hue[0.6005256395921953], AbsoluteThickness[0.5], 
    LineBox[{{7.149588554323984, 0.39620251982286314`}, {7.023002276207817, 
     0.295502185192169}}]}, 
   {Hue[0.3234969392221965], AbsoluteThickness[0.5], 
    LineBox[{{6.210207727521903, 1.4276179776384996`}, {6.15878733027199, 
     1.6075752278604718`}}]}, 
   {Hue[0.3271473101816088], AbsoluteThickness[0.5], 
    LineBox[{{6.15878733027199, 1.6075752278604718`}, {6.138161667657298, 
     1.8152616564018178`}}]}, 
   {Hue[0.6658995034978789], AbsoluteThickness[0.5], 
    LineBox[{{6.138161667657298, 1.8152616564018178`}, {6.3407786300541105`, 
     1.865315997948213}}]}, 
   {Hue[0.5757034199993609], AbsoluteThickness[0.5], 
    LineBox[{{6.564379290859342, 1.2701401149547122`}, {6.173897517513291, 
     1.4922222308732023`}}]}, 
   {Hue[0.5762194244685732], AbsoluteThickness[0.5], 
    LineBox[{{6.173897517513291, 1.4922222308732023`}, {5.906572075113312, 
     1.6300280086229113`}}]}, 
   {Hue[0.07208792970560063], AbsoluteThickness[0.5], 
    LineBox[{{6.827262885059063, 1.3995030840841007`}, {6.86588060212735, 
     1.4153193360404541`}}]}, 
   {Hue[0.0726998163333327], AbsoluteThickness[0.5], 
    LineBox[{{6.86588060212735, 1.4153193360404541`}, {7.093669848121032, 
     1.524370002952304}}]}, 
   {Hue[0.5909819908660026], AbsoluteThickness[0.5], 
    LineBox[{{7.093669848121032, 1.524370002952304}, {6.855177941768478, 
     1.6074458667673364`}}]}, 
   {Hue[0.5770989646258458], AbsoluteThickness[0.5], 
    LineBox[{{6.766857456221529, 1.1128085671356798`}, {6.708448676200015, 
     0.9067724022510022}}]}, 
   {Hue[0.5779860798622203], AbsoluteThickness[0.5], 
    LineBox[{{6.708448676200015, 0.9067724022510022}, {6.651825482761823, 
     0.6123048848944155}}]}, 
   {Hue[0.46174295117879194`], AbsoluteThickness[0.5], 
    LineBox[{{6.861695802697349, 0.8914085320417565}, {6.923015174258299, 
     0.8665829416559168}}]}, 
   {Hue[0.48197338840469794`], AbsoluteThickness[0.5], 
    LineBox[{{6.923015174258299, 0.8665829416559168}, {7.085580595820903, 
     0.854002837459179}}]}, 
   {Hue[0.655277438772554], AbsoluteThickness[0.5], 
    LineBox[{{7.085580595820903, 0.854002837459179}, {7.170659445319794, 
     0.9930976420975011}}]}, 
   {Hue[0.4081725769302344], AbsoluteThickness[0.5], 
    LineBox[{{6.944582686502063, 0.7367137983151183}, {6.962087990634822, 
     0.610365871059402}}]}, 
   {Hue[0.40860608698240725`], AbsoluteThickness[0.5], 
    LineBox[{{6.962087990634822, 0.610365871059402}, {7.009858902157705, 
     0.29414605418169715`}}]}, 
   {Hue[0.5322951866413816], AbsoluteThickness[0.5], 
    LineBox[{{6.851871680841061, 0.5876991494414672}, {6.388193315498784, 
     0.22781339223934294`}}]}, 
   {Hue[0.5368054203545528], AbsoluteThickness[0.5], 
    LineBox[{{6.388193315498784, 0.22781339223934294`}, {6.201895108699225, 
     0.13404720825810232`}}]}, 
   {Hue[0.656417796352531], AbsoluteThickness[0.5], 
    LineBox[{{6.676473013188744, 0.5936994440512137}, {6.426638551839447, 
     0.695930255202047}}]}, 
   {Hue[0.6568554386625283], AbsoluteThickness[0.5], 
    LineBox[{{6.426638551839447, 0.695930255202047}, {6.181246054674641, 
     0.7920159441033328}}]}, 
   {Hue[0.6055815485838434], AbsoluteThickness[0.5], 
    LineBox[{{6.390117073498233, 0.4231660672513824}, {6.376849617676264, 
     0.38338712241548806`}}]}, 
   {Hue[0.6065956509955429], AbsoluteThickness[0.5], 
    LineBox[{{6.376849617676264, 0.38338712241548806`}, {6.265601130014972, 
     0.13252449683787532`}}]}, 
   {Hue[0.31826921542161035`], AbsoluteThickness[0.5], 
    LineBox[{{5.44161162851695, 2.1008521793985264`}, {5.4052001909106355`, 
     2.188368164255041}}]}, 
   {Hue[0.32053388152286943`], AbsoluteThickness[0.5], 
    LineBox[{{5.4052001909106355`, 2.188368164255041}, {5.281549217936705, 
     2.393662979524827}}]}, 
   {Hue[0.5796417979898423], AbsoluteThickness[0.5], 
    LineBox[{{5.096987919537466, 0.8050340143317275}, {4.9002271483973, 
     0.6927389428709173}}]}, 
   {Hue[0.5806548430317789], AbsoluteThickness[0.5], 
    LineBox[{{4.9002271483973, 0.6927389428709173}, {4.661774242871442, 
     0.5853348539934812}}]}, 
   {Hue[0.39572661650997343`], AbsoluteThickness[0.5], 
    LineBox[{{5.196659372336918, 2.392077809593476}, {5.16146705380928, 
     2.459495952070657}}]}, 
   {Hue[0.3963641731999333], AbsoluteThickness[0.5], 
    LineBox[{{5.16146705380928, 2.459495952070657}, {5.030779336044413, 
     2.676347147327998}}]}, 
   {Hue[0.5493674209266036], AbsoluteThickness[0.5], 
    LineBox[{{4.504850056414801, -1.638153154138869}, {
     4.264541980679682, -2.063077950536602}}]}, 
   {Hue[0.5499026368958945], AbsoluteThickness[0.5], 
    LineBox[{{4.264541980679682, -2.063077950536602}, {
     4.124661105416246, -2.3387340168825825`}}]}, 
   {Hue[0.5398651249669212], AbsoluteThickness[0.5], 
    LineBox[{{3.441908484463648, 2.0971933654580392`}, {3.4265808277169003`, 
     2.1363854250599594`}}]}, 
   {Hue[0.5406489598245126], AbsoluteThickness[0.5], 
    LineBox[{{3.4265808277169003`, 2.1363854250599594`}, {3.3029927365134313`,
      2.392105076645819}}]}, 
   {Hue[0.6887465814006744], AbsoluteThickness[0.5], 
    LineBox[{{2.62483621605374, 1.8150511819089745`}, {2.5404676344877757`, 
     1.8460457280781986`}}]}, 
   {Hue[0.6899181301637605], AbsoluteThickness[0.5], 
    LineBox[{{2.5404676344877757`, 1.8460457280781986`}, {2.343762746750923, 
     1.942814293537967}}]}, 
   {Hue[0.6005058331393036], AbsoluteThickness[0.5], 
    LineBox[{{4.219114605262637, 3.465115747956994}, {4.23838438109044, 
     3.5748988595083064`}}]}, 
   {Hue[0.60097236322084], AbsoluteThickness[0.5], 
    LineBox[{{4.23838438109044, 3.5748988595083064`}, {4.280397869598468, 
     3.861107072129512}}]}, 
   {Hue[0.6209941555736407], AbsoluteThickness[0.5], 
    LineBox[{{4.336060454326416, -2.048563542978325}, {
     4.324293906473938, -2.0851829426308126`}}]}, 
   {Hue[0.62146609953486], AbsoluteThickness[0.5], 
    LineBox[{{4.324293906473938, -2.0851829426308126`}, {
     4.2181607665763075`, -2.3845840937373826`}}]}, 
   {Hue[0.40605322172092345`], AbsoluteThickness[0.5], 
    LineBox[{{4.89730892546485, -2.328408717485419}, {
     4.900247627253384, -2.3386992859774027`}}]}, 
   {Hue[0.4065205130402932], AbsoluteThickness[0.5], 
    LineBox[{{4.900247627253384, -2.3386992859774027`}, {
     4.98706238472236, -2.6130891036376314`}}]}, 
   {Hue[0.6356571807346318], AbsoluteThickness[0.5], 
    LineBox[{{5.425596819191235, -1.7594386651443743`}, {
     5.606556560752712, -1.7170743737511538`}}]}, 
   {Hue[0.6361699656065368], AbsoluteThickness[0.5], 
    LineBox[{{5.606556560752712, -1.7170743737511538`}, {
     5.904669138379134, -1.659887120277511}}]}, 
   {Hue[0.6885678915266367], AbsoluteThickness[0.5], 
    LineBox[{{3.3377198487469006`, -3.0170515924032815`}, {
     3.324027551406275, -3.148574757286003}}]}, 
   {Hue[0.6890279411242193], AbsoluteThickness[0.5], 
    LineBox[{{3.324027551406275, -3.148574757286003}, {
     3.2845361695773225`, -3.451930118639752}}]}, 
   {Hue[0.6651812209581678], AbsoluteThickness[0.5], 
    LineBox[{{4.0163239959262445`, -3.177042364698447}, {
     4.049166234986604, -3.327412204096638}}]}, 
   {Hue[0.6656599405743772], AbsoluteThickness[0.5], 
    LineBox[{{4.049166234986604, -3.327412204096638}, {
     4.098707237603652, -3.594779469366155}}]}, 
   {Hue[0.37384011378536436`], AbsoluteThickness[0.5], 
    LineBox[{{6.656058319055695, -1.6013410460322093`}, {
     6.815526877505738, -1.5686230883675008`}}]}, 
   {Hue[0.37427671338872603`], AbsoluteThickness[0.5], 
    LineBox[{{6.815526877505738, -1.5686230883675008`}, {
     7.094434272406804, -1.507168333288381}}]}, 
   {Hue[0.6526921418428668], AbsoluteThickness[0.5], 
    LineBox[{{4.703790114254977, 1.8587686157399164`}, {4.6924560136552635`, 
     1.9287622604177104`}}]}, 
   {Hue[0.6585563825605524], AbsoluteThickness[0.5], 
    LineBox[{{4.6924560136552635`, 1.9287622604177104`}, {4.621049234263878, 
     2.11142933026245}}]}, 
   {Hue[0.637907329538398], AbsoluteThickness[0.5], 
    LineBox[{{6.851715824070499, -1.7796608853611917`}, {
     7.135166883473191, -1.6951952677710114`}}]}, 
   {Hue[0.641796628374366], AbsoluteThickness[0.5], 
    LineBox[{{7.135166883473191, -1.6951952677710114`}, {
     7.323467037101664, -1.6751611621407192`}}]}, 
   {Hue[0.5198626427662293], AbsoluteThickness[0.5], 
    LineBox[{{7.911138843765136, -2.231385724115977}, {
     8.071246516513641, -2.250411788594996}}]}, 
   {Hue[0.5203253799074802], AbsoluteThickness[0.5], 
    LineBox[{{8.071246516513641, -2.250411788594996}, {
     8.401975547029126, -2.2807864255972574`}}]}, 
   {Hue[0.6399352650767747], AbsoluteThickness[0.5], 
    LineBox[{{3.801874768326722, 2.3024910349631913`}, {3.724029939682887, 
     2.6476608277111637`}}]}, 
   {Hue[0.6409212371729904], AbsoluteThickness[0.5], 
    LineBox[{{3.724029939682887, 2.6476608277111637`}, {3.695805809785824, 
     2.866527677746259}}]}, 
   {Hue[0.5900056656290046], AbsoluteThickness[0.5], 
    LineBox[{{6.65142678716684, -4.433067663540734}, {
     6.823061481658637, -4.438548023581164}}]}, 
   {Hue[0.5905561508843694], AbsoluteThickness[0.5], 
    LineBox[{{6.823061481658637, -4.438548023581164}, {
     7.171848511095581, -4.466470844256226}}]}, 
   {Hue[0.538158887568632], AbsoluteThickness[0.5], 
    LineBox[{{4.371335710079582, 1.375755329449778}, {4.4017533533104976`, 
     1.46527486956323}}]}, 
   {Hue[0.5282458028974027], AbsoluteThickness[0.5], 
    LineBox[{{5.377762976520847, 2.329701444635402}, {5.406224758391896, 
     2.3785037440403065`}}]}, 
   {Hue[0.5286994152816612], AbsoluteThickness[0.5], 
    LineBox[{{5.406224758391896, 2.3785037440403065`}, {5.5675038681376, 
     2.670410151123271}}]}, 
   {Hue[0.46252877014487653`], AbsoluteThickness[0.5], 
    LineBox[{{6.654172447446525, -4.060227812306669}, {
     6.715471678912768, -4.10454440587955}}]}, 
   {Hue[0.46552589604199307`], AbsoluteThickness[0.5], 
    LineBox[{{6.715471678912768, -4.10454440587955}, {
     6.8682424534576745`, -4.259391979326185}}]}, 
   {Hue[0.6291993351111201], AbsoluteThickness[0.5], 
    LineBox[{{2.4699506456783737`, -4.194327592707677}, {
     2.401714069741746, -4.415754772917201}}]}, 
   {Hue[0.6505339876620819], AbsoluteThickness[0.5], 
    LineBox[{{2.401714069741746, -4.415754772917201}, {
     2.40399489126151, -4.59226124924312}}]}, 
   {Hue[0.556192837292832], AbsoluteThickness[0.5], 
    LineBox[{{4.574502971991735, -4.154234647857121}, {
     4.5755978922742315`, -4.226688352359056}}]}, 
   {Hue[0.5640595127981727], AbsoluteThickness[0.5], 
    LineBox[{{4.5755978922742315`, -4.226688352359056}, {
     4.622575149499135, -4.4118126079021325`}}]}, 
   {Hue[0.5436362108798307], AbsoluteThickness[0.5], 
    LineBox[{{4.152322038791029, -0.3776855619147659}, {
     4.126827200054976, -0.4542738477000071}}]}, 
   {Hue[0.5466095853356779], AbsoluteThickness[0.5], 
    LineBox[{{4.126827200054976, -0.4542738477000071}, {
     4.0297919191832205`, -0.6375176141917281}}]}, 
   {Hue[0.5639799686231358], AbsoluteThickness[0.5], 
    LineBox[{{4.413847884344333, -0.04876934874106442}, {
     4.3950587847333695`, -0.11735719428773858`}}]}, 
   {Hue[0.5647133780522634], AbsoluteThickness[0.5], 
    LineBox[{{4.3950587847333695`, -0.11735719428773858`}, {
     4.289286091294092, -0.41655710818901154`}}]}, 
   {Hue[0.4428547634699742], AbsoluteThickness[0.5], 
    LineBox[{{6.182106164247197, 0.8655105325882662}, {6.220094127121644, 
     0.8372717964020956}}]}, 
   {Hue[0.4433529433159107], AbsoluteThickness[0.5], 
    LineBox[{{6.220094127121644, 0.8372717964020956}, {6.419911009220153, 
     0.6769187691717595}}]}, 
   {Hue[0.5335305262883808], AbsoluteThickness[0.5], 
    LineBox[{{4.906642608275437, 1.9471155537229472`}, {4.695166942111226, 
     1.9395919391239604`}}]}, 
   {Hue[0.5340047123522308], AbsoluteThickness[0.5], 
    LineBox[{{4.695166942111226, 1.9395919391239604`}, {4.379646651025986, 
     1.937982657496769}}]}, 
   {Hue[0.47234265467630693`], AbsoluteThickness[0.5], 
    LineBox[{{5.58917574795608, 2.1875585809746148`}, {5.381722041198316, 
     2.324076395357619}}]}, 
   {Hue[0.47985324008763025`], AbsoluteThickness[0.5], 
    LineBox[{{5.381722041198316, 2.324076395357619}, {5.196625391513515, 
     2.392068266809049}}]}, 
   {Hue[0.02452962753672967], AbsoluteThickness[0.5], 
    LineBox[{{5.721787506516539, 2.323506259434896}, {5.884936412882811, 
     2.4584498492918745`}}]}, 
   {Hue[0.02521571132033554], AbsoluteThickness[0.5], 
    LineBox[{{5.884936412882811, 2.4584498492918745`}, {6.129726388989648, 
     2.6346189782149056`}}]}, 
   {Hue[0.5319332987132471], AbsoluteThickness[0.5], 
    LineBox[{{6.129726388989648, 2.6346189782149056`}, {6.112860660048427, 
     2.3334989995101267`}}]}, 
   {Hue[0.47474473915419546`], AbsoluteThickness[0.5], 
    LineBox[{{5.8128551426721735`, 2.156849920124739}, {5.8561089110007645`, 
     2.052616939111972}}]}, 
   {Hue[0.476375759244421], AbsoluteThickness[0.5], 
    LineBox[{{5.8561089110007645`, 2.052616939111972}, {5.987623434108285, 
     1.8229200724093193`}}]}, 
   {Hue[0.5352657547497326], AbsoluteThickness[0.5], 
    LineBox[{{5.690004646627714, 1.6005894811625923`}, {5.745992866163633, 
     1.4220952202390449`}}]}, 
   {Hue[0.5357348379163339], AbsoluteThickness[0.5], 
    LineBox[{{5.745992866163633, 1.4220952202390449`}, {5.841556265712472, 
     1.08352780933259}}]}, 
   {Hue[0.4460005546394731], AbsoluteThickness[0.5], 
    LineBox[{{4.1046091761300945`, 2.3452849795091817`}, {4.084863150638843, 
     2.3527170764835463`}}]}, 
   {Hue[0.44762949470590063`], AbsoluteThickness[0.5], 
    LineBox[{{4.084863150638843, 2.3527170764835463`}, {3.857910094936058, 
     2.4727676927602973`}}]}, 
   {Hue[0.5633030677764121], AbsoluteThickness[0.5], 
    LineBox[{{3.6934624853434057`, 1.186121574306045}, {3.574632654195685, 
     1.1687899802200699`}}]}, 
   {Hue[0.5720275991023713], AbsoluteThickness[0.5], 
    LineBox[{{3.574632654195685, 1.1687899802200699`}, {3.4074647741395303`, 
     1.100868100585285}}]}, 
   {Hue[0.532384709702209], AbsoluteThickness[0.5], 
    LineBox[{{2.6622370933964734`, 1.882400810535004}, {2.5910696911369357`, 
     1.8921564799623525`}}]}, 
   {Hue[0.5329884557932716], AbsoluteThickness[0.5], 
    LineBox[{{2.5910696911369357`, 1.8921564799623525`}, {2.3442146370442005`,
      1.9403559693066417`}}]}, 
   {Hue[0.5675575215651947], AbsoluteThickness[0.5], 
    LineBox[{{2.8491339179551556`, -0.4994275905067843}, {
     2.4382237767051884`, -0.8600616311049766}}]}, 
   {Hue[0.5734455993465841], AbsoluteThickness[0.5], 
    LineBox[{{2.4382237767051884`, -0.8600616311049766}, {
     2.3087350126270367`, -1.0346811505942586`}}]}, 
   {Hue[0.49750196914545936`], AbsoluteThickness[0.5], 
    LineBox[{{5.334395925244653, -2.3590396185724534`}, {
     5.341916467140713, -2.3785478801445255`}}]}, 
   {Hue[0.4983348992630109], AbsoluteThickness[0.5], 
    LineBox[{{5.341916467140713, -2.3785478801445255`}, {
     5.461249524104117, -2.6257436817870565`}}]}, 
   {Hue[0.6141120087513902], AbsoluteThickness[0.5], 
    LineBox[{{4.539477099095544, -2.6646289125185705`}, {
     4.595999888678197, -2.7807077602726644`}}]}, 
   {Hue[0.6195139318031501], AbsoluteThickness[0.5], 
    LineBox[{{4.595999888678197, -2.7807077602726644`}, {
     4.714104199254343, -2.9330594058373904`}}]}, 
   {Hue[0.5743196273599155], AbsoluteThickness[0.5], 
    LineBox[{{2.6484390094968067`, -2.890484593255407}, {
     2.618279114238243, -2.975067279622828}}]}, 
   {Hue[0.5900734924542168], AbsoluteThickness[0.5], 
    LineBox[{{2.618279114238243, -2.975067279622828}, {
     2.5228785156480416`, -3.1060300197478097`}}]}, 
   {Hue[0.5295498877879917], AbsoluteThickness[0.5], 
    LineBox[{{4.484142604719942, -3.623348017930987}, {
     4.493020686283771, -3.866168726039999}}]}, 
   {Hue[0.5300011590170923], AbsoluteThickness[0.5], 
    LineBox[{{4.493020686283771, -3.866168726039999}, {
     4.510414066612559, -4.161751528114774}}]}, 
   {Hue[0.49336333770577606`], AbsoluteThickness[0.5], 
    LineBox[{{5.791530589925796, -2.8869201373136533`}, {
     5.760642471442485, -3.1205222285707124`}}]}, 
   {Hue[0.49381555205461347`], AbsoluteThickness[0.5], 
    LineBox[{{5.760642471442485, -3.1205222285707124`}, {
     5.712142858728008, -3.4327634707051033`}}]}, 
   {Hue[0.5617403237880936], AbsoluteThickness[0.5], 
    LineBox[{{4.992084335219275, -2.146884224942067}, {
     4.971429403287574, -2.3202153752174635`}}]}, 
   {Hue[0.5621770491778115], AbsoluteThickness[0.5], 
    LineBox[{{4.971429403287574, -2.3202153752174635`}, {
     4.941106411937431, -2.610713824372934}}]}, 
   {Hue[0.5744687934041302], AbsoluteThickness[0.5], 
    LineBox[{{4.014121849651803, -0.13614123669336992`}, {
     3.8762680092974295`, -0.2757090949787102}}]}, 
   {Hue[0.5774210767903066], AbsoluteThickness[0.5], 
    LineBox[{{3.8762680092974295`, -0.2757090949787102}, {
     3.6886031705493783`, -0.4115032874689321}}]}, 
   {Hue[0.4619324469306683], AbsoluteThickness[0.5], 
    LineBox[{{6.869550375697416, 1.1914323411561465`}, {6.9108501421941115`, 
     1.1096557106206306`}}]}, 
   {Hue[0.4624121593133066], AbsoluteThickness[0.5], 
    LineBox[{{6.9108501421941115`, 1.1096557106206306`}, {7.056618119712267, 
     0.84268477071087}}]}, 
   {Hue[0.6858629239600472], AbsoluteThickness[0.5], 
    LineBox[{{5.339271642832133, 3.2677948659245852`}, {5.398348533128037, 
     3.379165278145128}}]}, 
   {Hue[0.6862933090169506], AbsoluteThickness[0.5], 
    LineBox[{{5.398348533128037, 3.379165278145128}, {5.5647158787587605`, 
     3.6857683027575874`}}]}, 
   {Hue[0.32327637642640494`], AbsoluteThickness[0.5], 
    LineBox[{{5.196690725453032, 3.3876020552150212`}, {5.155079461213317, 
     3.4124871095362592`}}]}, 
   {Hue[0.3237359777832124], AbsoluteThickness[0.5], 
    LineBox[{{5.155079461213317, 3.4124871095362592`}, {4.92344151322571, 
     3.5430974150242442`}}]}, 
   {Hue[0.6913072867253192], AbsoluteThickness[0.5], 
    LineBox[{{5.069735205569932, 3.251347232997411}, {5.004247056529533, 
     3.153588763368667}}]}, 
   {Hue[0.6919675526613174], AbsoluteThickness[0.5], 
    LineBox[{{5.004247056529533, 3.153588763368667}, {4.856593554957436, 
     2.8992955446024955`}}]}, 
   {Hue[0.5540590219142104], AbsoluteThickness[0.5], 
    LineBox[{{5.14488508447451, 2.814393882361741}, {4.906975772110317, 
     2.8004979784095347`}}]}, 
   {Hue[0.5544950710982467], AbsoluteThickness[0.5], 
    LineBox[{{4.906975772110317, 2.8004979784095347`}, {4.593327904888156, 
     2.777723990238855}}]}, 
   {Hue[0.5012250518020301], AbsoluteThickness[0.5], 
    LineBox[{{5.760770670023549, 3.406742873564329}, {5.652716016296258, 
     3.4580410600026505`}}]}, 
   {Hue[0.5016520498474787], AbsoluteThickness[0.5], 
    LineBox[{{5.652716016296258, 3.4580410600026505`}, {5.3363388708132575`, 
     3.6064017829104773`}}]}, 
   {Hue[0.5724074796689788], AbsoluteThickness[0.5], 
    LineBox[{{6.667757912857175, 3.1931177689322365`}, {6.617693989343164, 
     3.074797340066353}}]}, 
   {Hue[0.5730746481544798], AbsoluteThickness[0.5], 
    LineBox[{{6.617693989343164, 3.074797340066353}, {6.484085620914714, 
     2.8086764783587337`}}]}, 
   {Hue[0.03820731094806679], AbsoluteThickness[0.5], 
    LineBox[{{6.888579848334961, 3.3287620282258708`}, {6.922006080976466, 
     3.351254167915466}}]}, 
   {Hue[0.03948574295498592], AbsoluteThickness[0.5], 
    LineBox[{{6.922006080976466, 3.351254167915466}, {7.085809987709163, 
     3.4901097008981803`}}]}, 
   {Hue[0.4834096928685349], AbsoluteThickness[0.5], 
    LineBox[{{7.085809987709163, 3.4901097008981803`}, {6.908943011069066, 
     3.6118908631319147`}}]}, 
   {Hue[0.5734423024147326], AbsoluteThickness[0.5], 
    LineBox[{{6.629521208981891, 3.3358552393470893`}, {6.40723457317926, 
     3.3327256777419323`}}]}, 
   {Hue[0.5743953294680634], AbsoluteThickness[0.5], 
    LineBox[{{6.40723457317926, 3.3327256777419323`}, {6.128399606312667, 
     3.303249660698134}}]}, 
   {Hue[0.501705180646743], AbsoluteThickness[0.5], 
    LineBox[{{6.673267135335926, 2.578541564886991}, {6.74293707430353, 
     2.344257864494768}}]}, 
   {Hue[0.5021429567427755], AbsoluteThickness[0.5], 
    LineBox[{{6.74293707430353, 2.344257864494768}, {6.818222922356668, 
     2.104560414048737}}]}, 
   {Hue[0.5537607276612854], AbsoluteThickness[0.5], 
    LineBox[{{6.250904282396079, 1.5648940337397252`}, {6.255050019253875, 
     1.4204423477012622`}}]}, 
   {Hue[0.5542794596478161], AbsoluteThickness[0.5], 
    LineBox[{{6.255050019253875, 1.4204423477012622`}, {6.251131608875174, 
     1.1200558308715454`}}]}, 
   {Hue[0.3339685885456781], AbsoluteThickness[0.5], 
    LineBox[{{7.558492112243443, 1.8797807286307913`}, {7.637148051867781, 
     1.8575133446923346`}}]}, 
   {Hue[0.33460504221738], AbsoluteThickness[0.5], 
    LineBox[{{7.637148051867781, 1.8575133446923346`}, {7.940716569850648, 
     1.7511483361603677`}}]}, 
   {Hue[0.6685038049729148], AbsoluteThickness[0.5], 
    LineBox[{{6.134454509787367, 1.6368769745609075`}, {6.137646730644715, 
     1.6251851908415822`}}]}, 
   {Hue[0.6739385208965045], AbsoluteThickness[0.5], 
    LineBox[{{6.137646730644715, 1.6251851908415822`}, {6.149159592329257, 
     1.432920447901706}}]}, 
   {Hue[0.45900259509060803`], AbsoluteThickness[0.5], 
    LineBox[{{3.583730704152318, 2.1579012487626157`}, {3.4405614860341682`, 
     2.1599393523087227`}}]}, 
   {Hue[0.45960272935938523`], AbsoluteThickness[0.5], 
    LineBox[{{3.4405614860341682`, 2.1599393523087227`}, {3.140796824006409, 
     2.1810475011681056`}}]}, 
   {Hue[0.6327934892371645], AbsoluteThickness[0.5], 
    LineBox[{{5.160580187971834, -0.33518162828033005`}, {
     5.438329192107522, -0.8782289285675865}}]}, 
   {Hue[0.633229851351293], AbsoluteThickness[0.5], 
    LineBox[{{5.438329192107522, -0.8782289285675865}, {
     5.578497901415817, -1.1622676241185033`}}]}, 
   {Hue[0.571432931377702], AbsoluteThickness[0.5], 
    LineBox[{{7.375166765175819, -4.219275662651597}, {
     7.5764128484618976`, -4.296460211484058}}]}, 
   {Hue[0.5720742347776431], AbsoluteThickness[0.5], 
    LineBox[{{7.5764128484618976`, -4.296460211484058}, {
     7.834018473127194, -4.37740761211912}}]}, 
   {Hue[0.6467350006131265], AbsoluteThickness[0.5], 
    LineBox[{{6.5644794331739575`, -1.1341761338926948`}, {
     6.682709395707722, -1.1873303452404462`}}]}, 
   {Hue[0.6473178222689756], AbsoluteThickness[0.5], 
    LineBox[{{6.682709395707722, -1.1873303452404462`}, {
     6.9211764478180635`, -1.310246915725767}}]}, 
   {Hue[0.5225941926323466], AbsoluteThickness[0.5], 
    LineBox[{{7.388403003789321, 0.711875681285104}, {7.625820852094849, 
     0.8016667799417466}}]}, 
   {Hue[0.5234654046420409], AbsoluteThickness[0.5], 
    LineBox[{{7.625820852094849, 0.8016667799417466}, {7.904497148023356, 
     0.8807691391392298}}]}, 
   {Hue[0.48215377716458696`], AbsoluteThickness[0.5], 
    LineBox[{{6.642143572427722, 2.0960407953271347`}, {6.72001753421257, 
     2.125949046064493}}]}, 
   {Hue[0.48294303075485134`], AbsoluteThickness[0.5], 
    LineBox[{{6.72001753421257, 2.1259490460644925`}, {6.919966331184247, 
     2.2212040573780865`}}]}, 
   {Hue[0.3059504054679176], AbsoluteThickness[0.5], 
    LineBox[{{6.206189280531699, 2.355743408486711}, {6.254148843936288, 
     2.617100141548595}}]}, 
   {Hue[0.30654120279710145`], AbsoluteThickness[0.5], 
    LineBox[{{6.254148843936288, 2.617100141548595}, {6.293528047281662, 
     2.9259358820069323`}}]}, 
   {Hue[0.5144453029981189], AbsoluteThickness[0.5], 
    LineBox[{{5.646026875172219, 2.308400628916752}, {5.3736325651504515`, 
     2.3350909523319463`}}]}, 
   {Hue[0.5157550956046727], AbsoluteThickness[0.5], 
    LineBox[{{5.3736325651504515`, 2.3350909523319463`}, {5.107612553308031, 
     2.3311626032181527`}}]}, 
   {Hue[0.5475463701680394], AbsoluteThickness[0.5], 
    LineBox[{{4.081432225660939, 3.3476147222467385`}, {4.069130041731719, 
     3.4167774200332546`}}]}, 
   {Hue[0.5480762470975961], AbsoluteThickness[0.5], 
    LineBox[{{4.069130041731719, 3.4167774200332546`}, {4.007698929471425, 
     3.6913907495601546`}}]}, 
   {Hue[0.6636263198323318], AbsoluteThickness[0.5], 
    LineBox[{{5.079308969156486, 3.1264005343894525`}, {5.085581517133244, 
     3.189133827884568}}]}, 
   {Hue[0.6664821540958271], AbsoluteThickness[0.5], 
    LineBox[{{5.085581517133244, 3.189133827884568}, {5.13352786984925, 
     3.3674628919146667`}}]}, 
   {Hue[0.6119264804003075], AbsoluteThickness[0.5], 
    LineBox[{{3.1651919845681658`, -2.8921128139775836`}, {
     3.23390778137463, -3.1468841171915}}]}, 
   {Hue[0.612352437453302], AbsoluteThickness[0.5], 
    LineBox[{{3.23390778137463, -3.1468841171915}, {
     3.3153511117860948`, -3.447141188437976}}]}, 
   {Hue[0.6033256224909646], AbsoluteThickness[0.5], 
    LineBox[{{6.603463194870228, -0.7008325084878011}, {
     6.647665523360936, -0.7124378853266384}}]}, 
   {Hue[0.6038724972621723], AbsoluteThickness[0.5], 
    LineBox[{{6.647665523360936, -0.7124378853266384}, {
     6.910706807014745, -0.7949791373091479}}]}, 
   {Hue[0.6044741064595291], AbsoluteThickness[0.5], 
    LineBox[{{4.557654897968823, -0.6902334873112135}, {
     4.605119771487435, -0.8444818908342048}}]}, 
   {Hue[0.6068596076535578], AbsoluteThickness[0.5], 
    LineBox[{{4.605119771487435, -0.8444818908342048}, {
     4.637075549499139, -1.0598563333570816`}}]}, 
   {Hue[0.5890727273896473], AbsoluteThickness[0.5], 
    LineBox[{{2.4366708621308497`, -0.1772562880104147}, {
     2.4270532799842868`, -0.4120422125728759}}]}, 
   {Hue[0.590683746450872], AbsoluteThickness[0.5], 
    LineBox[{{2.4270532799842868`, -0.4120422125728759}, {
     2.4488608051482226`, -0.6682448631716018}}]}, 
   {Hue[0.5393147490000262], AbsoluteThickness[0.5], 
    LineBox[{{3.7992055211933065`, 2.1288553928966074`}, {3.887124704309503, 
     2.040427886632083}}]}, 
   {Hue[0.5398670297046178], AbsoluteThickness[0.5], 
    LineBox[{{3.887124704309503, 2.040427886632083}, {4.119043863728996, 
     1.8286690149427338`}}]}, 
   {Hue[0.6043433955981516], AbsoluteThickness[0.5], 
    LineBox[{{3.2622496447919174`, 0.5767104367430875}, {3.3009528934913264`, 
     0.41489366490703883`}}]}, 
   {Hue[0.6052459857193091], AbsoluteThickness[0.5], 
    LineBox[{{3.3009528934913264`, 0.41489366490703883`}, {
     3.3420322280993027`, 0.13801343009092454`}}]}, 
   {Hue[0.5948754611637046], AbsoluteThickness[0.5], 
    LineBox[{{3.1664225351941844`, -0.1490562979243117}, {
     3.165221072588552, -0.15735250681665064`}}]}, 
   {Hue[0.5963457821829391], AbsoluteThickness[0.5], 
    LineBox[{{3.165221072588552, -0.15735250681665064`}, {
     3.159373636926916, -0.4022539621907468}}]}, 
   {Hue[0.68297200528554], AbsoluteThickness[0.5], 
    LineBox[{{4.628983332378161, -3.553092014493604}, {
     4.6151408223013926`, -3.6517472727248226`}}]}, 
   {Hue[0.6843094619921916], AbsoluteThickness[0.5], 
    LineBox[{{4.6151408223013926`, -3.6517472727248226`}, {
     4.609098423757178, -3.8877164056568936`}}]}, 
   {Hue[0.549826352150181], AbsoluteThickness[0.5], 
    LineBox[{{5.55351247328033, -3.143682286431134}, {
     5.590776189681061, -3.1668987989554984`}}]}, 
   {Hue[0.5502731136036569], AbsoluteThickness[0.5], 
    LineBox[{{5.590776189681061, -3.1668987989554984`}, {
     5.856242723704777, -3.339828421191142}}]}, 
   {Hue[0.5541909201971077], AbsoluteThickness[0.5], 
    LineBox[{{5.819384485417921, 2.2385446670767823`}, {6.021652945398963, 
     2.3232971450957915`}}]}, 
   {Hue[0.5573835223112584], AbsoluteThickness[0.5], 
    LineBox[{{6.021652945398963, 2.3232971450957915`}, {6.210462364799511, 
     2.4435620456518214`}}]}, 
   {Hue[0.4367705383900473], AbsoluteThickness[0.5], 
    LineBox[{{7.39439141910835, -0.2987398054366874}, {
     7.600002790644775, -0.2637243500849415}}]}, 
   {Hue[0.43719704171752666`], AbsoluteThickness[0.5], 
    LineBox[{{7.600002790644775, -0.2637243500849415}, {
     7.887164735274242, -0.2137628481629584}}]}, 
   {Hue[0.3643957619192698], AbsoluteThickness[0.5], 
    LineBox[{{6.421575284465714, -2.312268820533387}, {
     6.4248196969788, -2.330511316204775}}]}, 
   {Hue[0.3652175739034544], AbsoluteThickness[0.5], 
    LineBox[{{6.4248196969788, -2.330511316204775}, {
     6.50110992969594, -2.6209800457583454`}}]}, 
   {Hue[0.5159054229565062], AbsoluteThickness[0.5], 
    LineBox[{{5.748222733078297, -2.4239958775671884`}, {
     5.7824122029460225`, -2.6547506887514585`}}]}, 
   {Hue[0.5170188431972496], AbsoluteThickness[0.5], 
    LineBox[{{5.7824122029460225`, -2.6547506887514585`}, {
     5.792899854559246, -2.8858688777378743`}}]}, 
   {Hue[0.6484145493971407], AbsoluteThickness[0.5], 
    LineBox[{{4.386231449035498, -2.139063828099931}, {
     4.382594813293866, -2.1472970053809113`}}]}, 
   {Hue[0.6493842192714353], AbsoluteThickness[0.5], 
    LineBox[{{4.382594813293866, -2.1472970053809113`}, {
     4.249811483182865, -2.3855964276395603`}}]}, 
   {Hue[0.5040345015414992], AbsoluteThickness[0.5], 
    LineBox[{{7.153350389928379, 0.05082189004744936}, {7.584658827871159, 
     0.18011362664022948`}}]}, 
   {Hue[0.5044692900740815], AbsoluteThickness[0.5], 
    LineBox[{{7.584658827871159, 0.18011362664022948`}, {7.910112966549745, 
     0.27299501936239406`}}]}, 
   {Hue[0.3263261177476086], AbsoluteThickness[0.5], 
    LineBox[{{6.441750375671983, 3.253622803973537}, {6.622840355044747, 
     3.290785180987466}}]}, 
   {Hue[0.3267771313185511], AbsoluteThickness[0.5], 
    LineBox[{{6.622840355044747, 3.290785180987466}, {6.885516698435229, 
     3.3386618045455494`}}]}, 
   {Hue[0.6017043930768559], AbsoluteThickness[0.5], 
    LineBox[{{4.119628625037054, 1.828988438913347}, {4.132226597512573, 
     1.8143637982346976`}}]}, 
   {Hue[0.6023363424483483], AbsoluteThickness[0.5], 
    LineBox[{{4.132226597512573, 1.8143637982346976`}, {4.345360367852291, 
     1.5952765565059506`}}]}, 
   {Hue[0.6086193564814478], AbsoluteThickness[0.5], 
    LineBox[{{2.358296061078627, 2.8596381184239403`}, {2.3132102649487254`, 
     2.847099937636763}}]}, 
   {Hue[0.6091044042112072], AbsoluteThickness[0.5], 
    LineBox[{{2.3132102649487254`, 2.847099937636763}, {2.071483577123253, 
     2.7710373824642467`}}]}, 
   {Hue[0.515977055131384], AbsoluteThickness[0.5], 
    LineBox[{{4.062850046859226, 3.413332923529567}, {4.121304450498017, 
     3.4119200402356697`}}]}, 
   {Hue[0.5171636471813232], AbsoluteThickness[0.5], 
    LineBox[{{4.121304450498017, 3.4119200402356697`}, {4.413675956051858, 
     3.3736581416917426`}}]}, 
   {Hue[0.5935571919622563], AbsoluteThickness[0.5], 
    LineBox[{{4.080612067517458, 2.351119380027708}, {4.097134087901639, 
     2.3338429068450757`}}]}, 
   {Hue[0.5940420591523572], AbsoluteThickness[0.5], 
    LineBox[{{4.097134087901639, 2.3338429068450757`}, {4.326788430770375, 
     2.1092959533383793`}}]}, 
   {Hue[0.6273037398283287], AbsoluteThickness[0.5], 
    LineBox[{{4.644904950112239, 0.378923077217265}, {4.645207468634767, 
     0.3786928412992356}}]}, 
   {Hue[0.6277713960911734], AbsoluteThickness[0.5], 
    LineBox[{{4.645207468634767, 0.3786928412992356}, {4.851391769698768, 
     0.21232615024948656`}}]}, 
   {Hue[0.3959300570745341], AbsoluteThickness[0.5], 
    LineBox[{{4.16008456639786, 0.5164298020164279}, {4.276303283560598, 
     0.4255125167370273}}]}, 
   {Hue[0.397227741381709], AbsoluteThickness[0.5], 
    LineBox[{{4.276303283560598, 0.4255125167370273}, {4.460488619071898, 
     0.24487139870824842`}}]}, 
   {Hue[0.6299346148892162], AbsoluteThickness[0.5], 
    LineBox[{{5.39401071867388, 2.3025743134912293`}, {5.526073490783671, 
     2.3396342550977156`}}]}, 
   {Hue[0.6561979405449545], AbsoluteThickness[0.5], 
    LineBox[{{5.526073490783671, 2.3396342550977156`}, {5.668980988449335, 
     2.437994346955613}}]}, 
   {Hue[0.4782580804751381], AbsoluteThickness[0.5], 
    LineBox[{{5.11639912409441, 1.3727973890021874`}, {5.125680742242608, 
     1.368179474519234}}]}, 
   {Hue[0.47882691582515235`], AbsoluteThickness[0.5], 
    LineBox[{{5.125680742242608, 1.368179474519234}, {5.397778395803371, 
     1.2149688828508987`}}]}, 
   {Hue[0.6684152312650893], AbsoluteThickness[0.5], 
    LineBox[{{4.121700246132638, 0.6557821780153458}, {4.121582486599908, 
     0.6543497119348792}}]}, 
   {Hue[0.6697124903719941], AbsoluteThickness[0.5], 
    LineBox[{{4.121582486599908, 0.6543497119348792}, {4.071143539096906, 
     0.3973995733688912}}]}, 
   {Hue[0.6889714006941328], AbsoluteThickness[0.5], 
    LineBox[{{2.081693283977317, -1.169304508066604}, {
     2.08376228154328, -1.2478370874458165`}}]}, 
   {Hue[0.5563296215540816], AbsoluteThickness[0.5], 
    LineBox[{{5.67898607833694, 2.5521651430028407`}, {5.8853088638533375`, 
     2.519719366469188}}]}, 
   {Hue[0.5567563673588097], AbsoluteThickness[0.5], 
    LineBox[{{5.8853088638533375`, 2.519719366469188}, {6.215095120904238, 
     2.466439957889516}}]}, 
   {Hue[0.5035960217005857], AbsoluteThickness[0.5], 
    LineBox[{{5.594806016273934, 3.0594086291919242`}, {5.668888276517271, 
     3.262789686764737}}]}, 
   {Hue[0.5082636824390581], AbsoluteThickness[0.5], 
    LineBox[{{5.668888276517271, 3.262789686764737}, {5.755090428644162, 
     3.4048446215977908`}}]}, 
   {Hue[0.6267621486373006], AbsoluteThickness[0.5], 
    LineBox[{{5.104605520113022, 3.3432878158281074`}, {5.103933642588136, 
     3.3451321806277794`}}]}, 
   {Hue[0.6272395638009113], AbsoluteThickness[0.5], 
    LineBox[{{5.103933642588136, 3.3451321806277794`}, {5.005919397592576, 
     3.5899733280453776`}}]}, 
   {Hue[0.502497963919128], AbsoluteThickness[0.5], 
    LineBox[{{5.863187908244088, -0.3865853464737124}, {
     5.844631933204503, -0.5630525049548416}}]}, 
   {Hue[0.6101390562036522], AbsoluteThickness[0.5], 
    LineBox[{{6.57301106451763, -3.161012498151936}, {
     6.592903239248143, -3.1643427862064724`}}]}, 
   {Hue[0.6106101297570111], AbsoluteThickness[0.5], 
    LineBox[{{6.592903239248143, -3.1643427862064724`}, {
     6.909248710760159, -3.226945035051209}}]}, 
   {Hue[0.5645969379965347], AbsoluteThickness[0.5], 
    LineBox[{{6.5040977593809135`, -2.621749653850517}, {
     6.572064405288819, -2.902121930706667}}]}, 
   {Hue[0.5663152046710659], AbsoluteThickness[0.5], 
    LineBox[{{6.572064405288819, -2.902121930706667}, {
     6.597709276441529, -3.139054403924216}}]}, 
   {Hue[0.6539870846321406], AbsoluteThickness[0.5], 
    LineBox[{{2.0114709502235355`, -4.158585897221139}, {
     2.039007895578074, -4.249810937506771}}]}, 
   {Hue[0.6595671063610796], AbsoluteThickness[0.5], 
    LineBox[{{2.039007895578074, -4.249810937506771}, {
     2.136101595593632, -4.426803765304228}}]}, 
   {Hue[0.6166674834649906], AbsoluteThickness[0.5], 
    LineBox[{{4.117011463966711, 1.1898406687380232`}, {4.109350103570995, 
     1.1809525149927325`}}]}, 
   {Hue[0.6171298466323581], AbsoluteThickness[0.5], 
    LineBox[{{4.109350103570995, 1.1809525149927325`}, {3.9126037156760174`, 
     0.9400497728405409}}]}, 
   {Hue[0.6234446744420963], AbsoluteThickness[0.5], 
    LineBox[{{3.8570624548722, 2.544401331401697}, {3.618693829819333, 
     2.561458128259942}}]}, 
   {Hue[0.6240700301123318], AbsoluteThickness[0.5], 
    LineBox[{{3.618693829819333, 2.561458128259942}, {3.3272601388817984`, 
     2.564893456808081}}]}, 
   {Hue[0.6001768186748938], AbsoluteThickness[0.5], 
    LineBox[{{5.650185126947786, 2.1023147520081773`}, {5.64352347250828, 
     2.095936124973868}}]}, 
   {Hue[0.6006497308426222], AbsoluteThickness[0.5], 
    LineBox[{{5.64352347250828, 2.095936124973868}, {5.472079943310583, 
     1.9413839497817942`}}]}, 
   {Hue[0.580934296451877], AbsoluteThickness[0.5], 
    LineBox[{{6.329358695684978, 3.46437702431007}, {5.936178819655766, 
     3.680429469309238}}]}, 
   {Hue[0.5813604255483638], AbsoluteThickness[0.5], 
    LineBox[{{5.936178819655766, 3.680429469309238}, {5.630211614269072, 
     3.8476318279584887`}}]}, 
   {Hue[0.605487517301034], AbsoluteThickness[0.5], 
    LineBox[{{7.071917710051005, 3.162874425755288}, {6.98709464265656, 
     3.096227711922565}}]}, 
   {Hue[0.6184194334339606], AbsoluteThickness[0.5], 
    LineBox[{{6.98709464265656, 3.096227711922565}, {6.898242309253645, 
     2.9752548096697433`}}]}, 
   {Hue[0.34790512276449603`], AbsoluteThickness[0.5], 
    LineBox[{{7.773158465343258, 3.5786703846785697`}, {7.82847484785163, 
     3.5513768336302016`}}]}, 
   {Hue[0.3483327139320729], AbsoluteThickness[0.5], 
    LineBox[{{7.82847484785163, 3.5513768336302016`}, {8.121434815931508, 
     3.4089534552495677`}}]}, 
   {Hue[0.653956922499106], AbsoluteThickness[0.5], 
    LineBox[{{7.6604514382132205`, 3.8574606111180048`}, {7.440238067432641, 
     3.780767482112551}}]}, 
   {Hue[0.6543916106679691], AbsoluteThickness[0.5], 
    LineBox[{{7.440238067432641, 3.780767482112551}, {7.139653122319598, 
     3.671624584055357}}]}, 
   {Hue[0.6095322815461053], AbsoluteThickness[0.5], 
    LineBox[{{6.8599606263435575`, 3.3832138549220097`}, {6.859340339360481, 
     3.383252535983295}}]}, 
   {Hue[0.6109003186693746], AbsoluteThickness[0.5], 
    LineBox[{{6.859340339360481, 3.383252535983295}, {6.64775465860125, 
     3.372029593616976}}]}, 
   {Hue[0.5848630622201604], AbsoluteThickness[0.5], 
    LineBox[{{6.363186588319081, 1.9510299941773805`}, {6.329526563866309, 
     1.8705134635760547`}}]}, 
   {Hue[0.5852889197340265], AbsoluteThickness[0.5], 
    LineBox[{{6.329526563866309, 1.8705134635760547`}, {6.206648843783724, 
     1.5763679373743835`}}]}, 
   {Hue[0.6026598040243153], AbsoluteThickness[0.5], 
    LineBox[{{4.8335343415254055`, 3.0388091207575525`}, {4.67759894804999, 
     3.0449224721827264`}}]}, 
   {Hue[0.6031918752605622], AbsoluteThickness[0.5], 
    LineBox[{{4.67759894804999, 3.0449224721827264`}, {4.376437706556258, 
     3.0433267404645954`}}]}, 
   {Hue[0.6163657039947894], AbsoluteThickness[0.5], 
    LineBox[{{5.212702987534832, 1.6382768878787577`}, {5.140552145152831, 
     1.5929570312526327`}}]}, 
   {Hue[0.6167930678312415], AbsoluteThickness[0.5], 
    LineBox[{{5.140552145152831, 1.5929570312526327`}, {4.855671826111661, 
     1.4118413453612613`}}]}, 
   {Hue[0.5830985300527863], AbsoluteThickness[0.5], 
    LineBox[{{3.353326043150201, 3.482264864734766}, {3.1250902249581203`, 
     3.6319594340556796`}}]}, 
   {Hue[0.5943589299123889], AbsoluteThickness[0.5], 
    LineBox[{{3.1250902249581203`, 3.6319594340556796`}, {2.962206148706929, 
     3.685931457064358}}]}, 
   {Hue[0.6755384269142732], AbsoluteThickness[0.5], 
    LineBox[{{5.259192939370284, -0.37890936935633684`}, {
     5.237329102679356, -0.6166981646356489}}]}, 
   {Hue[0.6759711777525481], AbsoluteThickness[0.5], 
    LineBox[{{5.237329102679356, -0.6166981646356489}, {
     5.206861751990726, -0.9105020148394174}}]}, 
   {Hue[0.6306526626762868], AbsoluteThickness[0.5], 
    LineBox[{{3.603048087742365, 0.2148379396310841}, {3.561191866065692, 
     0.09894127369645093}}]}, 
   {Hue[0.6312242022154589], AbsoluteThickness[0.5], 
    LineBox[{{3.561191866065692, 0.09894127369645093}, {
     3.443592719859303, -0.18062871745977066`}}]}, 
   {Hue[0.6007770805470438], AbsoluteThickness[0.5], 
    LineBox[{{2.1886393392389287`, -0.4169637356993533}, {
     2.159874332831821, -0.4468120938874235}}]}, 
   {Hue[0.6021137957521155], AbsoluteThickness[0.5], 
    LineBox[{{2.159874332831821, -0.4468120938874235}, {
     1.9670437454925587`, -0.6059992505720451}}]}, 
   {Hue[0.6270107481837163], AbsoluteThickness[0.5], 
    LineBox[{{5.07358023395044, -2.093179708045068}, {
     5.025259879803827, -2.330382053222231}}]}, 
   {Hue[0.6274598126167442], AbsoluteThickness[0.5], 
    LineBox[{{5.025259879803827, -2.330382053222231}, {
     4.961279207451795, -2.613547491004378}}]}, 
   {Hue[0.42191800003363306`], AbsoluteThickness[0.5], 
    LineBox[{{7.308185128128607, 0.154456904406362}, {7.6000816555887045`, 
     0.2876338363349829}}]}, 
   {Hue[0.42392806507249553`], AbsoluteThickness[0.5], 
    LineBox[{{7.6000816555887045`, 0.2876338363349829}, {7.8373704666150825`, 
     0.3579038554164762}}]}, 
   {Hue[0.6468189765779994], AbsoluteThickness[0.5], 
    LineBox[{{6.5802317485468125`, 1.6422550315138007`}, {6.6282719383390525`,
      1.6778978991531306`}}]}, 
   {Hue[0.6474044270285035], AbsoluteThickness[0.5], 
    LineBox[{{6.6282719383390525`, 1.6778978991531306`}, {6.8408922287666085`,
      1.8185683634064385`}}]}, 
   {Hue[0.6142225785975559], AbsoluteThickness[0.5], 
    LineBox[{{4.507939832892837, -2.670937073928645}, {
     4.531699182739817, -2.844513118757678}}]}, 
   {Hue[0.6151433122037027], AbsoluteThickness[0.5], 
    LineBox[{{4.531699182739817, -2.844513118757678}, {
     4.54345942258864, -3.093626491191982}}]}, 
   {Hue[0.594019112666506], AbsoluteThickness[0.5], 
    LineBox[{{6.880104052986749, -1.144807751977019}, {
     6.886564933639233, -1.1997796855417935`}}]}, 
   {Hue[0.5967222211276364], AbsoluteThickness[0.5], 
    LineBox[{{6.886564933639233, -1.1997796855417935`}, {
     6.878172654199187, -1.3976314620617747`}}]}, 
   {Hue[0.3171381977278094], AbsoluteThickness[0.5], 
    LineBox[{{7.880670043153048, -0.8224727448413636}, {
     8.166597328755254, -0.9000455878932121}}]}, 
   {Hue[0.32364664575308255`], AbsoluteThickness[0.5], 
    LineBox[{{8.166597328755254, -0.9000455878932121}, {
     8.377781466990362, -0.9096298242187749}}]}, 
   {Hue[0.6051986487294532], AbsoluteThickness[0.5], 
    LineBox[{{8.377781466990362, -0.9096298242187749}, {
     8.447160011434354, -0.7099370216472173}}]}, 
   {Hue[0.6024335997407109], AbsoluteThickness[0.5], 
    LineBox[{{7.577874835180306, 0.6051284611839773}, {7.623544074181169, 
     0.7238507720779869}}]}, 
   {Hue[0.6055250106154512], AbsoluteThickness[0.5], 
    LineBox[{{7.623544074181169, 0.7238507720779869}, {7.739518327730417, 
     0.9193336434393964}}]}, 
   {Hue[0.5885579464785875], AbsoluteThickness[0.5], 
    LineBox[{{6.302711337739858, 0.44654363461627244`}, {6.340466142463547, 
     0.5026871586164836}}]}, 
   {Hue[0.5899109918485008], AbsoluteThickness[0.5], 
    LineBox[{{6.340466142463547, 0.5026871586164836}, {6.475641036853403, 
     0.661050925414534}}]}, 
   {Hue[0.40610377751252186`], AbsoluteThickness[0.5], 
    LineBox[{{5.878808672295261, -3.8559140554290106`}, {
     5.880807229444046, -3.859336705744433}}]}, 
   {Hue[0.40653658944656434`], AbsoluteThickness[0.5], 
    LineBox[{{5.880807229444046, -3.859336705744433}, {
     6.04082172643458, -4.1261568611775425`}}]}, 
   {Hue[0.6987357522764397], AbsoluteThickness[0.5], 
    LineBox[{{7.159310893986256, 0.4738546586489607}, {7.283606191542591, 
     0.43448894888455264`}}]}, 
   {Hue[0.6993608285874536], AbsoluteThickness[0.5], 
    LineBox[{{7.283606191542591, 0.43448894888455264`}, {7.609329008368893, 
     0.3523211392255329}}]}, 
   {Hue[0.5832518717928293], AbsoluteThickness[0.5], 
    LineBox[{{7.167347752578515, 1.0249884071210174`}, {7.191987384137254, 
     1.1046301381593198`}}]}, 
   {Hue[0.5837210601204808], AbsoluteThickness[0.5], 
    LineBox[{{7.191987384137254, 1.1046301381593198`}, {7.280531061134359, 
     1.4231266834695357`}}]}, 
   {Hue[0.6057900051515588], AbsoluteThickness[0.5], 
    LineBox[{{7.8546266865640595`, -0.14133457938006783`}, {
     7.921130180472336, -0.14864767681956315`}}]}, 
   {Hue[0.6111883516511314], AbsoluteThickness[0.5], 
    LineBox[{{7.921130180472336, -0.14864767681956315`}, {
     8.115495197179278, -0.12978836450045209`}}]}, 
   {Hue[0.6617910675328347], AbsoluteThickness[0.5], 
    LineBox[{{6.5966959731051595`, 2.619501207356274}, {6.597878405929595, 
     2.6240293451596544`}}]}, 
   {Hue[0.6625444574902087], AbsoluteThickness[0.5], 
    LineBox[{{6.597878405929595, 2.6240293451596544`}, {6.691897724535111, 
     2.898627414609461}}]}, 
   {Hue[0.640250788064906], AbsoluteThickness[0.5], 
    LineBox[{{6.643032610432254, 3.030039309534566}, {7.1065864901438305`, 
     3.125204171491069}}]}, 
   {Hue[0.6412898702889379], AbsoluteThickness[0.5], 
    LineBox[{{7.1065864901438305`, 3.125204171491069}, {7.375847657411202, 
     3.208379050095885}}]}, 
   {Hue[0.5196716943065656], AbsoluteThickness[0.5], 
    LineBox[{{3.313726285250286, -2.3483699737780213`}, {
     3.19524819722381, -2.5823656711035112`}}]}, 
   {Hue[0.5208091402129398], AbsoluteThickness[0.5], 
    LineBox[{{3.19524819722381, -2.5823656711035112`}, {
     3.098880981156591, -2.8341545261033}}]}, 
   {Hue[0.5281542854502912], AbsoluteThickness[0.5], 
    LineBox[{{5.530437087684105, -2.126576375659792}, {
     5.569306696930712, -2.2163709346922036`}}]}, 
   {Hue[0.5297290262808257], AbsoluteThickness[0.5], 
    LineBox[{{5.569306696930712, -2.2163709346922036`}, {
     5.692019106243056, -2.4244200686707953`}}]}, 
   {Hue[0.5600304042399608], AbsoluteThickness[0.5], 
    LineBox[{{4.161472469369289, 1.8611597178640045`}, {4.1612087843970835`, 
     1.8613374105256102`}}]}, 
   {Hue[0.5604753029173122], AbsoluteThickness[0.5], 
    LineBox[{{4.1612087843970835`, 1.8613374105256102`}, {3.891869768995597, 
     2.050490734928184}}]}, 
   {Hue[0.6034818346626126], AbsoluteThickness[0.5], 
    LineBox[{{6.636815982541633, -0.6847583976500393}, {
     6.662520160084867, -0.6951269204619983}}]}, 
   {Hue[0.6040526569094333], AbsoluteThickness[0.5], 
    LineBox[{{6.662520160084867, -0.6951269204619983}, {
     6.910252953942922, -0.810214142574577}}]}, 
   {Hue[0.4334850550498648], AbsoluteThickness[0.5], 
    LineBox[{{7.301021752762318, -0.4257239580760057}, {
     7.329583846174349, -0.44192570611836457`}}]}, 
   {Hue[0.4339682353602109], AbsoluteThickness[0.5], 
    LineBox[{{7.329583846174349, -0.44192570611836457`}, {
     7.591652825546645, -0.5793268949247641}}]}, 
   {Hue[0.6110481176486556], AbsoluteThickness[0.5], 
    LineBox[{{6.800981047292761, 1.4161617202549708`}, {6.828761189802619, 
     1.4706473153853625`}}]}, 
   {Hue[0.6122912595780498], AbsoluteThickness[0.5], 
    LineBox[{{6.828761189802619, 1.4706473153853625`}, {6.948407650623727, 
     1.6530561184669716`}}]}, 
   {Hue[0.4358763358900306], AbsoluteThickness[0.5], 
    LineBox[{{6.9727359361623815`, 0.6125725169885153}, {7.1548408851475225`, 
     0.6796349221985264}}]}, 
   {Hue[0.4365449153693683], AbsoluteThickness[0.5], 
    LineBox[{{7.1548408851475225`, 0.6796349221985264}, {7.413704082427893, 
     0.7946269072737185}}]}, 
   {Hue[0.36688437617100966`], AbsoluteThickness[0.5], 
    LineBox[{{7.124261249833905, 0.5559622483194528}, {7.286949308434228, 
     0.4180465453503094}}]}, 
   {Hue[0.36937542576422344`], AbsoluteThickness[0.5], 
    LineBox[{{7.286949308434228, 0.4180465453503094}, {7.50480514066982, 
     0.28473796934225265`}}]}, 
   {Hue[0.49964789854545927`], AbsoluteThickness[0.5], 
    LineBox[{{7.149588554323984, 0.39620251982286314`}, {7.1306716078876295`, 
     0.2969875681601553}}]}, 
   {Hue[0.5014650437217925], AbsoluteThickness[0.5], 
    LineBox[{{7.1306716078876295`, 0.2969875681601553}, {7.121207705261646, 
     0.124421371094444}}]}, 
   {Hue[0.632411420919911], AbsoluteThickness[0.5], 
    LineBox[{{7.023002276207817, 0.295502185192169}, {6.90793278603264, 
     0.25655474291280594`}}]}, 
   {Hue[0.6328726723616981], AbsoluteThickness[0.5], 
    LineBox[{{6.90793278603264, 0.25655474291280594`}, {6.6064471127504, 
     0.1632268817193362}}]}, 
   {Hue[0.6622491325384683], AbsoluteThickness[0.5], 
    LineBox[{{6.15878733027199, 1.6075752278604718`}, {6.149667461583674, 
     1.609648625537538}}]}, 
   {Hue[0.663777848416211], AbsoluteThickness[0.5], 
    LineBox[{{6.149667461583674, 1.609648625537538}, {5.910421260764438, 
     1.6339147951744553`}}]}, 
   {Hue[0.33079768114102115`], AbsoluteThickness[0.5], 
    LineBox[{{6.138161667657298, 1.8152616564018178`}, {6.142484126405598, 
     1.8689435945722732`}}]}, 
   {Hue[0.3324956287705719], AbsoluteThickness[0.5], 
    LineBox[{{6.142484126405598, 1.8689435945722732`}, {6.129646499554149, 
     2.1312779337183385`}}]}, 
   {Hue[0.6695498744572911], AbsoluteThickness[0.5], 
    LineBox[{{6.3407786300541105`, 1.865315997948213}, {6.412628270536646, 
     1.8698381865104927`}}]}, 
   {Hue[0.6709063021621435], AbsoluteThickness[0.5], 
    LineBox[{{6.412628270536646, 1.8698381865104927`}, {6.662178063456696, 
     1.9146235096829016`}}]}, 
   {Hue[0.5767354289377857], AbsoluteThickness[0.5], 
    LineBox[{{5.906572075113312, 1.6300280086229113`}, {5.822161638701561, 
     1.6692341661800316`}}]}, 
   {Hue[0.5771612835562053], AbsoluteThickness[0.5], 
    LineBox[{{5.822161638701561, 1.6692341661800316`}, {5.6012266185365265`, 
     1.7718238781726001`}}]}, 
   {Hue[0.5903701042382715], AbsoluteThickness[0.5], 
    LineBox[{{6.86588060212735, 1.4153193360404541`}, {6.853683886906552, 
     1.3736655186343547`}}]}, 
   {Hue[0.5912001448337523], AbsoluteThickness[0.5], 
    LineBox[{{6.853683886906552, 1.3736655186343547`}, {6.752465187692428, 
     1.1098884940926201`}}]}, 
   {Hue[0.07331170296106468], AbsoluteThickness[0.5], 
    LineBox[{{7.093669848121032, 1.524370002952304}, {7.1713417341219925`, 
     1.5672332409803995`}}]}, 
   {Hue[0.07423370752259172], AbsoluteThickness[0.5], 
    LineBox[{{7.1713417341219925`, 1.5672332409803995`}, {7.402324571261527, 
     1.7229689355963524`}}]}, 
   {Hue[0.5511102583910733], AbsoluteThickness[0.5], 
    LineBox[{{7.402324571261527, 1.7229689355963524`}, {7.160882952162815, 
     1.861938796348728}}]}, 
   {Hue[0.5915938774937346], AbsoluteThickness[0.5], 
    LineBox[{{6.855177941768478, 1.6074458667673364`}, {6.854851855008272, 
     1.6075387250942355`}}]}, 
   {Hue[0.592320953994834], AbsoluteThickness[0.5], 
    LineBox[{{6.854851855008272, 1.6075387250942355`}, {6.626059789910555, 
     1.690843101632873}}]}, 
   {Hue[0.5788731950985946], AbsoluteThickness[0.5], 
    LineBox[{{6.651825482761823, 0.6123048848944155}, {6.623390496292902, 
     0.3390908053378923}}]}, 
   {Hue[0.5819087006510433], AbsoluteThickness[0.5], 
    LineBox[{{6.623390496292902, 0.3390908053378923}, {6.637122142212859, 
     0.12252587693930486`}}]}, 
   {Hue[0.6350470015466507], AbsoluteThickness[0.5], 
    LineBox[{{6.923015174258299, 0.8665829416559168}, {7.282681354150403, 
     0.44125248525526883`}}]}, 
   {Hue[0.6379533777827091], AbsoluteThickness[0.5], 
    LineBox[{{7.282681354150403, 0.44125248525526883`}, {7.471984697019943, 
     0.280277420153079}}]}, 
   {Hue[0.5022038256306045], AbsoluteThickness[0.5], 
    LineBox[{{7.085580595820903, 0.854002837459179}, {7.115192976271737, 
     0.8609433990142377}}]}, 
   {Hue[0.5031372184530765], AbsoluteThickness[0.5], 
    LineBox[{{7.115192976271737, 0.8609433990142377}, {7.3767971009306486`, 
     0.8979203433837606}}]}, 
   {Hue[0.6755078759984606], AbsoluteThickness[0.5], 
    LineBox[{{7.170659445319794, 0.9930976420975011}, {7.198057946306266, 
     1.1043377007780222`}}]}, 
   {Hue[0.6759687544545804], AbsoluteThickness[0.5], 
    LineBox[{{7.198057946306266, 1.1043377007780222`}, {7.2690121445846865`, 
     1.4285283340357744`}}]}, 
   {Hue[0.40903959703458004`], AbsoluteThickness[0.5], 
    LineBox[{{7.009858902157705, 0.29414605418169715`}, {7.031775453222543, 
     0.1602108172311511}}]}, 
   {Hue[0.40947579942889184`], AbsoluteThickness[0.5], 
    LineBox[{{7.031775453222543, 0.1602108172311511}, {
     7.0659382503118, -0.06900653153683413}}]}, 
   {Hue[0.541315654067724], AbsoluteThickness[0.5], 
    LineBox[{{6.201895108699225, 0.13404720825810232`}, {6.164429652985627, 
     0.12357511368605784`}}]}, 
   {Hue[0.541856590384919], AbsoluteThickness[0.5], 
    LineBox[{{6.164429652985627, 0.12357511368605784`}, {5.850860910963141, 
     0.020093843438103307`}}]}, 
   {Hue[0.6572930809725256], AbsoluteThickness[0.5], 
    LineBox[{{6.181246054674641, 0.7920159441033328}, {6.125455509733436, 
     0.812889020653937}}]}, 
   {Hue[0.6583463443446566], AbsoluteThickness[0.5], 
    LineBox[{{6.125455509733436, 0.812889020653937}, {5.877369095129161, 
     0.9345830477685935}}]}, 
   {Hue[0.6076097534072423], AbsoluteThickness[0.5], 
    LineBox[{{6.265601130014972, 0.13252449683787532`}, {6.198562193382331, 
     0.013481716467197535`}}]}, 
   {Hue[0.6124797644458445], AbsoluteThickness[0.5], 
    LineBox[{{6.198562193382331, 0.013481716467197535`}, {
     6.056602913067607, -0.1510339795213436}}]}, 
   {Hue[0.3227985476241286], AbsoluteThickness[0.5], 
    LineBox[{{5.281549217936705, 2.393662979524827}, {5.184125349479772, 
     2.5117135714477112`}}]}, 
   {Hue[0.32380066893377935`], AbsoluteThickness[0.5], 
    LineBox[{{5.184125349479772, 2.5117135714477112`}, {5.021321546827152, 
     2.674766329649607}}]}, 
   {Hue[0.5816678880737155], AbsoluteThickness[0.5], 
    LineBox[{{4.661774242871442, 0.5853348539934812}, {4.635929846874104, 
     0.5765460927802402}}]}, 
   {Hue[0.5823892710326531], AbsoluteThickness[0.5], 
    LineBox[{{4.635929846874104, 0.5765460927802402}, {4.41344621305268, 
     0.48275493892262417`}}]}, 
   {Hue[0.3970017298898931], AbsoluteThickness[0.5], 
    LineBox[{{5.030779336044413, 2.676347147327998}, {4.910066605830011, 
     2.851416128255608}}]}, 
   {Hue[0.40226334994079127`], AbsoluteThickness[0.5], 
    LineBox[{{4.910066605830011, 2.851416128255608}, {4.832518333151736, 
     3.035242643737927}}]}, 
   {Hue[0.5504378528651853], AbsoluteThickness[0.5], 
    LineBox[{{4.124661105416246, -2.3387340168825825`}, {
     4.10541153449713, -2.381324927303682}}]}, 
   {Hue[0.5510707152336373], AbsoluteThickness[0.5], 
    LineBox[{{4.10541153449713, -2.381324927303682}, {
     3.965443688620002, -2.6468334956355664`}}]}, 
   {Hue[0.5414327946821038], AbsoluteThickness[0.5], 
    LineBox[{{3.3029927365134313`, 2.392105076645819}, {3.2068984881653346`, 
     2.5570227778147667`}}]}, 
   {Hue[0.5650479458282142], AbsoluteThickness[0.5], 
    LineBox[{{3.2068984881653346`, 2.5570227778147667`}, {3.0617982060428366`,
      2.685031388046329}}]}, 
   {Hue[0.6910896789268466], AbsoluteThickness[0.5], 
    LineBox[{{2.343762746750923, 1.942814293537967}, {2.1591989007264, 
     2.0591200636459273`}}]}, 
   {Hue[0.6921051159649123], AbsoluteThickness[0.5], 
    LineBox[{{2.1591989007264, 2.0591200636459273`}, {1.9481999003918455`, 
     2.1654359797360208`}}]}, 
   {Hue[0.6219380434960795], AbsoluteThickness[0.5], 
    LineBox[{{4.2181607665763075`, -2.3845840937373826`}, {
     4.016210456355375, -2.9045961971267107`}}]}, 
   {Hue[0.6226202022763814], AbsoluteThickness[0.5], 
    LineBox[{{4.016210456355375, -2.9045961971267107`}, {
     3.941898177482209, -3.1417717106772582`}}]}, 
   {Hue[0.40698780435966303`], AbsoluteThickness[0.5], 
    LineBox[{{4.98706238472236, -2.6130891036376314`}, {
     5.06492117152495, -2.8369705179242892`}}]}, 
   {Hue[0.40835241358568336`], AbsoluteThickness[0.5], 
    LineBox[{{5.06492117152495, -2.8369705179242892`}, {
     5.11847046710034, -3.076913919542624}}]}, 
   {Hue[0.6366827504784417], AbsoluteThickness[0.5], 
    LineBox[{{5.904669138379134, -1.659887120277511}, {
     6.4096092818631485`, -1.584042869736672}}]}, 
   {Hue[0.6371742653736305], AbsoluteThickness[0.5], 
    LineBox[{{6.4096092818631485`, -1.584042869736672}, {
     6.678316212899568, -1.533915608636902}}]}, 
   {Hue[0.6894879907218021], AbsoluteThickness[0.5], 
    LineBox[{{3.2845361695773225`, -3.451930118639752}, {
     3.264239047182039, -3.5816793285018016`}}]}, 
   {Hue[0.6899846328170866], AbsoluteThickness[0.5], 
    LineBox[{{3.264239047182039, -3.5816793285018016`}, {
     3.2245010859309735`, -3.915360346702302}}]}, 
   {Hue[0.6661386601905864], AbsoluteThickness[0.5], 
    LineBox[{{4.098707237603652, -3.594779469366155}, {
     4.113745362355316, -3.693349721043314}}]}, 
   {Hue[0.6672374709602773], AbsoluteThickness[0.5], 
    LineBox[{{4.113745362355316, -3.693349721043314}, {
     4.167958697336765, -3.9036804150824103`}}]}, 
   {Hue[0.37471331299208765`], AbsoluteThickness[0.5], 
    LineBox[{{7.094434272406804, -1.507168333288381}, {
     7.33759408490105, -1.4498772522078571`}}]}, 
   {Hue[0.37563302986501373`], AbsoluteThickness[0.5], 
    LineBox[{{7.33759408490105, -1.4498772522078571`}, {
     7.601027565382564, -1.4120536737927514`}}]}, 
   {Hue[0.6644206232782378], AbsoluteThickness[0.5], 
    LineBox[{{4.621049234263878, 2.11142933026245}, {4.492044644763469, 
     2.3063031340404367`}}]}, 
   {Hue[0.665193952206972], AbsoluteThickness[0.5], 
    LineBox[{{4.492044644763469, 2.3063031340404367`}, {4.356680650977259, 
     2.5492351995807776`}}]}, 
   {Hue[0.6456859272103339], AbsoluteThickness[0.5], 
    LineBox[{{7.323467037101664, -1.6751611621407192`}, {
     7.680401347659828, -1.7029222872433023`}}]}, 
   {Hue[0.6464261038293984], AbsoluteThickness[0.5], 
    LineBox[{{7.680401347659828, -1.7029222872433023`}, {
     7.934776382695046, -1.7415599206446053`}}]}, 
   {Hue[0.6419072092692062], AbsoluteThickness[0.5], 
    LineBox[{{3.695805809785824, 2.866527677746259}, {3.6869953932623454`, 
     3.1204700391325453`}}]}, 
   {Hue[0.6427845596475645], AbsoluteThickness[0.5], 
    LineBox[{{3.6869953932623454`, 3.1204700391325453`}, {3.7017774712606606`,
      3.4111450163654986`}}]}, 
   {Hue[0.5911066361397342], AbsoluteThickness[0.5], 
    LineBox[{{7.171848511095581, -4.466470844256226}, {
     7.374507349316423, -4.49252361638569}}]}, 
   {Hue[0.5915405854027502], AbsoluteThickness[0.5], 
    LineBox[{{7.374507349316423, -4.49252361638569}, {
     7.666327745158103, -4.5263042505964926`}}]}, 
   {Hue[0.538158887568632], AbsoluteThickness[0.5], 
    LineBox[{{4.4017533533104976`, 1.46527486956323}, {4.373303634451374, 
     1.6090590629268038`}}]}, 
   {Hue[0.538733555385572], AbsoluteThickness[0.5], 
    LineBox[{{4.373303634451374, 1.6090590629268038`}, {4.329704555767314, 
     1.9113776743296644`}}]}, 
   {Hue[0.5291530276659197], AbsoluteThickness[0.5], 
    LineBox[{{5.5675038681376, 2.670410151123271}, {5.578767199827133, 
     2.691963562036642}}]}, 
   {Hue[0.5297720454958875], AbsoluteThickness[0.5], 
    LineBox[{{5.578767199827133, 2.691963562036642}, {5.695537779149067, 
     2.9515108698623704`}}]}, 
   {Hue[0.4685230219391094], AbsoluteThickness[0.5], 
    LineBox[{{6.8682424534576745`, -4.259391979326185}, {
     6.925035630888107, -4.340225626196848}}]}, 
   {Hue[0.46899391591034595`], AbsoluteThickness[0.5], 
    LineBox[{{6.925035630888107, -4.340225626196848}, {
     7.124298827398118, -4.642363448150974}}]}, 
   {Hue[0.5495829597915252], AbsoluteThickness[0.5], 
    LineBox[{{4.0297919191832205`, -0.6375176141917281}, {
     3.938241068289987, -0.7572847800725618}}]}, 
   {Hue[0.5542417158166427], AbsoluteThickness[0.5], 
    LineBox[{{3.938241068289987, -0.7572847800725618}, {
     3.793892028169414, -0.884442745485643}}]}, 
   {Hue[0.5654467874813909], AbsoluteThickness[0.5], 
    LineBox[{{4.289286091294092, -0.41655710818901154`}, {
     4.189509115331509, -0.6447313243517765}}]}, 
   {Hue[0.5682172200854928], AbsoluteThickness[0.5], 
    LineBox[{{4.189509115331509, -0.6447313243517765}, {
     4.136815177225127, -0.8500443532867662}}]}, 
   {Hue[0.4438511231618471], AbsoluteThickness[0.5], 
    LineBox[{{6.419911009220153, 0.6769187691717595}, {6.441766750751875, 
     0.6580077950733911}}]}, 
   {Hue[0.4447562194594398], AbsoluteThickness[0.5], 
    LineBox[{{6.441766750751875, 0.6580077950733911}, {6.598923364376289, 
     0.4958819657231898}}]}, 
   {Hue[0.5344788984160806], AbsoluteThickness[0.5], 
    LineBox[{{4.379646651025986, 1.937982657496769}, {4.202689923803201, 
     1.9424714224315633`}}]}, 
   {Hue[0.5349269109012219], AbsoluteThickness[0.5], 
    LineBox[{{4.202689923803201, 1.9424714224315633`}, {3.874416828245021, 
     1.9576276360098128`}}]}, 
   {Hue[0.4873638254989536], AbsoluteThickness[0.5], 
    LineBox[{{5.196625391513515, 2.392068266809049}, {5.084101946889524, 
     2.4058690500966513`}}]}, 
   {Hue[0.4955811476794922], AbsoluteThickness[0.5], 
    LineBox[{{5.084101946889524, 2.4058690500966513`}, {4.934425242033932, 
     2.461981246706217}}]}, 
   {Hue[0.5312472149296403], AbsoluteThickness[0.5], 
    LineBox[{{5.884936412882811, 2.4584498492918745`}, {5.683439682239791, 
     2.5284772814258223`}}]}, 
   {Hue[0.5318597715433907], AbsoluteThickness[0.5], 
    LineBox[{{5.683439682239791, 2.5284772814258223`}, {5.381505336890114, 
     2.614193283771849}}]}, 
   {Hue[0.025901795103941493`], AbsoluteThickness[0.5], 
    LineBox[{{6.129726388989648, 2.6346189782149056`}, {6.380285951415324, 
     2.790508259713016}}]}, 
   {Hue[0.5371288677498818], AbsoluteThickness[0.5], 
    LineBox[{{6.380285951415324, 2.790508259713016}, {6.1110018217393485`, 
     2.9111380726361253`}}]}, 
   {Hue[0.532619382496853], AbsoluteThickness[0.5], 
    LineBox[{{6.112860660048427, 2.3334989995101267`}, {6.09071761109892, 
     2.1546803890232913`}}]}, 
   {Hue[0.53311272930523], AbsoluteThickness[0.5], 
    LineBox[{{6.09071761109892, 2.1546803890232913`}, {6.037121457755522, 
     1.8204748728262978`}}]}, 
   {Hue[0.47800677933464647`], AbsoluteThickness[0.5], 
    LineBox[{{5.987623434108285, 1.8229200724093193`}, {6.133381975343982, 
     1.629843470142983}}]}, 
   {Hue[0.5355942029851191], AbsoluteThickness[0.5], 
    LineBox[{{6.133381975343982, 1.629843470142983}, {6.171449462576855, 
     1.4814766454007846`}}]}, 
   {Hue[0.6203445351570328], AbsoluteThickness[0.5], 
    LineBox[{{6.171449462576855, 1.4814766454007846`}, {6.06488059020504, 
     1.3714542671784113`}}]}, 
   {Hue[0.5362039210829349], AbsoluteThickness[0.5], 
    LineBox[{{5.841556265712472, 1.08352780933259}, {5.876117871452808, 
     0.946026212397528}}]}, 
   {Hue[0.570976894743762], AbsoluteThickness[0.5], 
    LineBox[{{5.8761178714528075`, 0.946026212397528}, {5.970680495622673, 
     0.8075797189555547}}]}, 
   {Hue[0.6963185901295714], AbsoluteThickness[0.5], 
    LineBox[{{5.970680495622673, 0.8075797189555547}, {6.137830693222841, 
     0.8206308828306335}}]}, 
   {Hue[0.44925843477232813`], AbsoluteThickness[0.5], 
    LineBox[{{3.857910094936058, 2.4727676927602973`}, {3.4535669635723747`, 
     2.7572521867829813`}}]}, 
   {Hue[0.4500310229819585], AbsoluteThickness[0.5], 
    LineBox[{{3.4535669635723747`, 2.7572521867829813`}, {3.2140370835863243`,
      2.899791381213015}}]}, 
   {Hue[0.5807521304283305], AbsoluteThickness[0.5], 
    LineBox[{{3.4074647741395303`, 1.100868100585285}, {3.1917652078885013`, 
     0.9445753687365126}}]}, 
   {Hue[0.582713550976313], AbsoluteThickness[0.5], 
    LineBox[{{3.1917652078885013`, 0.9445753687365126}, {2.9652896535439273`, 
     0.8242148133160775}}]}, 
   {Hue[0.5335922018843342], AbsoluteThickness[0.5], 
    LineBox[{{2.3442146370442005`, 1.9403559693066417`}, {2.1503270600253503`,
      1.989744822328481}}]}, 
   {Hue[0.5340302591772371], AbsoluteThickness[0.5], 
    LineBox[{{2.1503270600253503`, 1.989744822328481}, {1.8778961993820098`, 
     2.0636446539298334`}}]}, 
   {Hue[0.5793336771279732], AbsoluteThickness[0.5], 
    LineBox[{{2.3087350126270367`, -1.0346811505942586`}, {
     2.264615738304449, -1.1319906148284948`}}]}, 
   {Hue[0.5798095586638781], AbsoluteThickness[0.5], 
    LineBox[{{2.264615738304449, -1.1319906148284948`}, {
     2.1457291700392247`, -1.4173965861641962`}}]}, 
   {Hue[0.49916782938056237`], AbsoluteThickness[0.5], 
    LineBox[{{5.461249524104117, -2.6257436817870565`}, {
     5.568377298491135, -2.8079328153849126`}}]}, 
   {Hue[0.5136788385190818], AbsoluteThickness[0.5], 
    LineBox[{{5.568377298491135, -2.8079328153849126`}, {
     5.679390213696134, -2.91318799329737}}]}, 
   {Hue[0.62491585485491], AbsoluteThickness[0.5], 
    LineBox[{{4.714104199254343, -2.9330594058373904`}, {
     4.862714787622306, -3.0595223634126265`}}]}, 
   {Hue[0.6368262075861848], AbsoluteThickness[0.5], 
    LineBox[{{4.862714787622306, -3.0595223634126265`}, {
     5.019320383757114, -3.1332816674277235`}}]}, 
   {Hue[0.6058273575485181], AbsoluteThickness[0.5], 
    LineBox[{{2.5228785156480416`, -3.1060300197478097`}, {
     2.4344697137835114`, -3.173823070760175}}]}, 
   {Hue[0.6064138897491418], AbsoluteThickness[0.5], 
    LineBox[{{2.4344697137835114`, -3.173823070760175}, {
     2.201375846667205, -3.3333508196755988`}}]}, 
   {Hue[0.530452430246193], AbsoluteThickness[0.5], 
    LineBox[{{4.510414066612559, -4.161751528114774}, {
     4.526796226197812, -4.363540017080481}}]}, 
   {Hue[0.5310461551952023], AbsoluteThickness[0.5], 
    LineBox[{{4.526796226197812, -4.363540017080481}, {
     4.535489378086449, -4.699079505227689}}]}, 
   {Hue[0.49426776640345077`], AbsoluteThickness[0.5], 
    LineBox[{{5.712142858728008, -3.4327634707051033`}, {
     5.677463037508224, -3.6269476269405474`}}]}, 
   {Hue[0.495275214665063], AbsoluteThickness[0.5], 
    LineBox[{{5.677463037508224, -3.6269476269405474`}, {
     5.656233227837493, -3.8862284908205975`}}]}, 
   {Hue[0.5626137745675296], AbsoluteThickness[0.5], 
    LineBox[{{4.941106411937431, -2.610713824372934}, {
     4.920447846077698, -2.8411607083625556`}}]}, 
   {Hue[0.5634332479261821], AbsoluteThickness[0.5], 
    LineBox[{{4.920447846077698, -2.8411607083625556`}, {
     4.918055268610592, -3.1137571390036975`}}]}, 
   {Hue[0.580373360176483], AbsoluteThickness[0.5], 
    LineBox[{{3.6886031705493783`, -0.4115032874689321}, {
     3.655275081869369, -0.42806560440972574`}}]}, 
   {Hue[0.5808344576926047], AbsoluteThickness[0.5], 
    LineBox[{{3.655275081869369, -0.42806560440972574`}, {
     3.369238487905497, -0.5796465797694774}}]}, 
   {Hue[0.46289187169594476`], AbsoluteThickness[0.5], 
    LineBox[{{7.056618119712267, 0.84268477071087}, {7.106570400029819, 
     0.7577961924881375}}]}, 
   {Hue[0.4786843066969929], AbsoluteThickness[0.5], 
    LineBox[{{7.106570400029819, 0.7577961924881375}, {7.22859843104247, 
     0.6437345447726576}}]}, 
   {Hue[0.6749391235701002], AbsoluteThickness[0.5], 
    LineBox[{{7.22859843104247, 0.6437345447726576}, {7.38387409082862, 
     0.7053005200379826}}]}, 
   {Hue[0.686723694073854], AbsoluteThickness[0.5], 
    LineBox[{{5.5647158787587605`, 3.6857683027575874`}, {5.607432685986307, 
     3.762749280037168}}]}, 
   {Hue[0.6910514816623744], AbsoluteThickness[0.5], 
    LineBox[{{5.607432685986307, 3.762749280037168}, {5.750021816859751, 
     3.9328997953405174`}}]}, 
   {Hue[0.32419557914001973`], AbsoluteThickness[0.5], 
    LineBox[{{4.92344151322571, 3.5430974150242442`}, {4.8399750201208125`, 
     3.5873885422680316`}}]}, 
   {Hue[0.3251586397064317], AbsoluteThickness[0.5], 
    LineBox[{{4.8399750201208125`, 3.5873885422680316`}, {4.629001932081449, 
     3.7255581614965347`}}]}, 
   {Hue[0.6926278185973155], AbsoluteThickness[0.5], 
    LineBox[{{4.856593554957436, 2.8992955446024955`}, {4.8537110500346206`, 
     2.893505160186801}}]}, 
   {Hue[0.6931006024456393], AbsoluteThickness[0.5], 
    LineBox[{{4.8537110500346206`, 2.893505160186801}, {4.707777054944674, 
     2.6211681366309105`}}]}, 
   {Hue[0.554931120282283], AbsoluteThickness[0.5], 
    LineBox[{{4.593327904888156, 2.777723990238855}, {4.428047037238906, 
     2.763370851989755}}]}, 
   {Hue[0.5554343170331196], AbsoluteThickness[0.5], 
    LineBox[{{4.428047037238906, 2.763370851989755}, {4.115486524453757, 
     2.7482356002086603`}}]}, 
   {Hue[0.5020790478929273], AbsoluteThickness[0.5], 
    LineBox[{{5.3363388708132575`, 3.6064017829104773`}, {5.323829765497887, 
     3.61219544274007}}]}, 
   {Hue[0.502883025515948], AbsoluteThickness[0.5], 
    LineBox[{{5.323829765497887, 3.61219544274007}, {5.057927451576063, 
     3.7619747970657627`}}]}, 
   {Hue[0.573741816639981], AbsoluteThickness[0.5], 
    LineBox[{{6.484085620914714, 2.8086764783587337`}, {6.401549048321953, 
     2.667908671568066}}]}, 
   {Hue[0.5760404740280174], AbsoluteThickness[0.5], 
    LineBox[{{6.401549048321953, 2.667908671568066}, {6.31288380818695, 
     2.4468796855628687`}}]}, 
   {Hue[0.48213126086161917`], AbsoluteThickness[0.5], 
    LineBox[{{6.922006080976466, 3.351254167915466}, {7.0767127570539765`, 
     3.0985607828905835`}}]}, 
   {Hue[0.4838677309490244], AbsoluteThickness[0.5], 
    LineBox[{{7.0767127570539765`, 3.0985607828905835`}, {7.16021407138392, 
     2.910910368175072}}]}, 
   {Hue[0.04076417496190505], AbsoluteThickness[0.5], 
    LineBox[{{7.085809987709163, 3.4901097008981803`}, {7.184929342423349, 
     3.5950695805290787`}}]}, 
   {Hue[0.04119002931792445], AbsoluteThickness[0.5], 
    LineBox[{{7.184929342423349, 3.5950695805290787`}, {7.405462989726377, 
     3.82863349191544}}]}, 
   {Hue[0.5961194297441387], AbsoluteThickness[0.5], 
    LineBox[{{7.405462989726377, 3.82863349191544}, {7.184673460553426, 
     3.595311452445399}}]}, 
   {Hue[0.48468812487545404`], AbsoluteThickness[0.5], 
    LineBox[{{6.908943011069066, 3.6118908631319147`}, {6.854369860157847, 
     3.6411498626507304`}}]}, 
   {Hue[0.48514575304281454`], AbsoluteThickness[0.5], 
    LineBox[{{6.854369860157847, 3.6411498626507304`}, {6.560805073135587, 
     3.8080483109659182`}}]}, 
   {Hue[0.5753483565213942], AbsoluteThickness[0.5], 
    LineBox[{{6.128399606312667, 3.303249660698134}, {5.930836621471983, 
     3.263908230259783}}]}, 
   {Hue[0.5758610512811771], AbsoluteThickness[0.5], 
    LineBox[{{5.930836621471983, 3.263908230259783}, {5.680189173199461, 
     3.224450026102771}}]}, 
   {Hue[0.5025807328388081], AbsoluteThickness[0.5], 
    LineBox[{{6.818222922356668, 2.104560414048737}, {6.967687836694678, 
     1.6529515100908023`}}]}, 
   {Hue[0.5031444938279939], AbsoluteThickness[0.5], 
    LineBox[{{6.967687836694678, 1.6529515100908023`}, {7.036072613088459, 
     1.4052017722240022`}}]}, 
   {Hue[0.5547981916343468], AbsoluteThickness[0.5], 
    LineBox[{{6.251131608875174, 1.1200558308715454`}, {6.236181719412194, 
     0.8474189910818072}}]}, 
   {Hue[0.5555306424167147], AbsoluteThickness[0.5], 
    LineBox[{{6.236181719412194, 0.8474189910818072}, {6.24032129301724, 
     0.6114943942542783}}]}, 
   {Hue[0.33524149588908175`], AbsoluteThickness[0.5], 
    LineBox[{{7.940716569850648, 1.7511483361603677`}, {8.111021728893364, 
     1.679515389246104}}]}, 
   {Hue[0.3374403668063666], AbsoluteThickness[0.5], 
    LineBox[{{8.111021728893364, 1.679515389246104}, {8.307638247551502, 
     1.6288465342009568`}}]}, 
   {Hue[0.6793732368200943], AbsoluteThickness[0.5], 
    LineBox[{{6.149159592329257, 1.432920447901706}, {6.14651109979753, 
     1.4150232238697515`}}]}, 
   {Hue[0.6801132896223488], AbsoluteThickness[0.5], 
    LineBox[{{6.14651109979753, 1.4150232238697515`}, {6.125973392619561, 
     1.1372774693986152`}}]}, 
   {Hue[0.4602028636281624], AbsoluteThickness[0.5], 
    LineBox[{{3.140796824006409, 2.1810475011681056`}, {2.88799735068067, 
     2.213163563874684}}]}, 
   {Hue[0.46063516391812953`], AbsoluteThickness[0.5], 
    LineBox[{{2.88799735068067, 2.213163563874684}, {2.535869208967545, 
     2.2619321249728177`}}]}, 
   {Hue[0.6336662134654213], AbsoluteThickness[0.5], 
    LineBox[{{5.578497901415817, -1.1622676241185033`}, {
     5.600616732500492, -1.2087593620831791`}}]}, 
   {Hue[0.6407954435794576], AbsoluteThickness[0.5], 
    LineBox[{{5.600616732500492, -1.2087593620831791`}, {
     5.717349801914242, -1.3560279734229912`}}]}, 
   {Hue[0.5727155381775839], AbsoluteThickness[0.5], 
    LineBox[{{7.834018473127194, -4.37740761211912}, {
     7.860575480744936, -4.383982308176037}}]}, 
   {Hue[0.5734114579036065], AbsoluteThickness[0.5], 
    LineBox[{{7.860575480744936, -4.383982308176037}, {
     8.15465960642248, -4.478530175230115}}]}, 
   {Hue[0.6479006439248248], AbsoluteThickness[0.5], 
    LineBox[{{6.9211764478180635`, -1.310246915725767}, {
     7.32840579007605, -1.54849212345228}}]}, 
   {Hue[0.6491555071482558], AbsoluteThickness[0.5], 
    LineBox[{{7.32840579007605, -1.54849212345228}, {
     7.556633694946215, -1.6503326565423853`}}]}, 
   {Hue[0.5243366166517351], AbsoluteThickness[0.5], 
    LineBox[{{7.904497148023356, 0.8807691391392298}, {7.966080597518681, 
     0.892713731880143}}]}, 
   {Hue[0.5270864364329385], AbsoluteThickness[0.5], 
    LineBox[{{7.966080597518681, 0.892713731880143}, {8.178288251225302, 
     0.9706782509751182}}]}, 
   {Hue[0.4837322843451157], AbsoluteThickness[0.5], 
    LineBox[{{6.919966331184247, 2.2212040573780865`}, {7.052057816300141, 
     2.297271157464445}}]}, 
   {Hue[0.4848623271863569], AbsoluteThickness[0.5], 
    LineBox[{{7.052057816300141, 2.297271157464445}, {7.282726334575455, 
     2.400213277866814}}]}, 
   {Hue[0.3071320001262854], AbsoluteThickness[0.5], 
    LineBox[{{6.293528047281662, 2.9259358820069323`}, {6.303555961640977, 
     3.0646524154828247`}}]}, 
   {Hue[0.30760008486236823`], AbsoluteThickness[0.5], 
    LineBox[{{6.303555961640977, 3.0646524154828247`}, {6.317775973003887, 
     3.3902650168562634`}}]}, 
   {Hue[0.5170648882112264], AbsoluteThickness[0.5], 
    LineBox[{{5.107612553308031, 2.3311626032181527`}, {4.883616233051652, 
     2.3025145897336494`}}]}, 
   {Hue[0.517506394187905], AbsoluteThickness[0.5], 
    LineBox[{{4.883616233051652, 2.3025145897336494`}, {4.573343818916358, 
     2.2573028258669767`}}]}, 
   {Hue[0.6693379883593223], AbsoluteThickness[0.5], 
    LineBox[{{5.13352786984925, 3.3674628919146667`}, {5.140213403570508, 
     3.382209311908974}}]}, 
   {Hue[0.6127783945062963], AbsoluteThickness[0.5], 
    LineBox[{{3.3153511117860948`, -3.447141188437976}, {
     3.3552531246179096`, -3.5934222994399425`}}]}, 
   {Hue[0.6137366338299709], AbsoluteThickness[0.5], 
    LineBox[{{3.3552531246179096`, -3.5934222994399425`}, {
     3.4060892046090165`, -3.8814786394256395`}}]}, 
   {Hue[0.6044193720333799], AbsoluteThickness[0.5], 
    LineBox[{{6.910706807014745, -0.7949791373091479}, {
     7.070828128952637, -0.8536773617912177}}]}, 
   {Hue[0.6061852465006687], AbsoluteThickness[0.5], 
    LineBox[{{7.070828128952637, -0.8536773617912177}, {
     7.3425803584284415`, -0.914332636399622}}]}, 
   {Hue[0.6092451088475866], AbsoluteThickness[0.5], 
    LineBox[{{4.637075549499139, -1.0598563333570816`}, {
     4.637022960342147, -1.073256090060538}}]}, 
   {Hue[0.6098983723092457], AbsoluteThickness[0.5], 
    LineBox[{{4.637022960342147, -1.073256090060538}, {
     4.653979532192287, -1.358505314228561}}]}, 
   {Hue[0.5922947655120966], AbsoluteThickness[0.5], 
    LineBox[{{2.4488608051482226`, -0.6682448631716018}, {
     2.488399389203851, -0.8530521580717095}}]}, 
   {Hue[0.5927565155756029], AbsoluteThickness[0.5], 
    LineBox[{{2.488399389203851, -0.8530521580717095}, {
     2.5529457093690726`, -1.1990597241502436`}}]}, 
   {Hue[0.5404193104092092], AbsoluteThickness[0.5], 
    LineBox[{{4.119043863728996, 1.8286690149427338`}, {4.133287762037923, 
     1.816872242365836}}]}, 
   {Hue[0.5409104243079741], AbsoluteThickness[0.5], 
    LineBox[{{4.133287762037923, 1.816872242365836}, {4.388896960105848, 
     1.6199368422242373`}}]}, 
   {Hue[0.6061485758404667], AbsoluteThickness[0.5], 
    LineBox[{{3.3420322280993027`, 0.13801343009092454`}, {
     3.3441698726014493`, 0.10231671986879591`}}]}, 
   {Hue[0.6071039792583163], AbsoluteThickness[0.5], 
    LineBox[{{3.3441698726014493`, 0.10231671986879591`}, {
     3.3851906214941887`, -0.16686817252223235`}}]}, 
   {Hue[0.5978161032021736], AbsoluteThickness[0.5], 
    LineBox[{{3.159373636926916, -0.4022539621907469}, {
     3.1812481711312466`, -0.62923132526271}}]}, 
   {Hue[0.5982515723482541], AbsoluteThickness[0.5], 
    LineBox[{{3.1812481711312466`, -0.62923132526271}, {
     3.2161520007271167`, -0.9458052882553587}}]}, 
   {Hue[0.6856469186988432], AbsoluteThickness[0.5], 
    LineBox[{{4.609098423757178, -3.8877164056568936`}, {
     4.609140620151058, -3.888193583835607}}]}, 
   {Hue[0.6866538529777958], AbsoluteThickness[0.5], 
    LineBox[{{4.609140620151058, -3.888193583835607}, {
     4.6074420391303885`, -4.138066228502307}}]}, 
   {Hue[0.5507198750571326], AbsoluteThickness[0.5], 
    LineBox[{{5.856242723704777, -3.339828421191142}, {
     5.933231673117509, -3.392223984829856}}]}, 
   {Hue[0.5512572183531191], AbsoluteThickness[0.5], 
    LineBox[{{5.9332316731175085`, -3.392223984829856}, {
     6.1642060149909925`, -3.5653003030303325`}}]}, 
   {Hue[0.5605761244254094], AbsoluteThickness[0.5], 
    LineBox[{{6.210462364799511, 2.4435620456518214`}, {6.299473526632081, 
     2.5244345546628946`}}]}, 
   {Hue[0.5620246496397562], AbsoluteThickness[0.5], 
    LineBox[{{6.299473526632081, 2.5244345546628946`}, {6.511221273900341, 
     2.6751388822755158`}}]}, 
   {Hue[0.437623545045006], AbsoluteThickness[0.5], 
    LineBox[{{7.887164735274242, -0.2137628481629584}, {
     8.107241949841438, -0.1746611121800603}}]}, 
   {Hue[0.43835180471508267`], AbsoluteThickness[0.5], 
    LineBox[{{8.107241949841438, -0.1746611121800603}, {
     8.410391108578374, -0.14303440522758398`}}]}, 
   {Hue[0.3660393858876388], AbsoluteThickness[0.5], 
    LineBox[{{6.50110992969594, -2.6209800457583454`}, {
     6.616788479765853, -2.950428166710202}}]}, 
   {Hue[0.3936419738319677], AbsoluteThickness[0.5], 
    LineBox[{{6.616788479765853, -2.950428166710202}, {
     6.617477561541223, -3.1122152641639285`}}]}, 
   {Hue[0.5389906336434023], AbsoluteThickness[0.5], 
    LineBox[{{6.617477561541223, -3.1122152641639285`}, {
     6.476040812300579, -3.1907721588354567`}}]}, 
   {Hue[0.6843392934548364], AbsoluteThickness[0.5], 
    LineBox[{{6.476040812300579, -3.1907721588354567`}, {
     6.339056195726693, -3.104686419259728}}]}, 
   {Hue[0.5181322634379928], AbsoluteThickness[0.5], 
    LineBox[{{5.792899854559246, -2.8858688777378743`}, {
     5.7792341152495466`, -3.1279123595784255`}}]}, 
   {Hue[0.5186871139002982], AbsoluteThickness[0.5], 
    LineBox[{{5.7792341152495466`, -3.1279123595784255`}, {
     5.747507527268757, -3.428531406454751}}]}, 
   {Hue[0.6503538891457299], AbsoluteThickness[0.5], 
    LineBox[{{4.249811483182865, -2.3855964276395603`}, {
     3.726632122281262, -3.1490265441063703`}}]}, 
   {Hue[0.653848827055669], AbsoluteThickness[0.5], 
    LineBox[{{3.726632122281262, -3.1490265441063703`}, {
     3.644504655349183, -3.33078911514527}}]}, 
   {Hue[0.5049040786066638], AbsoluteThickness[0.5], 
    LineBox[{{7.910112966549745, 0.272995019362394}, {8.108508909587304, 
     0.3267845593947174}}]}, 
   {Hue[0.5083916992578856], AbsoluteThickness[0.5], 
    LineBox[{{8.108508909587304, 0.3267845593947174}, {8.317236633285857, 
     0.34530278021980587`}}]}, 
   {Hue[0.3272281448894935], AbsoluteThickness[0.5], 
    LineBox[{{6.885516698435229, 3.3386618045455494`}, {6.9456444988373125`, 
     3.348252113197838}}]}, 
   {Hue[0.3557875425781024], AbsoluteThickness[0.5], 
    LineBox[{{6.9456444988373125`, 3.348252113197838}, {7.066479208495928, 
     3.4133985998359253`}}]}, 
   {Hue[0.4981383383271885], AbsoluteThickness[0.5], 
    LineBox[{{7.066479208495928, 3.4133985998359253`}, {7.068022801183105, 
     3.550667347557992}}]}, 
   {Hue[0.6404891340762731], AbsoluteThickness[0.5], 
    LineBox[{{7.068022801183105, 3.550667347557992}, {6.94868361155915, 
     3.6185145995249357`}}]}, 
   {Hue[0.6029682918198408], AbsoluteThickness[0.5], 
    LineBox[{{4.345360367852291, 1.5952765565059506`}, {4.421314903870682, 
     1.5261133103270939`}}]}, 
   {Hue[0.6034199759033472], AbsoluteThickness[0.5], 
    LineBox[{{4.421314903870682, 1.5261133103270939`}, {4.617511954272839, 
     1.3553408825106987`}}]}, 
   {Hue[0.5183502392312624], AbsoluteThickness[0.5], 
    LineBox[{{4.413675956051858, 3.3736581416917426`}, {4.636125646650743, 
     3.320142023206282}}]}, 
   {Hue[0.5188342866239247], AbsoluteThickness[0.5], 
    LineBox[{{4.636125646650743, 3.320142023206282}, {4.941176113767496, 
     3.2359053568132}}]}, 
   {Hue[0.5945269263424582], AbsoluteThickness[0.5], 
    LineBox[{{4.326788430770375, 2.1092959533383793`}, {4.39394573897629, 
     2.0479024742557574`}}]}, 
   {Hue[0.5950074595122647], AbsoluteThickness[0.5], 
    LineBox[{{4.39394573897629, 2.0479024742557574`}, {4.632895834542047, 
     1.8432453051362663`}}]}, 
   {Hue[0.6282390523540181], AbsoluteThickness[0.5], 
    LineBox[{{4.851391769698768, 0.21232615024948656`}, {4.906709009144479, 
     0.1650381442436504}}]}, 
   {Hue[0.6287769822189541], AbsoluteThickness[0.5], 
    LineBox[{{4.906709009144479, 0.1650381442436504}, {
     5.127647872288066, -0.042000409698869576`}}]}, 
   {Hue[0.39852542568888394`], AbsoluteThickness[0.5], 
    LineBox[{{4.460488619071898, 0.24487139870824842`}, {4.51111997379845, 
     0.18267846301439408`}}]}, 
   {Hue[0.39916247039538083`], AbsoluteThickness[0.5], 
    LineBox[{{4.51111997379845, 0.18267846301439408`}, {
     4.67460324119989, -0.045320862185058056`}}]}, 
   {Hue[0.6824612662006934], AbsoluteThickness[0.5], 
    LineBox[{{5.668980988449335, 2.437994346955613}, {6.013395625851309, 
     2.901786042760981}}]}, 
   {Hue[0.6850396538463548], AbsoluteThickness[0.5], 
    LineBox[{{6.013395625851309, 2.901786042760981}, {6.107817892937866, 
     3.0820703584775844`}}]}, 
   {Hue[0.47939575117516653`], AbsoluteThickness[0.5], 
    LineBox[{{5.397778395803371, 1.2149688828508987`}, {5.498724683690596, 
     1.1511201970149967`}}]}, 
   {Hue[0.4818280740803884], AbsoluteThickness[0.5], 
    LineBox[{{5.498724683690596, 1.1511201970149967`}, {5.675986714913615, 
     0.9967549667739574}}]}, 
   {Hue[0.6710097494788989], AbsoluteThickness[0.5], 
    LineBox[{{4.071143539096906, 0.3973995733688912}, {4.004505088779328, 
     0.18620571204944245`}}]}, 
   {Hue[0.671618945634775], AbsoluteThickness[0.5], 
    LineBox[{{4.004505088779328, 0.18620571204944245`}, {
     3.9307210461549835`, -0.10486998684732424`}}]}, 
   {Hue[0.5571831131635377], AbsoluteThickness[0.5], 
    LineBox[{{6.215095120904238, 2.466439957889516}, {6.311380788098559, 
     2.4504697031957656`}}]}, 
   {Hue[0.5579209680904781], AbsoluteThickness[0.5], 
    LineBox[{{6.311380788098559, 2.4504697031957656`}, {6.608183685638831, 
     2.4232407335413124`}}]}, 
   {Hue[0.5129313431775304], AbsoluteThickness[0.5], 
    LineBox[{{5.755090428644162, 3.4048446215977908`}, {5.8527775372498985`, 
     3.5115025091842322`}}]}, 
   {Hue[0.5183492337767271], AbsoluteThickness[0.5], 
    LineBox[{{5.8527775372498985`, 3.5115025091842322`}, {5.984647502017991, 
     3.6061967241379795`}}]}, 
   {Hue[0.504234103729415], AbsoluteThickness[0.5], 
    LineBox[{{5.844631933204503, -0.5630525049548416}, {
     5.838491669218192, -0.5886481851988924}}]}, 
   {Hue[0.5047374765195243], AbsoluteThickness[0.5], 
    LineBox[{{5.838491669218192, -0.5886481851988924}, {
     5.781922615041296, -0.871832099910341}}]}, 
   {Hue[0.6110812033103702], AbsoluteThickness[0.5], 
    LineBox[{{6.909248710760159, -3.226945035051209}, {
     7.0535651790287375`, -3.25995381259771}}]}, 
   {Hue[0.6115724433174122], AbsoluteThickness[0.5], 
    LineBox[{{7.0535651790287375`, -3.25995381259771}, {
     7.361646608524819, -3.319072509789756}}]}, 
   {Hue[0.5680334713455971], AbsoluteThickness[0.5], 
    LineBox[{{6.597709276441529, -3.139054403924216}, {
     6.597359994769189, -3.1547900230461683`}}]}, 
   {Hue[0.5737142505418719], AbsoluteThickness[0.5], 
    LineBox[{{6.597359994769189, -3.1547900230461683`}, {
     6.634881995568328, -3.352382832507059}}]}, 
   {Hue[0.6175922097997258], AbsoluteThickness[0.5], 
    LineBox[{{3.9126037156760174`, 0.9400497728405409}, {3.8745503986546836`, 
     0.8908444481380439}}]}, 
   {Hue[0.6180481554541322], AbsoluteThickness[0.5], 
    LineBox[{{3.8745503986546836`, 0.8908444481380439}, {3.6792366205783775`, 
     0.6505188873889134}}]}, 
   {Hue[0.6246953857825671], AbsoluteThickness[0.5], 
    LineBox[{{3.3272601388817984`, 2.564893456808081}, {3.2062289013418113`, 
     2.5590964325931864`}}]}, 
   {Hue[0.6251801935906328], AbsoluteThickness[0.5], 
    LineBox[{{3.2062289013418113`, 2.5590964325931864`}, {2.842417548472058, 
     2.529414166170133}}]}, 
   {Hue[0.6011226430103507], AbsoluteThickness[0.5], 
    LineBox[{{5.472079943310583, 1.9413839497817942`}, {5.324376959387573, 
     1.8160733270445415`}}]}, 
   {Hue[0.6016344619726655], AbsoluteThickness[0.5], 
    LineBox[{{5.324376959387573, 1.8160733270445415`}, {5.127998350145082, 
     1.6626096101271308`}}]}, 
   {Hue[0.6313513495668875], AbsoluteThickness[0.5], 
    LineBox[{{6.898242309253645, 2.9752548096697433`}, {6.846193982767419, 
     2.837878537335821}}]}, 
   {Hue[0.6320795746093133], AbsoluteThickness[0.5], 
    LineBox[{{6.846193982767419, 2.837878537335821}, {6.723258134196153, 
     2.5726603038964178`}}]}, 
   {Hue[0.3487603050996499], AbsoluteThickness[0.5], 
    LineBox[{{8.121434815931508, 3.4089534552495677`}, {8.177831753784204, 
     3.3819427544629743`}}]}, 
   {Hue[0.3500803345552801], AbsoluteThickness[0.5], 
    LineBox[{{8.177831753784204, 3.3819427544629743`}, {8.3840153907699, 
     3.252789866833132}}]}, 
   {Hue[0.6548262988368325], AbsoluteThickness[0.5], 
    LineBox[{{7.139653122319598, 3.671624584055357}, {6.986513743313508, 
     3.6137258703339334`}}]}, 
   {Hue[0.6572383464491718], AbsoluteThickness[0.5], 
    LineBox[{{6.986513743313508, 3.6137258703339334`}, {6.820739513568189, 
     3.520254990127432}}]}, 
   {Hue[0.6122683557926439], AbsoluteThickness[0.5], 
    LineBox[{{6.64775465860125, 3.372029593616976}, {6.4083164328865925`, 
     3.3313561458423226`}}]}, 
   {Hue[0.612931992973365], AbsoluteThickness[0.5], 
    LineBox[{{6.4083164328865925`, 3.3313561458423226`}, {6.114109083381312, 
     3.2615845759705047`}}]}, 
   {Hue[0.5857147772478926], AbsoluteThickness[0.5], 
    LineBox[{{6.206648843783724, 1.5763679373743835`}, {6.175378656065071, 
     1.501458207343609}}]}, 
   {Hue[0.602757937933796], AbsoluteThickness[0.5], 
    LineBox[{{6.175378656065071, 1.501458207343609}, {6.069546825119555, 
     1.372931739423643}}]}, 
   {Hue[0.6037239464968092], AbsoluteThickness[0.5], 
    LineBox[{{4.376437706556258, 3.0433267404645954`}, {4.0703981969221035`, 
     3.028079063906905}}]}, 
   {Hue[0.6043324046069112], AbsoluteThickness[0.5], 
    LineBox[{{4.0703981969221035`, 3.028079063906905}, {3.8276922923986394`, 
     3.001994781875114}}]}, 
   {Hue[0.6172204316676938], AbsoluteThickness[0.5], 
    LineBox[{{4.855671826111661, 1.4118413453612613`}, {4.820503234050702, 
     1.389212190179973}}]}, 
   {Hue[0.6177210834000604], AbsoluteThickness[0.5], 
    LineBox[{{4.820503234050702, 1.389212190179973}, {4.611935093798961, 
     1.243631193343742}}]}, 
   {Hue[0.6056193297719916], AbsoluteThickness[0.5], 
    LineBox[{{2.962206148706929, 3.685931457064358}, {2.880638286539342, 
     3.6907853900179575`}}]}, 
   {Hue[0.6061641849693812], AbsoluteThickness[0.5], 
    LineBox[{{2.880638286539342, 3.6907853900179575`}, {2.546881021977942, 
     3.7264227465521644`}}]}, 
   {Hue[0.676403928590823], AbsoluteThickness[0.5], 
    LineBox[{{5.206861751990726, -0.9105020148394174}, {
     5.176474435711514, -1.173638448831572}}]}, 
   {Hue[0.677755707653423], AbsoluteThickness[0.5], 
    LineBox[{{5.176474435711514, -1.173638448831572}, {
     5.176367482115074, -1.3974741076502395`}}]}, 
   {Hue[0.631795741754631], AbsoluteThickness[0.5], 
    LineBox[{{3.443592719859303, -0.18062871745977066`}, {
     3.4154190023509563`, -0.23898634576522293`}}]}, 
   {Hue[0.6334648948721662], AbsoluteThickness[0.5], 
    LineBox[{{3.4154190023509563`, -0.23898634576522293`}, {
     3.2848390399757355`, -0.4392031787611495}}]}, 
   {Hue[0.6279088770497722], AbsoluteThickness[0.5], 
    LineBox[{{4.961279207451795, -2.613547491004378}, {
     4.901689523586127, -2.8534402802869425`}}]}, 
   {Hue[0.6299110385486093], AbsoluteThickness[0.5], 
    LineBox[{{4.901689523586127, -2.8534402802869425`}, {
     4.878069014737911, -3.0806208376058892`}}]}, 
   {Hue[0.4259381301113578], AbsoluteThickness[0.5], 
    LineBox[{{7.8373704666150825`, 0.3579038554164762}, {7.928039400083714, 
     0.3714014358272505}}]}, 
   {Hue[0.4276158207145196], AbsoluteThickness[0.5], 
    LineBox[{{7.928039400083714, 0.3714014358272505}, {8.169633442256165, 
     0.4398932754219116}}]}, 
   {Hue[0.6479898774790077], AbsoluteThickness[0.5], 
    LineBox[{{6.8408922287666085`, 1.8185683634064385`}, {7.3309257100173095`,
      2.1061202216363135`}}]}, 
   {Hue[0.6501196998928364], AbsoluteThickness[0.5], 
    LineBox[{{7.3309257100173095`, 2.1061202216363135`}, {7.563580472881811, 
     2.2008818576107276`}}]}, 
   {Hue[0.6160640458098496], AbsoluteThickness[0.5], 
    LineBox[{{4.54345942258864, -3.093626491191982}, {
     4.5349678086887, -3.297196228916799}}]}, 
   {Hue[0.6165252974819206], AbsoluteThickness[0.5], 
    LineBox[{{4.5349678086887, -3.297196228916799}, {
     4.51286598813684, -3.6224376980746786`}}]}, 
   {Hue[0.5994253295887668], AbsoluteThickness[0.5], 
    LineBox[{{6.878172654199187, -1.3976314620617747`}, {
     6.877620249974395, -1.400331903473955}}]}, 
   {Hue[0.6006302859284061], AbsoluteThickness[0.5], 
    LineBox[{{6.877620249974395, -1.400331903473955}, {
     6.855775058733314, -1.630067245352622}}]}, 
   {Hue[0.5986902007041848], AbsoluteThickness[0.5], 
    LineBox[{{8.166597328755254, -0.9000455878932121}, {
     8.256273535504738, -1.0795767647902077`}}]}, 
   {Hue[0.5993015373491793], AbsoluteThickness[0.5], 
    LineBox[{{8.256273535504738, -1.0795767647902077`}, {
     8.364274917699328, -1.331118158695416}}]}, 
   {Hue[0.6086164214901916], AbsoluteThickness[0.5], 
    LineBox[{{7.739518327730417, 0.9193336434393964}, {7.8690301655675405`, 
     1.0719491008031667`}}]}, 
   {Hue[0.6123196563730929], AbsoluteThickness[0.5], 
    LineBox[{{7.8690301655675405`, 1.0719491008031667`}, {8.035106071540802, 
     1.2081276660530174`}}]}, 
   {Hue[0.591264037218414], AbsoluteThickness[0.5], 
    LineBox[{{6.475641036853403, 0.661050925414534}, {6.596915104614413, 
     0.7739562902065716}}]}, 
   {Hue[0.5935696586013646], AbsoluteThickness[0.5], 
    LineBox[{{6.596915104614413, 0.7739562902065716}, {6.802189898380744, 
     0.9145935981196168}}]}, 
   {Hue[0.40696940138060694`], AbsoluteThickness[0.5], 
    LineBox[{{6.04082172643458, -4.1261568611775425`}, {
     6.085316326472471, -4.198421151297264}}]}, 
   {Hue[0.4075745248509412], AbsoluteThickness[0.5], 
    LineBox[{{6.085316326472471, -4.198421151297264}, {
     6.268681526761039, -4.461506493875207}}]}, 
   {Hue[0.6999859048984676], AbsoluteThickness[0.5], 
    LineBox[{{7.609329008368893, 0.3523211392255329}, {7.647353667549535, 
     0.3451068516208472}}]}, 
   {Hue[0.584190248448132], AbsoluteThickness[0.5], 
    LineBox[{{7.280531061134359, 1.4231266834695357`}, {7.317685171116831, 
     1.5734694427045344`}}]}, 
   {Hue[0.5854056350023444], AbsoluteThickness[0.5], 
    LineBox[{{7.317685171116831, 1.5734694427045344`}, {7.3530684958010575`, 
     1.8344932747784646`}}]}, 
   {Hue[0.616586698150704], AbsoluteThickness[0.5], 
    LineBox[{{8.115495197179278, -0.12978836450045209`}, {
     8.139035691207155, -0.12242948339719908`}}]}, 
   {Hue[0.6201224830839469], AbsoluteThickness[0.5], 
    LineBox[{{8.139035691207155, -0.12242948339719908`}, {
     8.3623979938044, -0.09418333262133213}}]}, 
   {Hue[0.6632978474475828], AbsoluteThickness[0.5], 
    LineBox[{{6.691897724535111, 2.898627414609461}, {6.807087540627745, 
     3.1678210307867136`}}]}, 
   {Hue[0.6646250345248549], AbsoluteThickness[0.5], 
    LineBox[{{6.807087540627745, 3.1678210307867136`}, {6.868249878261521, 
     3.372010837322364}}]}, 
   {Hue[0.6423289525129698], AbsoluteThickness[0.5], 
    LineBox[{{7.375847657411202, 3.208379050095885}, {7.582435089776584, 
     3.294926040948381}}]}, 
   {Hue[0.6432138275199025], AbsoluteThickness[0.5], 
    LineBox[{{7.582435089776584, 3.294926040948381}, {7.8333764060731985`, 
     3.3754843712530844`}}]}, 
   {Hue[0.5219465861193139], AbsoluteThickness[0.5], 
    LineBox[{{3.098880981156591, -2.8341545261033}, {
     3.094196448462791, -2.8515979216224094`}}]}, 
   {Hue[0.5224353683396927], AbsoluteThickness[0.5], 
    LineBox[{{3.094196448462791, -2.8515979216224094`}, {
     2.995715173182376, -3.1733914357500974`}}]}, 
   {Hue[0.5313037671113604], AbsoluteThickness[0.5], 
    LineBox[{{5.692019106243056, -2.4244200686707953`}, {
     5.997000838660809, -2.8195930914026057`}}]}, 
   {Hue[0.5321692556161027], AbsoluteThickness[0.5], 
    LineBox[{{5.997000838660809, -2.8195930914026057`}, {
     6.16168791822775, -3.0749755625848882`}}]}, 
   {Hue[0.5609202015946635], AbsoluteThickness[0.5], 
    LineBox[{{3.891869768995597, 2.050490734928184}, {3.793219791483428, 
     2.1226503952972355`}}]}, 
   {Hue[0.561367978257443], AbsoluteThickness[0.5], 
    LineBox[{{3.793219791483428, 2.1226503952972355`}, {3.58604050655056, 
     2.2808705225509027`}}]}, 
   {Hue[0.604623479156254], AbsoluteThickness[0.5], 
    LineBox[{{6.910252953942922, -0.810214142574577}, {
     7.421322400143861, -1.0804400260182716`}}]}, 
   {Hue[0.6122576991209033], AbsoluteThickness[0.5], 
    LineBox[{{7.421322400143861, -1.0804400260182716`}, {
     7.599792642783219, -1.1269982569351897`}}]}, 
   {Hue[0.4344514156705568], AbsoluteThickness[0.5], 
    LineBox[{{7.591652825546645, -0.579326894924764}, {
     7.679765983315665, -0.6218685537678982}}]}, 
   {Hue[0.435231342921407], AbsoluteThickness[0.5], 
    LineBox[{{7.679765983315665, -0.6218685537678981}, {
     7.901723674736531, -0.7509719170866105}}]}, 
   {Hue[0.6135344015074438], AbsoluteThickness[0.5], 
    LineBox[{{6.948407650623727, 1.6530561184669716`}, {7.345386415836615, 
     2.1344858275164205`}}]}, 
   {Hue[0.6650143542674867], AbsoluteThickness[0.5], 
    LineBox[{{7.345386415836615, 2.1344858275164205`}, {7.4960132121304595`, 
     2.2158125464444107`}}]}, 
   {Hue[0.4372134948487059], AbsoluteThickness[0.5], 
    LineBox[{{7.413704082427893, 0.7946269072737185}, {7.5523250595791, 
     0.8673630759479951}}]}, 
   {Hue[0.4487859314466239], AbsoluteThickness[0.5], 
    LineBox[{{7.5523250595791, 0.8673630759479951}, {7.6951212409165795`, 
     0.9992939556104838}}]}, 
   {Hue[0.6744934711661934], AbsoluteThickness[0.5], 
    LineBox[{{7.6951212409165795`, 0.9992939556104838}, {7.628588505962726, 
     1.181968260296843}}]}, 
   {Hue[0.37186647535743717`], AbsoluteThickness[0.5], 
    LineBox[{{7.50480514066982, 0.28473796934225265`}, {7.586520231525652, 
     0.2506614257282793}}]}, 
   {Hue[0.37231192200328167`], AbsoluteThickness[0.5], 
    LineBox[{{7.586520231525652, 0.2506614257282793}, {7.899719388540627, 
     0.12718288154891433`}}]}, 
   {Hue[0.5032821888981257], AbsoluteThickness[0.5], 
    LineBox[{{7.121207705261646, 0.124421371094444}, {
     7.132814152039796, -0.022506673106382477`}}]}, 
   {Hue[0.6333339238034855], AbsoluteThickness[0.5], 
    LineBox[{{6.6064471127504, 0.1632268817193362}, {6.599130717874676, 
     0.16117013040739403`}}]}, 
   {Hue[0.6342172316816792], AbsoluteThickness[0.5], 
    LineBox[{{6.599130717874676, 0.16117013040739403`}, {6.3418509883730865`, 
     0.06432645586652262}}]}, 
   {Hue[0.6653065642939537], AbsoluteThickness[0.5], 
    LineBox[{{5.910421260764438, 1.6339147951744553`}, {5.794797136580917, 
     1.6314417080014754`}}]}, 
   {Hue[0.6669521070325088], AbsoluteThickness[0.5], 
    LineBox[{{5.794797136580917, 1.6314417080014754`}, {5.611670008287723, 
     1.6508958569376952`}}]}, 
   {Hue[0.3341935764001225], AbsoluteThickness[0.5], 
    LineBox[{{6.129646499554149, 2.1312779337183385`}, {6.094380395598452, 
     2.3271470792619113`}}]}, 
   {Hue[0.33462617358514407`], AbsoluteThickness[0.5], 
    LineBox[{{6.094380395598452, 2.3271470792619113`}, {6.031591311258323, 
     2.6542426414846823`}}]}, 
   {Hue[0.672262729866996], AbsoluteThickness[0.5], 
    LineBox[{{6.662178063456696, 1.9146235096829016`}, {6.866509999129093, 
     1.9761090768571001`}}]}, 
   {Hue[0.6727688616790969], AbsoluteThickness[0.5], 
    LineBox[{{6.866509999129093, 1.9761090768571001`}, {7.096712114255172, 
     2.0552726307044797`}}]}, 
   {Hue[0.577587138174625], AbsoluteThickness[0.5], 
    LineBox[{{5.6012266185365265`, 1.7718238781726001`}, {5.164485872862822, 
     1.9745660313315498`}}]}, 
   {Hue[0.5782714697195663], AbsoluteThickness[0.5], 
    LineBox[{{5.164485872862822, 1.9745660313315498`}, {4.945914233964435, 
     2.0587301597946626`}}]}, 
   {Hue[0.5920301854292331], AbsoluteThickness[0.5], 
    LineBox[{{6.752465187692428, 1.1098884940926201`}, {6.619886806170689, 
     0.8339896808481111}}]}, 
   {Hue[0.6574516123848457], AbsoluteThickness[0.5], 
    LineBox[{{6.619886806170689, 0.8339896808481111}, {6.612721049405311, 
     0.6636512942405419}}]}, 
   {Hue[0.5501882538295466], AbsoluteThickness[0.5], 
    LineBox[{{7.1713417341219925`, 1.5672332409803995`}, {7.200278879001138, 
     1.4418834812499188`}}]}, 
   {Hue[0.5506486292178114], AbsoluteThickness[0.5], 
    LineBox[{{7.200278879001138, 1.4418834812499188`}, {7.266562499096643, 
     1.1166251339557969`}}]}, 
   {Hue[0.07515571208411852], AbsoluteThickness[0.5], 
    LineBox[{{7.402324571261527, 1.7229689355963524`}, {8.061343879347792, 
     2.258271950304787}}]}, 
   {Hue[0.07636319882220147], AbsoluteThickness[0.5], 
    LineBox[{{8.061343879347792, 2.258271950304787}, {8.265486549579814, 
     2.390585319143767}}]}, 
   {Hue[0.5260390737562287], AbsoluteThickness[0.5], 
    LineBox[{{8.265486549579814, 2.390585319143767}, {8.332772803173347, 
     2.156804187611888}}]}, 
   {Hue[0.5520322629526002], AbsoluteThickness[0.5], 
    LineBox[{{7.160882952162815, 1.861938796348728}, {7.014845564222732, 
     1.9295013501217044`}}]}, 
   {Hue[0.5533737345794758], AbsoluteThickness[0.5], 
    LineBox[{{7.014845564222732, 1.9295013501217044`}, {6.8450430960388005`, 
     2.032980779809204}}]}, 
   {Hue[0.5930480304959332], AbsoluteThickness[0.5], 
    LineBox[{{6.626059789910555, 1.690843101632873}, {6.415243242981701, 
     1.7852276850984747`}}]}, 
   {Hue[0.5945790399782982], AbsoluteThickness[0.5], 
    LineBox[{{6.415243242981701, 1.7852276850984747`}, {6.181660761323864, 
     1.8570695721971526`}}]}, 
   {Hue[0.584944206203492], AbsoluteThickness[0.5], 
    LineBox[{{6.637122142212859, 0.12252587693930486`}, {6.638811174228368, 
     0.11532344366757136`}}]}, 
   {Hue[0.5991371141157106], AbsoluteThickness[0.5], 
    LineBox[{{6.638811174228368, 0.11532344366757136`}, {
     6.6304109223217775`, -0.05827625494896646}}]}, 
   {Hue[0.6408597540187675], AbsoluteThickness[0.5], 
    LineBox[{{7.471984697019943, 0.280277420153079}, {7.5818617863557725`, 
     0.21433205531867736`}}]}, 
   {Hue[0.6415567832486134], AbsoluteThickness[0.5], 
    LineBox[{{7.5818617863557725`, 0.21433205531867736`}, {
     7.8542008051209935`, 0.07529020404886505}}]}, 
   {Hue[0.5040706112755484], AbsoluteThickness[0.5], 
    LineBox[{{7.3767971009306486`, 0.8979203433837606}, {7.41951896676543, 
     0.9000842933768485}}]}, 
   {Hue[0.5059534843862665], AbsoluteThickness[0.5], 
    LineBox[{{7.41951896676543, 0.9000842933768485}, {7.6736423294833855`, 
     0.9480402193088191}}]}, 
   {Hue[0.6764296329107001], AbsoluteThickness[0.5], 
    LineBox[{{7.2690121445846865`, 1.4285283340357744`}, {7.294799897312053, 
     1.5630206158581086`}}]}, 
   {Hue[0.6771551603994589], AbsoluteThickness[0.5], 
    LineBox[{{7.294799897312053, 1.5630206158581086`}, {7.32922660086373, 
     1.8538082160152232`}}]}, 
   {Hue[0.4099120018232038], AbsoluteThickness[0.5], 
    LineBox[{{7.0659382503118, -0.06900653153683414}, {
     7.092235975091861, -0.2645162436929099}}]}, 
   {Hue[0.4265221659250126], AbsoluteThickness[0.5], 
    LineBox[{{7.092235975091861, -0.2645162436929099}, {
     7.158998934542703, -0.41201890895875926`}}]}, 
   {Hue[0.6180576089772322], AbsoluteThickness[0.5], 
    LineBox[{{7.158998934542703, -0.41201890895875926`}, {
     7.320863950601745, -0.4157666537966871}}]}, 
   {Hue[0.5423975267021139], AbsoluteThickness[0.5], 
    LineBox[{{5.850860910963141, 0.020093843438103304`}, {
     5.446761181945003, -0.1343023022441086}}]}, 
   {Hue[0.5428234597325045], AbsoluteThickness[0.5], 
    LineBox[{{5.446761181945003, -0.1343023022441086}, {
     5.110941489397328, -0.26309098116977064`}}]}, 
   {Hue[0.6593996077167876], AbsoluteThickness[0.5], 
    LineBox[{{5.877369095129161, 0.9345830477685935}, {5.649168709518589, 
     1.0757771935519949`}}]}, 
   {Hue[0.6653602251355493], AbsoluteThickness[0.5], 
    LineBox[{{5.649168709518589, 1.0757771935519949`}, {5.458242853094072, 
     1.1434878315914034`}}]}, 
   {Hue[0.6173497754844467], AbsoluteThickness[0.5], 
    LineBox[{{6.056602913067607, -0.1510339795213436}, {
     5.90259385530774, -0.27051606232329933`}}]}, 
   {Hue[0.6180416472029683], AbsoluteThickness[0.5], 
    LineBox[{{5.90259385530774, -0.27051606232329933`}, {
     5.700258301580861, -0.40654928608680774`}}]}, 
   {Hue[0.3248027902434301], AbsoluteThickness[0.5], 
    LineBox[{{5.021321546827152, 2.674766329649607}, {4.9092688358434335`, 
     2.7675285064782393`}}]}, 
   {Hue[0.32574716938366893`], AbsoluteThickness[0.5], 
    LineBox[{{4.9092688358434335`, 2.7675285064782393`}, {4.689132423954502, 
     2.9184148253929196`}}]}, 
   {Hue[0.5831106539915907], AbsoluteThickness[0.5], 
    LineBox[{{4.41344621305268, 0.48275493892262417`}, {4.30369683818009, 
     0.42698975716624715`}}]}, 
   {Hue[0.5874093974071773], AbsoluteThickness[0.5], 
    LineBox[{{4.30369683818009, 0.42698975716624715`}, {4.139745075665066, 
     0.29960027545355683`}}]}, 
   {Hue[0.699493108397769], AbsoluteThickness[0.5], 
    LineBox[{{4.910066605830011, 2.851416128255608}, {4.8880263456037065`, 
     2.8524202785986335`}}]}, 
   {Hue[0.40752496999168963`], AbsoluteThickness[0.5], 
    LineBox[{{4.832518333151736, 3.035242643737927}, {4.8227330808711955`, 
     3.0848498645167184`}}]}, 
   {Hue[0.40795567844387703`], AbsoluteThickness[0.5], 
    LineBox[{{4.8227330808711955`, 3.0848498645167184`}, {4.756799612100083, 
     3.4027125196327686`}}]}, 
   {Hue[0.5517035776020891], AbsoluteThickness[0.5], 
    LineBox[{{3.965443688620002, -2.6468334956355664`}, {
     3.5626396015239776`, -3.310051063766913}}]}, 
   {Hue[0.5522732936291044], AbsoluteThickness[0.5], 
    LineBox[{{3.5626396015239776`, -3.310051063766913}, {
     3.4278913674215907`, -3.5599590611101397`}}]}, 
   {Hue[0.5886630969743257], AbsoluteThickness[0.5], 
    LineBox[{{3.0617982060428366`, 2.685031388046329}, {2.8843829226257056`, 
     2.7605827859213243`}}]}, 
   {Hue[0.5892896955620673], AbsoluteThickness[0.5], 
    LineBox[{{2.8843829226257056`, 2.7605827859213243`}, {2.6150090051493806`,
      2.8567104620536683`}}]}, 
   {Hue[0.6233023610566831], AbsoluteThickness[0.5], 
    LineBox[{{3.941898177482209, -3.1417717106772582`}, {
     3.923610541764025, -3.2175384228327104`}}]}, 
   {Hue[0.6250563196752588], AbsoluteThickness[0.5], 
    LineBox[{{3.923610541764025, -3.2175384228327104`}, {
     3.842320733218131, -3.4282627906929}}]}, 
   {Hue[0.40971702281170386`], AbsoluteThickness[0.5], 
    LineBox[{{5.11847046710034, -3.076913919542624}, {
     5.125570306939505, -3.144628478809884}}]}, 
   {Hue[0.41087697368352993`], AbsoluteThickness[0.5], 
    LineBox[{{5.125570306939505, -3.144628478809884}, {
     5.1829528576084085`, -3.41526974910726}}]}, 
   {Hue[0.6376657802688194], AbsoluteThickness[0.5], 
    LineBox[{{6.678316212899568, -1.533915608636902}, {
     6.809398713656605, -1.5046346554243935`}}]}, 
   {Hue[0.6381957461664497], AbsoluteThickness[0.5], 
    LineBox[{{6.809398713656605, -1.5046346554243935`}, {
     7.079003859623861, -1.456769501463413}}]}, 
   {Hue[0.6904812749123711], AbsoluteThickness[0.5], 
    LineBox[{{3.2245010859309735`, -3.915360346702302}, {
     3.2087371158917426`, -4.10743873899729}}]}, 
   {Hue[0.6914596237583097], AbsoluteThickness[0.5], 
    LineBox[{{3.2087371158917426`, -4.10743873899729}, {
     3.211729190752347, -4.37575177328833}}]}, 
   {Hue[0.6683362817299683], AbsoluteThickness[0.5], 
    LineBox[{{4.167958697336765, -3.9036804150824103`}, {
     4.224189204008672, -4.0562408987674905`}}]}, 
   {Hue[0.6687626403894247], AbsoluteThickness[0.5], 
    LineBox[{{4.224189204008672, -4.0562408987674905`}, {
     4.332653229857758, -4.3534032715972595`}}]}, 
   {Hue[0.37655274673794], AbsoluteThickness[0.5], 
    LineBox[{{7.601027565382564, -1.4120536737927514`}, {
     7.737901491697695, -1.4046801979414945`}}]}, 
   {Hue[0.3868428892589272], AbsoluteThickness[0.5], 
    LineBox[{{7.737901491697695, -1.4046801979414945`}, {
     7.917912238522208, -1.3475306158439462`}}]}, 
   {Hue[0.6238252281011395], AbsoluteThickness[0.5], 
    LineBox[{{7.917912238522208, -1.3475306158439462`}, {
     7.931100993014548, -1.1591267930027302`}}]}, 
   {Hue[0.6659672811357061], AbsoluteThickness[0.5], 
    LineBox[{{4.356680650977259, 2.5492351995807776`}, {4.313666446992499, 
     2.642541354119188}}]}, 
   {Hue[0.6664121961791016], AbsoluteThickness[0.5], 
    LineBox[{{4.313666446992499, 2.642541354119188}, {4.184756378522427, 
     2.936978088744807}}]}, 
   {Hue[0.647166280448463], AbsoluteThickness[0.5], 
    LineBox[{{7.934776382695046, -1.7415599206446053`}, {
     8.065276719653786, -1.771271719840888}}]}, 
   {Hue[0.6477103036649081], AbsoluteThickness[0.5], 
    LineBox[{{8.065276719653786, -1.771271719840888}, {
     8.343752856166647, -1.821106110139898}}]}, 
   {Hue[0.6436619100259229], AbsoluteThickness[0.5], 
    LineBox[{{3.7017774712606606`, 3.4111450163654986`}, {3.7330637372456303`,
      3.6392586060135566`}}]}, 
   {Hue[0.6441409406052466], AbsoluteThickness[0.5], 
    LineBox[{{3.7330637372456303`, 3.6392586060135566`}, {3.7841761801919556`,
      3.940245613868155}}]}, 
   {Hue[0.5919745346657663], AbsoluteThickness[0.5], 
    LineBox[{{7.666327745158103, -4.5263042505964926`}, {
     7.8175541332593035`, -4.541880429645631}}]}, 
   {Hue[0.5924937407547529], AbsoluteThickness[0.5], 
    LineBox[{{7.8175541332593035`, -4.541880429645631}, {
     8.145805196125265, -4.561862734719783}}]}, 
   {Hue[0.5393082232025119], AbsoluteThickness[0.5], 
    LineBox[{{4.329704555767314, 1.9113776743296644`}, {4.312358142331223, 
     2.1012290336728325`}}]}, 
   {Hue[0.5398951892698545], AbsoluteThickness[0.5], 
    LineBox[{{4.312358142331223, 2.1012290336728325`}, {4.301196942047683, 
     2.402361191206961}}]}, 
   {Hue[0.5303910633258554], AbsoluteThickness[0.5], 
    LineBox[{{5.695537779149067, 2.9515108698623704`}, {5.771712236963253, 
     3.151458030609364}}]}, 
   {Hue[0.5308394219929031], AbsoluteThickness[0.5], 
    LineBox[{{5.771712236963253, 3.151458030609364}, {5.869474534490239, 
     3.3927611189889895`}}]}, 
   {Hue[0.5589004718417603], AbsoluteThickness[0.5], 
    LineBox[{{3.793892028169414, -0.884442745485643}, {
     3.709229876851505, -0.9336156654547124}}]}, 
   {Hue[0.5594632140792368], AbsoluteThickness[0.5], 
    LineBox[{{3.709229876851505, -0.9336156654547124}, {
     3.4340157429530946`, -1.0755231686163798`}}]}, 
   {Hue[0.5709876526895947], AbsoluteThickness[0.5], 
    LineBox[{{4.136815177225127, -0.8500443532867662}, {
     4.131885147841124, -0.9045349747169875}}]}, 
   {Hue[0.5723381300140987], AbsoluteThickness[0.5], 
    LineBox[{{4.131885147841124, -0.9045349747169875}, {
     4.080487026085644, -1.1521571027353676`}}]}, 
   {Hue[0.44566131575703255`], AbsoluteThickness[0.5], 
    LineBox[{{6.598923364376289, 0.4958819657231898}, {6.68746838690366, 
     0.3868694830402538}}]}, 
   {Hue[0.4461573667482606], AbsoluteThickness[0.5], 
    LineBox[{{6.68746838690366, 0.3868694830402538}, {6.874396088271538, 
     0.13875400708377703`}}]}, 
   {Hue[0.535374923386363], AbsoluteThickness[0.5], 
    LineBox[{{3.874416828245021, 1.9576276360098128`}, {3.6661796613848283`, 
     1.9715821399192257`}}]}, 
   {Hue[0.5358391918018949], AbsoluteThickness[0.5], 
    LineBox[{{3.6661796613848283`, 1.9715821399192257`}, {3.408688002214408, 
     1.9958950995123375`}}]}, 
   {Hue[0.5037984698600307], AbsoluteThickness[0.5], 
    LineBox[{{4.934425242033932, 2.461981246706217}, {4.690358752098864, 
     2.6272805756918824`}}]}, 
   {Hue[0.5316656604180918], AbsoluteThickness[0.5], 
    LineBox[{{4.690358752098864, 2.6272805756918824`}, {4.594175413266948, 
     2.7561250850535886`}}]}, 
   {Hue[0.6761735113848211], AbsoluteThickness[0.5], 
    LineBox[{{4.594175413266948, 2.7561250850535886`}, {4.660611049918947, 
     2.902543828540062}}]}, 
   {Hue[0.532472328157141], AbsoluteThickness[0.5], 
    LineBox[{{5.381505336890114, 2.614193283771849}, {5.342604534843155, 
     2.6228410240577134`}}]}, 
   {Hue[0.5333656067406488], AbsoluteThickness[0.5], 
    LineBox[{{5.342604534843155, 2.6228410240577134`}, {5.117615039556583, 
     2.6937964120339943`}}]}, 
   {Hue[0.026557929174284855`], AbsoluteThickness[0.5], 
    LineBox[{{6.380285951415324, 2.790508259713016}, {6.432743400291953, 
     2.8186840716085455`}}]}, 
   {Hue[0.028293584801353952`], AbsoluteThickness[0.5], 
    LineBox[{{6.432743400291953, 2.8186840716085455`}, {6.633830151583649, 
     2.894888176787843}}]}, 
   {Hue[0.4414527550172738], AbsoluteThickness[0.5], 
    LineBox[{{6.633830151583649, 2.894888176787843}, {6.586647321954805, 
     3.1046898159126157`}}]}, 
   {Hue[0.5377850018202252], AbsoluteThickness[0.5], 
    LineBox[{{6.1110018217393485`, 2.9111380726361253`}, {6.067586420801625, 
     2.934007202393559}}]}, 
   {Hue[0.5383368802559354], AbsoluteThickness[0.5], 
    LineBox[{{6.067586420801625, 2.934007202393559}, {5.821380755156411, 
     3.0488953396630754`}}]}, 
   {Hue[0.5336060761136069], AbsoluteThickness[0.5], 
    LineBox[{{6.037121457755522, 1.8204748728262978`}, {6.009021817079919, 
     1.6780758824483046`}}]}, 
   {Hue[0.5340880712459685], AbsoluteThickness[0.5], 
    LineBox[{{6.009021817079919, 1.6780758824483046`}, {5.959770288121485, 
     1.3768438189285859`}}]}, 
   {Hue[0.562757111506559], AbsoluteThickness[0.5], 
    LineBox[{{6.133381975343982, 1.629843470142983}, {6.152280563703263, 
     1.6141019226942375`}}]}, 
   {Hue[0.6168847554052226], AbsoluteThickness[0.5], 
    LineBox[{{6.152280563703263, 1.6141019226942375`}, {6.301205715342333, 
     1.5673547568775967`}}]}, 
   {Hue[0.5931816266355906], AbsoluteThickness[0.5], 
    LineBox[{{6.171449462576855, 1.4814766454007846`}, {6.162644452382119, 
     1.4208940456883201`}}]}, 
   {Hue[0.5937835417901576], AbsoluteThickness[0.5], 
    LineBox[{{6.162644452382119, 1.4208940456883201`}, {6.137072660338236, 
     1.1310572121574078`}}]}, 
   {Hue[0.6779319588075046], AbsoluteThickness[0.5], 
    LineBox[{{6.06488059020504, 1.3714542671784113`}, {5.924754942601214, 
     1.3112407067150496`}}]}, 
   {Hue[0.6783579940162165], AbsoluteThickness[0.5], 
    LineBox[{{5.924754942601214, 1.3112407067150496`}, {5.59440241290321, 
     1.1700237445038633`}}]}, 
   {Hue[0.661545616468743], AbsoluteThickness[0.5], 
    LineBox[{{5.8761178714528075`, 0.946026212397528}, {5.869758434399189, 
     0.880834174568842}}]}, 
   {Hue[0.6624870989132993], AbsoluteThickness[0.5], 
    LineBox[{{5.869758434399189, 0.880834174568842}, {5.822022768727359, 
     0.6294336225975885}}]}, 
   {Hue[0.6057498684045884], AbsoluteThickness[0.5], 
    LineBox[{{5.970680495622673, 0.8075797189555547}, {6.194985738401109, 
     0.6479324438767774}}]}, 
   {Hue[0.621294207603565], AbsoluteThickness[0.5], 
    LineBox[{{6.194985738401109, 0.6479324438767774}, {6.3292846119777035`, 
     0.6015429566875906}}]}, 
   {Hue[0.45080361119158885`], AbsoluteThickness[0.5], 
    LineBox[{{3.2140370835863243`, 2.899791381213015}, {3.155006221087407, 
     2.929072509283962}}]}, 
   {Hue[0.4513199005805614], AbsoluteThickness[0.5], 
    LineBox[{{3.155006221087407, 2.929072509283962}, {2.8896365999503066`, 
     3.0746226664742258`}}]}, 
   {Hue[0.5846749715242956], AbsoluteThickness[0.5], 
    LineBox[{{2.9652896535439273`, 0.8242148133160775}, {2.901149744196053, 
     0.8008059623627904}}]}, 
   {Hue[0.5851247698505314], AbsoluteThickness[0.5], 
    LineBox[{{2.901149744196053, 0.8008059623627904}, {2.5976146879161774`, 
     0.6825412425653781}}]}, 
   {Hue[0.5802854401997828], AbsoluteThickness[0.5], 
    LineBox[{{2.1457291700392247`, -1.4173965861641962`}, {
     2.139852015312577, -1.4328362726534227`}}]}, 
   {Hue[0.5819928869744903], AbsoluteThickness[0.5], 
    LineBox[{{2.139852015312577, -1.4328362726534227`}, {
     2.0272464193462265`, -1.6422724498873857`}}]}, 
   {Hue[0.5281898476576007], AbsoluteThickness[0.5], 
    LineBox[{{5.679390213696134, -2.91318799329737}, {
     5.82680554195812, -2.989619097367775}}]}, 
   {Hue[0.5287940444876664], AbsoluteThickness[0.5], 
    LineBox[{{5.82680554195812, -2.989619097367775}, {
     6.1258387511766115`, -3.123753256907864}}]}, 
   {Hue[0.6487365603174595], AbsoluteThickness[0.5], 
    LineBox[{{5.019320383757114, -3.1332816674277235`}, {
     5.119999499873803, -3.151111978663123}}]}, 
   {Hue[0.6494184018704566], AbsoluteThickness[0.5], 
    LineBox[{{5.119999499873803, -3.151111978663123}, {
     5.419701386209029, -3.225102878942382}}]}, 
   {Hue[0.6070004219497656], AbsoluteThickness[0.5], 
    LineBox[{{2.201375846667205, -3.3333508196755988`}, {
     2.1115723079636104`, -3.3879381385750396`}}]}, 
   {Hue[0.6074360305962732], AbsoluteThickness[0.5], 
    LineBox[{{2.1115723079636104`, -3.3879381385750396`}, {
     1.8433493946560566`, -3.5561030269363942`}}]}, 
   {Hue[0.4962826629266755], AbsoluteThickness[0.5], 
    LineBox[{{5.656233227837493, -3.8862284908205975`}, {
     5.656834890776827, -3.931346458832389}}]}, 
   {Hue[0.5014710143626511], AbsoluteThickness[0.5], 
    LineBox[{{5.656834890776827, -3.931346458832389}, {
     5.62033761361892, -4.120985004134547}}]}, 
   {Hue[0.5642527212848344], AbsoluteThickness[0.5], 
    LineBox[{{4.918055268610592, -3.1137571390036975`}, {
     4.927924298756059, -3.2508706963395118`}}]}, 
   {Hue[0.5812955552087263], AbsoluteThickness[0.5], 
    LineBox[{{3.369238487905497, -0.5796465797694774}, {
     3.269857989314481, -0.6356821997749984}}]}, 
   {Hue[0.5823665106903128], AbsoluteThickness[0.5], 
    LineBox[{{3.269857989314481, -0.6356821997749984}, {
     3.0543692916866285`, -0.7871154269790568}}]}, 
   {Hue[0.6591466885690559], AbsoluteThickness[0.5], 
    LineBox[{{7.106570400029819, 0.7577961924881375}, {7.102473340508566, 
     0.5779112173078137}}]}, 
   {Hue[0.6601249406698391], AbsoluteThickness[0.5], 
    LineBox[{{7.102473340508566, 0.5779112173078137}, {7.071378568365358, 
     0.31059879151226477`}}]}, 
   {Hue[0.49447674169804157`], AbsoluteThickness[0.5], 
    LineBox[{{7.22859843104247, 0.6437345447726576}, {7.334123986135445, 
     0.590869903527443}}]}, 
   {Hue[0.49498492908267777`], AbsoluteThickness[0.5], 
    LineBox[{{7.334123986135445, 0.590869903527443}, {7.641683393485013, 
     0.4213203387581476}}]}, 
   {Hue[0.6907315585711492], AbsoluteThickness[0.5], 
    LineBox[{{7.38387409082862, 0.7053005200379826}, {7.87279100232886, 
     1.0884699864880871`}}]}, 
   {Hue[0.6931259260754193], AbsoluteThickness[0.5], 
    LineBox[{{7.87279100232886, 1.0884699864880871`}, {8.074689512295892, 
     1.2022706671763876`}}]}, 
   {Hue[0.6935733862939631], AbsoluteThickness[0.5], 
    LineBox[{{4.707777054944674, 2.6211681366309105`}, {4.642088838947643, 
     2.506957978314241}}]}, 
   {Hue[0.6948988384378257], AbsoluteThickness[0.5], 
    LineBox[{{4.642088838947643, 2.506957978314241}, {4.494228650609289, 
     2.306347385714413}}]}, 
   {Hue[0.5559375137839565], AbsoluteThickness[0.5], 
    LineBox[{{4.115486524453757, 2.7482356002086603`}, {3.911798329504154, 
     2.746168564477438}}]}, 
   {Hue[0.5563839834562034], AbsoluteThickness[0.5], 
    LineBox[{{3.911798329504154, 2.746168564477438}, {3.65082766030624, 
     2.7487523936756824`}}]}, 
   {Hue[0.5783391314160539], AbsoluteThickness[0.5], 
    LineBox[{{6.31288380818695, 2.4468796855628687`}, {6.296794173493695, 
     2.3789835878655965`}}]}, 
   {Hue[0.5787930315363498], AbsoluteThickness[0.5], 
    LineBox[{{6.296794173493695, 2.3789835878655965`}, {6.230600065070971, 
     2.067423848193402}}]}, 
   {Hue[0.4856042010364298], AbsoluteThickness[0.5], 
    LineBox[{{7.16021407138392, 2.910910368175072}, {7.1657382258026, 
     2.892261476358964}}]}, 
   {Hue[0.48604585192972255`], AbsoluteThickness[0.5], 
    LineBox[{{7.1657382258026, 2.892261476358964}, {7.247655659047368, 
     2.6325659946933193`}}]}, 
   {Hue[0.5956935753881211], AbsoluteThickness[0.5], 
    LineBox[{{7.184929342423349, 3.5950695805290787`}, {7.085822270912795, 
     3.4898600064567704`}}]}, 
   {Hue[0.596984291510796], AbsoluteThickness[0.5], 
    LineBox[{{7.085822270912795, 3.4898600064567704`}, {6.922415044469377, 
     3.351165708620553}}]}, 
   {Hue[0.5965452841001581], AbsoluteThickness[0.5], 
    LineBox[{{7.184673460553426, 3.595311452445399}, {7.085774561823019, 
     3.4907829423666716`}}]}, 
   {Hue[0.5978006895708602], AbsoluteThickness[0.5], 
    LineBox[{{7.085774561823019, 3.4907829423666716`}, {6.92141241281815, 
     3.351384939936086}}]}, 
   {Hue[0.5763737460409601], AbsoluteThickness[0.5], 
    LineBox[{{5.680189173199461, 3.224450026102771}, {5.320583836945981, 
     3.182647944303204}}]}, 
   {Hue[0.5773274747125038], AbsoluteThickness[0.5], 
    LineBox[{{5.320583836945981, 3.182647944303204}, {5.092824504435442, 
     3.1770821719074314`}}]}, 
   {Hue[0.5037082548171797], AbsoluteThickness[0.5], 
    LineBox[{{7.036072613088459, 1.4052017722240022`}, {7.0497744669569276`, 
     1.3436458620790104`}}]}, 
   {Hue[0.5059220909408577], AbsoluteThickness[0.5], 
    LineBox[{{7.0497744669569276`, 1.3436458620790104`}, {7.13603491295625, 
     1.118172794723853}}]}, 
   {Hue[0.5562630931990825], AbsoluteThickness[0.5], 
    LineBox[{{6.24032129301724, 0.6114943942542783}, {6.254052353796291, 
     0.4591150657613863}}]}, 
   {Hue[0.5567169201109111], AbsoluteThickness[0.5], 
    LineBox[{{6.254052353796291, 0.4591150657613863}, {6.275686069130053, 
     0.13458730455650642`}}]}, 
   {Hue[0.6808533424246034], AbsoluteThickness[0.5], 
    LineBox[{{6.125973392619561, 1.1372774693986152`}, {6.125949862638041, 
     1.1037930866091488`}}]}, 
   {Hue[0.6815465017368533], AbsoluteThickness[0.5], 
    LineBox[{{6.125949862638041, 1.1037930866091488`}, {6.105245188704591, 
     0.8031678899006431}}]}, 
   {Hue[0.4610674642080967], AbsoluteThickness[0.5], 
    LineBox[{{2.535869208967545, 2.2619321249728177`}, {2.3611057402227593`, 
     2.28814444016606}}]}, 
   {Hue[0.4618550954856375], AbsoluteThickness[0.5], 
    LineBox[{{2.3611057402227593`, 2.28814444016606}, {2.112757166851967, 
     2.3058394773120328`}}]}, 
   {Hue[0.6479246736934939], AbsoluteThickness[0.5], 
    LineBox[{{5.717349801914242, -1.3560279734229912`}, {
     5.808873908217251, -1.4291918788502151`}}]}, 
   {Hue[0.6484604164651047], AbsoluteThickness[0.5], 
    LineBox[{{5.808873908217251, -1.4291918788502151`}, {
     6.05552751728086, -1.6087165333660023`}}]}, 
   {Hue[0.6504103703716868], AbsoluteThickness[0.5], 
    LineBox[{{7.556633694946215, -1.650332656542385}, {
     7.688625993698778, -1.692623694802423}}]}, 
   {Hue[0.6509855572612708], AbsoluteThickness[0.5], 
    LineBox[{{7.688625993698778, -1.692623694802423}, {
     7.9424463737825235`, -1.7888201348337402`}}]}, 
   {Hue[0.48599237002759815`], AbsoluteThickness[0.5], 
    LineBox[{{7.282726334575455, 2.400213277866814}, {7.307815675639781, 
     2.408444784236237}}]}, 
   {Hue[0.48645069822284587`], AbsoluteThickness[0.5], 
    LineBox[{{7.307815675639781, 2.408444784236237}, {7.61985987874316, 
     2.519564290810599}}]}, 
   {Hue[0.308068169598451], AbsoluteThickness[0.5], 
    LineBox[{{6.317775973003887, 3.3902650168562634`}, {6.320664742520367, 
     3.5812749838905065`}}]}, 
   {Hue[0.30894999268242096`], AbsoluteThickness[0.5], 
    LineBox[{{6.320664742520367, 3.5812749838905065`}, {6.302348483843416, 
     3.8398168413632288`}}]}, 
   {Hue[0.5179479001645835], AbsoluteThickness[0.5], 
    LineBox[{{4.573343818916358, 2.2573028258669767`}, {4.403070982979961, 
     2.2294412893510875`}}]}, 
   {Hue[0.5184386592786769], AbsoluteThickness[0.5], 
    LineBox[{{4.403070982979961, 2.2294412893510875`}, {4.085304837150187, 
     2.1888510178329126`}}]}, 
   {Hue[0.6146948731536453], AbsoluteThickness[0.5], 
    LineBox[{{3.4060892046090165`, -3.8814786394256395`}, {
     3.412677577305526, -3.9606126493363623`}}]}, 
   {Hue[0.6171297744436484], AbsoluteThickness[0.5], 
    LineBox[{{3.412677577305526, -3.9606126493363623`}, {
     3.465190071487695, -4.179340878098618}}]}, 
   {Hue[0.6079511209679576], AbsoluteThickness[0.5], 
    LineBox[{{7.3425803584284415`, -0.914332636399622}, {
     7.397240851224664, -0.9191457759134312}}]}, 
   {Hue[0.6084547708584248], AbsoluteThickness[0.5], 
    LineBox[{{7.397240851224664, -0.9191457759134312}, {
     7.699047522042055, -0.9574292814846297}}]}, 
   {Hue[0.6105516357709048], AbsoluteThickness[0.5], 
    LineBox[{{4.653979532192287, -1.358505314228561}, {
     4.658814739349143, -1.3977223638135636`}}]}, 
   {Hue[0.6139484834391948], AbsoluteThickness[0.5], 
    LineBox[{{4.658814739349143, -1.3977223638135636`}, {
     4.648458270266406, -1.597359610086278}}]}, 
   {Hue[0.5932182656391091], AbsoluteThickness[0.5], 
    LineBox[{{2.5529457093690726`, -1.1990597241502436`}, {
     2.584367748602323, -1.3961680961671077`}}]}, 
   {Hue[0.5955846322321386], AbsoluteThickness[0.5], 
    LineBox[{{2.584367748602323, -1.3961680961671077`}, {
     2.5859190739538196`, -1.6062134069907046`}}]}, 
   {Hue[0.5414015382067392], AbsoluteThickness[0.5], 
    LineBox[{{4.388896960105848, 1.6199368422242373`}, {4.462148044020867, 
     1.5675062543096865`}}]}, 
   {Hue[0.5419528456214565], AbsoluteThickness[0.5], 
    LineBox[{{4.462148044020867, 1.5675062543096865`}, {4.657509732164344, 
     1.4129386468563787`}}]}, 
   {Hue[0.6080593826761659], AbsoluteThickness[0.5], 
    LineBox[{{3.3851906214941887`, -0.16686817252223235`}, {
     3.3904336998779727`, -0.18805103874740176`}}]}, 
   {Hue[0.6156833317283802], AbsoluteThickness[0.5], 
    LineBox[{{3.3904336998779727`, -0.18805103874740176`}, {
     3.39257354235322, -0.37339001916191417`}}]}, 
   {Hue[0.5986870414943346], AbsoluteThickness[0.5], 
    LineBox[{{3.2161520007271167`, -0.9458052882553587}, {
     3.2323865649864016`, -1.076540780847948}}]}, 
   {Hue[0.5991622478132098], AbsoluteThickness[0.5], 
    LineBox[{{3.2323865649864016`, -1.076540780847948}, {
     3.262436722702359, -1.3995195642428773`}}]}, 
   {Hue[0.6876607872567483], AbsoluteThickness[0.5], 
    LineBox[{{4.6074420391303885`, -4.138066228502307}, {
     4.603105553837387, -4.180519181541881}}]}, 
   {Hue[0.6903812642228967], AbsoluteThickness[0.5], 
    LineBox[{{4.603105553837387, -4.180519181541881}, {
     4.616209255770585, -4.406150595429859}}]}, 
   {Hue[0.5517945616491053], AbsoluteThickness[0.5], 
    LineBox[{{6.1642060149909925`, -3.5653003030303325`}, {
     6.201434215006257, -3.5959377423351433`}}]}, 
   {Hue[0.5531029763373083], AbsoluteThickness[0.5], 
    LineBox[{{6.201434215006257, -3.5959377423351433`}, {
     6.368486949501586, -3.7682712387193535`}}]}, 
   {Hue[0.563473174854103], AbsoluteThickness[0.5], 
    LineBox[{{6.511221273900341, 2.6751388822755158`}, {6.557248759344015, 
     2.7002577953350144`}}]}, 
   {Hue[0.5639608634212643], AbsoluteThickness[0.5], 
    LineBox[{{6.557248759344015, 2.7002577953350144`}, {6.841882527430227, 
     2.8431398365597307`}}]}, 
   {Hue[0.5113880456990749], AbsoluteThickness[0.5], 
    LineBox[{{6.616788479765853, -2.950428166710202}, {
     6.722009770070851, -3.0659198794765894`}}]}, 
   {Hue[0.5122169518407885], AbsoluteThickness[0.5], 
    LineBox[{{6.722009770070851, -3.0659198794765894`}, {
     6.896738922740622, -3.292247395390472}}]}, 
   {Hue[0.4212445617762969], AbsoluteThickness[0.5], 
    LineBox[{{6.617477561541223, -3.1122152641639285`}, {
     6.610176993702046, -3.1335876994741643`}}]}, 
   {Hue[0.43575911636371817`], AbsoluteThickness[0.5], 
    LineBox[{{6.610176993702046, -3.1335876994741643`}, {
     6.60151692415968, -3.3113512365335254`}}]}, 
   {Hue[0.6399441022531662], AbsoluteThickness[0.5], 
    LineBox[{{6.60151692415968, -3.3113512365335254`}, {
     6.759467349062372, -3.393366693524221}}]}, 
   {Hue[0.5665932215877317], AbsoluteThickness[0.5], 
    LineBox[{{6.476040812300579, -3.1907721588354567`}, {
     6.398715475913875, -3.2043303385469644`}}]}, 
   {Hue[0.5670414796954155], AbsoluteThickness[0.5], 
    LineBox[{{6.398715475913875, -3.2043303385469644`}, {
     6.102093022519754, -3.2627510398409374`}}]}, 
   {Hue[0.5192419643626038], AbsoluteThickness[0.5], 
    LineBox[{{5.747507527268757, -3.428531406454751}, {
     5.719170966011284, -3.611202752973073}}]}, 
   {Hue[0.5197870713218915], AbsoluteThickness[0.5], 
    LineBox[{{5.719170966011284, -3.611202752973073}, {
     5.687592682646478, -3.9054368108495336`}}]}, 
   {Hue[0.6573437649656083], AbsoluteThickness[0.5], 
    LineBox[{{3.644504655349183, -3.33078911514527}, {
     3.6406737326091285`, -3.34592015108992}}]}, 
   {Hue[0.6579791781337404], AbsoluteThickness[0.5], 
    LineBox[{{3.6406737326091285`, -3.34592015108992}, {
     3.5563293545715076`, -3.610162980692292}}]}, 
   {Hue[0.4695789406385876], AbsoluteThickness[0.5], 
    LineBox[{{6.9456444988373125`, 3.348252113197838}, {7.055392354312962, 
     3.322054396985389}}]}, 
   {Hue[0.4700224553669398], AbsoluteThickness[0.5], 
    LineBox[{{7.055392354312962, 3.322054396985389}, {7.382016008118116, 
     3.2376458166909385`}}]}, 
   {Hue[0.38434694026671384`], AbsoluteThickness[0.5], 
    LineBox[{{7.066479208495928, 3.4133985998359253`}, {7.213018404823525, 
     3.5738752489258165`}}]}, 
   {Hue[0.384805120664513], AbsoluteThickness[0.5], 
    LineBox[{{7.213018404823525, 3.5738752489258165`}, {7.42028194458383, 
     3.81258141514433}}]}, 
   {Hue[0.6690485317648855], AbsoluteThickness[0.5], 
    LineBox[{{6.94868361155915, 3.6185145995249357`}, {6.850338372406041, 
     3.63647705585204}}]}, 
   {Hue[0.6697862829820282], AbsoluteThickness[0.5], 
    LineBox[{{6.850338372406041, 3.63647705585204}, {6.555222817980784, 
     3.712942174031116}}]}, 
   {Hue[0.6038716599868535], AbsoluteThickness[0.5], 
    LineBox[{{4.617511954272839, 1.3553408825106987`}, {4.620905424598565, 
     1.352518276667503}}]}, 
   {Hue[0.6043237834298204], AbsoluteThickness[0.5], 
    LineBox[{{4.620905424598565, 1.352518276667503}, {4.824543219372039, 
     1.1907794533236074`}}]}, 
   {Hue[0.519318334016587], AbsoluteThickness[0.5], 
    LineBox[{{4.941176113767496, 3.2359053568132}, {5.08454426361663, 
     3.1911221629516984`}}]}, 
   {Hue[0.5206427628384985], AbsoluteThickness[0.5], 
    LineBox[{{5.08454426361663, 3.1911221629516984`}, {5.2939762893011935`, 
     3.1509313385206026`}}]}, 
   {Hue[0.5954879926820712], AbsoluteThickness[0.5], 
    LineBox[{{4.632895834542047, 1.8432453051362663`}, {4.639061016812665, 
     1.838301402809118}}]}, 
   {Hue[0.596029774309896], AbsoluteThickness[0.5], 
    LineBox[{{4.639061016812665, 1.838301402809118}, {4.858981809466942, 
     1.644533716837456}}]}, 
   {Hue[0.62931491208389], AbsoluteThickness[0.5], 
    LineBox[{{5.127647872288066, -0.04200040969886959}, {
     5.15514282247866, -0.07022867350685053}}]}, 
   {Hue[0.6297408299540798], AbsoluteThickness[0.5], 
    LineBox[{{5.15514282247866, -0.07022867350685053}, {
     5.405810919239806, -0.3281606663910663}}]}, 
   {Hue[0.39979951510187767`], AbsoluteThickness[0.5], 
    LineBox[{{4.67460324119989, -0.04532086218505807}, {
     4.6941905447843775`, -0.07650392881212484}}]}, 
   {Hue[0.4003544403100145], AbsoluteThickness[0.5], 
    LineBox[{{4.6941905447843775`, -0.07650392881212484}, {
     4.843559146862032, -0.34223311752639957`}}]}, 
   {Hue[0.6876180414920163], AbsoluteThickness[0.5], 
    LineBox[{{6.107817892937866, 3.0820703584775844`}, {6.130789427356583, 
     3.1499837990060775`}}]}, 
   {Hue[0.6888443534416709], AbsoluteThickness[0.5], 
    LineBox[{{6.130789427356583, 3.1499837990060775`}, {6.242904913959022, 
     3.3917007551980287`}}]}, 
   {Hue[0.48426039698561024`], AbsoluteThickness[0.5], 
    LineBox[{{5.675986714913615, 0.9967549667739574}, {5.741208637325714, 
     0.9196099797378152}}]}, 
   {Hue[0.4849778749178962], AbsoluteThickness[0.5], 
    LineBox[{{5.741208637325714, 0.9196099797378152}, {5.900968478509016, 
     0.7010010828736314}}]}, 
   {Hue[0.6722281417906512], AbsoluteThickness[0.5], 
    LineBox[{{3.9307210461549835`, -0.10486998684732424`}, {
     3.8778067648072603`, -0.3787194834671994}}]}, 
   {Hue[0.6743879878134211], AbsoluteThickness[0.5], 
    LineBox[{{3.8778067648072603`, -0.3787194834671994}, {
     3.8676867473927774`, -0.5981021422521511}}]}, 
   {Hue[0.5586588230174182], AbsoluteThickness[0.5], 
    LineBox[{{6.608183685638831, 2.4232407335413124`}, {6.837601401431566, 
     2.418972433736205}}]}, 
   {Hue[0.5592518795085747], AbsoluteThickness[0.5], 
    LineBox[{{6.837601401431566, 2.418972433736205}, {7.126230613235518, 
     2.4294834043892255`}}]}, 
   {Hue[0.5237671243759239], AbsoluteThickness[0.5], 
    LineBox[{{5.984647502017991, 3.6061967241379795`}, {6.091279886441849, 
     3.653337637290371}}]}, 
   {Hue[0.5241964353067677], AbsoluteThickness[0.5], 
    LineBox[{{6.091279886441849, 3.653337637290371}, {6.368635478872738, 
     3.7732276526942092`}}]}, 
   {Hue[0.5052408493096338], AbsoluteThickness[0.5], 
    LineBox[{{5.781922615041296, -0.871832099910341}, {
     5.754428191410227, -1.0434185725979352`}}]}, 
   {Hue[0.5057044651286476], AbsoluteThickness[0.5], 
    LineBox[{{5.754428191410227, -1.0434185725979352`}, {
     5.696981487684972, -1.348888178586828}}]}, 
   {Hue[0.6120636833244542], AbsoluteThickness[0.5], 
    LineBox[{{7.361646608524819, -3.319072509789756}, {
     7.594301855746022, -3.355263573386797}}]}, 
   {Hue[0.6135527841635182], AbsoluteThickness[0.5], 
    LineBox[{{7.594301855746022, -3.355263573386797}, {
     7.858649778899655, -3.3641357320589047`}}]}, 
   {Hue[0.5793950297381467], AbsoluteThickness[0.5], 
    LineBox[{{6.634881995568328, -3.352382832507059}, {
     6.732289888655586, -3.5843794438519327`}}]}, 
   {Hue[0.5799546383060875], AbsoluteThickness[0.5], 
    LineBox[{{6.732289888655586, -3.5843794438519327`}, {
     6.843682850484345, -3.891511137126358}}]}, 
   {Hue[0.6185041011085385], AbsoluteThickness[0.5], 
    LineBox[{{3.6792366205783775`, 0.6505188873889134}, {3.605425499707965, 
     0.5640513837439174}}]}, 
   {Hue[0.6190730597078685], AbsoluteThickness[0.5], 
    LineBox[{{3.605425499707965, 0.5640513837439174}, {3.4084463355944523`, 
     0.35587524451730274`}}]}, 
   {Hue[0.6256650013986984], AbsoluteThickness[0.5], 
    LineBox[{{2.842417548472058, 2.529414166170133}, {2.654457714501894, 
     2.5077119463284476`}}]}, 
   {Hue[0.6261740466718139], AbsoluteThickness[0.5], 
    LineBox[{{2.654457714501894, 2.5077119463284476`}, {2.3562469830919617`, 
     2.485197468968269}}]}, 
   {Hue[0.6021462809349803], AbsoluteThickness[0.5], 
    LineBox[{{5.127998350145082, 1.6626096101271308`}, {5.094051417503939, 
     1.6382145771636516`}}]}, 
   {Hue[0.6026895674512033], AbsoluteThickness[0.5], 
    LineBox[{{5.094051417503939, 1.6382145771636516`}, {4.842844512824184, 
     1.4392936771747449`}}]}, 
   {Hue[0.632807799651739], AbsoluteThickness[0.5], 
    LineBox[{{6.723258134196153, 2.5726603038964178`}, {6.488638875158121, 
     2.149179832717918}}]}, 
   {Hue[0.6338676670998354], AbsoluteThickness[0.5], 
    LineBox[{{6.488638875158121, 2.149179832717918}, {6.383085316021455, 
     1.9046355066773064`}}]}, 
   {Hue[0.6596503940615112], AbsoluteThickness[0.5], 
    LineBox[{{6.820739513568189, 3.520254990127432}, {6.443529319245155, 
     3.2242510633743606`}}]}, 
   {Hue[0.6606922555552005], AbsoluteThickness[0.5], 
    LineBox[{{6.443529319245155, 3.2242510633743606`}, {6.21143363240012, 
     3.0761220534022833`}}]}, 
   {Hue[0.6135956301540858], AbsoluteThickness[0.5], 
    LineBox[{{6.114109083381312, 3.2615845759705047`}, {5.9016842042455435`, 
     3.196470461302906}}]}, 
   {Hue[0.6165174884139832], AbsoluteThickness[0.5], 
    LineBox[{{5.9016842042455435`, 3.196470461302906}, {5.723562029721975, 
     3.1726519464830676`}}]}, 
   {Hue[0.6198010986196992], AbsoluteThickness[0.5], 
    LineBox[{{6.069546825119555, 1.372931739423643}, {5.933871885578536, 
     1.2823801343430137`}}]}, 
   {Hue[0.6203427769232372], AbsoluteThickness[0.5], 
    LineBox[{{5.933871885578536, 1.2823801343430137`}, {5.641773977924679, 
     1.1064211514942497`}}]}, 
   {Hue[0.6049408627170132], AbsoluteThickness[0.5], 
    LineBox[{{3.8276922923986394`, 3.001994781875114}, {3.6614940550573465`, 
     2.9744327987728054`}}]}, 
   {Hue[0.6055494898983186], AbsoluteThickness[0.5], 
    LineBox[{{3.6614940550573465`, 2.9744327987728054`}, {3.357926920129768, 
     2.9418150624706527`}}]}, 
   {Hue[0.6182217351324272], AbsoluteThickness[0.5], 
    LineBox[{{4.611935093798961, 1.243631193343742}, {4.5371863396406376`, 
     1.1871584538361455`}}]}, 
   {Hue[0.6195893537076113], AbsoluteThickness[0.5], 
    LineBox[{{4.5371863396406376`, 1.1871584538361455`}, {4.3353333284748645`,
      0.9944352179258321}}]}, 
   {Hue[0.6067090401667707], AbsoluteThickness[0.5], 
    LineBox[{{2.546881021977942, 3.7264227465521644`}, {2.3699339514170727`, 
     3.753764811790943}}]}, 
   {Hue[0.607275252259304], AbsoluteThickness[0.5], 
    LineBox[{{2.3699339514170727`, 3.753764811790943}, {2.086562279789608, 
     3.7829403166810858`}}]}, 
   {Hue[0.6791074867160228], AbsoluteThickness[0.5], 
    LineBox[{{5.176367482115074, -1.3974741076502395`}, {
     5.194883436993998, -1.5591672337011635`}}]}, 
   {Hue[0.6796011436934976], AbsoluteThickness[0.5], 
    LineBox[{{5.194883436993998, -1.5591672337011635`}, {
     5.2440335586323, -1.8845762587955819`}}]}, 
   {Hue[0.6351340479897015], AbsoluteThickness[0.5], 
    LineBox[{{3.2848390399757355`, -0.43920317876114956`}, {
     2.930148660701906, -0.8551677775408688}}]}, 
   {Hue[0.638150028842419], AbsoluteThickness[0.5], 
    LineBox[{{2.930148660701906, -0.8551677775408688}, {
     2.8294913838282776`, -1.023295967301037}}]}, 
   {Hue[0.6319132000474463], AbsoluteThickness[0.5], 
    LineBox[{{4.878069014737911, -3.0806208376058892`}, {
     4.880673410767832, -3.152388936105107}}]}, 
   {Hue[0.6334386663641202], AbsoluteThickness[0.5], 
    LineBox[{{4.880673410767832, -3.152388936105107}, {
     4.859135948332847, -3.4020404720633985`}}]}, 
   {Hue[0.6522495223066651], AbsoluteThickness[0.5], 
    LineBox[{{7.563580472881811, 2.2008818576107276`}, {7.6013280068486315`, 
     2.210236207525206}}]}, 
   {Hue[0.6527187273493844], AbsoluteThickness[0.5], 
    LineBox[{{7.6013280068486315`, 2.210236207525206}, {7.903756265187747, 
     2.2945246706427374`}}]}, 
   {Hue[0.6169865491539915], AbsoluteThickness[0.5], 
    LineBox[{{4.51286598813684, -3.6224376980746786`}, {
     4.489814181940462, -3.866914974361937}}]}, 
   {Hue[0.6175058795931306], AbsoluteThickness[0.5], 
    LineBox[{{4.489814181940462, -3.866914974361937}, {
     4.474844057299938, -4.153721484040043}}]}, 
   {Hue[0.6018352422680453], AbsoluteThickness[0.5], 
    LineBox[{{6.855775058733314, -1.630067245352622}, {
     6.861251966509902, -2.080076122642013}}]}, 
   {Hue[0.602472618930128], AbsoluteThickness[0.5], 
    LineBox[{{6.861251966509902, -2.080076122642013}, {
     6.847778179036615, -2.3543430890640478`}}]}, 
   {Hue[0.6160228912559946], AbsoluteThickness[0.5], 
    LineBox[{{8.035106071540802, 1.2081276660530174`}, {8.119758215217612, 
     1.255090599882629}}]}, 
   {Hue[0.6165604550875642], AbsoluteThickness[0.5], 
    LineBox[{{8.119758215217612, 1.255090599882629}, {8.422129204667854, 
     1.4052562964613458`}}]}, 
   {Hue[0.5958752799843151], AbsoluteThickness[0.5], 
    LineBox[{{6.802189898380744, 0.9145935981196168}, {6.865883608391564, 
     0.9454915227551592}}]}, 
   {Hue[0.5963166355063766], AbsoluteThickness[0.5], 
    LineBox[{{6.865883608391564, 0.9454915227551592}, {7.1468844959084254`, 
     1.0758120627395946`}}]}, 
   {Hue[0.40817964832127557`], AbsoluteThickness[0.5], 
    LineBox[{{6.268681526761039, -4.461506493875207}, {
     6.378832522633722, -4.601835939593728}}]}, 
   {Hue[0.4426711236556462], AbsoluteThickness[0.5], 
    LineBox[{{6.378832522633722, -4.601835939593728}, {
     6.515842879083667, -4.686404768494359}}]}, 
   {Hue[0.5687040006970404], AbsoluteThickness[0.5], 
    LineBox[{{6.515842879083667, -4.686404768494359}, {
     6.657366973317836, -4.609628109623558}}]}, 
   {Hue[0.6947368777384358], AbsoluteThickness[0.5], 
    LineBox[{{6.657366973317836, -4.609628109623558}, {
     6.661176382373915, -4.4486647193796625`}}]}, 
   {Hue[0.5866210215565567], AbsoluteThickness[0.5], 
    LineBox[{{7.3530684958010575`, 1.8344932747784646`}, {7.355765027095357, 
     1.9336270023813256`}}]}, 
   {Hue[0.588498499265156], AbsoluteThickness[0.5], 
    LineBox[{{7.355765027095357, 1.9336270023813256`}, {7.397482777677356, 
     2.187423202025673}}]}, 
   {Hue[0.6659522216021271], AbsoluteThickness[0.5], 
    LineBox[{{6.868249878261521, 3.372010837322364}, {6.868923634040502, 
     3.3757616659563117`}}]}, 
   {Hue[0.6665897796268608], AbsoluteThickness[0.5], 
    LineBox[{{6.868923634040502, 3.3757616659563117`}, {6.927591023790071, 
     3.6165254492702736`}}]}, 
   {Hue[0.6440987025268351], AbsoluteThickness[0.5], 
    LineBox[{{7.8333764060731985`, 3.3754843712530844`}, {7.854209724742897, 
     3.380242534400179}}]}, 
   {Hue[0.6447494025790502], AbsoluteThickness[0.5], 
    LineBox[{{7.854209724742897, 3.380242534400179}, {8.139525524408215, 
     3.4646133869763553`}}]}, 
   {Hue[0.5229241505600716], AbsoluteThickness[0.5], 
    LineBox[{{2.995715173182376, -3.1733914357500974`}, {
     2.9112239811308207`, -3.4187740102724917`}}]}, 
   {Hue[0.525905156741434], AbsoluteThickness[0.5], 
    LineBox[{{2.9112239811308207`, -3.4187740102724917`}, {
     2.875237313262489, -3.6338522143657372`}}]}, 
   {Hue[0.5330347441208451], AbsoluteThickness[0.5], 
    LineBox[{{6.16168791822775, -3.0749755625848882`}, {
     6.185423174042029, -3.1196653768079265`}}]}, 
   {Hue[0.5334608180936676], AbsoluteThickness[0.5], 
    LineBox[{{6.185423174042029, -3.1196653768079265`}, {
     6.328250223895723, -3.389944059906378}}]}, 
   {Hue[0.5618157549202227], AbsoluteThickness[0.5], 
    LineBox[{{3.58604050655056, 2.2808705225509027`}, {3.5041453032767076`, 
     2.3461357344948643`}}]}, 
   {Hue[0.5628623979645866], AbsoluteThickness[0.5], 
    LineBox[{{3.5041453032767076`, 2.3461357344948643`}, {3.3162643999417827`,
      2.528492634657914}}]}, 
   {Hue[0.619891919085553], AbsoluteThickness[0.5], 
    LineBox[{{7.599792642783219, -1.1269982569351897`}, {
     7.663408327300694, -1.128524939457774}}]}, 
   {Hue[0.6210486046170238], AbsoluteThickness[0.5], 
    LineBox[{{7.663408327300694, -1.128524939457774}, {
     7.933481416148531, -1.1633584400397454`}}]}, 
   {Hue[0.4360112701722574], AbsoluteThickness[0.5], 
    LineBox[{{7.901723674736531, -0.7509719170866105}, {
     8.109117926431201, -0.8940324685834786}}]}, 
   {Hue[0.48501864828567864`], AbsoluteThickness[0.5], 
    LineBox[{{8.109117926431201, -0.8940324685834786}, {
     8.189489835027498, -1.0154040558751327`}}]}, 
   {Hue[0.5822069259139432], AbsoluteThickness[0.5], 
    LineBox[{{8.189489835027498, -1.0154040558751327`}, {
     8.127048359594852, -1.1469022233106576`}}]}, 
   {Hue[0.6793952035422072], AbsoluteThickness[0.5], 
    LineBox[{{8.127048359594852, -1.1469022233106576`}, {
     7.982194437236002, -1.1613260601914297`}}]}, 
   {Hue[0.6629210345682767], AbsoluteThickness[0.5], 
    LineBox[{{7.5523250595791, 0.8673630759479951}, {7.6482464649643465`, 
     0.8513226029777012}}]}, 
   {Hue[0.6635062152011303], AbsoluteThickness[0.5], 
    LineBox[{{7.6482464649643465`, 0.8513226029777012}, {7.955694403024574, 
     0.782738456935068}}]}, 
   {Hue[0.46035836804454194`], AbsoluteThickness[0.5], 
    LineBox[{{7.6951212409165795`, 0.9992939556104838}, {7.785066957458206, 
     1.1420356299509875`}}]}, 
   {Hue[0.4611512575468515], AbsoluteThickness[0.5], 
    LineBox[{{7.785066957458206, 1.1420356299509875`}, {7.896605317102891, 
     1.3541813632763937`}}]}, 
   {Hue[0.6860659077641116], AbsoluteThickness[0.5], 
    LineBox[{{7.628588505962726, 1.181968260296843}, {7.513490984129314, 
     1.3459727162800545`}}]}, 
   {Hue[0.686712169199623], AbsoluteThickness[0.5], 
    LineBox[{{7.513490984129314, 1.3459727162800545`}, {7.356772733660368, 
     1.6018628005425573`}}]}, 
   {Hue[0.3727573686491261], AbsoluteThickness[0.5], 
    LineBox[{{7.899719388540627, 0.12718288154891433`}, {7.920827481869453, 
     0.11933425148703974`}}]}, 
   {Hue[0.3736802888127117], AbsoluteThickness[0.5], 
    LineBox[{{7.920827481869453, 0.11933425148703974`}, {8.164008729672853, 
     0.003355539846870325}}]}, 
   {Hue[0.5052194376669057], AbsoluteThickness[0.5], 
    LineBox[{{7.132814152039796, -0.02250667310638249}, {
     7.162241287651955, -0.15624996277182365`}}]}, 
   {Hue[0.5057805155701909], AbsoluteThickness[0.5], 
    LineBox[{{7.162241287651955, -0.15624996277182365`}, {
     7.20888768430507, -0.4334086119362308}}]}, 
   {Hue[0.6351005395598729], AbsoluteThickness[0.5], 
    LineBox[{{6.3418509883730865`, 0.06432645586652264}, {
     6.196887468772629, -0.00498097224151306}}]}, 
   {Hue[0.6359058447784124], AbsoluteThickness[0.5], 
    LineBox[{{6.196887468772629, -0.00498097224151306}, {
     5.913563059055855, -0.11376840001306046`}}]}, 
   {Hue[0.6685976497710641], AbsoluteThickness[0.5], 
    LineBox[{{5.611670008287723, 1.6508958569376952`}, {5.324295866875185, 
     1.719110217028241}}]}, 
   {Hue[0.6690409578118728], AbsoluteThickness[0.5], 
    LineBox[{{5.324295866875185, 1.719110217028241}, {5.075245876106266, 
     1.7831069164949753`}}]}, 
   {Hue[0.3350587707701657], AbsoluteThickness[0.5], 
    LineBox[{{6.031591311258323, 2.6542426414846823`}, {5.982462563269062, 
     2.8951615399397537`}}]}, 
   {Hue[0.3354919703778555], AbsoluteThickness[0.5], 
    LineBox[{{5.982462563269062, 2.8951615399397537`}, {5.927645572126009, 
     3.1815019861593914`}}]}, 
   {Hue[0.6732749934911978], AbsoluteThickness[0.5], 
    LineBox[{{7.096712114255172, 2.0552726307044797`}, {7.36409748654082, 
     2.1590264323344486`}}]}, 
   {Hue[0.678540912896661], AbsoluteThickness[0.5], 
    LineBox[{{7.36409748654082, 2.1590264323344486`}, {7.576460371272108, 
     2.194527155146336}}]}, 
   {Hue[0.5789558012645077], AbsoluteThickness[0.5], 
    LineBox[{{4.945914233964435, 2.058730159794663}, {4.780241384855322, 
     2.1100725609344484`}}]}, 
   {Hue[0.5815080731893206], AbsoluteThickness[0.5], 
    LineBox[{{4.780241384855322, 2.1100725609344484`}, {4.58256336409172, 
     2.2070644110135347`}}]}, 
   {Hue[0.6673750048354613], AbsoluteThickness[0.5], 
    LineBox[{{6.619886806170689, 0.8339896808481111}, {6.48721949779537, 
     0.6600890488725857}}]}, 
   {Hue[0.6680775530391526], AbsoluteThickness[0.5], 
    LineBox[{{6.48721949779537, 0.6600890488725857}, {6.35625304966237, 
     0.46131508443818753`}}]}, 
   {Hue[0.5511090046060761], AbsoluteThickness[0.5], 
    LineBox[{{7.266562499096643, 1.1166251339557969`}, {7.296354765024151, 
     0.948314484576309}}]}, 
   {Hue[0.5516989393247438], AbsoluteThickness[0.5], 
    LineBox[{{7.296354765024151, 0.948314484576309}, {7.3313718199692195`, 
     0.6595266115944417}}]}, 
   {Hue[0.5248315870181482], AbsoluteThickness[0.5], 
    LineBox[{{8.061343879347792, 2.258271950304787}, {8.004131387367227, 
     2.3181327588131215`}}]}, 
   {Hue[0.5261334684200435], AbsoluteThickness[0.5], 
    LineBox[{{8.004131387367227, 2.3181327588131215`}, {7.858953238404366, 
     2.5088130487343236`}}]}, 
   {Hue[0.5547152062063514], AbsoluteThickness[0.5], 
    LineBox[{{6.8450430960388005`, 2.032980779809204}, {6.74166076337731, 
     2.1134329243504824`}}]}, 
   {Hue[0.5758481320702709], AbsoluteThickness[0.5], 
    LineBox[{{6.74166076337731, 2.1134329243504824`}, {6.667580882181964, 
     2.2220822606053163`}}]}, 
   {Hue[0.5961100494606633], AbsoluteThickness[0.5], 
    LineBox[{{6.181660761323864, 1.8570695721971526`}, {6.13806954529159, 
     1.864813670924702}}]}, 
   {Hue[0.5970641297047724], AbsoluteThickness[0.5], 
    LineBox[{{6.13806954529159, 1.864813670924702}, {5.854047822456555, 
     1.9425440800647433`}}]}, 
   {Hue[0.6133300220279292], AbsoluteThickness[0.5], 
    LineBox[{{6.6304109223217775`, -0.05827625494896646}, {
     6.617063285700968, -0.0976231368562884}}]}, 
   {Hue[0.6155005971961504], AbsoluteThickness[0.5], 
    LineBox[{{6.617063285700968, -0.0976231368562884}, {
     6.574169473921102, -0.33075794754658466`}}]}, 
   {Hue[0.6422538124784595], AbsoluteThickness[0.5], 
    LineBox[{{7.8542008051209935`, 0.07529020404886505}, {7.870707310780147, 
     0.06824215646268747}}]}, 
   {Hue[0.6426957512369486], AbsoluteThickness[0.5], 
    LineBox[{{7.870707310780147, 0.06824215646268747}, {
     8.158205626616963, -0.06058942318474259}}]}, 
   {Hue[0.5078363574969847], AbsoluteThickness[0.5], 
    LineBox[{{7.6736423294833855`, 0.9480402193088191}, {7.869415976259476, 
     1.0134452203449582`}}]}, 
   {Hue[0.508276539669171], AbsoluteThickness[0.5], 
    LineBox[{{7.869415976259476, 1.0134452203449582`}, {8.180737920192712, 
     1.111690354039852}}]}, 
   {Hue[0.6778806878882175], AbsoluteThickness[0.5], 
    LineBox[{{7.32922660086373, 1.8538082160152232`}, {7.334526240740403, 
     1.9683302663316777`}}]}, 
   {Hue[0.6826813145161403], AbsoluteThickness[0.5], 
    LineBox[{{7.334526240740403, 1.9683302663316777`}, {7.387360143015135, 
     2.180282114376349}}]}, 
   {Hue[0.6014474448754233], AbsoluteThickness[0.5], 
    LineBox[{{7.092235975091861, -0.2645162436929099}, {
     7.065511116741623, -0.3266400195372335}}]}, 
   {Hue[0.6019490616157223], AbsoluteThickness[0.5], 
    LineBox[{{7.065511116741623, -0.3266400195372335}, {
     6.928646105208941, -0.6142804425623265}}]}, 
   {Hue[0.44313233002682134`], AbsoluteThickness[0.5], 
    LineBox[{{7.158998934542703, -0.41201890895875926`}, {
     7.320278928417021, -0.597260717572432}}]}, 
   {Hue[0.45173733702252933`], AbsoluteThickness[0.5], 
    LineBox[{{7.320278928417021, -0.597260717572432}, {
     7.418706028138566, -0.7880472302313272}}]}, 
   {Hue[0.634667773079041], AbsoluteThickness[0.5], 
    LineBox[{{7.320863950601745, -0.4157666537966871}, {
     7.341630828646332, -0.41005999132847265`}}]}, 
   {Hue[0.6358636764778236], AbsoluteThickness[0.5], 
    LineBox[{{7.341630828646332, -0.41005999132847265`}, {
     7.583248365483674, -0.3706463557624019}}]}, 
   {Hue[0.543249392762895], AbsoluteThickness[0.5], 
    LineBox[{{5.110941489397328, -0.26309098116977064`}, {
     4.631085858667331, -0.4478055950402298}}]}, 
   {Hue[0.5437281395899206], AbsoluteThickness[0.5], 
    LineBox[{{4.631085858667331, -0.4478055950402298}, {
     4.344821048486562, -0.5685940836680768}}]}, 
   {Hue[0.6713208425543107], AbsoluteThickness[0.5], 
    LineBox[{{5.458242853094072, 1.1434878315914034`}, {5.374982028591521, 
     1.1541643980993037`}}]}, 
   {Hue[0.6719124732679392], AbsoluteThickness[0.5], 
    LineBox[{{5.374982028591521, 1.1541643980993037`}, {5.070465296677498, 
     1.2103076159297081`}}]}, 
   {Hue[0.6187335189214899], AbsoluteThickness[0.5], 
    LineBox[{{5.700258301580861, -0.40654928608680774`}, {
     5.630034872362556, -0.44712928847469885`}}]}, 
   {Hue[0.6191646152500633], AbsoluteThickness[0.5], 
    LineBox[{{5.630034872362556, -0.44712928847469885`}, {
     5.351801058307338, -0.6117034079138762}}]}, 
   {Hue[0.3266915485239077], AbsoluteThickness[0.5], 
    LineBox[{{4.689132423954502, 2.9184148253929196`}, {4.670340703466021, 
     2.928932547011298}}]}, 
   {Hue[0.32712123131698617`], AbsoluteThickness[0.5], 
    LineBox[{{4.670340703466021, 2.928932547011298}, {4.393713261763169, 
     3.080622086119426}}]}, 
   {Hue[0.591708140822764], AbsoluteThickness[0.5], 
    LineBox[{{4.139745075665066, 0.29960027545355683`}, {4.041195950510876, 
     0.1871940670784382}}]}, 
   {Hue[0.5926002068467077], AbsoluteThickness[0.5], 
    LineBox[{{4.041195950510876, 0.1871940670784382}, {
     3.8771971001729177`, -0.03625443962313352}}]}, 
   {Hue[0.4083863868960644], AbsoluteThickness[0.5], 
    LineBox[{{4.756799612100083, 3.4027125196327686`}, {4.716462440233642, 
     3.588049937403011}}]}, 
   {Hue[0.4093024732202209], AbsoluteThickness[0.5], 
    LineBox[{{4.716462440233642, 3.588049937403011}, {4.684496917568904, 
     3.8408297373822142`}}]}, 
   {Hue[0.5528430096561197], AbsoluteThickness[0.5], 
    LineBox[{{3.4278913674215907`, -3.5599590611101397`}, {
     3.3993361102638113`, -3.620112569555268}}]}, 
   {Hue[0.5533187879355127], AbsoluteThickness[0.5], 
    LineBox[{{3.3993361102638113`, -3.620112569555268}, {
     3.2444688680454186`, -3.921878370549686}}]}, 
   {Hue[0.589916294149809], AbsoluteThickness[0.5], 
    LineBox[{{2.6150090051493806`, 2.8567104620536683`}, {2.572358613725891, 
     2.8691112336945124`}}]}, 
   {Hue[0.5905893364373875], AbsoluteThickness[0.5], 
    LineBox[{{2.572358613725891, 2.8691112336945124`}, {2.3020493809113587`, 
     2.967375694836575}}]}, 
   {Hue[0.6268102782938344], AbsoluteThickness[0.5], 
    LineBox[{{3.842320733218131, -3.4282627906929}, {
     3.7774031973001483`, -3.5472321258513486`}}]}, 
   {Hue[0.6276440881415422], AbsoluteThickness[0.5], 
    LineBox[{{3.7774031973001483`, -3.5472321258513486`}, {
     3.651841608084488, -3.830196555364701}}]}, 
   {Hue[0.412036924555356], AbsoluteThickness[0.5], 
    LineBox[{{5.1829528576084085`, -3.41526974910726}, {
     5.254669121272646, -3.6365667442564873`}}]}, 
   {Hue[0.4124669949931789], AbsoluteThickness[0.5], 
    LineBox[{{5.254669121272646, -3.6365667442564873`}, {
     5.3480016421772785`, -3.9337704905598554`}}]}, 
   {Hue[0.6387257120640799], AbsoluteThickness[0.5], 
    LineBox[{{7.079003859623861, -1.456769501463413}, {
     7.220422625561052, -1.4380442414777173`}}]}, 
   {Hue[0.6456680947196918], AbsoluteThickness[0.5], 
    LineBox[{{7.220422625561052, -1.4380442414777173`}, {
     7.394500372696452, -1.3733365778580926`}}]}, 
   {Hue[0.6691889990488813], AbsoluteThickness[0.5], 
    LineBox[{{4.332653229857758, -4.3534032715972595`}, {
     4.348005280937179, -4.395879349855272}}]}, 
   {Hue[0.6697258035164274], AbsoluteThickness[0.5], 
    LineBox[{{4.348005280937179, -4.395879349855272}, {
     4.4791147456258855`, -4.71282681990497}}]}, 
   {Hue[0.613535085580152], AbsoluteThickness[0.5], 
    LineBox[{{7.737901491697695, -1.4046801979414945`}, {
     7.856073873896268, -1.4912917762209985`}}]}, 
   {Hue[0.6140147782222195], AbsoluteThickness[0.5], 
    LineBox[{{7.856073873896268, -1.4912917762209985`}, {
     8.095943003714337, -1.6555295330148176`}}]}, 
   {Hue[0.39713303177991427`], AbsoluteThickness[0.5], 
    LineBox[{{7.917912238522208, -1.3475306158439462`}, {
     8.110515231541697, -1.2265071376449534`}}]}, 
   {Hue[0.3979009816058088], AbsoluteThickness[0.5], 
    LineBox[{{8.110515231541697, -1.2265071376449534`}, {
     8.341279892169863, -1.1048597669000682`}}]}, 
   {Hue[0.6341153706221266], AbsoluteThickness[0.5], 
    LineBox[{{7.931100993014548, -1.1591267930027302`}, {
     7.922641409989466, -1.113596686398682}}]}, 
   {Hue[0.6396651206139368], AbsoluteThickness[0.5], 
    LineBox[{{7.922641409989466, -1.113596686398682}, {
     7.92708060284666, -0.9324159151240392}}]}, 
   {Hue[0.666857111222497], AbsoluteThickness[0.5], 
    LineBox[{{4.184756378522427, 2.936978088744807}, {3.993901764848671, 
     3.396839890601077}}]}, 
   {Hue[0.6674254157703104], AbsoluteThickness[0.5], 
    LineBox[{{3.993901764848671, 3.396839890601077}, {3.9008531008824088`, 
     3.657948572361989}}]}, 
   {Hue[0.5404821553371969], AbsoluteThickness[0.5], 
    LineBox[{{4.301196942047683, 2.402361191206961}, {4.305249222151655, 
     2.6404125598900925`}}]}, 
   {Hue[0.5409676379452785], AbsoluteThickness[0.5], 
    LineBox[{{4.305249222151655, 2.6404125598900925`}, {4.3211081754517675`, 
     2.9526189882752405`}}]}, 
   {Hue[0.5312877806599509], AbsoluteThickness[0.5], 
    LineBox[{{5.869474534490239, 3.3927611189889895`}, {5.871675589170737, 
     3.397883102939443}}]}, 
   {Hue[0.5321859052230149], AbsoluteThickness[0.5], 
    LineBox[{{5.871675589170737, 3.397883102939443}, {5.938272068142221, 
     3.599698849580576}}]}, 
   {Hue[0.5600259563167134], AbsoluteThickness[0.5], 
    LineBox[{{3.4340157429530946`, -1.0755231686163798`}, {
     3.3285765398825795`, -1.1233636066606576`}}]}, 
   {Hue[0.5605655620183064], AbsoluteThickness[0.5], 
    LineBox[{{3.3285765398825795`, -1.1233636066606576`}, {
     3.047494941223747, -1.266814309040785}}]}, 
   {Hue[0.5736886073386027], AbsoluteThickness[0.5], 
    LineBox[{{4.080487026085644, -1.1521571027353676`}, {
     4.015652149899521, -1.3483992568196361`}}]}, 
   {Hue[0.5741163397138135], AbsoluteThickness[0.5], 
    LineBox[{{4.015652149899521, -1.3483992568196361`}, {
     3.9341411072357984`, -1.6002509270067984`}}]}, 
   {Hue[0.44665341773948863`], AbsoluteThickness[0.5], 
    LineBox[{{6.874396088271538, 0.13875400708377703`}, {6.923271246693641, 
     0.06870064127812858}}]}, 
   {Hue[0.44786634316416], AbsoluteThickness[0.5], 
    LineBox[{{6.923271246693641, 0.06870064127812858}, {
     7.046079077259909, -0.07229074484891419}}]}, 
   {Hue[0.5363034602174267], AbsoluteThickness[0.5], 
    LineBox[{{3.408688002214408, 1.9958950995123375`}, {3.1495573498564475`, 
     2.0275021555342922`}}]}, 
   {Hue[0.5368401081657249], AbsoluteThickness[0.5], 
    LineBox[{{3.1495573498564475`, 2.0275021555342922`}, {2.855226775280789, 
     2.0499127811651507`}}]}, 
   {Hue[0.6483063208267594], AbsoluteThickness[0.5], 
    LineBox[{{4.690358752098864, 2.6272805756918824`}, {4.387840092996258, 
     2.687515443855927}}]}, 
   {Hue[0.6490587366349189], AbsoluteThickness[0.5], 
    LineBox[{{4.387840092996258, 2.687515443855927}, {4.1111099959190245`, 
     2.7643697156273657`}}]}, 
   {Hue[0.5595328509761527], AbsoluteThickness[0.5], 
    LineBox[{{4.594175413266948, 2.7561250850535886`}, {4.566621051080708, 
     2.8430302032309624`}}]}, 
   {Hue[0.5599610158608451], AbsoluteThickness[0.5], 
    LineBox[{{4.566621051080708, 2.8430302032309624`}, {4.47322879120796, 
     3.144633852475876}}]}, 
   {Hue[0.5342588853241566], AbsoluteThickness[0.5], 
    LineBox[{{5.117615039556583, 2.6937964120339943`}, {4.909216542017599, 
     2.780009030139012}}]}, 
   {Hue[0.5348582745278927], AbsoluteThickness[0.5], 
    LineBox[{{4.909216542017599, 2.780009030139012}, {4.6321015179910034`, 
     2.8768822681350086`}}]}, 
   {Hue[0.4397170993902055], AbsoluteThickness[0.5], 
    LineBox[{{6.432743400291953, 2.8186840716085455`}, {6.486985719368664, 
     2.6799088466027503`}}]}, 
   {Hue[0.4404868732625802], AbsoluteThickness[0.5], 
    LineBox[{{6.486985719368664, 2.6799088466027503`}, {6.609521110165274, 
     2.425372271459734}}]}, 
   {Hue[0.03002924042842321], AbsoluteThickness[0.5], 
    LineBox[{{6.633830151583649, 2.894888176787843}, {6.898432682666804, 
     2.9572840842236214`}}]}, 
   {Hue[0.03047938661243996], AbsoluteThickness[0.5], 
    LineBox[{{6.898432682666804, 2.9572840842236214`}, {7.1599998255150314`, 
     3.0249987506464455`}}]}, 
   {Hue[0.5797976325696879], AbsoluteThickness[0.5], 
    LineBox[{{7.1599998255150314`, 3.0249987506464455`}, {6.93818844042659, 
     2.870718629724511}}]}, 
   {Hue[0.44318841064434306`], AbsoluteThickness[0.5], 
    LineBox[{{6.586647321954805, 3.1046898159126157`}, {6.560272425915774, 
     3.3951597397920303`}}]}, 
   {Hue[0.4440619404706798], AbsoluteThickness[0.5], 
    LineBox[{{6.560272425915774, 3.3951597397920303`}, {6.558954293880868, 
     3.6406805323054274`}}]}, 
   {Hue[0.5388887586916455], AbsoluteThickness[0.5], 
    LineBox[{{5.821380755156411, 3.0488953396630754`}, {5.339951891029596, 
     3.2458795924112507`}}]}, 
   {Hue[0.5394458804087352], AbsoluteThickness[0.5], 
    LineBox[{{5.339951891029596, 3.2458795924112507`}, {5.113178426862221, 
     3.3519570902175926`}}]}, 
   {Hue[0.53457006637833], AbsoluteThickness[0.5], 
    LineBox[{{5.959770288121485, 1.3768438189285859`}, {5.920144567215162, 
     1.072102903555994}}]}, 
   {Hue[0.537101831537456], AbsoluteThickness[0.5], 
    LineBox[{{5.920144567215162, 1.072102903555994}, {5.926167261299292, 
     0.8386769757087384}}]}, 
   {Hue[0.6522161993438585], AbsoluteThickness[0.5], 
    LineBox[{{6.152280563703263, 1.6141019226942375`}, {6.455565390980103, 
     1.2012899393197825`}}]}, 
   {Hue[0.6529897705043272], AbsoluteThickness[0.5], 
    LineBox[{{6.455565390980103, 1.2012899393197825`}, {6.615251264306741, 
     0.9449976108986228}}]}, 
   {Hue[0.671012399303887], AbsoluteThickness[0.5], 
    LineBox[{{6.301205715342333, 1.5673547568775967`}, {6.355795988156994, 
     1.5720719508363705`}}]}, 
   {Hue[0.671714026634995], AbsoluteThickness[0.5], 
    LineBox[{{6.355795988156994, 1.5720719508363705`}, {6.642059694726332, 
     1.5769917915728056`}}]}, 
   {Hue[0.5943854569447247], AbsoluteThickness[0.5], 
    LineBox[{{6.137072660338236, 1.1310572121574078`}, {6.13601157442402, 
     1.097566483844061}}]}, 
   {Hue[0.5951366853333724], AbsoluteThickness[0.5], 
    LineBox[{{6.13601157442402, 1.097566483844061}, {6.104691567615338, 
     0.8029470965160467}}]}, 
   {Hue[0.6787840292249286], AbsoluteThickness[0.5], 
    LineBox[{{5.59440241290321, 1.1700237445038633`}, {5.54274620382369, 
     1.148057485387422}}]}, 
   {Hue[0.6814609513697287], AbsoluteThickness[0.5], 
    LineBox[{{5.54274620382369, 1.148057485387422}, {5.347094476103539, 
     1.0251699140352626`}}]}, 
   {Hue[0.6634285813578555], AbsoluteThickness[0.5], 
    LineBox[{{5.822022768727359, 0.6294336225975885}, {5.737022245000927, 
     0.33164872136422835`}}]}, 
   {Hue[0.6638554339172122], AbsoluteThickness[0.5], 
    LineBox[{{5.737022245000927, 0.33164872136422835`}, {5.671416649564645, 
     0.10561550987405684`}}]}, 
   {Hue[0.6368385468025414], AbsoluteThickness[0.5], 
    LineBox[{{6.3292846119777035`, 0.6015429566875906}, {6.358889151952296, 
     0.6001619492660363}}]}, 
   {Hue[0.6375393295733228], AbsoluteThickness[0.5], 
    LineBox[{{6.358889151952296, 0.6001619492660363}, {6.595468318726314, 
     0.5727070445538006}}]}, 
   {Hue[0.4518361899695339], AbsoluteThickness[0.5], 
    LineBox[{{2.8896365999503066`, 3.0746226664742258`}, {2.875180264846636, 
     3.083345013264773}}]}, 
   {Hue[0.4523246456771022], AbsoluteThickness[0.5], 
    LineBox[{{2.875180264846636, 3.083345013264773}, {2.6146782042776437`, 
     3.253058795594541}}]}, 
   {Hue[0.5855745681767672], AbsoluteThickness[0.5], 
    LineBox[{{2.5976146879161774`, 0.6825412425653781}, {2.5667976711092013`, 
     0.6697613614926294}}]}, 
   {Hue[0.586403178402205], AbsoluteThickness[0.5], 
    LineBox[{{2.5667976711092013`, 0.6697613614926294}, {2.31839713512876, 
     0.5421590529651334}}]}, 
   {Hue[0.5293982413177323], AbsoluteThickness[0.5], 
    LineBox[{{6.1258387511766115`, -3.123753256907864}, {
     6.159282745281812, -3.136532666726578}}]}, 
   {Hue[0.5301089893318316], AbsoluteThickness[0.5], 
    LineBox[{{6.159282745281812, -3.136532666726578}, {
     6.407618281581385, -3.2519335022571187`}}]}, 
   {Hue[0.6501002434234537], AbsoluteThickness[0.5], 
    LineBox[{{5.419701386209029, -3.225102878942382}, {
     5.550942704198445, -3.266969544032278}}]}, 
   {Hue[0.6505863748471323], AbsoluteThickness[0.5], 
    LineBox[{{5.550942704198445, -3.266969544032278}, {
     5.850313825183448, -3.351401617036807}}]}, 
   {Hue[0.5066593657986269], AbsoluteThickness[0.5], 
    LineBox[{{5.62033761361892, -4.120985004134547}, {
     5.540315338945764, -4.3136850882103674`}}]}, 
   {Hue[0.5070965446230115], AbsoluteThickness[0.5], 
    LineBox[{{5.540315338945764, -4.3136850882103674`}, {
     5.412007363072621, -4.636142539784959}}]}, 
   {Hue[0.5899513546538169], AbsoluteThickness[0.5], 
    LineBox[{{4.927924298756059, -3.2508706963395118`}, {
     4.9407869971078195`, -3.3415620761116}}]}, 
   {Hue[0.5904267128416029], AbsoluteThickness[0.5], 
    LineBox[{{4.9407869971078195`, -3.3415620761116}, {
     4.995273828679291, -3.65575921504511}}]}, 
   {Hue[0.5834374661718994], AbsoluteThickness[0.5], 
    LineBox[{{3.0543692916866285`, -0.7871154269790568}, {
     2.981954770727219, -0.8495741169481779}}]}, 
   {Hue[0.5848065673902209], AbsoluteThickness[0.5], 
    LineBox[{{2.981954770727219, -0.8495741169481779}, {
     2.8282756185062667`, -1.0166156968726434`}}]}, 
   {Hue[0.6611031927706222], AbsoluteThickness[0.5], 
    LineBox[{{7.071378568365358, 0.31059879151226477`}, {7.039527784207696, 
     0.16030554527639895`}}]}, 
   {Hue[0.6615564273902742], AbsoluteThickness[0.5], 
    LineBox[{{7.039527784207696, 0.16030554527639895`}, {
     6.997078773669759, -0.06555787562316041}}]}, 
   {Hue[0.4954931164673139], AbsoluteThickness[0.5], 
    LineBox[{{7.641683393485013, 0.42132033875814756`}, {7.715109076652004, 
     0.3769845663652072}}]}, 
   {Hue[0.49697403642291976`], AbsoluteThickness[0.5], 
    LineBox[{{7.715109076652004, 0.37698456636520716`}, {7.9217632247763605`, 
     0.21539190540840342`}}]}, 
   {Hue[0.6955202935796898], AbsoluteThickness[0.5], 
    LineBox[{{8.074689512295892, 1.2022706671763876`}, {8.127781524112356, 
     1.2223638529612555`}}]}, 
   {Hue[0.6959466688624437], AbsoluteThickness[0.5], 
    LineBox[{{8.127781524112356, 1.2223638529612555`}, {8.46024334030817, 
     1.3469700440551973`}}]}, 
   {Hue[0.6962242905816883], AbsoluteThickness[0.5], 
    LineBox[{{4.494228650609289, 2.306347385714413}, {4.397365210871644, 
     2.2020323365442005`}}]}, 
   {Hue[0.5568304531284504], AbsoluteThickness[0.5], 
    LineBox[{{3.65082766030624, 2.7487523936756824`}, {3.4534366854816128`, 
     2.7546657700224806`}}]}, 
   {Hue[0.5572569190344397], AbsoluteThickness[0.5], 
    LineBox[{{3.4534366854816128`, 2.7546657700224806`}, {3.1370210043598545`,
      2.765245133260674}}]}, 
   {Hue[0.5792469316566459], AbsoluteThickness[0.5], 
    LineBox[{{6.230600065070971, 2.067423848193402}, {6.192193104315867, 
     1.8633359757182042`}}]}, 
   {Hue[0.5802633283214621], AbsoluteThickness[0.5], 
    LineBox[{{6.192193104315867, 1.8633359757182042`}, {6.168262864429902, 
     1.5992893779000643`}}]}, 
   {Hue[0.48648750282301545`], AbsoluteThickness[0.5], 
    LineBox[{{7.247655659047368, 2.6325659946933193`}, {7.287042203466497, 
     2.5149479996901167`}}]}, 
   {Hue[0.49180668240794095`], AbsoluteThickness[0.5], 
    LineBox[{{7.287042203466497, 2.5149479996901167`}, {7.3916057879028205`, 
     2.335807728372676}}]}, 
   {Hue[0.598275007633471], AbsoluteThickness[0.5], 
    LineBox[{{6.922415044469377, 3.351165708620553}, {6.888662031959078, 
     3.3284537824309592`}}]}, 
   {Hue[0.5987938816542602], AbsoluteThickness[0.5], 
    LineBox[{{6.888662031959078, 3.3284537824309592`}, {6.667931909106055, 
     3.192962063917454}}]}, 
   {Hue[0.5990560950415623], AbsoluteThickness[0.5], 
    LineBox[{{6.92141241281815, 3.351384939936086}, {6.888474563677563, 
     3.329152715312067}}]}, 
   {Hue[0.5995725478305132], AbsoluteThickness[0.5], 
    LineBox[{{6.888474563677563, 3.329152715312067}, {6.667787220680128, 
     3.193091504153586}}]}, 
   {Hue[0.5782812033840475], AbsoluteThickness[0.5], 
    LineBox[{{5.092824504435442, 3.1770821719074314`}, {4.93218358027338, 
     3.1878387397856396`}}]}, 
   {Hue[0.5787653770747279], AbsoluteThickness[0.5], 
    LineBox[{{4.93218358027338, 3.1878387397856396`}, {4.617322384440408, 
     3.2195038869246626`}}]}, 
   {Hue[0.5081359270645357], AbsoluteThickness[0.5], 
    LineBox[{{7.13603491295625, 1.118172794723853}, {7.230077860766891, 
     0.950742578527233}}]}, 
   {Hue[0.5086556731475439], AbsoluteThickness[0.5], 
    LineBox[{{7.230077860766891, 0.950742578527233}, {7.365413251419635, 
     0.6841959912807087}}]}, 
   {Hue[0.5571707470227396], AbsoluteThickness[0.5], 
    LineBox[{{6.275686069130053, 0.13458730455650636`}, {
     6.287066928673188, -0.12833515149836464`}}]}, 
   {Hue[0.5578209199490534], AbsoluteThickness[0.5], 
    LineBox[{{6.287066928673188, -0.12833515149836464`}, {
     6.281101302504902, -0.4318847979400394}}]}, 
   {Hue[0.6822396610491032], AbsoluteThickness[0.5], 
    LineBox[{{6.105245188704591, 0.8031678899006431}, {6.08008578255235, 
     0.6204355580142669}}]}, 
   {Hue[0.6838037592970924], AbsoluteThickness[0.5], 
    LineBox[{{6.08008578255235, 0.6204355580142669}, {6.020465011260368, 
     0.3970081757770556}}]}, 
   {Hue[0.4626427267631783], AbsoluteThickness[0.5], 
    LineBox[{{2.112757166851967, 2.3058394773120328`}, {2.03429347850575, 
     2.305320322626094}}]}, 
   {Hue[0.47082062662348306`], AbsoluteThickness[0.5], 
    LineBox[{{2.03429347850575, 2.305320322626094}, {1.831044157957408, 
     2.3528372243762026`}}]}, 
   {Hue[0.6489961592367153], AbsoluteThickness[0.5], 
    LineBox[{{6.05552751728086, -1.6087165333660023`}, {
     6.166085395265262, -1.6817785846525553`}}]}, 
   {Hue[0.6499062394637928], AbsoluteThickness[0.5], 
    LineBox[{{6.166085395265262, -1.6817785846525553`}, {
     6.326614213397263, -1.8094864221156384`}}]}, 
   {Hue[0.6515607441508549], AbsoluteThickness[0.5], 
    LineBox[{{7.9424463737825235`, -1.7888201348337402`}, {
     8.12190314797101, -1.8677721414578583`}}]}, 
   {Hue[0.671910851174794], AbsoluteThickness[0.5], 
    LineBox[{{8.12190314797101, -1.8677721414578583`}, {
     8.276768586390968, -1.8843314290778375`}}]}, 
   {Hue[0.48690902641809375`], AbsoluteThickness[0.5], 
    LineBox[{{7.61985987874316, 2.519564290810599}, {8.065838772053745, 
     2.6910970532822343`}}]}, 
   {Hue[0.4873364847818269], AbsoluteThickness[0.5], 
    LineBox[{{8.065838772053745, 2.6910970532822343`}, {8.40552823451734, 
     2.8195605696367014`}}]}, 
   {Hue[0.5189294183927703], AbsoluteThickness[0.5], 
    LineBox[{{4.085304837150187, 2.1888510178329126`}, {3.82225239586998, 
     2.1646068536875105`}}]}, 
   {Hue[0.5196021615795702], AbsoluteThickness[0.5], 
    LineBox[{{3.82225239586998, 2.1646068536875105`}, {3.5835079010038977`, 
     2.1583455438748014`}}]}, 
   {Hue[0.6195646757336516], AbsoluteThickness[0.5], 
    LineBox[{{3.465190071487695, -4.179340878098618}, {
     3.5588701108869314`, -4.408427970841941}}]}, 
   {Hue[0.6231806158171818], AbsoluteThickness[0.5], 
    LineBox[{{3.5588701108869314`, -4.408427970841941}, {
     3.605695872945691, -4.628678587593793}}]}, 
   {Hue[0.6089584207488921], AbsoluteThickness[0.5], 
    LineBox[{{7.699047522042055, -0.9574292814846297}, {
     7.898136445323434, -0.9904819813580956}}]}, 
   {Hue[0.6093887381401645], AbsoluteThickness[0.5], 
    LineBox[{{7.898136445323434, -0.9904819813580956}, {
     8.189024607964996, -1.041580941979841}}]}, 
   {Hue[0.6173453311074849], AbsoluteThickness[0.5], 
    LineBox[{{4.648458270266406, -1.597359610086278}, {
     4.612199466364905, -1.7548148686868592`}}]}, 
   {Hue[0.5979509988251681], AbsoluteThickness[0.5], 
    LineBox[{{2.5859190739538196`, -1.6062134069907046`}, {
     2.5809771434659354`, -1.6404602895596736`}}]}, 
   {Hue[0.6035140920423075], AbsoluteThickness[0.5], 
    LineBox[{{2.5809771434659354`, -1.6404602895596736`}, {
     2.5941998381883153`, -1.843413467771807}}]}, 
   {Hue[0.542504153036174], AbsoluteThickness[0.5], 
    LineBox[{{4.657509732164344, 1.4129386468563787`}, {4.66981551460014, 
     1.4022008325524653`}}]}, 
   {Hue[0.5430199289722318], AbsoluteThickness[0.5], 
    LineBox[{{4.66981551460014, 1.4022008325524653`}, {4.853245755986811, 
     1.228362590144612}}]}, 
   {Hue[0.6233072807805947], AbsoluteThickness[0.5], 
    LineBox[{{3.39257354235322, -0.37339001916191417`}, {
     3.326114496991309, -0.6712185560885473}}]}, 
   {Hue[0.6240513300048169], AbsoluteThickness[0.5], 
    LineBox[{{3.326114496991309, -0.6712185560885473}, {
     3.2440938727381115`, -0.943034104802493}}]}, 
   {Hue[0.5996374541320849], AbsoluteThickness[0.5], 
    LineBox[{{3.262436722702359, -1.3995195642428773`}, {
     3.2730272465497943`, -1.5701130907982561`}}]}, 
   {Hue[0.6000915868482818], AbsoluteThickness[0.5], 
    LineBox[{{3.2730272465497943`, -1.5701130907982561`}, {
     3.2853832813839796`, -1.8902978357150382`}}]}, 
   {Hue[0.6931017411890452], AbsoluteThickness[0.5], 
    LineBox[{{4.616209255770585, -4.406150595429859}, {
     4.626435305086794, -4.452353873180521}}]}, 
   {Hue[0.5544113910255114], AbsoluteThickness[0.5], 
    LineBox[{{6.368486949501586, -3.7682712387193535`}, {
     6.436669784467318, -3.8565842422270067`}}]}, 
   {Hue[0.5549044810958959], AbsoluteThickness[0.5], 
    LineBox[{{6.436669784467318, -3.8565842422270067`}, {
     6.623160239879996, -4.11685898111007}}]}, 
   {Hue[0.5644485519884255], AbsoluteThickness[0.5], 
    LineBox[{{6.841882527430227, 2.8431398365597307`}, {6.927646356146619, 
     2.882566913806387}}]}, 
   {Hue[0.5649195243500782], AbsoluteThickness[0.5], 
    LineBox[{{6.927646356146619, 2.882566913806387}, {7.168209300253958, 
     3.0018620179182847`}}]}, 
   {Hue[0.5130458579825022], AbsoluteThickness[0.5], 
    LineBox[{{6.896738922740622, -3.292247395390472}, {
     6.948950929558283, -3.3726410996534493`}}]}, 
   {Hue[0.5134753446482343], AbsoluteThickness[0.5], 
    LineBox[{{6.948950929558283, -3.3726410996534493`}, {
     7.122594726748541, -3.645025531959841}}]}, 
   {Hue[0.6254295476657479], AbsoluteThickness[0.5], 
    LineBox[{{6.610176993702046, -3.1335876994741643`}, {
     6.402447329626029, -3.29549235304369}}]}, 
   {Hue[0.6276752848174035], AbsoluteThickness[0.5], 
    LineBox[{{6.402447329626029, -3.29549235304369}, {
     6.212681772302014, -3.402826411605234}}]}, 
   {Hue[0.4502736709511401], AbsoluteThickness[0.5], 
    LineBox[{{6.60151692415968, -3.3113512365335254`}, {
     6.620385576799296, -3.391286972946736}}]}, 
   {Hue[0.47287661923813346`], AbsoluteThickness[0.5], 
    LineBox[{{6.620385576799296, -3.391286972946736}, {
     6.606984461148083, -3.54884573825549}}]}, 
   {Hue[0.6360844676553628], AbsoluteThickness[0.5], 
    LineBox[{{6.606984461148083, -3.54884573825549}, {
     6.461263316345204, -3.6102436403666744`}}]}, 
   {Hue[0.654458656840588], AbsoluteThickness[0.5], 
    LineBox[{{6.759467349062372, -3.393366693524221}, {
     6.895350726410851, -3.42069160228426}}]}, 
   {Hue[0.655040715235445], AbsoluteThickness[0.5], 
    LineBox[{{6.895350726410851, -3.42069160228426}, {
     7.1882538136537715`, -3.4960261746754795`}}]}, 
   {Hue[0.5674897378030991], AbsoluteThickness[0.5], 
    LineBox[{{6.102093022519754, -3.2627510398409374`}, {
     5.865441652651371, -3.3145174180862846`}}]}, 
   {Hue[0.5681351900728012], AbsoluteThickness[0.5], 
    LineBox[{{5.865441652651371, -3.3145174180862846`}, {
     5.57619006002271, -3.3591352369491663`}}]}, 
   {Hue[0.5203321782811791], AbsoluteThickness[0.5], 
    LineBox[{{5.687592682646478, -3.9054368108495336`}, {
     5.676021498664552, -4.098276520467236}}]}, 
   {Hue[0.5210523472572585], AbsoluteThickness[0.5], 
    LineBox[{{5.676021498664552, -4.098276520467236}, {
     5.679412893097671, -4.403820925012704}}]}, 
   {Hue[0.6586145913018725], AbsoluteThickness[0.5], 
    LineBox[{{3.5563293545715076`, -3.610162980692292}, {
     3.429170691841342, -3.93803763826356}}]}, 
   {Hue[0.6685741595074212], AbsoluteThickness[0.5], 
    LineBox[{{3.429170691841342, -3.93803763826356}, {
     3.407749641880839, -4.117400187872137}}]}, 
   {Hue[0.470465970095292], AbsoluteThickness[0.5], 
    LineBox[{{7.382016008118116, 3.2376458166909385`}, {7.60258243125024, 
     3.176253960693313}}]}, 
   {Hue[0.4721132942894612], AbsoluteThickness[0.5], 
    LineBox[{{7.60258243125024, 3.176253960693313}, {7.832978007201858, 
     3.142804697606758}}]}, 
   {Hue[0.670524034199171], AbsoluteThickness[0.5], 
    LineBox[{{6.555222817980784, 3.712942174031116}, {6.36681551020418, 
     3.7767191166784055`}}]}, 
   {Hue[0.6720555943577446], AbsoluteThickness[0.5], 
    LineBox[{{6.36681551020418, 3.7767191166784055`}, {6.139585176930218, 
     3.8236831509040035`}}]}, 
   {Hue[0.6047759068727872], AbsoluteThickness[0.5], 
    LineBox[{{4.824543219372039, 1.1907794533236074`}, {4.9020251918910205`, 
     1.1320447904787805`}}]}, 
   {Hue[0.6052555373268462], AbsoluteThickness[0.5], 
    LineBox[{{4.9020251918910205`, 1.1320447904787805`}, {5.153802559318333, 
     0.9281451875374592}}]}, 
   {Hue[0.5219671916604102], AbsoluteThickness[0.5], 
    LineBox[{{5.2939762893011935`, 3.1509313385206026`}, {5.408220479212908, 
     3.14218193895542}}]}, 
   {Hue[0.5313223176898039], AbsoluteThickness[0.5], 
    LineBox[{{5.408220479212908, 3.14218193895542}, {5.579179784471038, 
     3.084998329048042}}]}, 
   {Hue[0.5965715559377207], AbsoluteThickness[0.5], 
    LineBox[{{4.858981809466942, 1.644533716837456}, {4.885228607591649, 
     1.6191530538762855`}}]}, 
   {Hue[0.596998705601011], AbsoluteThickness[0.5], 
    LineBox[{{4.885228607591649, 1.6191530538762855`}, {5.126741043285065, 
     1.3832368302410234`}}]}, 
   {Hue[0.6301667478242696], AbsoluteThickness[0.5], 
    LineBox[{{5.405810919239806, -0.3281606663910662}, {
     5.458248353302605, -0.38223890834304514`}}]}, 
   {Hue[0.6308747049797668], AbsoluteThickness[0.5], 
    LineBox[{{5.458248353302605, -0.38223890834304514`}, {
     5.645495370537435, -0.6044183073765027}}]}, 
   {Hue[0.4009093655181514], AbsoluteThickness[0.5], 
    LineBox[{{4.843559146862032, -0.3422331175263996}, {
     4.883798730881684, -0.42277615551994646`}}]}, 
   {Hue[0.40152380875919613`], AbsoluteThickness[0.5], 
    LineBox[{{4.883798730881684, -0.42277615551994646`}, {
     5.023835999081673, -0.6665280528057512}}]}, 
   {Hue[0.6900706653913256], AbsoluteThickness[0.5], 
    LineBox[{{6.242904913959022, 3.3917007551980287`}, {6.319760213708643, 
     3.5192130544224196`}}]}, 
   {Hue[0.6937856778022432], AbsoluteThickness[0.5], 
    LineBox[{{6.319760213708643, 3.5192130544224196`}, {6.450487183915666, 
     3.6673821343144635`}}]}, 
   {Hue[0.48569535285018206`], AbsoluteThickness[0.5], 
    LineBox[{{5.900968478509016, 0.7010010828736314}, {5.914380098655782, 
     0.6796261924672506}}]}, 
   {Hue[0.4861865982318102], AbsoluteThickness[0.5], 
    LineBox[{{5.914380098655782, 0.6796261924672506}, {6.061562489712735, 
     0.42557290280680754`}}]}, 
   {Hue[0.6765478338361912], AbsoluteThickness[0.5], 
    LineBox[{{3.8676867473927774`, -0.5981021422521511}, {
     3.868046504327016, -0.6017360664987048}}]}, 
   {Hue[0.6774856729108745], AbsoluteThickness[0.5], 
    LineBox[{{3.868046504327016, -0.6017360664987048}, {
     3.8702547831848895`, -0.8602510474568634}}]}, 
   {Hue[0.5598449359997311], AbsoluteThickness[0.5], 
    LineBox[{{7.126230613235518, 2.4294834043892255`}, {7.29233576715886, 
     2.444708560196507}}]}, 
   {Hue[0.560300289294396], AbsoluteThickness[0.5], 
    LineBox[{{7.29233576715886, 2.444708560196507}, {7.621841849280827, 
     2.4828785986592417`}}]}, 
   {Hue[0.5246257462376116], AbsoluteThickness[0.5], 
    LineBox[{{6.368635478872738, 3.7732276526942092`}, {6.600148633385447, 
     3.8710428329025874`}}]}, 
   {Hue[0.5321966700936173], AbsoluteThickness[0.5], 
    LineBox[{{6.600148633385447, 3.8710428329025874`}, {6.798027937241265, 
     3.904841967448282}}]}, 
   {Hue[0.5061680809476614], AbsoluteThickness[0.5], 
    LineBox[{{5.696981487684972, -1.348888178586828}, {
     5.6783861907012945`, -1.4349105526054597`}}]}, 
   {Hue[0.5100518835817363], AbsoluteThickness[0.5], 
    LineBox[{{5.6783861907012945`, -1.4349105526054597`}, {
     5.6737625552074435`, -1.5922807528453093`}}]}, 
   {Hue[0.6150418850025823], AbsoluteThickness[0.5], 
    LineBox[{{7.858649778899655, -3.3641357320589047`}, {
     7.907509394439188, -3.359863350168401}}]}, 
   {Hue[0.6162874799070968], AbsoluteThickness[0.5], 
    LineBox[{{7.907509394439188, -3.359863350168401}, {
     8.15469176456565, -3.3652854145736475`}}]}, 
   {Hue[0.5805142468740282], AbsoluteThickness[0.5], 
    LineBox[{{6.843682850484345, -3.891511137126358}, {
     6.856200554600797, -3.9322151512667944`}}]}, 
   {Hue[0.5818902647099324], AbsoluteThickness[0.5], 
    LineBox[{{6.856200554600797, -3.9322151512667944`}, {
     6.954315508168411, -4.155510397004101}}]}, 
   {Hue[0.6196420183071984], AbsoluteThickness[0.5], 
    LineBox[{{3.4084463355944523`, 0.35587524451730274`}, {
     3.3851465330668433`, 0.3336474917820216}}]}, 
   {Hue[0.6201547487616587], AbsoluteThickness[0.5], 
    LineBox[{{3.3851465330668433`, 0.3336474917820216}, {3.1482838292612056`, 
     0.12530338494943868`}}]}, 
   {Hue[0.6266830919449293], AbsoluteThickness[0.5], 
    LineBox[{{2.3562469830919617`, 2.485197468968269}, {2.146280373847849, 
     2.477686239771925}}]}, 
   {Hue[0.6271089660354411], AbsoluteThickness[0.5], 
    LineBox[{{2.146280373847849, 2.477686239771925}, {1.786021915223815, 
     2.4650252923779488`}}]}, 
   {Hue[0.6032328539674262], AbsoluteThickness[0.5], 
    LineBox[{{4.842844512824184, 1.4392936771747449`}, {4.800931976989778, 
     1.402799561334059}}]}, 
   {Hue[0.6037549868593344], AbsoluteThickness[0.5], 
    LineBox[{{4.800931976989778, 1.402799561334059}, {4.618038889208468, 
     1.2293657926361408`}}]}, 
   {Hue[0.6349275345479319], AbsoluteThickness[0.5], 
    LineBox[{{6.383085316021455, 1.9046355066773064`}, {6.365537154101552, 
     1.8496687488011507`}}]}, 
   {Hue[0.6354551952354894], AbsoluteThickness[0.5], 
    LineBox[{{6.365537154101552, 1.8496687488011507`}, {6.260458992293717, 
     1.5641309692343006`}}]}, 
   {Hue[0.66173411704889], AbsoluteThickness[0.5], 
    LineBox[{{6.21143363240012, 3.0761220534022833`}, {6.113050094229969, 
     3.026053598561676}}]}, 
   {Hue[0.662506885864607], AbsoluteThickness[0.5], 
    LineBox[{{6.113050094229969, 3.026053598561676}, {5.875277310478567, 
     2.927088613603575}}]}, 
   {Hue[0.6194393466738806], AbsoluteThickness[0.5], 
    LineBox[{{5.723562029721975, 3.1726519464830676`}, {5.322164779573246, 
     3.1853289420837494`}}]}, 
   {Hue[0.6200965060048694], AbsoluteThickness[0.5], 
    LineBox[{{5.322164779573246, 3.1853289420837494`}, {5.077048849492125, 
     3.2087738870667355`}}]}, 
   {Hue[0.6208844552267753], AbsoluteThickness[0.5], 
    LineBox[{{5.641773977924679, 1.1064211514942497`}, {5.629899634597604, 
     1.0999981692030905`}}]}, 
   {Hue[0.6213686004783785], AbsoluteThickness[0.5], 
    LineBox[{{5.629899634597604, 1.0999981692030905`}, {5.34916530037734, 
     0.9358116501049869}}]}, 
   {Hue[0.6061581170796241], AbsoluteThickness[0.5], 
    LineBox[{{3.357926920129768, 2.9418150624706527`}, {3.1577375439378836`, 
     2.9318508791362645`}}]}, 
   {Hue[0.6076607612719883], AbsoluteThickness[0.5], 
    LineBox[{{3.1577375439378836`, 2.9318508791362645`}, {2.9155203122478293`,
      2.949228897842466}}]}, 
   {Hue[0.6209569722827956], AbsoluteThickness[0.5], 
    LineBox[{{4.3353333284748645`, 0.9944352179258321}, {4.265175809775193, 
     0.9099961923737712}}]}, 
   {Hue[0.6219316770258564], AbsoluteThickness[0.5], 
    LineBox[{{4.265175809775193, 0.9099961923737712}, {4.108449097599739, 
     0.6811536759800854}}]}, 
   {Hue[0.6800948006709723], AbsoluteThickness[0.5], 
    LineBox[{{5.2440335586323, -1.8845762587955819`}, {
     5.280047446256343, -2.0761725678208953`}}]}, 
   {Hue[0.6808396842042319], AbsoluteThickness[0.5], 
    LineBox[{{5.280047446256343, -2.0761725678208953`}, {
     5.313761382725557, -2.3753885576840545`}}]}, 
   {Hue[0.6411660096951367], AbsoluteThickness[0.5], 
    LineBox[{{2.8294913838282776`, -1.023295967301037}, {
     2.8049734224789895`, -1.0859763914619105`}}]}, 
   {Hue[0.6416731301003656], AbsoluteThickness[0.5], 
    LineBox[{{2.8049734224789895`, -1.0859763914619105`}, {
     2.711156949285175, -1.3565984331188055`}}]}, 
   {Hue[0.6349641326807939], AbsoluteThickness[0.5], 
    LineBox[{{4.859135948332847, -3.4020404720633985`}, {
     4.854342034952602, -3.4247113452288356`}}]}, 
   {Hue[0.6586900083841964], AbsoluteThickness[0.5], 
    LineBox[{{4.854342034952602, -3.4247113452288356`}, {
     4.87319977211185, -3.5919042339573353`}}]}, 
   {Hue[0.6531879323921038], AbsoluteThickness[0.5], 
    LineBox[{{7.903756265187747, 2.2945246706427374`}, {7.984470178779184, 
     2.31955400505413}}]}, 
   {Hue[0.6591284137792758], AbsoluteThickness[0.5], 
    LineBox[{{7.984470178779184, 2.31955400505413}, {8.144303604482594, 
     2.409741835893898}}]}, 
   {Hue[0.6180252100322695], AbsoluteThickness[0.5], 
    LineBox[{{4.474844057299938, -4.153721484040043}, {
     4.472796135082891, -4.352833183254616}}]}, 
   {Hue[0.618451843578358], AbsoluteThickness[0.5], 
    LineBox[{{4.472796135082891, -4.352833183254616}, {
     4.467674369815455, -4.713351817149001}}]}, 
   {Hue[0.603109995592211], AbsoluteThickness[0.5], 
    LineBox[{{6.847778179036615, -2.3543430890640478`}, {
     6.844373523826172, -2.3850726169371894`}}]}, 
   {Hue[0.612770948841672], AbsoluteThickness[0.5], 
    LineBox[{{6.844373523826172, -2.3850726169371894`}, {
     6.867917801542046, -2.5540481791056706`}}]}, 
   {Hue[0.596757991028438], AbsoluteThickness[0.5], 
    LineBox[{{7.1468844959084254`, 1.0758120627395946`}, {7.211614713197823, 
     1.1044736606095447`}}]}, 
   {Hue[0.6056756651716628], AbsoluteThickness[0.5], 
    LineBox[{{7.211614713197823, 1.1044736606095449`}, {7.364336585397516, 
     1.2228997999409443`}}]}, 
   {Hue[0.6031954760314098], AbsoluteThickness[0.5], 
    LineBox[{{6.657366973317836, -4.609628109623558}, {
     7.069384772918847, -4.141214182360272}}]}, 
   {Hue[0.6134032944425041], AbsoluteThickness[0.5], 
    LineBox[{{7.069384772918847, -4.141214182360272}, {
     7.148521939918161, -3.9848216415948503`}}]}, 
   {Hue[0.5903759769737552], AbsoluteThickness[0.5], 
    LineBox[{{7.397482777677356, 2.187423202025673}, {7.439678146837101, 
     2.324488380856029}}]}, 
   {Hue[0.5908380036195097], AbsoluteThickness[0.5], 
    LineBox[{{7.439678146837101, 2.324488380856029}, {7.528576631554694, 
     2.642972966420536}}]}, 
   {Hue[0.5288861629227967], AbsoluteThickness[0.5], 
    LineBox[{{2.875237313262489, -3.6338522143657372`}, {
     2.8752376061614626`, -3.640660371040141}}]}, 
   {Hue[0.5315946204053968], AbsoluteThickness[0.5], 
    LineBox[{{2.8752376061614626`, -3.640660371040141}, {
     2.8408548025121005`, -3.854433554101237}}]}, 
   {Hue[0.5338868920664903], AbsoluteThickness[0.5], 
    LineBox[{{6.328250223895723, -3.389944059906378}, {
     6.338626966612421, -3.409679885298945}}]}, 
   {Hue[0.5351437131276578], AbsoluteThickness[0.5], 
    LineBox[{{6.338626966612421, -3.409679885298945}, {
     6.47494742669398, -3.6116142461570684`}}]}, 
   {Hue[0.5639090410089503], AbsoluteThickness[0.5], 
    LineBox[{{3.3162643999417827`, 2.528492634657914}, {3.243615231412173, 
     2.614272287166962}}]}, 
   {Hue[0.5675471221410221], AbsoluteThickness[0.5], 
    LineBox[{{3.243615231412173, 2.614272287166962}, {3.139885600420258, 
     2.7939362106969026`}}]}, 
   {Hue[0.6222052901484947], AbsoluteThickness[0.5], 
    LineBox[{{7.933481416148531, -1.1633584400397452`}, {
     8.112140327448067, -1.2056703088452638`}}]}, 
   {Hue[0.6226364775140799], AbsoluteThickness[0.5], 
    LineBox[{{8.112140327448067, -1.2056703088452638`}, {
     8.400087425138171, -1.2707577891163828`}}]}, 
   {Hue[0.5340260263990999], AbsoluteThickness[0.5], 
    LineBox[{{8.189489835027498, -1.0154040558751327`}, {
     8.204764458786885, -1.0896666455639268`}}]}, 
   {Hue[0.5344738683555543], AbsoluteThickness[0.5], 
    LineBox[{{8.204764458786885, -1.0896666455639268`}, {
     8.269671040239817, -1.3751566092853875`}}]}, 
   {Hue[0.6312143040273648], AbsoluteThickness[0.5], 
    LineBox[{{8.127048359594852, -1.1469022233106576`}, {
     7.931520819701299, -1.3273915674027055`}}]}, 
   {Hue[0.6444663821877477], AbsoluteThickness[0.5], 
    LineBox[{{7.931520819701299, -1.3273915674027055`}, {
     7.768301649781222, -1.4107465967438921`}}]}, 
   {Hue[0.664091395833984], AbsoluteThickness[0.5], 
    LineBox[{{7.955694403024574, 0.782738456935068}, {8.058698817095573, 
     0.7538679628063729}}]}, 
   {Hue[0.6646647909981225], AbsoluteThickness[0.5], 
    LineBox[{{8.058698817095573, 0.7538679628063729}, {8.359462754786117, 
     0.68617942945637}}]}, 
   {Hue[0.4619441470491611], AbsoluteThickness[0.5], 
    LineBox[{{7.896605317102891, 1.3541813632763937`}, {7.898001724548881, 
     1.357431397901153}}]}, 
   {Hue[0.4624315592916687], AbsoluteThickness[0.5], 
    LineBox[{{7.898001724548881, 1.357431397901153}, {8.011255643735685, 
     1.5979565114567478`}}]}, 
   {Hue[0.6873584306351342], AbsoluteThickness[0.5], 
    LineBox[{{7.356772733660368, 1.6018628005425573`}, {7.356198889396762, 
     1.6029461807218612`}}]}, 
   {Hue[0.6878662146199087], AbsoluteThickness[0.5], 
    LineBox[{{7.356198889396762, 1.6029461807218612`}, {7.197431200713964, 
     1.8761586910474153`}}]}, 
   {Hue[0.37460320897629734`], AbsoluteThickness[0.5], 
    LineBox[{{8.164008729672853, 0.0033555398468703146`}, {
     8.280552381767672, -0.0655638623289786}}]}, 
   {Hue[0.380058065274563], AbsoluteThickness[0.5], 
    LineBox[{{8.280552381767672, -0.06556386232897862}, {
     8.435457052106512, -0.20729853359247122`}}]}, 
   {Hue[0.6789892031575832], AbsoluteThickness[0.5], 
    LineBox[{{8.435457052106512, -0.20729853359247122`}, {
     8.336253808635119, -0.3923468797501998}}]}, 
   {Hue[0.506341593473476], AbsoluteThickness[0.5], 
    LineBox[{{7.20888768430507, -0.4334086119362308}, {
     7.225655616469309, -0.5761891753457344}}]}, 
   {Hue[0.5067727104792163], AbsoluteThickness[0.5], 
    LineBox[{{7.225655616469309, -0.5761891753457344}, {
     7.272801865781254, -0.9451938823982878}}]}, 
   {Hue[0.6367111499969519], AbsoluteThickness[0.5], 
    LineBox[{{5.913563059055855, -0.11376840001306049`}, {
     5.775361541347448, -0.15459478727944334`}}]}, 
   {Hue[0.6474056705121813], AbsoluteThickness[0.5], 
    LineBox[{{5.775361541347448, -0.15459478727944334`}, {
     5.645820473983794, -0.2329151577727986}}]}, 
   {Hue[0.6694842658526816], AbsoluteThickness[0.5], 
    LineBox[{{5.075245876106266, 1.7831069164949753`}, {4.677434171161526, 
     1.8931981619757388`}}]}, 
   {Hue[0.6699597956647131], AbsoluteThickness[0.5], 
    LineBox[{{4.677434171161526, 1.8931981619757388`}, {4.376267523511717, 
     1.9866423881345274`}}]}, 
   {Hue[0.3359251699855454], AbsoluteThickness[0.5], 
    LineBox[{{5.927645572126009, 3.1815019861593914`}, {5.919799137943257, 
     3.225333198110428}}]}, 
   {Hue[0.3385525353995442], AbsoluteThickness[0.5], 
    LineBox[{{5.919799137943257, 3.225333198110428}, {5.85965356045574, 
     3.398293420346523}}]}, 
   {Hue[0.6838068323021241], AbsoluteThickness[0.5], 
    LineBox[{{7.576460371272108, 2.194527155146336}, {7.611537608916849, 
     2.193163053332392}}]}, 
   {Hue[0.6847133062898281], AbsoluteThickness[0.5], 
    LineBox[{{7.611537608916849, 2.193163053332392}, {7.884238761714839, 
     2.2065111999676392`}}]}, 
   {Hue[0.5840603451141335], AbsoluteThickness[0.5], 
    LineBox[{{4.58256336409172, 2.2070644110135347`}, {4.411073530094515, 
     2.327374771406374}}]}, 
   {Hue[0.6586411766511898], AbsoluteThickness[0.5], 
    LineBox[{{4.411073530094515, 2.327374771406374}, {4.332026196204194, 
     2.458451532325881}}]}, 
   {Hue[0.668780101242844], AbsoluteThickness[0.5], 
    LineBox[{{6.35625304966237, 0.4613150844381875}, {6.3367813769064085`, 
     0.42678630282339536`}}]}, 
   {Hue[0.6692191938748143], AbsoluteThickness[0.5], 
    LineBox[{{6.3367813769064085`, 0.42678630282339536`}, {6.171289075482996, 
     0.14405856747697232`}}]}, 
   {Hue[0.5522888740434115], AbsoluteThickness[0.5], 
    LineBox[{{7.3313718199692195`, 0.6595266115944417}, {7.335807973202994, 
     0.5925517186265716}}]}, 
   {Hue[0.5533861219672402], AbsoluteThickness[0.5], 
    LineBox[{{7.335807973202994, 0.5925517186265716}, {7.385463149865783, 
     0.29782541036290366`}}]}, 
   {Hue[0.5274353498219387], AbsoluteThickness[0.5], 
    LineBox[{{7.858953238404366, 2.5088130487343236`}, {7.774071020878523, 
     2.6508380355748704`}}]}, 
   {Hue[0.5279185286366214], AbsoluteThickness[0.5], 
    LineBox[{{7.774071020878523, 2.6508380355748704`}, {7.639214815761387, 
     2.894437862224022}}]}, 
   {Hue[0.5969810579341913], AbsoluteThickness[0.5], 
    LineBox[{{6.667580882181964, 2.2220822606053163`}, {6.608147697987499, 
     2.4231843471407615`}}]}, 
   {Hue[0.5980879249974219], AbsoluteThickness[0.5], 
    LineBox[{{6.608147697987499, 2.4231843471407615`}, {6.504240233721568, 
     2.6768960329973375`}}]}, 
   {Hue[0.5980182099488816], AbsoluteThickness[0.5], 
    LineBox[{{5.854047822456555, 1.9425440800647433`}, {5.657287291314636, 
     2.01625832951255}}]}, 
   {Hue[0.5984691721410474], AbsoluteThickness[0.5], 
    LineBox[{{5.657287291314636, 2.01625832951255}, {5.437130501128906, 
     2.0932348131319585`}}]}, 
   {Hue[0.6176711723643714], AbsoluteThickness[0.5], 
    LineBox[{{6.574169473921102, -0.33075794754658466`}, {
     6.572484761332511, -0.37644725243388044`}}]}, 
   {Hue[0.618106432841687], AbsoluteThickness[0.5], 
    LineBox[{{6.572484761332511, -0.37644725243388044`}, {
     6.555636347097228, -0.7101769206441444}}]}, 
   {Hue[0.6431376899954375], AbsoluteThickness[0.5], 
    LineBox[{{8.158205626616963, -0.060589423184742586`}, {
     8.19824146059104, -0.07938934368218678}}]}, 
   {Hue[0.6442561977112836], AbsoluteThickness[0.5], 
    LineBox[{{8.19824146059104, -0.07938934368218678}, {
     8.437398262155398, -0.2230933330235878}}]}, 
   {Hue[0.5087167218413572], AbsoluteThickness[0.5], 
    LineBox[{{8.180737920192712, 1.111690354039852}, {8.2158034728587, 
     1.1221138681655263`}}]}, 
   {Hue[0.5102317678498557], AbsoluteThickness[0.5], 
    LineBox[{{8.2158034728587, 1.1221138681655263`}, {8.465913272022314, 
     1.2310651969474307`}}]}, 
   {Hue[0.6874819411440631], AbsoluteThickness[0.5], 
    LineBox[{{7.387360143015135, 2.180282114376349}, {7.455385823285109, 
     2.323902464874797}}]}, 
   {Hue[0.6880970478345719], AbsoluteThickness[0.5], 
    LineBox[{{7.455385823285109, 2.323902464874797}, {7.571882148877435, 
     2.612119747805933}}]}, 
   {Hue[0.6024506783560212], AbsoluteThickness[0.5], 
    LineBox[{{6.928646105208941, -0.6142804425623265}, {
     6.879518942444783, -0.7081909466536707}}]}, 
   {Hue[0.6030365630775884], AbsoluteThickness[0.5], 
    LineBox[{{6.879518942444783, -0.7081909466536707}, {
     6.7408206958356605`, -0.9417525328365888}}]}, 
   {Hue[0.6974137483805103], AbsoluteThickness[0.5], 
    LineBox[{{7.320278928417021, -0.597260717572432}, {
     7.391211354321168, -0.6050358945602891}}]}, 
   {Hue[0.46034234401823754`], AbsoluteThickness[0.5], 
    LineBox[{{7.418706028138566, -0.7880472302313272}, {
     7.436767009655542, -0.8630789738638475}}]}, 
   {Hue[0.46101378751954375`], AbsoluteThickness[0.5], 
    LineBox[{{7.436767009655542, -0.8630789738638475}, {
     7.521778551184318, -1.1362070560766158`}}]}, 
   {Hue[0.6370595798766062], AbsoluteThickness[0.5], 
    LineBox[{{7.583248365483674, -0.3706463557624019}, {
     7.677730466289875, -0.3654234758440501}}]}, 
   {Hue[0.6409895229502197], AbsoluteThickness[0.5], 
    LineBox[{{7.677730466289875, -0.3654234758440501}, {
     7.860910609681471, -0.32068477923304844`}}]}, 
   {Hue[0.5442068864169463], AbsoluteThickness[0.5], 
    LineBox[{{4.344821048486562, -0.5685940836680768}, {
     3.9385381065942284`, -0.7554693517995876}}]}, 
   {Hue[0.5450077105629575], AbsoluteThickness[0.5], 
    LineBox[{{3.9385381065942284`, -0.7554693517995876}, {
     3.687819082841866, -0.8475995104306607}}]}, 
   {Hue[0.6725041039815677], AbsoluteThickness[0.5], 
    LineBox[{{5.070465296677498, 1.2103076159297081`}, {4.864587743744715, 
     1.260058533851504}}]}, 
   {Hue[0.6729303075056844], AbsoluteThickness[0.5], 
    LineBox[{{4.864587743744715, 1.260058533851504}, {4.608363908700315, 
     1.3212642126444838`}}]}, 
   {Hue[0.6195957115786369], AbsoluteThickness[0.5], 
    LineBox[{{5.351801058307338, -0.6117034079138762}, {
     5.298755662838219, -0.6438110610571225}}]}, 
   {Hue[0.6201489031083898], AbsoluteThickness[0.5], 
    LineBox[{{5.298755662838219, -0.6438110610571225}, {
     5.066478706165485, -0.800260473329759}}]}, 
   {Hue[0.3275509141100646], AbsoluteThickness[0.5], 
    LineBox[{{4.393713261763169, 3.080622086119426}, {4.325387096563474, 
     3.1173210348387763`}}]}, 
   {Hue[0.32853896637159846`], AbsoluteThickness[0.5], 
    LineBox[{{4.325387096563474, 3.1173210348387763`}, {4.070555544280658, 
     3.28669553708706}}]}, 
   {Hue[0.5934922728706513], AbsoluteThickness[0.5], 
    LineBox[{{3.8771971001729177`, -0.036254439623133516`}, {
     3.826936708882109, -0.1188811375909068}}]}, 
   {Hue[0.5939550454685412], AbsoluteThickness[0.5], 
    LineBox[{{3.826936708882109, -0.11888113759090681`}, {
     3.6452464622785774`, -0.4003603473890379}}]}, 
   {Hue[0.5537945662149056], AbsoluteThickness[0.5], 
    LineBox[{{3.2444688680454186`, -3.921878370549686}, {
     3.008411702972068, -4.34878860240163}}]}, 
   {Hue[0.5543966050656481], AbsoluteThickness[0.5], 
    LineBox[{{3.008411702972068, -4.34878860240163}, {
     2.873452224089641, -4.629067101688141}}]}, 
   {Hue[0.5912623787249665], AbsoluteThickness[0.5], 
    LineBox[{{2.3020493809113587`, 2.967375694836575}, {2.142017116268618, 
     3.0377684164683942`}}]}, 
   {Hue[0.5934837737686435], AbsoluteThickness[0.5], 
    LineBox[{{2.142017116268618, 3.0377684164683942`}, {1.962371930559912, 
     3.087061317093}}]}, 
   {Hue[0.6284778979892499], AbsoluteThickness[0.5], 
    LineBox[{{3.651841608084488, -3.830196555364701}, {
     3.6264553913256945`, -3.9029429244285017`}}]}, 
   {Hue[0.628924604017934], AbsoluteThickness[0.5], 
    LineBox[{{3.6264553913256945`, -3.9029429244285017`}, {
     3.5160672400291246`, -4.199885695478522}}]}, 
   {Hue[0.41289706543100163`], AbsoluteThickness[0.5], 
    LineBox[{{5.3480016421772785`, -3.9337704905598554`}, {
     5.363234313248962, -3.983868773180004}}]}, 
   {Hue[0.4195275775199866], AbsoluteThickness[0.5], 
    LineBox[{{5.363234313248962, -3.983868773180004}, {
     5.455098671638979, -4.14577889402922}}]}, 
   {Hue[0.699256465793728], AbsoluteThickness[0.5], 
    LineBox[{{5.455098671638979, -4.14577889402922}, {
     5.636642891119751, -4.1046006965342565`}}]}, 
   {Hue[0.6526104773753038], AbsoluteThickness[0.5], 
    LineBox[{{7.394500372696452, -1.3733365778580926`}, {
     7.618686824866546, -1.2264135958136297`}}]}, 
   {Hue[0.6536226620583444], AbsoluteThickness[0.5], 
    LineBox[{{7.618686824866546, -1.2264135958136297`}, {
     7.866209861046067, -1.096041321916395}}]}, 
   {Hue[0.614494470864287], AbsoluteThickness[0.5], 
    LineBox[{{8.095943003714337, -1.6555295330148176`}, {
     8.096657951598072, -1.6559860588439455`}}]}, 
   {Hue[0.6149294219027795], AbsoluteThickness[0.5], 
    LineBox[{{8.096657951598072, -1.6559860588439455`}, {
     8.344805214942266, -1.819147107136867}}]}, 
   {Hue[0.6452148706057469], AbsoluteThickness[0.5], 
    LineBox[{{7.92708060284666, -0.9324159151240392}, {
     7.989105420730255, -0.6707005244921975}}]}, 
   {Hue[0.6458784974920335], AbsoluteThickness[0.5], 
    LineBox[{{7.989105420730255, -0.6707005244921975}, {
     8.033555458375794, -0.4087953838336355}}]}, 
   {Hue[0.6679937203181238], AbsoluteThickness[0.5], 
    LineBox[{{3.9008531008824088`, 3.657948572361989}, {3.8979864106465003`, 
     3.667510820787938}}]}, 
   {Hue[0.6685989361464542], AbsoluteThickness[0.5], 
    LineBox[{{3.8979864106465003`, 3.667510820787938}, {3.7989694265902703`, 
     3.940396614600485}}]}, 
   {Hue[0.5414531205533599], AbsoluteThickness[0.5], 
    LineBox[{{4.3211081754517675`, 2.9526189882752405`}, {4.335451801191139, 
     3.1219931969817014`}}]}, 
   {Hue[0.5423524008151415], AbsoluteThickness[0.5], 
    LineBox[{{4.335451801191139, 3.1219931969817014`}, {4.385707428777757, 
     3.411794517789677}}]}, 
   {Hue[0.5611051677198995], AbsoluteThickness[0.5], 
    LineBox[{{3.047494941223747, -1.266814309040785}, {
     2.6285388976632134`, -1.5054940684456088`}}]}, 
   {Hue[0.5618314409983969], AbsoluteThickness[0.5], 
    LineBox[{{2.6285388976632134`, -1.5054940684456088`}, {
     2.3893370596734043`, -1.6199123857139923`}}]}, 
   {Hue[0.5745440720890241], AbsoluteThickness[0.5], 
    LineBox[{{3.9341411072357984`, -1.6002509270067984`}, {
     3.7810187900075434`, -2.0833803435246803`}}]}, 
   {Hue[0.5750818135885667], AbsoluteThickness[0.5], 
    LineBox[{{3.7810187900075434`, -2.0833803435246803`}, {
     3.715013625580026, -2.330175543466793}}]}, 
   {Hue[0.44907926858883135`], AbsoluteThickness[0.5], 
    LineBox[{{7.046079077259909, -0.0722907448489142}, {
     7.147830536759592, -0.16647787122496044`}}]}, 
   {Hue[0.44952205071309104`], AbsoluteThickness[0.5], 
    LineBox[{{7.147830536759592, -0.16647787122496044`}, {
     7.365390946938891, -0.37533790806279116`}}]}, 
   {Hue[0.5373767561140231], AbsoluteThickness[0.5], 
    LineBox[{{2.855226775280789, 2.0499127811651507`}, {2.576715327880711, 
     2.058442033556609}}]}, 
   {Hue[0.5387188079844267], AbsoluteThickness[0.5], 
    LineBox[{{2.576715327880711, 2.058442033556609}, {2.3640818396500354`, 
     2.040665198588407}}]}, 
   {Hue[0.6498111524430782], AbsoluteThickness[0.5], 
    LineBox[{{4.1111099959190245`, 2.7643697156273657`}, {3.887441159086155, 
     2.844813518403313}}]}, 
   {Hue[0.6526777582916535], AbsoluteThickness[0.5], 
    LineBox[{{3.887441159086155, 2.844813518403313}, {3.710444025769342, 
     2.8773885668309362`}}]}, 
   {Hue[0.5603891807455376], AbsoluteThickness[0.5], 
    LineBox[{{4.47322879120796, 3.144633852475876}, {4.435606120922269, 
     3.2690997649574105`}}]}, 
   {Hue[0.5684754015015286], AbsoluteThickness[0.5], 
    LineBox[{{4.435606120922269, 3.2690997649574105`}, {4.328555922061131, 
     3.452232302207925}}]}, 
   {Hue[0.5354576637316288], AbsoluteThickness[0.5], 
    LineBox[{{4.6321015179910034`, 2.8768822681350086`}, {4.6312985013903125`,
      2.8771134781731114`}}]}, 
   {Hue[0.5362320967864916], AbsoluteThickness[0.5], 
    LineBox[{{4.6312985013903125`, 2.8771134781731114`}, {4.3707376204537685`,
      2.9742523454572622`}}]}, 
   {Hue[0.4412566471349549], AbsoluteThickness[0.5], 
    LineBox[{{6.609521110165274, 2.425372271459734}, {6.6856192076960035`, 
     2.293906393216652}}]}, 
   {Hue[0.44204559672155097`], AbsoluteThickness[0.5], 
    LineBox[{{6.6856192076960035`, 2.293906393216652}, {6.776949991146875, 
     2.1033056834417496`}}]}, 
   {Hue[0.5793474863856728], AbsoluteThickness[0.5], 
    LineBox[{{6.898432682666804, 2.9572840842236214`}, {6.653361755472767, 
     2.976771941987892}}]}, 
   {Hue[0.5797841595460174], AbsoluteThickness[0.5], 
    LineBox[{{6.653361755472767, 2.976771941987892}, {6.329085771463512, 
     3.0073167251405075`}}]}, 
   {Hue[0.030929532796456636`], AbsoluteThickness[0.5], 
    LineBox[{{7.1599998255150314`, 3.0249987506464455`}, {7.619319822595562, 
     3.1546246011206627`}}]}, 
   {Hue[0.031660303271886604`], AbsoluteThickness[0.5], 
    LineBox[{{7.619319822595562, 3.1546246011206627`}, {7.8773714846537075`, 
     3.207716530134219}}]}, 
   {Hue[0.5320040303615774], AbsoluteThickness[0.5], 
    LineBox[{{7.8773714846537075`, 3.207716530134219}, {7.710780634946925, 
     3.4118167555415506`}}]}, 
   {Hue[0.5802477787537046], AbsoluteThickness[0.5], 
    LineBox[{{6.93818844042659, 2.870718629724511}, {6.8613760529855226`, 
     2.814775838835141}}]}, 
   {Hue[0.5806911018621468], AbsoluteThickness[0.5], 
    LineBox[{{6.8613760529855226`, 2.814775838835141}, {6.6027921080926735`, 
     2.6190375343642924`}}]}, 
   {Hue[0.4449354702970166], AbsoluteThickness[0.5], 
    LineBox[{{6.558954293880868, 3.6406805323054274`}, {6.562767994141647, 
     3.688360696017967}}]}, 
   {Hue[0.540003002125825], AbsoluteThickness[0.5], 
    LineBox[{{5.113178426862221, 3.3519570902175926`}, {5.113070670636429, 
     3.352014107434671}}]}, 
   {Hue[0.5406213753139779], AbsoluteThickness[0.5], 
    LineBox[{{5.113070670636429, 3.352014107434671}, {4.892089298290888, 
     3.4528251620344106`}}]}, 
   {Hue[0.5396335966965818], AbsoluteThickness[0.5], 
    LineBox[{{5.926167261299292, 0.8386769757087384}, {5.9542042127164025`, 
     0.6853823706142881}}]}, 
   {Hue[0.5400819102793869], AbsoluteThickness[0.5], 
    LineBox[{{5.9542042127164025`, 0.6853823706142881}, {6.0019164694981235`, 
     0.3896956928529087}}]}, 
   {Hue[0.6537633416647957], AbsoluteThickness[0.5], 
    LineBox[{{6.615251264306741, 0.9449976108986228}, {6.652685535045622, 
     0.8732305211759899}}]}, 
   {Hue[0.6542380043002122], AbsoluteThickness[0.5], 
    LineBox[{{6.652685535045622, 0.8732305211759899}, {6.820261502818483, 
     0.574620493756075}}]}, 
   {Hue[0.6724156539661029], AbsoluteThickness[0.5], 
    LineBox[{{6.642059694726332, 1.5769917915728056`}, {6.747253606880097, 
     1.5715349809928376`}}]}, 
   {Hue[0.5958879137220201], AbsoluteThickness[0.5], 
    LineBox[{{6.104691567615338, 0.8029470965160467}, {6.073132324950481, 
     0.6296587100067061}}]}, 
   {Hue[0.5969681038991038], AbsoluteThickness[0.5], 
    LineBox[{{6.073132324950481, 0.6296587100067061}, {6.004398486055967, 
     0.3905134791917678}}]}, 
   {Hue[0.6841378735145289], AbsoluteThickness[0.5], 
    LineBox[{{5.347094476103539, 1.0251699140352626`}, {5.210888181553036, 
     0.9058118086750747}}]}, 
   {Hue[0.6880489619450791], AbsoluteThickness[0.5], 
    LineBox[{{5.210888181553036, 0.9058118086750747}, {5.0893023848741015`, 
     0.7514683095174013}}]}, 
   {Hue[0.664282286476569], AbsoluteThickness[0.5], 
    LineBox[{{5.671416649564645, 0.10561550987405684`}, {5.658567112835011, 
     0.06206733673480741}}]}, 
   {Hue[0.6705926258579338], AbsoluteThickness[0.5], 
    LineBox[{{5.658567112835011, 0.06206733673480741}, {
     5.590230707932722, -0.06176111640099165}}]}, 
   {Hue[0.638240112344104], AbsoluteThickness[0.5], 
    LineBox[{{6.595468318726314, 0.5727070445538006}, {6.855426234858795, 
     0.5242063178763734}}]}, 
   {Hue[0.638722764915963], AbsoluteThickness[0.5], 
    LineBox[{{6.855426234858795, 0.5242063178763734}, {7.160479006915052, 
     0.45682380466071615`}}]}, 
   {Hue[0.45281310138467057`], AbsoluteThickness[0.5], 
    LineBox[{{2.6146782042776437`, 3.253058795594541}, {2.5523338538537166`, 
     3.2968141164314755`}}]}, 
   {Hue[0.4542678560239067], AbsoluteThickness[0.5], 
    LineBox[{{2.5523338538537166`, 3.2968141164314755`}, {2.351995175438638, 
     3.4765393804834037`}}]}, 
   {Hue[0.5872317886276428], AbsoluteThickness[0.5], 
    LineBox[{{2.31839713512876, 0.5421590529651334}, {2.1624732672734486`, 
     0.445275338137764}}]}, 
   {Hue[0.5881836334297645], AbsoluteThickness[0.5], 
    LineBox[{{2.1624732672734486`, 0.445275338137764}, {1.9810809793451094`, 
     0.35431426284942463`}}]}, 
   {Hue[0.530819737345931], AbsoluteThickness[0.5], 
    LineBox[{{6.407618281581385, -3.2519335022571187`}, {
     6.509797950260904, -3.3084229956179145`}}]}, 
   {Hue[0.5419243626791607], AbsoluteThickness[0.5], 
    LineBox[{{6.509797950260904, -3.3084229956179145`}, {
     6.6326411925935025`, -3.426230662475405}}]}, 
   {Hue[0.6510725062708108], AbsoluteThickness[0.5], 
    LineBox[{{5.850313825183448, -3.351401617036807}, {
     5.958329535416332, -3.377947390336031}}]}, 
   {Hue[0.6531789351763412], AbsoluteThickness[0.5], 
    LineBox[{{5.958329535416332, -3.377947390336031}, {
     6.161426995675384, -3.4600429560301116`}}]}, 
   {Hue[0.5909020710293891], AbsoluteThickness[0.5], 
    LineBox[{{4.995273828679291, -3.65575921504511}, {
     5.038866950441019, -3.868054064292813}}]}, 
   {Hue[0.5914233431394961], AbsoluteThickness[0.5], 
    LineBox[{{5.038866950441019, -3.868054064292813}, {
     5.083711816614594, -4.145494646314502}}]}, 
   {Hue[0.5861756686085423], AbsoluteThickness[0.5], 
    LineBox[{{2.8282756185062667`, -1.0166156968726434`}, {
     2.777183174367187, -1.0869210082209868`}}]}, 
   {Hue[0.5874234854957849], AbsoluteThickness[0.5], 
    LineBox[{{2.777183174367187, -1.0869210082209868`}, {
     2.6593738488259104`, -1.2930771849225233`}}]}, 
   {Hue[0.662009662009926], AbsoluteThickness[0.5], 
    LineBox[{{6.997078773669759, -0.0655578756231604}, {
     6.960755928857651, -0.2868161777442779}}]}, 
   {Hue[0.6624517939275039], AbsoluteThickness[0.5], 
    LineBox[{{6.960755928857651, -0.2868161777442779}, {
     6.913487041955967, -0.6107996390954793}}]}, 
   {Hue[0.4984549563785256], AbsoluteThickness[0.5], 
    LineBox[{{7.9217632247763605`, 0.21539190540840342`}, {7.993605224212099, 
     0.143743440142892}}]}, 
   {Hue[0.49953737869375936`], AbsoluteThickness[0.5], 
    LineBox[{{7.993605224212099, 0.143743440142892}, {
     8.158989313164788, -0.057917451750119094`}}]}, 
   {Hue[0.5576833849404291], AbsoluteThickness[0.5], 
    LineBox[{{3.1370210043598545`, 2.765245133260674}, {2.88289456592321, 
     2.7746257420258678`}}]}, 
   {Hue[0.5581366665460691], AbsoluteThickness[0.5], 
    LineBox[{{2.88289456592321, 2.7746257420258678`}, {2.576228232959433, 
     2.778863057263447}}]}, 
   {Hue[0.5812797249862786], AbsoluteThickness[0.5], 
    LineBox[{{6.168262864429902, 1.5992893779000643`}, {6.168406464880693, 
     1.5719317806317512`}}]}, 
   {Hue[0.5930986405962584], AbsoluteThickness[0.5], 
    LineBox[{{6.168406464880693, 1.5719317806317512`}, {6.1240205160931875`, 
     1.4044319741249232`}}]}, 
   {Hue[0.4971258619928666], AbsoluteThickness[0.5], 
    LineBox[{{7.3916057879028205`, 2.335807728372676}, {7.499863383869908, 
     2.2157014611722747`}}]}, 
   {Hue[0.49844261254237593`], AbsoluteThickness[0.5], 
    LineBox[{{7.499863383869908, 2.2157014611722747`}, {7.660085761568094, 
     1.991639475688847}}]}, 
   {Hue[0.5993127556750495], AbsoluteThickness[0.5], 
    LineBox[{{6.667931909106055, 3.192962063917454}, {6.547716237158338, 
     3.12591339074066}}]}, 
   {Hue[0.6003692260551463], AbsoluteThickness[0.5], 
    LineBox[{{6.547716237158338, 3.12591339074066}, {6.32537587746439, 
     2.9715059207034944`}}]}, 
   {Hue[0.600089000619464], AbsoluteThickness[0.5], 
    LineBox[{{6.667787220680128, 3.193091504153586}, {6.5479081712180465`, 
     3.1258402327006487`}}]}, 
   {Hue[0.6011347086001493], AbsoluteThickness[0.5], 
    LineBox[{{6.5479081712180465`, 3.1258402327006487`}, {6.325383143333483, 
     2.9707127390400045`}}]}, 
   {Hue[0.5792495507654082], AbsoluteThickness[0.5], 
    LineBox[{{4.617322384440408, 3.2195038869246626`}, {4.431681568987099, 
     3.2444546234587444`}}]}, 
   {Hue[0.5796818870391675], AbsoluteThickness[0.5], 
    LineBox[{{4.431681568987099, 3.2444546234587444`}, {4.070921077963201, 
     3.2970942111012103`}}]}, 
   {Hue[0.5091754192305521], AbsoluteThickness[0.5], 
    LineBox[{{7.365413251419635, 0.6841959912807087}, {7.390320095139854, 
     0.6295804953727764}}]}, 
   {Hue[0.5096013948897029], AbsoluteThickness[0.5], 
    LineBox[{{7.390320095139854, 0.6295804953727764}, {7.541237704228514, 
     0.29728744001578383`}}]}, 
   {Hue[0.5584710928753672], AbsoluteThickness[0.5], 
    LineBox[{{6.281101302504902, -0.4318847979400394}, {
     6.265782653179332, -0.6170093719238439}}]}, 
   {Hue[0.5589056480864093], AbsoluteThickness[0.5], 
    LineBox[{{6.265782653179332, -0.6170093719238439}, {
     6.236768542904116, -0.9194868360831555}}]}, 
   {Hue[0.6853678575450817], AbsoluteThickness[0.5], 
    LineBox[{{6.020465011260368, 0.3970081757770556}, {5.925651404455485, 
     0.1628377127777016}}]}, 
   {Hue[0.6883401100652174], AbsoluteThickness[0.5], 
    LineBox[{{5.925651404455485, 0.1628377127777016}, {
     5.8743858822338515`, -0.06740588598618104}}]}, 
   {Hue[0.6508163196908703], AbsoluteThickness[0.5], 
    LineBox[{{6.326614213397263, -1.8094864221156384`}, {
     6.3685090168693, -1.84931118724903}}]}, 
   {Hue[0.6512426474820501], AbsoluteThickness[0.5], 
    LineBox[{{6.3685090168693, -1.84931118724903}, {
     6.599699214104081, -2.070427420410414}}]}, 
   {Hue[0.5202749047663701], AbsoluteThickness[0.5], 
    LineBox[{{3.5835079010038977`, 2.1583455438748014`}, {3.442421113742128, 
     2.163916450013235}}]}, 
   {Hue[0.5208296572711979], AbsoluteThickness[0.5], 
    LineBox[{{3.442421113742128, 2.163916450013235}, {3.137994040881305, 
     2.1908355687382985`}}]}, 
   {Hue[0.6205143968745861], AbsoluteThickness[0.5], 
    LineBox[{{4.612199466364905, -1.7548148686868592`}, {
     4.565780664710141, -1.8657751986203939`}}]}, 
   {Hue[0.6209406072695797], AbsoluteThickness[0.5], 
    LineBox[{{4.565780664710141, -1.8657751986203939`}, {
     4.438669232612174, -2.171901738027648}}]}, 
   {Hue[0.6090771852594472], AbsoluteThickness[0.5], 
    LineBox[{{2.5941998381883153`, -1.843413467771807}, {
     2.5973129178618475`, -1.8545134771397527`}}]}, 
   {Hue[0.6146779573162864], AbsoluteThickness[0.5], 
    LineBox[{{2.5973129178618475`, -1.8545134771397527`}, {
     2.6100171321598715`, -2.050953332835073}}]}, 
   {Hue[0.5435357049082896], AbsoluteThickness[0.5], 
    LineBox[{{4.853245755986811, 1.228362590144612}, {4.929781749248638, 
     1.1496127828110625`}}]}, 
   {Hue[0.544038646932833], AbsoluteThickness[0.5], 
    LineBox[{{4.929781749248638, 1.1496127828110625`}, {5.144332398712329, 
     0.9112951667036241}}]}, 
   {Hue[0.6247953792290392], AbsoluteThickness[0.5], 
    LineBox[{{3.2440938727381115`, -0.943034104802493}, {
     3.1929293372730934`, -1.0762994219603472`}}]}, 
   {Hue[0.6254405729881142], AbsoluteThickness[0.5], 
    LineBox[{{3.1929293372730934`, -1.0762994219603472`}, {
     3.1019228176940237`, -1.3660763134177214`}}]}, 
   {Hue[0.6005457195644786], AbsoluteThickness[0.5], 
    LineBox[{{3.2853832813839796`, -1.8902978357150382`}, {
     3.2878222912012216`, -2.0513667183651787`}}]}, 
   {Hue[0.6009727978742267], AbsoluteThickness[0.5], 
    LineBox[{{3.2878222912012216`, -2.0513667183651787`}, {
     3.2908890461004017`, -2.351180740694631}}]}, 
   {Hue[0.5553975711662805], AbsoluteThickness[0.5], 
    LineBox[{{6.623160239879996, -4.11685898111007}, {
     6.628671941787822, -4.125162934772743}}]}, 
   {Hue[0.5558272576554183], AbsoluteThickness[0.5], 
    LineBox[{{6.628671941787822, -4.125162934772743}, {
     6.80363511272709, -4.393798477068168}}]}, 
   {Hue[0.565390496711731], AbsoluteThickness[0.5], 
    LineBox[{{7.168209300253958, 3.0018620179182847`}, {7.582648419089688, 
     3.222822611794038}}]}, 
   {Hue[0.5658664928763033], AbsoluteThickness[0.5], 
    LineBox[{{7.582648419089688, 3.222822611794038}, {7.852175989175377, 
     3.355959722212503}}]}, 
   {Hue[0.5139048313139665], AbsoluteThickness[0.5], 
    LineBox[{{7.122594726748541, -3.645025531959841}, {
     7.187211785259113, -3.7483029477285106`}}]}, 
   {Hue[0.5147865924767205], AbsoluteThickness[0.5], 
    LineBox[{{7.187211785259113, -3.7483029477285106`}, {
     7.311324516671275, -3.913297926926461}}]}, 
   {Hue[0.6299210219690592], AbsoluteThickness[0.5], 
    LineBox[{{6.212681772302014, -3.402826411605234}, {
     6.144603747626657, -3.4290318597994163`}}]}, 
   {Hue[0.6303951275614069], AbsoluteThickness[0.5], 
    LineBox[{{6.144603747626657, -3.4290318597994163`}, {
     5.871212731829672, -3.543939326356616}}]}, 
   {Hue[0.613481519368372], AbsoluteThickness[0.5], 
    LineBox[{{6.620385576799296, -3.391286972946736}, {
     6.784668594955748, -3.59209962717789}}]}, 
   {Hue[0.6163789771032214], AbsoluteThickness[0.5], 
    LineBox[{{6.784668594955748, -3.59209962717789}, {
     6.9023591406331, -3.796830652540959}}]}, 
   {Hue[0.4954795675251274], AbsoluteThickness[0.5], 
    LineBox[{{6.606984461148083, -3.54884573825549}, {
     6.480765490026102, -3.8461329310720345`}}]}, 
   {Hue[0.49614521706910925`], AbsoluteThickness[0.5], 
    LineBox[{{6.480765490026102, -3.8461329310720345`}, {
     6.381582789046667, -4.129511876999055}}]}, 
   {Hue[0.6586874159423567], AbsoluteThickness[0.5], 
    LineBox[{{6.461263316345204, -3.6102436403666744`}, {
     6.306073229994347, -3.6230150011365967`}}]}, 
   {Hue[0.6605235795777529], AbsoluteThickness[0.5], 
    LineBox[{{6.306073229994347, -3.6230150011365967`}, {
     6.086546351166646, -3.6712760709133776`}}]}, 
   {Hue[0.6556227736303022], AbsoluteThickness[0.5], 
    LineBox[{{7.1882538136537715`, -3.4960261746754795`}, {
     7.336752358198967, -3.5427838567322407`}}]}, 
   {Hue[0.6561641557291997], AbsoluteThickness[0.5], 
    LineBox[{{7.336752358198967, -3.5427838567322407`}, {
     7.6151470245621935`, -3.616472540687838}}]}, 
   {Hue[0.5687806423425034], AbsoluteThickness[0.5], 
    LineBox[{{5.57619006002271, -3.3591352369491663`}, {
     5.536034501193216, -3.3627889670919906`}}]}, 
   {Hue[0.5756048328604272], AbsoluteThickness[0.5], 
    LineBox[{{5.536034501193216, -3.3627889670919906`}, {
     5.349415346524624, -3.4233382997347994`}}]}, 
   {Hue[0.6785337277129702], AbsoluteThickness[0.5], 
    LineBox[{{3.407749641880839, -4.117400187872137}, {
     3.408841217733547, -4.125606705068884}}]}, 
   {Hue[0.6805874340815704], AbsoluteThickness[0.5], 
    LineBox[{{3.408841217733547, -4.125606705068884}, {
     3.406687868964709, -4.357682820256416}}]}, 
   {Hue[0.47376061848363055`], AbsoluteThickness[0.5], 
    LineBox[{{7.832978007201858, 3.142804697606758}, {7.881326379821396, 
     3.141988358505115}}]}, 
   {Hue[0.4748904899102399], AbsoluteThickness[0.5], 
    LineBox[{{7.881326379821396, 3.141988358505115}, {8.130494833710449, 
     3.11204376697034}}]}, 
   {Hue[0.6735871545163183], AbsoluteThickness[0.5], 
    LineBox[{{6.139585176930218, 3.8236831509040035`}, {5.937385560660644, 
     3.8401425774858495`}}]}, 
   {Hue[0.6743252614481196], AbsoluteThickness[0.5], 
    LineBox[{{5.937385560660644, 3.8401425774858495`}, {5.627522106718701, 
     3.8427191085072376`}}]}, 
   {Hue[0.6057351677809053], AbsoluteThickness[0.5], 
    LineBox[{{5.153802559318333, 0.9281451875374592}, {5.187441375507766, 
     0.8990676838634921}}]}, 
   {Hue[0.6064017528050523], AbsoluteThickness[0.5], 
    LineBox[{{5.187441375507766, 0.8990676838634921}, {5.383819168512068, 
     0.7056745150359914}}]}, 
   {Hue[0.5406774437191978], AbsoluteThickness[0.5], 
    LineBox[{{5.579179784471038, 3.084998329048042}, {6.04659022239642, 
     2.785969388060624}}]}, 
   {Hue[0.5413850982846878], AbsoluteThickness[0.5], 
    LineBox[{{6.04659022239642, 2.785969388060624}, {6.309615612953485, 
     2.642461401938074}}]}, 
   {Hue[0.5974258552643013], AbsoluteThickness[0.5], 
    LineBox[{{5.126741043285065, 1.3832368302410234`}, {5.134711618515106, 
     1.3753718323018633`}}]}, 
   {Hue[0.5978699727875754], AbsoluteThickness[0.5], 
    LineBox[{{5.134711618515106, 1.3753718323018633`}, {5.364814184513919, 
     1.1395778115275113`}}]}, 
   {Hue[0.631582662135264], AbsoluteThickness[0.5], 
    LineBox[{{5.645495370537435, -0.6044183073765027}, {
     5.655061322001635, -0.6175224813338749}}]}, 
   {Hue[0.6320352008979999], AbsoluteThickness[0.5], 
    LineBox[{{5.655061322001635, -0.6175224813338749}, {
     5.8367488458582315`, -0.8548696119196835}}]}, 
   {Hue[0.4021382520002407], AbsoluteThickness[0.5], 
    LineBox[{{5.023835999081673, -0.6665280528057512}, {
     5.065177912131772, -0.7296846712052988}}]}, 
   {Hue[0.40343762392665294`], AbsoluteThickness[0.5], 
    LineBox[{{5.065177912131772, -0.7296846712052988}, {
     5.214825389274107, -0.9104432563716474}}]}, 
   {Hue[0.6975006902131607], AbsoluteThickness[0.5], 
    LineBox[{{6.450487183915666, 3.6673821343144635`}, {6.5510358286568025`, 
     3.746607847897437}}]}, 
   {Hue[0.6984134312739387], AbsoluteThickness[0.5], 
    LineBox[{{6.5510358286568025`, 3.746607847897437}, {6.795146643621801, 
     3.9062218054326836`}}]}, 
   {Hue[0.4866778436134383], AbsoluteThickness[0.5], 
    LineBox[{{6.061562489712735, 0.42557290280680754`}, {6.090959783697516, 
     0.37043438120289063`}}]}, 
   {Hue[0.4875137554486494], AbsoluteThickness[0.5], 
    LineBox[{{6.090959783697516, 0.37043438120289063`}, {6.245500766226435, 
     0.1303209000596991}}]}, 
   {Hue[0.6784235119855577], AbsoluteThickness[0.5], 
    LineBox[{{3.8702547831848895`, -0.8602510474568634}, {
     3.8639135244134777`, -0.9377956201938629}}]}, 
   {Hue[0.6871370840207508], AbsoluteThickness[0.5], 
    LineBox[{{3.8639135244134777`, -0.9377956201938629}, {
     3.8932499823145847`, -1.1202604420727047`}}]}, 
   {Hue[0.5607556425890611], AbsoluteThickness[0.5], 
    LineBox[{{7.621841849280827, 2.4828785986592417`}, {7.861213351791472, 
     2.516427710353663}}]}, 
   {Hue[0.5613730458210503], AbsoluteThickness[0.5], 
    LineBox[{{7.861213351791472, 2.516427710353663}, {8.139771995019071, 
     2.538955894412594}}]}, 
   {Hue[0.5397675939496233], AbsoluteThickness[0.5], 
    LineBox[{{6.798027937241265, 3.904841967448282}, {7.655314767344942, 
     3.8521331472537867`}}]}, 
   {Hue[0.5407807029013192], AbsoluteThickness[0.5], 
    LineBox[{{7.655314767344942, 3.8521331472537867`}, {7.923327375963976, 
     3.8097561171301613`}}]}, 
   {Hue[0.5139356862158111], AbsoluteThickness[0.5], 
    LineBox[{{5.6737625552074435`, -1.5922807528453093`}, {
     5.675118992189309, -1.6010105166914816`}}]}, 
   {Hue[0.5146170797300509], AbsoluteThickness[0.5], 
    LineBox[{{5.675118992189309, -1.6010105166914816`}, {
     5.699220542120158, -1.8759377065215141`}}]}, 
   {Hue[0.6175330748116112], AbsoluteThickness[0.5], 
    LineBox[{{8.15469176456565, -3.3652854145736475`}, {
     8.156202860372474, -3.3654846375570675`}}]}, 
   {Hue[0.618320035061628], AbsoluteThickness[0.5], 
    LineBox[{{8.156202860372474, -3.3654846375570675`}, {
     8.427343778782822, -3.379977234582916}}]}, 
   {Hue[0.5832662825458367], AbsoluteThickness[0.5], 
    LineBox[{{6.954315508168411, -4.155510397004101}, {
     7.0631258102997245`, -4.341368826453183}}]}, 
   {Hue[0.5854790616354112], AbsoluteThickness[0.5], 
    LineBox[{{7.0631258102997245`, -4.341368826453183}, {
     7.162060876427187, -4.5867116589993575`}}]}, 
   {Hue[0.6206674792161189], AbsoluteThickness[0.5], 
    LineBox[{{3.1482838292612056`, 0.12530338494943868`}, {
     3.1157635502213084`, 0.09895155607266265}}]}, 
   {Hue[0.6212500527544271], AbsoluteThickness[0.5], 
    LineBox[{{3.1157635502213084`, 0.09895155607266265}, {
     2.8911720077417504`, -0.10381883717983781`}}]}, 
   {Hue[0.6042771197512425], AbsoluteThickness[0.5], 
    LineBox[{{4.618038889208468, 1.2293657926361408`}, {4.569702380589193, 
     1.1794656257646177`}}]}, 
   {Hue[0.6048835896577814], AbsoluteThickness[0.5], 
    LineBox[{{4.569702380589193, 1.1794656257646177`}, {4.3540554618427265`, 
     0.9298355122021543}}]}, 
   {Hue[0.6359828559230469], AbsoluteThickness[0.5], 
    LineBox[{{6.260458992293717, 1.5641309692343006`}, {6.203325078948011, 
     1.4275587715943667`}}]}, 
   {Hue[0.6365736059493102], AbsoluteThickness[0.5], 
    LineBox[{{6.203325078948011, 1.4275587715943667`}, {6.105472351067921, 
     1.1523049405410153`}}]}, 
   {Hue[0.6632796546803241], AbsoluteThickness[0.5], 
    LineBox[{{5.875277310478567, 2.927088613603575}, {5.81177671674325, 
     2.9061815200081904`}}]}, 
   {Hue[0.6639211751851659], AbsoluteThickness[0.5], 
    LineBox[{{5.81177671674325, 2.9061815200081904`}, {5.542364330642674, 
     2.7986175425247923`}}]}, 
   {Hue[0.6207536653358584], AbsoluteThickness[0.5], 
    LineBox[{{5.077048849492125, 3.2087738870667355`}, {4.940909932697841, 
     3.23062448818001}}]}, 
   {Hue[0.6211859936033535], AbsoluteThickness[0.5], 
    LineBox[{{4.940909932697841, 3.23062448818001}, {4.620087209872344, 
     3.278411453925016}}]}, 
   {Hue[0.6218527457299817], AbsoluteThickness[0.5], 
    LineBox[{{5.34916530037734, 0.9358116501049869}, {5.292232482236305, 
     0.899913808964154}}]}, 
   {Hue[0.6228158978163714], AbsoluteThickness[0.5], 
    LineBox[{{5.292232482236305, 0.899913808964154}, {5.089718268161514, 
     0.7445079973178222}}]}, 
   {Hue[0.6091634054643527], AbsoluteThickness[0.5], 
    LineBox[{{2.9155203122478293`, 2.949228897842466}, {2.616680848723848, 
     3.0076251963566873`}}]}, 
   {Hue[0.6096996317162177], AbsoluteThickness[0.5], 
    LineBox[{{2.616680848723848, 3.0076251963566873`}, {2.318041721433721, 
     3.052051871801317}}]}, 
   {Hue[0.6229063817689174], AbsoluteThickness[0.5], 
    LineBox[{{4.108449097599739, 0.6811536759800854}, {4.103413048617648, 
     0.6721019198900418}}]}, 
   {Hue[0.6233600415774014], AbsoluteThickness[0.5], 
    LineBox[{{4.103413048617648, 0.6721019198900418}, {3.938283698466122, 
     0.3908842974101462}}]}, 
   {Hue[0.6815845677374917], AbsoluteThickness[0.5], 
    LineBox[{{5.313761382725557, -2.3753885576840545`}, {
     5.316368076890608, -2.4428816098702963`}}]}, 
   {Hue[0.6421802505055946], AbsoluteThickness[0.5], 
    LineBox[{{2.711156949285175, -1.3565984331188055`}, {
     2.6414778995977044`, -1.5862791653479533`}}]}, 
   {Hue[0.6435159878119407], AbsoluteThickness[0.5], 
    LineBox[{{2.6414778995977044`, -1.5862791653479533`}, {
     2.5944206583869787`, -1.843662876519331}}]}, 
   {Hue[0.6824158840875983], AbsoluteThickness[0.5], 
    LineBox[{{4.87319977211185, -3.5919042339573353`}, {
     5.0007847873994065`, -3.8678953518657604`}}]}, 
   {Hue[0.6829195652927549], AbsoluteThickness[0.5], 
    LineBox[{{5.0007847873994065`, -3.8678953518657604`}, {
     5.1096505316662615`, -4.129265422351729}}]}, 
   {Hue[0.6224319020911335], AbsoluteThickness[0.5], 
    LineBox[{{6.867917801542046, -2.5540481791056706`}, {
     6.971924926268554, -2.8090780652640226`}}]}, 
   {Hue[0.6229340850036152], AbsoluteThickness[0.5], 
    LineBox[{{6.971924926268554, -2.8090780652640226`}, {
     7.078435876499311, -3.1015598020127157`}}]}, 
   {Hue[0.6145933393148875], AbsoluteThickness[0.5], 
    LineBox[{{7.364336585397516, 1.2228997999409443`}, {7.462518724403162, 
     1.3472179807268656`}}]}, 
   {Hue[0.6152485980061096], AbsoluteThickness[0.5], 
    LineBox[{{7.462518724403162, 1.3472179807268656`}, {7.632665524876749, 
     1.5933143457950287`}}]}, 
   {Hue[0.6236111128535975], AbsoluteThickness[0.5], 
    LineBox[{{7.148521939918161, -3.9848216415948503`}, {
     7.183147228357507, -3.8266178675455915`}}]}, 
   {Hue[0.6280324602324335], AbsoluteThickness[0.5], 
    LineBox[{{7.183147228357507, -3.8266178675455915`}, {
     7.243816924659211, -3.6861978945527274`}}]}, 
   {Hue[0.5913000302652642], AbsoluteThickness[0.5], 
    LineBox[{{7.528576631554694, 2.642972966420536}, {7.576355691837412, 
     2.833455862591213}}]}, 
   {Hue[0.5926218100240032], AbsoluteThickness[0.5], 
    LineBox[{{7.576355691837412, 2.833455862591213}, {7.606240752714355, 
     3.0572917106210094`}}]}, 
   {Hue[0.534303077887997], AbsoluteThickness[0.5], 
    LineBox[{{2.8408548025121005`, -3.854433554101237}, {
     2.8340800912329427`, -3.874946472042584}}]}, 
   {Hue[0.567081644324229], AbsoluteThickness[0.5], 
    LineBox[{{2.8340800912329427`, -3.874946472042584}, {
     2.8387106544176817`, -4.034649028598426}}]}, 
   {Hue[0.6974686744909337], AbsoluteThickness[0.5], 
    LineBox[{{2.8387106544176817`, -4.034649028598426}, {
     2.9798364196256135`, -4.109548074522625}}]}, 
   {Hue[0.5364005341888254], AbsoluteThickness[0.5], 
    LineBox[{{6.47494742669398, -3.6116142461570684`}, {
     6.5648711505674475`, -3.717611645704477}}]}, 
   {Hue[0.5372935852954929], AbsoluteThickness[0.5], 
    LineBox[{{6.5648711505674475`, -3.717611645704477}, {
     6.775239153259096, -3.9259373130475024`}}]}, 
   {Hue[0.5711852032730939], AbsoluteThickness[0.5], 
    LineBox[{{3.139885600420258, 2.7939362106969026`}, {3.103612441526273, 
     2.89503130844431}}]}, 
   {Hue[0.5716125077898958], AbsoluteThickness[0.5], 
    LineBox[{{3.103612441526273, 2.89503130844431}, {2.995513837179193, 
     3.1913138537350196`}}]}, 
   {Hue[0.5349217103120087], AbsoluteThickness[0.5], 
    LineBox[{{8.269671040239817, -1.3751566092853875`}, {
     8.346399351888461, -1.6830254685833002`}}]}, 
   {Hue[0.5591158054909481], AbsoluteThickness[0.5], 
    LineBox[{{8.346399351888461, -1.6830254685833002`}, {
     8.334429269146463, -1.8359994485996693`}}]}, 
   {Hue[0.6577184603481308], AbsoluteThickness[0.5], 
    LineBox[{{7.768301649781222, -1.4107465967438921`}, {
     7.620137048530509, -1.4406123419546961`}}]}, 
   {Hue[0.6582084156619346], AbsoluteThickness[0.5], 
    LineBox[{{7.620137048530509, -1.4406123419546961`}, {
     7.324342525977599, -1.511069363246536}}]}, 
   {Hue[0.46291897153417627`], AbsoluteThickness[0.5], 
    LineBox[{{8.011255643735685, 1.5979565114567478`}, {8.09234689855119, 
     1.7559015424393827`}}]}, 
   {Hue[0.4690172079920003], AbsoluteThickness[0.5], 
    LineBox[{{8.09234689855119, 1.7559015424393827`}, {8.201225639449289, 
     1.888031298201017}}]}, 
   {Hue[0.6883739986046832], AbsoluteThickness[0.5], 
    LineBox[{{7.197431200713964, 1.8761586910474153`}, {7.09631396129713, 
     2.0354097006529908`}}]}, 
   {Hue[0.6904679945777327], AbsoluteThickness[0.5], 
    LineBox[{{7.09631396129713, 2.0354097006529908`}, {6.977504011886045, 
     2.174057454003598}}]}, 
   {Hue[0.6844440594558487], AbsoluteThickness[0.5], 
    LineBox[{{8.336253808635119, -0.3923468797501998}, {
     7.760178656819524, -1.0775511150705575`}}]}, 
   {Hue[0.6861583286192617], AbsoluteThickness[0.5], 
    LineBox[{{7.760178656819524, -1.0775511150705575`}, {
     7.624300977912175, -1.2898988057754643`}}]}, 
   {Hue[0.5072038274849567], AbsoluteThickness[0.5], 
    LineBox[{{7.272801865781254, -0.9451938823982878}, {
     7.298966895713358, -1.1346303069569257`}}]}, 
   {Hue[0.507787830125935], AbsoluteThickness[0.5], 
    LineBox[{{7.298966895713358, -1.1346303069569257`}, {
     7.353286851739628, -1.4157762403458516`}}]}, 
   {Hue[0.658100191027411], AbsoluteThickness[0.5], 
    LineBox[{{5.645820473983794, -0.2329151577727986}, {
     5.505240325822599, -0.37776210062150706`}}]}, 
   {Hue[0.6592200265250483], AbsoluteThickness[0.5], 
    LineBox[{{5.505240325822599, -0.37776210062150706`}, {
     5.341437726948885, -0.5852316572884696}}]}, 
   {Hue[0.6704353254767447], AbsoluteThickness[0.5], 
    LineBox[{{4.376267523511717, 1.9866423881345274`}, {4.186766894816547, 
     2.051916825630026}}]}, 
   {Hue[0.6719443333978263], AbsoluteThickness[0.5], 
    LineBox[{{4.186766894816547, 2.051916825630026}, {3.9369298921301183`, 
     2.105193170765109}}]}, 
   {Hue[0.3411799008135431], AbsoluteThickness[0.5], 
    LineBox[{{5.85965356045574, 3.398293420346523}, {5.757506694998987, 
     3.588795243241317}}]}, 
   {Hue[0.34206877321258783`], AbsoluteThickness[0.5], 
    LineBox[{{5.757506694998987, 3.588795243241317}, {5.639831855099425, 
     3.8626991554348473`}}]}, 
   {Hue[0.6856197802775321], AbsoluteThickness[0.5], 
    LineBox[{{7.884238761714839, 2.2065111999676392`}, {8.06209144646059, 
     2.230973824136083}}]}, 
   {Hue[0.6860459054133093], AbsoluteThickness[0.5], 
    LineBox[{{8.06209144646059, 2.230973824136083}, {8.362160963191506, 
     2.271539872712762}}]}, 
   {Hue[0.6501795257156816], AbsoluteThickness[0.5], 
    LineBox[{{4.411073530094515, 2.327374771406374}, {4.37407674379674, 
     2.3444893641066074`}}]}, 
   {Hue[0.6540272871878757], AbsoluteThickness[0.5], 
    LineBox[{{4.37407674379674, 2.3444893641066074`}, {4.166332242020228, 
     2.3976217938655116`}}]}, 
   {Hue[0.6696582865067845], AbsoluteThickness[0.5], 
    LineBox[{{6.171289075482996, 0.14405856747697232`}, {6.161319919524752, 
     0.1276393753253839}}]}, 
   {Hue[0.6701931860457848], AbsoluteThickness[0.5], 
    LineBox[{{6.161319919524752, 0.1276393753253839}, {
     5.976967796365814, -0.14727286201191875`}}]}, 
   {Hue[0.5544833698910688], AbsoluteThickness[0.5], 
    LineBox[{{7.385463149865783, 0.29782541036290366`}, {7.4457114926337695`, 
     0.07815400115471503}}]}, 
   {Hue[0.554965609532914], AbsoluteThickness[0.5], 
    LineBox[{{7.4457114926337695`, 0.07815400115471503}, {
     7.529709983347873, -0.19289718336638262`}}]}, 
   {Hue[0.528401707451304], AbsoluteThickness[0.5], 
    LineBox[{{7.639214815761387, 2.894437862224022}, {7.635848098518711, 
     2.901024756797929}}]}, 
   {Hue[0.5294519514382272], AbsoluteThickness[0.5], 
    LineBox[{{7.635848098518711, 2.901024756797929}, {7.508174570221676, 
     3.1000610347106634`}}]}, 
   {Hue[0.5991947920606525], AbsoluteThickness[0.5], 
    LineBox[{{6.504240233721568, 2.6768960329973375`}, {6.427520508565434, 
     2.8207081665321936`}}]}, 
   {Hue[0.6010678259751436], AbsoluteThickness[0.5], 
    LineBox[{{6.427520508565434, 2.820708166532194}, {6.343531270821802, 
     3.047626479215385}}]}, 
   {Hue[0.5989201343332136], AbsoluteThickness[0.5], 
    LineBox[{{5.437130501128906, 2.0932348131319585`}, {5.366181905054965, 
     2.1162953607223183`}}]}, 
   {Hue[0.5995119281015104], AbsoluteThickness[0.5], 
    LineBox[{{5.366181905054965, 2.1162953607223183`}, {5.073849018752725, 
     2.229368526730973}}]}, 
   {Hue[0.6185416933190023], AbsoluteThickness[0.5], 
    LineBox[{{6.555636347097228, -0.7101769206441444}, {
     6.547788679552207, -0.8325751086305845}}]}, 
   {Hue[0.6189865984263385], AbsoluteThickness[0.5], 
    LineBox[{{6.547788679552207, -0.8325751086305845}, {
     6.521907817182187, -1.1425161133586363`}}]}, 
   {Hue[0.6887121545250808], AbsoluteThickness[0.5], 
    LineBox[{{7.571882148877435, 2.612119747805933}, {7.609014933599285, 
     2.7219993677550995`}}]}, 
   {Hue[0.6899757944250291], AbsoluteThickness[0.5], 
    LineBox[{{7.609014933599285, 2.7219993677550995`}, {7.705234316539079, 
     2.9285293916648074`}}]}, 
   {Hue[0.6036224477991555], AbsoluteThickness[0.5], 
    LineBox[{{6.7408206958356605`, -0.9417525328365889}, {
     6.2459776223668, -1.6811697075099992`}}]}, 
   {Hue[0.6041024089701288], AbsoluteThickness[0.5], 
    LineBox[{{6.2459776223668, -1.6811697075099992`}, {
     6.121673836900843, -1.8804994787920926`}}]}, 
   {Hue[0.46168523102085], AbsoluteThickness[0.5], 
    LineBox[{{7.521778551184318, -1.136207056076616}, {
     7.724464554356151, -1.6630286850822555`}}]}, 
   {Hue[0.4621312483876313], AbsoluteThickness[0.5], 
    LineBox[{{7.724464554356151, -1.6630286850822555`}, {
     7.832735015989198, -1.9286080583021337`}}]}, 
   {Hue[0.6449194660238332], AbsoluteThickness[0.5], 
    LineBox[{{7.860910609681471, -0.32068477923304844`}, {
     8.09727079420092, -0.21403521143951734`}}]}, 
   {Hue[0.6456628728761453], AbsoluteThickness[0.5], 
    LineBox[{{8.09727079420092, -0.21403521143951734`}, {
     8.382307720264123, -0.10985419536918947`}}]}, 
   {Hue[0.5458085347089688], AbsoluteThickness[0.5], 
    LineBox[{{3.687819082841866, -0.8475995104306607}, {
     3.673839149655659, -0.8515165648712542}}]}, 
   {Hue[0.5463834839981687], AbsoluteThickness[0.5], 
    LineBox[{{3.673839149655659, -0.8515165648712542}, {
     3.381785206595015, -0.9500355551792761}}]}, 
   {Hue[0.6733565110298012], AbsoluteThickness[0.5], 
    LineBox[{{4.608363908700315, 1.3212642126444838`}, {4.570466524704, 
     1.3302118673378742`}}]}, 
   {Hue[0.677292905692931], AbsoluteThickness[0.5], 
    LineBox[{{4.570466524704, 1.3302118673378742`}, {4.414665050307726, 
     1.3990961048210333`}}]}, 
   {Hue[0.6207020946381427], AbsoluteThickness[0.5], 
    LineBox[{{5.066478706165485, -0.800260473329759}, {
     4.982995732082213, -0.8625735707939168}}]}, 
   {Hue[0.6356679846401152], AbsoluteThickness[0.5], 
    LineBox[{{4.982995732082213, -0.8625735707939168}, {
     4.886892221043563, -0.9898714097928788}}]}, 
   {Hue[0.594417818066431], AbsoluteThickness[0.5], 
    LineBox[{{3.6452464622785774`, -0.4003603473890379}, {
     3.638597364622188, -0.41008139079784595`}}]}, 
   {Hue[0.5948606051880359], AbsoluteThickness[0.5], 
    LineBox[{{3.638597364622188, -0.41008139079784595`}, {
     3.4493430546787973`, -0.6762515234235578}}]}, 
   {Hue[0.6293713100466183], AbsoluteThickness[0.5], 
    LineBox[{{3.5160672400291246`, -4.199885695478522}, {
     3.44730903365, -4.374013059577854}}]}, 
   {Hue[0.6299593010829286], AbsoluteThickness[0.5], 
    LineBox[{{3.44730903365, -4.374013059577854}, {
     3.3460217449265173`, -4.677772515436229}}]}, 
   {Hue[0.6926259537047464], AbsoluteThickness[0.5], 
    LineBox[{{5.363234313248962, -3.983868773180004}, {
     5.305147262540535, -4.080607123518644}}]}, 
   {Hue[0.6930543207695322], AbsoluteThickness[0.5], 
    LineBox[{{5.305147262540535, -4.080607123518644}, {
     5.155932782359881, -4.333118346270187}}]}, 
   {Hue[0.4261580896089717], AbsoluteThickness[0.5], 
    LineBox[{{5.455098671638979, -4.14577889402922}, {
     5.589138182026479, -4.293463375572911}}]}, 
   {Hue[0.4308929288924335], AbsoluteThickness[0.5], 
    LineBox[{{5.589138182026479, -4.293463375572911}, {
     5.761747095208018, -4.421095011046312}}]}, 
   {Hue[0.6546348467413852], AbsoluteThickness[0.5], 
    LineBox[{{7.866209861046067, -1.096041321916395}, {
     7.90426289168355, -1.0804245643021486`}}]}, 
   {Hue[0.6550608081136338], AbsoluteThickness[0.5], 
    LineBox[{{7.90426289168355, -1.0804245643021486`}, {
     8.178263851490088, -0.9684416026621805}}]}, 
   {Hue[0.6465421243783201], AbsoluteThickness[0.5], 
    LineBox[{{8.033555458375794, -0.4087953838336355}, {
     8.058953834593604, -0.16435366971912915`}}]}, 
   {Hue[0.6471474539301777], AbsoluteThickness[0.5], 
    LineBox[{{8.058953834593604, -0.16435366971912915`}, {8.072695612833158, 
     0.12966087382778554`}}]}, 
   {Hue[0.543251681076923], AbsoluteThickness[0.5], 
    LineBox[{{4.385707428777757, 3.411794517789677}, {4.404834181927382, 
     3.484005137985638}}]}, 
   {Hue[0.5516914998674188], AbsoluteThickness[0.5], 
    LineBox[{{4.404834181927382, 3.484005137985638}, {4.407069581962368, 
     3.594081478125723}}]}, 
   {Hue[0.5625577142768942], AbsoluteThickness[0.5], 
    LineBox[{{2.3893370596734043`, -1.6199123857139923`}, {
     2.3870847559222454`, -1.6207976175825938`}}]}, 
   {Hue[0.5630561336821193], AbsoluteThickness[0.5], 
    LineBox[{{2.3870847559222454`, -1.6207976175825938`}, {
     2.123718354849669, -1.7357571562527376`}}]}, 
   {Hue[0.5756195550881095], AbsoluteThickness[0.5], 
    LineBox[{{3.715013625580026, -2.330175543466793}, {
     3.6549160599114416`, -2.6044021729952123`}}]}, 
   {Hue[0.5765488182496826], AbsoluteThickness[0.5], 
    LineBox[{{3.6549160599114416`, -2.6044021729952123`}, {
     3.62205526617613, -2.8633204609321807`}}]}, 
   {Hue[0.44996483283735067`], AbsoluteThickness[0.5], 
    LineBox[{{7.365390946938891, -0.37533790806279116`}, {
     7.3657552094949885`, -0.3757005609226706}}]}, 
   {Hue[0.45039148311817384`], AbsoluteThickness[0.5], 
    LineBox[{{7.3657552094949885`, -0.3757005609226706}, {
     7.582072730470732, -0.5893620531666515}}]}, 
   {Hue[0.5400608598548304], AbsoluteThickness[0.5], 
    LineBox[{{2.3640818396500354`, 2.040665198588407}, {2.1534670888270924`, 
     1.9985339883319397`}}]}, 
   {Hue[0.5407403417325316], AbsoluteThickness[0.5], 
    LineBox[{{2.1534670888270924`, 1.9985339883319397`}, {1.898838704979184, 
     1.9649983268560656`}}]}, 
   {Hue[0.6555443641402287], AbsoluteThickness[0.5], 
    LineBox[{{3.710444025769342, 2.8773885668309362`}, {3.589385755428531, 
     2.8796600441408997`}}]}, 
   {Hue[0.658649581249988], AbsoluteThickness[0.5], 
    LineBox[{{3.589385755428531, 2.8796600441408997`}, {3.3712773081489127`, 
     2.9209939304071986`}}]}, 
   {Hue[0.5765616222575197], AbsoluteThickness[0.5], 
    LineBox[{{4.328555922061131, 3.452232302207925}, {4.209715041142722, 
     3.5761660754653386`}}]}, 
   {Hue[0.5786527666403628], AbsoluteThickness[0.5], 
    LineBox[{{4.209715041142722, 3.5761660754653386`}, {4.085523175279689, 
     3.7494878705405608`}}]}, 
   {Hue[0.5370065298413546], AbsoluteThickness[0.5], 
    LineBox[{{4.3707376204537685`, 2.9742523454572622`}, {3.929763898802404, 
     3.178282321907158}}]}, 
   {Hue[0.5374369769796273], AbsoluteThickness[0.5], 
    LineBox[{{3.929763898802404, 3.178282321907158}, {3.6236936984178687`, 
     3.3234434251614515`}}]}, 
   {Hue[0.4428345463081471], AbsoluteThickness[0.5], 
    LineBox[{{6.776949991146875, 2.1033056834417496`}, {6.951000265534278, 
     1.65320071140903}}]}, 
   {Hue[0.44337809755862306`], AbsoluteThickness[0.5], 
    LineBox[{{6.951000265534278, 1.65320071140903}, {7.053854609025802, 
     1.4201769265535833`}}]}, 
   {Hue[0.580220832706362], AbsoluteThickness[0.5], 
    LineBox[{{6.329085771463512, 3.0073167251405075`}, {6.113450053020738, 
     3.030801318129775}}]}, 
   {Hue[0.5806483015886508], AbsoluteThickness[0.5], 
    LineBox[{{6.113450053020738, 3.030801318129775}, {5.8230317078827385`, 
     3.0640893620835405`}}]}, 
   {Hue[0.5312732598861496], AbsoluteThickness[0.5], 
    LineBox[{{7.619319822595562, 3.1546246011206627`}, {7.589131687108674, 
     3.072149924583044}}]}, 
   {Hue[0.5317877516025766], AbsoluteThickness[0.5], 
    LineBox[{{7.589131687108674, 3.072149924583044}, {7.506394396696632, 
     2.813919555485486}}]}, 
   {Hue[0.03239107374731641], AbsoluteThickness[0.5], 
    LineBox[{{7.8773714846537075`, 3.207716530134219}, {8.076565246452969, 
     3.2339127688562757`}}]}, 
   {Hue[0.03282884195747575], AbsoluteThickness[0.5], 
    LineBox[{{8.076565246452969, 3.2339127688562757`}, {8.379180945862812, 
     3.2784235964968107`}}]}, 
   {Hue[0.5849672800323227], AbsoluteThickness[0.5], 
    LineBox[{{8.379180945862812, 3.2784235964968107`}, {8.097005192411306, 
     3.160379878025099}}]}, 
   {Hue[0.5327348008370072], AbsoluteThickness[0.5], 
    LineBox[{{7.710780634946925, 3.4118167555415506`}, {7.672727982087615, 
     3.465983916917439}}]}, 
   {Hue[0.5363010312071599], AbsoluteThickness[0.5], 
    LineBox[{{7.672727982087615, 3.465983916917439}, {7.606107559594368, 
     3.60948563560889}}]}, 
   {Hue[0.5811344249705891], AbsoluteThickness[0.5], 
    LineBox[{{6.6027921080926735`, 2.6190375343642924`}, {6.5992704944420195`,
      2.6162680203603497`}}]}, 
   {Hue[0.5815603172176665], AbsoluteThickness[0.5], 
    LineBox[{{6.5992704944420195`, 2.6162680203603497`}, {6.335825634537416, 
     2.4087158960677053`}}]}, 
   {Hue[0.5412397485021309], AbsoluteThickness[0.5], 
    LineBox[{{4.892089298290888, 3.4528251620344106`}, {4.695187913259111, 
     3.5290398253854054`}}]}, 
   {Hue[0.5417822025102734], AbsoluteThickness[0.5], 
    LineBox[{{4.695187913259111, 3.5290398253854054`}, {4.439198819447457, 
     3.642069564449045}}]}, 
   {Hue[0.5405302238621921], AbsoluteThickness[0.5], 
    LineBox[{{6.0019164694981235`, 0.3896956928529087}, {6.029337615123934, 
     0.19378940584868945`}}]}, 
   {Hue[0.5409771358127975], AbsoluteThickness[0.5], 
    LineBox[{{6.029337615123934, 0.19378940584868945`}, {
     6.070131265381225, -0.14795229775202326`}}]}, 
   {Hue[0.6547126669356289], AbsoluteThickness[0.5], 
    LineBox[{{6.820261502818483, 0.574620493756075}, {6.853333300479423, 
     0.5196975862460491}}]}, 
   {Hue[0.6555556113270862], AbsoluteThickness[0.5], 
    LineBox[{{6.853333300479423, 0.5196975862460491}, {7.015615568848052, 
     0.29460547312310115`}}]}, 
   {Hue[0.5980482940761874], AbsoluteThickness[0.5], 
    LineBox[{{6.004398486055967, 0.3905134791917678}, {5.907960007194396, 
     0.14877967366884798`}}]}, 
   {Hue[0.6034806191607642], AbsoluteThickness[0.5], 
    LineBox[{{5.907960007194396, 0.14877967366884798`}, {
     5.871203898410041, -0.06168178135465244}}]}, 
   {Hue[0.6919600503756296], AbsoluteThickness[0.5], 
    LineBox[{{5.0893023848741015`, 0.7514683095174013}, {5.057733747102783, 
     0.6913071182547987}}]}, 
   {Hue[0.6924452916059929], AbsoluteThickness[0.5], 
    LineBox[{{5.057733747102783, 0.6913071182547987}, {4.929510524386582, 
     0.42557532187130603`}}]}, 
   {Hue[0.6769029652392987], AbsoluteThickness[0.5], 
    LineBox[{{5.590230707932722, -0.061761116400991634`}, {
     5.458952346058275, -0.21095078426477282`}}]}, 
   {Hue[0.679018031664683], AbsoluteThickness[0.5], 
    LineBox[{{5.458952346058275, -0.21095078426477282`}, {
     5.261561876287769, -0.3791617873073436}}]}, 
   {Hue[0.639205417487822], AbsoluteThickness[0.5], 
    LineBox[{{7.160479006915052, 0.45682380466071615`}, {7.285366410502466, 
     0.42488909969849425`}}]}, 
   {Hue[0.6398274378526188], AbsoluteThickness[0.5], 
    LineBox[{{7.285366410502466, 0.42488909969849425`}, {7.615519205944208, 
     0.3609992293996514}}]}, 
   {Hue[0.455722610663143], AbsoluteThickness[0.5], 
    LineBox[{{2.351995175438638, 3.4765393804834037`}, {2.2679663825017795`, 
     3.5722835968565083`}}]}, 
   {Hue[0.45630602454745256`], AbsoluteThickness[0.5], 
    LineBox[{{2.2679663825017795`, 3.5722835968565083`}, {2.0929066569062744`,
      3.794701955447239}}]}, 
   {Hue[0.5530289880123902], AbsoluteThickness[0.5], 
    LineBox[{{6.6326411925935025`, -3.426230662475405}, {
     6.72895656647207, -3.584434801031472}}]}, 
   {Hue[0.5537255985792225], AbsoluteThickness[0.5], 
    LineBox[{{6.72895656647207, -3.584434801031472}, {
     6.872510382750326, -3.8612445774118154`}}]}, 
   {Hue[0.6552853640818714], AbsoluteThickness[0.5], 
    LineBox[{{6.161426995675384, -3.4600429560301116`}, {
     6.570656948503143, -3.698331037957478}}]}, 
   {Hue[0.6557356380289008], AbsoluteThickness[0.5], 
    LineBox[{{6.570656948503143, -3.698331037957478}, {
     6.870287339406849, -3.8641641797506416`}}]}, 
   {Hue[0.591944615249603], AbsoluteThickness[0.5], 
    LineBox[{{5.083711816614594, -4.145494646314502}, {
     5.0903825983469115`, -4.201775477291383}}]}, 
   {Hue[0.6248554449991623], AbsoluteThickness[0.5], 
    LineBox[{{5.0903825983469115`, -4.201775477291383}, {
     5.156763285825094, -4.3336637715719535`}}]}, 
   {Hue[0.5886713023830277], AbsoluteThickness[0.5], 
    LineBox[{{2.6593738488259104`, -1.2930771849225233`}, {
     2.6041146052597184`, -1.4202530720949884`}}]}, 
   {Hue[0.5894576807193684], AbsoluteThickness[0.5], 
    LineBox[{{2.6041146052597184`, -1.4202530720949884`}, {
     2.4819550675434985`, -1.6506481239259634`}}]}, 
   {Hue[0.6628939258450819], AbsoluteThickness[0.5], 
    LineBox[{{6.913487041955967, -0.6107996390954793}, {
     6.89733561700219, -0.7372512684118521}}]}, 
   {Hue[0.6661435166142415], AbsoluteThickness[0.5], 
    LineBox[{{6.89733561700219, -0.7372512684118521}, {
     6.840156331745918, -0.9230251212024825}}]}, 
   {Hue[0.500619801008993], AbsoluteThickness[0.5], 
    LineBox[{{8.158989313164788, -0.05791745175011909}, {
     8.179627834529063, -0.08894125498794164}}]}, 
   {Hue[0.5010476633572788], AbsoluteThickness[0.5], 
    LineBox[{{8.179627834529063, -0.08894125498794164}, {
     8.367088356561416, -0.3746126053750917}}]}, 
   {Hue[0.5585899481517089], AbsoluteThickness[0.5], 
    LineBox[{{2.576228232959433, 2.778863057263447}, {2.3318542372304174`, 
     2.7765992419725833`}}]}, 
   {Hue[0.5590166815189384], AbsoluteThickness[0.5], 
    LineBox[{{2.3318542372304174`, 2.7765992419725833`}, {2.071265717306184, 
     2.7752704039276375`}}]}, 
   {Hue[0.6049175562062387], AbsoluteThickness[0.5], 
    LineBox[{{6.1240205160931875`, 1.4044319741249232`}, {6.122867288008741, 
     1.402433254956149}}]}, 
   {Hue[0.6098655179936077], AbsoluteThickness[0.5], 
    LineBox[{{6.122867288008741, 1.402433254956149}, {6.060805165975804, 
     1.2171244957969503`}}]}, 
   {Hue[0.499759363091885], AbsoluteThickness[0.5], 
    LineBox[{{7.660085761568094, 1.991639475688847}, {7.708794871856945, 
     1.9041472417206553`}}]}, 
   {Hue[0.5002094915945762], AbsoluteThickness[0.5], 
    LineBox[{{7.708794871856945, 1.9041472417206553`}, {7.870768948804756, 
     1.597722354156475}}]}, 
   {Hue[0.6014256964352431], AbsoluteThickness[0.5], 
    LineBox[{{6.32537587746439, 2.9715059207034944`}, {6.279733738543502, 
     2.9326515214838618`}}]}, 
   {Hue[0.6020476970464439], AbsoluteThickness[0.5], 
    LineBox[{{6.279733738543502, 2.9326515214838618`}, {6.057473603887017, 
     2.7195236185863134`}}]}, 
   {Hue[0.6021804165808347], AbsoluteThickness[0.5], 
    LineBox[{{6.325383143333483, 2.9707127390400045`}, {6.280422371978424, 
     2.932352719027345}}]}, 
   {Hue[0.6027965924744236], AbsoluteThickness[0.5], 
    LineBox[{{6.280422371978424, 2.932352719027345}, {6.057778744430611, 
     2.718731591933424}}]}, 
   {Hue[0.5801142233129267], AbsoluteThickness[0.5], 
    LineBox[{{4.070921077963201, 3.2970942111012103`}, {3.9419703784414537`, 
     3.3173988353408728`}}]}, 
   {Hue[0.5807747622256718], AbsoluteThickness[0.5], 
    LineBox[{{3.9419703784414537`, 3.3173988353408728`}, {3.6344031295273584`,
      3.3457667530564503`}}]}, 
   {Hue[0.5100273705488537], AbsoluteThickness[0.5], 
    LineBox[{{7.541237704228514, 0.29728744001578383`}, {7.581866004336178, 
     0.2074620731590467}}]}, 
   {Hue[0.5172014993572187], AbsoluteThickness[0.5], 
    LineBox[{{7.581866004336178, 0.2074620731590467}, {7.703408009658129, 
     0.04804660215171214}}]}, 
   {Hue[0.5593402032974515], AbsoluteThickness[0.5], 
    LineBox[{{6.236768542904116, -0.9194868360831555}, {
     6.219191332398124, -1.0805559059187888`}}]}, 
   {Hue[0.5600418921897932], AbsoluteThickness[0.5], 
    LineBox[{{6.219191332398124, -1.080555905918789}, {
     6.207216824471388, -1.3821793664575344`}}]}, 
   {Hue[0.6913123625853533], AbsoluteThickness[0.5], 
    LineBox[{{5.8743858822338515`, -0.06740588598618102}, {
     5.867437433419874, -0.19727646230711873`}}]}, 
   {Hue[0.6925948506884637], AbsoluteThickness[0.5], 
    LineBox[{{5.867437433419874, -0.19727646230711873`}, {
     5.832253426120939, -0.40920902314885765`}}]}, 
   {Hue[0.6516689752732299], AbsoluteThickness[0.5], 
    LineBox[{{6.599699214104081, -2.070427420410414}, {
     6.667297676623416, -2.135477143486397}}]}, 
   {Hue[0.6521301734350624], AbsoluteThickness[0.5], 
    LineBox[{{6.667297676623416, -2.135477143486397}, {
     6.884703476767587, -2.3340057301473056`}}]}, 
   {Hue[0.5213844097760256], AbsoluteThickness[0.5], 
    LineBox[{{3.137994040881305, 2.1908355687382985`}, {2.8902082002353473`, 
     2.224977801321209}}]}, 
   {Hue[0.5218104185022251], AbsoluteThickness[0.5], 
    LineBox[{{2.8902082002353473`, 2.224977801321209}, {2.536999264163651, 
     2.274275053629753}}]}, 
   {Hue[0.6213668176645732], AbsoluteThickness[0.5], 
    LineBox[{{4.438669232612174, -2.171901738027648}, {
     4.266132687031081, -2.5905576268305146`}}]}, 
   {Hue[0.6222024242053349], AbsoluteThickness[0.5], 
    LineBox[{{4.266132687031081, -2.5905576268305146`}, {
     4.1561096230708445`, -2.805583895232883}}]}, 
   {Hue[0.620278729373126], AbsoluteThickness[0.5], 
    LineBox[{{2.6100171321598715`, -2.050953332835073}, {
     2.604204242326641, -2.0909656804118164`}}]}, 
   {Hue[0.6220030762056996], AbsoluteThickness[0.5], 
    LineBox[{{2.604204242326641, -2.0909656804118164`}, {
     2.6008087458995384`, -2.332969908019844}}]}, 
   {Hue[0.5445415889573764], AbsoluteThickness[0.5], 
    LineBox[{{5.144332398712329, 0.9112951667036241}, {5.163912527337722, 
     0.8878013803209809}}]}, 
   {Hue[0.5449876862702389], AbsoluteThickness[0.5], 
    LineBox[{{5.163912527337722, 0.8878013803209809}, {5.351678461717469, 
     0.6531798138207725}}]}, 
   {Hue[0.6260857667471892], AbsoluteThickness[0.5], 
    LineBox[{{3.1019228176940237`, -1.3660763134177214`}, {
     3.1006854573032157`, -1.3710885364872003`}}]}, 
   {Hue[0.6265930956133281], AbsoluteThickness[0.5], 
    LineBox[{{3.1006854573032157`, -1.3710885364872003`}, {
     3.013870251880679, -1.6716013556489617`}}]}, 
   {Hue[0.6013998761839752], AbsoluteThickness[0.5], 
    LineBox[{{3.2908890461004017`, -2.351180740694631}, {
     3.2921389113393262`, -2.586314136598829}}]}, 
   {Hue[0.601925042622614], AbsoluteThickness[0.5], 
    LineBox[{{3.2921389113393262`, -2.586314136598829}, {
     3.2801742418737287`, -2.90292690580947}}]}, 
   {Hue[0.5562569441445562], AbsoluteThickness[0.5], 
    LineBox[{{6.80363511272709, -4.393798477068168}, {
     6.826924484557559, -4.43024495734332}}]}, 
   {Hue[0.5569838322230746], AbsoluteThickness[0.5], 
    LineBox[{{6.826924484557559, -4.43024495734332}, {
     7.0239771913713165`, -4.694715334178262}}]}, 
   {Hue[0.5663424890408756], AbsoluteThickness[0.5], 
    LineBox[{{7.852175989175377, 3.355959722212503}, {7.870094034013028, 
     3.3641295739796013`}}]}, 
   {Hue[0.5669269812907354], AbsoluteThickness[0.5], 
    LineBox[{{7.870094034013028, 3.3641295739796013`}, {8.13990032539598, 
     3.5051011365688627`}}]}, 
   {Hue[0.5156683536394745], AbsoluteThickness[0.5], 
    LineBox[{{7.311324516671275, -3.913297926926461}, {
     7.3627746279259, -3.970700945459805}}]}, 
   {Hue[0.5188443033764321], AbsoluteThickness[0.5], 
    LineBox[{{7.3627746279259, -3.970700945459805}, {
     7.489474724603615, -4.071081278785943}}]}, 
   {Hue[0.6308692331537546], AbsoluteThickness[0.5], 
    LineBox[{{5.871212731829672, -3.543939326356616}, {
     5.727366794389693, -3.609618432394761}}]}, 
   {Hue[0.6481707117372337], AbsoluteThickness[0.5], 
    LineBox[{{5.727366794389693, -3.609618432394761}, {
     5.603251542097308, -3.7191275131110295`}}]}, 
   {Hue[0.6192764348380708], AbsoluteThickness[0.5], 
    LineBox[{{6.9023591406331, -3.796830652540959}, {
     6.92746984326231, -3.8639959164697024`}}]}, 
   {Hue[0.6197075639585785], AbsoluteThickness[0.5], 
    LineBox[{{6.92746984326231, -3.8639959164697024`}, {
     7.039250850505489, -4.153945232996375}}]}, 
   {Hue[0.4968108666130911], AbsoluteThickness[0.5], 
    LineBox[{{6.381582789046667, -4.129511876999055}, {
     6.365986819051299, -4.1854625796552565`}}]}, 
   {Hue[0.4976948014914067], AbsoluteThickness[0.5], 
    LineBox[{{6.365986819051299, -4.1854625796552565`}, {
     6.262257890411295, -4.4628400756510835`}}]}, 
   {Hue[0.6623597432131492], AbsoluteThickness[0.5], 
    LineBox[{{6.086546351166646, -3.6712760709133776`}, {
     5.906723986612602, -3.737056573148718}}]}, 
   {Hue[0.6628105770232309], AbsoluteThickness[0.5], 
    LineBox[{{5.906723986612602, -3.737056573148718}, {
     5.614866408966126, -3.836583952122601}}]}, 
   {Hue[0.6567055378280974], AbsoluteThickness[0.5], 
    LineBox[{{7.6151470245621935`, -3.616472540687838}, {
     7.615222511804742, -3.6164888254527585`}}]}, 
   {Hue[0.6572811990098109], AbsoluteThickness[0.5], 
    LineBox[{{7.615222511804742, -3.6164888254527585`}, {
     7.889527662878461, -3.690855882716071}}]}, 
   {Hue[0.582429023378351], AbsoluteThickness[0.5], 
    LineBox[{{5.349415346524624, -3.4233382997347994`}, {
     5.160372614666836, -3.535819114894998}}]}, 
   {Hue[0.58388354807664], AbsoluteThickness[0.5], 
    LineBox[{{5.160372614666836, -3.535819114894998}, {
     4.929182404960507, -3.638366311205012}}]}, 
   {Hue[0.6826411404501708], AbsoluteThickness[0.5], 
    LineBox[{{3.406687868964709, -4.357682820256416}, {
     3.402986248374862, -4.382044042525229}}]}, 
   {Hue[0.683266518230561], AbsoluteThickness[0.5], 
    LineBox[{{3.402986248374862, -4.382044042525229}, {
     3.3742235017671405`, -4.696746927710387}}]}, 
   {Hue[0.4760203613368493], AbsoluteThickness[0.5], 
    LineBox[{{8.130494833710449, 3.11204376697034}, {8.145543566611257, 
     3.1086418039590713`}}]}, 
   {Hue[0.4851482958152923], AbsoluteThickness[0.5], 
    LineBox[{{8.145543566611257, 3.1086418039590713`}, {8.321412038743945, 
     3.1125416921353892`}}]}, 
   {Hue[0.6750633683799208], AbsoluteThickness[0.5], 
    LineBox[{{5.627522106718701, 3.8427191085072376`}, {5.394534826188597, 
     3.8276487820146126`}}]}, 
   {Hue[0.6755767778922593], AbsoluteThickness[0.5], 
    LineBox[{{5.394534826188597, 3.8276487820146126`}, {5.0606960747944525`, 
     3.792408825410699}}]}, 
   {Hue[0.6070683378291993], AbsoluteThickness[0.5], 
    LineBox[{{5.383819168512068, 0.7056745150359914}, {5.4173300053456295`, 
     0.6680861581475823}}]}, 
   {Hue[0.607563975211383], AbsoluteThickness[0.5], 
    LineBox[{{5.4173300053456295`, 0.6680861581475823}, {5.63566326846503, 
     0.40447144656459033`}}]}, 
   {Hue[0.542092752850178], AbsoluteThickness[0.5], 
    LineBox[{{6.309615612953485, 2.642461401938074}, {6.343399804617717, 
     2.6269760558811197`}}]}, 
   {Hue[0.5426003117300856], AbsoluteThickness[0.5], 
    LineBox[{{6.343399804617717, 2.6269760558811197`}, {6.631347575578011, 
     2.4810552737437255`}}]}, 
   {Hue[0.5983140903108496], AbsoluteThickness[0.5], 
    LineBox[{{5.364814184513919, 1.1395778115275113`}, {5.395550404225942, 
     1.106867904802044}}]}, 
   {Hue[0.5987399791759596], AbsoluteThickness[0.5], 
    LineBox[{{5.395550404225942, 1.106867904802044}, {5.624370367594265, 
     0.8629498577615555}}]}, 
   {Hue[0.6324877396607358], AbsoluteThickness[0.5], 
    LineBox[{{5.8367488458582315`, -0.8548696119196835}, {
     5.888600847923837, -0.9195026197470805}}]}, 
   {Hue[0.6330881975485559], AbsoluteThickness[0.5], 
    LineBox[{{5.888600847923837, -0.9195026197470805}, {
     6.07801876148019, -1.1302165045389283`}}]}, 
   {Hue[0.40473699585306505`], AbsoluteThickness[0.5], 
    LineBox[{{5.214825389274107, -0.9104432563716474}, {
     5.334491465386138, -1.0258692911626035`}}]}, 
   {Hue[0.40598884432283233`], AbsoluteThickness[0.5], 
    LineBox[{{5.334491465386138, -1.0258692911626035`}, {
     5.535451838398299, -1.1811554162161833`}}]}, 
   {Hue[0.4883496672838604], AbsoluteThickness[0.5], 
    LineBox[{{6.245500766226435, 0.1303209000596991}, {6.342146624766196, 
     0.0042216818509222855`}}]}, 
   {Hue[0.4936128652893492], AbsoluteThickness[0.5], 
    LineBox[{{6.342146624766196, 0.0042216818509222855`}, {
     6.492165487288916, -0.12534943730385134`}}]}, 
   {Hue[0.6958506560559444], AbsoluteThickness[0.5], 
    LineBox[{{3.8932499823145847`, -1.1202604420727047`}, {
     3.9878900155312884`, -1.3438414589196026`}}]}, 
   {Hue[0.6964709283992299], AbsoluteThickness[0.5], 
    LineBox[{{3.9878900155312884`, -1.3438414589196026`}, {
     4.069692726586191, -1.5740146171322618`}}]}, 
   {Hue[0.5417938118530152], AbsoluteThickness[0.5], 
    LineBox[{{7.923327375963976, 3.8097561171301613`}, {8.080947888856896, 
     3.769134514243339}}]}, 
   {Hue[0.5423003970514747], AbsoluteThickness[0.5], 
    LineBox[{{8.080947888856896, 3.769134514243339}, {8.491652828617568, 
     3.6802223154970233`}}]}, 
   {Hue[0.5152984732442906], AbsoluteThickness[0.5], 
    LineBox[{{5.699220542120158, -1.8759377065215141`}, {
     5.704087499349172, -2.1106228893457946`}}]}, 
   {Hue[0.5157295720787053], AbsoluteThickness[0.5], 
    LineBox[{{5.704087499349172, -2.1106228893457946`}, {
     5.7074270169805095`, -2.426305985591439}}]}, 
   {Hue[0.6218326262927354], AbsoluteThickness[0.5], 
    LineBox[{{2.8911720077417504`, -0.10381883717983781`}, {
     2.866785277310495, -0.1283211702870097}}]}, 
   {Hue[0.6222671753413618], AbsoluteThickness[0.5], 
    LineBox[{{2.866785277310495, -0.1283211702870097}, {
     2.6495586149342545`, -0.3523567257319539}}]}, 
   {Hue[0.6054900595643202], AbsoluteThickness[0.5], 
    LineBox[{{4.3540554618427265`, 0.9298355122021543}, {4.327967909828327, 
     0.8959076646911858}}]}, 
   {Hue[0.6059612319602989], AbsoluteThickness[0.5], 
    LineBox[{{4.327967909828327, 0.8959076646911858}, {4.138471530475225, 
     0.6337987915180525}}]}, 
   {Hue[0.6371643559755736], AbsoluteThickness[0.5], 
    LineBox[{{6.105472351067921, 1.1523049405410153`}, {6.095190424813283, 
     1.117457500678739}}]}, 
   {Hue[0.6375909030736869], AbsoluteThickness[0.5], 
    LineBox[{{6.095190424813283, 1.117457500678739}, {5.999332355927682, 
     0.7969463744818078}}]}, 
   {Hue[0.6645626956900077], AbsoluteThickness[0.5], 
    LineBox[{{5.542364330642674, 2.7986175425247923`}, {5.389845797393381, 
     2.726504885047324}}]}, 
   {Hue[0.6651701410042786], AbsoluteThickness[0.5], 
    LineBox[{{5.389845797393381, 2.726504885047324}, {5.1527156129385885`, 
     2.630544908827115}}]}, 
   {Hue[0.6216183218708485], AbsoluteThickness[0.5], 
    LineBox[{{4.620087209872344, 3.278411453925016}, {4.435420630173775, 
     3.3037918697638244`}}]}, 
   {Hue[0.6220886976702376], AbsoluteThickness[0.5], 
    LineBox[{{4.435420630173775, 3.3037918697638244`}, {4.079548642068997, 
     3.3421302901625793`}}]}, 
   {Hue[0.6237790499027611], AbsoluteThickness[0.5], 
    LineBox[{{5.089718268161514, 0.7445079973178222}, {5.035544450815711, 
     0.6943928214803506}}]}, 
   {Hue[0.6250420828538138], AbsoluteThickness[0.5], 
    LineBox[{{5.035544450815711, 0.6943928214803506}, {4.877231600589201, 
     0.5117766354533423}}]}, 
   {Hue[0.6102358579680829], AbsoluteThickness[0.5], 
    LineBox[{{2.318041721433721, 3.052051871801317}, {2.113309287780597, 
     3.0730865153611227`}}]}, 
   {Hue[0.6128396918426542], AbsoluteThickness[0.5], 
    LineBox[{{2.113309287780597, 3.0730865153611227`}, {1.9325852525149245`, 
     3.0632178453598473`}}]}, 
   {Hue[0.6238137013858855], AbsoluteThickness[0.5], 
    LineBox[{{3.938283698466122, 0.3908842974101462}, {3.8927855577958077`, 
     0.31736739115508755`}}]}, 
   {Hue[0.6243437328427037], AbsoluteThickness[0.5], 
    LineBox[{{3.8927855577958077`, 0.31736739115508755`}, {
     3.7185360029406773`, 0.06171541703321498}}]}, 
   {Hue[0.6448517251182869], AbsoluteThickness[0.5], 
    LineBox[{{2.5944206583869787`, -1.843662876519331}, {
     2.5939405878414212`, -1.8508050900555166`}}]}, 
   {Hue[0.6460775931447967], AbsoluteThickness[0.5], 
    LineBox[{{2.5939405878414212`, -1.8508050900555166`}, {
     2.5489895992890736`, -2.1047151263232498`}}]}, 
   {Hue[0.6834232464979113], AbsoluteThickness[0.5], 
    LineBox[{{5.1096505316662615`, -4.129265422351729}, {
     5.111524998490077, -4.134301612446678}}]}, 
   {Hue[0.6843960115200011], AbsoluteThickness[0.5], 
    LineBox[{{5.111524998490077, -4.134301612446678}, {
     5.21849177025518, -4.356328899681455}}]}, 
   {Hue[0.6234362679160972], AbsoluteThickness[0.5], 
    LineBox[{{7.078435876499311, -3.1015598020127157`}, {
     7.092400231731464, -3.144968545601297}}]}, 
   {Hue[0.6241743871246758], AbsoluteThickness[0.5], 
    LineBox[{{7.092400231731464, -3.144968545601297}, {
     7.200174263904642, -3.4115834804259024`}}]}, 
   {Hue[0.6159038566973319], AbsoluteThickness[0.5], 
    LineBox[{{7.632665524876749, 1.5933143457950287`}, {7.643933893993814, 
     1.6120545816067393`}}]}, 
   {Hue[0.6163702045042743], AbsoluteThickness[0.5], 
    LineBox[{{7.643933893993814, 1.6120545816067393`}, {7.829333096227265, 
     1.9017419001810434`}}]}, 
   {Hue[0.6324538076112695], AbsoluteThickness[0.5], 
    LineBox[{{7.243816924659211, -3.6861978945527274`}, {
     7.337323774164759, -3.5495782901857376`}}]}, 
   {Hue[0.6342421363894489], AbsoluteThickness[0.5], 
    LineBox[{{7.337323774164759, -3.5495782901857376`}, {
     7.488342833418298, -3.381770267529771}}]}, 
   {Hue[0.5939435897827421], AbsoluteThickness[0.5], 
    LineBox[{{7.606240752714355, 3.0572917106210094`}, {7.608417218499267, 
     3.167781272079977}}]}, 
   {Hue[0.5961061337182296], AbsoluteThickness[0.5], 
    LineBox[{{7.608417218499267, 3.167781272079977}, {7.644647879748138, 
     3.3859686087284717`}}]}, 
   {Hue[0.6646901080547009], AbsoluteThickness[0.5], 
    LineBox[{{2.8340800912329427`, -3.874946472042584}, {
     2.6991427066925873`, -4.04286539329482}}]}, 
   {Hue[0.6665864506347734], AbsoluteThickness[0.5], 
    LineBox[{{2.6991427066925873`, -4.04286539329482}, {
     2.5246480757808416`, -4.207886893050314}}]}, 
   {Hue[0.599860210760461], AbsoluteThickness[0.5], 
    LineBox[{{2.8387106544176817`, -4.034649028598426}, {
     2.8729443034108897`, -4.121121049620603}}]}, 
   {Hue[0.6024195643238656], AbsoluteThickness[0.5], 
    LineBox[{{2.8729443034108897`, -4.121121049620603}, {
     2.9227982160179797`, -4.342862234475462}}]}, 
   {Hue[0.5381866364021602], AbsoluteThickness[0.5], 
    LineBox[{{6.775239153259096, -3.9259373130475024`}, {
     6.840225235231438, -3.9799874124023624`}}]}, 
   {Hue[0.538901097493014], AbsoluteThickness[0.5], 
    LineBox[{{6.840225235231438, -3.9799874124023624`}, {
     7.066572118463241, -4.142731300267221}}]}, 
   {Hue[0.5720398123066978], AbsoluteThickness[0.5], 
    LineBox[{{2.995513837179193, 3.1913138537350196`}, {2.9139436727469197`, 
     3.411226511080124}}]}, 
   {Hue[0.5747790955703987], AbsoluteThickness[0.5], 
    LineBox[{{2.9139436727469197`, 3.411226511080124}, {2.8727990606433753`, 
     3.6196178892045157`}}]}, 
   {Hue[0.583309900669888], AbsoluteThickness[0.5], 
    LineBox[{{8.334429269146463, -1.8359994485996693`}, {
     8.237615182389757, -2.064713183579697}}]}, 
   {Hue[0.5838871847987461], AbsoluteThickness[0.5], 
    LineBox[{{8.237615182389757, -2.064713183579697}, {
     8.12967530025782, -2.3623625924030676`}}]}, 
   {Hue[0.6586983709757384], AbsoluteThickness[0.5], 
    LineBox[{{7.324342525977599, -1.511069363246536}, {
     7.084910015710377, -1.577017483726423}}]}, 
   {Hue[0.6596335043405519], AbsoluteThickness[0.5], 
    LineBox[{{7.084910015710377, -1.577017483726423}, {
     6.845850173832062, -1.6202311905802698`}}]}, 
   {Hue[0.6925619905507823], AbsoluteThickness[0.5], 
    LineBox[{{6.977504011886045, 2.174057454003598}, {6.920110379973352, 
     2.2243476038123458`}}]}, 
   {Hue[0.6935836374183647], AbsoluteThickness[0.5], 
    LineBox[{{6.920110379973352, 2.2243476038123458`}, {6.7496263124307445`, 
     2.346973220463829}}]}, 
   {Hue[0.6878725977826747], AbsoluteThickness[0.5], 
    LineBox[{{7.624300977912175, -1.2898988057754643`}, {
     7.577531074682716, -1.3894069334505808`}}]}, 
   {Hue[0.6883377648730754], AbsoluteThickness[0.5], 
    LineBox[{{7.577531074682716, -1.3894069334505808`}, {
     7.439106500816046, -1.6640125000315449`}}]}, 
   {Hue[0.5083718327669132], AbsoluteThickness[0.5], 
    LineBox[{{7.353286851739628, -1.4157762403458516`}, {
     7.3544788873245635`, -1.4205548569771693`}}]}, 
   {Hue[0.5098928998543656], AbsoluteThickness[0.5], 
    LineBox[{{7.3544788873245635`, -1.4205548569771693`}, {
     7.380635155024043, -1.6333231843665383`}}]}, 
   {Hue[0.6603398620226857], AbsoluteThickness[0.5], 
    LineBox[{{5.341437726948885, -0.5852316572884696}, {
     5.302404848500758, -0.6466417457863961}}]}, 
   {Hue[0.6607747521113684], AbsoluteThickness[0.5], 
    LineBox[{{5.302404848500758, -0.6466417457863961}, {
     5.140825486719869, -0.8935282559203496}}]}, 
   {Hue[0.6734533413189081], AbsoluteThickness[0.5], 
    LineBox[{{3.9369298921301183`, 2.105193170765109}, {3.7885749987215447`, 
     2.118352275389838}}]}, 
   {Hue[0.6747152347299901], AbsoluteThickness[0.5], 
    LineBox[{{3.7885749987215447`, 2.118352275389838}, {3.582825726935251, 
     2.159732603011195}}]}, 
   {Hue[0.6578750486600698], AbsoluteThickness[0.5], 
    LineBox[{{4.166332242020228, 2.3976217938655116`}, {4.1504450759573155`, 
     2.3986958458377172`}}]}, 
   {Hue[0.6588124697139796], AbsoluteThickness[0.5], 
    LineBox[{{4.1504450759573155`, 2.3986958458377172`}, {3.8673941461262373`,
      2.443679911372603}}]}, 
   {Hue[0.670728085584785], AbsoluteThickness[0.5], 
    LineBox[{{5.976967796365814, -0.14727286201191875`}, {
     5.898898703049188, -0.2530634281576685}}]}, 
   {Hue[0.6716828181919887], AbsoluteThickness[0.5], 
    LineBox[{{5.898898703049188, -0.2530634281576685}, {
     5.747337534014557, -0.4234074682555766}}]}, 
   {Hue[0.5554478491747591], AbsoluteThickness[0.5], 
    LineBox[{{7.529709983347873, -0.19289718336638262`}, {
     7.596262488865814, -0.3850982387363096}}]}, 
   {Hue[0.5662219738031401], AbsoluteThickness[0.5], 
    LineBox[{{7.596262488865814, -0.3850982387363096}, {
     7.6092045723493005`, -0.5545651886532563}}]}, 
   {Hue[0.5305021954251504], AbsoluteThickness[0.5], 
    LineBox[{{7.508174570221676, 3.1000610347106634`}, {7.383234037006223, 
     3.2583521559237294`}}]}, 
   {Hue[0.5325839428669712], AbsoluteThickness[0.5], 
    LineBox[{{7.383234037006223, 3.2583521559237294`}, {7.204861113512161, 
     3.4279605084327196`}}]}, 
   {Hue[0.6029408598896348], AbsoluteThickness[0.5], 
    LineBox[{{6.343531270821802, 3.047626479215385}, {6.3376797364591875`, 
     3.073926821062652}}]}, 
   {Hue[0.6033846622047765], AbsoluteThickness[0.5], 
    LineBox[{{6.3376797364591875`, 3.073926821062652}, {6.260056484791117, 
     3.3943918755810785`}}]}, 
   {Hue[0.6001037218698074], AbsoluteThickness[0.5], 
    LineBox[{{5.073849018752725, 2.229368526730973}, {4.8786696851856926`, 
     2.317440942054847}}]}, 
   {Hue[0.6015079814228483], AbsoluteThickness[0.5], 
    LineBox[{{4.8786696851856926`, 2.317440942054847}, {4.643787737142121, 
     2.391881696125663}}]}, 
   {Hue[0.6194315035336746], AbsoluteThickness[0.5], 
    LineBox[{{6.521907817182187, -1.1425161133586363`}, {
     6.496431126237164, -1.3899785698138718`}}]}, 
   {Hue[0.619997836700362], AbsoluteThickness[0.5], 
    LineBox[{{6.496431126237164, -1.3899785698138718`}, {
     6.482689160232547, -1.6547322774824422`}}]}, 
   {Hue[0.6912394343249775], AbsoluteThickness[0.5], 
    LineBox[{{7.705234316539079, 2.9285293916648074`}, {7.838500987730043, 
     3.1478173430544873`}}]}, 
   {Hue[0.6045823701411019], AbsoluteThickness[0.5], 
    LineBox[{{6.121673836900843, -1.8804994787920926`}, {
     6.00453104713107, -2.0825467007885563`}}]}, 
   {Hue[0.4625772657544126], AbsoluteThickness[0.5], 
    LineBox[{{7.832735015989198, -1.9286080583021337`}, {
     7.863249776218835, -1.999409063885954}}]}, 
   {Hue[0.47407251500333675`], AbsoluteThickness[0.5], 
    LineBox[{{7.863249776218835, -1.999409063885954}, {
     7.962873987838886, -2.1253988731939986`}}]}, 
   {Hue[0.5469584332873686], AbsoluteThickness[0.5], 
    LineBox[{{3.381785206595015, -0.9500355551792761}, {
     3.0992063393991534`, -1.062083839125182}}]}, 
   {Hue[0.5487624979443171], AbsoluteThickness[0.5], 
    LineBox[{{3.0992063393991534`, -1.062083839125182}, {
     2.8904050259831595`, -1.1141449940680594`}}]}, 
   {Hue[0.6812293003560609], AbsoluteThickness[0.5], 
    LineBox[{{4.414665050307726, 1.3990961048210333`}, {4.118312967904865, 
     1.6021552622006519`}}]}, 
   {Hue[0.6506338746420879], AbsoluteThickness[0.5], 
    LineBox[{{4.886892221043563, -0.9898714097928788}, {
     4.837071454590036, -1.120748514822409}}]}, 
   {Hue[0.6514305777302307], AbsoluteThickness[0.5], 
    LineBox[{{4.837071454590036, -1.120748514822409}, {
     4.719762777538782, -1.3684374927220562`}}]}, 
   {Hue[0.5953033923096408], AbsoluteThickness[0.5], 
    LineBox[{{3.4493430546787973`, -0.6762515234235578}, {
     3.3742240549990807`, -0.7779321935254505}}]}, 
   {Hue[0.59723692029523], AbsoluteThickness[0.5], 
    LineBox[{{3.3742240549990807`, -0.7779321935254505}, {
     3.210211863053803, -0.9457604212523338}}]}, 
   {Hue[0.6934826878343179], AbsoluteThickness[0.5], 
    LineBox[{{5.155932782359881, -4.333118346270187}, {
     5.110049055819271, -4.412028490117641}}]}, 
   {Hue[0.6940959383938377], AbsoluteThickness[0.5], 
    LineBox[{{5.110049055819271, -4.412028490117641}, {
     4.94269924349137, -4.6648877660039965`}}]}, 
   {Hue[0.43562776817589544`], AbsoluteThickness[0.5], 
    LineBox[{{5.761747095208018, -4.421095011046312}, {
     5.833906094536374, -4.455031281707051}}]}, 
   {Hue[0.4360562126190551], AbsoluteThickness[0.5], 
    LineBox[{{5.833906094536374, -4.455031281707051}, {
     6.145547850246446, -4.6043238095271075`}}]}, 
   {Hue[0.6554867694858825], AbsoluteThickness[0.5], 
    LineBox[{{8.178263851490088, -0.9684416026621805}, {
     8.25268631542281, -0.9381517748579774}}]}, 
   {Hue[0.6591499792775262], AbsoluteThickness[0.5], 
    LineBox[{{8.25268631542281, -0.9381517748579774}, {
     8.447945665973808, -0.8140697957836572}}]}, 
   {Hue[0.6477527834820354], AbsoluteThickness[0.5], 
    LineBox[{{8.072695612833158, 0.12966087382778554`}, {8.072303920169732, 
     0.16835206583190912`}}]}, 
   {Hue[0.6611048348227703], AbsoluteThickness[0.5], 
    LineBox[{{8.072303920169732, 0.16835206583190912`}, {8.117415494108787, 
     0.33541963584986956`}}]}, 
   {Hue[0.5601313186579148], AbsoluteThickness[0.5], 
    LineBox[{{4.407069581962368, 3.594081478125723}, {4.378060462600589, 
     3.724838818750329}}]}, 
   {Hue[0.5635545530873444], AbsoluteThickness[0.5], 
    LineBox[{{2.123718354849669, -1.7357571562527376`}, {
     2.031977727468466, -1.7799208982345756`}}]}, 
   {Hue[0.5682390152597703], AbsoluteThickness[0.5], 
    LineBox[{{2.031977727468466, -1.7799208982345756`}, {
     1.8610135905386578`, -1.90854730665057}}]}, 
   {Hue[0.5774780814112558], AbsoluteThickness[0.5], 
    LineBox[{{3.62205526617613, -2.8633204609321807`}, {
     3.6215701971233276`, -2.8765175036658652`}}]}, 
   {Hue[0.5802277108028496], AbsoluteThickness[0.5], 
    LineBox[{{3.6215701971233276`, -2.8765175036658652`}, {
     3.578676367639576, -3.091155362120867}}]}, 
   {Hue[0.4508181333989969], AbsoluteThickness[0.5], 
    LineBox[{{7.582072730470732, -0.5893620531666515}, {
     7.645117048507147, -0.6511406668349511}}]}, 
   {Hue[0.45124685586969115`], AbsoluteThickness[0.5], 
    LineBox[{{7.645117048507147, -0.6511406668349511}, {
     7.855126564432227, -0.8538621350659643}}]}, 
   {Hue[0.6617547983597473], AbsoluteThickness[0.5], 
    LineBox[{{3.3712773081489127`, 2.9209939304071986`}, {3.192282605944833, 
     2.9875147780555555`}}]}, 
   {Hue[0.662180719716371], AbsoluteThickness[0.5], 
    LineBox[{{3.192282605944833, 2.9875147780555555`}, {2.8963147457212575`, 
     3.0971190840845253`}}]}, 
   {Hue[0.5378674241179002], AbsoluteThickness[0.5], 
    LineBox[{{3.6236936984178687`, 3.3234434251614515`}, {3.6023440895184624`,
      3.3338187418810814`}}]}, 
   {Hue[0.5386508397616787], AbsoluteThickness[0.5], 
    LineBox[{{3.6023440895184624`, 3.3338187418810814`}, {3.353229056610456, 
     3.479684235162389}}]}, 
   {Hue[0.44392164880909907`], AbsoluteThickness[0.5], 
    LineBox[{{7.053854609025802, 1.4201769265535833`}, {7.073356032890572, 
     1.3810485171728772`}}]}, 
   {Hue[0.4445632856676026], AbsoluteThickness[0.5], 
    LineBox[{{7.073356032890572, 1.3810485171728772`}, {7.190353661181457, 
     1.1047463072116575`}}]}, 
   {Hue[0.5810757704709396], AbsoluteThickness[0.5], 
    LineBox[{{5.8230317078827385`, 3.0640893620835405`}, {5.571606240479859, 
     3.094346096841242}}]}, 
   {Hue[0.5843058605693503], AbsoluteThickness[0.5], 
    LineBox[{{5.571606240479859, 3.0943460968412424`}, {5.410078480362247, 
     3.1427085144968765`}}]}, 
   {Hue[0.5323022433190037], AbsoluteThickness[0.5], 
    LineBox[{{7.506394396696632, 2.813919555485486}, {7.4639724405217, 
     2.6601898932271837`}}]}, 
   {Hue[0.5327731281461356], AbsoluteThickness[0.5], 
    LineBox[{{7.4639724405217, 2.6601898932271837`}, {7.367720676222741, 
     2.3475729216963095`}}]}, 
   {Hue[0.5845295118221647], AbsoluteThickness[0.5], 
    LineBox[{{8.076565246452969, 3.2339127688562757`}, {7.886042401994469, 
     3.2508858872213766`}}]}, 
   {Hue[0.5849564960948821], AbsoluteThickness[0.5], 
    LineBox[{{7.886042401994469, 3.2508858872213766`}, {7.579609168760798, 
     3.2796437937832055`}}]}, 
   {Hue[0.5854050482424821], AbsoluteThickness[0.5], 
    LineBox[{{8.097005192411306, 3.160379878025099}, {8.091933774620061, 
     3.1581666927779026`}}]}, 
   {Hue[0.5861516149961865], AbsoluteThickness[0.5], 
    LineBox[{{8.091933774620061, 3.1581666927779026`}, {7.844709541267707, 
     3.0713477083191605`}}]}, 
   {Hue[0.581986209464744], AbsoluteThickness[0.5], 
    LineBox[{{6.335825634537416, 2.4087158960677053`}, {6.298077858507061, 
     2.378923591762827}}]}, 
   {Hue[0.5855133315920216], AbsoluteThickness[0.5], 
    LineBox[{{6.298077858507061, 2.378923591762827}, {6.151205115380451, 
     2.300371118010761}}]}, 
   {Hue[0.542324656518416], AbsoluteThickness[0.5], 
    LineBox[{{4.439198819447457, 3.642069564449045}, {4.3707151176105885`, 
     3.676194780822109}}]}, 
   {Hue[0.5427715258050639], AbsoluteThickness[0.5], 
    LineBox[{{4.3707151176105885`, 3.676194780822109}, {4.112866587376991, 
     3.8112616455611974`}}]}, 
   {Hue[0.5414240477634027], AbsoluteThickness[0.5], 
    LineBox[{{6.070131265381225, -0.14795229775202326`}, {
     6.074453792384198, -0.19167232381328458`}}]}, 
   {Hue[0.5436420901193332], AbsoluteThickness[0.5], 
    LineBox[{{6.074453792384198, -0.1916723238132846}, {
     6.132131498680236, -0.42231781201897955`}}]}, 
   {Hue[0.6563985557185433], AbsoluteThickness[0.5], 
    LineBox[{{7.015615568848052, 0.29460547312310115`}, {7.0875212534388545`, 
     0.2104918141485232}}]}, 
   {Hue[0.6579759048020871], AbsoluteThickness[0.5], 
    LineBox[{{7.0875212534388545`, 0.2104918141485232}, {7.21877148902684, 
     0.09089025971375768}}]}, 
   {Hue[0.608912944245341], AbsoluteThickness[0.5], 
    LineBox[{{5.871203898410041, -0.06168178135465244}, {
     5.876135089765699, -0.20754753917220814`}}]}, 
   {Hue[0.6114241271090028], AbsoluteThickness[0.5], 
    LineBox[{{5.876135089765699, -0.20754753917220814`}, {
     5.85334823550192, -0.39530175298136316`}}]}, 
   {Hue[0.6929305328363561], AbsoluteThickness[0.5], 
    LineBox[{{4.929510524386582, 0.425575321871306}, {4.866271875228801, 
     0.2823955230595905}}]}, 
   {Hue[0.6978252961287823], AbsoluteThickness[0.5], 
    LineBox[{{4.866271875228801, 0.2823955230595905}, {4.7688390502492455`, 
     0.1445545652620225}}]}, 
   {Hue[0.6811330980900674], AbsoluteThickness[0.5], 
    LineBox[{{5.261561876287769, -0.3791617873073436}, {
     5.143318604126908, -0.45367966550443756`}}]}, 
   {Hue[0.681574607405429], AbsoluteThickness[0.5], 
    LineBox[{{5.143318604126908, -0.45367966550443756`}, {
     4.885114946348674, -0.6101584351666627}}]}, 
   {Hue[0.6404494582174156], AbsoluteThickness[0.5], 
    LineBox[{{7.615519205944208, 0.36099922939965134`}, {7.6613435758758595`, 
     0.3549167600868867}}]}, 
   {Hue[0.6423274024857639], AbsoluteThickness[0.5], 
    LineBox[{{7.6613435758758595`, 0.3549167600868867}, {7.903067938259836, 
     0.2886149924945818}}]}, 
   {Hue[0.5544222091460551], AbsoluteThickness[0.5], 
    LineBox[{{6.872510382750326, -3.8612445774118154`}, {
     6.886095538756343, -3.8925041741562776`}}]}, 
   {Hue[0.5549557510376854], AbsoluteThickness[0.5], 
    LineBox[{{6.886095538756343, -3.8925041741562776`}, {
     7.016407964865166, -4.15903831782656}}]}, 
   {Hue[0.65618591197593], AbsoluteThickness[0.5], 
    LineBox[{{6.870287339406849, -3.8641641797506416`}, {
     6.900674822582103, -3.880127369964327}}]}, 
   {Hue[0.6567938114054405], AbsoluteThickness[0.5], 
    LineBox[{{6.900674822582103, -3.880127369964327}, {
     7.147985198350537, -4.028674826976259}}]}, 
   {Hue[0.6577662747487233], AbsoluteThickness[0.5], 
    LineBox[{{5.156763285825094, -4.3336637715719535`}, {
     5.319041006739704, -4.486727857139798}}]}, 
   {Hue[0.6591292167264902], AbsoluteThickness[0.5], 
    LineBox[{{5.319041006739704, -4.486727857139798}, {
     5.538412725305849, -4.6504554065232595`}}]}, 
   {Hue[0.5902440590557091], AbsoluteThickness[0.5], 
    LineBox[{{2.4819550675434985`, -1.6506481239259634`}, {
     2.411101050976116, -1.7623771712179495`}}]}, 
   {Hue[0.6124625245101094], AbsoluteThickness[0.5], 
    LineBox[{{2.411101050976116, -1.7623771712179495`}, {
     2.2923390683512768`, -1.860477850389255}}]}, 
   {Hue[0.6693931073834013], AbsoluteThickness[0.5], 
    LineBox[{{6.840156331745918, -0.9230251212024825}, {
     6.826500453872797, -0.9498995455684857}}]}, 
   {Hue[0.6148134797809769], AbsoluteThickness[0.5], 
    LineBox[{{6.060805165975804, 1.2171244957969503`}, {6.049499241149078, 
     1.1256836499049956`}}]}, 
   {Hue[0.6152446689310117], AbsoluteThickness[0.5], 
    LineBox[{{6.049499241149078, 1.1256836499049956`}, {6.0119410880608575`, 
     0.7940571556182572}}]}, 
   {Hue[0.5006596200972673], AbsoluteThickness[0.5], 
    LineBox[{{7.870768948804756, 1.597722354156475}, {7.888751514466339, 
     1.5618361938710457`}}]}, 
   {Hue[0.5011634905943811], AbsoluteThickness[0.5], 
    LineBox[{{7.888751514466339, 1.5618361938710457`}, {8.01597157241524, 
     1.3305717242216883`}}]}, 
   {Hue[0.6026696976576449], AbsoluteThickness[0.5], 
    LineBox[{{6.057473603887017, 2.7195236185863134`}, {5.986498356153631, 
     2.6429052233082113`}}]}, 
   {Hue[0.6086189578544254], AbsoluteThickness[0.5], 
    LineBox[{{5.986498356153631, 2.6429052233082113`}, {5.88342624414638, 
     2.4686103759691127`}}]}, 
   {Hue[0.6034127683680126], AbsoluteThickness[0.5], 
    LineBox[{{6.057778744430611, 2.718731591933424}, {5.988035112096832, 
     2.643520695595911}}]}, 
   {Hue[0.6090693096996357], AbsoluteThickness[0.5], 
    LineBox[{{5.988035112096832, 2.643520695595911}, {5.883459705995046, 
     2.468327304112954}}]}, 
   {Hue[0.5814353011384169], AbsoluteThickness[0.5], 
    LineBox[{{3.6344031295273584`, 3.3457667530564503`}, {3.620122738284003, 
     3.346163392446979}}]}, 
   {Hue[0.5832633879599995], AbsoluteThickness[0.5], 
    LineBox[{{3.620122738284003, 3.346163392446979}, {3.379558515205473, 
     3.385423196915734}}]}, 
   {Hue[0.5243756281655838], AbsoluteThickness[0.5], 
    LineBox[{{7.703408009658129, 0.048046602151712144`}, {
     7.864013841511189, -0.0852527559746615}}]}, 
   {Hue[0.5310530167043127], AbsoluteThickness[0.5], 
    LineBox[{{7.864013841511189, -0.0852527559746615}, {
     8.032581829611344, -0.17116208422406284`}}]}, 
   {Hue[0.5607435810821347], AbsoluteThickness[0.5], 
    LineBox[{{6.207216824471388, -1.3821793664575344`}, {
     6.215810235160814, -1.6749902322397539`}}]}, 
   {Hue[0.5611775244543283], AbsoluteThickness[0.5], 
    LineBox[{{6.215810235160814, -1.6749902322397539`}, {
     6.219828900602508, -1.9150900243448221`}}]}, 
   {Hue[0.6938773387915741], AbsoluteThickness[0.5], 
    LineBox[{{5.832253426120939, -0.40920902314885765`}, {
     5.7864180675735595`, -0.5713019529883407}}]}, 
   {Hue[0.6943173670673063], AbsoluteThickness[0.5], 
    LineBox[{{5.7864180675735595`, -0.5713019529883407}, {
     5.709416493396021, -0.8620178950550683}}]}, 
   {Hue[0.6525913715968948], AbsoluteThickness[0.5], 
    LineBox[{{6.884703476767587, -2.3340057301473056`}, {
     6.885340783503449, -2.3345578522948944`}}]}, 
   {Hue[0.6530438260895999], AbsoluteThickness[0.5], 
    LineBox[{{6.885340783503449, -2.3345578522948944`}, {
     7.105502242140097, -2.5342313189210763`}}]}, 
   {Hue[0.5222364272284246], AbsoluteThickness[0.5], 
    LineBox[{{2.536999264163651, 2.274275053629753}, {2.3549609004467165`, 
     2.300006342914979}}]}, 
   {Hue[0.5232035568088041], AbsoluteThickness[0.5], 
    LineBox[{{2.3549609004467165`, 2.300006342914979}, {2.116605119891804, 
     2.311497092707608}}]}, 
   {Hue[0.6230380307460964], AbsoluteThickness[0.5], 
    LineBox[{{4.1561096230708445`, -2.805583895232883}, {
     4.088831977815843, -2.9141016860142086`}}]}, 
   {Hue[0.6234881346133665], AbsoluteThickness[0.5], 
    LineBox[{{4.088831977815843, -2.9141016860142086`}, {
     3.941179008481316, -3.1411014976104723`}}]}, 
   {Hue[0.6237274230382733], AbsoluteThickness[0.5], 
    LineBox[{{2.6008087458995384`, -2.332969908019844}, {
     2.601220694696248, -2.3364988480974}}]}, 
   {Hue[0.6245458673737689], AbsoluteThickness[0.5], 
    LineBox[{{2.601220694696248, -2.3364988480974}, {
     2.6112381929810637`, -2.617223922503814}}]}, 
   {Hue[0.5454337835831016], AbsoluteThickness[0.5], 
    LineBox[{{5.351678461717469, 0.6531798138207725}, {5.367154877029989, 
     0.6330336137653085}}]}, 
   {Hue[0.5458722435857792], AbsoluteThickness[0.5], 
    LineBox[{{5.367154877029989, 0.6330336137653085}, {5.5856727355978135`, 
     0.3576482797426801}}]}, 
   {Hue[0.627100424479467], AbsoluteThickness[0.5], 
    LineBox[{{3.013870251880679, -1.6716013556489617`}, {
     2.9304171253193854`, -1.9230608325446268`}}]}, 
   {Hue[0.6359798397376375], AbsoluteThickness[0.5], 
    LineBox[{{2.9304171253193854`, -1.9230608325446268`}, {
     2.9170262207093085`, -2.094356345222378}}]}, 
   {Hue[0.6024502090612531], AbsoluteThickness[0.5], 
    LineBox[{{3.2801742418737287`, -2.90292690580947}, {
     3.2608177205986233`, -3.1417917844119554`}}]}, 
   {Hue[0.6029010781786742], AbsoluteThickness[0.5], 
    LineBox[{{3.2608177205986233`, -3.1417917844119554`}, {
     3.2427603696725935`, -3.4485238725590546`}}]}, 
   {Hue[0.5675114735405951], AbsoluteThickness[0.5], 
    LineBox[{{8.13990032539598, 3.5051011365688627`}, {8.248994914860969, 
     3.5697801319893414`}}]}, 
   {Hue[0.5689712857771738], AbsoluteThickness[0.5], 
    LineBox[{{8.248994914860969, 3.5697801319893414`}, {8.516859731327582, 
     3.775382473228311}}]}, 
   {Hue[0.5220202531133897], AbsoluteThickness[0.5], 
    LineBox[{{7.489474724603615, -4.071081278785943}, {
     7.644214239056241, -4.155612800867108}}]}, 
   {Hue[0.5226990486225498], AbsoluteThickness[0.5], 
    LineBox[{{7.644214239056241, -4.155612800867108}, {
     7.869344381027741, -4.298769149958636}}]}, 
   {Hue[0.6654721903207135], AbsoluteThickness[0.5], 
    LineBox[{{5.603251542097308, -3.7191275131110295`}, {
     5.524279277646885, -3.8470141394015434`}}]}, 
   {Hue[0.6661598185680009], AbsoluteThickness[0.5], 
    LineBox[{{5.524279277646885, -3.8470141394015434`}, {
     5.392812119703785, -4.096019482239557}}]}, 
   {Hue[0.6201386930790862], AbsoluteThickness[0.5], 
    LineBox[{{7.039250850505489, -4.153945232996375}, {
     7.063649851543421, -4.215362564608466}}]}, 
   {Hue[0.6271420670814334], AbsoluteThickness[0.5], 
    LineBox[{{7.063649851543421, -4.215362564608466}, {
     7.168199915597048, -4.367194291247976}}]}, 
   {Hue[0.6632614108333127], AbsoluteThickness[0.5], 
    LineBox[{{5.614866408966126, -3.836583952122601}, {
     5.562232762163538, -3.8532471755165356`}}]}, 
   {Hue[0.6660668786279424], AbsoluteThickness[0.5], 
    LineBox[{{5.562232762163538, -3.8532471755165356`}, {
     5.371396807160023, -3.949809085911326}}]}, 
   {Hue[0.6578568601915242], AbsoluteThickness[0.5], 
    LineBox[{{7.889527662878461, -3.690855882716071}, {
     8.126407885147248, -3.7685730769439783`}}]}, 
   {Hue[0.6583685548251648], AbsoluteThickness[0.5], 
    LineBox[{{8.126407885147248, -3.7685730769439783`}, {
     8.415844440771576, -3.850807883571618}}]}, 
   {Hue[0.585338072774929], AbsoluteThickness[0.5], 
    LineBox[{{4.929182404960507, -3.638366311205012}, {
     4.8169604684811995`, -3.6728640852389334`}}]}, 
   {Hue[0.5859272313903653], AbsoluteThickness[0.5], 
    LineBox[{{4.8169604684811995`, -3.672864085238934}, {
     4.55465095500315, -3.7694016568520077`}}]}, 
   {Hue[0.6760901874045979], AbsoluteThickness[0.5], 
    LineBox[{{5.0606960747944525`, 3.792408825410699}, {4.921160431590899, 
     3.771926602891622}}]}, 
   {Hue[0.6765402803304541], AbsoluteThickness[0.5], 
    LineBox[{{4.921160431590899, 3.771926602891622}, {4.629008260561779, 
     3.7225390896858497`}}]}, 
   {Hue[0.6080596125935667], AbsoluteThickness[0.5], 
    LineBox[{{5.63566326846503, 0.40447144656459033`}, {5.68773960631045, 
     0.33672027121228465`}}]}, 
   {Hue[0.6087923710148112], AbsoluteThickness[0.5], 
    LineBox[{{5.68773960631045, 0.33672027121228465`}, {5.803108710693385, 
     0.16176495353043238`}}]}, 
   {Hue[0.5431078706099931], AbsoluteThickness[0.5], 
    LineBox[{{6.631347575578011, 2.4810552737437255`}, {7.050096841704011, 
     2.247758442592552}}]}, 
   {Hue[0.5439906836676075], AbsoluteThickness[0.5], 
    LineBox[{{7.050096841704011, 2.247758442592552}, {7.292391991774231, 
     2.1388661667030737`}}]}, 
   {Hue[0.5991658680410695], AbsoluteThickness[0.5], 
    LineBox[{{5.624370367594265, 0.8629498577615555}, {5.637119571476474, 
     0.8493368424241358}}]}, 
   {Hue[0.5996499521418256], AbsoluteThickness[0.5], 
    LineBox[{{5.637119571476474, 0.8493368424241358}, {5.845517805074358, 
     0.6411847580869643}}]}, 
   {Hue[0.6336886554363759], AbsoluteThickness[0.5], 
    LineBox[{{6.07801876148019, -1.1302165045389283`}, {
     6.128032380091881, -1.179936833422636}}]}, 
   {Hue[0.634305068441467], AbsoluteThickness[0.5], 
    LineBox[{{6.128032380091881, -1.179936833422636}, {
     6.36046649154151, -1.385467386754145}}]}, 
   {Hue[0.4072406927925999], AbsoluteThickness[0.5], 
    LineBox[{{5.535451838398299, -1.1811554162161833`}, {
     5.601638143066753, -1.2215893680721173`}}]}, 
   {Hue[0.40821498147911484`], AbsoluteThickness[0.5], 
    LineBox[{{5.601638143066753, -1.2215893680721173`}, {
     5.841522396781157, -1.3391428313563603`}}]}, 
   {Hue[0.49887606329483797`], AbsoluteThickness[0.5], 
    LineBox[{{6.492165487288916, -0.12534943730385134`}, {
     6.560041798937662, -0.16313170513686337`}}]}, 
   {Hue[0.4993044227346283], AbsoluteThickness[0.5], 
    LineBox[{{6.560041798937662, -0.16313170513686337`}, {
     6.849430144312218, -0.32156236612948885`}}]}, 
   {Hue[0.6970912007425154], AbsoluteThickness[0.5], 
    LineBox[{{4.069692726586191, -1.5740146171322618`}, {
     4.086534755432983, -1.6320324547495302`}}]}, 
   {Hue[0.6981762584530301], AbsoluteThickness[0.5], 
    LineBox[{{4.086534755432983, -1.6320324547495302`}, {
     4.197731824070849, -1.9083847657845558`}}]}, 
   {Hue[0.51616067091312], AbsoluteThickness[0.5], 
    LineBox[{{5.7074270169805095`, -2.426305985591439}, {
     5.707513832574532, -2.632347355833845}}]}, 
   {Hue[0.5165866545553703], AbsoluteThickness[0.5], 
    LineBox[{{5.707513832574532, -2.632347355833845}, {
     5.708086234467998, -2.91568110183199}}]}, 
   {Hue[0.6227017243899882], AbsoluteThickness[0.5], 
    LineBox[{{2.6495586149342545`, -0.352356725731954}, {
     2.6239248219920763`, -0.37949459883138614`}}]}, 
   {Hue[0.6231966433429106], AbsoluteThickness[0.5], 
    LineBox[{{2.6239248219920763`, -0.37949459883138614`}, {
     2.4076011961404964`, -0.6257946093550647}}]}, 
   {Hue[0.6064324043562777], AbsoluteThickness[0.5], 
    LineBox[{{4.138471530475225, 0.6337987915180525}, {4.137686490490605, 
     0.6326425260557249}}]}, 
   {Hue[0.6070150925107012], AbsoluteThickness[0.5], 
    LineBox[{{4.137686490490605, 0.6326425260557249}, {3.950760089238828, 
     0.3866778167108589}}]}, 
   {Hue[0.6380174501718002], AbsoluteThickness[0.5], 
    LineBox[{{5.999332355927682, 0.7969463744818078}, {5.9654250499795305`, 
     0.6850820513217843}}]}, 
   {Hue[0.6384853124743763], AbsoluteThickness[0.5], 
    LineBox[{{5.9654250499795305`, 0.6850820513217843}, {5.887460470133315, 
     0.3987704762146003}}]}, 
   {Hue[0.6657775863185493], AbsoluteThickness[0.5], 
    LineBox[{{5.1527156129385885`, 2.630544908827115}, {5.152621523580029, 
     2.630512954687764}}]}, 
   {Hue[0.6663390979315598], AbsoluteThickness[0.5], 
    LineBox[{{5.152621523580029, 2.630512954687764}, {4.910765952497771, 
     2.534667903500388}}]}, 
   {Hue[0.6225590734696265], AbsoluteThickness[0.5], 
    LineBox[{{4.079548642068997, 3.3421302901625793`}, {3.923780352740499, 
     3.354312853208487}}]}, 
   {Hue[0.62350636362133], AbsoluteThickness[0.5], 
    LineBox[{{3.923780352740499, 3.354312853208487}, {3.6373122574391967`, 
     3.350652634541655}}]}, 
   {Hue[0.6263051158048666], AbsoluteThickness[0.5], 
    LineBox[{{4.877231600589201, 0.5117766354533423}, {4.795530958102025, 
     0.3934172861978686}}]}, 
   {Hue[0.6267400072118844], AbsoluteThickness[0.5], 
    LineBox[{{4.795530958102025, 0.3934172861978686}, {4.64558602680015, 
     0.16988255042311304`}}]}, 
   {Hue[0.624873764299522], AbsoluteThickness[0.5], 
    LineBox[{{3.7185360029406773`, 0.061715417033214925`}, {
     3.203919334977637, -0.6261047064107796}}]}, 
   {Hue[0.6259579210905285], AbsoluteThickness[0.5], 
    LineBox[{{3.203919334977637, -0.6261047064107796}, {
     3.068309778028274, -0.8511257134025512}}]}, 
   {Hue[0.6473034611713064], AbsoluteThickness[0.5], 
    LineBox[{{2.5489895992890736`, -2.1047151263232498`}, {
     2.485272650966958, -2.3235557236524733`}}]}, 
   {Hue[0.6480299277540639], AbsoluteThickness[0.5], 
    LineBox[{{2.485272650966958, -2.3235557236524733`}, {
     2.424779191002233, -2.6051266598383847`}}]}, 
   {Hue[0.6853687765420908], AbsoluteThickness[0.5], 
    LineBox[{{5.21849177025518, -4.356328899681455}, {
     5.328910658019526, -4.539865999782798}}]}, 
   {Hue[0.6249125063332542], AbsoluteThickness[0.5], 
    LineBox[{{7.200174263904642, -3.4115834804259024`}, {
     7.330730123267211, -3.6770544884618026`}}]}, 
   {Hue[0.6260448027542352], AbsoluteThickness[0.5], 
    LineBox[{{7.330730123267211, -3.6770544884618026`}, {
     7.398778767765943, -3.8610749824656057`}}]}, 
   {Hue[0.6168365523112167], AbsoluteThickness[0.5], 
    LineBox[{{7.829333096227265, 1.9017419001810434`}, {8.061168447300119, 
     2.242619914474071}}]}, 
   {Hue[0.6191633379964079], AbsoluteThickness[0.5], 
    LineBox[{{8.061168447300119, 2.242619914474071}, {8.206927076053136, 
     2.4000705263846855`}}]}, 
   {Hue[0.6360304651676286], AbsoluteThickness[0.5], 
    LineBox[{{7.488342833418298, -3.381770267529771}, {
     7.570054655560186, -3.312184648607174}}]}, 
   {Hue[0.6365521083316705], AbsoluteThickness[0.5], 
    LineBox[{{7.570054655560186, -3.312184648607174}, {
     7.828824992088412, -3.1100767930433006`}}]}, 
   {Hue[0.5982686776537169], AbsoluteThickness[0.5], 
    LineBox[{{7.644647879748138, 3.3859686087284717`}, {7.64840564030223, 
     3.3977235844542775`}}]}, 
   {Hue[0.614833692545025], AbsoluteThickness[0.5], 
    LineBox[{{7.64840564030223, 3.3977235844542775`}, {7.651406859887087, 
     3.5616938284326185`}}]}, 
   {Hue[0.6684827932148459], AbsoluteThickness[0.5], 
    LineBox[{{2.5246480757808416`, -4.207886893050314}, {
     2.3589307833225113`, -4.326478090096596}}]}, 
   {Hue[0.6708284328631495], AbsoluteThickness[0.5], 
    LineBox[{{2.3589307833225113`, -4.326478090096596}, {
     2.150891620342144, -4.432418677915112}}]}, 
   {Hue[0.60497891788727], AbsoluteThickness[0.5], 
    LineBox[{{2.9227982160179797`, -4.342862234475462}, {
     2.9242573447221756`, -4.36516066258851}}]}, 
   {Hue[0.6055344659994397], AbsoluteThickness[0.5], 
    LineBox[{{2.9242573447221756`, -4.36516066258851}, {
     2.960325942428792, -4.679581994091531}}]}, 
   {Hue[0.5396155585838677], AbsoluteThickness[0.5], 
    LineBox[{{7.066572118463241, -4.142731300267221}, {
     7.079774113824037, -4.1508791376512635`}}]}, 
   {Hue[0.5400479448627405], AbsoluteThickness[0.5], 
    LineBox[{{7.079774113824037, -4.1508791376512635`}, {
     7.3458789414368155`, -4.310975309510481}}]}, 
   {Hue[0.5775183788340996], AbsoluteThickness[0.5], 
    LineBox[{{2.8727990606433753`, 3.6196178892045157`}, {2.870961375585637, 
     3.6725949554587043`}}]}, 
   {Hue[0.5804626119239596], AbsoluteThickness[0.5], 
    LineBox[{{2.870961375585637, 3.6725949554587043`}, {2.8232471189250177`, 
     3.9083630230031163`}}]}, 
   {Hue[0.5844644689276043], AbsoluteThickness[0.5], 
    LineBox[{{8.12967530025782, -2.3623625924030676`}, {
     8.116568240601296, -2.4054419207679634`}}]}, 
   {Hue[0.5862296201713231], AbsoluteThickness[0.5], 
    LineBox[{{8.116568240601296, -2.4054419207679634`}, {
     8.02247996579969, -2.6121761715601304`}}]}, 
   {Hue[0.6605686377053656], AbsoluteThickness[0.5], 
    LineBox[{{6.845850173832062, -1.6202311905802698`}, {
     6.791409411633891, -1.6250836229955241`}}]}, 
   {Hue[0.6627097537425218], AbsoluteThickness[0.5], 
    LineBox[{{6.791409411633891, -1.6250836229955241`}, {
     6.594009517820903, -1.6719512268040675`}}]}, 
   {Hue[0.6946052842859473], AbsoluteThickness[0.5], 
    LineBox[{{6.7496263124307445`, 2.346973220463829}, {6.610968797159891, 
     2.4277628070741692`}}]}, 
   {Hue[0.6950311940459966], AbsoluteThickness[0.5], 
    LineBox[{{6.610968797159891, 2.4277628070741692`}, {6.321365555620282, 
     2.5969086691699172`}}]}, 
   {Hue[0.6888029319634761], AbsoluteThickness[0.5], 
    LineBox[{{7.439106500816046, -1.6640125000315449`}, {
     7.384149288466267, -1.7659514337130753`}}]}, 
   {Hue[0.6906295464012845], AbsoluteThickness[0.5], 
    LineBox[{{7.384149288466267, -1.7659514337130753`}, {
     7.256803451101262, -1.9411965658563528`}}]}, 
   {Hue[0.5114139669418182], AbsoluteThickness[0.5], 
    LineBox[{{7.380635155024043, -1.6333231843665383`}, {
     7.3806561142382465`, -1.7524904689617327`}}]}, 
   {Hue[0.661209642200051], AbsoluteThickness[0.5], 
    LineBox[{{5.140825486719869, -0.8935282559203496}, {
     5.1389962100286315`, -0.8962436951024122}}]}, 
   {Hue[0.6616630322926266], AbsoluteThickness[0.5], 
    LineBox[{{5.1389962100286315`, -0.8962436951024122}, {
     4.970073842626896, -1.1348969065999024`}}]}, 
   {Hue[0.675977128141072], AbsoluteThickness[0.5], 
    LineBox[{{3.582825726935251, 2.159732603011195}, {3.4539934790294877`, 
     2.2007847594994967`}}]}, 
   {Hue[0.6764146876067973], AbsoluteThickness[0.5], 
    LineBox[{{3.4539934790294877`, 2.2007847594994967`}, {3.1459790090928546`,
      2.2938186367574374`}}]}, 
   {Hue[0.6597498907678891], AbsoluteThickness[0.5], 
    LineBox[{{3.8673941461262373`, 2.443679911372603}, {3.630575653385052, 
     2.5035729946753316`}}]}, 
   {Hue[0.6602311080058834], AbsoluteThickness[0.5], 
    LineBox[{{3.630575653385052, 2.5035729946753316`}, {3.3293293636998897`, 
     2.569412289987462}}]}, 
   {Hue[0.6726375507991925], AbsoluteThickness[0.5], 
    LineBox[{{5.747337534014557, -0.4234074682555766}, {
     5.656065145973654, -0.5088322279225999}}]}, 
   {Hue[0.6733941455547929], AbsoluteThickness[0.5], 
    LineBox[{{5.656065145973654, -0.5088322279225999}, {
     5.432824940891503, -0.6884538183085083}}]}, 
   {Hue[0.5769960984315213], AbsoluteThickness[0.5], 
    LineBox[{{7.6092045723493005`, -0.5545651886532563}, {
     7.560104938101359, -0.8230154966812452}}]}, 
   {Hue[0.5774258003858624], AbsoluteThickness[0.5], 
    LineBox[{{7.560104938101359, -0.8230154966812452}, {
     7.506142311023532, -1.1332885695842547`}}]}, 
   {Hue[0.5346656903087919], AbsoluteThickness[0.5], 
    LineBox[{{7.204861113512161, 3.427960508432719}, {7.082187758509196, 
     3.515135854495587}}]}, 
   {Hue[0.5363970960088759], AbsoluteThickness[0.5], 
    LineBox[{{7.082187758509196, 3.515135854495587}, {6.903325860847801, 
     3.609924473499574}}]}, 
   {Hue[0.6038284645199185], AbsoluteThickness[0.5], 
    LineBox[{{6.260056484791117, 3.3943918755810785`}, {6.218096600671689, 
     3.5544633598592714`}}]}, 
   {Hue[0.6043642080061098], AbsoluteThickness[0.5], 
    LineBox[{{6.218096600671689, 3.5544633598592714`}, {6.157741943512265, 
     3.8360266132916783`}}]}, 
   {Hue[0.6029122409758892], AbsoluteThickness[0.5], 
    LineBox[{{4.643787737142121, 2.391881696125663}, {4.631565840877236, 
     2.3942315120540165`}}]}, 
   {Hue[0.6033966933448421], AbsoluteThickness[0.5], 
    LineBox[{{4.631565840877236, 2.3942315120540165`}, {4.3319303609323425`, 
     2.4623042057782922`}}]}, 
   {Hue[0.6205641698670493], AbsoluteThickness[0.5], 
    LineBox[{{6.482689160232547, -1.6547322774824422`}, {
     6.482522844509324, -1.8024304261603812`}}]}, 
   {Hue[0.6209900374458317], AbsoluteThickness[0.5], 
    LineBox[{{6.482522844509324, -1.8024304261603812`}, {
     6.48199729344255, -2.122413977577235}}]}, 
   {Hue[0.6050587021727576], AbsoluteThickness[0.5], 
    LineBox[{{6.00453104713107, -2.0825467007885563`}, {
     5.708220393010216, -2.63235697927851}}]}, 
   {Hue[0.6057998708802416], AbsoluteThickness[0.5], 
    LineBox[{{5.708220393010216, -2.63235697927851}, {
     5.578477281294309, -2.835880088932723}}]}, 
   {Hue[0.6889253143291452], AbsoluteThickness[0.5], 
    LineBox[{{7.863249776218835, -1.999409063885954}, {
     7.833378459689488, -2.11935182706607}}]}, 
   {Hue[0.6894034775343906], AbsoluteThickness[0.5], 
    LineBox[{{7.833378459689488, -2.11935182706607}, {
     7.752546253621849, -2.4050343260713234`}}]}, 
   {Hue[0.4855677642522609], AbsoluteThickness[0.5], 
    LineBox[{{7.962873987838886, -2.1253988731939986`}, {
     8.072566573530391, -2.2070022762323007`}}]}, 
   {Hue[0.4862140263275351], AbsoluteThickness[0.5], 
    LineBox[{{8.072566573530391, -2.2070022762323007`}, {
     8.331576727391782, -2.3756603472289126`}}]}, 
   {Hue[0.5505665626012657], AbsoluteThickness[0.5], 
    LineBox[{{2.8904050259831595`, -1.1141449940680594`}, {
     2.8844833043300553`, -1.1148062133207994`}}]}, 
   {Hue[0.5521168754390385], AbsoluteThickness[0.5], 
    LineBox[{{2.8844833043300553`, -1.1148062133207994`}, {
     2.6631789270061814`, -1.167691930355863}}]}, 
   {Hue[0.6522272808183736], AbsoluteThickness[0.5], 
    LineBox[{{4.719762777538782, -1.3684374927220562`}, {
     4.681003234178682, -1.4359912177494016`}}]}, 
   {Hue[0.6532101753633394], AbsoluteThickness[0.5], 
    LineBox[{{4.681003234178682, -1.4359912177494016`}, {
     4.5354194971365835`, -1.6424134561282961`}}]}, 
   {Hue[0.5991704482808193], AbsoluteThickness[0.5], 
    LineBox[{{3.210211863053803, -0.9457604212523337}, {
     3.1137479357268254`, -1.0205146510743779`}}]}, 
   {Hue[0.60082955939854], AbsoluteThickness[0.5], 
    LineBox[{{3.1137479357268254`, -1.0205146510743779`}, {
     2.9252547676986698`, -1.1313422716621653`}}]}, 
   {Hue[0.6744568861635054], AbsoluteThickness[0.5], 
    LineBox[{{8.117415494108787, 0.33541963584986956`}, {8.291136572580854, 
     0.6268244619996882}}]}, 
   {Hue[0.677215646889372], AbsoluteThickness[0.5], 
    LineBox[{{8.291136572580854, 0.6268244619996882}, {8.374285718113672, 
     0.8369149174200784}}]}, 
   {Hue[0.5829773401944435], AbsoluteThickness[0.5], 
    LineBox[{{3.578676367639576, -3.091155362120867}, {
     3.494693239522083, -3.315807927764469}}]}, 
   {Hue[0.5839552797564586], AbsoluteThickness[0.5], 
    LineBox[{{3.494693239522083, -3.315807927764469}, {
     3.428360151344511, -3.560486037240447}}]}, 
   {Hue[0.45167557834038546`], AbsoluteThickness[0.5], 
    LineBox[{{7.855126564432227, -0.8538621350659643}, {
     7.931864306394035, -0.9268305440575548}}]}, 
   {Hue[0.4521019850801679], AbsoluteThickness[0.5], 
    LineBox[{{7.931864306394035, -0.9268305440575548}, {
     8.146993693718674, -1.1300445683332456`}}]}, 
   {Hue[0.662606641072995], AbsoluteThickness[0.5], 
    LineBox[{{2.8963147457212575`, 3.0971190840845253`}, {2.8901851043891975`,
      3.099381015686142}}]}, 
   {Hue[0.6631237487712092], AbsoluteThickness[0.5], 
    LineBox[{{2.8901851043891975`, 3.099381015686142}, {2.6067272563782438`, 
     3.2175246182152866`}}]}, 
   {Hue[0.5394342554054573], AbsoluteThickness[0.5], 
    LineBox[{{3.353229056610456, 3.479684235162389}, {3.1364397866644826`, 
     3.630258200153701}}]}, 
   {Hue[0.6057017092858246], AbsoluteThickness[0.5], 
    LineBox[{{3.1364397866644826`, 3.630258200153701}, {3.0571378812011796`, 
     3.757656047482914}}]}, 
   {Hue[0.6801216046518207], AbsoluteThickness[0.5], 
    LineBox[{{3.0571378812011796`, 3.757656047482914}, {3.123532613557504, 
     3.8922322089289896`}}]}, 
   {Hue[0.4452049225261062], AbsoluteThickness[0.5], 
    LineBox[{{7.190353661181457, 1.1047463072116575`}, {7.243959187147743, 
     0.9525938495609663}}]}, 
   {Hue[0.44569774286244734`], AbsoluteThickness[0.5], 
    LineBox[{{7.243959187147743, 0.9525938495609663}, {7.3534722477398216`, 
     0.6738980820321048}}]}, 
   {Hue[0.5875359506677611], AbsoluteThickness[0.5], 
    LineBox[{{5.410078480362247, 3.1427085144968765`}, {5.322680080231242, 
     3.1862343082710054`}}]}, 
   {Hue[0.5879643938239628], AbsoluteThickness[0.5], 
    LineBox[{{5.322680080231242, 3.1862343082710054`}, {5.0802046298578745`, 
     3.3048373343399757`}}]}, 
   {Hue[0.5332440129732676], AbsoluteThickness[0.5], 
    LineBox[{{7.367720676222741, 2.3475729216963095`}, {7.353888990622367, 
     2.306940895760733}}]}, 
   {Hue[0.5441197451534455], AbsoluteThickness[0.5], 
    LineBox[{{7.353888990622367, 2.306940895760733}, {7.346741657868016, 
     2.205387342236899}}]}, 
   {Hue[0.5853834803675995], AbsoluteThickness[0.5], 
    LineBox[{{7.579609168760798, 3.2796437937832055`}, {7.378086301481368, 
     3.299516287245053}}]}, 
   {Hue[0.585946768843776], AbsoluteThickness[0.5], 
    LineBox[{{7.378086301481368, 3.299516287245053}, {7.067399890693107, 
     3.3459984052891585`}}]}, 
   {Hue[0.5868981817498911], AbsoluteThickness[0.5], 
    LineBox[{{7.844709541267707, 3.0713477083191605`}, {7.635109495957082, 
     3.0147015363413368`}}]}, 
   {Hue[0.5873469039358546], AbsoluteThickness[0.5], 
    LineBox[{{7.635109495957082, 3.0147015363413368`}, {7.361395788478123, 
     2.9468915299588536`}}]}, 
   {Hue[0.5890404537192991], AbsoluteThickness[0.5], 
    LineBox[{{6.151205115380451, 2.300371118010761}, {5.823121937058358, 
     2.193792039733954}}]}, 
   {Hue[0.5896922795453782], AbsoluteThickness[0.5], 
    LineBox[{{5.823121937058358, 2.193792039733954}, {5.628902988323729, 
     2.116844314640011}}]}, 
   {Hue[0.5458601324752637], AbsoluteThickness[0.5], 
    LineBox[{{6.132131498680236, -0.42231781201897955`}, {
     6.212218597063261, -0.6162994156348078}}]}, 
   {Hue[0.546327187380076], AbsoluteThickness[0.5], 
    LineBox[{{6.212218597063261, -0.6162994156348078}, {
     6.3185314586776355`, -0.8958880928834307}}]}, 
   {Hue[0.659553253885631], AbsoluteThickness[0.5], 
    LineBox[{{7.21877148902684, 0.09089025971375768}, {
     7.376463012832983, -0.02038394288388683}}]}, 
   {Hue[0.6601449024269039], AbsoluteThickness[0.5], 
    LineBox[{{7.376463012832983, -0.020383942883886834`}, {
     7.606558666045835, -0.1645510306856529}}]}, 
   {Hue[0.6139353099726645], AbsoluteThickness[0.5], 
    LineBox[{{5.85334823550192, -0.39530175298136316`}, {
     5.852712970476946, -0.3975503292892403}}]}, 
   {Hue[0.6200632514540251], AbsoluteThickness[0.5], 
    LineBox[{{5.852712970476946, -0.3975503292892403}, {
     5.842907241844697, -0.5605246634521897}}]}, 
   {Hue[0.6820161167207905], AbsoluteThickness[0.5], 
    LineBox[{{4.885114946348674, -0.6101584351666627}, {
     4.885011249402167, -0.6102188237242515}}]}, 
   {Hue[0.6824727949009965], AbsoluteThickness[0.5], 
    LineBox[{{4.885011249402167, -0.6102188237242515}, {
     4.6297905280739675`, -0.7673249284923777}}]}, 
   {Hue[0.6442053467541122], AbsoluteThickness[0.5], 
    LineBox[{{7.903067938259836, 0.2886149924945818}, {8.064632844591786, 
     0.21964982048099796`}}]}, 
   {Hue[0.6447628283480072], AbsoluteThickness[0.5], 
    LineBox[{{8.064632844591786, 0.21964982048099796`}, {8.345607421722669, 
     0.11573678270682296`}}]}, 
   {Hue[0.5554892929293157], AbsoluteThickness[0.5], 
    LineBox[{{7.016407964865166, -4.15903831782656}, {
     7.0667437121843815`, -4.251283949159036}}]}, 
   {Hue[0.5692652466064934], AbsoluteThickness[0.5], 
    LineBox[{{7.0667437121843815`, -4.251283949159036}, {
     7.18522286563358, -4.372049590288962}}]}, 
   {Hue[0.6574017108349509], AbsoluteThickness[0.5], 
    LineBox[{{7.147985198350537, -4.028674826976259}, {
     7.201677361760378, -4.065257939042039}}]}, 
   {Hue[0.6591558188639038], AbsoluteThickness[0.5], 
    LineBox[{{7.201677361760378, -4.065257939042039}, {
     7.375168373575928, -4.220343258756905}}]}, 
   {Hue[0.6346809899645097], AbsoluteThickness[0.5], 
    LineBox[{{2.2923390683512768`, -1.860477850389255}, {
     2.189089044935125, -1.9011418370275757`}}]}, 
   {Hue[0.6351121694027545], AbsoluteThickness[0.5], 
    LineBox[{{2.189089044935125, -1.9011418370275757`}, {
     1.8720033300450034`, -2.0222892192733335`}}]}, 
   {Hue[0.6911016454147217], AbsoluteThickness[0.5], 
    LineBox[{{6.826500453872797, -0.9498995455684857}, {
     6.692613571655691, -1.17922793116258}}]}, 
   {Hue[0.698386045337804], AbsoluteThickness[0.5], 
    LineBox[{{6.692613571655691, -1.17922793116258}, {
     6.642574355421501, -1.3405981601254995`}}]}, 
   {Hue[0.6156758580810467], AbsoluteThickness[0.5], 
    LineBox[{{6.0119410880608575`, 0.7940571556182572}, {6.000078326029462, 
     0.6787625659901261}}]}, 
   {Hue[0.6161311383300261], AbsoluteThickness[0.5], 
    LineBox[{{6.000078326029462, 0.6787625659901261}, {5.962440940640835, 
     0.38263978340399063`}}]}, 
   {Hue[0.5016673610914948], AbsoluteThickness[0.5], 
    LineBox[{{8.01597157241524, 1.3305717242216883`}, {8.098184382687867, 
     1.193830341289648}}]}, 
   {Hue[0.5042912296619859], AbsoluteThickness[0.5], 
    LineBox[{{8.098184382687867, 1.193830341289648}, {8.183565624824965, 
     0.9824516601748101}}]}, 
   {Hue[0.6145682180512062], AbsoluteThickness[0.5], 
    LineBox[{{5.88342624414638, 2.4686103759691127`}, {5.8128332855288996`, 
     2.256237830613128}}]}, 
   {Hue[0.6160761439231921], AbsoluteThickness[0.5], 
    LineBox[{{5.8128332855288996`, 2.256237830613128}, {5.7350803567637945`, 
     2.092143653094426}}]}, 
   {Hue[0.6147258510312589], AbsoluteThickness[0.5], 
    LineBox[{{5.883459705995046, 2.468327304112954}, {5.81185040303601, 
     2.258302665071833}}]}, 
   {Hue[0.6161058018831918], AbsoluteThickness[0.5], 
    LineBox[{{5.81185040303601, 2.258302665071833}, {5.732414526305361, 
     2.0914924135248683`}}]}, 
   {Hue[0.5850914747815822], AbsoluteThickness[0.5], 
    LineBox[{{3.379558515205473, 3.385423196915734}, {3.3634780310856978`, 
     3.3903231718613314`}}]}, 
   {Hue[0.5909962892155639], AbsoluteThickness[0.5], 
    LineBox[{{3.3634780310856978`, 3.3903231718613314`}, {3.1727002529779775`,
      3.4062280294506717`}}]}, 
   {Hue[0.5377304052430419], AbsoluteThickness[0.5], 
    LineBox[{{8.032581829611344, -0.17116208422406284`}, {
     8.102446531326565, -0.18899461472784707`}}]}, 
   {Hue[0.5381568791767356], AbsoluteThickness[0.5], 
    LineBox[{{8.102446531326565, -0.18899461472784707`}, {
     8.433456608403205, -0.27471677916892967`}}]}, 
   {Hue[0.5616114678265219], AbsoluteThickness[0.5], 
    LineBox[{{6.219828900602508, -1.9150900243448221`}, {
     6.220473267169088, -2.071024587393513}}]}, 
   {Hue[0.5621504921182303], AbsoluteThickness[0.5], 
    LineBox[{{6.220473267169088, -2.071024587393513}, {
     6.2362144043000445`, -2.385780754320708}}]}, 
   {Hue[0.6947573953430385], AbsoluteThickness[0.5], 
    LineBox[{{5.709416493396021, -0.8620178950550683}, {
     5.65487660616714, -1.0827175109123557`}}]}, 
   {Hue[0.6973683350523338], AbsoluteThickness[0.5], 
    LineBox[{{5.65487660616714, -1.0827175109123557`}, {
     5.6360832480944305`, -1.3028782696699424`}}]}, 
   {Hue[0.6534962805823049], AbsoluteThickness[0.5], 
    LineBox[{{7.105502242140097, -2.5342313189210763`}, {
     7.230430227509103, -2.65281989818651}}]}, 
   {Hue[0.6540630035939546], AbsoluteThickness[0.5], 
    LineBox[{{7.230430227509103, -2.65281989818651}, {
     7.4265923757368455`, -2.8589492058992665`}}]}, 
   {Hue[0.5241706863891836], AbsoluteThickness[0.5], 
    LineBox[{{2.116605119891804, 2.311497092707608}, {2.0408592301803767`, 
     2.308156168211118}}]}, 
   {Hue[0.5322429290096783], AbsoluteThickness[0.5], 
    LineBox[{{2.0408592301803767`, 2.308156168211118}, {1.8355723036449905`, 
     2.3478998085939784`}}]}, 
   {Hue[0.6239382384806365], AbsoluteThickness[0.5], 
    LineBox[{{3.941179008481316, -3.1411014976104723`}, {
     3.9067273359527235`, -3.191630970917446}}]}, 
   {Hue[0.6244580117326146], AbsoluteThickness[0.5], 
    LineBox[{{3.9067273359527235`, -3.191630970917446}, {
     3.755839460220349, -3.4342059430486307`}}]}, 
   {Hue[0.6253643117092647], AbsoluteThickness[0.5], 
    LineBox[{{2.6112381929810637`, -2.617223922503814}, {
     2.6100430114026696`, -2.6438425846634726`}}]}, 
   {Hue[0.6280250561090139], AbsoluteThickness[0.5], 
    LineBox[{{2.6100430114026696`, -2.6438425846634726`}, {
     2.6371709573438293`, -2.8818701224844}}]}, 
   {Hue[0.5463107035884569], AbsoluteThickness[0.5], 
    LineBox[{{5.5856727355978135`, 0.3576482797426801}, {5.624857028058343, 
     0.3098293539152201}}]}, 
   {Hue[0.5467366711052841], AbsoluteThickness[0.5], 
    LineBox[{{5.624857028058343, 0.3098293539152201}, {5.774373238040075, 
     0.12792163372319154`}}]}, 
   {Hue[0.6448592549958084], AbsoluteThickness[0.5], 
    LineBox[{{2.9170262207093085`, -2.094356345222378}, {
     2.953602526762863, -2.31482337768801}}]}, 
   {Hue[0.6452864820025291], AbsoluteThickness[0.5], 
    LineBox[{{2.953602526762863, -2.31482337768801}, {
     3.0084823417065314`, -2.6566205345470273`}}]}, 
   {Hue[0.6033519472960953], AbsoluteThickness[0.5], 
    LineBox[{{3.2427603696725935`, -3.4485238725590546`}, {
     3.2376493676363323`, -3.5875523465572945`}}]}, 
   {Hue[0.6038706063005939], AbsoluteThickness[0.5], 
    LineBox[{{3.2376493676363323`, -3.5875523465572945`}, {
     3.239305335860072, -3.920446766695947}}]}, 
   {Hue[0.5233778441317098], AbsoluteThickness[0.5], 
    LineBox[{{7.869344381027741, -4.298769149958636}, {
     7.926866202316255, -4.340955354456334}}]}, 
   {Hue[0.5241918950689983], AbsoluteThickness[0.5], 
    LineBox[{{7.926866202316255, -4.340955354456334}, {
     8.15298342777828, -4.536468089166777}}]}, 
   {Hue[0.6668474468152882], AbsoluteThickness[0.5], 
    LineBox[{{5.392812119703785, -4.096019482239557}, {
     5.369729511090495, -4.1479387628314175`}}]}, 
   {Hue[0.6679418740420558], AbsoluteThickness[0.5], 
    LineBox[{{5.369729511090495, -4.1479387628314175`}, {
     5.250391802464026, -4.356878172227948}}]}, 
   {Hue[0.6341454410837806], AbsoluteThickness[0.5], 
    LineBox[{{7.168199915597048, -4.367194291247976}, {
     7.401922554740271, -4.581844504803879}}]}, 
   {Hue[0.660254007998838], AbsoluteThickness[0.5], 
    LineBox[{{7.401922554740271, -4.581844504803879}, {
     7.5399612013595245`, -4.642523649834321}}]}, 
   {Hue[0.6688723464225721], AbsoluteThickness[0.5], 
    LineBox[{{5.371396807160023, -3.949809085911326}, {
     5.212254501523525, -4.065904878257032}}]}, 
   {Hue[0.6741219874334595], AbsoluteThickness[0.5], 
    LineBox[{{5.212254501523525, -4.065904878257032}, {
     5.090480980569442, -4.200278041498481}}]}, 
   {Hue[0.5865163900058016], AbsoluteThickness[0.5], 
    LineBox[{{4.55465095500315, -3.7694016568520077`}, {
     4.3041432203016985`, -3.877403469818622}}]}, 
   {Hue[0.5974362333455515], AbsoluteThickness[0.5], 
    LineBox[{{4.3041432203016985`, -3.877403469818622}, {
     4.1577731781019445`, -3.8993598595942367`}}]}, 
   {Hue[0.6769903732563103], AbsoluteThickness[0.5], 
    LineBox[{{4.629008260561779, 3.7225390896858497`}, {4.3695775569400865`, 
     3.6728658825698197`}}]}, 
   {Hue[0.6777004791272068], AbsoluteThickness[0.5], 
    LineBox[{{4.3695775569400865`, 3.6728658825698197`}, {4.10708851666691, 
     3.6414189865016136`}}]}, 
   {Hue[0.6095251294360557], AbsoluteThickness[0.5], 
    LineBox[{{5.803108710693385, 0.16176495353043238`}, {5.856966988753228, 
     0.06561763761564657}}]}, 
   {Hue[0.6109327627684777], AbsoluteThickness[0.5], 
    LineBox[{{5.856966988753228, 0.06561763761564657}, {
     6.016158633605827, -0.15375849795562907`}}]}, 
   {Hue[0.5448734967252218], AbsoluteThickness[0.5], 
    LineBox[{{7.292391991774231, 2.1388661667030737`}, {7.338584093550208, 
     2.1227109071916272`}}]}, 
   {Hue[0.5453162330640825], AbsoluteThickness[0.5], 
    LineBox[{{7.338584093550208, 2.1227109071916272`}, {7.662966235885576, 
     2.0026063222733623`}}]}, 
   {Hue[0.6001340362425817], AbsoluteThickness[0.5], 
    LineBox[{{5.845517805074358, 0.6411847580869643}, {5.8472389600111585`, 
     0.6395766328289121}}]}, 
   {Hue[0.6005602035705566], AbsoluteThickness[0.5], 
    LineBox[{{5.8472389600111585`, 0.6395766328289121}, {6.068013720136082, 
     0.4322700093041653}}]}, 
   {Hue[0.634921481446558], AbsoluteThickness[0.5], 
    LineBox[{{6.36046649154151, -1.385467386754145}, {
     6.42683383425765, -1.4375773800563978`}}]}, 
   {Hue[0.6353473376639981], AbsoluteThickness[0.5], 
    LineBox[{{6.42683383425765, -1.4375773800563978`}, {
     6.648616898412692, -1.6117898558056798`}}]}, 
   {Hue[0.40918927016562984`], AbsoluteThickness[0.5], 
    LineBox[{{5.841522396781157, -1.3391428313563603`}, {
     5.867445124206649, -1.3489860201371366`}}]}, 
   {Hue[0.4099820356301039], AbsoluteThickness[0.5], 
    LineBox[{{5.867445124206649, -1.3489860201371366`}, {
     6.121298699957291, -1.4688425221083325`}}]}, 
   {Hue[0.49973278217441836`], AbsoluteThickness[0.5], 
    LineBox[{{6.849430144312218, -0.32156236612948885`}, {
     6.8537240156701875`, -0.3238740611206945}}]}, 
   {Hue[0.5002946787390748], AbsoluteThickness[0.5], 
    LineBox[{{6.8537240156701875`, -0.3238740611206945}, {
     7.119715868342344, -0.4847121380972733}}]}, 
   {Hue[0.699261316163545], AbsoluteThickness[0.5], 
    LineBox[{{4.197731824070849, -1.9083847657845558`}, {
     4.280536398429412, -2.0664414848297996`}}]}, 
   {Hue[0.5170126381976206], AbsoluteThickness[0.5], 
    LineBox[{{5.708086234467998, -2.91568110183199}, {
     5.7087989803227615`, -3.112619111984865}}]}, 
   {Hue[0.5174385826496454], AbsoluteThickness[0.5], 
    LineBox[{{5.7087989803227615`, -3.112619111984865}, {
     5.709530098795576, -3.432762072685253}}]}, 
   {Hue[0.6236915622958329], AbsoluteThickness[0.5], 
    LineBox[{{2.4076011961404964`, -0.6257946093550647}, {
     2.3793441073036083`, -0.6604192327961098}}]}, 
   {Hue[0.6246072024907483], AbsoluteThickness[0.5], 
    LineBox[{{2.3793441073036083`, -0.6604192327961098}, {
     2.1830385543008757`, -0.8616708111132954}}]}, 
   {Hue[0.6075977806651248], AbsoluteThickness[0.5], 
    LineBox[{{3.950760089238828, 0.3866778167108589}, {3.8924040691564845`, 
     0.3178505460324323}}]}, 
   {Hue[0.608053975776784], AbsoluteThickness[0.5], 
    LineBox[{{3.8924040691564845`, 0.3178505460324323}, {3.6798519974907746`, 
     0.0791452045786627}}]}, 
   {Hue[0.6389531747769526], AbsoluteThickness[0.5], 
    LineBox[{{5.887460470133315, 0.3987704762146004}, {
     5.7533912479099465`, -0.15528893609848307`}}]}, 
   {Hue[0.6394833035879542], AbsoluteThickness[0.5], 
    LineBox[{{5.7533912479099465`, -0.15528893609848307`}, {
     5.703810831049231, -0.40855792643684563`}}]}, 
   {Hue[0.6669006095445702], AbsoluteThickness[0.5], 
    LineBox[{{4.910765952497771, 2.534667903500388}, {4.63860655582644, 
     2.4107659039206624`}}]}, 
   {Hue[0.6682150690612152], AbsoluteThickness[0.5], 
    LineBox[{{4.63860655582644, 2.4107659039206624`}, {4.4012300069003, 
     2.333536290524599}}]}, 
   {Hue[0.6244536537730336], AbsoluteThickness[0.5], 
    LineBox[{{3.6373122574391967`, 3.350652634541655}, {3.6238894846918295`, 
     3.3492569931643277`}}]}, 
   {Hue[0.627188838912257], AbsoluteThickness[0.5], 
    LineBox[{{3.6238894846918295`, 3.3492569931643277`}, {3.3978797198264634`,
      3.3620528333107855`}}]}, 
   {Hue[0.6271748986189022], AbsoluteThickness[0.5], 
    LineBox[{{4.64558602680015, 0.16988255042311304`}, {4.635792756484254, 
     0.15485411782035485`}}]}, 
   {Hue[0.6276047256241329], AbsoluteThickness[0.5], 
    LineBox[{{4.635792756484254, 0.15485411782035485`}, {
     4.466783916802798, -0.09955407799556754}}]}, 
   {Hue[0.6270420778815351], AbsoluteThickness[0.5], 
    LineBox[{{3.068309778028274, -0.8511257134025512}, {
     3.056216611666697, -0.8766542114563054}}]}, 
   {Hue[0.6274940825253147], AbsoluteThickness[0.5], 
    LineBox[{{3.056216611666697, -0.8766542114563054}, {
     2.9280115214635, -1.132237043068945}}]}, 
   {Hue[0.6487563943368213], AbsoluteThickness[0.5], 
    LineBox[{{2.424779191002233, -2.6051266598383847`}, {
     2.4185511074985224`, -2.6493451879075876`}}]}, 
   {Hue[0.6533249053464575], AbsoluteThickness[0.5], 
    LineBox[{{2.4185511074985224`, -2.6493451879075876`}, {
     2.3501695957700677`, -2.846061015187773}}]}, 
   {Hue[0.6271770991752164], AbsoluteThickness[0.5], 
    LineBox[{{7.398778767765943, -3.8610749824656057`}, {
     7.399226633360276, -3.8628192857748336`}}]}, 
   {Hue[0.6278490108357536], AbsoluteThickness[0.5], 
    LineBox[{{7.399226633360276, -3.8628192857748336`}, {
     7.467332368825523, -4.070477806340064}}]}, 
   {Hue[0.6370737514957125], AbsoluteThickness[0.5], 
    LineBox[{{7.828824992088412, -3.1100767930433006`}, {
     7.839522560000637, -3.1024281675384184`}}]}, 
   {Hue[0.63752660492414], AbsoluteThickness[0.5], 
    LineBox[{{7.839522560000637, -3.1024281675384184`}, {
     8.121612805702831, -2.910344556022919}}]}, 
   {Hue[0.673174072511453], AbsoluteThickness[0.5], 
    LineBox[{{2.150891620342144, -4.432418677915112}, {
     2.129381636430024, -4.439567871977106}}]}, 
   {Hue[0.6736508941215285], AbsoluteThickness[0.5], 
    LineBox[{{2.129381636430024, -4.439567871977106}, {
     1.8271792250108296`, -4.550613315536524}}]}, 
   {Hue[0.5404803311416134], AbsoluteThickness[0.5], 
    LineBox[{{7.3458789414368155`, -4.310975309510481}, {
     7.446024242013051, -4.369690473612612}}]}, 
   {Hue[0.5411497107879745], AbsoluteThickness[0.5], 
    LineBox[{{7.446024242013051, -4.369690473612612}, {
     7.667535763336039, -4.519797380881382}}]}, 
   {Hue[0.587994771415042], AbsoluteThickness[0.5], 
    LineBox[{{8.02247996579969, -2.6121761715601304`}, {
     7.730641643568021, -3.078860090276252}}]}, 
   {Hue[0.5887429852241886], AbsoluteThickness[0.5], 
    LineBox[{{7.730641643568021, -3.078860090276252}, {
     7.588906745736142, -3.347872534158761}}]}, 
   {Hue[0.6648508697796781], AbsoluteThickness[0.5], 
    LineBox[{{6.594009517820903, -1.6719512268040675`}, {
     6.326234838165975, -1.7780724701599686`}}]}, 
   {Hue[0.6653203236581009], AbsoluteThickness[0.5], 
    LineBox[{{6.326234838165975, -1.7780724701599686`}, {
     6.10436646262167, -1.858646250965007}}]}, 
   {Hue[0.6954571038060461], AbsoluteThickness[0.5], 
    LineBox[{{6.321365555620282, 2.5969086691699172`}, {6.275258506751589, 
     2.6239028427034463`}}]}, 
   {Hue[0.6964180785441233], AbsoluteThickness[0.5], 
    LineBox[{{6.275258506751589, 2.6239028427034463`}, {6.046664694881695, 
     2.787608407987304}}]}, 
   {Hue[0.692456160839093], AbsoluteThickness[0.5], 
    LineBox[{{7.256803451101262, -1.9411965658563528`}, {
     7.1632612317637046`, -2.0391520014585667`}}]}, 
   {Hue[0.6954017892159955], AbsoluteThickness[0.5], 
    LineBox[{{7.1632612317637046`, -2.0391520014585667`}, {
     7.000456023724924, -2.1612307036175165`}}]}, 
   {Hue[0.5114139669418181], AbsoluteThickness[0.5], 
    LineBox[{{7.3806561142382465`, -1.7524904689617327`}, {
     7.430879281209577, -1.825459105387416}}]}, 
   {Hue[0.511907256270691], AbsoluteThickness[0.5], 
    LineBox[{{7.430879281209577, -1.825459105387416}, {
     7.597960313514853, -2.05051528773962}}]}, 
   {Hue[0.6621164223852022], AbsoluteThickness[0.5], 
    LineBox[{{4.970073842626896, -1.1348969065999024`}, {
     4.6903886362415665`, -1.511268311761084}}]}, 
   {Hue[0.6662425085295614], AbsoluteThickness[0.5], 
    LineBox[{{4.6903886362415665`, -1.511268311761084}, {
     4.548013116630981, -1.6423405106117854`}}]}, 
   {Hue[0.6768522470725227], AbsoluteThickness[0.5], 
    LineBox[{{3.1459790090928546`, 2.2938186367574374`}, {3.0662643660532107`,
      2.3165844052506026`}}]}, 
   {Hue[0.6815228876507552], AbsoluteThickness[0.5], 
    LineBox[{{3.0662643660532107`, 2.3165844052506026`}, {2.856196786295409, 
     2.4244396548952962`}}]}, 
   {Hue[0.6607123252438776], AbsoluteThickness[0.5], 
    LineBox[{{3.3293293636998897`, 2.569412289987462}, {3.189969317748364, 
     2.595150826451411}}]}, 
   {Hue[0.6618087412414777], AbsoluteThickness[0.5], 
    LineBox[{{3.189969317748364, 2.595150826451411}, {2.883465894738931, 
     2.6203132831623264`}}]}, 
   {Hue[0.6741507403103933], AbsoluteThickness[0.5], 
    LineBox[{{5.432824940891503, -0.6884538183085083}, {
     5.3564242461508025`, -0.7410343630124578}}]}, 
   {Hue[0.674773001640017], AbsoluteThickness[0.5], 
    LineBox[{{5.3564242461508025`, -0.7410343630124578}, {
     5.122696146118362, -0.8822691851105929}}]}, 
   {Hue[0.5778555023402038], AbsoluteThickness[0.5], 
    LineBox[{{7.506142311023532, -1.1332885695842547`}, {
     7.4692917149267695`, -1.3566709346632027`}}]}, 
   {Hue[0.5783266342479148], AbsoluteThickness[0.5], 
    LineBox[{{7.4692917149267695`, -1.3566709346632027`}, {
     7.428325028482044, -1.6605921303653863`}}]}, 
   {Hue[0.53812850170896], AbsoluteThickness[0.5], 
    LineBox[{{6.903325860847801, 3.609924473499574}, {6.845636726032674, 
     3.6314297127073485`}}]}, 
   {Hue[0.5387070792629807], AbsoluteThickness[0.5], 
    LineBox[{{6.845636726032674, 3.6314297127073485`}, {6.55119005122597, 
     3.7592534298454576`}}]}, 
   {Hue[0.603881145713795], AbsoluteThickness[0.5], 
    LineBox[{{4.3319303609323425`, 2.4623042057782922`}, {4.19220174008318, 
     2.499002846849476}}]}, 
   {Hue[0.6043346582846787], AbsoluteThickness[0.5], 
    LineBox[{{4.19220174008318, 2.499002846849476}, {3.8669700172845847`, 
     2.576412451487109}}]}, 
   {Hue[0.621415905024614], AbsoluteThickness[0.5], 
    LineBox[{{6.48199729344255, -2.122413977577235}, {
     6.481627925676043, -2.293511646624198}}]}, 
   {Hue[0.621968866528887], AbsoluteThickness[0.5], 
    LineBox[{{6.481627925676043, -2.293511646624198}, {
     6.496728196935427, -2.619747544574966}}]}, 
   {Hue[0.6065410395877255], AbsoluteThickness[0.5], 
    LineBox[{{5.578477281294309, -2.835880088932723}, {
     5.558624515001761, -2.862502786377589}}]}, 
   {Hue[0.6073240394544536], AbsoluteThickness[0.5], 
    LineBox[{{5.558624515001761, -2.862502786377589}, {
     5.40238890860362, -3.041334533398186}}]}, 
   {Hue[0.6898816407396361], AbsoluteThickness[0.5], 
    LineBox[{{7.752546253621849, -2.4050343260713234`}, {
     7.673933080120672, -2.652670048159879}}]}, 
   {Hue[0.690714098882563], AbsoluteThickness[0.5], 
    LineBox[{{7.673933080120672, -2.652670048159879}, {
     7.624133682737433, -2.8696226106247162`}}]}, 
   {Hue[0.5536671882768114], AbsoluteThickness[0.5], 
    LineBox[{{2.6631789270061814`, -1.167691930355863}, {
     2.394146065821072, -1.2683267478022278`}}]}, 
   {Hue[0.5541363230311696], AbsoluteThickness[0.5], 
    LineBox[{{2.394146065821072, -1.2683267478022278`}, {
     2.100649054848924, -1.3685558754020393`}}]}, 
   {Hue[0.6541930699083052], AbsoluteThickness[0.5], 
    LineBox[{{4.5354194971365835`, -1.6424134561282961`}, {
     4.410698060492794, -1.7882216096527954`}}]}, 
   {Hue[0.6619751583440602], AbsoluteThickness[0.5], 
    LineBox[{{4.410698060492794, -1.7882216096527954`}, {
     4.2398046363845925`, -1.9129746370262588`}}]}, 
   {Hue[0.6024886705162608], AbsoluteThickness[0.5], 
    LineBox[{{2.9252547676986698`, -1.1313422716621653`}, {
     2.9094351875269227`, -1.1381011460586674`}}]}, 
   {Hue[0.6029889629483334], AbsoluteThickness[0.5], 
    LineBox[{{2.9094351875269227`, -1.1381011460586674`}, {
     2.6496931160868273`, -1.2607999160399423`}}]}, 
   {Hue[0.6799744076152385], AbsoluteThickness[0.5], 
    LineBox[{{8.374285718113672, 0.8369149174200784}, {8.454345649376688, 
     1.201539119426876}}]}, 
   {Hue[0.6995476297943194], AbsoluteThickness[0.5], 
    LineBox[{{8.454345649376688, 1.201539119426876}, {8.437884070142402, 
     1.3868614783614448`}}]}, 
   {Hue[0.5849332193184738], AbsoluteThickness[0.5], 
    LineBox[{{3.428360151344511, -3.560486037240447}, {
     3.4153889557071935`, -3.635274258099369}}]}, 
   {Hue[0.5858598828055175], AbsoluteThickness[0.5], 
    LineBox[{{3.4153889557071935`, -3.635274258099369}, {
     3.3393767132908363`, -3.91982198394021}}]}, 
   {Hue[0.45252839181995036`], AbsoluteThickness[0.5], 
    LineBox[{{8.146993693718674, -1.1300445683332456`}, {
     8.147098350358924, -1.1301427765257306`}}]}, 
   {Hue[0.4529551727461537], AbsoluteThickness[0.5], 
    LineBox[{{8.147098350358924, -1.1301427765257306`}, {
     8.363719637950052, -1.3316822376678055`}}]}, 
   {Hue[0.6636408564694233], AbsoluteThickness[0.5], 
    LineBox[{{2.6067272563782438`, 3.2175246182152866`}, {2.4081671729052134`,
      3.31010353935628}}]}, 
   {Hue[0.6659649676687539], AbsoluteThickness[0.5], 
    LineBox[{{2.4081671729052134`, 3.31010353935628}, {2.192404213798056, 
     3.373728866127636}}]}, 
   {Hue[0.6138541507714482], AbsoluteThickness[0.5], 
    LineBox[{{3.1364397866644826`, 3.630258200153701}, {3.121130981600186, 
     3.6368366357402224`}}]}, 
   {Hue[0.6190638614667818], AbsoluteThickness[0.5], 
    LineBox[{{3.1211309816001855`, 3.6368366357402224`}, {2.9341462978652597`,
      3.6751499578657896`}}]}, 
   {Hue[0.4461905631987885], AbsoluteThickness[0.5], 
    LineBox[{{7.3534722477398216`, 0.6738980820321048}, {7.3758505175732525`, 
     0.6224228149010798}}]}, 
   {Hue[0.44662502121517883`], AbsoluteThickness[0.5], 
    LineBox[{{7.3758505175732525`, 0.6224228149010798}, {7.516203222586097, 
     0.2877488951103276}}]}, 
   {Hue[0.5883928369801645], AbsoluteThickness[0.5], 
    LineBox[{{5.0802046298578745`, 3.3048373343399757`}, {5.043854665510818, 
     3.322296740257277}}]}, 
   {Hue[0.6027557861943604], AbsoluteThickness[0.5], 
    LineBox[{{5.043854665510818, 3.322296740257277}, {4.967278484843762, 
     3.3352941733234203`}}]}, 
   {Hue[0.5549954773336235], AbsoluteThickness[0.5], 
    LineBox[{{7.346741657868016, 2.205387342236899}, {7.357091364834886, 
     2.1508613578029423`}}]}, 
   {Hue[0.5565784839099681], AbsoluteThickness[0.5], 
    LineBox[{{7.357091364834886, 2.1508613578029423`}, {7.371886946492448, 
     1.9157945383152968`}}]}, 
   {Hue[0.5865100573199526], AbsoluteThickness[0.5], 
    LineBox[{{7.067399890693107, 3.3459984052891585`}, {7.003522215650526, 
     3.358862298201469}}]}, 
   {Hue[0.5964839939195808], AbsoluteThickness[0.5], 
    LineBox[{{7.003522215650526, 3.358862298201469}, {6.911393394025902, 
     3.3540222469010583`}}]}, 
   {Hue[0.5877956261218181], AbsoluteThickness[0.5], 
    LineBox[{{7.361395788478123, 2.9468915299588536`}, {7.154834164450537, 
     2.9003207435619895`}}]}, 
   {Hue[0.5896135986630222], AbsoluteThickness[0.5], 
    LineBox[{{7.154834164450537, 2.9003207435619895`}, {6.988649470709163, 
     2.8386402671644477`}}]}, 
   {Hue[0.5903441053714572], AbsoluteThickness[0.5], 
    LineBox[{{5.628902988323729, 2.116844314640011}, {5.6284594608572664`, 
     2.1166353281664203`}}]}, 
   {Hue[0.5908675393915152], AbsoluteThickness[0.5], 
    LineBox[{{5.6284594608572664`, 2.1166353281664203`}, {5.423189707391853, 
     2.03042680215362}}]}, 
   {Hue[0.5467942422848887], AbsoluteThickness[0.5], 
    LineBox[{{6.3185314586776355`, -0.8958880928834307}, {
     6.358095091996244, -1.0094699125584443`}}]}, 
   {Hue[0.5783940246180432], AbsoluteThickness[0.5], 
    LineBox[{{6.358095091996244, -1.0094699125584443`}, {
     6.4576399530363515`, -1.1325557478900088`}}]}, 
   {Hue[0.6607365509681769], AbsoluteThickness[0.5], 
    LineBox[{{7.606558666045835, -0.1645510306856529}, {
     7.61332610795308, -0.1682915038431113}}]}, 
   {Hue[0.661163053755838], AbsoluteThickness[0.5], 
    LineBox[{{7.61332610795308, -0.1682915038431113}, {
     7.868931497304395, -0.30837742809816804`}}]}, 
   {Hue[0.6261911929353857], AbsoluteThickness[0.5], 
    LineBox[{{5.842907241844697, -0.5605246634521897}, {
     5.8482207907814265`, -0.5944965528902599}}]}, 
   {Hue[0.6273593108727422], AbsoluteThickness[0.5], 
    LineBox[{{5.8482207907814265`, -0.5944965528902599}, {
     5.860518242054113, -0.839128868739959}}]}, 
   {Hue[0.6829294730812024], AbsoluteThickness[0.5], 
    LineBox[{{4.6297905280739675`, -0.7673249284923777}, {
     4.550849126330322, -0.8186208871851882}}]}, 
   {Hue[0.6841397201187776], AbsoluteThickness[0.5], 
    LineBox[{{4.550849126330322, -0.8186208871851882}, {
     4.358652565028932, -0.9751569390416835}}]}, 
   {Hue[0.5830412002836709], AbsoluteThickness[0.5], 
    LineBox[{{7.18522286563358, -4.372049590288962}, {
     7.375291101571015, -4.480529165050945}}]}, 
   {Hue[0.5836192326441435], AbsoluteThickness[0.5], 
    LineBox[{{7.375291101571015, -4.480529165050945}, {
     7.621935216094019, -4.604568051236409}}]}, 
   {Hue[0.6609099268928568], AbsoluteThickness[0.5], 
    LineBox[{{7.375168373575928, -4.220343258756905}, {
     7.488711811184294, -4.352438987666628}}]}, 
   {Hue[0.6615587782284945], AbsoluteThickness[0.5], 
    LineBox[{{7.488711811184294, -4.352438987666628}, {
     7.651135859322089, -4.567311006548015}}]}, 
   {Hue[0.6165864185790055], AbsoluteThickness[0.5], 
    LineBox[{{5.962440940640835, 0.38263978340399063`}, {5.929547840786771, 
     0.16546318542656827`}}]}, 
   {Hue[0.6177405196940349], AbsoluteThickness[0.5], 
    LineBox[{{5.929547840786771, 0.16546318542656827`}, {
     5.916530137214064, -0.11618151529877507`}}]}, 
   {Hue[0.5069150982324773], AbsoluteThickness[0.5], 
    LineBox[{{8.183565624824965, 0.9824516601748101}, {8.193835979698894, 
     0.9378757036774685}}]}, 
   {Hue[0.5073433550678451], AbsoluteThickness[0.5], 
    LineBox[{{8.193835979698894, 0.9378757036774685}, {8.265369680883804, 
     0.6173366249552241}}]}, 
   {Hue[0.617584069795178], AbsoluteThickness[0.5], 
    LineBox[{{5.7350803567637945`, 2.092143653094426}, {5.294911473850186, 
     1.3963820564603466`}}]}, 
   {Hue[0.6180370918718536], AbsoluteThickness[0.5], 
    LineBox[{{5.294911473850186, 1.3963820564603466`}, {5.125944584954543, 
     1.1152073648838863`}}]}, 
   {Hue[0.6174857527351247], AbsoluteThickness[0.5], 
    LineBox[{{5.732414526305361, 2.0914924135248683`}, {5.296067263600495, 
     1.3959194036758111`}}]}, 
   {Hue[0.6179354931579778], AbsoluteThickness[0.5], 
    LineBox[{{5.296067263600495, 1.3959194036758111`}, {5.12750793307874, 
     1.113893103206935}}]}, 
   {Hue[0.5969011036495457], AbsoluteThickness[0.5], 
    LineBox[{{3.1727002529779775`, 3.4062280294506717`}, {3.05140276858113, 
     3.390440840262216}}]}, 
   {Hue[0.6274872126405434], AbsoluteThickness[0.5], 
    LineBox[{{3.05140276858113, 3.390440840262216}, {2.898921916017004, 
     3.423367857281849}}]}, 
   {Hue[0.5626895164099387], AbsoluteThickness[0.5], 
    LineBox[{{6.2362144043000445`, -2.385780754320708}, {
     6.255681969326441, -2.5883572317291743`}}]}, 
   {Hue[0.5632855739732185], AbsoluteThickness[0.5], 
    LineBox[{{6.255681969326441, -2.5883572317291743`}, {
     6.265450883855791, -2.830337884481135}}]}, 
   {Hue[0.699979274761629], AbsoluteThickness[0.5], 
    LineBox[{{5.6360832480944305`, -1.3028782696699424`}, {
     5.642358461956265, -1.3899346762693658`}}]}, 
   {Hue[0.6546297266056043], AbsoluteThickness[0.5], 
    LineBox[{{7.4265923757368455`, -2.8589492058992665`}, {
     7.443864948416868, -2.8790515391062423`}}]}, 
   {Hue[0.6550668222428027], AbsoluteThickness[0.5], 
    LineBox[{{7.443864948416868, -2.8790515391062423`}, {
     7.613175489634371, -3.070282724272699}}]}, 
   {Hue[0.6249777849845928], AbsoluteThickness[0.5], 
    LineBox[{{3.755839460220349, -3.4342059430486307`}, {
     3.6474549914141208`, -3.6259414293881043`}}]}, 
   {Hue[0.6306858005087633], AbsoluteThickness[0.5], 
    LineBox[{{2.6371709573438293`, -2.8818701224844}, {
     2.7047334378611363`, -3.1242644778116553`}}]}, 
   {Hue[0.6311116902810354], AbsoluteThickness[0.5], 
    LineBox[{{2.7047334378611363`, -3.1242644778116553`}, {
     2.7886268599303374`, -3.4262292037669697`}}]}, 
   {Hue[0.5471626386221113], AbsoluteThickness[0.5], 
    LineBox[{{5.774373238040075, 0.12792163372319154`}, {5.851464376563164, 
     0.03441484610663412}}]}, 
   {Hue[0.5485867569286382], AbsoluteThickness[0.5], 
    LineBox[{{5.851464376563164, 0.03441484610663412}, {
     6.0468398197260615`, -0.15256604111827518`}}]}, 
   {Hue[0.64571370900925], AbsoluteThickness[0.5], 
    LineBox[{{3.0084823417065314`, -2.6566205345470273`}, {
     3.035322964688952, -2.8295290195486182`}}]}, 
   {Hue[0.6462309803587561], AbsoluteThickness[0.5], 
    LineBox[{{3.035322964688952, -2.8295290195486182`}, {
     3.0726678157857443`, -3.159846358286216}}]}, 
   {Hue[0.6043892653050923], AbsoluteThickness[0.5], 
    LineBox[{{3.239305335860072, -3.920446766695947}, {
     3.2471668524547797`, -4.088684867419461}}]}, 
   {Hue[0.6048755175356882], AbsoluteThickness[0.5], 
    LineBox[{{3.2471668524547797`, -4.088684867419461}, {
     3.2722174507406647`, -4.398673009144304}}]}, 
   {Hue[0.6690363012688234], AbsoluteThickness[0.5], 
    LineBox[{{5.250391802464026, -4.356878172227948}, {
     5.1378041928355564`, -4.5147363497576425`}}]}, 
   {Hue[0.6723821180923185], AbsoluteThickness[0.5], 
    LineBox[{{5.1378041928355564`, -4.5147363497576425`}, {
     4.982476204594444, -4.667709352623432}}]}, 
   {Hue[0.679371628444347], AbsoluteThickness[0.5], 
    LineBox[{{5.090480980569442, -4.200278041498481}, {
     5.006461437290685, -4.3430346858934845`}}]}, 
   {Hue[0.6798908380329586], AbsoluteThickness[0.5], 
    LineBox[{{5.006461437290685, -4.3430346858934845`}, {
     4.858530645043943, -4.620295884802233}}]}, 
   {Hue[0.6083560766853016], AbsoluteThickness[0.5], 
    LineBox[{{4.1577731781019445`, -3.8993598595942367`}, {
     4.146304233949312, -3.8981017405555276`}}]}, 
   {Hue[0.6098051470541852], AbsoluteThickness[0.5], 
    LineBox[{{4.146304233949312, -3.8981017405555276`}, {
     3.940727122053501, -3.9001051205121313`}}]}, 
   {Hue[0.6784105849981032], AbsoluteThickness[0.5], 
    LineBox[{{4.10708851666691, 3.6414189865016136`}, {4.1062441191014845`, 
     3.6413773337077795`}}]}, 
   {Hue[0.6793842270814735], AbsoluteThickness[0.5], 
    LineBox[{{4.1062441191014845`, 3.6413773337077795`}, {3.8611422503062918`,
      3.6063377762638935`}}]}, 
   {Hue[0.6123403961008995], AbsoluteThickness[0.5], 
    LineBox[{{6.016158633605827, -0.1537584979556291}, {
     6.065814614751762, -0.20761257125896315`}}]}, 
   {Hue[0.6128947271601786], AbsoluteThickness[0.5], 
    LineBox[{{6.065814614751762, -0.20761257125896315`}, {
     6.289736363515965, -0.4279265821460039}}]}, 
   {Hue[0.5457589694029431], AbsoluteThickness[0.5], 
    LineBox[{{7.662966235885576, 2.0026063222733623`}, {7.909879912538127, 
     1.9060507269250953`}}]}, 
   {Hue[0.5469893422857912], AbsoluteThickness[0.5], 
    LineBox[{{7.909879912538127, 1.9060507269250953`}, {8.128975302602791, 
     1.8467280822779273`}}]}, 
   {Hue[0.6009863708985315], AbsoluteThickness[0.5], 
    LineBox[{{6.068013720136082, 0.4322700093041653}, {6.106903689523396, 
     0.39557013890099363`}}]}, 
   {Hue[0.6014199179664131], AbsoluteThickness[0.5], 
    LineBox[{{6.106903689523396, 0.39557013890099363`}, {6.34858144096538, 
     0.17305485031267182`}}]}, 
   {Hue[0.6357731938814382], AbsoluteThickness[0.5], 
    LineBox[{{6.648616898412692, -1.6117898558056798`}, {
     6.654648791050919, -1.616529969326641}}]}, 
   {Hue[0.6363967125794463], AbsoluteThickness[0.5], 
    LineBox[{{6.654648791050919, -1.616529969326641}, {
     6.84896645337855, -1.7888405054900018`}}]}, 
   {Hue[0.41077480109457803`], AbsoluteThickness[0.5], 
    LineBox[{{6.121298699957291, -1.4688425221083325`}, {
     6.575177251361179, -1.7283196027091863`}}]}, 
   {Hue[0.4113498976469581], AbsoluteThickness[0.5], 
    LineBox[{{6.575177251361179, -1.7283196027091863`}, {
     6.811102602752794, -1.847319760714078}}]}, 
   {Hue[0.5008565753037313], AbsoluteThickness[0.5], 
    LineBox[{{7.119715868342344, -0.4847121380972733}, {
     7.257121589355531, -0.5774762250394627}}]}, 
   {Hue[0.5059121037308532], AbsoluteThickness[0.5], 
    LineBox[{{7.257121589355531, -0.5774762250394627}, {
     7.41940848481094, -0.7430684503325836}}]}, 
   {Hue[0.5178645271016703], AbsoluteThickness[0.5], 
    LineBox[{{5.709530098795576, -3.432762072685253}, {
     5.709701600965893, -3.613610491514049}}]}, 
   {Hue[0.5183751542591039], AbsoluteThickness[0.5], 
    LineBox[{{5.709701600965893, -3.613610491514049}, {
     5.698140820509109, -3.909833361381687}}]}, 
   {Hue[0.6255228426856636], AbsoluteThickness[0.5], 
    LineBox[{{2.1830385543008757`, -0.8616708111132954}, {
     2.12523705859962, -0.9112886522952625}}]}, 
   {Hue[0.6259609988950363], AbsoluteThickness[0.5], 
    LineBox[{{2.12523705859962, -0.9112886522952625}, {
     1.8317833265383652`, -1.1553855788917735`}}]}, 
   {Hue[0.6085101708884431], AbsoluteThickness[0.5], 
    LineBox[{{3.6798519974907746`, 0.07914520457866271}, {3.6106293134595293`,
      0.005101707327080221}}]}, 
   {Hue[0.6094848651495659], AbsoluteThickness[0.5], 
    LineBox[{{3.6106293134595293`, 0.005101707327080221}, {
     3.4078760843545353`, -0.17498192092571602`}}]}, 
   {Hue[0.6400134323989558], AbsoluteThickness[0.5], 
    LineBox[{{5.703810831049231, -0.40855792643684563`}, {
     5.675074005141703, -0.5997046770988907}}]}, 
   {Hue[0.6413926942055025], AbsoluteThickness[0.5], 
    LineBox[{{5.675074005141703, -0.5997046770988907}, {
     5.667155504861843, -0.8365643262589335}}]}, 
   {Hue[0.6695295285778602], AbsoluteThickness[0.5], 
    LineBox[{{4.4012300069003, 2.333536290524599}, {4.3832838588164655`, 
     2.329863384876594}}]}, 
   {Hue[0.6700334768942741], AbsoluteThickness[0.5], 
    LineBox[{{4.3832838588164655`, 2.329863384876594}, {4.073923362661347, 
     2.2540624195184087`}}]}, 
   {Hue[0.6299240240514803], AbsoluteThickness[0.5], 
    LineBox[{{3.3978797198264634`, 3.3620528333107855`}, {3.3863493424717634`,
      3.3645915101782733`}}]}, 
   {Hue[0.63153122871753], AbsoluteThickness[0.5], 
    LineBox[{{3.3863493424717634`, 3.3645915101782733`}, {3.1476438126796924`,
      3.386377317383355}}]}, 
   {Hue[0.6280345526293638], AbsoluteThickness[0.5], 
    LineBox[{{4.466783916802798, -0.09955407799556754}, {
     4.42530508813502, -0.16080968871444629`}}]}, 
   {Hue[0.6287255565859375], AbsoluteThickness[0.5], 
    LineBox[{{4.42530508813502, -0.1608096887144463}, {
     4.227508507987348, -0.41407637705659406`}}]}, 
   {Hue[0.6279460871690943], AbsoluteThickness[0.5], 
    LineBox[{{2.9280115214635, -1.132237043068945}, {
     2.918580291324473, -1.1500263396056438`}}]}, 
   {Hue[0.6285914214868455], AbsoluteThickness[0.5], 
    LineBox[{{2.918580291324473, -1.1500263396056438`}, {
     2.7764650826370234`, -1.3819378318042619`}}]}, 
   {Hue[0.6578934163560938], AbsoluteThickness[0.5], 
    LineBox[{{2.3501695957700677`, -2.846061015187773}, {
     2.216394907440351, -3.074812389208614}}]}, 
   {Hue[0.6612091564321386], AbsoluteThickness[0.5], 
    LineBox[{{2.216394907440351, -3.074812389208614}, {
     2.146125804373175, -3.263625546825293}}]}, 
   {Hue[0.6285209224962911], AbsoluteThickness[0.5], 
    LineBox[{{7.467332368825523, -4.070477806340064}, {
     7.5849225293306395`, -4.362760773623391}}]}, 
   {Hue[0.6300716498291786], AbsoluteThickness[0.5], 
    LineBox[{{7.5849225293306395`, -4.362760773623391}, {
     7.642720084997502, -4.580808076199778}}]}, 
   {Hue[0.6379794583525676], AbsoluteThickness[0.5], 
    LineBox[{{8.121612805702831, -2.910344556022919}, {
     8.133795539980584, -2.902451142428699}}]}, 
   {Hue[0.6384103497026163], AbsoluteThickness[0.5], 
    LineBox[{{8.133795539980584, -2.902451142428699}, {
     8.44458051347068, -2.696666785219309}}]}, 
   {Hue[0.5894911990333351], AbsoluteThickness[0.5], 
    LineBox[{{7.588906745736142, -3.347872534158761}, {
     7.5650221925707095`, -3.402679414237125}}]}, 
   {Hue[0.5899280572890491], AbsoluteThickness[0.5], 
    LineBox[{{7.5650221925707095`, -3.402679414237125}, {
     7.440437150444039, -3.677467573319588}}]}, 
   {Hue[0.6657897775365236], AbsoluteThickness[0.5], 
    LineBox[{{6.10436646262167, -1.858646250965007}, {
     6.0961781978592455`, -1.861354134336508}}]}, 
   {Hue[0.6669786711739903], AbsoluteThickness[0.5], 
    LineBox[{{6.0961781978592455`, -1.861354134336508}, {
     5.919203996310539, -1.9415501279422243`}}]}, 
   {Hue[0.6973790532822007], AbsoluteThickness[0.5], 
    LineBox[{{6.046664694881695, 2.787608407987304}, {5.909333451319997, 
     2.9064362901734944`}}]}, 
   {Hue[0.6983474175928981], AbsoluteThickness[0.5], 
    LineBox[{{7.000456023724924, -2.1612307036175165`}, {
     6.9426972919677254`, -2.1911805354581477`}}]}, 
   {Hue[0.698860597245001], AbsoluteThickness[0.5], 
    LineBox[{{6.9426972919677254`, -2.1911805354581477`}, {
     6.6821679720876, -2.3131451992433747`}}]}, 
   {Hue[0.5124005455995639], AbsoluteThickness[0.5], 
    LineBox[{{7.597960313514853, -2.05051528773962}, {
     7.664992360973044, -2.13436134503284}}]}, 
   {Hue[0.5128264088179982], AbsoluteThickness[0.5], 
    LineBox[{{7.664992360973044, -2.13436134503284}, {
     7.85503313393785, -2.3722783101316423`}}]}, 
   {Hue[0.6703685946739207], AbsoluteThickness[0.5], 
    LineBox[{{4.548013116630981, -1.6423405106117854`}, {
     4.419551324850941, -1.722245875930281}}]}, 
   {Hue[0.6710451234213652], AbsoluteThickness[0.5], 
    LineBox[{{4.419551324850941, -1.722245875930281}, {
     4.1297619399001055`, -1.876933837130775}}]}, 
   {Hue[0.6861935282289878], AbsoluteThickness[0.5], 
    LineBox[{{2.856196786295409, 2.4244396548952962`}, {2.649514891898992, 
     2.588347133301914}}]}, 
   {Hue[0.6892107120262064], AbsoluteThickness[0.5], 
    LineBox[{{2.649514891898992, 2.588347133301914}, {2.4653510565744354`, 
     2.689881330009678}}]}, 
   {Hue[0.6629051572390777], AbsoluteThickness[0.5], 
    LineBox[{{2.883465894738931, 2.6203132831623264`}, {2.810853135758297, 
     2.618947283069274}}]}, 
   {Hue[0.6665611897396163], AbsoluteThickness[0.5], 
    LineBox[{{2.810853135758297, 2.618947283069274}, {2.6099701769338224`, 
     2.6514950955566032`}}]}, 
   {Hue[0.6753952629696407], AbsoluteThickness[0.5], 
    LineBox[{{5.122696146118362, -0.8822691851105929}, {
     4.886521429511438, -1.0065269395006466`}}]}, 
   {Hue[0.5787977661556258], AbsoluteThickness[0.5], 
    LineBox[{{7.428325028482044, -1.6605921303653863`}, {
     7.410035982641988, -1.8350056623040125`}}]}, 
   {Hue[0.5796462687365688], AbsoluteThickness[0.5], 
    LineBox[{{7.410035982641988, -1.8350056623040125`}, {
     7.404648896999284, -2.0872448436695152`}}]}, 
   {Hue[0.6047881708555622], AbsoluteThickness[0.5], 
    LineBox[{{3.8669700172845847`, 2.576412451487109}, {3.5314474096078596`, 
     2.6480986665448536`}}]}, 
   {Hue[0.6392934777062131], AbsoluteThickness[0.5], 
    LineBox[{{3.5314474096078596`, 2.6480986665448536`}, {3.3743060117984514`,
      2.6256585036078928`}}]}, 
   {Hue[0.6225218280331601], AbsoluteThickness[0.5], 
    LineBox[{{6.496728196935427, -2.619747544574966}, {
     6.521281697939889, -2.8783434620309674`}}]}, 
   {Hue[0.6230553134249927], AbsoluteThickness[0.5], 
    LineBox[{{6.521281697939889, -2.8783434620309674`}, {
     6.536378875421498, -3.180621263077501}}]}, 
   {Hue[0.6081070393211817], AbsoluteThickness[0.5], 
    LineBox[{{5.40238890860362, -3.041334533398186}, {
     5.333496892798885, -3.1088652639739385`}}]}, 
   {Hue[0.6086324966220336], AbsoluteThickness[0.5], 
    LineBox[{{5.333496892798885, -3.1088652639739385`}, {
     5.094250718311349, -3.323952200950803}}]}, 
   {Hue[0.6915465570254898], AbsoluteThickness[0.5], 
    LineBox[{{7.624133682737433, -2.8696226106247162`}, {
     7.593389328174188, -3.081839629196285}}]}, 
   {Hue[0.5546054577855278], AbsoluteThickness[0.5], 
    LineBox[{{2.100649054848924, -1.3685558754020393`}, {
     2.0967613092784556`, -1.3697594193412397`}}]}, 
   {Hue[0.5553333764038854], AbsoluteThickness[0.5], 
    LineBox[{{2.0967613092784556`, -1.3697594193412397`}, {
     1.8337758556591919`, -1.472387867355167}}]}, 
   {Hue[0.6697572467798153], AbsoluteThickness[0.5], 
    LineBox[{{4.2398046363845925`, -1.9129746370262588`}, {
     4.100960146402066, -1.9713459922262992`}}]}, 
   {Hue[0.6701843809148625], AbsoluteThickness[0.5], 
    LineBox[{{4.100960146402066, -1.9713459922262992`}, {
     3.853895879813507, -2.07667746648865}}]}, 
   {Hue[0.6034892553804061], AbsoluteThickness[0.5], 
    LineBox[{{2.6496931160868273`, -1.2607999160399423`}, {
     2.4710657117432335`, -1.3535356284240618`}}]}, 
   {Hue[0.6100633759056433], AbsoluteThickness[0.5], 
    LineBox[{{2.4710657117432335`, -1.3535356284240618`}, {
     2.3351704243193216`, -1.4678020819757058`}}]}, 
   {Hue[0.5867865462925613], AbsoluteThickness[0.5], 
    LineBox[{{3.3393767132908363`, -3.91982198394021}, {
     3.2803010402357593`, -4.081486943610866}}]}, 
   {Hue[0.587408260919449], AbsoluteThickness[0.5], 
    LineBox[{{3.2803010402357593`, -4.081486943610866}, {
     3.195611615130556, -4.364051097425589}}]}, 
   {Hue[0.6682890788680845], AbsoluteThickness[0.5], 
    LineBox[{{2.192404213798056, 3.373728866127636}, {2.099846410859643, 
     3.3865108697535398`}}]}, 
   {Hue[0.6695729584232197], AbsoluteThickness[0.5], 
    LineBox[{{2.099846410859643, 3.3865108697535398`}, {1.8667550241570885`, 
     3.4456226385646933`}}]}, 
   {Hue[0.6242735721621154], AbsoluteThickness[0.5], 
    LineBox[{{2.9341462978652597`, 3.6751499578657896`}, {2.872428655604342, 
     3.675048044125714}}]}, 
   {Hue[0.624986863787992], AbsoluteThickness[0.5], 
    LineBox[{{2.872428655604342, 3.675048044125714}, {2.5562379792331087`, 
     3.696785817077129}}]}, 
   {Hue[0.4470594792315691], AbsoluteThickness[0.5], 
    LineBox[{{7.516203222586097, 0.2877488951103276}, {7.603448118696625, 
     0.07188772153539935}}]}, 
   {Hue[0.4606592633429327], AbsoluteThickness[0.5], 
    LineBox[{{7.603448118696625, 0.07188772153539935}, {7.656164033468119, 
     0.003880534099787808}}]}, 
   {Hue[0.6709961721934209], AbsoluteThickness[0.5], 
    LineBox[{{7.656164033468119, 0.003880534099787801}, {
     7.661346339655778, -0.08200944736298293}}]}, 
   {Hue[0.6171187354085564], AbsoluteThickness[0.5], 
    LineBox[{{4.967278484843762, 3.3352941733234203`}, {4.91540264125504, 
     3.3294850927008564`}}]}, 
   {Hue[0.6178282871095298], AbsoluteThickness[0.5], 
    LineBox[{{4.91540264125504, 3.3294850927008564`}, {4.634856166160669, 
     3.3177990760907483`}}]}, 
   {Hue[0.5581614904863127], AbsoluteThickness[0.5], 
    LineBox[{{7.371886946492448, 1.9157945383152968`}, {7.365971921981666, 
     1.820301106782596}}]}, 
   {Hue[0.5612086260623768], AbsoluteThickness[0.5], 
    LineBox[{{7.365971921981666, 1.820301106782596}, {7.384731341770811, 
     1.6430025991553125`}}]}, 
   {Hue[0.6064579305192092], AbsoluteThickness[0.5], 
    LineBox[{{6.911393394025902, 3.3540222469010583`}, {6.8830486225210645`, 
     3.345139134685279}}]}, 
   {Hue[0.6068910433582683], AbsoluteThickness[0.5], 
    LineBox[{{6.8830486225210645`, 3.345139134685279}, {6.625338666623581, 
     3.2677414991415046`}}]}, 
   {Hue[0.5914315712042262], AbsoluteThickness[0.5], 
    LineBox[{{6.988649470709163, 2.8386402671644477`}, {6.875754654997678, 
     2.778562144043666}}]}, 
   {Hue[0.5919128956816343], AbsoluteThickness[0.5], 
    LineBox[{{6.875754654997678, 2.778562144043666}, {6.601095269047666, 
     2.620713467258177}}]}, 
   {Hue[0.5913909734115733], AbsoluteThickness[0.5], 
    LineBox[{{5.423189707391853, 2.03042680215362}, {5.161026586622374, 
     1.9332773910339605`}}]}, 
   {Hue[0.5924425277056966], AbsoluteThickness[0.5], 
    LineBox[{{5.161026586622374, 1.9332773910339605`}, {4.9821327185112185`, 
     1.8462422589072365`}}]}, 
   {Hue[0.6803355214768636], AbsoluteThickness[0.5], 
    LineBox[{{6.358095091996244, -1.0094699125584443`}, {
     6.355819445214748, -1.0809613611688575`}}]}, 
   {Hue[0.6808945303622126], AbsoluteThickness[0.5], 
    LineBox[{{6.355819445214748, -1.0809613611688578`}, {
     6.3300897771464, -1.3967473388681166`}}]}, 
   {Hue[0.6099938069511979], AbsoluteThickness[0.5], 
    LineBox[{{6.4576399530363515`, -1.1325557478900088`}, {
     6.64347334017318, -1.245440602390063}}]}, 
   {Hue[0.6104504399908828], AbsoluteThickness[0.5], 
    LineBox[{{6.64347334017318, -1.245440602390063}, {
     6.888698889454106, -1.3863213734763462`}}]}, 
   {Hue[0.6285274288100987], AbsoluteThickness[0.5], 
    LineBox[{{5.860518242054113, -0.839128868739959}, {
     5.84787880102875, -1.0699692637696454`}}]}, 
   {Hue[0.6292400334093012], AbsoluteThickness[0.5], 
    LineBox[{{5.84787880102875, -1.0699692637696454`}, {
     5.812362079143403, -1.3528110321285494`}}]}, 
   {Hue[0.6853499671563528], AbsoluteThickness[0.5], 
    LineBox[{{4.358652565028932, -0.9751569390416835}, {
     4.278691578825188, -1.0559794935556421`}}]}, 
   {Hue[0.6862415186593828], AbsoluteThickness[0.5], 
    LineBox[{{4.278691578825188, -1.0559794935556421`}, {
     4.102913132111565, -1.267479403083184}}]}, 
   {Hue[0.6188946208090642], AbsoluteThickness[0.5], 
    LineBox[{{5.916530137214064, -0.11618151529877507`}, {
     5.930242265399694, -0.3525752267934792}}]}, 
   {Hue[0.6193334008125323], AbsoluteThickness[0.5], 
    LineBox[{{5.930242265399694, -0.3525752267934792}, {
     5.950082603036835, -0.6207427008287703}}]}, 
   {Hue[0.507771611903213], AbsoluteThickness[0.5], 
    LineBox[{{8.265369680883804, 0.6173366249552241}, {8.325519823778864, 
     0.33880531349783316`}}]}, 
   {Hue[0.5099038231544255], AbsoluteThickness[0.5], 
    LineBox[{{8.325519823778864, 0.33880531349783316`}, {8.341227452391623, 
     0.1106812513935639}}]}, 
   {Hue[0.6184901139485293], AbsoluteThickness[0.5], 
    LineBox[{{5.125944584954543, 1.1152073648838863`}, {5.125676182386895, 
     1.1147365530927205`}}]}, 
   {Hue[0.6189896536569065], AbsoluteThickness[0.5], 
    LineBox[{{5.125676182386895, 1.1147365530927205`}, {4.956320247326729, 
     0.8418836377244369}}]}, 
   {Hue[0.618385233580831], AbsoluteThickness[0.5], 
    LineBox[{{5.12750793307874, 1.113893103206935}, {5.127107856200765, 
     1.1131897067821306`}}]}, 
   {Hue[0.6188923509309168], AbsoluteThickness[0.5], 
    LineBox[{{5.127107856200765, 1.1131897067821306`}, {4.958082859222745, 
     0.8413619757736507}}]}, 
   {Hue[0.6580733216315429], AbsoluteThickness[0.5], 
    LineBox[{{2.898921916017004, 3.423367857281849}, {2.6700749372859374`, 
     3.5651839524146647`}}]}, 
   {Hue[0.6643996719882445], AbsoluteThickness[0.5], 
    LineBox[{{2.6700749372859374`, 3.5651839524146647`}, {2.473133788155841, 
     3.634239667294495}}]}, 
   {Hue[0.5638816315364984], AbsoluteThickness[0.5], 
    LineBox[{{6.265450883855791, -2.830337884481135}, {
     6.2613288367944655`, -3.1031529259989066`}}]}, 
   {Hue[0.5643080566811879], AbsoluteThickness[0.5], 
    LineBox[{{6.2613288367944655`, -3.1031529259989066`}, {
     6.255685701723194, -3.4087417896953545`}}]}, 
   {Hue[0.655503917880001], AbsoluteThickness[0.5], 
    LineBox[{{7.613175489634371, -3.070282724272699}, {
     7.642797252074717, -3.102755392613153}}]}, 
   {Hue[0.6559627749268475], AbsoluteThickness[0.5], 
    LineBox[{{7.642797252074717, -3.102755392613153}, {
     7.863947043839654, -3.357851212301397}}]}, 
   {Hue[0.6249777849845928], AbsoluteThickness[0.5], 
    LineBox[{{3.6474549914141208`, -3.6259414293881043`}, {
     3.294836911509751, -4.080580396392623}}]}, 
   {Hue[0.6263806812881785], AbsoluteThickness[0.5], 
    LineBox[{{3.294836911509751, -4.080580396392623}, {
     3.137457956812264, -4.240756154953614}}]}, 
   {Hue[0.6315375800533077], AbsoluteThickness[0.5], 
    LineBox[{{2.7886268599303374`, -3.4262292037669697`}, {
     2.83726805094932, -3.6018790736717863`}}]}, 
   {Hue[0.6335231061854997], AbsoluteThickness[0.5], 
    LineBox[{{2.83726805094932, -3.6018790736717863`}, {
     2.867158436195579, -3.829064221102564}}]}, 
   {Hue[0.5500108752351651], AbsoluteThickness[0.5], 
    LineBox[{{6.0468398197260615`, -0.15256604111827518`}, {
     6.082662915237249, -0.17954916444837865`}}]}, 
   {Hue[0.5504367592151974], AbsoluteThickness[0.5], 
    LineBox[{{6.082662915237249, -0.17954916444837865`}, {
     6.348511926731925, -0.3794753668318248}}]}, 
   {Hue[0.6467482517082622], AbsoluteThickness[0.5], 
    LineBox[{{3.0726678157857443`, -3.159846358286216}, {
     3.090247960059215, -3.4064878090482416`}}]}, 
   {Hue[0.6475619133161046], AbsoluteThickness[0.5], 
    LineBox[{{3.090247960059215, -3.4064878090482416`}, {
     3.087738764963825, -3.6865902757657762`}}]}, 
   {Hue[0.6053617697662841], AbsoluteThickness[0.5], 
    LineBox[{{3.2722174507406647`, -4.398673009144304}, {
     3.2859794351903764`, -4.518257182868027}}]}, 
   {Hue[0.6215207397699651], AbsoluteThickness[0.5], 
    LineBox[{{3.2859794351903764`, -4.518257182868027}, {
     3.357977758736339, -4.686818559071904}}]}, 
   {Hue[0.6112542174230688], AbsoluteThickness[0.5], 
    LineBox[{{3.940727122053501, -3.9001051205121313`}, {
     3.667852783817803, -3.9354333099021344`}}]}, 
   {Hue[0.6121007126137498], AbsoluteThickness[0.5], 
    LineBox[{{3.667852783817803, -3.9354333099021344`}, {
     3.397577599733239, -3.9935228088181676`}}]}, 
   {Hue[0.6803578691648439], AbsoluteThickness[0.5], 
    LineBox[{{3.8611422503062918`, 3.6063377762638935`}, {3.659442640044657, 
     3.558108888858868}}]}, 
   {Hue[0.6808557417061184], AbsoluteThickness[0.5], 
    LineBox[{{3.659442640044657, 3.558108888858868}, {3.353168598074446, 
     3.472799023191937}}]}, 
   {Hue[0.6134490582194574], AbsoluteThickness[0.5], 
    LineBox[{{6.289736363515965, -0.4279265821460039}, {
     6.3828029906979, -0.5109826923516838}}]}, 
   {Hue[0.6141728060779952], AbsoluteThickness[0.5], 
    LineBox[{{6.3828029906979, -0.5109826923516838}, {
     6.619986953759674, -0.6940040478433551}}]}, 
   {Hue[0.5482197151686394], AbsoluteThickness[0.5], 
    LineBox[{{8.128975302602791, 1.8467280822779273`}, {8.130107432829067, 
     1.8465499348097691`}}]}, 
   {Hue[0.5490294010829975], AbsoluteThickness[0.5], 
    LineBox[{{8.130107432829067, 1.8465499348097691`}, {8.370464170731102, 
     1.7887900493143614`}}]}, 
   {Hue[0.6018534650342949], AbsoluteThickness[0.5], 
    LineBox[{{6.34858144096538, 0.17305485031267182`}, {6.381391428637422, 
     0.14358325009195905`}}]}, 
   {Hue[0.6022793990412384], AbsoluteThickness[0.5], 
    LineBox[{{6.381391428637422, 0.14358325009195905`}, {
     6.620032966732974, -0.0713188558585213}}]}, 
   {Hue[0.6370202312774543], AbsoluteThickness[0.5], 
    LineBox[{{6.84896645337855, -1.7888405054900018`}, {
     6.942110266692319, -1.8818805181603466`}}]}, 
   {Hue[0.6375052987820911], AbsoluteThickness[0.5], 
    LineBox[{{6.942110266692319, -1.8818805181603466`}, {
     7.141099977830597, -2.094482523143234}}]}, 
   {Hue[0.41192499419933837`], AbsoluteThickness[0.5], 
    LineBox[{{6.811102602752794, -1.847319760714078}, {
     6.921482923522778, -1.8959490421105794`}}]}, 
   {Hue[0.41256373197266116`], AbsoluteThickness[0.5], 
    LineBox[{{6.921482923522778, -1.8959490421105794`}, {
     7.165392368317681, -2.0218208876841404`}}]}, 
   {Hue[0.5109676321579751], AbsoluteThickness[0.5], 
    LineBox[{{7.41940848481094, -0.7430684503325836}, {
     7.4791430435721065`, -0.8355152133078592}}]}, 
   {Hue[0.511412639512447], AbsoluteThickness[0.5], 
    LineBox[{{7.4791430435721065`, -0.8355152133078592}, {
     7.643650688548465, -1.101243518335143}}]}, 
   {Hue[0.5188857814165374], AbsoluteThickness[0.5], 
    LineBox[{{5.698140820509109, -3.909833361381687}, {
     5.683518540024253, -4.094626421621767}}]}, 
   {Hue[0.5196852459981484], AbsoluteThickness[0.5], 
    LineBox[{{5.683518540024253, -4.094626421621767}, {
     5.638743713989404, -4.376010070499919}}]}, 
   {Hue[0.610459559410689], AbsoluteThickness[0.5], 
    LineBox[{{3.4078760843545353`, -0.17498192092571602`}, {
     3.390309756773288, -0.18788338776385893`}}]}, 
   {Hue[0.6108854243034902], AbsoluteThickness[0.5], 
    LineBox[{{3.390309756773288, -0.18788338776385893`}, {
     3.1348654532715856`, -0.37567449969633726`}}]}, 
   {Hue[0.642771956012049], AbsoluteThickness[0.5], 
    LineBox[{{5.667155504861843, -0.8365643262589335}, {
     5.685733763255035, -1.0615618473214579`}}]}, 
   {Hue[0.6433399651786459], AbsoluteThickness[0.5], 
    LineBox[{{5.685733763255035, -1.0615618473214579`}, {
     5.725521214793974, -1.3580526099063395`}}]}, 
   {Hue[0.6705374252106878], AbsoluteThickness[0.5], 
    LineBox[{{4.073923362661346, 2.2540624195184087`}, {3.8289403624687894`, 
     2.18395949477298}}]}, 
   {Hue[0.6712522168817059], AbsoluteThickness[0.5], 
    LineBox[{{3.8289403624687894`, 2.18395949477298}, {3.598245970512421, 
     2.135210154388042}}]}, 
   {Hue[0.6331384333835797], AbsoluteThickness[0.5], 
    LineBox[{{3.1476438126796924`, 3.386377317383355}, {2.668605297109755, 
     3.369754423929008}}]}, 
   {Hue[0.6340435772942171], AbsoluteThickness[0.5], 
    LineBox[{{2.668605297109755, 3.369754423929008}, {2.3729736239521633`, 
     3.385434283518879}}]}, 
   {Hue[0.6294165605425112], AbsoluteThickness[0.5], 
    LineBox[{{4.227508507987348, -0.41407637705659406`}, {
     4.128729400233654, -0.5242652614175635}}]}, 
   {Hue[0.6331982913641182], AbsoluteThickness[0.5], 
    LineBox[{{4.128729400233654, -0.5242652614175635}, {
     3.971296545108753, -0.6460029204857657}}]}, 
   {Hue[0.6292367558045966], AbsoluteThickness[0.5], 
    LineBox[{{2.7764650826370234`, -1.3819378318042619`}, {
     2.627010750952619, -1.5948346705387653`}}]}, 
   {Hue[0.637768314003238], AbsoluteThickness[0.5], 
    LineBox[{{2.627010750952619, -1.5948346705387653`}, {
     2.5573539299401027`, -1.773029560276039}}]}, 
   {Hue[0.6645248965081836], AbsoluteThickness[0.5], 
    LineBox[{{2.146125804373175, -3.263625546825293}, {
     2.1206564775047214`, -3.4009459750120374`}}]}, 
   {Hue[0.6660973287808957], AbsoluteThickness[0.5], 
    LineBox[{{2.1206564775047214`, -3.4009459750120374`}, {
     2.0471726840126716`, -3.6321943387411695`}}]}, 
   {Hue[0.5903649155447631], AbsoluteThickness[0.5], 
    LineBox[{{7.440437150444039, -3.677467573319588}, {
     7.409049380254523, -3.7440782046106187`}}]}, 
   {Hue[0.5914533941055564], AbsoluteThickness[0.5], 
    LineBox[{{7.409049380254523, -3.7440782046106187`}, {
     7.307270233632588, -3.9136445541160185`}}]}, 
   {Hue[0.6681675648114572], AbsoluteThickness[0.5], 
    LineBox[{{5.919203996310539, -1.9415501279422243`}, {
     5.387597689263363, -2.254142808031448}}]}, 
   {Hue[0.6690906480471456], AbsoluteThickness[0.5], 
    LineBox[{{5.387597689263363, -2.254142808031448}, {
     5.127351028486624, -2.3774643912473565`}}]}, 
   {Hue[0.6993737768971039], AbsoluteThickness[0.5], 
    LineBox[{{6.6821679720876, -2.3131451992433747`}, {
     6.658504585415838, -2.323075010902361}}]}, 
   {Hue[0.7], AbsoluteThickness[0.5], 
    LineBox[{{6.658504585415838, -2.323075010902361}, {
     6.373145260601066, -2.463418605209668}}]}, 
   {Hue[0.5132522720364328], AbsoluteThickness[0.5], 
    LineBox[{{7.85503313393785, -2.3722783101316423`}, {
     7.8564722902842, -2.3740815983100556`}}]}, 
   {Hue[0.5137401880894555], AbsoluteThickness[0.5], 
    LineBox[{{7.8564722902842, -2.3740815983100556`}, {
     8.031203008274142, -2.609168160994198}}]}, 
   {Hue[0.6717216521688097], AbsoluteThickness[0.5], 
    LineBox[{{4.1297619399001055`, -1.876933837130775}, {
     4.048834386859633, -1.9134805000106974`}}]}, 
   {Hue[0.6725517662788], AbsoluteThickness[0.5], 
    LineBox[{{4.048834386859633, -1.9134805000106974`}, {
     3.844976811233043, -2.026372501257352}}]}, 
   {Hue[0.6922278958234253], AbsoluteThickness[0.5], 
    LineBox[{{2.4653510565744354`, 2.689881330009678}, {2.3253211986687328`, 
     2.7389800714441055`}}]}, 
   {Hue[0.6926540011791659], AbsoluteThickness[0.5], 
    LineBox[{{2.3253211986687328`, 2.7389800714441055`}, {2.0791369314085033`,
      2.8246847467474496`}}]}, 
   {Hue[0.670217222240155], AbsoluteThickness[0.5], 
    LineBox[{{2.6099701769338224`, 2.6514950955566032`}, {2.6088673703795204`,
      2.651885280387879}}]}, 
   {Hue[0.6768998386556364], AbsoluteThickness[0.5], 
    LineBox[{{2.6088673703795204`, 2.651885280387879}, {2.4249831250930063`, 
     2.673794079973199}}]}, 
   {Hue[0.6760089181528768], AbsoluteThickness[0.5], 
    LineBox[{{4.886521429511438, -1.0065269395006466`}, {
     4.760427446617796, -1.0637936865247328`}}]}, 
   {Hue[0.6787968434429097], AbsoluteThickness[0.5], 
    LineBox[{{4.760427446617796, -1.0637936865247328`}, {
     4.591057342731512, -1.1097384512699517`}}]}, 
   {Hue[0.5804947713175117], AbsoluteThickness[0.5], 
    LineBox[{{7.404648896999284, -2.0872448436695152`}, {
     7.423580929275376, -2.3933432499301657`}}]}, 
   {Hue[0.5810122129849169], AbsoluteThickness[0.5], 
    LineBox[{{7.423580929275376, -2.3933432499301657`}, {
     7.4549119419967385`, -2.695773474669179}}]}, 
   {Hue[0.6737987845568636], AbsoluteThickness[0.5], 
    LineBox[{{3.3743060117984514`, 2.6256585036078928`}, {3.2118167283704797`,
      2.5381148061924583`}}]}, 
   {Hue[0.674294194718679], AbsoluteThickness[0.5], 
    LineBox[{{3.2118167283704797`, 2.5381148061924583`}, {2.885923967441558, 
     2.3775268506857437`}}]}, 
   {Hue[0.6235887988168252], AbsoluteThickness[0.5], 
    LineBox[{{6.536378875421498, -3.180621263077501}, {
     6.537074216680973, -3.315874383932462}}]}, 
   {Hue[0.6241287214605727], AbsoluteThickness[0.5], 
    LineBox[{{6.537074216680973, -3.315874383932462}, {
     6.52521129942522, -3.605993359919443}}]}, 
   {Hue[0.6091579539228854], AbsoluteThickness[0.5], 
    LineBox[{{5.094250718311349, -3.323952200950803}, {
     5.070154701754886, -3.3438041336972018`}}]}, 
   {Hue[0.6098624491716489], AbsoluteThickness[0.5], 
    LineBox[{{5.070154701754886, -3.3438041336972018`}, {
     4.840266800779301, -3.5078523878027394`}}]}, 
   {Hue[0.6923401223530142], AbsoluteThickness[0.5], 
    LineBox[{{7.593389328174188, -3.081839629196285}, {
     7.588695474944856, -3.153317424160739}}]}, 
   {Hue[0.6706115150499097], AbsoluteThickness[0.5], 
    LineBox[{{3.853895879813507, -2.07667746648865}, {
     3.826230415296862, -2.0886367448991394`}}]}, 
   {Hue[0.6724844835378055], AbsoluteThickness[0.5], 
    LineBox[{{3.826230415296862, -2.0886367448991394`}, {
     3.656568979849653, -2.1911668031095592`}}]}, 
   {Hue[0.6166374964308807], AbsoluteThickness[0.5], 
    LineBox[{{2.3351704243193216`, -1.4678020819757058`}, {
     2.261087500116173, -1.5649817171911231`}}]}, 
   {Hue[0.6177474116174705], AbsoluteThickness[0.5], 
    LineBox[{{2.261087500116173, -1.5649817171911231`}, {
     2.1341321523900394`, -1.7721400917120582`}}]}, 
   {Hue[0.5880299755463367], AbsoluteThickness[0.5], 
    LineBox[{{3.195611615130556, -4.364051097425589}, {
     3.163954621870089, -4.4980170804116675`}}]}, 
   {Hue[0.5985299241907175], AbsoluteThickness[0.5], 
    LineBox[{{3.163954621870089, -4.4980170804116675`}, {
     3.0759695116888794`, -4.664093883655732}}]}, 
   {Hue[0.6257001554138686], AbsoluteThickness[0.5], 
    LineBox[{{2.5562379792331087`, 3.696785817077129}, {2.3743810270375634`, 
     3.722215606297828}}]}, 
   {Hue[0.6261493020868534], AbsoluteThickness[0.5], 
    LineBox[{{2.3743810270375634`, 3.722215606297828}, {2.076929595087193, 
     3.7573698636445343`}}]}, 
   {Hue[0.6573963880820569], AbsoluteThickness[0.5], 
    LineBox[{{7.603448118696625, 0.07188772153539935}, {7.657002602982537, 
     0.06990842644658593}}]}, 
   {Hue[0.6758660472692476], AbsoluteThickness[0.5], 
    LineBox[{{7.657002602982537, 0.06990842644658593}, {7.737884003719304, 
     0.04157859154768473}}]}, 
   {Hue[0.47425904745429637`], AbsoluteThickness[0.5], 
    LineBox[{{7.656164033468119, 0.00388053409978778}, {
     7.795602685932063, -0.09909122935849812}}]}, 
   {Hue[0.6845959563047845], AbsoluteThickness[0.5], 
    LineBox[{{7.661346339655778, -0.08200944736298293}, {
     7.670575853410365, -0.10847309814490258`}}]}, 
   {Hue[0.6850562405751657], AbsoluteThickness[0.5], 
    LineBox[{{7.670575853410365, -0.10847309814490258`}, {
     7.757511057990773, -0.38008938210294685`}}]}, 
   {Hue[0.6185378388105032], AbsoluteThickness[0.5], 
    LineBox[{{4.634856166160669, 3.3177990760907483`}, {4.432338532622577, 
     3.3235227475623974`}}]}, 
   {Hue[0.6190232419074531], AbsoluteThickness[0.5], 
    LineBox[{{4.432338532622577, 3.3235227475623974`}, {4.080628883455281, 
     3.3453443580009683`}}]}, 
   {Hue[0.5642557616384409], AbsoluteThickness[0.5], 
    LineBox[{{7.384731341770811, 1.6430025991553125`}, {7.386985335367384, 
     1.6349427979530715`}}]}, 
   {Hue[0.5649062199137926], AbsoluteThickness[0.5], 
    LineBox[{{7.386985335367384, 1.6349427979530715`}, {7.447495728601493, 
     1.3506931534024529`}}]}, 
   {Hue[0.6073241561973273], AbsoluteThickness[0.5], 
    LineBox[{{6.625338666623581, 3.2677414991415046`}, {6.443041145113933, 
     3.2153573515339398`}}]}, 
   {Hue[0.607903679879776], AbsoluteThickness[0.5], 
    LineBox[{{6.443041145113933, 3.2153573515339398`}, {6.155171368570712, 
     3.1158816520449086`}}]}, 
   {Hue[0.5923942201590425], AbsoluteThickness[0.5], 
    LineBox[{{6.601095269047666, 2.620713467258177}, {6.597511005496018, 
     2.618495246561053}}]}, 
   {Hue[0.5928350594474013], AbsoluteThickness[0.5], 
    LineBox[{{6.597511005496018, 2.618495246561053}, {6.312158430422439, 
     2.4485831079417952`}}]}, 
   {Hue[0.5934940819998199], AbsoluteThickness[0.5], 
    LineBox[{{4.9821327185112185`, 1.8462422589072365`}, {4.85711908986633, 
     1.7694704079669419`}}]}, 
   {Hue[0.5939340454147629], AbsoluteThickness[0.5], 
    LineBox[{{4.85711908986633, 1.7694704079669419`}, {4.599059695615218, 
     1.6050274962531759`}}]}, 
   {Hue[0.6814535392475614], AbsoluteThickness[0.5], 
    LineBox[{{6.3300897771464, -1.3967473388681166`}, {
     6.289259616883371, -1.7071777488785385`}}]}, 
   {Hue[0.6823199017260353], AbsoluteThickness[0.5], 
    LineBox[{{6.289259616883371, -1.7071777488785385`}, {
     6.244971727631186, -1.909615852449876}}]}, 
   {Hue[0.6109070730305677], AbsoluteThickness[0.5], 
    LineBox[{{6.888698889454106, -1.3863213734763462`}, {
     6.896725192257936, -1.3906752392913224`}}]}, 
   {Hue[0.6119129599624554], AbsoluteThickness[0.5], 
    LineBox[{{6.896725192257936, -1.3906752392913224`}, {
     7.095339007569644, -1.524221248078049}}]}, 
   {Hue[0.6299526380085038], AbsoluteThickness[0.5], 
    LineBox[{{5.812362079143403, -1.3528110321285494`}, {
     5.768687552244283, -1.573780058802838}}]}, 
   {Hue[0.630399442858248], AbsoluteThickness[0.5], 
    LineBox[{{5.768687552244283, -1.573780058802838}, {
     5.714253840290816, -1.8817804023755529`}}]}, 
   {Hue[0.6871330701624127], AbsoluteThickness[0.5], 
    LineBox[{{4.102913132111565, -1.267479403083184}, {
     4.040170004788002, -1.3578651641195691`}}]}, 
   {Hue[0.6875736907175863], AbsoluteThickness[0.5], 
    LineBox[{{4.040170004788002, -1.3578651641195691`}, {
     3.8938895626502643`, -1.5764303117977925`}}]}, 
   {Hue[0.619772180816], AbsoluteThickness[0.5], 
    LineBox[{{5.950082603036835, -0.6207427008287703}, {
     5.97023748298438, -0.8446809574506541}}]}, 
   {Hue[0.620262057967064], AbsoluteThickness[0.5], 
    LineBox[{{5.97023748298438, -0.8446809574506541}, {
     6.007048934924831, -1.1384163522927242`}}]}, 
   {Hue[0.512036034405638], AbsoluteThickness[0.5], 
    LineBox[{{8.341227452391623, 0.11068125139356388`}, {
     8.327163819542704, -0.0759968738934112}}]}, 
   {Hue[0.5125280499851949], AbsoluteThickness[0.5], 
    LineBox[{{8.327163819542704, -0.0759968738934112}, {
     8.290560566361714, -0.4054054254208461}}]}, 
   {Hue[0.6194891933652837], AbsoluteThickness[0.5], 
    LineBox[{{4.956320247326729, 0.8418836377244369}, {4.897971889898232, 
     0.7552736067184654}}]}, 
   {Hue[0.6206835583109978], AbsoluteThickness[0.5], 
    LineBox[{{4.897971889898232, 0.7552736067184654}, {4.73514652639224, 
     0.5616627675230024}}]}, 
   {Hue[0.6193994682810027], AbsoluteThickness[0.5], 
    LineBox[{{4.958082859222745, 0.8413619757736507}, {4.898431077491128, 
     0.7533134991721826}}]}, 
   {Hue[0.6206308500890083], AbsoluteThickness[0.5], 
    LineBox[{{4.898431077491128, 0.7533134991721826}, {4.735708600166107, 
     0.5616276381678873}}]}, 
   {Hue[0.670726022344946], AbsoluteThickness[0.5], 
    LineBox[{{2.473133788155841, 3.634239667294495}, {2.3579202440083633`, 
     3.6480986534005377`}}]}, 
   {Hue[0.671257348925732], AbsoluteThickness[0.5], 
    LineBox[{{2.3579202440083633`, 3.6480986534005377`}, {2.0730027268356324`,
      3.695263018154518}}]}, 
   {Hue[0.5647344818258772], AbsoluteThickness[0.5], 
    LineBox[{{6.255685701723194, -3.4087417896953545`}, {
     6.2515398542363325`, -3.5987094534829}}]}, 
   {Hue[0.5651913865227812], AbsoluteThickness[0.5], 
    LineBox[{{6.2515398542363325`, -3.5987094534829}, {
     6.237687502770319, -3.8973424952887434`}}]}, 
   {Hue[0.6564216319736942], AbsoluteThickness[0.5], 
    LineBox[{{7.863947043839654, -3.357851212301397}, {
     7.889447652192413, -3.3888138477674072`}}]}, 
   {Hue[0.6570195921049365], AbsoluteThickness[0.5], 
    LineBox[{{7.889447652192413, -3.3888138477674072`}, {
     8.084473530306214, -3.6003953980442054`}}]}, 
   {Hue[0.6277835775917643], AbsoluteThickness[0.5], 
    LineBox[{{3.137457956812264, -4.240756154953614}, {
     3.0034423345868206`, -4.34853205716194}}]}, 
   {Hue[0.6314279134177144], AbsoluteThickness[0.5], 
    LineBox[{{3.0034423345868206`, -4.34853205716194}, {
     2.85331485672713, -4.430172625393303}}]}, 
   {Hue[0.6355086323176917], AbsoluteThickness[0.5], 
    LineBox[{{2.867158436195579, -3.829064221102564}, {
     2.8671251631263863`, -3.832970559842751}}]}, 
   {Hue[0.6367101966896173], AbsoluteThickness[0.5], 
    LineBox[{{2.8671251631263863`, -3.832970559842751}, {
     2.892188884882182, -4.08719734670312}}]}, 
   {Hue[0.5508626431952298], AbsoluteThickness[0.5], 
    LineBox[{{6.348511926731925, -0.3794753668318248}, {
     6.420186320347976, -0.43329044126272076`}}]}, 
   {Hue[0.5512915939672174], AbsoluteThickness[0.5], 
    LineBox[{{6.420186320347976, -0.43329044126272076`}, {
     6.686679527092785, -0.6366544407880373}}]}, 
   {Hue[0.6483755749239469], AbsoluteThickness[0.5], 
    LineBox[{{3.087738764963825, -3.6865902757657762`}, {
     3.0750596373214902`, -3.828558038852899}}]}, 
   {Hue[0.6492063402507947], AbsoluteThickness[0.5], 
    LineBox[{{3.0750596373214902`, -3.828558038852899}, {
     3.0282763525262046`, -4.099977303351206}}]}, 
   {Hue[0.6129472078044307], AbsoluteThickness[0.5], 
    LineBox[{{3.397577599733239, -3.9935228088181676`}, {
     2.90092881496671, -4.144254528682409}}]}, 
   {Hue[0.613586007677808], AbsoluteThickness[0.5], 
    LineBox[{{2.90092881496671, -4.144254528682409}, {
     2.620685453665359, -4.248495009490144}}]}, 
   {Hue[0.6813536142473929], AbsoluteThickness[0.5], 
    LineBox[{{3.353168598074446, 3.472799023191937}, {2.873007734260582, 
     3.319728596580408}}]}, 
   {Hue[0.6820639903199853], AbsoluteThickness[0.5], 
    LineBox[{{2.873007734260582, 3.319728596580408}, {2.6063630157182653`, 
     3.213666009830594}}]}, 
   {Hue[0.614896553936533], AbsoluteThickness[0.5], 
    LineBox[{{6.619986953759674, -0.6940040478433551}, {
     6.647699709156817, -0.712391090501299}}]}, 
   {Hue[0.6153239519985938], AbsoluteThickness[0.5], 
    LineBox[{{6.647699709156817, -0.712391090501299}, {
     6.889166358902941, -0.8745266268336298}}]}, 
   {Hue[0.6027053330481819], AbsoluteThickness[0.5], 
    LineBox[{{6.620032966732974, -0.0713188558585213}, {
     6.636710721622637, -0.08637552514015198}}]}, 
   {Hue[0.6032606606485104], AbsoluteThickness[0.5], 
    LineBox[{{6.636710721622637, -0.08637552514015198}, {
     6.85770203869262, -0.306394084307807}}]}, 
   {Hue[0.6379903662867279], AbsoluteThickness[0.5], 
    LineBox[{{7.141099977830597, -2.094482523143234}, {
     7.151862189325563, -2.106784921308509}}]}, 
   {Hue[0.6384517942991818], AbsoluteThickness[0.5], 
    LineBox[{{7.151862189325563, -2.106784921308509}, {
     7.349109262287151, -2.3445640369222334`}}]}, 
   {Hue[0.4132024697459839], AbsoluteThickness[0.5], 
    LineBox[{{7.165392368317681, -2.0218208876841404`}, {
     7.612363602778493, -2.2884431681602897`}}]}, 
   {Hue[0.41451690158890475`], AbsoluteThickness[0.5], 
    LineBox[{{7.612363602778493, -2.2884431681602897`}, {
     7.831463463761261, -2.3876514529395703`}}]}, 
   {Hue[0.5118576468669187], AbsoluteThickness[0.5], 
    LineBox[{{7.643650688548465, -1.101243518335143}, {
     7.661223376483112, -1.130894371323315}}]}, 
   {Hue[0.512357669758816], AbsoluteThickness[0.5], 
    LineBox[{{7.661223376483112, -1.130894371323315}, {
     7.837025999119502, -1.4036815954050308`}}]}, 
   {Hue[0.5204847105797592], AbsoluteThickness[0.5], 
    LineBox[{{5.638743713989404, -4.376010070499919}, {
     5.63713438058045, -4.382683468270461}}]}, 
   {Hue[0.5222601491610308], AbsoluteThickness[0.5], 
    LineBox[{{5.63713438058045, -4.382683468270461}, {
     5.6134370144256724`, -4.608588312428118}}]}, 
   {Hue[0.6113112891962916], AbsoluteThickness[0.5], 
    LineBox[{{3.1348654532715856`, -0.37567449969633726`}, {
     3.133283092238982, -0.37683890712445034`}}]}, 
   {Hue[0.6117405902519495], AbsoluteThickness[0.5], 
    LineBox[{{3.133283092238982, -0.37683890712445034`}, {
     2.8797543985585126`, -0.5602019316967672}}]}, 
   {Hue[0.6439079743452428], AbsoluteThickness[0.5], 
    LineBox[{{5.725521214793974, -1.3580526099063395`}, {
     5.765749496289483, -1.5737185821916975`}}]}, 
   {Hue[0.6443637685410861], AbsoluteThickness[0.5], 
    LineBox[{{5.765749496289483, -1.5737185821916975`}, {
     5.815460435693613, -1.8811418665828301`}}]}, 
   {Hue[0.671967008552724], AbsoluteThickness[0.5], 
    LineBox[{{3.598245970512421, 2.135210154388042}, {3.583813789515727, 
     2.133208751353198}}]}, 
   {Hue[0.6767766422113478], AbsoluteThickness[0.5], 
    LineBox[{{3.583813789515727, 2.133208751353198}, {3.428056622006744, 
     2.0788153781225205`}}]}, 
   {Hue[0.6349487212048547], AbsoluteThickness[0.5], 
    LineBox[{{2.3729736239521633`, 3.385434283518879}, {2.130898096848381, 
     3.419712048224451}}]}, 
   {Hue[0.6355731508173037], AbsoluteThickness[0.5], 
    LineBox[{{2.130898096848381, 3.419712048224451}, {1.857499664753598, 
     3.475185409637206}}]}, 
   {Hue[0.6369800221857254], AbsoluteThickness[0.5], 
    LineBox[{{3.971296545108753, -0.6460029204857657}, {
     3.9269145689543565`, -0.668912057968803}}]}, 
   {Hue[0.637408017349615], AbsoluteThickness[0.5], 
    LineBox[{{3.9269145689543565`, -0.668912057968803}, {
     3.6546010237332194`, -0.8072425147732455}}]}, 
   {Hue[0.6462998722018791], AbsoluteThickness[0.5], 
    LineBox[{{2.5573539299401027`, -1.773029560276039}, {
     2.5512780585542845`, -1.8183710362726588`}}]}, 
   {Hue[0.6468295257565487], AbsoluteThickness[0.5], 
    LineBox[{{2.5512780585542845`, -1.8183710362726588`}, {
     2.4971499188158277`, -2.120614691945374}}]}, 
   {Hue[0.6676697610536078], AbsoluteThickness[0.5], 
    LineBox[{{2.0471726840126716`, -3.6321943387411695`}, {
     1.951778438868305, -3.8391210900106105`}}]}, 
   {Hue[0.6695115545785036], AbsoluteThickness[0.5], 
    LineBox[{{1.951778438868305, -3.8391210900106105`}, {
     1.8789243850365844`, -4.07675672383878}}]}, 
   {Hue[0.5925418726663497], AbsoluteThickness[0.5], 
    LineBox[{{7.307270233632588, -3.9136445541160185`}, {
     7.193306535028217, -4.066445881350842}}]}, 
   {Hue[0.5940181680022434], AbsoluteThickness[0.5], 
    LineBox[{{7.193306535028217, -4.066445881350842}, {
     7.073646426140753, -4.275138670711803}}]}, 
   {Hue[0.6700137312828339], AbsoluteThickness[0.5], 
    LineBox[{{5.127351028486624, -2.3774643912473565`}, {
     5.095975916179526, -2.3890411578488253`}}]}, 
   {Hue[0.670473003818413], AbsoluteThickness[0.5], 
    LineBox[{{5.095975916179526, -2.3890411578488253`}, {
     4.827584008551751, -2.495902893490062}}]}, 
   {Hue[0.5142281041424783], AbsoluteThickness[0.5], 
    LineBox[{{8.031203008274142, -2.609168160994198}, {
     8.107872635423494, -2.720093490730732}}]}, 
   {Hue[0.515255203442393], AbsoluteThickness[0.5], 
    LineBox[{{8.107872635423494, -2.720093490730732}, {
     8.248394193998207, -2.9722322799903087`}}]}, 
   {Hue[0.6733818803887901], AbsoluteThickness[0.5], 
    LineBox[{{3.844976811233043, -2.026372501257352}, {
     3.752199511796017, -2.088129665820767}}]}, 
   {Hue[0.685671781353077], AbsoluteThickness[0.5], 
    LineBox[{{3.752199511796017, -2.088129665820767}, {
     3.6551517408398477`, -2.1996402902971544`}}]}, 
   {Hue[0.6930801065349065], AbsoluteThickness[0.5], 
    LineBox[{{2.0791369314085033`, 2.8246847467474496`}, {2.022592047046506, 
     2.8442287957117443`}}]}, 
   {Hue[0.683582455071118], AbsoluteThickness[0.5], 
    LineBox[{{2.4249831250930063`, 2.673794079973199}, {2.236827205186796, 
     2.6543652247556406`}}]}, 
   {Hue[0.6815847687329427], AbsoluteThickness[0.5], 
    LineBox[{{4.591057342731512, -1.1097384512699517`}, {
     4.568947302697387, -1.1120346014042195`}}]}, 
   {Hue[0.5815296546523221], AbsoluteThickness[0.5], 
    LineBox[{{7.4549119419967385`, -2.695773474669179}, {
     7.477758758781938, -2.8525744258396246`}}]}, 
   {Hue[0.5820597465836903], AbsoluteThickness[0.5], 
    LineBox[{{7.477758758781938, -2.8525744258396246`}, {
     7.52372126101211, -3.0931518763713113`}}]}, 
   {Hue[0.6747896048804946], AbsoluteThickness[0.5], 
    LineBox[{{2.885923967441558, 2.3775268506857437`}, {2.8534125477264456`, 
     2.3629493971713176`}}]}, 
   {Hue[0.6752657964172856], AbsoluteThickness[0.5], 
    LineBox[{{2.8534125477264456`, 2.3629493971713176`}, {2.5403871699446454`,
      2.210745342140647}}]}, 
   {Hue[0.6246686441043202], AbsoluteThickness[0.5], 
    LineBox[{{6.52521129942522, -3.605993359919443}, {
     6.5043453840166405`, -3.8455716508119355`}}]}, 
   {Hue[0.62509565584919], AbsoluteThickness[0.5], 
    LineBox[{{6.5043453840166405`, -3.8455716508119355`}, {
     6.47725142519477, -4.174851693333649}}]}, 
   {Hue[0.6105669444204124], AbsoluteThickness[0.5], 
    LineBox[{{4.840266800779301, -3.5078523878027394`}, {
     4.342967641370358, -3.8130680329994058`}}]}, 
   {Hue[0.6132142244550757], AbsoluteThickness[0.5], 
    LineBox[{{4.342967641370358, -3.8130680329994058`}, {
     4.2281321529499225`, -3.911470090579482}}]}, 
   {Hue[0.6743574520257014], AbsoluteThickness[0.5], 
    LineBox[{{3.656568979849653, -2.1911668031095592`}, {
     3.134126793926831, -2.6129201368796235`}}]}, 
   {Hue[0.6188573268040602], AbsoluteThickness[0.5], 
    LineBox[{{2.1341321523900394`, -1.7721400917120582`}, {
     2.117595544888155, -1.806525069873295}}]}, 
   {Hue[0.619294050444607], AbsoluteThickness[0.5], 
    LineBox[{{2.117595544888155, -1.806525069873295}, {
     1.9664523904852502`, -2.1094000205732324`}}]}, 
   {Hue[0.694335706456438], AbsoluteThickness[0.5], 
    LineBox[{{7.737884003719304, 0.04157859154768473}, {
     7.849643314885136, -0.04109005292237211}}]}, 
   {Hue[0.6969589503456202], AbsoluteThickness[0.5], 
    LineBox[{{7.849643314885136, -0.04109005292237211}, {
     7.976904588960164, -0.17063718064607022`}}]}, 
   {Hue[0.47425904745429637`], AbsoluteThickness[0.5], 
    LineBox[{{7.795602685932063, -0.09909122935849812}, {
     7.877496025785315, -0.10756611380160272`}}]}, 
   {Hue[0.47602379391558924`], AbsoluteThickness[0.5], 
    LineBox[{{7.877496025785315, -0.10756611380160272`}, {
     8.07890181571581, -0.1557557220969754}}]}, 
   {Hue[0.6855165248455468], AbsoluteThickness[0.5], 
    LineBox[{{7.757511057990773, -0.38008938210294685`}, {
     7.8059892584011115`, -0.5462011445443831}}]}, 
   {Hue[0.6195086450044031], AbsoluteThickness[0.5], 
    LineBox[{{4.080628883455281, 3.3453443580009683`}, {3.9192986710930553`, 
     3.3608268725173343`}}]}, 
   {Hue[0.6212151837086678], AbsoluteThickness[0.5], 
    LineBox[{{3.9192986710930553`, 3.3608268725173343`}, {3.7011542383534133`,
      3.4108107424783585`}}]}, 
   {Hue[0.5655566781891446], AbsoluteThickness[0.5], 
    LineBox[{{7.447495728601493, 1.3506931534024529`}, {7.468744159786958, 
     1.2069914978384135`}}]}, 
   {Hue[0.5660143538144908], AbsoluteThickness[0.5], 
    LineBox[{{7.468744159786958, 1.2069914978384135`}, {7.510577794479128, 
     0.8657158603036285}}]}, 
   {Hue[0.6084832035622246], AbsoluteThickness[0.5], 
    LineBox[{{6.155171368570712, 3.1158816520449086`}, {6.103394725121491, 
     3.094863951915385}}]}, 
   {Hue[0.6089090982444781], AbsoluteThickness[0.5], 
    LineBox[{{6.103394725121491, 3.094863951915385}, {5.832354569334761, 
     2.984557862474512}}]}, 
   {Hue[0.5932758987357601], AbsoluteThickness[0.5], 
    LineBox[{{6.312158430422439, 2.4485831079417952`}, {6.155143590071331, 
     2.3586940118926876`}}]}, 
   {Hue[0.5943740088297059], AbsoluteThickness[0.5], 
    LineBox[{{4.599059695615218, 1.6050274962531759`}, {4.5670684947244355`, 
     1.5838862733601409`}}]}, 
   {Hue[0.5961228271239215], AbsoluteThickness[0.5], 
    LineBox[{{4.5670684947244355`, 1.5838862733601409`}, {4.412133784008534, 
     1.5085057179426717`}}]}, 
   {Hue[0.6831862642045092], AbsoluteThickness[0.5], 
    LineBox[{{6.244971727631186, -1.909615852449876}, {
     6.190313297072057, -2.0863233188401593`}}]}, 
   {Hue[0.6850229786985081], AbsoluteThickness[0.5], 
    LineBox[{{6.190313297072057, -2.0863233188401593`}, {
     6.149813745587216, -2.328537236436302}}]}, 
   {Hue[0.6129188468943433], AbsoluteThickness[0.5], 
    LineBox[{{7.095339007569644, -1.524221248078049}, {
     7.248625025783172, -1.6499321192597283`}}]}, 
   {Hue[0.6152683969912573], AbsoluteThickness[0.5], 
    LineBox[{{7.248625025783172, -1.6499321192597283`}, {
     7.3870518431380745`, -1.8034726369509528`}}]}, 
   {Hue[0.630846247707992], AbsoluteThickness[0.5], 
    LineBox[{{5.714253840290816, -1.8817804023755529`}, {
     5.677824581922385, -2.115354928742387}}]}, 
   {Hue[0.6314284237875495], AbsoluteThickness[0.5], 
    LineBox[{{5.677824581922385, -2.115354928742387}, {
     5.647857129708009, -2.409877969129411}}]}, 
   {Hue[0.68801431127276], AbsoluteThickness[0.5], 
    LineBox[{{3.8938895626502643`, -1.5764303117977925`}, {
     3.808406020150058, -1.7089748840624546`}}]}, 
   {Hue[0.6885450821403418], AbsoluteThickness[0.5], 
    LineBox[{{3.808406020150058, -1.7089748840624546`}, {
     3.6597548707287904`, -1.9185071769942716`}}]}, 
   {Hue[0.6207519351181279], AbsoluteThickness[0.5], 
    LineBox[{{6.007048934924831, -1.1384163522927242`}, {
     6.0393227829288945`, -1.3389345418394962`}}]}, 
   {Hue[0.6217253262497189], AbsoluteThickness[0.5], 
    LineBox[{{6.0393227829288945`, -1.3389345418394962`}, {
     6.057308236112045, -1.607403877544903}}]}, 
   {Hue[0.5130200655647517], AbsoluteThickness[0.5], 
    LineBox[{{8.290560566361714, -0.4054054254208461}, {
     8.263816254745741, -0.587113023910422}}]}, 
   {Hue[0.5134877176487176], AbsoluteThickness[0.5], 
    LineBox[{{8.263816254745741, -0.587113023910422}, {
     8.22311831270981, -0.9311270977544646}}]}, 
   {Hue[0.6218779232567119], AbsoluteThickness[0.5], 
    LineBox[{{4.73514652639224, 0.5616627675230024}, {4.679116981859106, 
     0.5078561500491768}}]}, 
   {Hue[0.6225586265658823], AbsoluteThickness[0.5], 
    LineBox[{{4.679116981859106, 0.5078561500491768}, {4.4919443417521, 
     0.3506704583278908}}]}, 
   {Hue[0.6218622318970138], AbsoluteThickness[0.5], 
    LineBox[{{4.735708600166107, 0.5616276381678873}, {4.679087350124718, 
     0.5079689214092781}}]}, 
   {Hue[0.622533406217827], AbsoluteThickness[0.5], 
    LineBox[{{4.679087350124718, 0.5079689214092781}, {4.490492314225324, 
     0.3513472582330304}}]}, 
   {Hue[0.5656482912196853], AbsoluteThickness[0.5], 
    LineBox[{{6.237687502770319, -3.8973424952887434`}, {
     6.221877562507504, -4.120005988777282}}]}, 
   {Hue[0.5660850294292812], AbsoluteThickness[0.5], 
    LineBox[{{6.221877562507504, -4.120005988777282}, {
     6.202522408805371, -4.4635698079991135`}}]}, 
   {Hue[0.6576175522361788], AbsoluteThickness[0.5], 
    LineBox[{{8.084473530306214, -3.6003953980442054`}, {
     8.158820504806856, -3.672537881166552}}]}, 
   {Hue[0.6580534984145225], AbsoluteThickness[0.5], 
    LineBox[{{8.158820504806856, -3.672537881166552}, {
     8.385450909418084, -3.8863404841300664`}}]}, 
   {Hue[0.6350722492436646], AbsoluteThickness[0.5], 
    LineBox[{{2.85331485672713, -4.430172625393303}, {
     2.7156069042293565`, -4.475632663202619}}]}, 
   {Hue[0.6355246038059558], AbsoluteThickness[0.5], 
    LineBox[{{2.7156069042293565`, -4.475632663202619}, {
     2.4010846565280537`, -4.587438706269421}}]}, 
   {Hue[0.6379117610615428], AbsoluteThickness[0.5], 
    LineBox[{{2.892188884882182, -4.08719734670312}, {
     2.904953441231246, -4.148570771507939}}]}, 
   {Hue[0.6416877038551965], AbsoluteThickness[0.5], 
    LineBox[{{2.904953441231246, -4.148570771507939}, {
     2.90993414174298, -4.36098339460051}}]}, 
   {Hue[0.5517205447392051], AbsoluteThickness[0.5], 
    LineBox[{{6.686679527092785, -0.6366544407880373}, {
     6.717688066730012, -0.6607028966793652}}]}, 
   {Hue[0.5525060662126673], AbsoluteThickness[0.5], 
    LineBox[{{6.717688066730012, -0.6607028966793652}, {
     6.906703855419936, -0.8323229814989265}}]}, 
   {Hue[0.6500371055776425], AbsoluteThickness[0.5], 
    LineBox[{{3.0282763525262046`, -4.099977303351206}, {
     2.9633334499919166`, -4.351892856991395}}]}, 
   {Hue[0.6506568217977622], AbsoluteThickness[0.5], 
    LineBox[{{2.9633334499919166`, -4.351892856991395}, {
     2.9039037683444393`, -4.6552909014186055`}}]}, 
   {Hue[0.6142248075511852], AbsoluteThickness[0.5], 
    LineBox[{{2.620685453665359, -4.248495009490144}, {
     2.3326715642119162`, -4.376268798860359}}]}, 
   {Hue[0.6186104390346429], AbsoluteThickness[0.5], 
    LineBox[{{2.3326715642119162`, -4.376268798860359}, {
     2.1283593277559065`, -4.423190159719259}}]}, 
   {Hue[0.6827743663925776], AbsoluteThickness[0.5], 
    LineBox[{{2.6063630157182653`, 3.213666009830594}, {2.4531496027314477`, 
     3.1399282260010053`}}]}, 
   {Hue[0.6899286023328093], AbsoluteThickness[0.5], 
    LineBox[{{2.4531496027314477`, 3.1399282260010053`}, {2.3069695813385716`,
      3.0229245098074813`}}]}, 
   {Hue[0.6157513500606547], AbsoluteThickness[0.5], 
    LineBox[{{6.889166358902941, -0.8745266268336298}, {
     6.902478592102191, -0.8835722292291124}}]}, 
   {Hue[0.6165951240280071], AbsoluteThickness[0.5], 
    LineBox[{{6.902478592102191, -0.8835722292291124}, {
     7.098132783092955, -1.041647206754451}}]}, 
   {Hue[0.6038159882488389], AbsoluteThickness[0.5], 
    LineBox[{{6.85770203869262, -0.306394084307807}, {
     6.865594549520117, -0.31505918723909176`}}]}, 
   {Hue[0.6042579015468186], AbsoluteThickness[0.5], 
    LineBox[{{6.865594549520117, -0.31505918723909176`}, {
     7.0817686072083985`, -0.5610095654230524}}]}, 
   {Hue[0.6389132223116357], AbsoluteThickness[0.5], 
    LineBox[{{7.349109262287151, -2.3445640369222334`}, {
     7.398014537477761, -2.4067686400622628`}}]}, 
   {Hue[0.6393454153962641], AbsoluteThickness[0.5], 
    LineBox[{{7.398014537477761, -2.4067686400622628`}, {
     7.590653146189346, -2.6575041683729923`}}]}, 
   {Hue[0.4158313334318256], AbsoluteThickness[0.5], 
    LineBox[{{7.831463463761261, -2.3876514529395703`}, {
     7.844670390084492, -2.3919185813701693`}}]}, 
   {Hue[0.416288960710703], AbsoluteThickness[0.5], 
    LineBox[{{7.844670390084492, -2.3919185813701693`}, {
     8.127526960553944, -2.4911237110956934`}}]}, 
   {Hue[0.5128576926507133], AbsoluteThickness[0.5], 
    LineBox[{{7.837025999119502, -1.4036815954050308`}, {
     7.874652265033216, -1.4575219930231944`}}]}, 
   {Hue[0.5133737407560738], AbsoluteThickness[0.5], 
    LineBox[{{7.874652265033216, -1.4575219930231944`}, {
     8.04807331557566, -1.6851219035822034`}}]}, 
   {Hue[0.6121698913076074], AbsoluteThickness[0.5], 
    LineBox[{{2.8797543985585126`, -0.5602019316967672}, {
     2.7880387895709107`, -0.6253906163367503}}]}, 
   {Hue[0.6146483055093067], AbsoluteThickness[0.5], 
    LineBox[{{2.7880387895709107`, -0.6253906163367503}, {
     2.642603157525169, -0.7668753339832077}}]}, 
   {Hue[0.6448195627369293], AbsoluteThickness[0.5], 
    LineBox[{{5.815460435693613, -1.8811418665828301`}, {
     5.8581774923499665`, -2.19279473431691}}]}, 
   {Hue[0.6540548171931422], AbsoluteThickness[0.5], 
    LineBox[{{5.8581774923499665`, -2.19279473431691}, {
     5.838513137269682, -2.372219024277051}}]}, 
   {Hue[0.6815862758699716], AbsoluteThickness[0.5], 
    LineBox[{{3.428056622006744, 2.0788153781225205`}, {3.1236858312455498`, 
     1.8987741911773015`}}]}, 
   {Hue[0.6888594124651718], AbsoluteThickness[0.5], 
    LineBox[{{3.1236858312455498`, 1.8987741911773015`}, {2.9495367199161224`,
      1.8436565212157179`}}]}, 
   {Hue[0.637836012513505], AbsoluteThickness[0.5], 
    LineBox[{{3.6546010237332194`, -0.8072425147732455}, {
     3.6352158629573195`, -0.8169319429945177}}]}, 
   {Hue[0.6385530772868709], AbsoluteThickness[0.5], 
    LineBox[{{3.6352158629573195`, -0.8169319429945177}, {
     3.3821022150611197`, -0.9666727855388964}}]}, 
   {Hue[0.6473591793112181], AbsoluteThickness[0.5], 
    LineBox[{{2.4971499188158277`, -2.120614691945374}, {
     2.4481514364957895`, -2.338492569736267}}]}, 
   {Hue[0.6485073268937833], AbsoluteThickness[0.5], 
    LineBox[{{2.4481514364957895`, -2.338492569736267}, {
     2.4174437381289438`, -2.59880111081165}}]}, 
   {Hue[0.595494463338137], AbsoluteThickness[0.5], 
    LineBox[{{7.073646426140753, -4.275138670711803}, {
     7.04793884124306, -4.335874361327648}}]}, 
   {Hue[0.5959274278251467], AbsoluteThickness[0.5], 
    LineBox[{{7.04793884124306, -4.335874361327648}, {
     6.9082748078523, -4.677016666388979}}]}, 
   {Hue[0.6709322763539922], AbsoluteThickness[0.5], 
    LineBox[{{4.827584008551751, -2.495902893490062}, {
     4.632723387207279, -2.579289395470585}}]}, 
   {Hue[0.6723561219320697], AbsoluteThickness[0.5], 
    LineBox[{{4.632723387207279, -2.579289395470585}, {
     4.409515094137474, -2.645043123359037}}]}, 
   {Hue[0.5162823027423076], AbsoluteThickness[0.5], 
    LineBox[{{8.248394193998207, -2.9722322799903087`}, {
     8.324441060246778, -3.146198149584564}}]}, 
   {Hue[0.5173324569583354], AbsoluteThickness[0.5], 
    LineBox[{{8.324441060246778, -3.146198149584564}, {
     8.440420912633492, -3.3535716039904258`}}]}, 
   {Hue[0.6979616823173642], AbsoluteThickness[0.5], 
    LineBox[{{3.6551517408398477`, -2.1996402902971544`}, {
     3.5669895343140374`, -2.382698231221222}}]}, 
   {Hue[0.6983883042198745], AbsoluteThickness[0.5], 
    LineBox[{{3.5669895343140374`, -2.382698231221222}, {
     3.4344314282810204`, -2.660700888059832}}]}, 
   {Hue[0.6815847687329428], AbsoluteThickness[0.5], 
    LineBox[{{4.568947302697387, -1.1120346014042195`}, {
     4.415703835937024, -1.2262110081277164`}}]}, 
   {Hue[0.683195558264859], AbsoluteThickness[0.5], 
    LineBox[{{4.415703835937024, -1.2262110081277164`}, {
     4.259970709098641, -1.3760705400366915`}}]}, 
   {Hue[0.5825898385150584], AbsoluteThickness[0.5], 
    LineBox[{{7.52372126101211, -3.0931518763713113`}, {
     7.558814103819643, -3.2411189766397506`}}]}, 
   {Hue[0.5973569035229046], AbsoluteThickness[0.5], 
    LineBox[{{7.558814103819643, -3.2411189766397506`}, {
     7.6498482435499335`, -3.402076625683853}}]}, 
   {Hue[0.6757419879540768], AbsoluteThickness[0.5], 
    LineBox[{{2.5403871699446454`, 2.210745342140647}, {2.156399101215461, 
     2.00905435076678}}]}, 
   {Hue[0.6768545418473556], AbsoluteThickness[0.5], 
    LineBox[{{2.156399101215461, 2.00905435076678}, {1.9411744189700002`, 
     1.9226037056268033`}}]}, 
   {Hue[0.6255226675940597], AbsoluteThickness[0.5], 
    LineBox[{{6.47725142519477, -4.174851693333649}, {
     6.461639865980343, -4.376358060150151}}]}, 
   {Hue[0.6261374237517766], AbsoluteThickness[0.5], 
    LineBox[{{6.461639865980343, -4.376358060150151}, {
     6.455960794371551, -4.673002440240368}}]}, 
   {Hue[0.615861504489739], AbsoluteThickness[0.5], 
    LineBox[{{4.2281321529499225`, -3.911470090579482}, {
     4.1765536569346295`, -3.9721752133526294`}}]}, 
   {Hue[0.6182100427560188], AbsoluteThickness[0.5], 
    LineBox[{{4.1765536569346295`, -3.9721752133526294`}, {
     4.0936940083268185`, -4.1060914196434215`}}]}, 
   {Hue[0.6803554688890578], AbsoluteThickness[0.5], 
    LineBox[{{3.134126793926831, -2.6129201368796235`}, {
     2.917936849583626, -2.781768771251792}}]}, 
   {Hue[0.6820868515469823], AbsoluteThickness[0.5], 
    LineBox[{{2.917936849583626, -2.781768771251792}, {
     2.6944967045332793`, -2.9134554559454098`}}]}, 
   {Hue[0.6995821942348024], AbsoluteThickness[0.5], 
    LineBox[{{7.976904588960164, -0.17063718064607025`}, {
     8.27326581916018, -0.5865735402068892}}]}, 
   {Hue[0.4777885403768821], AbsoluteThickness[0.5], 
    LineBox[{{8.07890181571581, -0.1557557220969754}, {
     8.110083650077982, -0.1677275691269019}}]}, 
   {Hue[0.4782163060487433], AbsoluteThickness[0.5], 
    LineBox[{{8.110083650077982, -0.1677275691269019}, {
     8.42973611997406, -0.28820788512005385`}}]}, 
   {Hue[0.6855165248455468], AbsoluteThickness[0.5], 
    LineBox[{{7.8059892584011115`, -0.5462011445443831}, {
     7.8025348592584445`, -0.6083752473991714}}]}, 
   {Hue[0.6860217836024888], AbsoluteThickness[0.5], 
    LineBox[{{7.8025348592584445`, -0.6083752473991714}, {
     7.797863863312986, -0.886725330345322}}]}, 
   {Hue[0.6229217224129325], AbsoluteThickness[0.5], 
    LineBox[{{3.7011542383534133`, 3.4108107424783585`}, {3.673124014623662, 
     3.4211957231328363`}}]}, 
   {Hue[0.6233480841150605], AbsoluteThickness[0.5], 
    LineBox[{{3.673124014623662, 3.4211957231328363`}, {3.365133870070051, 
     3.5364133439494947`}}]}, 
   {Hue[0.5664720294398373], AbsoluteThickness[0.5], 
    LineBox[{{7.510577794479128, 0.8657158603036286}, {7.5334185585860265`, 
     0.6313289352807301}}]}, 
   {Hue[0.5672312935734349], AbsoluteThickness[0.5], 
    LineBox[{{7.5334185585860265`, 0.6313289352807301}, {7.5863024741606555`, 
     0.32721821485756514`}}]}, 
   {Hue[0.6093349929267315], AbsoluteThickness[0.5], 
    LineBox[{{5.832354569334761, 2.984557862474512}, {5.739665428139701, 
     2.9467391084978116`}}]}, 
   {Hue[0.6161710044689069], AbsoluteThickness[0.5], 
    LineBox[{{5.739665428139701, 2.9467391084978116`}, {5.61431915281813, 
     2.925960662203796}}]}, 
   {Hue[0.59327589873576], AbsoluteThickness[0.5], 
    LineBox[{{6.155143590071331, 2.3586940118926876`}, {5.985700267840742, 
     2.165646384790255}}]}, 
   {Hue[0.5994013565861773], AbsoluteThickness[0.5], 
    LineBox[{{5.985700267840742, 2.165646384790255}, {5.867818928692731, 
     2.078754142542307}}]}, 
   {Hue[0.5978716454181372], AbsoluteThickness[0.5], 
    LineBox[{{4.412133784008534, 1.5085057179426717`}, {4.1453723432256835`, 
     1.4196097767615565`}}]}, 
   {Hue[0.601210377303791], AbsoluteThickness[0.5], 
    LineBox[{{4.1453723432256835`, 1.4196097767615565`}, {4.007729379709157, 
     1.3453028148427408`}}]}, 
   {Hue[0.6868596931925071], AbsoluteThickness[0.5], 
    LineBox[{{6.149813745587216, -2.328537236436302}, {
     6.144490450859584, -2.498203582946883}}]}, 
   {Hue[0.6982665558481213], AbsoluteThickness[0.5], 
    LineBox[{{6.144490450859584, -2.498203582946883}, {
     6.102759338511509, -2.6365841487551527`}}]}, 
   {Hue[0.6176179470881715], AbsoluteThickness[0.5], 
    LineBox[{{7.3870518431380745`, -1.8034726369509528`}, {
     7.408456006668925, -1.8358982071684424`}}]}, 
   {Hue[0.6180467900472307], AbsoluteThickness[0.5], 
    LineBox[{{7.408456006668925, -1.8358982071684424`}, {
     7.567367035398076, -2.0807002774882424`}}]}, 
   {Hue[0.6320105998671068], AbsoluteThickness[0.5], 
    LineBox[{{5.647857129708009, -2.409877969129411}, {
     5.63627126883985, -2.6506500257469385`}}]}, 
   {Hue[0.6327686914812299], AbsoluteThickness[0.5], 
    LineBox[{{5.63627126883985, -2.6506500257469385`}, {
     5.642989552274237, -2.9009455140444844`}}]}, 
   {Hue[0.6890758530079237], AbsoluteThickness[0.5], 
    LineBox[{{3.6597548707287904`, -1.9185071769942716`}, {
     3.6434610090569928`, -1.9394470862910846`}}]}, 
   {Hue[0.6898024662258152], AbsoluteThickness[0.5], 
    LineBox[{{3.6434610090569928`, -1.9394470862910846`}, {
     3.48269564343008, -2.1180184923955507`}}]}, 
   {Hue[0.6226987173813099], AbsoluteThickness[0.5], 
    LineBox[{{6.057308236112045, -1.607403877544903}, {
     6.051132565821505, -1.846733394578716}}]}, 
   {Hue[0.6231307420356471], AbsoluteThickness[0.5], 
    LineBox[{{6.051132565821505, -1.846733394578716}, {
     6.0422861077435535`, -2.086937005863033}}]}, 
   {Hue[0.5139553697326835], AbsoluteThickness[0.5], 
    LineBox[{{8.22311831270981, -0.9311270977544646}, {
     8.209053607149041, -1.0880706240698534`}}]}, 
   {Hue[0.5145492664304947], AbsoluteThickness[0.5], 
    LineBox[{{8.209053607149041, -1.0880706240698534`}, {
     8.199622401950812, -1.3633537769945152`}}]}, 
   {Hue[0.6232393298750528], AbsoluteThickness[0.5], 
    LineBox[{{4.4919443417521, 0.3506704583278908}, {4.451403657620565, 
     0.3209928303262811}}]}, 
   {Hue[0.6237266604224102], AbsoluteThickness[0.5], 
    LineBox[{{4.451403657620565, 0.3209928303262811}, {4.189896547297728, 
     0.14297643679626976`}}]}, 
   {Hue[0.6232045805386403], AbsoluteThickness[0.5], 
    LineBox[{{4.490492314225324, 0.3513472582330304}, {4.450809938345374, 
     0.3225631441929233}}]}, 
   {Hue[0.623685096514466], AbsoluteThickness[0.5], 
    LineBox[{{4.450809938345374, 0.3225631441929233}, {4.188061334293501, 
     0.14465009550084384`}}]}, 
   {Hue[0.6454636466488505], AbsoluteThickness[0.5], 
    LineBox[{{2.90993414174298, -4.36098339460051}, {
     2.9078113870863342`, -4.374291953662138}}]}, 
   {Hue[0.6465895081552853], AbsoluteThickness[0.5], 
    LineBox[{{2.9078113870863342`, -4.374291953662138}, {
     2.892609262003886, -4.647011310104842}}]}, 
   {Hue[0.5532915876861295], AbsoluteThickness[0.5], 
    LineBox[{{6.906703855419936, -0.8323229814989265}, {
     6.946253232414067, -0.8742649183273812}}]}, 
   {Hue[0.5543551085241666], AbsoluteThickness[0.5], 
    LineBox[{{6.946253232414067, -0.8742649183273812}, {
     7.0928235806820235`, -1.0641504112274234`}}]}, 
   {Hue[0.6229960705181004], AbsoluteThickness[0.5], 
    LineBox[{{2.1283593277559065`, -4.423190159719259}, {
     2.117616978796341, -4.423554802013556}}]}, 
   {Hue[0.6239495852476282], AbsoluteThickness[0.5], 
    LineBox[{{2.117616978796341, -4.423554802013556}, {
     1.841728059751892, -4.458280139384017}}]}, 
   {Hue[0.6970828382730414], AbsoluteThickness[0.5], 
    LineBox[{{2.3069695813385716`, 3.0229245098074813`}, {2.217051684875891, 
     2.9092817327415323`}}]}, 
   {Hue[0.6978219754429978], AbsoluteThickness[0.5], 
    LineBox[{{2.217051684875891, 2.9092817327415323`}, {2.086978103167211, 
     2.7176601430837306`}}]}, 
   {Hue[0.6174388979953594], AbsoluteThickness[0.5], 
    LineBox[{{7.098132783092955, -1.041647206754451}, {
     7.203662841767495, -1.1424082173453707`}}]}, 
   {Hue[0.6180209170289166], AbsoluteThickness[0.5], 
    LineBox[{{7.203662841767495, -1.1424082173453707`}, {
     7.40449050870465, -1.3557384738641833`}}]}, 
   {Hue[0.6046998148447982], AbsoluteThickness[0.5], 
    LineBox[{{7.0817686072083985`, -0.5610095654230524}, {
     7.12447492034723, -0.6113703600784248}}]}, 
   {Hue[0.6051302171531131], AbsoluteThickness[0.5], 
    LineBox[{{7.12447492034723, -0.6113703600784248}, {
     7.3626564409025415`, -0.8976900950741802}}]}, 
   {Hue[0.6397776084808923], AbsoluteThickness[0.5], 
    LineBox[{{7.590653146189346, -2.6575041683729923`}, {
     7.615325955604085, -2.690370907965813}}]}, 
   {Hue[0.6402354676367533], AbsoluteThickness[0.5], 
    LineBox[{{7.615325955604085, -2.690370907965813}, {
     7.772104627638885, -2.8887310412258054`}}]}, 
   {Hue[0.5138897888614342], AbsoluteThickness[0.5], 
    LineBox[{{8.04807331557566, -1.6851219035822034`}, {
     8.068938805676842, -1.71028676680541}}]}, 
   {Hue[0.5147379680279307], AbsoluteThickness[0.5], 
    LineBox[{{8.068938805676842, -1.71028676680541}, {
     8.249212888102363, -1.8942158677196408`}}]}, 
   {Hue[0.6171267197110062], AbsoluteThickness[0.5], 
    LineBox[{{2.642603157525169, -0.7668753339832077}, {
     2.5646712943187593`, -0.8703624139705601}}]}, 
   {Hue[0.6175845051496441], AbsoluteThickness[0.5], 
    LineBox[{{2.5646712943187593`, -0.8703624139705601}, {
     2.3596080836550355`, -1.157247715276085}}]}, 
   {Hue[0.6632900716493552], AbsoluteThickness[0.5], 
    LineBox[{{5.838513137269682, -2.372219024277051}, {
     5.740625375377219, -2.636650556678002}}]}, 
   {Hue[0.6637246388932843], AbsoluteThickness[0.5], 
    LineBox[{{5.740625375377219, -2.636650556678002}, {
     5.64615843944406, -2.9024683892889973`}}]}, 
   {Hue[0.696132549060372], AbsoluteThickness[0.5], 
    LineBox[{{2.9495367199161224`, 1.8436565212157179`}, {2.91578947130026, 
     1.8409888719404466`}}]}, 
   {Hue[0.6966659061363697], AbsoluteThickness[0.5], 
    LineBox[{{2.91578947130026, 1.8409888719404466`}, {2.622470830872643, 
     1.804542720901665}}]}, 
   {Hue[0.6392701420602369], AbsoluteThickness[0.5], 
    LineBox[{{3.3821022150611197`, -0.9666727855388964}, {
     3.224365125357284, -1.0757287070240613`}}]}, 
   {Hue[0.6412318389014259], AbsoluteThickness[0.5], 
    LineBox[{{3.224365125357284, -1.0757287070240613`}, {
     3.0455371131817257`, -1.24015648415561}}]}, 
   {Hue[0.6496554744763484], AbsoluteThickness[0.5], 
    LineBox[{{2.4174437381289438`, -2.59880111081165}, {
     2.416816605095714, -2.644781520500396}}]}, 
   {Hue[0.6573536042330705], AbsoluteThickness[0.5], 
    LineBox[{{2.416816605095714, -2.644781520500396}, {
     2.370000768943542, -2.8316746932625865`}}]}, 
   {Hue[0.6737799675101472], AbsoluteThickness[0.5], 
    LineBox[{{4.409515094137474, -2.645043123359037}, {
     4.401872001645496, -2.646344205218175}}]}, 
   {Hue[0.6744366480385557], AbsoluteThickness[0.5], 
    LineBox[{{4.401872001645496, -2.646344205218175}, {
     4.141422905688039, -2.707969986426545}}]}, 
   {Hue[0.6988149261223847], AbsoluteThickness[0.5], 
    LineBox[{{3.4344314282810204`, -2.660700888059832}, {
     3.4024316761626983`, -2.728488952859161}}]}, 
   {Hue[0.6848063477967752], AbsoluteThickness[0.5], 
    LineBox[{{4.259970709098641, -1.3760705400366915`}, {
     3.450806689768134, -2.379210258708659}}]}, 
   {Hue[0.6121239685307509], AbsoluteThickness[0.5], 
    LineBox[{{7.6498482435499335`, -3.402076625683853}, {
     8.067728374594525, -3.8107100052381853`}}]}, 
   {Hue[0.6149398933311148], AbsoluteThickness[0.5], 
    LineBox[{{8.067728374594525, -3.8107100052381853`}, {
     8.19482519320377, -3.9833836252003407`}}]}, 
   {Hue[0.6205585810222985], AbsoluteThickness[0.5], 
    LineBox[{{4.0936940083268185`, -4.1060914196434215`}, {
     3.992585606109777, -4.3426723687386275`}}]}, 
   {Hue[0.621796863275249], AbsoluteThickness[0.5], 
    LineBox[{{3.992585606109777, -4.3426723687386275`}, {
     3.8778196477390376`, -4.546578690181134}}]}, 
   {Hue[0.6838182342049067], AbsoluteThickness[0.5], 
    LineBox[{{2.6944967045332793`, -2.9134554559454098`}, {
     2.617397420637174, -2.946239745737199}}]}, 
   {Hue[0.6843057985082953], AbsoluteThickness[0.5], 
    LineBox[{{2.617397420637174, -2.946239745737199}, {
     2.343113342076487, -3.051918862286229}}]}, 
   {Hue[0.6865270423594305], AbsoluteThickness[0.5], 
    LineBox[{{7.797863863312986, -0.886725330345322}, {
     7.80202590438112, -1.0763599844559903`}}]}, 
   {Hue[0.6869667807330079], AbsoluteThickness[0.5], 
    LineBox[{{7.80202590438112, -1.0763599844559903`}, {
     7.814820804456725, -1.4091481844477491`}}]}, 
   {Hue[0.6237744458171887], AbsoluteThickness[0.5], 
    LineBox[{{3.365133870070051, 3.5364133439494947`}, {3.1300630530102382`, 
     3.6252011429879385`}}]}, 
   {Hue[0.6334047356468259], AbsoluteThickness[0.5], 
    LineBox[{{3.1300630530102382`, 3.6252011429879385`}, {3.0423354506370206`,
      3.686474959544571}}]}, 
   {Hue[0.5679905577070326], AbsoluteThickness[0.5], 
    LineBox[{{7.5863024741606555`, 0.32721821485756514`}, {7.597590896344406, 
     0.2824885754802023}}]}, 
   {Hue[0.5726205328919765], AbsoluteThickness[0.5], 
    LineBox[{{7.597590896344406, 0.2824885754802023}, {7.605786907111898, 
     0.12398738939301089`}}]}, 
   {Hue[0.6230070160110824], AbsoluteThickness[0.5], 
    LineBox[{{5.61431915281813, 2.925960662203796}, {5.597737175844771, 
     2.926937630692795}}]}, 
   {Hue[0.6235755365623565], AbsoluteThickness[0.5], 
    LineBox[{{5.597737175844771, 2.926937630692795}, {5.306017225710853, 
     2.9291986214927843`}}]}, 
   {Hue[0.6055268144365947], AbsoluteThickness[0.5], 
    LineBox[{{5.867818928692731, 2.078754142542307}, {5.643605552430667, 
     1.9786305367959995`}}]}, 
   {Hue[0.612623171327595], AbsoluteThickness[0.5], 
    LineBox[{{5.643605552430667, 1.9786305367959995`}, {5.56914190903269, 
     1.9225116933473307`}}]}, 
   {Hue[0.6045491091894448], AbsoluteThickness[0.5], 
    LineBox[{{4.007729379709157, 1.3453028148427408`}, {3.946299250007618, 
     1.296797201299726}}]}, 
   {Hue[0.6057565081440875], AbsoluteThickness[0.5], 
    LineBox[{{3.946299250007618, 1.296797201299726}, {3.7901668088195843`, 
     1.1437321969884917`}}]}, 
   {Hue[0.6184756330062898], AbsoluteThickness[0.5], 
    LineBox[{{7.567367035398076, -2.0807002774882424`}, {
     7.628656639737911, -2.176721991887068}}]}, 
   {Hue[0.6191191413038658], AbsoluteThickness[0.5], 
    LineBox[{{7.628656639737911, -2.176721991887068}, {
     7.792788387516609, -2.4017598006551846`}}]}, 
   {Hue[0.633526783095353], AbsoluteThickness[0.5], 
    LineBox[{{5.642989552274237, -2.9009455140444844`}, {
     5.643668866755042, -2.9075986050956746`}}]}, 
   {Hue[0.6358808738035258], AbsoluteThickness[0.5], 
    LineBox[{{5.643668866755042, -2.9075986050956746`}, {
     5.633934871821642, -3.107692973601716}}]}, 
   {Hue[0.6905290794437067], AbsoluteThickness[0.5], 
    LineBox[{{3.48269564343008, -2.1180184923955507`}, {
     3.4303777288244657`, -2.1683560530181873`}}]}, 
   {Hue[0.6912597346152207], AbsoluteThickness[0.5], 
    LineBox[{{3.4303777288244657`, -2.1683560530181873`}, {
     3.225004821890163, -2.3392337190446915`}}]}, 
   {Hue[0.6235627666899842], AbsoluteThickness[0.5], 
    LineBox[{{6.0422861077435535`, -2.086937005863033}, {
     6.027011336771846, -2.4060729701755816`}}]}, 
   {Hue[0.6239886558036646], AbsoluteThickness[0.5], 
    LineBox[{{6.027011336771846, -2.4060729701755816`}, {
     6.014342712224227, -2.6662281519930944`}}]}, 
   {Hue[0.5151431631283061], AbsoluteThickness[0.5], 
    LineBox[{{8.199622401950812, -1.3633537769945152`}, {
     8.204577479212206, -1.6005819942484192`}}]}, 
   {Hue[0.5155699206134061], AbsoluteThickness[0.5], 
    LineBox[{{8.204577479212206, -1.6005819942484192`}, {
     8.212063602712718, -1.8987097494766103`}}]}, 
   {Hue[0.6242139909697676], AbsoluteThickness[0.5], 
    LineBox[{{4.189896547297728, 0.14297643679626976`}, {4.157346757213528, 
     0.12241286332565383`}}]}, 
   {Hue[0.6246442305158059], AbsoluteThickness[0.5], 
    LineBox[{{4.157346757213528, 0.12241286332565383`}, {
     3.8852677086934384`, -0.05303254157581197}}]}, 
   {Hue[0.6241656124902919], AbsoluteThickness[0.5], 
    LineBox[{{4.188061334293501, 0.14465009550084384`}, {4.155884278640482, 
     0.12434795363180176`}}]}, 
   {Hue[0.6245978362311974], AbsoluteThickness[0.5], 
    LineBox[{{4.155884278640482, 0.12434795363180176`}, {
     3.8843112934825035`, -0.05128020537470955}}]}, 
   {Hue[0.5554186293622038], AbsoluteThickness[0.5], 
    LineBox[{{7.0928235806820235`, -1.0641504112274234`}, {
     7.159167543915934, -1.170281937444524}}]}, 
   {Hue[0.5558665747550572], AbsoluteThickness[0.5], 
    LineBox[{{7.159167543915934, -1.170281937444524}, {
     7.328939623135354, -1.4297353981323624`}}]}, 
   {Hue[0.6985611126129543], AbsoluteThickness[0.5], 
    LineBox[{{2.086978103167211, 2.7176601430837306`}, {2.040153771203757, 
     2.6365104896876446`}}]}, 
   {Hue[0.6989945519604498], AbsoluteThickness[0.5], 
    LineBox[{{2.040153771203757, 2.6365104896876446`}, {1.8644957903577517`, 
     2.3233134659984858`}}]}, 
   {Hue[0.6186029360624736], AbsoluteThickness[0.5], 
    LineBox[{{7.40449050870465, -1.3557384738641833`}, {
     7.416628185922641, -1.3700926145554724`}}]}, 
   {Hue[0.619091507995434], AbsoluteThickness[0.5], 
    LineBox[{{7.416628185922641, -1.3700926145554724`}, {
     7.604937219436727, -1.6090734582493624`}}]}, 
   {Hue[0.605560619461428], AbsoluteThickness[0.5], 
    LineBox[{{7.3626564409025415`, -0.8976900950741802}, {
     7.392008119350851, -0.9336607348038872}}]}, 
   {Hue[0.6063650775982701], AbsoluteThickness[0.5], 
    LineBox[{{7.392008119350851, -0.9336607348038872}, {
     7.582472583595729, -1.1325730232489837`}}]}, 
   {Hue[0.6406933267926144], AbsoluteThickness[0.5], 
    LineBox[{{7.772104627638885, -2.8887310412258054`}, {
     7.835860855253753, -2.965393461802193}}]}, 
   {Hue[0.6413584320633523], AbsoluteThickness[0.5], 
    LineBox[{{7.835860855253753, -2.965393461802193}, {
     8.051973869043513, -3.1934533095887794`}}]}, 
   {Hue[0.618042290588282], AbsoluteThickness[0.5], 
    LineBox[{{2.3596080836550355`, -1.157247715276085}, {
     2.3477514356522424`, -1.174738969426968}}]}, 
   {Hue[0.6184928917343704], AbsoluteThickness[0.5], 
    LineBox[{{2.3477514356522424`, -1.174738969426968}, {
     2.166557523143603, -1.4298083240605381`}}]}, 
   {Hue[0.6641592061372135], AbsoluteThickness[0.5], 
    LineBox[{{5.64615843944406, -2.9024683892889973`}, {
     5.644207106032314, -2.9081954850591307`}}]}, 
   {Hue[0.664843580722663], AbsoluteThickness[0.5], 
    LineBox[{{5.644207106032314, -2.908195485059131}, {
     5.5456568881097965`, -3.144286661858681}}]}, 
   {Hue[0.6971992632123672], AbsoluteThickness[0.5], 
    LineBox[{{2.622470830872643, 1.804542720901665}, {2.424320090960703, 
     1.7708636811774565`}}]}, 
   {Hue[0.697647694029316], AbsoluteThickness[0.5], 
    LineBox[{{2.424320090960703, 1.7708636811774565`}, {2.1590217654388435`, 
     1.7314758920438502`}}]}, 
   {Hue[0.643193535742615], AbsoluteThickness[0.5], 
    LineBox[{{3.0455371131817257`, -1.24015648415561}, {
     2.944711241056241, -1.3626263203510345`}}]}, 
   {Hue[0.649238151474575], AbsoluteThickness[0.5], 
    LineBox[{{2.944711241056241, -1.3626263203510345`}, {
     2.8549691822643504`, -1.5373437536555938`}}]}, 
   {Hue[0.6650517339897929], AbsoluteThickness[0.5], 
    LineBox[{{2.370000768943542, -2.8316746932625865`}, {
     2.3511876483972936`, -2.8680551400955103`}}]}, 
   {Hue[0.6888440543578482], AbsoluteThickness[0.5], 
    LineBox[{{2.3511876483972936`, -2.8680551400955103`}, {
     2.3269157483041476`, -3.0220646628974106`}}]}, 
   {Hue[0.6750933285669641], AbsoluteThickness[0.5], 
    LineBox[{{4.141422905688039, -2.707969986426545}, {
     3.8661731729353046`, -2.791930157850308}}]}, 
   {Hue[0.675939432753403], AbsoluteThickness[0.5], 
    LineBox[{{3.8661731729353046`, -2.791930157850308}, {
     3.606099806785473, -2.8482183770159804`}}]}, 
   {Hue[0.6177558181314786], AbsoluteThickness[0.5], 
    LineBox[{{8.19482519320377, -3.9833836252003407`}, {
     8.248600817022513, -4.088610550870275}}]}, 
   {Hue[0.6182383482868351], AbsoluteThickness[0.5], 
    LineBox[{{8.248600817022513, -4.088610550870275}, {
     8.405682692771821, -4.422678791709511}}]}, 
   {Hue[0.6847933628116838], AbsoluteThickness[0.5], 
    LineBox[{{2.343113342076487, -3.051918862286229}, {
     2.318333879711401, -3.0605025105169434`}}]}, 
   {Hue[0.6883348072858356], AbsoluteThickness[0.5], 
    LineBox[{{2.318333879711401, -3.0605025105169434`}, {
     2.14453791246489, -3.157890857199682}}]}, 
   {Hue[0.6874065191065852], AbsoluteThickness[0.5], 
    LineBox[{{7.814820804456725, -1.4091481844477491`}, {
     7.827863058923042, -1.6464163925429354`}}]}, 
   {Hue[0.6879080797683097], AbsoluteThickness[0.5], 
    LineBox[{{7.827863058923042, -1.6464163925429354`}, {
     7.853474098307033, -1.9217223254702545`}}]}, 
   {Hue[0.5772505080769205], AbsoluteThickness[0.5], 
    LineBox[{{7.605786907111898, 0.12398738939301089`}, {7.59870125582765, 
     0.07508114224729576}}]}, 
   {Hue[0.5779115784789881], AbsoluteThickness[0.5], 
    LineBox[{{7.59870125582765, 0.07508114224729576}, {
     7.578274318245844, -0.18096193956250184`}}]}, 
   {Hue[0.6241440571136306], AbsoluteThickness[0.5], 
    LineBox[{{5.306017225710853, 2.9291986214927843`}, {5.133611066157003, 
     2.9217203597834582`}}]}, 
   {Hue[0.6249242097386457], AbsoluteThickness[0.5], 
    LineBox[{{5.133611066157003, 2.9217203597834582`}, {4.86440481242861, 
     2.889151973498527}}]}, 
   {Hue[0.6197195282185951], AbsoluteThickness[0.5], 
    LineBox[{{5.56914190903269, 1.9225116933473307`}, {5.158583668098091, 
     1.434215591264671}}]}, 
   {Hue[0.6069639070987302], AbsoluteThickness[0.5], 
    LineBox[{{3.7901668088195843`, 1.1437321969884917`}, {3.6960654045383796`,
      1.0293001113693785`}}]}, 
   {Hue[0.6094491198710842], AbsoluteThickness[0.5], 
    LineBox[{{3.6960654045383796`, 1.0293001113693785`}, {3.6028431440171853`,
      0.8717600966734926}}]}, 
   {Hue[0.6197626496014418], AbsoluteThickness[0.5], 
    LineBox[{{7.792788387516609, -2.4017598006551846`}, {
     7.82687308492691, -2.4428722454703067`}}]}, 
   {Hue[0.6208871729161378], AbsoluteThickness[0.5], 
    LineBox[{{7.82687308492691, -2.4428722454703067`}, {
     8.003931885000908, -2.616695986235377}}]}, 
   {Hue[0.6382349645116985], AbsoluteThickness[0.5], 
    LineBox[{{5.633934871821642, -3.107692973601716}, {
     5.628314655545293, -3.1355658049305815`}}]}, 
   {Hue[0.6394284817188838], AbsoluteThickness[0.5], 
    LineBox[{{5.628314655545293, -3.1355658049305815`}, {
     5.604471603216617, -3.3922457130380943`}}]}, 
   {Hue[0.6919903897867348], AbsoluteThickness[0.5], 
    LineBox[{{3.225004821890163, -2.3392337190446915`}, {
     3.128935915451403, -2.4080846722099327`}}]}, 
   {Hue[0.6924335851590078], AbsoluteThickness[0.5], 
    LineBox[{{3.128935915451403, -2.4080846722099327`}, {
     2.8461771885009433`, -2.602957727421706}}]}, 
   {Hue[0.6244145449173449], AbsoluteThickness[0.5], 
    LineBox[{{6.014342712224227, -2.6662281519930944`}, {
     6.00675081893816, -2.8195068314385696`}}]}, 
   {Hue[0.6248411086137851], AbsoluteThickness[0.5], 
    LineBox[{{6.00675081893816, -2.8195068314385696`}, {
     5.990589600779161, -3.1725225800613552`}}]}, 
   {Hue[0.515996678098506], AbsoluteThickness[0.5], 
    LineBox[{{8.212063602712718, -1.8987097494766103`}, {
     8.216977217198032, -2.0662131342040526`}}]}, 
   {Hue[0.5164307999154202], AbsoluteThickness[0.5], 
    LineBox[{{8.216977217198032, -2.0662131342040526`}, {
     8.23114057542169, -2.402698168739778}}]}, 
   {Hue[0.6250744700618441], AbsoluteThickness[0.5], 
    LineBox[{{3.8852677086934384`, -0.05303254157581197}, {
     3.8084834705197244`, -0.1035615656737163}}]}, 
   {Hue[0.6256156954558854], AbsoluteThickness[0.5], 
    LineBox[{{3.8084834705197244`, -0.10356156567371633`}, {
     3.546477141054959, -0.2939045578781239}}]}, 
   {Hue[0.6250300599721028], AbsoluteThickness[0.5], 
    LineBox[{{3.8843112934825035`, -0.05128020537470954}, {
     3.807003709571238, -0.10251139094221126`}}]}, 
   {Hue[0.6255767034113331], AbsoluteThickness[0.5], 
    LineBox[{{3.807003709571238, -0.10251139094221126`}, {
     3.5463651803018155`, -0.2935516357383721}}]}, 
   {Hue[0.5563145201479104], AbsoluteThickness[0.5], 
    LineBox[{{7.328939623135354, -1.4297353981323624`}, {
     7.339652811246415, -1.4453891672860353`}}]}, 
   {Hue[0.557016828273118], AbsoluteThickness[0.5], 
    LineBox[{{7.339652811246415, -1.4453891672860353`}, {
     7.514306472209127, -1.6661779766029337`}}]}, 
   {Hue[0.6195800799283944], AbsoluteThickness[0.5], 
    LineBox[{{7.604937219436727, -1.6090734582493624`}, {
     7.677167670864879, -1.7075600781839817`}}]}, 
   {Hue[0.6201091002286461], AbsoluteThickness[0.5], 
    LineBox[{{7.677167670864879, -1.7075600781839817`}, {
     7.850228375156257, -1.9230337114001173`}}]}, 
   {Hue[0.6071695357351121], AbsoluteThickness[0.5], 
    LineBox[{{7.582472583595729, -1.1325730232489837`}, {
     7.631786616841591, -1.1765100055072817`}}]}, 
   {Hue[0.6076788009384477], AbsoluteThickness[0.5], 
    LineBox[{{7.631786616841591, -1.1765100055072817`}, {
     7.881467779569185, -1.3818065062824325`}}]}, 
   {Hue[0.6420235373340903], AbsoluteThickness[0.5], 
    LineBox[{{8.051973869043513, -3.1934533095887794`}, {
     8.14234913743633, -3.277229594432395}}]}, 
   {Hue[0.6428683017767339], AbsoluteThickness[0.5], 
    LineBox[{{8.14234913743633, -3.277229594432395}, {
     8.352937966366648, -3.442265170870861}}]}, 
   {Hue[0.6189434928804588], AbsoluteThickness[0.5], 
    LineBox[{{2.166557523143603, -1.4298083240605381`}, {
     2.146625962503927, -1.4566012842280651`}}]}, 
   {Hue[0.6201039252565106], AbsoluteThickness[0.5], 
    LineBox[{{2.146625962503927, -1.4566012842280651`}, {
     1.9729062030320605`, -1.6453033620748563`}}]}, 
   {Hue[0.6655279553081127], AbsoluteThickness[0.5], 
    LineBox[{{5.5456568881097965`, -3.144286661858681}, {
     5.437691345739366, -3.3608441953131893`}}]}, 
   {Hue[0.6667351419595134], AbsoluteThickness[0.5], 
    LineBox[{{5.437691345739366, -3.3608441953131893`}, {
     5.345336939710102, -3.6096745775539394`}}]}, 
   {Hue[0.6980961248462648], AbsoluteThickness[0.5], 
    LineBox[{{2.1590217654388435`, 1.7314758920438502`}, {2.0447280817456566`,
      1.7169493054819225`}}]}, 
   {Hue[0.6552827672065351], AbsoluteThickness[0.5], 
    LineBox[{{2.8549691822643504`, -1.5373437536555938`}, {
     2.8344990977046924`, -1.614221150894996}}]}, 
   {Hue[0.6559662044963015], AbsoluteThickness[0.5], 
    LineBox[{{2.8344990977046924`, -1.614221150894996}, {
     2.7380491073409425`, -1.898422259247826}}]}, 
   {Hue[0.6767855369398419], AbsoluteThickness[0.5], 
    LineBox[{{3.606099806785473, -2.8482183770159804`}, {
     3.5997530055899527`, -2.849049571216667}}]}, 
   {Hue[0.6777185715215694], AbsoluteThickness[0.5], 
    LineBox[{{3.5997530055899527`, -2.849049571216667}, {
     3.3367938479373205`, -2.907853178791664}}]}, 
   {Hue[0.6918762517599875], AbsoluteThickness[0.5], 
    LineBox[{{2.14453791246489, -3.157890857199682}, {
     1.924840353497895, -3.3384995597333726`}}]}, 
   {Hue[0.6884096404300343], AbsoluteThickness[0.5], 
    LineBox[{{7.853474098307033, -1.9217223254702545`}, {
     7.862882957181824, -1.9933511318600936`}}]}, 
   {Hue[0.5785726488810559], AbsoluteThickness[0.5], 
    LineBox[{{7.578274318245844, -0.1809619395625019}, {
     7.575473020351489, -0.3635592853645343}}]}, 
   {Hue[0.5800518211558804], AbsoluteThickness[0.5], 
    LineBox[{{7.575473020351489, -0.3635592853645343}, {
     7.5974641228531254`, -0.5722342747232915}}]}, 
   {Hue[0.6257043623636609], AbsoluteThickness[0.5], 
    LineBox[{{4.86440481242861, 2.889151973498527}, {4.859640868664144, 
     2.888198965682635}}]}, 
   {Hue[0.6268284752904146], AbsoluteThickness[0.5], 
    LineBox[{{4.859640868664144, 2.888198965682635}, {4.623189543195739, 
     2.8656545381933154`}}]}, 
   {Hue[0.619719528218595], AbsoluteThickness[0.5], 
    LineBox[{{5.158583668098091, 1.434215591264671}, {5.155858890830358, 
     1.3887058475628145`}}]}, 
   {Hue[0.6206126383976756], AbsoluteThickness[0.5], 
    LineBox[{{5.155858890830358, 1.3887058475628145`}, {5.1167383055888465`, 
     1.1236608097956944`}}]}, 
   {Hue[0.6119343326434381], AbsoluteThickness[0.5], 
    LineBox[{{3.6028431440171853`, 0.8717600966734926}, {3.5112000883124472`, 
     0.6426027416695596}}]}, 
   {Hue[0.612369873108221], AbsoluteThickness[0.5], 
    LineBox[{{3.5112000883124472`, 0.6426027416695596}, {3.3947296286427604`, 
     0.3626209940796089}}]}, 
   {Hue[0.622011696230834], AbsoluteThickness[0.5], 
    LineBox[{{8.003931885000908, -2.616695986235377}, {
     8.114569163376904, -2.70503016580316}}]}, 
   {Hue[0.6224725633175486], AbsoluteThickness[0.5], 
    LineBox[{{8.114569163376904, -2.70503016580316}, {
     8.407472321122, -2.926658530906346}}]}, 
   {Hue[0.6406219989260691], AbsoluteThickness[0.5], 
    LineBox[{{5.604471603216617, -3.3922457130380943`}, {
     5.604673338685908, -3.4069474438124145`}}]}, 
   {Hue[0.6422346643170844], AbsoluteThickness[0.5], 
    LineBox[{{5.604673338685908, -3.4069474438124145`}, {
     5.57659833071006, -3.656122168259827}}]}, 
   {Hue[0.6928767805312809], AbsoluteThickness[0.5], 
    LineBox[{{2.8461771885009433`, -2.602957727421706}, {
     2.843869414683163, -2.604486340898023}}]}, 
   {Hue[0.6934429584563597], AbsoluteThickness[0.5], 
    LineBox[{{2.843869414683163, -2.604486340898023}, {
     2.5818298576013814`, -2.7978534381458506`}}]}, 
   {Hue[0.6252676723102252], AbsoluteThickness[0.5], 
    LineBox[{{5.990589600779161, -3.1725225800613552`}, {
     5.982309550213919, -3.3695157407921434`}}]}, 
   {Hue[0.6257654590782605], AbsoluteThickness[0.5], 
    LineBox[{{5.982309550213919, -3.3695157407921434`}, {
     5.980819198279447, -3.662947324586927}}]}, 
   {Hue[0.5168649217323343], AbsoluteThickness[0.5], 
    LineBox[{{8.23114057542169, -2.402698168739778}, {
     8.242281600345791, -2.6057664130992144`}}]}, 
   {Hue[0.5173100285129248], AbsoluteThickness[0.5], 
    LineBox[{{8.242281600345791, -2.6057664130992144`}, {
     8.269714391962346, -2.9748507077388915`}}]}, 
   {Hue[0.6261569208499268], AbsoluteThickness[0.5], 
    LineBox[{{3.546477141054959, -0.293904557878124}, {
     2.931417871441431, -0.7857436665549089}}]}, 
   {Hue[0.6275089203957996], AbsoluteThickness[0.5], 
    LineBox[{{2.931417871441431, -0.7857436665549089}, {
     2.738634427217114, -0.9066171249495928}}]}, 
   {Hue[0.6261233468505634], AbsoluteThickness[0.5], 
    LineBox[{{3.5463651803018155`, -0.2935516357383721}, {
     2.9307300124468, -0.7911667059495867}}]}, 
   {Hue[0.6276805462480226], AbsoluteThickness[0.5], 
    LineBox[{{2.9307300124468, -0.7911667059495867}, {
     2.7427363032337624`, -0.9080151657889958}}]}, 
   {Hue[0.5577191363983257], AbsoluteThickness[0.5], 
    LineBox[{{7.514306472209127, -1.6661779766029337`}, {
     7.656994217650129, -1.8229678637311504`}}]}, 
   {Hue[0.5621358360854914], AbsoluteThickness[0.5], 
    LineBox[{{7.656994217650129, -1.8229678637311504`}, {
     7.804427756954338, -1.9327748144213082`}}]}, 
   {Hue[0.6206381205288978], AbsoluteThickness[0.5], 
    LineBox[{{7.850228375156257, -1.9230337114001173`}, {
     7.8692698443463005`, -1.9447204430614864`}}]}, 
   {Hue[0.6213764301005515], AbsoluteThickness[0.5], 
    LineBox[{{7.8692698443463005`, -1.9447204430614864`}, {
     8.05276290210913, -2.1252753332548897`}}]}, 
   {Hue[0.6081880661417834], AbsoluteThickness[0.5], 
    LineBox[{{7.881467779569185, -1.3818065062824325`}, {
     7.92435251440694, -1.414306615712209}}]}, 
   {Hue[0.6087810282471182], AbsoluteThickness[0.5], 
    LineBox[{{7.92435251440694, -1.414306615712209}, {
     8.13613658274663, -1.593958613904507}}]}, 
   {Hue[0.6679423286109143], AbsoluteThickness[0.5], 
    LineBox[{{5.345336939710102, -3.6096745775539394`}, {
     5.337859342271228, -3.6391683673794497`}}]}, 
   {Hue[0.6683702811387017], AbsoluteThickness[0.5], 
    LineBox[{{5.337859342271228, -3.6391683673794497`}, {
     5.259277809483264, -3.9409564565087014`}}]}, 
   {Hue[0.656649641786068], AbsoluteThickness[0.5], 
    LineBox[{{2.7380491073409425`, -1.898422259247826}, {
     2.6724049776519188`, -2.056266360153274}}]}, 
   {Hue[0.6575250457403643], AbsoluteThickness[0.5], 
    LineBox[{{2.6724049776519188`, -2.056266360153274}, {
     2.5882204644179425`, -2.3201769034181954`}}]}, 
   {Hue[0.6786516061032972], AbsoluteThickness[0.5], 
    LineBox[{{3.3367938479373205`, -2.907853178791664}, {
     3.1735915933367402`, -2.960092564260793}}]}, 
   {Hue[0.6790818319048821], AbsoluteThickness[0.5], 
    LineBox[{{3.1735915933367402`, -2.960092564260793}, {
     2.8430782477811185`, -3.062516655636375}}]}, 
   {Hue[0.6884096404300343], AbsoluteThickness[0.5], 
    LineBox[{{7.862882957181824, -1.9933511318600936`}, {
     7.855617515091368, -2.134163063453573}}]}, 
   {Hue[0.6895564713917446], AbsoluteThickness[0.5], 
    LineBox[{{7.855617515091368, -2.134163063453573}, {
     7.867473029503727, -2.361254737600592}}]}, 
   {Hue[0.581530993430705], AbsoluteThickness[0.5], 
    LineBox[{{7.5974641228531254`, -0.5722342747232915}, {
     7.623266764962528, -0.6847980268657077}}]}, 
   {Hue[0.5868727423766795], AbsoluteThickness[0.5], 
    LineBox[{{7.623266764962528, -0.6847980268657077}, {
     7.625828259177134, -0.8140036201845062}}]}, 
   {Hue[0.6279525882171685], AbsoluteThickness[0.5], 
    LineBox[{{4.623189543195739, 2.8656545381933154`}, {4.616578934255711, 
     2.8657029596447035`}}]}, 
   {Hue[0.6370264153411676], AbsoluteThickness[0.5], 
    LineBox[{{4.616578934255711, 2.8657029596447035`}, {4.507249337256138, 
     2.83932736154426}}]}, 
   {Hue[0.6215057485767561], AbsoluteThickness[0.5], 
    LineBox[{{5.1167383055888465`, 1.1236608097956944`}, {5.11672186265773, 
     1.1235916079861843`}}]}, 
   {Hue[0.622307314163232], AbsoluteThickness[0.5], 
    LineBox[{{5.11672186265773, 1.1235916079861843`}, {5.074206042600119, 
     0.8501585949917446}}]}, 
   {Hue[0.6128054135730038], AbsoluteThickness[0.5], 
    LineBox[{{3.3947296286427604`, 0.3626209940796089}, {3.3835946958657415`, 
     0.33686109314573576`}}]}, 
   {Hue[0.614368754403704], AbsoluteThickness[0.5], 
    LineBox[{{3.3835946958657415`, 0.33686109314573576`}, {
     3.3211902648378135`, 0.12313662099190409`}}]}, 
   {Hue[0.6438473297080997], AbsoluteThickness[0.5], 
    LineBox[{{5.57659833071006, -3.656122168259827}, {
     5.530180896220038, -3.8473579861264504`}}]}, 
   {Hue[0.644293121704989], AbsoluteThickness[0.5], 
    LineBox[{{5.530180896220038, -3.8473579861264504`}, {
     5.463214094989343, -4.149093422144552}}]}, 
   {Hue[0.6940091363814388], AbsoluteThickness[0.5], 
    LineBox[{{2.5818298576013814`, -2.7978534381458506`}, {
     2.5397054202827367`, -2.832368740426672}}]}, 
   {Hue[0.6945644292292659], AbsoluteThickness[0.5], 
    LineBox[{{2.5397054202827367`, -2.832368740426672}, {
     2.3277460727377077`, -3.024073986759362}}]}, 
   {Hue[0.6262632458462959], AbsoluteThickness[0.5], 
    LineBox[{{5.980819198279447, -3.662947324586927}, {
     5.98615795836603, -3.8305155411777614`}}]}, 
   {Hue[0.6267004591175817], AbsoluteThickness[0.5], 
    LineBox[{{5.98615795836603, -3.8305155411777614`}, {
     5.991412832645857, -4.140906186364481}}]}, 
   {Hue[0.5177551352935155], AbsoluteThickness[0.5], 
    LineBox[{{8.269714391962346, -2.9748507077388915`}, {
     8.28557440442562, -3.143851169664928}}]}, 
   {Hue[0.5181815701450667], AbsoluteThickness[0.5], 
    LineBox[{{8.28557440442562, -3.143851169664928}, {
     8.313458932435713, -3.452196900119726}}]}, 
   {Hue[0.6288609199416726], AbsoluteThickness[0.5], 
    LineBox[{{2.738634427217114, -0.9066171249495928}, {
     2.6471644758840545`, -0.9502983853853652}}]}, 
   {Hue[0.6292874145358164], AbsoluteThickness[0.5], 
    LineBox[{{2.6471644758840545`, -0.9502983853853652}, {
     2.3245362444003437`, -1.1057793749963976`}}]}, 
   {Hue[0.629237745645482], AbsoluteThickness[0.5], 
    LineBox[{{2.7427363032337624`, -0.9080151657889958}, {
     2.6479187293147186`, -0.9517828881608098}}]}, 
   {Hue[0.6296644164556428], AbsoluteThickness[0.5], 
    LineBox[{{2.6479187293147186`, -0.9517828881608098}, {
     2.3233852627833578`, -1.1031702277800157`}}]}, 
   {Hue[0.5665525357726574], AbsoluteThickness[0.5], 
    LineBox[{{7.804427756954338, -1.9327748144213082`}, {
     7.865070924028563, -1.961909173468511}}]}, 
   {Hue[0.5670369262333788], AbsoluteThickness[0.5], 
    LineBox[{{7.865070924028563, -1.961909173468511}, {
     8.122915589637785, -2.0753379185326786`}}]}, 
   {Hue[0.6221147396722053], AbsoluteThickness[0.5], 
    LineBox[{{8.05276290210913, -2.1252753332548897`}, {
     8.0892463220499, -2.1562802538976533`}}]}, 
   {Hue[0.622581712010598], AbsoluteThickness[0.5], 
    LineBox[{{8.0892463220499, -2.1562802538976533`}, {
     8.347762881646055, -2.3637327996057573`}}]}, 
   {Hue[0.6093739903524529], AbsoluteThickness[0.5], 
    LineBox[{{8.13613658274663, -1.593958613904507}, {
     8.155144834088844, -1.6119702419479225`}}]}, 
   {Hue[0.609954141851332], AbsoluteThickness[0.5], 
    LineBox[{{8.155144834088844, -1.6119702419479225`}, {
     8.34722925391111, -1.8143450334840756`}}]}, 
   {Hue[0.6687982336664889], AbsoluteThickness[0.5], 
    LineBox[{{5.259277809483264, -3.9409564565087014`}, {
     5.226340048873448, -4.064196691610445}}]}, 
   {Hue[0.6693174772119683], AbsoluteThickness[0.5], 
    LineBox[{{5.226340048873448, -4.064196691610445}, {
     5.165144681101369, -4.3387375044823635`}}]}, 
   {Hue[0.6584004496946606], AbsoluteThickness[0.5], 
    LineBox[{{2.5882204644179425`, -2.3201769034181954`}, {
     2.5860852469588704`, -2.3295729900227076`}}]}, 
   {Hue[0.6588445447140233], AbsoluteThickness[0.5], 
    LineBox[{{2.5860852469588704`, -2.3295729900227076`}, {
     2.5092824344992155`, -2.640290673270088}}]}, 
   {Hue[0.6795120577064672], AbsoluteThickness[0.5], 
    LineBox[{{2.8430782477811185`, -3.062516655636375}, {
     2.4365691195202985`, -3.1843704205574537`}}]}, 
   {Hue[0.6799508542523088], AbsoluteThickness[0.5], 
    LineBox[{{2.4365691195202985`, -3.1843704205574537`}, {
     2.147129651758036, -3.2661333455868156`}}]}, 
   {Hue[0.6907033023534549], AbsoluteThickness[0.5], 
    LineBox[{{7.867473029503727, -2.361254737600592}, {
     7.905131822562114, -2.600901811647163}}]}, 
   {Hue[0.5922144913226541], AbsoluteThickness[0.5], 
    LineBox[{{7.625828259177134, -0.8140036201845062}, {
     7.620479272111576, -0.8424778836588525}}]}, 
   {Hue[0.5927629994759682], AbsoluteThickness[0.5], 
    LineBox[{{7.620479272111576, -0.8424778836588525}, {
     7.580082635868188, -1.1331728352239674`}}]}, 
   {Hue[0.6461002424651668], AbsoluteThickness[0.5], 
    LineBox[{{4.507249337256138, 2.83932736154426}, {4.43194012421159, 
     2.8000463626174943`}}]}, 
   {Hue[0.6468313747487634], AbsoluteThickness[0.5], 
    LineBox[{{4.43194012421159, 2.8000463626174943`}, {4.195768213451132, 
     2.654283965754612}}]}, 
   {Hue[0.6231088797497079], AbsoluteThickness[0.5], 
    LineBox[{{5.074206042600119, 0.8501585949917446}, {5.062156830300568, 
     0.6902854939748941}}]}, 
   {Hue[0.6235628152103697], AbsoluteThickness[0.5], 
    LineBox[{{5.062156830300568, 0.6902854939748941}, {5.0466991760492315`, 
     0.3925797261820434}}]}, 
   {Hue[0.6159320952344044], AbsoluteThickness[0.5], 
    LineBox[{{3.3211902648378135`, 0.1231366209919041}, {3.3114242066661, 
     0.06268709366213998}}]}, 
   {Hue[0.6447389137018783], AbsoluteThickness[0.5], 
    LineBox[{{5.463214094989343, -4.149093422144552}, {
     5.428865916014633, -4.319695354727436}}]}, 
   {Hue[0.6455234951865565], AbsoluteThickness[0.5], 
    LineBox[{{5.428865916014633, -4.319695354727436}, {
     5.391837404418872, -4.623670711122823}}]}, 
   {Hue[0.6951197220770929], AbsoluteThickness[0.5], 
    LineBox[{{2.3277460727377077`, -3.024073986759362}, {
     2.2943072836359706`, -3.057425487051129}}]}, 
   {Hue[0.6963070522747355], AbsoluteThickness[0.5], 
    LineBox[{{2.2943072836359706`, -3.057425487051129}, {
     2.140740260047843, -3.247055757417521}}]}, 
   {Hue[0.6271376723888675], AbsoluteThickness[0.5], 
    LineBox[{{5.991412832645857, -4.140906186364481}, {
     5.991862225519468, -4.364811195086578}}]}, 
   {Hue[0.6275645327133837], AbsoluteThickness[0.5], 
    LineBox[{{5.991862225519468, -4.364811195086578}, {
     5.9910158294558, -4.710646534692338}}]}, 
   {Hue[0.5186080049966179], AbsoluteThickness[0.5], 
    LineBox[{{8.313458932435713, -3.452196900119726}, {
     8.32788062021071, -3.6179225476110934`}}]}, 
   {Hue[0.5191575683047075], AbsoluteThickness[0.5], 
    LineBox[{{8.32788062021071, -3.6179225476110934`}, {
     8.339433941906254, -3.9139900446318636`}}]}, 
   {Hue[0.6297139091299601], AbsoluteThickness[0.5], 
    LineBox[{{2.3245362444003437`, -1.1057793749963976`}, {
     2.268936053297849, -1.1328181541023132`}}]}, 
   {Hue[0.6318798505073753], AbsoluteThickness[0.5], 
    LineBox[{{2.268936053297849, -1.1328181541023132`}, {
     2.0809498721494393`, -1.260762672529144}}]}, 
   {Hue[0.6300910872658035], AbsoluteThickness[0.5], 
    LineBox[{{2.3233852627833578`, -1.1031702277800157`}, {
     2.26287646332174, -1.1316924223769051`}}]}, 
   {Hue[0.6327584005958545], AbsoluteThickness[0.5], 
    LineBox[{{2.26287646332174, -1.1316924223769051`}, {
     2.0820327567060035`, -1.2551479639126923`}}]}, 
   {Hue[0.5675213166941001], AbsoluteThickness[0.5], 
    LineBox[{{8.122915589637785, -2.0753379185326786`}, {
     8.15414034051938, -2.0878457505570167`}}]}, 
   {Hue[0.5684760672396862], AbsoluteThickness[0.5], 
    LineBox[{{8.15414034051938, -2.0878457505570167`}, {
     8.407842852181336, -2.2174745498648143`}}]}, 
   {Hue[0.6698367207574477], AbsoluteThickness[0.5], 
    LineBox[{{5.165144681101369, -4.3387375044823635`}, {
     5.137711843038472, -4.491688232126044}}]}, 
   {Hue[0.688708074381917], AbsoluteThickness[0.5], 
    LineBox[{{5.137711843038472, -4.491688232126044}, {
     5.05818620988522, -4.644740772201499}}]}, 
   {Hue[0.659288639733386], AbsoluteThickness[0.5], 
    LineBox[{{2.5092824344992155`, -2.640290673270088}, {
     2.4628632408043143`, -2.8139508723736237`}}]}, 
   {Hue[0.6597831489555591], AbsoluteThickness[0.5], 
    LineBox[{{2.4628632408043143`, -2.8139508723736237`}, {
     2.39746057713, -3.0995969072076135`}}]}, 
   {Hue[0.6919628216012831], AbsoluteThickness[0.5], 
    LineBox[{{7.905131822562114, -2.600901811647163}, {
     7.9751206825718075`, -2.8580376016674043`}}]}, 
   {Hue[0.6924041593544931], AbsoluteThickness[0.5], 
    LineBox[{{7.9751206825718075`, -2.8580376016674043`}, {
     8.059481378738898, -3.190711912382503}}]}, 
   {Hue[0.5933115076292824], AbsoluteThickness[0.5], 
    LineBox[{{7.580082635868188, -1.1331728352239674`}, {
     7.55801660058517, -1.3764020216477506`}}]}, 
   {Hue[0.5939638723117575], AbsoluteThickness[0.5], 
    LineBox[{{7.55801660058517, -1.3764020216477506`}, {
     7.5504519941644, -1.6535558576106655`}}]}, 
   {Hue[0.64756250703236], AbsoluteThickness[0.5], 
    LineBox[{{4.195768213451132, 2.654283965754612}, {4.15088446707384, 
     2.621890900948156}}]}, 
   {Hue[0.6479966272440618], AbsoluteThickness[0.5], 
    LineBox[{{4.15088446707384, 2.621890900948156}, {3.8750451827851298`, 
     2.4281110438737294`}}]}, 
   {Hue[0.6240167506710316], AbsoluteThickness[0.5], 
    LineBox[{{5.0466991760492315`, 0.3925797261820434}, {5.0404643822003425`, 
     0.17408040232922495`}}]}, 
   {Hue[0.6245739673255734], AbsoluteThickness[0.5], 
    LineBox[{{5.0404643822003425`, 0.17408040232922495`}, {
     5.046551037710063, -0.12079558175066996`}}]}, 
   {Hue[0.6159320952344044], AbsoluteThickness[0.5], 
    LineBox[{{3.3114242066661, 0.06268709366213998}, {
     3.2025795688124017`, -0.023408578517858124`}}]}, 
   {Hue[0.6167914255386521], AbsoluteThickness[0.5], 
    LineBox[{{3.2025795688124017`, -0.023408578517858124`}, {
     3.0100182996257354`, -0.20397118821130286`}}]}, 
   {Hue[0.6974943824723782], AbsoluteThickness[0.5], 
    LineBox[{{2.140740260047843, -3.247055757417521}, {
     2.0726944854680904`, -3.3521265229749595`}}]}, 
   {Hue[0.6979202422304102], AbsoluteThickness[0.5], 
    LineBox[{{2.0726944854680904`, -3.3521265229749595`}, {
     1.899662619154039, -3.6191121210787403`}}]}, 
   {Hue[0.519707131612797], AbsoluteThickness[0.5], 
    LineBox[{{8.339433941906254, -3.9139900446318636`}, {
     8.337873706682904, -4.091341762690268}}]}, 
   {Hue[0.5201869945513129], AbsoluteThickness[0.5], 
    LineBox[{{8.337873706682904, -4.091341762690268}, {
     8.322743353069434, -4.460633030401693}}]}, 
   {Hue[0.6340457918847906], AbsoluteThickness[0.5], 
    LineBox[{{2.0809498721494393`, -1.260762672529144}, {
     2.0052604942791916`, -1.3302283594278967`}}]}, 
   {Hue[0.635237041344693], AbsoluteThickness[0.5], 
    LineBox[{{2.0052604942791916`, -1.3302283594278967`}, {
     1.8366321480346735`, -1.5217073842226172`}}]}, 
   {Hue[0.6354257139259054], AbsoluteThickness[0.5], 
    LineBox[{{2.0820327567060035`, -1.2551479639126923`}, {
     2.002847737993369, -1.330034768576756}}]}, 
   {Hue[0.6366181037777137], AbsoluteThickness[0.5], 
    LineBox[{{2.002847737993369, -1.330034768576756}, {
     1.8371465674119514`, -1.523988222112234}}]}, 
   {Hue[0.6602776581777322], AbsoluteThickness[0.5], 
    LineBox[{{2.39746057713, -3.0995969072076135`}, {
     2.3966061155094236`, -3.1040644934866473`}}]}, 
   {Hue[0.6611398627532529], AbsoluteThickness[0.5], 
    LineBox[{{2.3966061155094236`, -3.1040644934866473`}, {
     2.3263258992957696`, -3.354843989621977}}]}, 
   {Hue[0.6928454971077029], AbsoluteThickness[0.5], 
    LineBox[{{8.059481378738898, -3.190711912382503}, {
     8.088161308745294, -3.3126794503478663`}}]}, 
   {Hue[0.6937145718198392], AbsoluteThickness[0.5], 
    LineBox[{{8.088161308745294, -3.3126794503478663`}, {
     8.126890294247326, -3.5758298886639515`}}]}, 
   {Hue[0.5946162369942328], AbsoluteThickness[0.5], 
    LineBox[{{7.5504519941644, -1.6535558576106655`}, {
     7.557070011226581, -1.8378262981158406`}}]}, 
   {Hue[0.5956117991417111], AbsoluteThickness[0.5], 
    LineBox[{{7.557070011226581, -1.8378262981158406`}, {
     7.586645929449012, -2.0638299019402084`}}]}, 
   {Hue[0.6484307474557637], AbsoluteThickness[0.5], 
    LineBox[{{3.8750451827851298`, 2.4281110438737294`}, {3.7472582605192724`,
      2.3407494754846025`}}]}, 
   {Hue[0.6495455165104119], AbsoluteThickness[0.5], 
    LineBox[{{3.7472582605192724`, 2.3407494754846025`}, {3.572808695565323, 
     2.2459356567951256`}}]}, 
   {Hue[0.6251311839801152], AbsoluteThickness[0.5], 
    LineBox[{{5.046551037710063, -0.12079558175067001`}, {
     5.064381313802438, -0.37581464720174473`}}]}, 
   {Hue[0.6258673169202972], AbsoluteThickness[0.5], 
    LineBox[{{5.064381313802438, -0.37581464720174473`}, {
     5.101270262421297, -0.6329138848588926}}]}, 
   {Hue[0.6176507558428997], AbsoluteThickness[0.5], 
    LineBox[{{3.0100182996257354`, -0.20397118821130286`}, {
     2.913152580081936, -0.3114475260692791}}]}, 
   {Hue[0.6620020673287738], AbsoluteThickness[0.5], 
    LineBox[{{2.3263258992957696`, -3.354843989621977}, {
     2.2526387821856466`, -3.5521051693609222`}}]}, 
   {Hue[0.6624381261006157], AbsoluteThickness[0.5], 
    LineBox[{{2.2526387821856466`, -3.5521051693609222`}, {
     2.146087530769403, -3.850139576633989}}]}, 
   {Hue[0.6945836465319756], AbsoluteThickness[0.5], 
    LineBox[{{8.126890294247326, -3.5758298886639515`}, {
     8.135460666880002, -3.7154599696039408`}}]}, 
   {Hue[0.5966073612891896], AbsoluteThickness[0.5], 
    LineBox[{{7.586645929449012, -2.0638299019402084`}, {
     7.617710202943524, -2.199961529044277}}]}, 
   {Hue[0.6092788599734931], AbsoluteThickness[0.5], 
    LineBox[{{7.617710202943524, -2.199961529044277}, {
     7.613491457176896, -2.29286012295324}}]}, 
   {Hue[0.6506602855650602], AbsoluteThickness[0.5], 
    LineBox[{{3.572808695565323, 2.2459356567951256`}, {3.452990679862995, 
     2.195839441804835}}]}, 
   {Hue[0.6517588623880476], AbsoluteThickness[0.5], 
    LineBox[{{3.452990679862995, 2.195839441804835}, {3.2376783239338507`, 
     2.079088260505825}}]}, 
   {Hue[0.6266034498604792], AbsoluteThickness[0.5], 
    LineBox[{{5.101270262421297, -0.6329138848588926}, {
     5.10634753184899, -0.6561402864621838}}]}, 
   {Hue[0.6275231927367572], AbsoluteThickness[0.5], 
    LineBox[{{5.10634753184899, -0.6561402864621838}, {
     5.136197905370983, -0.8909912111596453}}]}, 
   {Hue[0.6176507558428995], AbsoluteThickness[0.5], 
    LineBox[{{2.913152580081936, -0.3114475260692791}, {
     2.9118210828607207`, -0.3321512020259885}}]}, 
   {Hue[0.6190176558055508], AbsoluteThickness[0.5], 
    LineBox[{{2.9118210828607207`, -0.3321512020259885}, {
     2.8722585741173083`, -0.5502557576815267}}]}, 
   {Hue[0.6628741848724578], AbsoluteThickness[0.5], 
    LineBox[{{2.146087530769403, -3.850139576633989}, {
     2.139422665413349, -3.8696481987309035`}}]}, 
   {Hue[0.6634714073822218], AbsoluteThickness[0.5], 
    LineBox[{{2.139422665413349, -3.8696481987309035`}, {
     2.022224436688972, -4.159003793357094}}]}, 
   {Hue[0.6219503586577965], AbsoluteThickness[0.5], 
    LineBox[{{7.613491457176896, -2.29286012295324}, {
     7.575295074339978, -2.4100358022648853`}}]}, 
   {Hue[0.622473087711076], AbsoluteThickness[0.5], 
    LineBox[{{7.575295074339978, -2.4100358022648853`}, {
     7.494769203610686, -2.698156494595948}}]}, 
   {Hue[0.652857439211035], AbsoluteThickness[0.5], 
    LineBox[{{3.2376783239338507`, 2.079088260505825}, {3.1511506879987876`, 
     2.0201807654824995`}}]}, 
   {Hue[0.653489936056401], AbsoluteThickness[0.5], 
    LineBox[{{3.1511506879987876`, 2.0201807654824995`}, {2.932041666764273, 
     1.8507146914758583`}}]}, 
   {Hue[0.6284429356130352], AbsoluteThickness[0.5], 
    LineBox[{{5.136197905370983, -0.8909912111596453}, {
     5.136297455116635, -0.8936349211958383}}]}, 
   {Hue[0.6309020409211002], AbsoluteThickness[0.5], 
    LineBox[{{5.136297455116635, -0.8936349211958383}, {
     5.169157403642955, -1.0637260963879793`}}]}, 
   {Hue[0.6203845557682018], AbsoluteThickness[0.5], 
    LineBox[{{2.8722585741173083`, -0.5502557576815267}, {
     2.8457343240913775`, -0.6376521290614047}}]}, 
   {Hue[0.6208246353085951], AbsoluteThickness[0.5], 
    LineBox[{{2.8457343240913775`, -0.6376521290614047}, {
     2.76698097094436, -0.9136282362013578}}]}, 
   {Hue[0.6640686298919858], AbsoluteThickness[0.5], 
    LineBox[{{2.022224436688972, -4.159003793357094}, {
     1.9174671061852435`, -4.381252121287735}}]}, 
   {Hue[0.6661183816140728], AbsoluteThickness[0.5], 
    LineBox[{{1.9174671061852435`, -4.381252121287735}, {
     1.8469510422318647`, -4.609958624362995}}]}, 
   {Hue[0.6229958167643556], AbsoluteThickness[0.5], 
    LineBox[{{7.494769203610686, -2.698156494595948}, {
     7.454944035715042, -2.8682826372845196`}}]}, 
   {Hue[0.6302227690919693], AbsoluteThickness[0.5], 
    LineBox[{{7.454944035715042, -2.8682826372845196`}, {
     7.410516235392727, -2.9586065861567707`}}]}, 
   {Hue[0.6541224329017671], AbsoluteThickness[0.5], 
    LineBox[{{2.932041666764273, 1.8507146914758583`}, {2.917240769385625, 
     1.8377610092310834`}}]}, 
   {Hue[0.6546538141828855], AbsoluteThickness[0.5], 
    LineBox[{{2.917240769385625, 1.8377610092310834`}, {2.706719792673475, 
     1.6363499671725925`}}]}, 
   {Hue[0.6333611462291652], AbsoluteThickness[0.5], 
    LineBox[{{5.169157403642955, -1.0637260963879793`}, {
     5.202675903432777, -1.1572774422594476`}}]}, 
   {Hue[0.6337979909740216], AbsoluteThickness[0.5], 
    LineBox[{{5.202675903432777, -1.1572774422594476`}, {
     5.294177272847616, -1.424972220754548}}]}, 
   {Hue[0.6212647148489885], AbsoluteThickness[0.5], 
    LineBox[{{2.76698097094436, -0.9136282362013579}, {
     2.7144331313152126`, -1.1101392835590347`}}]}, 
   {Hue[0.6245764947843357], AbsoluteThickness[0.5], 
    LineBox[{{2.7144331313152126`, -1.1101392835590347`}, {
     2.6484402532861626`, -1.2524896775383603`}}]}, 
   {Hue[0.6374497214195828], AbsoluteThickness[0.5], 
    LineBox[{{7.410516235392727, -2.9586065861567707`}, {
     7.289605387157921, -3.1068193646242244`}}]}, 
   {Hue[0.6379192622180107], AbsoluteThickness[0.5], 
    LineBox[{{7.289605387157921, -3.1068193646242244`}, {
     7.083657688760581, -3.3448343061345214`}}]}, 
   {Hue[0.655185195464004], AbsoluteThickness[0.5], 
    LineBox[{{2.706719792673475, 1.6363499671725925`}, {2.635683707268276, 
     1.56208263784201}}]}, 
   {Hue[0.6557573762034216], AbsoluteThickness[0.5], 
    LineBox[{{2.635683707268276, 1.56208263784201}, {2.429630316646151, 
     1.3230602773993003`}}]}, 
   {Hue[0.634234835718878], AbsoluteThickness[0.5], 
    LineBox[{{5.294177272847616, -1.424972220754548}, {
     5.3396476531621575`, -1.5646664816238565`}}]}, 
   {Hue[0.6366879722864841], AbsoluteThickness[0.5], 
    LineBox[{{5.3396476531621575`, -1.5646664816238565`}, {
     5.42927568770402, -1.7421093272485593`}}]}, 
   {Hue[0.6278882747196832], AbsoluteThickness[0.5], 
    LineBox[{{2.6484402532861626`, -1.2524896775383603`}, {
     2.561514554545255, -1.3776827889340666`}}]}, 
   {Hue[0.6283147754262667], AbsoluteThickness[0.5], 
    LineBox[{{2.561514554545255, -1.3776827889340666`}, {
     2.3911058066557005`, -1.6212494636512051`}}]}, 
   {Hue[0.6383888030164386], AbsoluteThickness[0.5], 
    LineBox[{{7.083657688760581, -3.3448343061345214`}, {
     7.071250431507805, -3.3583601575657864`}}]}, 
   {Hue[0.6391121955147429], AbsoluteThickness[0.5], 
    LineBox[{{7.071250431507805, -3.3583601575657864`}, {
     6.86945645847591, -3.54905670493163}}]}, 
   {Hue[0.6563295569428391], AbsoluteThickness[0.5], 
    LineBox[{{2.429630316646151, 1.3230602773993003`}, {2.4001864819998193`, 
     1.285102933583328}}]}, 
   {Hue[0.6571620495343204], AbsoluteThickness[0.5], 
    LineBox[{{2.4001864819998193`, 1.285102933583328}, {2.2510196220350576`, 
     1.0564239118444732`}}]}, 
   {Hue[0.6391411088540901], AbsoluteThickness[0.5], 
    LineBox[{{5.42927568770402, -1.7421093272485593`}, {
     5.465623712524398, -1.7929406007278716`}}]}, 
   {Hue[0.6398050163798671], AbsoluteThickness[0.5], 
    LineBox[{{5.465623712524398, -1.7929406007278716`}, {
     5.654902252091846, -2.0244421505628236`}}]}, 
   {Hue[0.6287412761328504], AbsoluteThickness[0.5], 
    LineBox[{{2.3911058066557005`, -1.6212494636512051`}, {
     2.3893576316063556`, -1.6237292441622926`}}]}, 
   {Hue[0.6292741623255974], AbsoluteThickness[0.5], 
    LineBox[{{2.3893576316063556`, -1.6237292441622926`}, {
     2.2389866643718768`, -1.8586334038293888`}}]}, 
   {Hue[0.6398355880130471], AbsoluteThickness[0.5], 
    LineBox[{{6.86945645847591, -3.54905670493163}, {
     6.806556703621603, -3.600523065438304}}]}, 
   {Hue[0.6405286408594836], AbsoluteThickness[0.5], 
    LineBox[{{6.806556703621603, -3.600523065438304}, {
     6.561030761843103, -3.7749583323120173`}}]}, 
   {Hue[0.6579945421258018], AbsoluteThickness[0.5], 
    LineBox[{{2.2510196220350576`, 1.0564239118444732`}, {1.9836210360795838`,
      0.5625322242415495}}]}, 
   {Hue[0.6746600836874829], AbsoluteThickness[0.5], 
    LineBox[{{1.9836210360795838`, 0.5625322242415495}, {1.9381887474905812`, 
     0.5173195772690438}}]}, 
   {Hue[0.6404689239056441], AbsoluteThickness[0.5], 
    LineBox[{{5.654902252091846, -2.0244421505628236`}, {
     5.735330146920918, -2.1107744017577317`}}]}, 
   {Hue[0.6440362827712625], AbsoluteThickness[0.5], 
    LineBox[{{5.735330146920918, -2.1107744017577317`}, {
     5.865545247894082, -2.2083344630332635`}}]}, 
   {Hue[0.6298070485183446], AbsoluteThickness[0.5], 
    LineBox[{{2.2389866643718768`, -1.8586334038293888`}, {
     2.1954794820733308`, -1.9337872264223561`}}]}, 
   {Hue[0.637764167678115], AbsoluteThickness[0.5], 
    LineBox[{{2.1954794820733308`, -1.9337872264223561`}, {
     2.1587789045899126`, -2.056541377106089}}]}, 
   {Hue[0.6412216937059202], AbsoluteThickness[0.5], 
    LineBox[{{6.561030761843103, -3.7749583323120173`}, {
     6.115347207721055, -4.048000810507359}}]}, 
   {Hue[0.6498281658020929], AbsoluteThickness[0.5], 
    LineBox[{{6.115347207721055, -4.048000810507359}, {
     6.035324734738089, -4.128721749115218}}]}, 
   {Hue[0.6476036416368809], AbsoluteThickness[0.5], 
    LineBox[{{5.865545247894082, -2.2083344630332635`}, {
     6.373129398373634, -2.4631229215039023`}}]}, 
   {Hue[0.6484256405530086], AbsoluteThickness[0.5], 
    LineBox[{{6.373129398373634, -2.4631229215039023`}, {
     6.61711340804775, -2.611394181237661}}]}, 
   {Hue[0.6457212868378853], AbsoluteThickness[0.5], 
    LineBox[{{2.1587789045899126`, -2.056541377106089}, {
     2.1551853208983887`, -2.120339421733841}}]}, 
   {Hue[0.6497005611517958], AbsoluteThickness[0.5], 
    LineBox[{{2.1551853208983887`, -2.120339421733841}, {
     2.115076282070993, -2.2832258633855997`}}]}, 
   {Hue[0.6584346378982657], AbsoluteThickness[0.5], 
    LineBox[{{6.035324734738089, -4.128721749115218}, {
     5.8624585313304705`, -4.416473147529362}}]}, 
   {Hue[0.6492476394691362], AbsoluteThickness[0.5], 
    LineBox[{{6.61711340804775, -2.611394181237661}, {
     6.645196623649224, -2.631737899811229}}]}, 
   {Hue[0.6498134363573699], AbsoluteThickness[0.5], 
    LineBox[{{6.645196623649224, -2.631737899811229}, {
     6.894578603508006, -2.79380194362968}}]}, 
   {Hue[0.6536798354657062], AbsoluteThickness[0.5], 
    LineBox[{{2.115076282070993, -2.2832258633855997`}, {
     2.0913015110832864`, -2.3355336163367113`}}]}, 
   {Hue[0.6541112995611441], AbsoluteThickness[0.5], 
    LineBox[{{2.0913015110832864`, -2.3355336163367113`}, {
     1.9555549598138837`, -2.64271960910893}}]}, 
   {Hue[0.6584346378982655], AbsoluteThickness[0.5], 
    LineBox[{{5.8624585313304705`, -4.416473147529362}, {
     5.655948822488801, -4.545586709949738}}]}, 
   {Hue[0.6651228707989512], AbsoluteThickness[0.5], 
    LineBox[{{5.655948822488801, -4.545586709949738}, {
     5.555610177325327, -4.6449068360619865`}}]}, 
   {Hue[0.6503792332456036], AbsoluteThickness[0.5], 
    LineBox[{{6.894578603508006, -2.79380194362968}, {
     6.93423925556448, -2.8168079437921905`}}]}, 
   {Hue[0.6520995488574346], AbsoluteThickness[0.5], 
    LineBox[{{6.93423925556448, -2.8168079437921905`}, {
     7.129977548591252, -2.8985398700526748`}}]}, 
   {Hue[0.6538198644692657], AbsoluteThickness[0.5], 
    LineBox[{{{7.129977548591252, -2.8985398700526748`}, {
     7.212694309035955, -2.921028813405682}}, {{
     7.212694309035955, -2.921028813405682}, {
     7.566692746754374, -3.3026383456230595`}}}], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJwUmXc4lt8fx5897VUhqVQqaQop54MSpZKKksy0KBUSKZH0FVJGIgltSkLJ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      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.566101536984902*^9, 3.614727912172139*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->
  "During evaluation of \
In[281]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData["11.9826080000000008141114449244923889637`7.099151265284586"], \
"Output",
 CellChangeTimes->{3.566101615836906*^9, 3.614727912174264*^9},
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."},
 CellLabel->"Out[281]="]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"chapter 7 topics"]], "Text",
 CellTags->"PR7."]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1422, 786},
WindowMargins->{{Automatic, -142}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "chapter 7 topics"->{
  Cell[579, 22, 193, 3, 60, "Subtitle",
   CellTags->{
    "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
     "Solar Array Example", "Cellular Array Example", "PR7."}]},
 "7.1 Introduction"->{
  Cell[579, 22, 193, 3, 60, "Subtitle",
   CellTags->{
    "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
     "Solar Array Example", "Cellular Array Example", "PR7."}],
  Cell[1215, 48, 92, 1, 34, "Section",
   CellTags->{"7.1", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1310, 51, 559, 14, 38, "Text",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1894, 69, 133, 2, 24, "Input",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[2030, 73, 2689, 37, 285, "Print",
   CellTags->{
    "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
     "PR7.", "PR7.1"}]},
 "Lenticular Array Example"->{
  Cell[579, 22, 193, 3, 60, "Subtitle",
   CellTags->{
    "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
     "Solar Array Example", "Cellular Array Example", "PR7."}],
  Cell[1310, 51, 559, 14, 38, "Text",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1894, 69, 133, 2, 24, "Input",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[2030, 73, 2689, 37, 285, "Print",
   CellTags->{
    "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
     "PR7.", "PR7.1"}],
  Cell[4905, 121, 112, 1, 60, "Section",
   CellTags->{"7.2", "Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5020, 124, 344, 6, 20, "Text",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5367, 132, 172, 4, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5542, 138, 169, 4, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5736, 146, 340, 8, 73, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[6079, 156, 1393, 39, 40, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7509, 200, 159, 2, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7671, 204, 203, 4, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7911, 213, 197, 5, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[8111, 220, 2570598, 42917, 365, 2474895, 41345, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2578746, 43142, 436, 10, 89, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579185, 43154, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579448, 43160, 248, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579699, 43166, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2580081, 43176, 369, 8, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2580453, 43186, 41439, 961, 658, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2621895, 44149, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2622275, 44159, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2622536, 44165, 565, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623104, 44179, 267, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623374, 44185, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623784, 44196, 272, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624059, 44202, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624328, 44208, 270, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624601, 44214, 535, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625139, 44228, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625394, 44234, 262, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625659, 44240, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625919, 44246, 381, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2626303, 44257, 445, 11, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2626751, 44270, 264, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2627018, 44276, 4085, 88, 36, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631106, 44366, 273, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631382, 44372, 353, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631738, 44382, 383, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632124, 44393, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632385, 44399, 395, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632783, 44409, 375, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633161, 44419, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633543, 44429, 244, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633790, 44435, 405, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2634198, 44446, 463, 10, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2634664, 44458, 709, 14, 22, "Message",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2635376, 44474, 412, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2635791, 44485, 700, 14, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2636494, 44501, 281, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2636778, 44508, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637038, 44514, 261, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637302, 44520, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637557, 44526, 296, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637856, 44533, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638104, 44539, 296, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638403, 44546, 247, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638653, 44552, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638916, 44558, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639173, 44564, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639430, 44570, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639699, 44576, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639956, 44582, 423361, 8223, 438, 399729, 7832, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063320, 52807, 261, 5, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063618, 52817, 328, 8, 73, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063949, 52827, 262, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064214, 52833, 246, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064463, 52839, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064843, 52849, 367, 8, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3065213, 52859, 40289, 930, 626, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3105505, 53791, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3105885, 53801, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106148, 53807, 567, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106718, 53821, 269, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106990, 53827, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107400, 53838, 272, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107675, 53844, 267, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107945, 53850, 268, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3108216, 53856, 537, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3108756, 53870, 253, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109012, 53876, 264, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109279, 53882, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109539, 53888, 381, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109923, 53899, 443, 11, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3110369, 53912, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3110638, 53918, 4085, 88, 36, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3114726, 54008, 273, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115002, 54014, 355, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115360, 54024, 383, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115746, 54035, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116007, 54041, 395, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116405, 54051, 375, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116783, 54061, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117165, 54071, 246, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117414, 54077, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117824, 54088, 476, 10, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3118303, 54100, 712, 14, 22, "Message",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3119018, 54116, 703, 14, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3119724, 54132, 281, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120008, 54139, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120268, 54145, 259, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120530, 54151, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120787, 54157, 298, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121088, 54164, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121336, 54170, 298, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121637, 54177, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121885, 54183, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122146, 54189, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122401, 54195, 277, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122681, 54202, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122938, 54208, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3123207, 54214, 251, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3123461, 54220, 402790, 7889, 195, 400150, 7842, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3526254, 62111, 259, 5, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]},
 "Solar Array Example"->{
  Cell[579, 22, 193, 3, 60, "Subtitle",
   CellTags->{
    "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
     "Solar Array Example", "Cellular Array Example", "PR7."}],
  Cell[3526699, 62127, 102, 1, 60, "Section",
   CellTags->{"7.3", "Solar Array Example", "PR7.3", "PR7."}],
  Cell[3526804, 62130, 166, 4, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3526973, 62136, 171, 4, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527147, 62142, 431, 10, 106, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527603, 62156, 198, 5, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527804, 62163, 590032, 10134, 365, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4117873, 72302, 151, 2, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4118027, 72306, 714894, 11684, 232, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4832958, 83995, 442, 11, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833403, 84008, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833658, 84014, 239, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833900, 84020, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4834273, 84030, 362, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4834638, 84040, 109392, 2541, 1638, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944033, 86583, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944404, 86593, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944658, 86599, 560, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945221, 86613, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945484, 86619, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945887, 86630, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946155, 86636, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946418, 86642, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946682, 86648, 530, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947215, 86662, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947464, 86668, 255, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947722, 86674, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947975, 86680, 376, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4948354, 86691, 435, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4948792, 86704, 257, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4949052, 86710, 4145, 92, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953200, 86804, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953467, 86810, 345, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953815, 86820, 375, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954193, 86831, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954447, 86837, 386, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954836, 86847, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955209, 86857, 374, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955586, 86867, 237, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955826, 86873, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4956229, 86884, 463, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4956695, 86896, 705, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4957403, 86912, 692, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958098, 86928, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958373, 86935, 248, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958624, 86941, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958879, 86947, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959127, 86953, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959400, 86960, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959648, 86966, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959923, 86973, 249, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960175, 86979, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960439, 86985, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960687, 86991, 182103, 3182, 345, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5142827, 90178, 442, 11, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143272, 90191, 253, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143528, 90197, 241, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143772, 90203, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5144145, 90213, 360, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5144508, 90223, 109392, 2541, 1638, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5253903, 92766, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5254274, 92776, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5254528, 92782, 558, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255089, 92796, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255352, 92802, 399, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255754, 92813, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256022, 92819, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256285, 92825, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256549, 92831, 528, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257080, 92845, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257329, 92851, 255, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257587, 92857, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257840, 92863, 376, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258219, 92874, 436, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258658, 92887, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258920, 92893, 4147, 92, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263070, 92987, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263337, 92993, 346, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263686, 93003, 378, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264067, 93014, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264320, 93020, 388, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264711, 93030, 366, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265080, 93040, 372, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265455, 93050, 237, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265695, 93056, 398, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5266096, 93067, 463, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5266562, 93079, 705, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5267270, 93095, 696, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5267969, 93111, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268244, 93118, 248, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268495, 93124, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268748, 93130, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268996, 93136, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269269, 93143, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269519, 93149, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269794, 93156, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270044, 93162, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270306, 93168, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270556, 93174, 262704, 4503, 345, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533297, 97682, 379, 9, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533679, 97693, 256, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533938, 97699, 242, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534183, 97705, 371, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534557, 97715, 361, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534921, 97725, 108234, 2511, 1622, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643158, 100238, 369, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643530, 100248, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643785, 100254, 559, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5644347, 100268, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5644611, 100274, 401, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645015, 100285, 266, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645284, 100291, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645548, 100297, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645815, 100303, 531, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646349, 100317, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646599, 100323, 258, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646860, 100329, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647114, 100335, 375, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647492, 100346, 437, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647932, 100359, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5648195, 100365, 4314, 95, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5652512, 100462, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5652780, 100468, 347, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653130, 100478, 377, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653510, 100489, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653764, 100495, 389, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654156, 100505, 369, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654528, 100515, 375, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654906, 100525, 240, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5655149, 100531, 401, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5655553, 100542, 468, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5656024, 100554, 709, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5656736, 100570, 407, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5657146, 100581, 695, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5657844, 100597, 275, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658122, 100604, 249, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658374, 100610, 253, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658630, 100616, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658879, 100622, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659152, 100629, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659401, 100635, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659674, 100642, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659927, 100648, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5660189, 100654, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5660438, 100660, 731212, 12186, 366, 728615, 12140, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6391687, 112851, 383, 9, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392073, 112862, 244, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392320, 112868, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392575, 112874, 239, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392817, 112880, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6393190, 112890, 360, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6393553, 112900, 111108, 2564, 1654, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6504664, 115466, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505035, 115476, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505289, 115482, 560, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505852, 115496, 262, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506117, 115502, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506520, 115513, 267, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506790, 115519, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507053, 115525, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507317, 115531, 527, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507847, 115545, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508096, 115551, 257, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508356, 115557, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508611, 115563, 374, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508988, 115574, 436, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6509427, 115587, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6509689, 115593, 4313, 95, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514005, 115690, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514259, 115696, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514513, 115702, 263, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514779, 115708, 352, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515134, 115718, 444, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515581, 115731, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515835, 115737, 399, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6516237, 115748, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6516610, 115758, 784, 18, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6517397, 115778, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6517800, 115789, 466, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6518269, 115801, 709, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6518981, 115817, 829, 19, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6519813, 115838, 1810585, 29865, 285, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330401, 145705, 242, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330680, 145714, 126, 2, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330809, 145718, 826, 19, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8331638, 145739, 1048347, 18090, 304, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}]},
 "Cellular Array Example"->{
  Cell[579, 22, 193, 3, 60, "Subtitle",
   CellTags->{
    "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
     "Solar Array Example", "Cellular Array Example", "PR7."}],
  Cell[9380171, 163840, 108, 1, 60, "Section",
   CellTags->{"7.4", "Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380282, 163843, 182, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380467, 163849, 174, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380666, 163857, 119, 2, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380788, 163861, 200, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381003, 163868, 172, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381178, 163874, 204, 5, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381385, 163881, 178, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381566, 163887, 250, 11, 138, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381841, 163902, 202, 6, 57, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9382046, 163910, 682, 21, 24, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9382765, 163936, 245, 8, 89, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9383013, 163946, 7130157, 126334, 404, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513207, 290285, 412, 10, 122, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513622, 290297, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513883, 290303, 242, 4, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514128, 290309, 373, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514504, 290319, 363, 8, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514870, 290329, 286398, 6012, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801271, 296343, 373, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801647, 296353, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801904, 296359, 558, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16802465, 296373, 263, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16802731, 296379, 402, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803136, 296390, 267, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803406, 296396, 263, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803672, 296402, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803939, 296408, 531, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804473, 296422, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804725, 296428, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804986, 296434, 253, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16805242, 296440, 377, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16805622, 296451, 439, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16806064, 296464, 260, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16806327, 296470, 3765, 84, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810095, 296556, 269, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810367, 296562, 349, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810719, 296572, 379, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811101, 296583, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811358, 296589, 389, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811750, 296599, 371, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812124, 296609, 375, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812502, 296619, 240, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812745, 296625, 405, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16813153, 296636, 582, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16813738, 296652, 735, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16814476, 296668, 413, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16814892, 296679, 699, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16815594, 296695, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16815872, 296702, 251, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816126, 296708, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816384, 296714, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816635, 296720, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816913, 296727, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817189, 296734, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817465, 296741, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817716, 296747, 271, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817990, 296754, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818266, 296761, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818544, 296768, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818820, 296775, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819098, 296782, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819374, 296789, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819641, 296795, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819894, 296801, 160382, 2849, 357, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980279, 299652, 257, 5, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980573, 299662, 412, 11, 122, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980988, 299675, 259, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981250, 299681, 245, 4, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981498, 299687, 374, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981875, 299697, 364, 8, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16982242, 299707, 282864, 5951, 3012, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265109, 305660, 372, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265484, 305670, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265742, 305676, 562, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266307, 305690, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266574, 305696, 406, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266983, 305707, 268, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267254, 305713, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267521, 305719, 265, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267789, 305725, 534, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268326, 305739, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268579, 305745, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268840, 305751, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269097, 305757, 378, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269478, 305768, 440, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269921, 305781, 260, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17270184, 305787, 3007, 66, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273194, 305855, 268, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273465, 305861, 350, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273818, 305871, 380, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274201, 305882, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274459, 305888, 394, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274856, 305898, 372, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275231, 305908, 375, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275609, 305918, 241, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275853, 305924, 402, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17276258, 305935, 590, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17276851, 305951, 735, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17277589, 305967, 700, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17278292, 305983, 6102990, 119951, 32772, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[23381285, 425936, 246, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[23381534, 425942, 6406134, 124480, 49716, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29787671, 550424, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29787923, 550430, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788200, 550437, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788477, 550444, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788754, 550451, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789006, 550457, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789283, 550464, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789560, 550471, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789837, 550478, 276, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790116, 550485, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790393, 550492, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790669, 550499, 721694, 12827, 314, 587316, 10621, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30512366, 563328, 235, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30512638, 563337, 410, 10, 106, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513051, 563349, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513287, 563354, 221, 3, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513511, 563359, 350, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513864, 563368, 340, 7, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30514207, 563377, 286002, 6005, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800212, 569384, 350, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800565, 569393, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800799, 569398, 538, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801340, 569411, 240, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801583, 569416, 380, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801966, 569426, 245, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802214, 569431, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802456, 569436, 243, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802702, 569441, 508, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803213, 569454, 226, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803442, 569459, 237, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803682, 569464, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803915, 569469, 354, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804272, 569479, 416, 10, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804691, 569491, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804933, 569496, 3100, 67, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808036, 569565, 246, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808285, 569570, 328, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808616, 569579, 358, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808977, 569589, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809211, 569594, 366, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809580, 569603, 347, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809930, 569612, 352, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810285, 569621, 217, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810505, 569626, 380, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810888, 569636, 568, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30811459, 569651, 739, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30812201, 569667, 388, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30812592, 569677, 674, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813269, 569692, 251, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813523, 569698, 228, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813754, 569703, 232, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813989, 569708, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814217, 569713, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814470, 569719, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814723, 569725, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814975, 569731, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815203, 569736, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815458, 569742, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815711, 569748, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815964, 569754, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816217, 569760, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816470, 569766, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816725, 569772, 227, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816955, 569777, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30817197, 569782, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30817425, 569787, 7747208, 134168, 271, 7579651, 131418, 
  "CachedBoxData", "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38564636, 703957, 232, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38564905, 703966, 439, 11, 106, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565347, 703979, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565583, 703984, 217, 3, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565803, 703989, 348, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38566154, 703998, 338, 7, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38566495, 704007, 286196, 6009, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38852694, 710018, 346, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853043, 710027, 229, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853275, 710032, 536, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853814, 710045, 238, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854055, 710050, 378, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854436, 710060, 245, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854684, 710065, 240, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854927, 710070, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855169, 710075, 506, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855678, 710088, 224, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855905, 710093, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856141, 710098, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856374, 710103, 352, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856729, 710113, 414, 10, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38857146, 710125, 235, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38857384, 710130, 3839, 85, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861226, 710217, 242, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861471, 710222, 324, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861798, 710231, 354, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862155, 710241, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862389, 710246, 364, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862756, 710255, 346, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863105, 710264, 349, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863457, 710273, 215, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863675, 710278, 378, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38864056, 710288, 566, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38864625, 710303, 737, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38865365, 710319, 386, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38865754, 710329, 672, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866429, 710344, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866684, 710350, 226, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866913, 710355, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867146, 710360, 222, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867371, 710365, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867624, 710371, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867875, 710377, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868126, 710383, 223, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868352, 710388, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868605, 710394, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868856, 710400, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869107, 710406, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869358, 710412, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869609, 710418, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869860, 710424, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38870102, 710429, 223, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38870328, 710434, 1245638, 22409, 357, 1051443, 19223, "CachedBoxData",
   "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[40115969, 732845, 232, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]},
 "PR7."->{
  Cell[579, 22, 193, 3, 60, "Subtitle",
   CellTags->{
    "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
     "Solar Array Example", "Cellular Array Example", "PR7."}],
  Cell[775, 27, 415, 17, 79, "Outline2",
   CellTags->"PR7."],
  Cell[1215, 48, 92, 1, 34, "Section",
   CellTags->{"7.1", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1310, 51, 559, 14, 38, "Text",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1894, 69, 133, 2, 24, "Input",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[2030, 73, 2689, 37, 285, "Print",
   CellTags->{
    "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
     "PR7.", "PR7.1"}],
  Cell[4734, 113, 134, 3, 20, "Text",
   CellTags->"PR7."],
  Cell[4905, 121, 112, 1, 60, "Section",
   CellTags->{"7.2", "Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5020, 124, 344, 6, 20, "Text",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5367, 132, 172, 4, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5542, 138, 169, 4, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5736, 146, 340, 8, 73, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[6079, 156, 1393, 39, 40, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7509, 200, 159, 2, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7671, 204, 203, 4, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7911, 213, 197, 5, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[8111, 220, 2570598, 42917, 365, 2474895, 41345, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2578746, 43142, 436, 10, 89, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579185, 43154, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579448, 43160, 248, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579699, 43166, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2580081, 43176, 369, 8, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2580453, 43186, 41439, 961, 658, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2621895, 44149, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2622275, 44159, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2622536, 44165, 565, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623104, 44179, 267, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623374, 44185, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623784, 44196, 272, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624059, 44202, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624328, 44208, 270, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624601, 44214, 535, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625139, 44228, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625394, 44234, 262, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625659, 44240, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625919, 44246, 381, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2626303, 44257, 445, 11, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2626751, 44270, 264, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2627018, 44276, 4085, 88, 36, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631106, 44366, 273, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631382, 44372, 353, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631738, 44382, 383, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632124, 44393, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632385, 44399, 395, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632783, 44409, 375, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633161, 44419, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633543, 44429, 244, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633790, 44435, 405, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2634198, 44446, 463, 10, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2634664, 44458, 709, 14, 22, "Message",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2635376, 44474, 412, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2635791, 44485, 700, 14, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2636494, 44501, 281, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2636778, 44508, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637038, 44514, 261, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637302, 44520, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637557, 44526, 296, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637856, 44533, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638104, 44539, 296, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638403, 44546, 247, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638653, 44552, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638916, 44558, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639173, 44564, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639430, 44570, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639699, 44576, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639956, 44582, 423361, 8223, 438, 399729, 7832, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063320, 52807, 261, 5, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063618, 52817, 328, 8, 73, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063949, 52827, 262, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064214, 52833, 246, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064463, 52839, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064843, 52849, 367, 8, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3065213, 52859, 40289, 930, 626, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3105505, 53791, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3105885, 53801, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106148, 53807, 567, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106718, 53821, 269, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106990, 53827, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107400, 53838, 272, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107675, 53844, 267, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107945, 53850, 268, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3108216, 53856, 537, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3108756, 53870, 253, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109012, 53876, 264, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109279, 53882, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109539, 53888, 381, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109923, 53899, 443, 11, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3110369, 53912, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3110638, 53918, 4085, 88, 36, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3114726, 54008, 273, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115002, 54014, 355, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115360, 54024, 383, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115746, 54035, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116007, 54041, 395, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116405, 54051, 375, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116783, 54061, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117165, 54071, 246, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117414, 54077, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117824, 54088, 476, 10, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3118303, 54100, 712, 14, 22, "Message",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3119018, 54116, 703, 14, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3119724, 54132, 281, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120008, 54139, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120268, 54145, 259, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120530, 54151, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120787, 54157, 298, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121088, 54164, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121336, 54170, 298, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121637, 54177, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121885, 54183, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122146, 54189, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122401, 54195, 277, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122681, 54202, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122938, 54208, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3123207, 54214, 251, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3123461, 54220, 402790, 7889, 195, 400150, 7842, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3526254, 62111, 259, 5, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3526528, 62119, 134, 3, 20, "Text",
   CellTags->"PR7."],
  Cell[3526699, 62127, 102, 1, 60, "Section",
   CellTags->{"7.3", "Solar Array Example", "PR7.3", "PR7."}],
  Cell[3526804, 62130, 166, 4, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3526973, 62136, 171, 4, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527147, 62142, 431, 10, 106, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527603, 62156, 198, 5, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527804, 62163, 590032, 10134, 365, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4117873, 72302, 151, 2, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4118027, 72306, 714894, 11684, 232, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4832958, 83995, 442, 11, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833403, 84008, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833658, 84014, 239, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833900, 84020, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4834273, 84030, 362, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4834638, 84040, 109392, 2541, 1638, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944033, 86583, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944404, 86593, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944658, 86599, 560, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945221, 86613, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945484, 86619, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945887, 86630, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946155, 86636, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946418, 86642, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946682, 86648, 530, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947215, 86662, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947464, 86668, 255, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947722, 86674, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947975, 86680, 376, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4948354, 86691, 435, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4948792, 86704, 257, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4949052, 86710, 4145, 92, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953200, 86804, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953467, 86810, 345, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953815, 86820, 375, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954193, 86831, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954447, 86837, 386, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954836, 86847, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955209, 86857, 374, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955586, 86867, 237, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955826, 86873, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4956229, 86884, 463, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4956695, 86896, 705, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4957403, 86912, 692, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958098, 86928, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958373, 86935, 248, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958624, 86941, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958879, 86947, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959127, 86953, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959400, 86960, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959648, 86966, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959923, 86973, 249, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960175, 86979, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960439, 86985, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960687, 86991, 182103, 3182, 345, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5142827, 90178, 442, 11, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143272, 90191, 253, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143528, 90197, 241, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143772, 90203, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5144145, 90213, 360, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5144508, 90223, 109392, 2541, 1638, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5253903, 92766, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5254274, 92776, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5254528, 92782, 558, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255089, 92796, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255352, 92802, 399, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255754, 92813, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256022, 92819, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256285, 92825, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256549, 92831, 528, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257080, 92845, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257329, 92851, 255, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257587, 92857, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257840, 92863, 376, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258219, 92874, 436, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258658, 92887, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258920, 92893, 4147, 92, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263070, 92987, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263337, 92993, 346, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263686, 93003, 378, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264067, 93014, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264320, 93020, 388, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264711, 93030, 366, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265080, 93040, 372, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265455, 93050, 237, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265695, 93056, 398, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5266096, 93067, 463, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5266562, 93079, 705, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5267270, 93095, 696, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5267969, 93111, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268244, 93118, 248, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268495, 93124, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268748, 93130, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268996, 93136, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269269, 93143, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269519, 93149, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269794, 93156, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270044, 93162, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270306, 93168, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270556, 93174, 262704, 4503, 345, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533297, 97682, 379, 9, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533679, 97693, 256, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533938, 97699, 242, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534183, 97705, 371, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534557, 97715, 361, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534921, 97725, 108234, 2511, 1622, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643158, 100238, 369, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643530, 100248, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643785, 100254, 559, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5644347, 100268, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5644611, 100274, 401, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645015, 100285, 266, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645284, 100291, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645548, 100297, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645815, 100303, 531, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646349, 100317, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646599, 100323, 258, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646860, 100329, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647114, 100335, 375, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647492, 100346, 437, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647932, 100359, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5648195, 100365, 4314, 95, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5652512, 100462, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5652780, 100468, 347, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653130, 100478, 377, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653510, 100489, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653764, 100495, 389, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654156, 100505, 369, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654528, 100515, 375, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654906, 100525, 240, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5655149, 100531, 401, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5655553, 100542, 468, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5656024, 100554, 709, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5656736, 100570, 407, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5657146, 100581, 695, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5657844, 100597, 275, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658122, 100604, 249, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658374, 100610, 253, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658630, 100616, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658879, 100622, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659152, 100629, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659401, 100635, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659674, 100642, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659927, 100648, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5660189, 100654, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5660438, 100660, 731212, 12186, 366, 728615, 12140, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6391687, 112851, 383, 9, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392073, 112862, 244, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392320, 112868, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392575, 112874, 239, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392817, 112880, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6393190, 112890, 360, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6393553, 112900, 111108, 2564, 1654, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6504664, 115466, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505035, 115476, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505289, 115482, 560, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505852, 115496, 262, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506117, 115502, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506520, 115513, 267, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506790, 115519, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507053, 115525, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507317, 115531, 527, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507847, 115545, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508096, 115551, 257, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508356, 115557, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508611, 115563, 374, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508988, 115574, 436, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6509427, 115587, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6509689, 115593, 4313, 95, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514005, 115690, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514259, 115696, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514513, 115702, 263, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514779, 115708, 352, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515134, 115718, 444, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515581, 115731, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515835, 115737, 399, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6516237, 115748, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6516610, 115758, 784, 18, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6517397, 115778, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6517800, 115789, 466, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6518269, 115801, 709, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6518981, 115817, 829, 19, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6519813, 115838, 1810585, 29865, 285, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330401, 145705, 242, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330680, 145714, 126, 2, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330809, 145718, 826, 19, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8331638, 145739, 1048347, 18090, 304, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[9380000, 163832, 134, 3, 20, "Text",
   CellTags->"PR7."],
  Cell[9380171, 163840, 108, 1, 60, "Section",
   CellTags->{"7.4", "Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380282, 163843, 182, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380467, 163849, 174, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380666, 163857, 119, 2, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380788, 163861, 200, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381003, 163868, 172, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381178, 163874, 204, 5, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381385, 163881, 178, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381566, 163887, 250, 11, 138, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381841, 163902, 202, 6, 57, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9382046, 163910, 682, 21, 24, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9382765, 163936, 245, 8, 89, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9383013, 163946, 7130157, 126334, 404, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513207, 290285, 412, 10, 122, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513622, 290297, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513883, 290303, 242, 4, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514128, 290309, 373, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514504, 290319, 363, 8, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514870, 290329, 286398, 6012, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801271, 296343, 373, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801647, 296353, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801904, 296359, 558, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16802465, 296373, 263, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16802731, 296379, 402, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803136, 296390, 267, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803406, 296396, 263, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803672, 296402, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803939, 296408, 531, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804473, 296422, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804725, 296428, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804986, 296434, 253, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16805242, 296440, 377, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16805622, 296451, 439, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16806064, 296464, 260, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16806327, 296470, 3765, 84, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810095, 296556, 269, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810367, 296562, 349, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810719, 296572, 379, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811101, 296583, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811358, 296589, 389, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811750, 296599, 371, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812124, 296609, 375, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812502, 296619, 240, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812745, 296625, 405, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16813153, 296636, 582, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16813738, 296652, 735, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16814476, 296668, 413, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16814892, 296679, 699, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16815594, 296695, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16815872, 296702, 251, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816126, 296708, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816384, 296714, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816635, 296720, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816913, 296727, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817189, 296734, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817465, 296741, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817716, 296747, 271, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817990, 296754, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818266, 296761, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818544, 296768, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818820, 296775, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819098, 296782, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819374, 296789, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819641, 296795, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819894, 296801, 160382, 2849, 357, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980279, 299652, 257, 5, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980573, 299662, 412, 11, 122, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980988, 299675, 259, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981250, 299681, 245, 4, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981498, 299687, 374, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981875, 299697, 364, 8, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16982242, 299707, 282864, 5951, 3012, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265109, 305660, 372, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265484, 305670, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265742, 305676, 562, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266307, 305690, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266574, 305696, 406, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266983, 305707, 268, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267254, 305713, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267521, 305719, 265, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267789, 305725, 534, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268326, 305739, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268579, 305745, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268840, 305751, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269097, 305757, 378, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269478, 305768, 440, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269921, 305781, 260, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17270184, 305787, 3007, 66, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273194, 305855, 268, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273465, 305861, 350, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273818, 305871, 380, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274201, 305882, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274459, 305888, 394, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274856, 305898, 372, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275231, 305908, 375, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275609, 305918, 241, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275853, 305924, 402, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17276258, 305935, 590, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17276851, 305951, 735, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17277589, 305967, 700, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17278292, 305983, 6102990, 119951, 32772, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[23381285, 425936, 246, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[23381534, 425942, 6406134, 124480, 49716, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29787671, 550424, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29787923, 550430, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788200, 550437, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788477, 550444, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788754, 550451, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789006, 550457, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789283, 550464, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789560, 550471, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789837, 550478, 276, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790116, 550485, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790393, 550492, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790669, 550499, 721694, 12827, 314, 587316, 10621, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30512366, 563328, 235, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30512638, 563337, 410, 10, 106, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513051, 563349, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513287, 563354, 221, 3, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513511, 563359, 350, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513864, 563368, 340, 7, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30514207, 563377, 286002, 6005, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800212, 569384, 350, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800565, 569393, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800799, 569398, 538, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801340, 569411, 240, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801583, 569416, 380, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801966, 569426, 245, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802214, 569431, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802456, 569436, 243, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802702, 569441, 508, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803213, 569454, 226, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803442, 569459, 237, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803682, 569464, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803915, 569469, 354, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804272, 569479, 416, 10, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804691, 569491, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804933, 569496, 3100, 67, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808036, 569565, 246, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808285, 569570, 328, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808616, 569579, 358, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808977, 569589, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809211, 569594, 366, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809580, 569603, 347, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809930, 569612, 352, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810285, 569621, 217, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810505, 569626, 380, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810888, 569636, 568, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30811459, 569651, 739, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30812201, 569667, 388, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30812592, 569677, 674, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813269, 569692, 251, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813523, 569698, 228, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813754, 569703, 232, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813989, 569708, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814217, 569713, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814470, 569719, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814723, 569725, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814975, 569731, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815203, 569736, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815458, 569742, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815711, 569748, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815964, 569754, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816217, 569760, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816470, 569766, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816725, 569772, 227, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816955, 569777, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30817197, 569782, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30817425, 569787, 7747208, 134168, 271, 7579651, 131418, 
  "CachedBoxData", "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38564636, 703957, 232, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38564905, 703966, 439, 11, 106, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565347, 703979, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565583, 703984, 217, 3, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565803, 703989, 348, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38566154, 703998, 338, 7, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38566495, 704007, 286196, 6009, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38852694, 710018, 346, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853043, 710027, 229, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853275, 710032, 536, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853814, 710045, 238, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854055, 710050, 378, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854436, 710060, 245, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854684, 710065, 240, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854927, 710070, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855169, 710075, 506, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855678, 710088, 224, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855905, 710093, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856141, 710098, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856374, 710103, 352, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856729, 710113, 414, 10, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38857146, 710125, 235, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38857384, 710130, 3839, 85, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861226, 710217, 242, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861471, 710222, 324, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861798, 710231, 354, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862155, 710241, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862389, 710246, 364, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862756, 710255, 346, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863105, 710264, 349, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863457, 710273, 215, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863675, 710278, 378, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38864056, 710288, 566, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38864625, 710303, 737, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38865365, 710319, 386, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38865754, 710329, 672, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866429, 710344, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866684, 710350, 226, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866913, 710355, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867146, 710360, 222, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867371, 710365, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867624, 710371, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867875, 710377, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868126, 710383, 223, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868352, 710388, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868605, 710394, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868856, 710400, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869107, 710406, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869358, 710412, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869609, 710418, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869860, 710424, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38870102, 710429, 223, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38870328, 710434, 1245638, 22409, 357, 1051443, 19223, "CachedBoxData",
   "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[40115969, 732845, 232, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[40116216, 732852, 134, 3, 20, "Text",
   CellTags->"PR7."]},
 "7.1"->{
  Cell[1215, 48, 92, 1, 34, "Section",
   CellTags->{"7.1", "7.1 Introduction", "PR7.1", "PR7."}]},
 "PR7.1"->{
  Cell[1215, 48, 92, 1, 34, "Section",
   CellTags->{"7.1", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1310, 51, 559, 14, 38, "Text",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[1894, 69, 133, 2, 24, "Input",
   CellTags->{
    "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
  Cell[2030, 73, 2689, 37, 285, "Print",
   CellTags->{
    "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
     "PR7.", "PR7.1"}]},
 "Info3614709718-4839658"->{
  Cell[2030, 73, 2689, 37, 285, "Print",
   CellTags->{
    "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
     "PR7.", "PR7.1"}]},
 "7.2"->{
  Cell[4905, 121, 112, 1, 60, "Section",
   CellTags->{"7.2", "Lenticular Array Example", "PR7.2", "PR7."}]},
 "PR7.2"->{
  Cell[4905, 121, 112, 1, 60, "Section",
   CellTags->{"7.2", "Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5020, 124, 344, 6, 20, "Text",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5367, 132, 172, 4, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5542, 138, 169, 4, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[5736, 146, 340, 8, 73, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[6079, 156, 1393, 39, 40, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7509, 200, 159, 2, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7671, 204, 203, 4, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[7911, 213, 197, 5, 24, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[8111, 220, 2570598, 42917, 365, 2474895, 41345, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2578746, 43142, 436, 10, 89, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579185, 43154, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579448, 43160, 248, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2579699, 43166, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2580081, 43176, 369, 8, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2580453, 43186, 41439, 961, 658, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2621895, 44149, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2622275, 44159, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2622536, 44165, 565, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623104, 44179, 267, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623374, 44185, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2623784, 44196, 272, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624059, 44202, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624328, 44208, 270, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2624601, 44214, 535, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625139, 44228, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625394, 44234, 262, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625659, 44240, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2625919, 44246, 381, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2626303, 44257, 445, 11, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2626751, 44270, 264, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2627018, 44276, 4085, 88, 36, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631106, 44366, 273, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631382, 44372, 353, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2631738, 44382, 383, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632124, 44393, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632385, 44399, 395, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2632783, 44409, 375, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633161, 44419, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633543, 44429, 244, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2633790, 44435, 405, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2634198, 44446, 463, 10, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2634664, 44458, 709, 14, 22, "Message",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2635376, 44474, 412, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2635791, 44485, 700, 14, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2636494, 44501, 281, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2636778, 44508, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637038, 44514, 261, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637302, 44520, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637557, 44526, 296, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2637856, 44533, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638104, 44539, 296, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638403, 44546, 247, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638653, 44552, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2638916, 44558, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639173, 44564, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639430, 44570, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639699, 44576, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[2639956, 44582, 423361, 8223, 438, 399729, 7832, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063320, 52807, 261, 5, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063618, 52817, 328, 8, 73, "Input",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3063949, 52827, 262, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064214, 52833, 246, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064463, 52839, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3064843, 52849, 367, 8, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3065213, 52859, 40289, 930, 626, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3105505, 53791, 377, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3105885, 53801, 260, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106148, 53807, 567, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106718, 53821, 269, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3106990, 53827, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107400, 53838, 272, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107675, 53844, 267, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3107945, 53850, 268, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3108216, 53856, 537, 12, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3108756, 53870, 253, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109012, 53876, 264, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109279, 53882, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109539, 53888, 381, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3109923, 53899, 443, 11, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3110369, 53912, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3110638, 53918, 4085, 88, 36, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3114726, 54008, 273, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115002, 54014, 355, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115360, 54024, 383, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3115746, 54035, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116007, 54041, 395, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116405, 54051, 375, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3116783, 54061, 379, 8, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117165, 54071, 246, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117414, 54077, 407, 9, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3117824, 54088, 476, 10, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3118303, 54100, 712, 14, 22, "Message",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3119018, 54116, 703, 14, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3119724, 54132, 281, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120008, 54139, 257, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120268, 54145, 259, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120530, 54151, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3120787, 54157, 298, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121088, 54164, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121336, 54170, 298, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121637, 54177, 245, 4, 19, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3121885, 54183, 258, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122146, 54189, 252, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122401, 54195, 277, 5, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122681, 54202, 254, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3122938, 54208, 266, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3123207, 54214, 251, 4, 20, "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3123461, 54220, 402790, 7889, 195, 400150, 7842, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
  Cell[3526254, 62111, 259, 5, 23, "Output",
   CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]},
 "7.3"->{
  Cell[3526699, 62127, 102, 1, 60, "Section",
   CellTags->{"7.3", "Solar Array Example", "PR7.3", "PR7."}]},
 "PR7.3"->{
  Cell[3526699, 62127, 102, 1, 60, "Section",
   CellTags->{"7.3", "Solar Array Example", "PR7.3", "PR7."}],
  Cell[3526804, 62130, 166, 4, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3526973, 62136, 171, 4, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527147, 62142, 431, 10, 106, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527603, 62156, 198, 5, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[3527804, 62163, 590032, 10134, 365, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4117873, 72302, 151, 2, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4118027, 72306, 714894, 11684, 232, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4832958, 83995, 442, 11, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833403, 84008, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833658, 84014, 239, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4833900, 84020, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4834273, 84030, 362, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4834638, 84040, 109392, 2541, 1638, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944033, 86583, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944404, 86593, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4944658, 86599, 560, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945221, 86613, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945484, 86619, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4945887, 86630, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946155, 86636, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946418, 86642, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4946682, 86648, 530, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947215, 86662, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947464, 86668, 255, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947722, 86674, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4947975, 86680, 376, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4948354, 86691, 435, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4948792, 86704, 257, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4949052, 86710, 4145, 92, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953200, 86804, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953467, 86810, 345, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4953815, 86820, 375, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954193, 86831, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954447, 86837, 386, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4954836, 86847, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955209, 86857, 374, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955586, 86867, 237, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4955826, 86873, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4956229, 86884, 463, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4956695, 86896, 705, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4957403, 86912, 692, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958098, 86928, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958373, 86935, 248, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958624, 86941, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4958879, 86947, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959127, 86953, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959400, 86960, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959648, 86966, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4959923, 86973, 249, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960175, 86979, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960439, 86985, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[4960687, 86991, 182103, 3182, 345, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5142827, 90178, 442, 11, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143272, 90191, 253, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143528, 90197, 241, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5143772, 90203, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5144145, 90213, 360, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5144508, 90223, 109392, 2541, 1638, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5253903, 92766, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5254274, 92776, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5254528, 92782, 558, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255089, 92796, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255352, 92802, 399, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5255754, 92813, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256022, 92819, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256285, 92825, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5256549, 92831, 528, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257080, 92845, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257329, 92851, 255, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257587, 92857, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5257840, 92863, 376, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258219, 92874, 436, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258658, 92887, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5258920, 92893, 4147, 92, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263070, 92987, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263337, 92993, 346, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5263686, 93003, 378, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264067, 93014, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264320, 93020, 388, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5264711, 93030, 366, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265080, 93040, 372, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265455, 93050, 237, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5265695, 93056, 398, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5266096, 93067, 463, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5266562, 93079, 705, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5267270, 93095, 696, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5267969, 93111, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268244, 93118, 248, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268495, 93124, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268748, 93130, 245, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5268996, 93136, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269269, 93143, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269519, 93149, 272, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5269794, 93156, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270044, 93162, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270306, 93168, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5270556, 93174, 262704, 4503, 345, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533297, 97682, 379, 9, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533679, 97693, 256, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5533938, 97699, 242, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534183, 97705, 371, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534557, 97715, 361, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5534921, 97725, 108234, 2511, 1622, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643158, 100238, 369, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643530, 100248, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5643785, 100254, 559, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5644347, 100268, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5644611, 100274, 401, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645015, 100285, 266, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645284, 100291, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645548, 100297, 264, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5645815, 100303, 531, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646349, 100317, 247, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646599, 100323, 258, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5646860, 100329, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647114, 100335, 375, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647492, 100346, 437, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5647932, 100359, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5648195, 100365, 4314, 95, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5652512, 100462, 265, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5652780, 100468, 347, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653130, 100478, 377, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653510, 100489, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5653764, 100495, 389, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654156, 100505, 369, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654528, 100515, 375, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5654906, 100525, 240, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5655149, 100531, 401, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5655553, 100542, 468, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5656024, 100554, 709, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5656736, 100570, 407, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5657146, 100581, 695, 14, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5657844, 100597, 275, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658122, 100604, 249, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658374, 100610, 253, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658630, 100616, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5658879, 100622, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659152, 100629, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659401, 100635, 270, 5, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659674, 100642, 250, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5659927, 100648, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5660189, 100654, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[5660438, 100660, 731212, 12186, 366, 728615, 12140, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6391687, 112851, 383, 9, 89, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392073, 112862, 244, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392320, 112868, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392575, 112874, 239, 4, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6392817, 112880, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6393190, 112890, 360, 8, 19, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6393553, 112900, 111108, 2564, 1654, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6504664, 115466, 368, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505035, 115476, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505289, 115482, 560, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6505852, 115496, 262, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506117, 115502, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506520, 115513, 267, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6506790, 115519, 260, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507053, 115525, 261, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507317, 115531, 527, 12, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6507847, 115545, 246, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508096, 115551, 257, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508356, 115557, 252, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508611, 115563, 374, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6508988, 115574, 436, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6509427, 115587, 259, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6509689, 115593, 4313, 95, 52, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514005, 115690, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514259, 115696, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514513, 115702, 263, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6514779, 115708, 352, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515134, 115718, 444, 11, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515581, 115731, 251, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6515835, 115737, 399, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6516237, 115748, 370, 8, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6516610, 115758, 784, 18, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6517397, 115778, 400, 9, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6517800, 115789, 466, 10, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6518269, 115801, 709, 14, 22, "Message",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6518981, 115817, 829, 19, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[6519813, 115838, 1810585, 29865, 285, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330401, 145705, 242, 4, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330680, 145714, 126, 2, 24, "Input",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8330809, 145718, 826, 19, 20, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
  Cell[8331638, 145739, 1048347, 18090, 304, "Print",
   CellTags->{"Solar Array Example", "PR7.3", "PR7."}]},
 "7.4"->{
  Cell[9380171, 163840, 108, 1, 60, "Section",
   CellTags->{"7.4", "Cellular Array Example", "PR7.4", "PR7."}]},
 "PR7.4"->{
  Cell[9380171, 163840, 108, 1, 60, "Section",
   CellTags->{"7.4", "Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380282, 163843, 182, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380467, 163849, 174, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380666, 163857, 119, 2, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9380788, 163861, 200, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381003, 163868, 172, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381178, 163874, 204, 5, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381385, 163881, 178, 4, 24, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381566, 163887, 250, 11, 138, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9381841, 163902, 202, 6, 57, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9382046, 163910, 682, 21, 24, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9382765, 163936, 245, 8, 89, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[9383013, 163946, 7130157, 126334, 404, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513207, 290285, 412, 10, 122, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513622, 290297, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16513883, 290303, 242, 4, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514128, 290309, 373, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514504, 290319, 363, 8, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16514870, 290329, 286398, 6012, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801271, 296343, 373, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801647, 296353, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16801904, 296359, 558, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16802465, 296373, 263, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16802731, 296379, 402, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803136, 296390, 267, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803406, 296396, 263, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803672, 296402, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16803939, 296408, 531, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804473, 296422, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804725, 296428, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16804986, 296434, 253, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16805242, 296440, 377, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16805622, 296451, 439, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16806064, 296464, 260, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16806327, 296470, 3765, 84, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810095, 296556, 269, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810367, 296562, 349, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16810719, 296572, 379, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811101, 296583, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811358, 296589, 389, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16811750, 296599, 371, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812124, 296609, 375, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812502, 296619, 240, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16812745, 296625, 405, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16813153, 296636, 582, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16813738, 296652, 735, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16814476, 296668, 413, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16814892, 296679, 699, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16815594, 296695, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16815872, 296702, 251, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816126, 296708, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816384, 296714, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816635, 296720, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16816913, 296727, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817189, 296734, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817465, 296741, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817716, 296747, 271, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16817990, 296754, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818266, 296761, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818544, 296768, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16818820, 296775, 275, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819098, 296782, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819374, 296789, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819641, 296795, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16819894, 296801, 160382, 2849, 357, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980279, 299652, 257, 5, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980573, 299662, 412, 11, 122, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16980988, 299675, 259, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981250, 299681, 245, 4, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981498, 299687, 374, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16981875, 299697, 364, 8, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[16982242, 299707, 282864, 5951, 3012, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265109, 305660, 372, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265484, 305670, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17265742, 305676, 562, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266307, 305690, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266574, 305696, 406, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17266983, 305707, 268, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267254, 305713, 264, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267521, 305719, 265, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17267789, 305725, 534, 12, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268326, 305739, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268579, 305745, 258, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17268840, 305751, 254, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269097, 305757, 378, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269478, 305768, 440, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17269921, 305781, 260, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17270184, 305787, 3007, 66, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273194, 305855, 268, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273465, 305861, 350, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17273818, 305871, 380, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274201, 305882, 255, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274459, 305888, 394, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17274856, 305898, 372, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275231, 305908, 375, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275609, 305918, 241, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17275853, 305924, 402, 9, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17276258, 305935, 590, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17276851, 305951, 735, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17277589, 305967, 700, 14, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[17278292, 305983, 6102990, 119951, 32772, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[23381285, 425936, 246, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[23381534, 425942, 6406134, 124480, 49716, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29787671, 550424, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29787923, 550430, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788200, 550437, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788477, 550444, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29788754, 550451, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789006, 550457, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789283, 550464, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789560, 550471, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29789837, 550478, 276, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790116, 550485, 274, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790393, 550492, 273, 5, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[29790669, 550499, 721694, 12827, 314, 587316, 10621, "CachedBoxData", 
  "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30512366, 563328, 235, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30512638, 563337, 410, 10, 106, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513051, 563349, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513287, 563354, 221, 3, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513511, 563359, 350, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30513864, 563368, 340, 7, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30514207, 563377, 286002, 6005, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800212, 569384, 350, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800565, 569393, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30800799, 569398, 538, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801340, 569411, 240, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801583, 569416, 380, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30801966, 569426, 245, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802214, 569431, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802456, 569436, 243, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30802702, 569441, 508, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803213, 569454, 226, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803442, 569459, 237, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803682, 569464, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30803915, 569469, 354, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804272, 569479, 416, 10, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804691, 569491, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30804933, 569496, 3100, 67, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808036, 569565, 246, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808285, 569570, 328, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808616, 569579, 358, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30808977, 569589, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809211, 569594, 366, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809580, 569603, 347, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30809930, 569612, 352, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810285, 569621, 217, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810505, 569626, 380, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30810888, 569636, 568, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30811459, 569651, 739, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30812201, 569667, 388, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30812592, 569677, 674, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813269, 569692, 251, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813523, 569698, 228, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813754, 569703, 232, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30813989, 569708, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814217, 569713, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814470, 569719, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814723, 569725, 249, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30814975, 569731, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815203, 569736, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815458, 569742, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815711, 569748, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30815964, 569754, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816217, 569760, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816470, 569766, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816725, 569772, 227, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30816955, 569777, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30817197, 569782, 225, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[30817425, 569787, 7747208, 134168, 271, 7579651, 131418, 
  "CachedBoxData", "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38564636, 703957, 232, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38564905, 703966, 439, 11, 106, "Input",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565347, 703979, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565583, 703984, 217, 3, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38565803, 703989, 348, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38566154, 703998, 338, 7, 19, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38566495, 704007, 286196, 6009, 3140, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38852694, 710018, 346, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853043, 710027, 229, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853275, 710032, 536, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38853814, 710045, 238, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854055, 710050, 378, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854436, 710060, 245, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854684, 710065, 240, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38854927, 710070, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855169, 710075, 506, 11, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855678, 710088, 224, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38855905, 710093, 233, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856141, 710098, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856374, 710103, 352, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38856729, 710113, 414, 10, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38857146, 710125, 235, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38857384, 710130, 3839, 85, 36, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861226, 710217, 242, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861471, 710222, 324, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38861798, 710231, 354, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862155, 710241, 231, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862389, 710246, 364, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38862756, 710255, 346, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863105, 710264, 349, 7, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863457, 710273, 215, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38863675, 710278, 378, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38864056, 710288, 566, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38864625, 710303, 737, 14, 22, "Message",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38865365, 710319, 386, 8, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38865754, 710329, 672, 13, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866429, 710344, 252, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866684, 710350, 226, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38866913, 710355, 230, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867146, 710360, 222, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867371, 710365, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867624, 710371, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38867875, 710377, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868126, 710383, 223, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868352, 710388, 250, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868605, 710394, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38868856, 710400, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869107, 710406, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869358, 710412, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869609, 710418, 248, 4, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38869860, 710424, 239, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38870102, 710429, 223, 3, 20, "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[38870328, 710434, 1245638, 22409, 357, 1051443, 19223, "CachedBoxData",
   "BoxData", "Print",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
  Cell[40115969, 732845, 232, 4, 23, "Output",
   CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"chapter 7 topics", 40116755, 732872},
 {"7.1 Introduction", 40116971, 732877},
 {"Lenticular Array Example", 40117701, 732894},
 {"Solar Array Example", 40130032, 733132},
 {"Cellular Array Example", 40149025, 733508},
 {"PR7.", 40172938, 733962},
 {"7.1", 40228153, 735032},
 {"PR7.1", 40228265, 735035},
 {"Info3614709718-4839658", 40228801, 735048},
 {"7.2", 40228971, 735053},
 {"PR7.2", 40229093, 735056},
 {"7.3", 40240809, 735280},
 {"PR7.3", 40240931, 735283},
 {"7.4", 40259713, 735655},
 {"PR7.4", 40259839, 735658}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 193, 3, 60, "Subtitle",
 CellTags->{
  "chapter 7 topics", "7.1 Introduction", "Lenticular Array Example", 
   "Solar Array Example", "Cellular Array Example", "PR7."}],
Cell[775, 27, 415, 17, 79, "Outline2",
 CellTags->"PR7."],
Cell[CellGroupData[{
Cell[1215, 48, 92, 1, 34, "Section",
 CellTags->{"7.1", "7.1 Introduction", "PR7.1", "PR7."}],
Cell[1310, 51, 559, 14, 38, "Text",
 CellTags->{
  "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
Cell[CellGroupData[{
Cell[1894, 69, 133, 2, 24, "Input",
 CellTags->{
  "Lenticular Array Example", "7.1 Introduction", "PR7.1", "PR7."}],
Cell[2030, 73, 2689, 37, 285, "Print",
 CellTags->{
  "7.1 Introduction", "Info3614709718-4839658", "Lenticular Array Example", 
   "PR7.", "PR7.1"}]
}, Open  ]],
Cell[4734, 113, 134, 3, 20, "Text",
 CellTags->"PR7."]
}, Open  ]],
Cell[CellGroupData[{
Cell[4905, 121, 112, 1, 60, "Section",
 CellTags->{"7.2", "Lenticular Array Example", "PR7.2", "PR7."}],
Cell[5020, 124, 344, 6, 20, "Text",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[5367, 132, 172, 4, 24, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[5542, 138, 169, 4, 24, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[CellGroupData[{
Cell[5736, 146, 340, 8, 73, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[6079, 156, 1393, 39, 40, "Output",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7509, 200, 159, 2, 24, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[7671, 204, 203, 4, 23, "Output",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7911, 213, 197, 5, 24, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[8111, 220, 2570598, 42917, 365, 2474895, 41345, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2578746, 43142, 436, 10, 89, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2579185, 43154, 260, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2579448, 43160, 248, 4, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2579699, 43166, 379, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2580081, 43176, 369, 8, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2580453, 43186, 41439, 961, 658, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2621895, 44149, 377, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2622275, 44159, 258, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2622536, 44165, 565, 12, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2623104, 44179, 267, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2623374, 44185, 407, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2623784, 44196, 272, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2624059, 44202, 266, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2624328, 44208, 270, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2624601, 44214, 535, 12, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2625139, 44228, 252, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2625394, 44234, 262, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2625659, 44240, 257, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2625919, 44246, 381, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2626303, 44257, 445, 11, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2626751, 44270, 264, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2627018, 44276, 4085, 88, 36, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2631106, 44366, 273, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2631382, 44372, 353, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2631738, 44382, 383, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2632124, 44393, 258, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2632385, 44399, 395, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2632783, 44409, 375, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2633161, 44419, 379, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2633543, 44429, 244, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2633790, 44435, 405, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2634198, 44446, 463, 10, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2634664, 44458, 709, 14, 22, "Message",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2635376, 44474, 412, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2635791, 44485, 700, 14, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2636494, 44501, 281, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2636778, 44508, 257, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2637038, 44514, 261, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2637302, 44520, 252, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2637557, 44526, 296, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2637856, 44533, 245, 4, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2638104, 44539, 296, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2638403, 44546, 247, 4, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2638653, 44552, 260, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2638916, 44558, 254, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2639173, 44564, 254, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2639430, 44570, 266, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2639699, 44576, 254, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[2639956, 44582, 423361, 8223, 438, 399729, 7832, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3063320, 52807, 261, 5, 23, "Output",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[3063618, 52817, 328, 8, 73, "Input",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3063949, 52827, 262, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3064214, 52833, 246, 4, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3064463, 52839, 377, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3064843, 52849, 367, 8, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3065213, 52859, 40289, 930, 626, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3105505, 53791, 377, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3105885, 53801, 260, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3106148, 53807, 567, 12, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3106718, 53821, 269, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3106990, 53827, 407, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3107400, 53838, 272, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3107675, 53844, 267, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3107945, 53850, 268, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3108216, 53856, 537, 12, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3108756, 53870, 253, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3109012, 53876, 264, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3109279, 53882, 257, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3109539, 53888, 381, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3109923, 53899, 443, 11, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3110369, 53912, 266, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3110638, 53918, 4085, 88, 36, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3114726, 54008, 273, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3115002, 54014, 355, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3115360, 54024, 383, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3115746, 54035, 258, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3116007, 54041, 395, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3116405, 54051, 375, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3116783, 54061, 379, 8, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3117165, 54071, 246, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3117414, 54077, 407, 9, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3117824, 54088, 476, 10, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3118303, 54100, 712, 14, 22, "Message",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3119018, 54116, 703, 14, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3119724, 54132, 281, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3120008, 54139, 257, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3120268, 54145, 259, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3120530, 54151, 254, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3120787, 54157, 298, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3121088, 54164, 245, 4, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3121336, 54170, 298, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3121637, 54177, 245, 4, 19, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3121885, 54183, 258, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3122146, 54189, 252, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3122401, 54195, 277, 5, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3122681, 54202, 254, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3122938, 54208, 266, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3123207, 54214, 251, 4, 20, "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3123461, 54220, 402790, 7889, 195, 400150, 7842, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}],
Cell[3526254, 62111, 259, 5, 23, "Output",
 CellTags->{"Lenticular Array Example", "PR7.2", "PR7."}]
}, Open  ]],
Cell[3526528, 62119, 134, 3, 20, "Text",
 CellTags->"PR7."]
}, Open  ]],
Cell[CellGroupData[{
Cell[3526699, 62127, 102, 1, 60, "Section",
 CellTags->{"7.3", "Solar Array Example", "PR7.3", "PR7."}],
Cell[3526804, 62130, 166, 4, 24, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[3526973, 62136, 171, 4, 24, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[3527147, 62142, 431, 10, 106, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[CellGroupData[{
Cell[3527603, 62156, 198, 5, 24, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[3527804, 62163, 590032, 10134, 365, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[4117873, 72302, 151, 2, 24, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4118027, 72306, 714894, 11684, 232, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[4832958, 83995, 442, 11, 89, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4833403, 84008, 252, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4833658, 84014, 239, 4, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4833900, 84020, 370, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4834273, 84030, 362, 8, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4834638, 84040, 109392, 2541, 1638, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4944033, 86583, 368, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4944404, 86593, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4944658, 86599, 560, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4945221, 86613, 260, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4945484, 86619, 400, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4945887, 86630, 265, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4946155, 86636, 260, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4946418, 86642, 261, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4946682, 86648, 530, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4947215, 86662, 246, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4947464, 86668, 255, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4947722, 86674, 250, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4947975, 86680, 376, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4948354, 86691, 435, 11, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4948792, 86704, 257, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4949052, 86710, 4145, 92, 52, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4953200, 86804, 264, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4953467, 86810, 345, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4953815, 86820, 375, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4954193, 86831, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4954447, 86837, 386, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4954836, 86847, 370, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4955209, 86857, 374, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4955586, 86867, 237, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4955826, 86873, 400, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4956229, 86884, 463, 10, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4956695, 86896, 705, 14, 22, "Message",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4957403, 86912, 692, 14, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4958098, 86928, 272, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4958373, 86935, 248, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4958624, 86941, 252, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4958879, 86947, 245, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4959127, 86953, 270, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4959400, 86960, 245, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4959648, 86966, 272, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4959923, 86973, 249, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4960175, 86979, 261, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4960439, 86985, 245, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[4960687, 86991, 182103, 3182, 345, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[5142827, 90178, 442, 11, 89, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5143272, 90191, 253, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5143528, 90197, 241, 4, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5143772, 90203, 370, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5144145, 90213, 360, 8, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5144508, 90223, 109392, 2541, 1638, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5253903, 92766, 368, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5254274, 92776, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5254528, 92782, 558, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5255089, 92796, 260, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5255352, 92802, 399, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5255754, 92813, 265, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5256022, 92819, 260, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5256285, 92825, 261, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5256549, 92831, 528, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5257080, 92845, 246, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5257329, 92851, 255, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5257587, 92857, 250, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5257840, 92863, 376, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5258219, 92874, 436, 11, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5258658, 92887, 259, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5258920, 92893, 4147, 92, 52, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5263070, 92987, 264, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5263337, 92993, 346, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5263686, 93003, 378, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5264067, 93014, 250, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5264320, 93020, 388, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5264711, 93030, 366, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5265080, 93040, 372, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5265455, 93050, 237, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5265695, 93056, 398, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5266096, 93067, 463, 10, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5266562, 93079, 705, 14, 22, "Message",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5267270, 93095, 696, 14, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5267969, 93111, 272, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5268244, 93118, 248, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5268495, 93124, 250, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5268748, 93130, 245, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5268996, 93136, 270, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5269269, 93143, 247, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5269519, 93149, 272, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5269794, 93156, 247, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5270044, 93162, 259, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5270306, 93168, 247, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5270556, 93174, 262704, 4503, 345, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[5533297, 97682, 379, 9, 89, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5533679, 97693, 256, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5533938, 97699, 242, 4, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5534183, 97705, 371, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5534557, 97715, 361, 8, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5534921, 97725, 108234, 2511, 1622, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5643158, 100238, 369, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5643530, 100248, 252, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5643785, 100254, 559, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5644347, 100268, 261, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5644611, 100274, 401, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5645015, 100285, 266, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5645284, 100291, 261, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5645548, 100297, 264, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5645815, 100303, 531, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5646349, 100317, 247, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5646599, 100323, 258, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5646860, 100329, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5647114, 100335, 375, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5647492, 100346, 437, 11, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5647932, 100359, 260, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5648195, 100365, 4314, 95, 52, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5652512, 100462, 265, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5652780, 100468, 347, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5653130, 100478, 377, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5653510, 100489, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5653764, 100495, 389, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5654156, 100505, 369, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5654528, 100515, 375, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5654906, 100525, 240, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5655149, 100531, 401, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5655553, 100542, 468, 10, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5656024, 100554, 709, 14, 22, "Message",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5656736, 100570, 407, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5657146, 100581, 695, 14, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5657844, 100597, 275, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5658122, 100604, 249, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5658374, 100610, 253, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5658630, 100616, 246, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5658879, 100622, 270, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5659152, 100629, 246, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5659401, 100635, 270, 5, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5659674, 100642, 250, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5659927, 100648, 259, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5660189, 100654, 246, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[5660438, 100660, 731212, 12186, 366, 728615, 12140, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[6391687, 112851, 383, 9, 89, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6392073, 112862, 244, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6392320, 112868, 252, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6392575, 112874, 239, 4, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6392817, 112880, 370, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6393190, 112890, 360, 8, 19, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6393553, 112900, 111108, 2564, 1654, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6504664, 115466, 368, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6505035, 115476, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6505289, 115482, 560, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6505852, 115496, 262, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6506117, 115502, 400, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6506520, 115513, 267, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6506790, 115519, 260, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6507053, 115525, 261, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6507317, 115531, 527, 12, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6507847, 115545, 246, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6508096, 115551, 257, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6508356, 115557, 252, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6508611, 115563, 374, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6508988, 115574, 436, 11, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6509427, 115587, 259, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6509689, 115593, 4313, 95, 52, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6514005, 115690, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6514259, 115696, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6514513, 115702, 263, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6514779, 115708, 352, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6515134, 115718, 444, 11, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6515581, 115731, 251, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6515835, 115737, 399, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6516237, 115748, 370, 8, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6516610, 115758, 784, 18, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6517397, 115778, 400, 9, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6517800, 115789, 466, 10, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6518269, 115801, 709, 14, 22, "Message",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6518981, 115817, 829, 19, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[6519813, 115838, 1810585, 29865, 285, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[8330401, 145705, 242, 4, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[8330680, 145714, 126, 2, 24, "Input",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[8330809, 145718, 826, 19, 20, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}],
Cell[8331638, 145739, 1048347, 18090, 304, "Print",
 CellTags->{"Solar Array Example", "PR7.3", "PR7."}]
}, Open  ]],
Cell[9380000, 163832, 134, 3, 20, "Text",
 CellTags->"PR7."]
}, Open  ]],
Cell[CellGroupData[{
Cell[9380171, 163840, 108, 1, 60, "Section",
 CellTags->{"7.4", "Cellular Array Example", "PR7.4", "PR7."}],
Cell[9380282, 163843, 182, 4, 24, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9380467, 163849, 174, 4, 24, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[CellGroupData[{
Cell[9380666, 163857, 119, 2, 24, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9380788, 163861, 200, 4, 23, "Output",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[9381003, 163868, 172, 4, 24, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9381178, 163874, 204, 5, 24, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9381385, 163881, 178, 4, 24, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9381566, 163887, 250, 11, 138, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[CellGroupData[{
Cell[9381841, 163902, 202, 6, 57, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9382046, 163910, 682, 21, 24, "Output",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[9382765, 163936, 245, 8, 89, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[9383013, 163946, 7130157, 126334, 404, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[16513207, 290285, 412, 10, 122, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16513622, 290297, 258, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16513883, 290303, 242, 4, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16514128, 290309, 373, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16514504, 290319, 363, 8, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16514870, 290329, 286398, 6012, 3140, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16801271, 296343, 373, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16801647, 296353, 254, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16801904, 296359, 558, 12, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16802465, 296373, 263, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16802731, 296379, 402, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16803136, 296390, 267, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16803406, 296396, 263, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16803672, 296402, 264, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16803939, 296408, 531, 12, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16804473, 296422, 249, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16804725, 296428, 258, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16804986, 296434, 253, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16805242, 296440, 377, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16805622, 296451, 439, 11, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16806064, 296464, 260, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16806327, 296470, 3765, 84, 36, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16810095, 296556, 269, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16810367, 296562, 349, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16810719, 296572, 379, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16811101, 296583, 254, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16811358, 296589, 389, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16811750, 296599, 371, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16812124, 296609, 375, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16812502, 296619, 240, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16812745, 296625, 405, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16813153, 296636, 582, 14, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16813738, 296652, 735, 14, 22, "Message",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16814476, 296668, 413, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16814892, 296679, 699, 14, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16815594, 296695, 275, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16815872, 296702, 251, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16816126, 296708, 255, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16816384, 296714, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16816635, 296720, 275, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16816913, 296727, 273, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16817189, 296734, 273, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16817465, 296741, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16817716, 296747, 271, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16817990, 296754, 273, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16818266, 296761, 275, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16818544, 296768, 273, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16818820, 296775, 275, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16819098, 296782, 273, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16819374, 296789, 264, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16819641, 296795, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16819894, 296801, 160382, 2849, 357, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16980279, 299652, 257, 5, 23, "Output",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[16980573, 299662, 412, 11, 122, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16980988, 299675, 259, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16981250, 299681, 245, 4, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16981498, 299687, 374, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16981875, 299697, 364, 8, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[16982242, 299707, 282864, 5951, 3012, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17265109, 305660, 372, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17265484, 305670, 255, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17265742, 305676, 562, 12, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17266307, 305690, 264, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17266574, 305696, 406, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17266983, 305707, 268, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17267254, 305713, 264, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17267521, 305719, 265, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17267789, 305725, 534, 12, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17268326, 305739, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17268579, 305745, 258, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17268840, 305751, 254, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17269097, 305757, 378, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17269478, 305768, 440, 11, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17269921, 305781, 260, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17270184, 305787, 3007, 66, 36, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17273194, 305855, 268, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17273465, 305861, 350, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17273818, 305871, 380, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17274201, 305882, 255, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17274459, 305888, 394, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17274856, 305898, 372, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17275231, 305908, 375, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17275609, 305918, 241, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17275853, 305924, 402, 9, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17276258, 305935, 590, 14, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17276851, 305951, 735, 14, 22, "Message",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17277589, 305967, 700, 14, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[17278292, 305983, 6102990, 119951, 32772, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[23381285, 425936, 246, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[23381534, 425942, 6406134, 124480, 49716, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29787671, 550424, 249, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29787923, 550430, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29788200, 550437, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29788477, 550444, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29788754, 550451, 249, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29789006, 550457, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29789283, 550464, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29789560, 550471, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29789837, 550478, 276, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29790116, 550485, 274, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29790393, 550492, 273, 5, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[29790669, 550499, 721694, 12827, 314, 587316, 10621, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30512366, 563328, 235, 4, 23, "Output",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[30512638, 563337, 410, 10, 106, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30513051, 563349, 233, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30513287, 563354, 221, 3, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30513511, 563359, 350, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30513864, 563368, 340, 7, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30514207, 563377, 286002, 6005, 3140, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30800212, 569384, 350, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30800565, 569393, 231, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30800799, 569398, 538, 11, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30801340, 569411, 240, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30801583, 569416, 380, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30801966, 569426, 245, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30802214, 569431, 239, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30802456, 569436, 243, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30802702, 569441, 508, 11, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30803213, 569454, 226, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30803442, 569459, 237, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30803682, 569464, 230, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30803915, 569469, 354, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30804272, 569479, 416, 10, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30804691, 569491, 239, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30804933, 569496, 3100, 67, 36, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30808036, 569565, 246, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30808285, 569570, 328, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30808616, 569579, 358, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30808977, 569589, 231, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30809211, 569594, 366, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30809580, 569603, 347, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30809930, 569612, 352, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30810285, 569621, 217, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30810505, 569626, 380, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30810888, 569636, 568, 13, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30811459, 569651, 739, 14, 22, "Message",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30812201, 569667, 388, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30812592, 569677, 674, 13, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30813269, 569692, 251, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30813523, 569698, 228, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30813754, 569703, 232, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30813989, 569708, 225, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30814217, 569713, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30814470, 569719, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30814723, 569725, 249, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30814975, 569731, 225, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30815203, 569736, 252, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30815458, 569742, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30815711, 569748, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30815964, 569754, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30816217, 569760, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30816470, 569766, 252, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30816725, 569772, 227, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30816955, 569777, 239, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30817197, 569782, 225, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[30817425, 569787, 7747208, 134168, 271, 7579651, 131418, \
"CachedBoxData", "BoxData", "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38564636, 703957, 232, 4, 23, "Output",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[38564905, 703966, 439, 11, 106, "Input",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38565347, 703979, 233, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38565583, 703984, 217, 3, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38565803, 703989, 348, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38566154, 703998, 338, 7, 19, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38566495, 704007, 286196, 6009, 3140, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38852694, 710018, 346, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38853043, 710027, 229, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38853275, 710032, 536, 11, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38853814, 710045, 238, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38854055, 710050, 378, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38854436, 710060, 245, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38854684, 710065, 240, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38854927, 710070, 239, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38855169, 710075, 506, 11, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38855678, 710088, 224, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38855905, 710093, 233, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38856141, 710098, 230, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38856374, 710103, 352, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38856729, 710113, 414, 10, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38857146, 710125, 235, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38857384, 710130, 3839, 85, 36, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38861226, 710217, 242, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38861471, 710222, 324, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38861798, 710231, 354, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38862155, 710241, 231, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38862389, 710246, 364, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38862756, 710255, 346, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38863105, 710264, 349, 7, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38863457, 710273, 215, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38863675, 710278, 378, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38864056, 710288, 566, 13, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38864625, 710303, 737, 14, 22, "Message",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38865365, 710319, 386, 8, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38865754, 710329, 672, 13, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38866429, 710344, 252, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38866684, 710350, 226, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38866913, 710355, 230, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38867146, 710360, 222, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38867371, 710365, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38867624, 710371, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38867875, 710377, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38868126, 710383, 223, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38868352, 710388, 250, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38868605, 710394, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38868856, 710400, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38869107, 710406, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38869358, 710412, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38869609, 710418, 248, 4, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38869860, 710424, 239, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38870102, 710429, 223, 3, 20, "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[38870328, 710434, 1245638, 22409, 357, 1051443, 19223, "CachedBoxData", \
"BoxData", "Print",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}],
Cell[40115969, 732845, 232, 4, 23, "Output",
 CellTags->{"Cellular Array Example", "PR7.4", "PR7."}]
}, Open  ]],
Cell[40116216, 732852, 134, 3, 20, "Text",
 CellTags->"PR7."]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
